(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   6319291,     317503]*)
(*NotebookOutlinePosition[   6319982,     317527]*)
(*  CellTagsIndexPosition[   6319938,     317523]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["The Standard Map", "Subtitle"],

Cell["\<\
This notebook describes how to create various plots that illustrate \
the dynamics of the Standard Map.  For a more detailed explanation of these \
plots please refer to the lecture slides on conservative chaos.  The code for \
creating each plot is presented is such a way as to be self-contained. The \
code used to create each plot does not depend on anything that has been done \
earlier in the notebook.  As a result, many portions of code (such as the \
definition of the mapping function) are repeated unnecessarily.  The \
advantage of presenting the code this way is that it should be easy to cut \
and paste any piece of code into a new notebook and get it working \
immediately.\
\>", "Text"],

Cell["\<\
Note that animations can be created by generating several plots, \
putting them into a correct sequence, selecting the plots, and then choosing \
Animate Selected Graphics from the Cell menu.    To save an animation in \
QuickTime format, just select the plots and choose Save Selection As: \
QuickTime from the Edit menu (Mac only).\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " basics"
}], "Section"],

Cell[TextData[{
  "The most important ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions for studying one dimensional maps are ",
  StyleBox["Nest", "Input"],
  ", and ",
  StyleBox["NestList", "Input"],
  ".  ",
  StyleBox["Nest ", "Input"],
  "calculates the result of iterating a function a certain number of times, \
using a certain initial value for the variable. ",
  StyleBox[" NestList", "Input"],
  " calculates each result in the iteration process and forms all of these \
results into a list.  The examples below illustrate how these functions can \
be used with the Standard Map."
}], "Text"],

Cell["First, we must define the function we wish to iterate.", "Text"],

Cell[BoxData[{
    \(\(K = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(f[{\[Theta]_, r_}] := 
        N[{Mod[\[Theta] + r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1], 
            Mod[r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 
              1]}];\)\)}], "Input"],

Cell[TextData[{
  "Now suppose we wanted to find the result of iterating this function four \
times using an initial point {0.3,0.7}.  In other words, we want to find \
f(f(f(f({0.3,0.7})))).  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " we can simply use the ",
  StyleBox["Nest", "Input"],
  " function to generate this result."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Nest[f, {0.3, 0.7}, 4]\)], "Input"],

Cell[BoxData[
    \({0.641932137270538`, 0.47727432499894884`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "If we wish to see a list of all of the first four iterates of f, using an \
initial point {0.3,0.7}, we use ",
  StyleBox["NestList", "Input"],
  " instead."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[f, {0.3, 0.7}, 4]\)], "Input"],

Cell[BoxData[
    \({{0.3`, 0.7`}, {0.7729519814078029`, 
        0.4729519814078028`}, {0.4821582211174693`, 
        0.7092062397096666`}, {0.16465781227158915`, 
        0.6824995911541197`}, {0.641932137270538`, 
        0.47727432499894884`}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that this list contains five elements, the first element being our \
initial point (or the ",
  Cell[BoxData[
      \(TraditionalForm\`0\^th\)]],
  " of the map)."
}], "Text",
  FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Surfaces of Section", "Section"],

Cell[TextData[{
  "We can generate Poincare surfaces of section by applying NestList to \
several different initial points in phase space.  In the example below each \
initial point is used to generate 400 other points through iteration of the \
map with K=0.8.  The initial points are chosen to have \[Theta]=0 or \
\[Theta]=0.5, with 20 different values for r distributed evenly from 0 to 1.  \
This example uses the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions ",
  StyleBox["Table", "Input"],
  ", ",
  StyleBox["Flatten", "Input"],
  ", ",
  StyleBox["Join", "Input"],
  ", and ",
  StyleBox["ListPlot", "Input"],
  ".  For more information on these functions see the online help in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(K = 0.8; n = 400; \[Theta]1 = 0; \[Theta]2 = 0.5; nr = 20;\), "\n", 
    \(\(f[{\[Theta]_, r_}] := 
        N[{Mod[\[Theta] + r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1], 
            Mod[r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1]}];\)\), "\n", 
    \(\(MapData\  = \ 
        Flatten[Table[
            Join[NestList[f, {\[Theta]1, i/nr}, n], 
              NestList[f, {\[Theta]2, i/nr}, n]], {i, 0, nr}], 
          1];\)\), "\n", 
    \(ListPlot[MapData, PlotStyle \[Rule] PointSize[0.002], 
      PlotRange \[Rule] {{0, 1}, {0, 1}}, Frame \[Rule] True, 
      RotateLabel \[Rule] False, 
      FrameLabel \[Rule] {"\<\[Theta]\>", "\<r\>", "\<\>", "\<\>"}, 
      Axes \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
0 .0309 Mdot
.05 .0309 Mdot
.06065 .00658 Mdot
.02395 .59535 Mdot
.96816 .58355 Mdot
.93767 .59919 Mdot
.95578 .01119 Mdot
.00881 .03278 Mdot
.0548 .02842 Mdot
.05781 .00186 Mdot
.01558 .59194 Mdot
.96091 .58425 Mdot
.9372 .60338 Mdot
.96243 .0156 Mdot
.01745 .034 Mdot
.05853 .02539 Mdot
.05384 .61513 Mdot
.00689 .58902 Mdot
.95444 .58561 Mdot
.93793 .60784 Mdot
.96984 .01972 Mdot
.02572 .03454 Mdot
.06112 .02188 Mdot
.04882 .61043 Mdot
.99807 .58667 Mdot
.94886 .58763 Mdot
.93987 .61248 Mdot
.97784 .02347 Mdot
.03349 .03439 Mdot
.06254 .01795 Mdot
.04283 .60586 Mdot
.98928 .58493 Mdot
.94429 .59023 Mdot
.94297 .61722 Mdot
.9863 .02678 Mdot
.04058 .03355 Mdot
.06274 .0137 Mdot
.03601 .60151 Mdot
.98071 .58386 Mdot
.94081 .59337 Mdot
.94717 .00394 Mdot
.99503 .02958 Mdot
.04686 .03203 Mdot
.06174 .0092 Mdot
.02846 .59746 Mdot
.97253 .58347 Mdot
.93847 .59698 Mdot
.95241 .00862 Mdot
.00387 .0318 Mdot
.05223 .02989 Mdot
.05955 .00453 Mdot
.02034 .5938 Mdot
.9649 .58377 Mdot
.93731 .60099 Mdot
.95859 .01315 Mdot
.01262 .03339 Mdot
.05657 .02716 Mdot
.0562 .61781 Mdot
.01181 .5906 Mdot
.95797 .58476 Mdot
.93737 .6053 Mdot
.96559 .01744 Mdot
.02112 .03432 Mdot
.05981 .02391 Mdot
.05176 .61306 Mdot
.00304 .58792 Mdot
.95188 .58642 Mdot
.93864 .60985 Mdot
.97328 .02141 Mdot
.02919 .03456 Mdot
.06189 .02021 Mdot
.04631 .60841 Mdot
.9942 .58583 Mdot
.94673 .5887 Mdot
.94109 .61454 Mdot
.9815 .02498 Mdot
.03668 .0341 Mdot
.06278 .01613 Mdot
.03994 .60392 Mdot
.98549 .58438 Mdot
.94263 .59154 Mdot
.94468 .00127 Mdot
.9901 .02807 Mdot
.04344 .03296 Mdot
.06245 .01175 Mdot
.03278 .5997 Mdot
.97707 .5836 Mdot
.93964 .5949 Mdot
.94935 .006 Mdot
.9989 .03062 Mdot
.04933 .03117 Mdot
.06093 .00717 Mdot
.02497 .59581 Mdot
.96911 .58351 Mdot
.93781 .59869 Mdot
.95501 .01063 Mdot
.00772 .03258 Mdot
.05426 .02876 Mdot
.05822 .00245 Mdot
.01664 .59234 Mdot
.96177 .58412 Mdot
.93719 .60284 Mdot
.96156 .01506 Mdot
.01638 .03388 Mdot
.05812 .0258 Mdot
.05439 .61573 Mdot
.00799 .58936 Mdot
.9552 .58541 Mdot
.93778 .60727 Mdot
.96888 .01922 Mdot
.02472 .03451 Mdot
.06086 .02234 Mdot
.0495 .61101 Mdot
.99917 .58693 Mdot
.94951 .58734 Mdot
.93956 .61189 Mdot
.97682 .02302 Mdot
.03255 .03445 Mdot
.06243 .01846 Mdot
.04363 .60642 Mdot
.99037 .58511 Mdot
.9448 .58988 Mdot
.94252 .61662 Mdot
.98523 .02639 Mdot
.03974 .03369 Mdot
.06278 .01425 Mdot
.0369 .60204 Mdot
.98176 .58395 Mdot
.94118 .59295 Mdot
.94659 .00335 Mdot
.99393 .02926 Mdot
.04613 .03226 Mdot
.06193 .00977 Mdot
.02943 .59795 Mdot
.97352 .58348 Mdot
.93869 .59651 Mdot
.95171 .00804 Mdot
.00277 .03156 Mdot
.05161 .03019 Mdot
.05989 .00511 Mdot
.02138 .59423 Mdot
.96582 .5837 Mdot
.93739 .60047 Mdot
.95777 .0126 Mdot
.01154 .03323 Mdot
.05608 .02753 Mdot
.05668 .00037 Mdot
.01289 .59097 Mdot
.95879 .5846 Mdot
.9373 .60475 Mdot
.96468 .01692 Mdot
.02008 .03424 Mdot
.05946 .02434 Mdot
.05237 .61365 Mdot
.00414 .58822 Mdot
.95259 .58618 Mdot
.93841 .60927 Mdot
.97228 .02093 Mdot
.02822 .03457 Mdot
.06169 .02069 Mdot
.04704 .60898 Mdot
.9953 .58606 Mdot
.94732 .58838 Mdot
.94072 .61395 Mdot
.98045 .02456 Mdot
.03578 .0342 Mdot
.06273 .01665 Mdot
.04078 .60447 Mdot
.98656 .58452 Mdot
.94308 .59116 Mdot
.94417 .00067 Mdot
.98901 .02771 Mdot
.04264 .03314 Mdot
.06256 .01231 Mdot
.03371 .60021 Mdot
.9781 .58366 Mdot
.93995 .59446 Mdot
.94871 .00541 Mdot
.9978 .03034 Mdot
.04865 .03143 Mdot
.06118 .00775 Mdot
.02597 .59627 Mdot
.97007 .58349 Mdot
.93798 .5982 Mdot
.95425 .01006 Mdot
.00662 .03237 Mdot
.0537 .02909 Mdot
.05862 .00304 Mdot
.0177 .59274 Mdot
.96265 .58401 Mdot
.9372 .60231 Mdot
.9607 .01452 Mdot
.01532 .03376 Mdot
.0577 .02619 Mdot
.05493 .61632 Mdot
.00908 .5897 Mdot
.95597 .58521 Mdot
.93764 .6067 Mdot
.96793 .01872 Mdot
.0237 .03447 Mdot
.06058 .02279 Mdot
.05016 .61159 Mdot
.00027 .5872 Mdot
.95016 .58707 Mdot
.93928 .61131 Mdot
.9758 .02257 Mdot
.03161 .03449 Mdot
.0623 .01897 Mdot
.04441 .60698 Mdot
.99146 .58531 Mdot
.94533 .58953 Mdot
.94209 .61603 Mdot
.98416 .026 Mdot
.03888 .03382 Mdot
.06281 .01479 Mdot
.03778 .60257 Mdot
.98281 .58406 Mdot
.94157 .59254 Mdot
.94603 .00275 Mdot
.99284 .02893 Mdot
.04538 .03247 Mdot
.06211 .01034 Mdot
.0304 .59844 Mdot
.97452 .5835 Mdot
.93894 .59604 Mdot
.95102 .00746 Mdot
.00166 .0313 Mdot
.05098 .03048 Mdot
.06021 .0057 Mdot
.02241 .59467 Mdot
.96674 .58363 Mdot
.93749 .59995 Mdot
.95697 .01204 Mdot
.01046 .03306 Mdot
.05558 .02789 Mdot
.05714 .00096 Mdot
.01396 .59135 Mdot
.95963 .58445 Mdot
.93724 .6042 Mdot
.96377 .0164 Mdot
.01904 .03415 Mdot
.0591 .02476 Mdot
.05297 .61424 Mdot
.00524 .58853 Mdot
.95332 .58594 Mdot
.93821 .6087 Mdot
.9713 .02045 Mdot
.02723 .03457 Mdot
.06148 .02117 Mdot
.04776 .60955 Mdot
.9964 .58629 Mdot
.94792 .58807 Mdot
.94037 .61336 Mdot
.97941 .02413 Mdot
.03488 .03428 Mdot
.06267 .01718 Mdot
.04161 .60502 Mdot
.98764 .58468 Mdot
.94355 .59078 Mdot
.94368 8e-05 Mdot
.98793 .02735 Mdot
.04183 .03331 Mdot
.06265 .01287 Mdot
.03464 .60072 Mdot
.97913 .58373 Mdot
.94028 .59402 Mdot
.94808 .00483 Mdot
.99669 .03004 Mdot
.04795 .03168 Mdot
.06142 .00833 Mdot
.02697 .59674 Mdot
.97104 .58347 Mdot
.93816 .59771 Mdot
.95351 .00949 Mdot
.00553 .03215 Mdot
.05312 .02942 Mdot
.05901 .00364 Mdot
.01876 .59316 Mdot
.96354 .58391 Mdot
.93723 .60178 Mdot
.95985 .01398 Mdot
.01425 .03362 Mdot
.05726 .02658 Mdot
.05545 .61691 Mdot
.01017 .59005 Mdot
.95676 .58502 Mdot
.93752 .60614 Mdot
.96699 .01821 Mdot
.02268 .03442 Mdot
.06029 .02324 Mdot
.05081 .61218 Mdot
.00137 .58748 Mdot
.95084 .5868 Mdot
.93901 .61072 Mdot
.97479 .02211 Mdot
.03065 .03453 Mdot
.06215 .01946 Mdot
.04518 .60755 Mdot
.99255 .58551 Mdot
.94588 .58919 Mdot
.94168 .61544 Mdot
.98309 .0256 Mdot
.03801 .03394 Mdot
.06281 .01532 Mdot
.03865 .6031 Mdot
.98388 .58418 Mdot
.94198 .59214 Mdot
.94548 .00216 Mdot
.99174 .0286 Mdot
.04461 .03268 Mdot
.06226 .0109 Mdot
.03136 .59894 Mdot
.97553 .58353 Mdot
.9392 .59558 Mdot
.95034 .00688 Mdot
.00056 .03104 Mdot
.05034 .03076 Mdot
.06051 .00629 Mdot
.02343 .59512 Mdot
.96768 .58358 Mdot
.9376 .59945 Mdot
.95618 .01148 Mdot
.00937 .03287 Mdot
.05507 .02824 Mdot
.05759 .00156 Mdot
.01504 .59174 Mdot
.96047 .58431 Mdot
.93721 .60366 Mdot
.96288 .01587 Mdot
.01798 .03405 Mdot
.05873 .02518 Mdot
.05355 .61483 Mdot
.00633 .58885 Mdot
.95405 .58572 Mdot
.93802 .60813 Mdot
.97033 .01997 Mdot
.02624 .03455 Mdot
.06125 .02164 Mdot
.04846 .61013 Mdot
.9975 .58654 Mdot
.94854 .58777 Mdot
.94003 .61277 Mdot
.97837 .02369 Mdot
.03396 .03436 Mdot
.06259 .01769 Mdot
.04242 .60557 Mdot
.98872 .58485 Mdot
.94404 .59042 Mdot
.9432 .61752 Mdot
.98685 .02697 Mdot
.041 .03347 Mdot
.06272 .01342 Mdot
.03555 .60124 Mdot
.98017 .58381 Mdot
.94062 .59359 Mdot
.94748 .00424 Mdot
.99559 .02974 Mdot
.04723 .03192 Mdot
.06164 .0089 Mdot
.02796 .59722 Mdot
.97202 .58347 Mdot
.93836 .59723 Mdot
.95278 .00891 Mdot
.00443 .03192 Mdot
.05253 .02973 Mdot
.05937 .00423 Mdot
.01981 .59358 Mdot
.96444 .58381 Mdot
.93728 .60125 Mdot
.95901 .01343 Mdot
.01317 .03347 Mdot
.05681 .02697 Mdot
.05595 .61751 Mdot
.01125 .59041 Mdot
.95756 .58485 Mdot
.93742 .60558 Mdot
.96606 .0177 Mdot
.02165 .03436 Mdot
.05997 .02369 Mdot
.05145 .61276 Mdot
.00248 .58777 Mdot
.95152 .58654 Mdot
.93876 .61014 Mdot
.97378 .02165 Mdot
.02969 .03455 Mdot
.06198 .01996 Mdot
.04593 .60811 Mdot
.99364 .58572 Mdot
.94644 .58886 Mdot
.94128 .61484 Mdot
.98204 .02519 Mdot
.03713 .03405 Mdot
.06279 .01586 Mdot
.03951 .60365 Mdot
.98494 .58431 Mdot
.9424 .59174 Mdot
.94494 .00157 Mdot
.99065 .02825 Mdot
.04384 .03287 Mdot
.06239 .01147 Mdot
.0323 .59944 Mdot
.5 .0309 Mdot
.55 .0309 Mdot
.63935 .05522 Mdot
.82646 .11564 Mdot
.12649 .18543 Mdot
.33564 .12927 Mdot
.43547 .0617 Mdot
.48508 .03066 Mdot
.52277 .02329 Mdot
.57862 .03452 Mdot
.69484 .07183 Mdot
.93081 .14584 Mdot
.22041 .17898 Mdot
.38487 .10165 Mdot
.46506 .04956 Mdot
.51752 .03242 Mdot
.58398 .04107 Mdot
.71454 .08069 Mdot
.96928 .15744 Mdot
.24844 .17253 Mdot
.40029 .09385 Mdot
.47748 .04771 Mdot
.53672 .03661 Mdot
.62507 .0546 Mdot
.80349 .11027 Mdot
.10211 .18456 Mdot
.32453 .13747 Mdot
.43334 .06725 Mdot
.49037 .03524 Mdot
.53969 .03048 Mdot
.62044 .04991 Mdot
.7886 .10393 Mdot
.08037 .18032 Mdot
.31053 .14225 Mdot
.42247 .06918 Mdot
.47482 .03235 Mdot
.50709 .01995 Mdot
.54505 .02346 Mdot
.61856 .04543 Mdot
.77838 .09878 Mdot
.06351 .17622 Mdot
.29917 .14564 Mdot
.41353 .07068 Mdot
.46207 .03 Mdot
.48056 .01142 Mdot
.48353 .00184 Mdot
.47335 .61174 Mdot
.44194 .59863 Mdot
.36512 .57055 Mdot
.19285 .51156 Mdot
.90137 .43789 Mdot
.68385 .4836 Mdot
.5828 .55559 Mdot
.54506 .59471 Mdot
.54288 .61669 Mdot
.57459 .0196 Mdot
.6638 .05514 Mdot
.86212 .12257 Mdot
.15746 .18253 Mdot
.34639 .11677 Mdot
.43065 .05207 Mdot
.46116 .01886 Mdot
.46091 .61788 Mdot
.4297 .59874 Mdot
.34406 .5651 Mdot
.15268 .49976 Mdot
.85706 .43533 Mdot
.66102 .49688 Mdot
.57292 .56359 Mdot
.54114 .59839 Mdot
.5419 .00047 Mdot
.57579 .02095 Mdot
.66804 .05702 Mdot
.8711 .1255 Mdot
.16637 .18249 Mdot
.3515 .11441 Mdot
.43433 .05119 Mdot
.46609 .01963 Mdot
.47093 .00299 Mdot
.45265 .60673 Mdot
.39704 .58367 Mdot
.26468 .53624 Mdot
.00555 .45788 Mdot
.74198 .45514 Mdot
.60556 .53373 Mdot
.54755 .58218 Mdot
.527 .60534 Mdot
.52795 .00059 Mdot
.55115 .01434 Mdot
.61457 .03919 Mdot
.76192 .09107 Mdot
.03624 .16954 Mdot
.28182 .15178 Mdot
.40261 .07465 Mdot
.45026 .02945 Mdot
.45877 .00526 Mdot
.43466 .60313 Mdot
.35973 .57173 Mdot
.18657 .51101 Mdot
.89605 .43849 Mdot
.68291 .48631 Mdot
.58595 .55811 Mdot
.55445 .59857 Mdot
.56567 .00693 Mdot
.62796 .03849 Mdot
.78193 .09516 Mdot
.06067 .17227 Mdot
.29204 .143 Mdot
.40051 .06704 Mdot
.43446 .02099 Mdot
.41746 .60752 Mdot
.33734 .56852 Mdot
.1486 .50138 Mdot
.85751 .43813 Mdot
.66579 .49954 Mdot
.58397 .56747 Mdot
.56626 .60709 Mdot
.60003 .02087 Mdot
.70867 .06714 Mdot
.94036 .14319 Mdot
.21866 .17199 Mdot
.37209 .09482 Mdot
.43385 .03817 Mdot
.44421 .0064 Mdot
.41084 .59741 Mdot
.30982 .5556 Mdot
.09037 .4824 Mdot
.80244 .44009 Mdot
.63499 .51454 Mdot
.56304 .57357 Mdot
.54021 .60393 Mdot
.54921 .00556 Mdot
.59694 .0295 Mdot
.71753 .07453 Mdot
.9628 .15158 Mdot
.23756 .16981 Mdot
.38538 .09136 Mdot
.44924 .03946 Mdot
.47317 .01479 Mdot
.47573 .00158 Mdot
.45895 .60766 Mdot
.4097 .58759 Mdot
.29201 .5453 Mdot
.05142 .46934 Mdot
.7704 .44436 Mdot
.61566 .5224 Mdot
.54552 .57468 Mdot
.5113 .59688 Mdot
.4861 .60246 Mdot
.4498 .5956 Mdot
.37401 .57119 Mdot
.20762 .5152 Mdot
.9184 .43928 Mdot
.69164 .47788 Mdot
.58373 .55134 Mdot
.53976 .59086 Mdot
.52726 .61031 Mdot
.53646 .00569 Mdot
.57458 .02356 Mdot
.67019 .05909 Mdot
.87746 .1281 Mdot
.17335 .18287 Mdot
.35641 .11313 Mdot
.43955 .05138 Mdot
.47549 .02221 Mdot
.49189 .01014 Mdot
.5018 .00613 Mdot
.51316 .00702 Mdot
.53503 .01352 Mdot
.58469 .03069 Mdot
.69895 .07062 Mdot
.93404 .14529 Mdot
.2204 .17698 Mdot
.38163 .09965 Mdot
.45667 .04637 Mdot
.49746 .02521 Mdot
.53621 .02395 Mdot
.60368 .0417 Mdot
.74836 .08941 Mdot
.02035 .1681 Mdot
.27611 .15807 Mdot
.40625 .08043 Mdot
.46565 .03671 Mdot
.49779 .01986 Mdot
.52816 .01877 Mdot
.58094 .03262 Mdot
.69571 .07093 Mdot
.93046 .14509 Mdot
.2191 .17839 Mdot
.3828 .10117 Mdot
.46099 .04832 Mdot
.50828 .02923 Mdot
.56219 .03332 Mdot
.66461 .06329 Mdot
.87645 .13093 Mdot
.1775 .18606 Mdot
.36421 .11539 Mdot
.455 .05611 Mdot
.51027 .03416 Mdot
.57374 .03923 Mdot
.69412 .0744 Mdot
.93405 .14829 Mdot
.22525 .17997 Mdot
.39066 .10223 Mdot
.47531 .05232 Mdot
.54029 .04016 Mdot
.63716 .05987 Mdot
.83067 .11959 Mdot
.13549 .18839 Mdot
.34455 .12921 Mdot
.4481 .064 Mdot
.51086 .03879 Mdot
.58231 .04416 Mdot
.7167 .08306 Mdot
.97564 .16003 Mdot
.25399 .17203 Mdot
.40506 .09337 Mdot
.4846 .04916 Mdot
.55185 .04156 Mdot
.65984 .06674 Mdot
.87527 .13314 Mdot
.18057 .18869 Mdot
.37048 .11737 Mdot
.46784 .06017 Mdot
.53963 .04437 Mdot
.64281 .06377 Mdot
.84551 .12528 Mdot
.15329 .19022 Mdot
.35653 .12561 Mdot
.45993 .0639 Mdot
.53161 .0443 Mdot
.62841 .05983 Mdot
.81716 .11665 Mdot
.12206 .18844 Mdot
.33861 .13383 Mdot
.44706 .06703 Mdot
.51393 .04133 Mdot
.59194 .04821 Mdot
.73947 .09118 Mdot
.01404 .1697 Mdot
.2774 .16276 Mdot
.41531 .08524 Mdot
.48863 .04531 Mdot
.55286 .0397 Mdot
.65861 .06535 Mdot
.87126 .13142 Mdot
.17603 .18836 Mdot
.36698 .11802 Mdot
.46349 .05964 Mdot
.53104 .04175 Mdot
.62327 .057 Mdot
.80454 .11203 Mdot
.10574 .18615 Mdot
.32843 .13763 Mdot
.43895 .0683 Mdot
.50181 .03885 Mdot
.56612 .03974 Mdot
.68181 .0715 Mdot
.91332 .14308 Mdot
.21079 .18385 Mdot
.38479 .10754 Mdot
.47446 .05542 Mdot
.54378 .04284 Mdot
.64769 .06422 Mdot
.85351 .1272 Mdot
.16066 .18983 Mdot
.36003 .12321 Mdot
.4613 .06259 Mdot
.53192 .04365 Mdot
.62791 .05932 Mdot
.81556 .11597 Mdot
.11988 .18808 Mdot
.33712 .13426 Mdot
.44563 .06706 Mdot
.51148 .0407 Mdot
.58651 .04637 Mdot
.72738 .08706 Mdot
.99429 .16496 Mdot
.26577 .16778 Mdot
.41055 .08948 Mdot
.48748 .04754 Mdot
.5544 .04136 Mdot
.664 .06774 Mdot
.88278 .13521 Mdot
.18709 .18807 Mdot
.37389 .11545 Mdot
.47003 .05942 Mdot
.54234 .04469 Mdot
.64812 .06538 Mdot
.85602 .12849 Mdot
.16403 .19036 Mdot
.36283 .12287 Mdot
.465 .06314 Mdot
.53938 .04597 Mdot
.64496 .06525 Mdot
.85112 .12741 Mdot
.15975 .19075 Mdot
.36099 .12437 Mdot
.46464 .06406 Mdot
.54023 .04672 Mdot
.64766 .0664 Mdot
.85698 .12937 Mdot
.16594 .19094 Mdot
.36491 .12298 Mdot
.46834 .06392 Mdot
.5466 .04837 Mdot
.66162 .07108 Mdot
.88482 .13795 Mdot
.19234 .19005 Mdot
.38079 .11647 Mdot
.48255 .06289 Mdot
.57037 .05428 Mdot
.71268 .08795 Mdot
.97883 .16449 Mdot
.26186 .17493 Mdot
.41793 .09645 Mdot
.5112 .05765 Mdot
.61344 .06318 Mdot
.79893 .11464 Mdot
.10577 .18964 Mdot
.33409 .14111 Mdot
.45245 .07315 Mdot
.53334 .04999 Mdot
.6407 .06635 Mdot
.84653 .12721 Mdot
.15697 .19186 Mdot
.36122 .12624 Mdot
.468 .06599 Mdot
.54936 .05028 Mdot
.66957 .07429 Mdot
.90118 .14315 Mdot
.20687 .18893 Mdot
.38988 .11311 Mdot
.49166 .0629 Mdot
.58677 .05878 Mdot
.74791 .09959 Mdot
.03636 .17827 Mdot
.29597 .16045 Mdot
.43354 .08502 Mdot
.51948 .05311 Mdot
.62095 .06271 Mdot
.81014 .11692 Mdot
.11766 .19006 Mdot
.33941 .13704 Mdot
.45339 .07045 Mdot
.53061 .04773 Mdot
.63218 .06277 Mdot
.82775 .12087 Mdot
.13575 .19035 Mdot
.34785 .13108 Mdot
.45593 .0668 Mdot
.52921 .04529 Mdot
.62573 .05965 Mdot
.81269 .11555 Mdot
.11722 .18821 Mdot
.33623 .13535 Mdot
.44615 .06793 Mdot
.51381 .04181 Mdot
.59249 .04863 Mdot
.74108 .09183 Mdot
.01679 .1704 Mdot
.27909 .16211 Mdot
.41619 .08473 Mdot
.48931 .04519 Mdot
.55387 .0399 Mdot
.66071 .06603 Mdot
.87535 .13266 Mdot
.17983 .18818 Mdot
.36916 .11701 Mdot
.46521 .05936 Mdot
.53366 .0423 Mdot
.62883 .05882 Mdot
.81616 .11578 Mdot
.11998 .18777 Mdot
.33665 .13391 Mdot
.44441 .0666 Mdot
.50858 .03966 Mdot
.57962 .04391 Mdot
.71174 .08165 Mdot
.96752 .15808 Mdot
.2491 .17403 Mdot
.40336 .09534 Mdot
.48498 .05044 Mdot
.5546 .04303 Mdot
.66705 .0695 Mdot
.88991 .13774 Mdot
.19399 .18793 Mdot
.37855 .11406 Mdot
.4751 .05967 Mdot
.55182 .04741 Mdot
.66927 .07259 Mdot
.89801 .14137 Mdot
.20287 .18841 Mdot
.38595 .11315 Mdot
.4854 .06146 Mdot
.57319 .05425 Mdot
.71748 .08918 Mdot
.98645 .16623 Mdot
.26624 .17292 Mdot
.41938 .09464 Mdot
.51074 .05647 Mdot
0 .0618 Mdot
.1 .0618 Mdot
.12516 .01555 Mdot
.0602 .57789 Mdot
.94822 .54883 Mdot
.87694 .57398 Mdot
.89458 .01091 Mdot
.99053 .0593 Mdot
.09405 .06398 Mdot
.12663 .02014 Mdot
.06826 .58196 Mdot
.95694 .54923 Mdot
.87965 .57026 Mdot
.88972 .00622 Mdot
.98112 .05649 Mdot
.08759 .0658 Mdot
.12747 .02465 Mdot
.07593 .58618 Mdot
.96593 .55005 Mdot
.88297 .56676 Mdot
.88543 .00152 Mdot
.97183 .0534 Mdot
.08065 .06725 Mdot
.12768 .02907 Mdot
.08317 .59053 Mdot
.97512 .55125 Mdot
.88689 .56351 Mdot
.88172 .61484 Mdot
.9627 .05005 Mdot
.07325 .06832 Mdot
.12725 .03337 Mdot
.08995 .59498 Mdot
.98446 .55284 Mdot
.89139 .56051 Mdot
.87861 .61014 Mdot
.95381 .04647 Mdot
.06544 .06899 Mdot
.12618 .03754 Mdot
.09623 .59952 Mdot
.9939 .55479 Mdot
.89645 .55781 Mdot
.87612 .60547 Mdot
.94519 .04269 Mdot
.05724 .06925 Mdot
.12449 .04156 Mdot
.10199 .60413 Mdot
.00337 .55709 Mdot
.90206 .55542 Mdot
.87424 .60084 Mdot
.93689 .03872 Mdot
.04871 .06911 Mdot
.12217 .0454 Mdot
.10721 .60879 Mdot
.01283 .5597 Mdot
.90819 .55337 Mdot
.873 .59628 Mdot
.92896 .03459 Mdot
.03989 .06856 Mdot
.11924 .04904 Mdot
.11187 .61348 Mdot
.0222 .56261 Mdot
.91483 .55167 Mdot
.87238 .5918 Mdot
.92144 .03032 Mdot
.03082 .0676 Mdot
.1157 .05246 Mdot
.11596 .00016 Mdot
.03144 .5658 Mdot
.92193 .55035 Mdot
.8724 .58742 Mdot
.91436 .02593 Mdot
.02157 .06626 Mdot
.11158 .05563 Mdot
.11945 .00487 Mdot
.04049 .56923 Mdot
.92948 .54943 Mdot
.87306 .58316 Mdot
.90776 .02145 Mdot
.01219 .06454 Mdot
.10688 .05852 Mdot
.12234 .00956 Mdot
.0493 .57289 Mdot
.93744 .5489 Mdot
.87435 .57904 Mdot
.90166 .01688 Mdot
.00273 .06247 Mdot
.10162 .06111 Mdot
.12462 .01422 Mdot
.05781 .57674 Mdot
.94576 .54878 Mdot
.87627 .57509 Mdot
.89609 .01225 Mdot
.99326 .06005 Mdot
.09582 .06339 Mdot
.12627 .01882 Mdot
.06598 .58077 Mdot
.9544 .54907 Mdot
.8788 .57131 Mdot
.89106 .00758 Mdot
.98382 .05733 Mdot
.0895 .06531 Mdot
.12729 .02336 Mdot
.07377 .58495 Mdot
.96331 .54977 Mdot
.88195 .56775 Mdot
.8866 .00288 Mdot
.97449 .05432 Mdot
.0827 .06687 Mdot
.12768 .0278 Mdot
.08113 .58926 Mdot
.97245 .55087 Mdot
.8857 .56442 Mdot
.88273 .6162 Mdot
.96531 .05104 Mdot
.07543 .06806 Mdot
.12743 .03214 Mdot
.08804 .59369 Mdot
.98175 .55234 Mdot
.89003 .56135 Mdot
.87945 .61149 Mdot
.95634 .04753 Mdot
.06773 .06884 Mdot
.12655 .03635 Mdot
.09447 .59821 Mdot
.99117 .55419 Mdot
.89493 .55856 Mdot
.87677 .60681 Mdot
.94764 .0438 Mdot
.05964 .06922 Mdot
.12504 .04042 Mdot
.10038 .6028 Mdot
.00064 .55639 Mdot
.90039 .55607 Mdot
.87472 .60217 Mdot
.93924 .03988 Mdot
.0512 .06919 Mdot
.1229 .04431 Mdot
.10576 .60744 Mdot
.01011 .55892 Mdot
.90637 .55392 Mdot
.87329 .59759 Mdot
.93121 .03579 Mdot
.04246 .06876 Mdot
.12014 .04801 Mdot
.11059 .61213 Mdot
.01951 .56174 Mdot
.91286 .55212 Mdot
.87249 .59308 Mdot
.92356 .03156 Mdot
.03346 .06792 Mdot
.11678 .0515 Mdot
.11484 .61683 Mdot
.0288 .56485 Mdot
.91984 .55069 Mdot
.87233 .58867 Mdot
.91636 .02721 Mdot
.02426 .06669 Mdot
.11283 .05474 Mdot
.11851 .00351 Mdot
.03791 .56822 Mdot
.92726 .54965 Mdot
.87281 .58438 Mdot
.90961 .02275 Mdot
.0149 .06507 Mdot
.10829 .05772 Mdot
.12157 .00821 Mdot
.04679 .57181 Mdot
.93511 .54901 Mdot
.87391 .58022 Mdot
.90337 .0182 Mdot
.00546 .0631 Mdot
.10319 .0604 Mdot
.12403 .01288 Mdot
.05539 .57561 Mdot
.94332 .54878 Mdot
.87565 .57621 Mdot
.89764 .01359 Mdot
.99599 .06078 Mdot
.09754 .06277 Mdot
.12586 .0175 Mdot
.06366 .57959 Mdot
.95188 .54895 Mdot
.87801 .57238 Mdot
.89246 .00893 Mdot
.98654 .05815 Mdot
.09138 .06479 Mdot
.12706 .02206 Mdot
.07156 .58373 Mdot
.96072 .54953 Mdot
.88098 .56875 Mdot
.88783 .00423 Mdot
.97717 .05521 Mdot
.08471 .06646 Mdot
.12764 .02653 Mdot
.07905 .58801 Mdot
.9698 .55051 Mdot
.88456 .56535 Mdot
.88379 .61756 Mdot
.96794 .05201 Mdot
.07757 .06775 Mdot
.12757 .0309 Mdot
.0861 .5924 Mdot
.97906 .55188 Mdot
.88872 .5622 Mdot
.88033 .61285 Mdot
.95891 .04856 Mdot
.06999 .06865 Mdot
.12687 .03515 Mdot
.09267 .59689 Mdot
.98845 .55362 Mdot
.89346 .55933 Mdot
.87748 .60816 Mdot
.95012 .04489 Mdot
.06201 .06915 Mdot
.12554 .03926 Mdot
.09873 .60147 Mdot
.99791 .55572 Mdot
.89876 .55676 Mdot
.87525 .6035 Mdot
.94163 .04103 Mdot
.05367 .06924 Mdot
.12358 .04321 Mdot
.10427 .6061 Mdot
.00738 .55815 Mdot
.90459 .55451 Mdot
.87364 .5989 Mdot
.93348 .03699 Mdot
.04501 .06892 Mdot
.121 .04697 Mdot
.10926 .61077 Mdot
.01681 .5609 Mdot
.91094 .5526 Mdot
.87266 .59437 Mdot
.92572 .0328 Mdot
.03607 .0682 Mdot
.11781 .05052 Mdot
.11368 .61548 Mdot
.02613 .56393 Mdot
.91778 .55107 Mdot
.87231 .58993 Mdot
.91839 .02847 Mdot
.02693 .06708 Mdot
.11403 .05383 Mdot
.11751 .00215 Mdot
.0353 .56722 Mdot
.92508 .54991 Mdot
.87261 .5856 Mdot
.91151 .02404 Mdot
.01761 .06558 Mdot
.10966 .05689 Mdot
.12075 .00686 Mdot
.04425 .57075 Mdot
.9328 .54916 Mdot
.87353 .5814 Mdot
.90512 .01952 Mdot
.00819 .0637 Mdot
.10472 .05966 Mdot
.12338 .01154 Mdot
.05294 .5745 Mdot
.94092 .5488 Mdot
.87509 .57735 Mdot
.89924 .01493 Mdot
.99872 .06148 Mdot
.09923 .06212 Mdot
.1254 .01617 Mdot
.06131 .57843 Mdot
.94938 .54886 Mdot
.87727 .57347 Mdot
.89389 .01028 Mdot
.98925 .05894 Mdot
.09321 .06425 Mdot
.12678 .02075 Mdot
.06932 .58252 Mdot
.95814 .54932 Mdot
.88006 .56978 Mdot
.88911 .00559 Mdot
.97986 .05609 Mdot
.08668 .06602 Mdot
.12754 .02525 Mdot
.07694 .58676 Mdot
.96716 .55019 Mdot
.88347 .56631 Mdot
.88489 .00088 Mdot
.97058 .05296 Mdot
.07967 .06742 Mdot
.12766 .02965 Mdot
.08412 .59113 Mdot
.97637 .55145 Mdot
.88746 .56308 Mdot
.88127 .6142 Mdot
.96149 .04958 Mdot
.07222 .06844 Mdot
.12714 .03394 Mdot
.09082 .59559 Mdot
.98573 .55308 Mdot
.89204 .56013 Mdot
.87824 .60951 Mdot
.95262 .04597 Mdot
.06435 .06905 Mdot
.12599 .03809 Mdot
.09704 .60014 Mdot
.99518 .55508 Mdot
.89718 .55747 Mdot
.87583 .60484 Mdot
.94404 .04216 Mdot
.05611 .06926 Mdot
.12421 .04209 Mdot
.10273 .60476 Mdot
.00465 .55742 Mdot
.90286 .55512 Mdot
.87404 .60022 Mdot
.93579 .03817 Mdot
.04753 .06906 Mdot
.12181 .0459 Mdot
.10788 .60942 Mdot
.0141 .56008 Mdot
.90906 .55312 Mdot
.87288 .59567 Mdot
.92792 .03402 Mdot
.03867 .06845 Mdot
.11879 .04952 Mdot
.11246 .61412 Mdot
.02346 .56303 Mdot
.91576 .55147 Mdot
.87235 .5912 Mdot
.92046 .02973 Mdot
.02958 .06744 Mdot
.11518 .0529 Mdot
.11647 .0008 Mdot
.03268 .56625 Mdot
.92293 .55021 Mdot
.87246 .58684 Mdot
.91344 .02533 Mdot
.02031 .06605 Mdot
.11097 .05603 Mdot
.11988 .0055 Mdot
.0417 .56971 Mdot
.93054 .54933 Mdot
.8732 .5826 Mdot
.90691 .02083 Mdot
.01091 .06428 Mdot
.1062 .05889 Mdot
.12269 .01019 Mdot
.05046 .5734 Mdot
.93854 .54886 Mdot
.87457 .5785 Mdot
.90088 .01626 Mdot
.00145 .06216 Mdot
.10086 .06144 Mdot
.12488 .01484 Mdot
.05893 .57728 Mdot
.94691 .5488 Mdot
.87657 .57457 Mdot
.89538 .01162 Mdot
.99198 .0597 Mdot
.09499 .06367 Mdot
.12645 .01944 Mdot
.06705 .58133 Mdot
.95559 .54915 Mdot
.87919 .57082 Mdot
.89043 .00694 Mdot
.98256 .05694 Mdot
.08861 .06555 Mdot
.12738 .02396 Mdot
.07479 .58553 Mdot
.96454 .5499 Mdot
.88242 .56729 Mdot
.88605 .00224 Mdot
.97324 .05389 Mdot
.08174 .06706 Mdot
.12769 .0284 Mdot
.08209 .58986 Mdot
.9737 .55104 Mdot
.88625 .56399 Mdot
.88225 .61556 Mdot
.96409 .05058 Mdot
.07441 .06818 Mdot
.12735 .03272 Mdot
.08894 .59429 Mdot
.98302 .55257 Mdot
.89066 .56095 Mdot
.87905 .61086 Mdot
.95515 .04703 Mdot
.06666 .06892 Mdot
.12638 .03691 Mdot
.0953 .59882 Mdot
.99245 .55447 Mdot
.89564 .5582 Mdot
.87646 .60618 Mdot
.94648 .04328 Mdot
.05852 .06924 Mdot
.12479 .04096 Mdot
.10114 .60342 Mdot
.00192 .55671 Mdot
.90116 .55576 Mdot
.87449 .60155 Mdot
.93814 .03934 Mdot
.05004 .06916 Mdot
.12256 .04482 Mdot
.10645 .60807 Mdot
.01138 .55928 Mdot
.5 .0618 Mdot
.6 .0618 Mdot
.77484 .10806 Mdot
.07545 .18579 Mdot
.31794 .14987 Mdot
.44453 .07824 Mdot
.52764 .05136 Mdot
.63276 .06496 Mdot
.83218 .12325 Mdot
.14233 .19168 Mdot
.35319 .13032 Mdot
.46258 .0676 Mdot
.54229 .04927 Mdot
.65545 .06994 Mdot
.87412 .13514 Mdot
.18332 .19109 Mdot
.3762 .11921 Mdot
.47974 .06399 Mdot
.56711 .054 Mdot
.70658 .0862 Mdot
.96867 .16198 Mdot
.25566 .17737 Mdot
.41541 .09873 Mdot
.51063 .05885 Mdot
.61435 .0641 Mdot
.80188 .1159 Mdot
.11003 .19045 Mdot
.337 .14028 Mdot
.4552 .07305 Mdot
.53804 .05119 Mdot
.65101 .06982 Mdot
.86747 .13378 Mdot
.17812 .19199 Mdot
.37421 .12119 Mdot
.47982 .06527 Mdot
.56932 .05532 Mdot
.71255 .08852 Mdot
.97959 .16504 Mdot
.26292 .1751 Mdot
.41933 .09667 Mdot
.51395 .05848 Mdot
.61971 .06536 Mdot
.81246 .11913 Mdot
.12286 .19183 Mdot
.34444 .13695 Mdot
.46047 .07171 Mdot
.54519 .05236 Mdot
.66558 .0744 Mdot
.89579 .14228 Mdot
.20354 .1902 Mdot
.38936 .11484 Mdot
.49362 .06444 Mdot
.59277 .06128 Mdot
.76201 .10459 Mdot
.05821 .18306 Mdot
.30887 .15492 Mdot
.44083 .08155 Mdot
.52652 .05296 Mdot
.63334 .06602 Mdot
.83477 .12449 Mdot
.14589 .19228 Mdot
.35597 .12984 Mdot
.46593 .06795 Mdot
.54883 .05124 Mdot
.67018 .075 Mdot
.90318 .144 Mdot
.20895 .18897 Mdot
.3916 .11289 Mdot
.49408 .06334 Mdot
.59183 .06041 Mdot
.75904 .10334 Mdot
.05337 .1819 Mdot
.3058 .15601 Mdot
.43865 .0821 Mdot
.52362 .05251 Mdot
.62741 .06415 Mdot
.82259 .12063 Mdot
.13207 .19127 Mdot
.34762 .13321 Mdot
.45905 .06887 Mdot
.53807 .04884 Mdot
.64727 .06749 Mdot
.85817 .13035 Mdot
.16811 .19155 Mdot
.3672 .12305 Mdot
.47197 .06475 Mdot
.55442 .05096 Mdot
.67957 .07735 Mdot
.91978 .14846 Mdot
.22148 .18646 Mdot
.3979 .10903 Mdot
.49812 .06194 Mdot
.59684 .06101 Mdot
.76834 .10599 Mdot
.06631 .18416 Mdot
.31276 .15231 Mdot
.44166 .07966 Mdot
.52492 .05146 Mdot
.62804 .06373 Mdot
.82288 .12042 Mdot
.13194 .19101 Mdot
.34712 .13299 Mdot
.45796 .0685 Mdot
.53556 .04796 Mdot
.64137 .0654 Mdot
.84599 .12646 Mdot
.15546 .19127 Mdot
.35942 .12605 Mdot
.46498 .06524 Mdot
.54276 .04807 Mdot
.65433 .06895 Mdot
.87091 .13385 Mdot
.1798 .19091 Mdot
.37356 .11975 Mdot
.47647 .0636 Mdot
.56062 .05201 Mdot
.6921 .08126 Mdot
.94258 .1548 Mdot
.238 .18258 Mdot
.40646 .10411 Mdot
.50432 .06048 Mdot
.60565 .06262 Mdot
.78542 .1111 Mdot
.08937 .18785 Mdot
.32553 .14595 Mdot
.44843 .07596 Mdot
.53079 .0509 Mdot
.63763 .06603 Mdot
.84136 .12591 Mdot
.152 .19199 Mdot
.3587 .12775 Mdot
.46665 .06671 Mdot
.5481 .05034 Mdot
.66745 .07376 Mdot
.89738 .1421 Mdot
.20384 .1894 Mdot
.38828 .114 Mdot
.49052 .06318 Mdot
.58517 .0585 Mdot
.74476 .09863 Mdot
.03161 .17728 Mdot
.29333 .16175 Mdot
.43242 .08596 Mdot
.51906 .05354 Mdot
.6209 .06294 Mdot
.81043 .11714 Mdot
.11822 .19022 Mdot
.33989 .137 Mdot
.45401 .07053 Mdot
.53184 .04811 Mdot
.63499 .06374 Mdot
.83363 .12277 Mdot
.14242 .19084 Mdot
.35188 .12946 Mdot
.45923 .06634 Mdot
.53431 .04641 Mdot
.63664 .06324 Mdot
.83533 .1228 Mdot
.14348 .19045 Mdot
.35177 .12873 Mdot
.4579 .06559 Mdot
.53074 .04502 Mdot
.62803 .06013 Mdot
.81704 .11682 Mdot
.12225 .18863 Mdot
.339 .13395 Mdot
.44781 .06725 Mdot
.51561 .0419 Mdot
.59588 .04961 Mdot
.7483 .0942 Mdot
.02804 .17289 Mdot
.28546 .15909 Mdot
.41871 .08235 Mdot
.48971 .04388 Mdot
.55248 .03879 Mdot
.65647 .06427 Mdot
.86644 .12976 Mdot
.17114 .18832 Mdot
.36384 .11909 Mdot
.46041 .05969 Mdot
.52563 .04031 Mdot
.61128 .05293 Mdot
.77886 .10357 Mdot
.07168 .18097 Mdot
.30908 .14672 Mdot
.42782 .07339 Mdot
.49078 .03891 Mdot
.54636 .03435 Mdot
.63851 .05695 Mdot
.828 .11711 Mdot
.12983 .18654 Mdot
.33893 .12923 Mdot
.44008 .06251 Mdot
.49442 .03358 Mdot
.5443 .03083 Mdot
.62916 .05245 Mdot
.80637 .10952 Mdot
.10301 .18333 Mdot
.32287 .13588 Mdot
.42852 .0653 Mdot
.47889 .03113 Mdot
.51243 .02073 Mdot
.5559 .02687 Mdot
.64317 .05394 Mdot
.83015 .11556 Mdot
.12864 .18448 Mdot
.33507 .12758 Mdot
.43193 .05986 Mdot
.47598 .02722 Mdot
.50088 .01539 Mdot
.52649 .01583 Mdot
.57318 .02886 Mdot
.67638 .06378 Mdot
.89353 .1342 Mdot
.18964 .18301 Mdot
.36747 .10991 Mdot
.45112 .0517 Mdot
.49627 .02791 Mdot
.53844 .02606 Mdot
.61107 .04489 Mdot
.76551 .09545 Mdot
.04667 .17377 Mdot
.29103 .15102 Mdot
.41227 .07493 Mdot
.46683 .03372 Mdot
.49504 .01744 Mdot
.51928 .01498 Mdot
.5589 .02449 Mdot
.64458 .05295 Mdot
.83066 .115 Mdot
.12806 .1838 Mdot
.33371 .1271 Mdot
.42925 .05905 Mdot
.47004 .02521 Mdot
.48699 .01048 Mdot
.49355 .00406 Mdot
.49496 .00087 Mdot
.49234 .61641 Mdot
.48359 .61263 Mdot
.46173 .60452 Mdot
.40954 .58578 Mdot
.28883 .54343 Mdot
.04456 .46707 Mdot
.76511 .44532 Mdot
.61241 .52366 Mdot
.54234 .57473 Mdot
.50574 .59541 Mdot
.47373 .59825 Mdot
.4208 .58532 Mdot
.30709 .54776 Mdot
.07416 .47408 Mdot
.78403 .43872 Mdot
.61832 .51562 Mdot
.53878 .56888 Mdot
.48997 .58787 Mdot
.43313 .58291 Mdot
.32437 .55081 Mdot
.10193 .48056 Mdot
.8034 .43354 Mdot
.62511 .50784 Mdot
.5369 .56352 Mdot
.47794 .5816 Mdot
.4014 .57073 Mdot
.25093 .52504 Mdot
.97314 .44635 Mdot
.71673 .45957 Mdot
.58488 .53655 Mdot
.51776 .57655 Mdot
.46482 .58531 Mdot
.38395 .56806 Mdot
.21826 .51563 Mdot
.92777 .4385 Mdot
.6931 .473 Mdot
.5777 .54671 Mdot
.52203 .58362 Mdot
.48391 .59448 Mdot
.43295 .58654 Mdot
.32993 .55436 Mdot
.11531 .48539 Mdot
.8163 .43324 Mdot
.63372 .5052 Mdot
.54598 .56381 Mdot
.49451 .58622 Mdot
.43865 .58351 Mdot
.33491 .55392 Mdot
.12155 .48617 Mdot
.82013 .43174 Mdot
.63387 .50292 Mdot
.54251 .56157 Mdot
.48477 .58234 Mdot
.41485 .57482 Mdot
.28002 .5347 Mdot
.02013 .45741 Mdot
.74417 .44749 Mdot
.59546 .52612 Mdot
.51861 .57054 Mdot
.45662 .57972 Mdot
.36036 .55854 Mdot
.16617 .49802 Mdot
.86192 .42999 Mdot
.65478 .49002 Mdot
.55286 .55504 Mdot
.49245 .5807 Mdot
.426 .57697 Mdot
.30247 .54169 Mdot
.05847 .46723 Mdot
.76874 .43897 Mdot
.60545 .51712 Mdot
.52048 .56552 Mdot
.45186 .57562 Mdot
.3453 .55218 Mdot
.13357 .48718 Mdot
.82709 .42862 Mdot
.63329 .49826 Mdot
.53409 .55672 Mdot
.46196 .57345 Mdot
.35968 .55482 Mdot
.15914 .49409 Mdot
.85146 .42788 Mdot
.6461 .49111 Mdot
.54188 .55362 Mdot
.47079 .57409 Mdot
.37646 .55973 Mdot
.19292 .5046 Mdot
.89016 .43092 Mdot
.66846 .48102 Mdot
.55774 .5496 Mdot
.4922 .57753 Mdot
.42042 .57367 Mdot
.28761 .53595 Mdot
.03101 .45945 Mdot
.74976 .44421 Mdot
.59583 .5229 Mdot
.51402 .56747 Mdot
.4434 .57439 Mdot
.32846 .547 Mdot
.10136 .47768 Mdot
.79854 .43088 Mdot
.61717 .50594 Mdot
.52129 .55878 Mdot
.44239 .56927 Mdot
.31841 .54141 Mdot
.07869 .46988 Mdot
.77855 .43254 Mdot
.60369 .50996 Mdot
.50604 .55768 Mdot
.41321 .56066 Mdot
.25434 .51985 Mdot
.9682 .44119 Mdot
.70733 .45681 Mdot
.56923 .53268 Mdot
.48479 .56584 Mdot
.38819 .55833 Mdot
.20932 .50749 Mdot
.90727 .43135 Mdot
.67527 .47465 Mdot
.55682 .54483 Mdot
.48287 .57233 Mdot
.39524 .56387 Mdot
.22972 .51574 Mdot
.93791 .43769 Mdot
.69452 .46761 Mdot
.5708 .54157 Mdot
.50187 .57543 Mdot
.43443 .57636 Mdot
.31601 .54485 Mdot
.08106 .47283 Mdot
.78403 .43446 Mdot
.61142 .51136 Mdot
.52085 .56206 Mdot
.44691 .57234 Mdot
.33129 .54657 Mdot
.10459 .47793 Mdot
.80011 .42986 Mdot
.6167 .50468 Mdot
.5185 .55735 Mdot
.43507 .56647 Mdot
.30113 .53525 Mdot
.04638 .46059 Mdot
.75505 .43798 Mdot
.59098 .51663 Mdot
.49578 .5592 Mdot
.39722 .55712 Mdot
.22203 .50976 Mdot
.92148 .43228 Mdot
.68123 .46955 Mdot
.55659 .54101 Mdot
.47629 .5684 Mdot
.37708 .55672 Mdot
.18902 .50181 Mdot
.88287 .42882 Mdot
.66219 .48165 Mdot
.54995 .54866 Mdot
.47701 .57295 Mdot
.38574 .56163 Mdot
.21071 .50986 Mdot
.91222 .43356 Mdot
.68044 .47479 Mdot
.56403 .54609 Mdot
.49747 .5769 Mdot
.42888 .57564 Mdot
0 .09271 Mdot
.15 .09271 Mdot
.19699 .02904 Mdot
.12366 .57271 Mdot
.96105 .51754 Mdot
.8293 .5366 Mdot
.80938 .60573 Mdot
.90803 .06097 Mdot
.07623 .10395 Mdot
.18575 .06768 Mdot
.17818 .61335 Mdot
.05603 .54254 Mdot
.88998 .51541 Mdot
.8051 .56558 Mdot
.83999 .02157 Mdot
.98239 .08801 Mdot
.13885 .0967 Mdot
.19779 .03643 Mdot
.1362 .57997 Mdot
.97847 .52055 Mdot
.83791 .53116 Mdot
.80574 .59815 Mdot
.89317 .05403 Mdot
.05979 .10297 Mdot
.17969 .07411 Mdot
.18449 .00297 Mdot
.07261 .54888 Mdot
.90463 .51422 Mdot
.80846 .5586 Mdot
.83113 .01401 Mdot
.96493 .08269 Mdot
.12656 .0999 Mdot
.19728 .04371 Mdot
.1476 .58733 Mdot
.99606 .52437 Mdot
.84766 .52632 Mdot
.80336 .59066 Mdot
.8793 .04693 Mdot
.0428 .10105 Mdot
.17247 .08014 Mdot
.18963 .0106 Mdot
.08852 .55554 Mdot
.92018 .514 Mdot
.81306 .55183 Mdot
.8234 .00639 Mdot
.94776 .07686 Mdot
.11317 .10223 Mdot
.19548 .05087 Mdot
.15787 .59479 Mdot
.01368 .52892 Mdot
.85856 .52217 Mdot
.80227 .58325 Mdot
.86651 .0397 Mdot
.02545 .09823 Mdot
.16412 .0857 Mdot
.19355 .01819 Mdot
.10359 .56243 Mdot
.93648 .51476 Mdot
.81885 .54534 Mdot
.81682 .61678 Mdot
.93105 .0706 Mdot
.09873 .10363 Mdot
.1924 .05789 Mdot
.16699 .60233 Mdot
.03119 .5341 Mdot
.87059 .51878 Mdot
.80249 .57594 Mdot
.85485 .03236 Mdot
.00789 .09458 Mdot
.15462 .09069 Mdot
.19622 .02571 Mdot
.11769 .5695 Mdot
.95336 .51647 Mdot
.82581 .5392 Mdot
.81141 .60914 Mdot
.91498 .06401 Mdot
.08337 .10407 Mdot
.18808 .06471 Mdot
.17497 .60994 Mdot
.04844 .53983 Mdot
.88374 .51625 Mdot
.804 .56875 Mdot
.84433 .02492 Mdot
.99026 .09019 Mdot
.14398 .095 Mdot
.19759 .03314 Mdot
.13073 .57671 Mdot
.97065 .5191 Mdot
.83392 .53353 Mdot
.80722 .60153 Mdot
.8997 .05716 Mdot
.06722 .10353 Mdot
.18255 .07127 Mdot
.18181 .61758 Mdot
.06526 .546 Mdot
.89795 .51463 Mdot
.8068 .5617 Mdot
.83495 .0174 Mdot
.97271 .08514 Mdot
.1322 .09857 Mdot
.19767 .04047 Mdot
.14264 .58402 Mdot
.98817 .52257 Mdot
.84316 .52841 Mdot
.80427 .594 Mdot
.88538 .05013 Mdot
.05046 .10203 Mdot
.17584 .07749 Mdot
.18748 .00719 Mdot
.08149 .55253 Mdot
.91312 .51397 Mdot
.81085 .55483 Mdot
.82671 .0098 Mdot
.95539 .07953 Mdot
.11929 .1013 Mdot
.19645 .04768 Mdot
.15342 .59144 Mdot
.0058 .5268 Mdot
.85354 .52393 Mdot
.8026 .58655 Mdot
.87209 .04295 Mdot
.03325 .0996 Mdot
.168 .08328 Mdot
.19195 .0148 Mdot
.09696 .55932 Mdot
.92911 .5143 Mdot
.81611 .5482 Mdot
.81962 .00217 Mdot
.93846 .07345 Mdot
.10531 .10312 Mdot
.19393 .05477 Mdot
.16305 .59895 Mdot
.02337 .53171 Mdot
.86507 .52019 Mdot
.80223 .5792 Mdot
.85993 .03566 Mdot
.01576 .09631 Mdot
.15901 .08853 Mdot
.19518 .02236 Mdot
.11151 .56632 Mdot
.94575 .51559 Mdot
.82256 .5419 Mdot
.81368 .61255 Mdot
.92208 .06699 Mdot
.09035 .104 Mdot
.19016 .06169 Mdot
.17154 .60653 Mdot
.04076 .53721 Mdot
.87772 .51727 Mdot
.80317 .57195 Mdot
.84889 .02826 Mdot
.99815 .09224 Mdot
.14888 .09316 Mdot
.19714 .02982 Mdot
.12503 .57347 Mdot
.96287 .51782 Mdot
.83015 .53601 Mdot
.80894 .60493 Mdot
.90643 .06025 Mdot
.07453 .10389 Mdot
.18517 .06838 Mdot
.17889 .61416 Mdot
.0578 .54319 Mdot
.89147 .51524 Mdot
.80539 .56484 Mdot
.83901 .02077 Mdot
.98055 .08748 Mdot
.13761 .09707 Mdot
.1978 .0372 Mdot
.13745 .58074 Mdot
.98031 .52092 Mdot
.83888 .53063 Mdot
.80543 .59736 Mdot
.89166 .05329 Mdot
.05802 .10282 Mdot
.17899 .07476 Mdot
.18509 .00377 Mdot
.07431 .54957 Mdot
.90622 .51415 Mdot
.80889 .55788 Mdot
.83026 .01321 Mdot
.96311 .0821 Mdot
.1252 .10018 Mdot
.19716 .04447 Mdot
.14874 .58811 Mdot
.99791 .52482 Mdot
.84875 .52585 Mdot
.80319 .58987 Mdot
.8779 .04618 Mdot
.04099 .10079 Mdot
.17165 .08075 Mdot
.1901 .0114 Mdot
.09014 .55626 Mdot
.92186 .51403 Mdot
.81361 .55113 Mdot
.82265 .00559 Mdot
.94598 .07622 Mdot
.1117 .10242 Mdot
.19522 .05162 Mdot
.15888 .59558 Mdot
.01552 .52944 Mdot
.85977 .52177 Mdot
.80224 .58248 Mdot
.86523 .03893 Mdot
.02361 .09788 Mdot
.16317 .08625 Mdot
.19389 .01899 Mdot
.10512 .56317 Mdot
.93823 .51489 Mdot
.81953 .54467 Mdot
.81619 .61597 Mdot
.92933 .06992 Mdot
.09716 .10373 Mdot
.192 .05862 Mdot
.16788 .60313 Mdot
.03301 .53468 Mdot
.87192 .51847 Mdot
.80259 .57518 Mdot
.85369 .03158 Mdot
.00603 .09416 Mdot
.15355 .09117 Mdot
.19642 .02649 Mdot
.11911 .57025 Mdot
.95516 .51671 Mdot
.82661 .53858 Mdot
.81091 .60833 Mdot
.91333 .0633 Mdot
.08171 .10406 Mdot
.18755 .06542 Mdot
.17575 .61074 Mdot
.05023 .54046 Mdot
.88519 .51604 Mdot
.80424 .568 Mdot
.84329 .02413 Mdot
.98841 .08969 Mdot
.14279 .09541 Mdot
.19766 .03391 Mdot
.13203 .57747 Mdot
.97248 .51942 Mdot
.83483 .53296 Mdot
.80685 .60074 Mdot
.89815 .05643 Mdot
.06548 .10342 Mdot
.1819 .07195 Mdot
.18246 .00035 Mdot
.067 .54667 Mdot
.8995 .51452 Mdot
.80717 .56097 Mdot
.83403 .0166 Mdot
.97088 .08458 Mdot
.13089 .09889 Mdot
.1976 .04123 Mdot
.14383 .5848 Mdot
.99002 .52298 Mdot
.8442 .52791 Mdot
.80403 .59321 Mdot
.88393 .04938 Mdot
.04867 .10181 Mdot
.17507 .07812 Mdot
.18801 .00799 Mdot
.08316 .55323 Mdot
.91476 .51396 Mdot
.81135 .55412 Mdot
.82591 .009 Mdot
.95359 .07891 Mdot
.11787 .10153 Mdot
.19624 .04844 Mdot
.15448 .59223 Mdot
.00765 .52729 Mdot
.8547 .52351 Mdot
.8025 .58577 Mdot
.87076 .04219 Mdot
.03142 .09929 Mdot
.16711 .08386 Mdot
.19235 .0156 Mdot
.09853 .56005 Mdot
.93083 .51439 Mdot
.81674 .54752 Mdot
.81894 .00136 Mdot
.93671 .07278 Mdot
.10378 .10326 Mdot
.1936 .05551 Mdot
.164 .59974 Mdot
.02521 .53226 Mdot
.86635 .51985 Mdot
.80227 .57843 Mdot
.85871 .03488 Mdot
.01391 .09592 Mdot
.158 .08905 Mdot
.19545 .02314 Mdot
.11298 .56707 Mdot
.94753 .51578 Mdot
.8233 .54126 Mdot
.81313 .61175 Mdot
.9204 .06629 Mdot
.08872 .10403 Mdot
.18969 .0624 Mdot
.17237 .60733 Mdot
.04257 .53781 Mdot
.87912 .51702 Mdot
.80334 .5712 Mdot
.8478 .02748 Mdot
.99629 .09177 Mdot
.14775 .09361 Mdot
.19727 .0306 Mdot
.12639 .57423 Mdot
.96469 .5181 Mdot
.83101 .53542 Mdot
.80852 .60413 Mdot
.90483 .05953 Mdot
.07283 .10383 Mdot
.18457 .06906 Mdot
.1796 .61496 Mdot
.05956 .54384 Mdot
.89298 .51508 Mdot
.8057 .5641 Mdot
.83803 .01998 Mdot
.9787 .08694 Mdot
.13636 .09744 Mdot
.19779 .03797 Mdot
.13869 .58151 Mdot
.98216 .52129 Mdot
.83987 .53009 Mdot
.80514 .59657 Mdot
.89017 .05255 Mdot
.05625 .10265 Mdot
.17827 .07541 Mdot
.18567 .00458 Mdot
.07601 .55026 Mdot
.90783 .51409 Mdot
.80933 .55716 Mdot
.82941 .01241 Mdot
.96129 .08151 Mdot
.12383 .10046 Mdot
.19701 .04523 Mdot
.14986 .58889 Mdot
.99976 .52527 Mdot
.84986 .52539 Mdot
.80303 .58909 Mdot
.87652 .04542 Mdot
.03918 .10053 Mdot
.17081 .08135 Mdot
.19056 .0122 Mdot
.09176 .55697 Mdot
.92355 .51408 Mdot
.81418 .55044 Mdot
.82192 .00478 Mdot
.9442 .07558 Mdot
.11021 .1026 Mdot
.19494 .05236 Mdot
.15988 .59637 Mdot
.01737 .52996 Mdot
.86099 .52139 Mdot
.80221 .5817 Mdot
.86396 .03816 Mdot
.02177 .09753 Mdot
.16221 .0868 Mdot
.19422 .01978 Mdot
.10664 .56391 Mdot
.93999 .51504 Mdot
.82022 .54401 Mdot
.81558 .61517 Mdot
.92761 .06924 Mdot
.09558 .10381 Mdot
.19159 .05934 Mdot
.16876 .60392 Mdot
.03484 .53526 Mdot
.87327 .51818 Mdot
.8027 .57442 Mdot
.85254 .0308 Mdot
.00418 .09372 Mdot
.15248 .09165 Mdot
.19661 .02728 Mdot
.12052 .57101 Mdot
.95697 .51695 Mdot
.82742 .53797 Mdot
.81043 .60753 Mdot
.91169 .06258 Mdot
.08003 .10404 Mdot
.18701 .06612 Mdot
.17651 .61154 Mdot
.05201 .54109 Mdot
.88665 .51583 Mdot
.80449 .56726 Mdot
.84226 .02335 Mdot
.98656 .08918 Mdot
.1416 .09582 Mdot
.19772 .03469 Mdot
.13333 .57824 Mdot
.97432 .51976 Mdot
.83576 .5324 Mdot
.80649 .59994 Mdot
.89661 .05569 Mdot
.06374 .10329 Mdot
.18123 .07261 Mdot
.1831 .00115 Mdot
.06873 .54735 Mdot
.90107 .51441 Mdot
.80755 .56024 Mdot
.83313 .01581 Mdot
.96905 .08401 Mdot
.5 .09271 Mdot
.65 .09271 Mdot
.90301 .15637 Mdot
.22889 .20141 Mdot
.42857 .12341 Mdot
.57301 .08927 Mdot
.77384 .12412 Mdot
.10056 .20193 Mdot
.35208 .15545 Mdot
.50158 .0924 Mdot
.65235 .09318 Mdot
.90721 .15752 Mdot
.23218 .20084 Mdot
.43061 .12264 Mdot
.57527 .08941 Mdot
.77794 .12525 Mdot
.10597 .20273 Mdot
.35535 .15413 Mdot
.5043 .09206 Mdot
.65669 .09418 Mdot
.91514 .15973 Mdot
.23831 .19973 Mdot
.43449 .12125 Mdot
.57974 .08977 Mdot
.78615 .12757 Mdot
.11661 .20424 Mdot
.36191 .1516 Mdot
.51008 .09158 Mdot
.66631 .09656 Mdot
.93267 .16462 Mdot
.2513 .19692 Mdot
.44261 .11823 Mdot
.58899 .09047 Mdot
.80291 .13221 Mdot
.13719 .20659 Mdot
.37481 .14686 Mdot
.52229 .09115 Mdot
.68754 .10213 Mdot
.97043 .17484 Mdot
.27684 .18937 Mdot
.45774 .1118 Mdot
.60522 .09115 Mdot
.83088 .13947 Mdot
.16778 .20821 Mdot
.39396 .13979 Mdot
.54146 .09116 Mdot
.72175 .11143 Mdot
.02736 .18888 Mdot
.31119 .17542 Mdot
.477 .10247 Mdot
.62446 .09114 Mdot
.86165 .14659 Mdot
.1961 .2067 Mdot
.41045 .13248 Mdot
.55689 .0905 Mdot
.74788 .11804 Mdot
.06619 .19672 Mdot
.33305 .16493 Mdot
.48954 .09672 Mdot
.63767 .09155 Mdot
.88271 .15144 Mdot
.21331 .20432 Mdot
.41996 .12771 Mdot
.56524 .08979 Mdot
.76127 .12115 Mdot
.0843 .19964 Mdot
.343 .15989 Mdot
.4955 .09425 Mdot
.64441 .09203 Mdot
.89363 .15403 Mdot
.22175 .20279 Mdot
.42455 .12534 Mdot
.56922 .08941 Mdot
.76755 .12257 Mdot
.09242 .20078 Mdot
.34744 .15761 Mdot
.49827 .09322 Mdot
.64771 .09236 Mdot
.89908 .15535 Mdot
.22588 .20197 Mdot
.42681 .12418 Mdot
.57124 .08926 Mdot
.77078 .12332 Mdot
.09655 .20134 Mdot
.34974 .15648 Mdot
.49979 .09274 Mdot
.64968 .09264 Mdot
.90243 .15621 Mdot
.22844 .20148 Mdot
.42829 .12351 Mdot
.57268 .08924 Mdot
.77323 .12394 Mdot
.09974 .2018 Mdot
.35158 .15565 Mdot
.50117 .09245 Mdot
.65169 .09303 Mdot
.90601 .15718 Mdot
.23122 .20099 Mdot
.43 .12285 Mdot
.57457 .08935 Mdot
.77662 .12488 Mdot
.10423 .20247 Mdot
.35429 .15454 Mdot
.50339 .09215 Mdot
.65519 .09382 Mdot
.9124 .15896 Mdot
.2362 .20012 Mdot
.43315 .12172 Mdot
.57819 .08964 Mdot
.78328 .12676 Mdot
.11293 .20373 Mdot
.35963 .15247 Mdot
.50803 .09172 Mdot
.66284 .09568 Mdot
.92637 .16287 Mdot
.24672 .19799 Mdot
.43977 .11931 Mdot
.58578 .09024 Mdot
.79715 .13063 Mdot
.13029 .20589 Mdot
.37046 .14843 Mdot
.51806 .09122 Mdot
.68008 .10014 Mdot
.95734 .17135 Mdot
.26832 .19219 Mdot
.45281 .11402 Mdot
.60011 .09103 Mdot
.82232 .13733 Mdot
.15893 .20804 Mdot
.3885 .14188 Mdot
.53599 .09115 Mdot
.71203 .1088 Mdot
.01179 .18526 Mdot
.30212 .17944 Mdot
.4719 .10493 Mdot
.61932 .09111 Mdot
.85349 .14473 Mdot
.18901 .20736 Mdot
.40644 .13438 Mdot
.55325 .09074 Mdot
.74188 .11658 Mdot
.05766 .19516 Mdot
.32832 .16728 Mdot
.48676 .09792 Mdot
.63462 .09138 Mdot
.87778 .15028 Mdot
.20939 .20495 Mdot
.4178 .1288 Mdot
.56333 .08994 Mdot
.75819 .12043 Mdot
.08021 .19902 Mdot
.34075 .16102 Mdot
.4941 .09478 Mdot
.64272 .09186 Mdot
.89083 .15334 Mdot
.21958 .20318 Mdot
.42333 .12592 Mdot
.56809 .08946 Mdot
.76567 .12211 Mdot
.08996 .20042 Mdot
.34605 .15827 Mdot
.49731 .09348 Mdot
.64642 .09216 Mdot
.89683 .15476 Mdot
.22412 .20227 Mdot
.42576 .12462 Mdot
.57014 .08923 Mdot
.76882 .1228 Mdot
.09394 .20094 Mdot
.3482 .15714 Mdot
.49861 .09296 Mdot
.6479 .09227 Mdot
.8992 .15531 Mdot
.22586 .20189 Mdot
.42666 .1241 Mdot
.57083 .08911 Mdot
.76982 .12298 Mdot
.09515 .20106 Mdot
.34881 .15677 Mdot
.49891 .09277 Mdot
.64813 .09223 Mdot
.89948 .15534 Mdot
.226 .2018 Mdot
.42664 .124 Mdot
.57066 .08901 Mdot
.76936 .12281 Mdot
.09445 .20091 Mdot
.34833 .15691 Mdot
.49843 .09277 Mdot
.64728 .09199 Mdot
.89784 .15485 Mdot
.22463 .20197 Mdot
.42571 .12427 Mdot
.56949 .08886 Mdot
.76712 .12214 Mdot
.09133 .20038 Mdot
.34643 .15766 Mdot
.49686 .09297 Mdot
.64478 .09142 Mdot
.89319 .15353 Mdot
.22078 .20246 Mdot
.42319 .12509 Mdot
.5665 .08857 Mdot
.76148 .1205 Mdot
.08345 .19899 Mdot
.34168 .15959 Mdot
.49313 .0936 Mdot
.63909 .09021 Mdot
.88269 .15055 Mdot
.21186 .20344 Mdot
.41736 .127 Mdot
.55966 .08795 Mdot
.74859 .11676 Mdot
.06483 .19545 Mdot
.33063 .16427 Mdot
.48511 .09547 Mdot
.62768 .08812 Mdot
.86179 .14469 Mdot
.19308 .20475 Mdot
.40511 .13104 Mdot
.54564 .08685 Mdot
.72219 .10911 Mdot
.02413 .18661 Mdot
.30683 .17472 Mdot
.47025 .101 Mdot
.61 .08637 Mdot
.83091 .13653 Mdot
.16305 .20527 Mdot
.38639 .13803 Mdot
.52637 .08651 Mdot
.68735 .09949 Mdot
.96592 .17216 Mdot
.27154 .18889 Mdot
.45101 .11092 Mdot
.5919 .08707 Mdot
.80228 .13003 Mdot
.13319 .20451 Mdot
.36955 .14608 Mdot
.51285 .08856 Mdot
.66641 .09491 Mdot
.93014 .16299 Mdot
.24798 .19644 Mdot
.4385 .11775 Mdot
.58105 .0881 Mdot
.78566 .12646 Mdot
.11442 .20318 Mdot
.35932 .15136 Mdot
.50578 .09051 Mdot
.65686 .09337 Mdot
.91407 .15897 Mdot
.23674 .19942 Mdot
.43252 .121 Mdot
.57592 .08863 Mdot
.77778 .12476 Mdot
.10504 .20225 Mdot
.35423 .15401 Mdot
.50243 .0916 Mdot
.65259 .0928 Mdot
.90695 .15721 Mdot
.23158 .20064 Mdot
.42975 .12247 Mdot
.57351 .08885 Mdot
.77402 .12392 Mdot
.1004 .20172 Mdot
.35169 .1553 Mdot
.50076 .09213 Mdot
.65045 .09251 Mdot
.90335 .1563 Mdot
.22891 .20121 Mdot
.42826 .1232 Mdot
.57214 .08892 Mdot
.77177 .12338 Mdot
.09754 .20134 Mdot
.35007 .15607 Mdot
.49963 .09243 Mdot
.64889 .09225 Mdot
.90063 .15558 Mdot
.2268 .20159 Mdot
.427 .12373 Mdot
.57082 .08889 Mdot
.76945 .12276 Mdot
.09446 .20086 Mdot
.34826 .15685 Mdot
.49823 .09269 Mdot
.64679 .09182 Mdot
.89683 .15453 Mdot
.22375 .20204 Mdot
.42507 .12442 Mdot
.56863 .08873 Mdot
.7654 .12161 Mdot
.0889 .19994 Mdot
.34493 .15823 Mdot
.49561 .09313 Mdot
.64277 .09095 Mdot
.88945 .15245 Mdot
.21762 .20282 Mdot
.42109 .12575 Mdot
.564 .08832 Mdot
.75673 .11911 Mdot
.07667 .19774 Mdot
.33762 .16128 Mdot
.49006 .09421 Mdot
.63455 .0893 Mdot
.87432 .14818 Mdot
.2045 .20406 Mdot
.41252 .12857 Mdot
.55404 .08746 Mdot
.73796 .11367 Mdot
.04884 .19213 Mdot
.32126 .16836 Mdot
.4789 .09743 Mdot
.61972 .08703 Mdot
.84753 .1408 Mdot
.1795 .20517 Mdot
.39643 .13407 Mdot
.53623 .0864 Mdot
.70478 .10416 Mdot
.99553 .1797 Mdot
.28987 .18191 Mdot
.46085 .10567 Mdot
.60082 .08651 Mdot
.81616 .13309 Mdot
.14798 .20508 Mdot
.37775 .14201 Mdot
.51906 .08733 Mdot
.67558 .09674 Mdot
.94577 .16698 Mdot
.2585 .19328 Mdot
.44409 .1147 Mdot
.58587 .08762 Mdot
.79306 .12805 Mdot
.12294 .20388 Mdot
.36396 .14896 Mdot
.50893 .0896 Mdot
.66104 .09401 Mdot
.9211 .16073 Mdot
.24173 .19816 Mdot
.4352 .11957 Mdot
.57825 .08841 Mdot
.7814 .12556 Mdot
.10941 .20272 Mdot
.35663 .15279 Mdot
.50404 .0911 Mdot
.65467 .0931 Mdot
.91047 .15809 Mdot
.23418 .20006 Mdot
.43118 .12176 Mdot
.57484 .08878 Mdot
.77618 .12444 Mdot
.10312 .20206 Mdot
.35322 .15457 Mdot
.50185 .09186 Mdot
.65197 .09277 Mdot
.906 .157 Mdot
.23094 .20082 Mdot
.42947 .1227 Mdot
.57339 .08895 Mdot
.77398 .12397 Mdot
.10045 .20177 Mdot
.35179 .15534 Mdot
.50096 .0922 Mdot
.65091 .09267 Mdot
.90429 .1566 Mdot
.22971 .20112 Mdot
.42883 .12307 Mdot
.5729 .08904 Mdot
.77328 .12384 Mdot
.09962 .20169 Mdot
.35137 .15559 Mdot
.50075 .09233 Mdot
.65074 .0927 Mdot
.90409 .15658 Mdot
.2296 .20118 Mdot
.42884 .12313 Mdot
.57302 .08911 Mdot
.77358 .12396 Mdot
.10008 .20179 Mdot
.35168 .1555 Mdot
.50108 .09233 Mdot
.65134 .09287 Mdot
.90523 .15692 Mdot
.23054 .20105 Mdot
.42947 .12295 Mdot
.57381 .08921 Mdot
.7751 .12441 Mdot
.10214 .20212 Mdot
.35296 .15502 Mdot
.50218 .09222 Mdot
.65314 .0933 Mdot
.90857 .15786 Mdot
.23318 .20062 Mdot
.43119 .12237 Mdot
.57583 .0894 Mdot
.77888 .12549 Mdot
.10716 .20289 Mdot
.35604 .15382 Mdot
.50484 .09196 Mdot
.6575 .09435 Mdot
.91657 .16012 Mdot
.23938 .1995 Mdot
.43514 .12099 Mdot
0 .12361 Mdot
.2 .12361 Mdot
.27891 .04877 Mdot
.23259 .58941 Mdot
.0597 .51119 Mdot
.84017 .48235 Mdot
.72807 .54875 Mdot
.74208 .00866 Mdot
.88326 .08725 Mdot
.10968 .13994 Mdot
.25514 .0899 Mdot
.27334 .01125 Mdot
.16558 .55144 Mdot
.94799 .48356 Mdot
.77128 .50882 Mdot
.72075 .5868 Mdot
.79539 .04614 Mdot
.99222 .12165 Mdot
.19527 .12549 Mdot
.27845 .05141 Mdot
.23633 .592 Mdot
.06736 .5136 Mdot
.84609 .48128 Mdot
.72964 .54606 Mdot
.73947 .00608 Mdot
.87635 .08459 Mdot
.10249 .13976 Mdot
.25219 .09252 Mdot
.27458 .01384 Mdot
.17116 .55412 Mdot
.95572 .48489 Mdot
.77525 .5065 Mdot
.72051 .5842 Mdot
.79091 .04351 Mdot
.98445 .11962 Mdot
.19041 .12729 Mdot
.27787 .05405 Mdot
.23996 .5946 Mdot
.07497 .51607 Mdot
.8522 .48036 Mdot
.7314 .54337 Mdot
.73704 .00349 Mdot
.86959 .08192 Mdot
.09518 .13942 Mdot
.24908 .09512 Mdot
.27566 .01643 Mdot
.17657 .55679 Mdot
.96346 .48633 Mdot
.77933 .50423 Mdot
.72037 .58159 Mdot
.78653 .04089 Mdot
.97667 .11752 Mdot
.18541 .12901 Mdot
.27717 .05671 Mdot
.24345 .5972 Mdot
.08252 .51857 Mdot
.85849 .47958 Mdot
.73333 .54068 Mdot
.7348 .00091 Mdot
.86301 .07924 Mdot
.08777 .13891 Mdot
.24582 .09768 Mdot
.2766 .01902 Mdot
.18182 .55946 Mdot
.97122 .48788 Mdot
.78352 .50203 Mdot
.72033 .57898 Mdot
.78226 .03827 Mdot
.96891 .11535 Mdot
.18027 .13063 Mdot
.27633 .05937 Mdot
.24681 .59979 Mdot
.08999 .52111 Mdot
.86495 .47895 Mdot
.73545 .538 Mdot
.73273 .61636 Mdot
.8566 .07655 Mdot
.08028 .13824 Mdot
.24242 .10021 Mdot
.27739 .02161 Mdot
.18692 .56212 Mdot
.97899 .48953 Mdot
.78782 .49989 Mdot
.7204 .57636 Mdot
.77811 .03566 Mdot
.96116 .11313 Mdot
.17497 .13215 Mdot
.27535 .06204 Mdot
.25002 .60238 Mdot
.09737 .52369 Mdot
.87159 .47849 Mdot
.73775 .53532 Mdot
.73085 .61377 Mdot
.85036 .07386 Mdot
.07271 .13742 Mdot
.23889 .10271 Mdot
.27806 .02421 Mdot
.19187 .56477 Mdot
.98676 .49127 Mdot
.79223 .49781 Mdot
.72057 .57374 Mdot
.77406 .03306 Mdot
.95342 .11085 Mdot
.16951 .13356 Mdot
.27423 .06472 Mdot
.25309 .60497 Mdot
.10464 .52629 Mdot
.87839 .4782 Mdot
.74023 .53265 Mdot
.72915 .61119 Mdot
.84431 .07117 Mdot
.06508 .13645 Mdot
.23523 .10516 Mdot
.2786 .0268 Mdot
.19669 .56741 Mdot
.99454 .4931 Mdot
.79675 .4958 Mdot
.72084 .57112 Mdot
.77011 .03045 Mdot
.9457 .10852 Mdot
.16389 .13485 Mdot
.27294 .0674 Mdot
.25598 .60756 Mdot
.1118 .52892 Mdot
.88535 .47808 Mdot
.74289 .52999 Mdot
.72763 .6086 Mdot
.83844 .06848 Mdot
.05741 .13533 Mdot
.23145 .10756 Mdot
.27902 .0294 Mdot
.20138 .57005 Mdot
.00232 .495 Mdot
.8014 .49386 Mdot
.72122 .56848 Mdot
.76629 .02785 Mdot
.93801 .10613 Mdot
.15809 .13601 Mdot
.27148 .07008 Mdot
.25871 .61014 Mdot
.11881 .53157 Mdot
.89245 .47813 Mdot
.74572 .52735 Mdot
.72628 .60602 Mdot
.83274 .0658 Mdot
.04971 .13409 Mdot
.22755 .10991 Mdot
.27934 .032 Mdot
.20595 .57268 Mdot
.01009 .49698 Mdot
.80616 .492 Mdot
.72171 .56584 Mdot
.76258 .02526 Mdot
.93037 .1037 Mdot
.15211 .13704 Mdot
.26985 .07277 Mdot
.26127 .61273 Mdot
.12568 .53423 Mdot
.89967 .47836 Mdot
.74872 .52474 Mdot
.72508 .60343 Mdot
.82721 .06312 Mdot
.04198 .13273 Mdot
.22355 .11222 Mdot
.27955 .03461 Mdot
.21041 .57531 Mdot
.01787 .49904 Mdot
.81106 .49022 Mdot
.72232 .56319 Mdot
.75899 .02266 Mdot
.92278 .10123 Mdot
.14595 .13793 Mdot
.26805 .07546 Mdot
.26364 .61531 Mdot
.13238 .53691 Mdot
.90701 .47875 Mdot
.75187 .52215 Mdot
.72405 .60084 Mdot
.82185 .06045 Mdot
.03423 .13125 Mdot
.21943 .11446 Mdot
.27965 .03722 Mdot
.21475 .57792 Mdot
.02564 .50116 Mdot
.8161 .48853 Mdot
.72307 .56053 Mdot
.75553 .02007 Mdot
.91525 .09871 Mdot
.13961 .13866 Mdot
.26606 .07815 Mdot
.26584 .6179 Mdot
.13892 .53959 Mdot
.91445 .4793 Mdot
.75517 .5196 Mdot
.72315 .59824 Mdot
.81665 .05778 Mdot
.02647 .12967 Mdot
.21521 .11665 Mdot
.27966 .03983 Mdot
.21899 .58054 Mdot
.0334 .50334 Mdot
.82129 .48694 Mdot
.72394 .55787 Mdot
.75222 .01747 Mdot
.9078 .09616 Mdot
.13309 .13923 Mdot
.26389 .08084 Mdot
.26784 .00245 Mdot
.14528 .54228 Mdot
.92197 .48002 Mdot
.75861 .51708 Mdot
.7224 .59565 Mdot
.81159 .05513 Mdot
.0187 .128 Mdot
.21088 .11877 Mdot
.27956 .04245 Mdot
.22311 .58315 Mdot
.04115 .50558 Mdot
.82663 .48546 Mdot
.72497 .5552 Mdot
.74905 .01488 Mdot
.90045 .09357 Mdot
.1264 .13965 Mdot
.26153 .08351 Mdot
.26967 .00503 Mdot
.15146 .54497 Mdot
.92956 .48089 Mdot
.76219 .51459 Mdot
.72177 .59305 Mdot
.80668 .05248 Mdot
.01092 .12623 Mdot
.20644 .12083 Mdot
.27936 .04507 Mdot
.22713 .58575 Mdot
.04888 .50787 Mdot
.83214 .48408 Mdot
.72614 .55252 Mdot
.74603 .01229 Mdot
.89321 .09096 Mdot
.11955 .13989 Mdot
.259 .08618 Mdot
.27132 .00762 Mdot
.15746 .54766 Mdot
.9372 .48191 Mdot
.76588 .51216 Mdot
.72126 .59046 Mdot
.8019 .04983 Mdot
.00315 .12438 Mdot
.20188 .12282 Mdot
.27906 .0477 Mdot
.23104 .58835 Mdot
.05659 .51022 Mdot
.83782 .48283 Mdot
.72748 .54984 Mdot
.74318 .00971 Mdot
.8861 .08833 Mdot
.11255 .13996 Mdot
.25628 .08883 Mdot
.27279 .0102 Mdot
.16328 .55035 Mdot
.94488 .48306 Mdot
.7697 .50977 Mdot
.72087 .58786 Mdot
.79724 .0472 Mdot
.99537 .12245 Mdot
.1972 .12474 Mdot
.27865 .05034 Mdot
.23483 .59095 Mdot
.06427 .51262 Mdot
.84368 .4817 Mdot
.72898 .54715 Mdot
.74051 .00712 Mdot
.87913 .08567 Mdot
.10541 .13985 Mdot
.2534 .09146 Mdot
.2741 .01279 Mdot
.16892 .55303 Mdot
.95259 .48433 Mdot
.77363 .50743 Mdot
.72059 .58525 Mdot
.79271 .04457 Mdot
.98759 .12045 Mdot
.19239 .12657 Mdot
.27812 .05298 Mdot
.23851 .59355 Mdot
.0719 .51507 Mdot
.84971 .48071 Mdot
.73066 .54446 Mdot
.738 .00454 Mdot
.87231 .083 Mdot
.09815 .13958 Mdot
.25036 .09407 Mdot
.27524 .01538 Mdot
.1744 .55571 Mdot
.96033 .48573 Mdot
.77767 .50514 Mdot
.72041 .58265 Mdot
.78829 .04195 Mdot
.97982 .11837 Mdot
.18745 .12833 Mdot
.27747 .05563 Mdot
.24205 .59615 Mdot
.07947 .51755 Mdot
.85592 .47987 Mdot
.73253 .54177 Mdot
.73568 .00195 Mdot
.86565 .08032 Mdot
.09078 .13914 Mdot
.24716 .09665 Mdot
.27624 .01797 Mdot
.17971 .55838 Mdot
.96808 .48724 Mdot
.78181 .50291 Mdot
.72034 .58004 Mdot
.78398 .03933 Mdot
.97205 .11624 Mdot
.18237 .12998 Mdot
.27669 .05829 Mdot
.24547 .59874 Mdot
.08698 .52008 Mdot
.86232 .47919 Mdot
.73457 .53908 Mdot
.73355 .6174 Mdot
.85917 .07764 Mdot
.08332 .13853 Mdot
.24382 .09919 Mdot
.27709 .02056 Mdot
.18487 .56104 Mdot
.97585 .48885 Mdot
.78607 .50075 Mdot
.72036 .57742 Mdot
.77977 .03672 Mdot
.96429 .11404 Mdot
.17713 .13155 Mdot
.27577 .06096 Mdot
.24874 .60133 Mdot
.0944 .52264 Mdot
.86888 .47866 Mdot
.7368 .5364 Mdot
.73159 .61482 Mdot
.85286 .07495 Mdot
.07578 .13777 Mdot
.24034 .1017 Mdot
.2778 .02316 Mdot
.18988 .5637 Mdot
.98362 .49055 Mdot
.79043 .49864 Mdot
.72049 .5748 Mdot
.77568 .03411 Mdot
.95654 .11178 Mdot
.17174 .133 Mdot
.2747 .06363 Mdot
.25187 .60392 Mdot
.10172 .52524 Mdot
.87562 .4783 Mdot
.7392 .53372 Mdot
.72982 .61223 Mdot
.84674 .07226 Mdot
.06817 .13686 Mdot
.23672 .10417 Mdot
.27839 .02575 Mdot
.19476 .56634 Mdot
.99139 .49235 Mdot
.79491 .4966 Mdot
.72071 .57218 Mdot
.77169 .03151 Mdot
.94882 .10947 Mdot
.16618 .13434 Mdot
.27348 .06631 Mdot
.25483 .60651 Mdot
.10892 .52786 Mdot
.88252 .47811 Mdot
.74179 .53106 Mdot
.72823 .60965 Mdot
.84079 .06957 Mdot
.06052 .1358 Mdot
.23299 .10659 Mdot
.27886 .02835 Mdot
.1995 .56899 Mdot
.99917 .49422 Mdot
.7995 .49463 Mdot
.72105 .56955 Mdot
.76782 .02891 Mdot
.94112 .1071 Mdot
.16045 .13556 Mdot
.27209 .069 Mdot
.25763 .6091 Mdot
.11599 .5305 Mdot
.88956 .47809 Mdot
.74456 .52842 Mdot
.7268 .60706 Mdot
.83502 .06688 Mdot
.05283 .13461 Mdot
.22914 .10897 Mdot
.27922 .03095 Mdot
.20412 .57162 Mdot
.00695 .49617 Mdot
.80422 .49274 Mdot
.7215 .56691 Mdot
.76406 .02631 Mdot
.93345 .10469 Mdot
.5 .12361 Mdot
.7 .12361 Mdot
.02109 .19845 Mdot
.32536 .18805 Mdot
.51631 .11802 Mdot
.72029 .12607 Mdot
.04938 .20339 Mdot
.3396 .17936 Mdot
.52214 .11282 Mdot
.72234 .12373 Mdot
.04794 .20123 Mdot
.33577 .17789 Mdot
.51432 .11035 Mdot
.7043 .11742 Mdot
.0164 .19289 Mdot
.3154 .18479 Mdot
.49768 .11265 Mdot
.6781 .1115 Mdot
.97306 .1823 Mdot
.28948 .19555 Mdot
.48246 .11927 Mdot
.66145 .11062 Mdot
.94856 .17744 Mdot
.27611 .20244 Mdot
.47804 .1248 Mdot
.66246 .11398 Mdot
.95543 .18106 Mdot
.28359 .20281 Mdot
.48725 .12587 Mdot
.68072 .11957 Mdot
.98964 .19092 Mdot
.30684 .19604 Mdot
.50476 .12232 Mdot
.70647 .12467 Mdot
.03078 .20043 Mdot
.33062 .18531 Mdot
.51912 .1165 Mdot
.72288 .12593 Mdot
.05212 .20348 Mdot
.34041 .17817 Mdot
.52136 .11184 Mdot
.71936 .12237 Mdot
.04233 .1996 Mdot
.33183 .17892 Mdot
.51047 .11041 Mdot
.69749 .11558 Mdot
.00495 .19003 Mdot
.30846 .18758 Mdot
.49314 .11414 Mdot
.67232 .11074 Mdot
.96397 .18025 Mdot
.28419 .19791 Mdot
.48002 .12103 Mdot
.65991 .11118 Mdot
.94725 .17759 Mdot
.27603 .2032 Mdot
.47918 .12556 Mdot
.66573 .11529 Mdot
.96217 .18321 Mdot
.28859 .20174 Mdot
.4914 .12535 Mdot
.68735 .1211 Mdot
.00088 .19377 Mdot
.31371 .19334 Mdot
.50927 .12087 Mdot
.71226 .12545 Mdot
.039 .20194 Mdot
.33485 .18285 Mdot
.52106 .11508 Mdot
.72405 .12546 Mdot
.05269 .20311 Mdot
.33994 .17753 Mdot
.51966 .11107 Mdot
.71506 .12077 Mdot
.03473 .19757 Mdot
.32684 .18053 Mdot
.50617 .11083 Mdot
.69045 .11389 Mdot
.99324 .18713 Mdot
.30143 .19048 Mdot
.4889 .11586 Mdot
.66749 .11037 Mdot
.95667 .17872 Mdot
.28009 .19988 Mdot
.47845 .1226 Mdot
.65963 .11198 Mdot
.94816 .17832 Mdot
.27743 .2035 Mdot
.48126 .12597 Mdot
.67013 .11673 Mdot
.97063 .18572 Mdot
.29449 .20016 Mdot
.49597 .12452 Mdot
.69423 .12253 Mdot
.01207 .19644 Mdot
.32027 .19047 Mdot
.51335 .11933 Mdot
.71709 .12592 Mdot
.04545 .20294 Mdot
.33794 .18077 Mdot
.52205 .11379 Mdot
.72375 .12466 Mdot
.05104 .20228 Mdot
.3382 .17747 Mdot
.51708 .11056 Mdot
.70961 .11899 Mdot
.02539 .19516 Mdot
.32094 .18266 Mdot
.5016 .11166 Mdot
.68355 .11245 Mdot
.98189 .18438 Mdot
.29468 .19332 Mdot
.48514 .11771 Mdot
.66372 .11037 Mdot
.95138 .17778 Mdot
.27733 .20145 Mdot
.47782 .12391 Mdot
.66064 .11299 Mdot
.95123 .1796 Mdot
.28023 .20333 Mdot
.48419 .12606 Mdot
.67554 .11826 Mdot
.98052 .18849 Mdot
.30105 .1981 Mdot
.50074 .12342 Mdot
.70104 .12379 Mdot
.02268 .19878 Mdot
.32624 .18761 Mdot
.5168 .11778 Mdot
.72078 .12607 Mdot
.04995 .20344 Mdot
.33981 .17914 Mdot
.52208 .11265 Mdot
.72197 .12354 Mdot
.0472 .20101 Mdot
.33523 .17801 Mdot
.51376 .11034 Mdot
.70327 .11713 Mdot
.01467 .19245 Mdot
.31434 .18521 Mdot
.49696 .11286 Mdot
.67715 .11136 Mdot
.97155 .18195 Mdot
.28859 .19594 Mdot
.48203 .11955 Mdot
.66113 .11069 Mdot
.94821 .17743 Mdot
.276 .20258 Mdot
.47815 .12494 Mdot
.66289 .11417 Mdot
.95635 .18137 Mdot
.28429 .20268 Mdot
.48786 .12581 Mdot
.68172 .11981 Mdot
.99136 .19137 Mdot
.30791 .19564 Mdot
.50548 .1221 Mdot
.70742 .12481 Mdot
.03216 .2007 Mdot
.33135 .18491 Mdot
.51948 .11627 Mdot
.72316 .12588 Mdot
.05236 .20345 Mdot
.34042 .17803 Mdot
.52116 .1117 Mdot
.71878 .12213 Mdot
.04127 .19932 Mdot
.33112 .17914 Mdot
.50983 .11045 Mdot
.6964 .11531 Mdot
.00314 .18958 Mdot
.30737 .18802 Mdot
.49245 .11439 Mdot
.67151 .11066 Mdot
.96271 .17997 Mdot
.28347 .19824 Mdot
.47972 .12129 Mdot
.65978 .11128 Mdot
.94725 .17767 Mdot
.27615 .20327 Mdot
.47945 .12564 Mdot
.66634 .11551 Mdot
.96337 .18358 Mdot
.28945 .20153 Mdot
.49209 .12524 Mdot
.68841 .12133 Mdot
.00263 .1942 Mdot
.31475 .1929 Mdot
.50994 .12063 Mdot
.71307 .12554 Mdot
.04012 .20213 Mdot
.33541 .1825 Mdot
.52127 .11487 Mdot
.7241 .12536 Mdot
.05258 .20301 Mdot
.33975 .17748 Mdot
.51931 .11098 Mdot
.71429 .1205 Mdot
.03339 .19722 Mdot
.32598 .18083 Mdot
.50548 .11094 Mdot
.68936 .11364 Mdot
.99143 .18669 Mdot
.30036 .19093 Mdot
.48828 .11614 Mdot
.66683 .11035 Mdot
.95571 .17854 Mdot
.27957 .20015 Mdot
.47829 .12282 Mdot
.65971 .11212 Mdot
.9485 .17848 Mdot
.27778 .2035 Mdot
.48166 .12601 Mdot
.67091 .11696 Mdot
.97208 .18614 Mdot
.29548 .19987 Mdot
.49671 .12437 Mdot
.6953 .12274 Mdot
.01377 .19683 Mdot
.32124 .19003 Mdot
.51393 .11909 Mdot
.71774 .12597 Mdot
.04628 .20305 Mdot
.33831 .18048 Mdot
.52212 .1136 Mdot
.72357 .1245 Mdot
.05059 .20211 Mdot
.33781 .17752 Mdot
.51661 .1105 Mdot
.70868 .1187 Mdot
.0238 .19476 Mdot
.31995 .18303 Mdot
.50088 .11182 Mdot
.68252 .11226 Mdot
.98021 .18398 Mdot
.29369 .19374 Mdot
.48461 .118 Mdot
.66324 .1104 Mdot
.95074 .17769 Mdot
.27702 .20165 Mdot
.47781 .12409 Mdot
.66091 .11316 Mdot
.95189 .17984 Mdot
.28078 .20326 Mdot
.48472 .12604 Mdot
.67645 .1185 Mdot
.98215 .18893 Mdot
.3021 .19774 Mdot
.50149 .12323 Mdot
.70206 .12396 Mdot
.02423 .19911 Mdot
.32709 .18718 Mdot
.51727 .11754 Mdot
.72124 .12606 Mdot
.05046 .20347 Mdot
.33999 .17894 Mdot
.522 .11249 Mdot
.72156 .12334 Mdot
.04642 .20077 Mdot
.33466 .17815 Mdot
.51318 .11033 Mdot
.70223 .11684 Mdot
.01292 .19201 Mdot
.31328 .18563 Mdot
.49625 .11308 Mdot
.67621 .11123 Mdot
.97006 .18161 Mdot
.28772 .19632 Mdot
.48162 .11983 Mdot
.66084 .11076 Mdot
.94792 .17743 Mdot
.27592 .20272 Mdot
.47829 .12507 Mdot
.66335 .11437 Mdot
.95732 .18168 Mdot
.28503 .20253 Mdot
.48848 .12574 Mdot
.68273 .12005 Mdot
.9931 .19182 Mdot
.30898 .19523 Mdot
.50619 .12188 Mdot
.70835 .12494 Mdot
.03351 .20095 Mdot
.33205 .18451 Mdot
.51982 .11605 Mdot
.7234 .12582 Mdot
.05253 .20342 Mdot
.3404 .17791 Mdot
.52093 .11158 Mdot
.71816 .12189 Mdot
.04017 .19902 Mdot
.33039 .17936 Mdot
.50918 .1105 Mdot
.69531 .11503 Mdot
.00132 .18912 Mdot
.30627 .18847 Mdot
.49178 .11465 Mdot
.67071 .11059 Mdot
.9615 .17971 Mdot
.28278 .19857 Mdot
.47944 .12154 Mdot
.65968 .1114 Mdot
.9473 .17776 Mdot
.27631 .20334 Mdot
.47973 .12572 Mdot
.66698 .11573 Mdot
.96462 .18395 Mdot
.29033 .2013 Mdot
.49279 .12512 Mdot
.68947 .12156 Mdot
.00438 .19463 Mdot
.31579 .19246 Mdot
.51059 .1204 Mdot
.71387 .12563 Mdot
.0412 .2023 Mdot
.33594 .18216 Mdot
.52147 .11466 Mdot
.72412 .12525 Mdot
.05241 .2029 Mdot
.33953 .17745 Mdot
.51895 .11088 Mdot
.71348 .12023 Mdot
.03201 .19686 Mdot
.3251 .18114 Mdot
.50478 .11105 Mdot
.68828 .11341 Mdot
.98964 .18626 Mdot
.29929 .19137 Mdot
.48767 .11643 Mdot
.6662 .11034 Mdot
.95481 .17837 Mdot
.27908 .20041 Mdot
.47816 .12303 Mdot
.65981 .11227 Mdot
.94889 .17866 Mdot
.27815 .2035 Mdot
.48208 .12604 Mdot
.67171 .1172 Mdot
.97357 .18656 Mdot
.29647 .19957 Mdot
.49744 .12421 Mdot
.69637 .12294 Mdot
.01545 .19721 Mdot
.3222 .18958 Mdot
.51449 .11885 Mdot
.71837 .126 Mdot
.04706 .20314 Mdot
.33865 .18021 Mdot
.52216 .11342 Mdot
.72335 .12434 Mdot
.05008 .20193 Mdot
.3374 .17758 Mdot
.51612 .11046 Mdot
.70772 .11841 Mdot
.02218 .19435 Mdot
.31895 .18341 Mdot
.50016 .11199 Mdot
.6815 .11207 Mdot
.97855 .18359 Mdot
.29271 .19416 Mdot
.4841 .11829 Mdot
.66279 .11044 Mdot
.95016 .17761 Mdot
.27676 .20185 Mdot
.47782 .12427 Mdot
.66121 .11334 Mdot
.95261 .18009 Mdot
.28136 .20318 Mdot
.48526 .12602 Mdot
.67738 .11874 Mdot
.9838 .18938 Mdot
.30316 .19737 Mdot
.50223 .12303 Mdot
.70308 .12413 Mdot
.02576 .19943 Mdot
.32792 .18675 Mdot
.51772 .1173 Mdot
.72167 .12605 Mdot
.05092 .20349 Mdot
.34013 .17874 Mdot
.5219 .11234 Mdot
.72112 .12313 Mdot
.04558 .20053 Mdot
.33407 .1783 Mdot
.51259 .11033 Mdot
.70118 .11655 Mdot
.01115 .19157 Mdot
.3122 .18606 Mdot
.49554 .11331 Mdot
.6753 .1111 Mdot
.96862 .18128 Mdot
.28688 .1967 Mdot
.48122 .12011 Mdot
.66057 .11085 Mdot
.94768 .17744 Mdot
.27589 .20285 Mdot
.47845 .12519 Mdot
.66384 .11457 Mdot
.95833 .18201 Mdot
.28579 .20238 Mdot
.48912 .12567 Mdot
0 .15451 Mdot
.25 .15451 Mdot
.37268 .07582 Mdot
.40402 .01937 Mdot
.36314 .59277 Mdot
.22578 .53314 Mdot
.96256 .45536 Mdot
.72902 .4737 Mdot
.6217 .55171 Mdot
.60253 .60619 Mdot
.65983 .03541 Mdot
.82455 .10181 Mdot
.10288 .17202 Mdot
.30452 .12462 Mdot
.38624 .0505 Mdot
.3845 .61696 Mdot
.29826 .56473 Mdot
.0905 .48963 Mdot
.81419 .44726 Mdot
.65498 .51964 Mdot
.60106 .58471 Mdot
.62267 .01336 Mdot
.73299 .06818 Mdot
.9699 .14642 Mdot
.23075 .16121 Mdot
.36521 .0831 Mdot
.40426 .02414 Mdot
.37126 .59764 Mdot
.24614 .54071 Mdot
.99374 .46204 Mdot
.74634 .46513 Mdot
.62623 .5438 Mdot
.59685 .59988 Mdot
.64026 .02683 Mdot
.7819 .08754 Mdot
.04832 .16466 Mdot
.27667 .14113 Mdot
.37949 .06354 Mdot
.39484 .00949 Mdot
.33205 .57923 Mdot
.15849 .51077 Mdot
.87808 .44473 Mdot
.68594 .49928 Mdot
.61095 .57169 Mdot
.6177 .00417 Mdot
.71026 .05721 Mdot
.9262 .13346 Mdot
.19908 .16865 Mdot
.3511 .09396 Mdot
.40064 .03062 Mdot
.37575 .60265 Mdot
.26126 .54727 Mdot
.01976 .46878 Mdot
.7625 .45903 Mdot
.63216 .53748 Mdot
.59581 .59557 Mdot
.63157 .0221 Mdot
.761 .07999 Mdot
.01745 .15849 Mdot
.25997 .14988 Mdot
.37541 .07135 Mdot
.40105 .01585 Mdot
.35254 .58805 Mdot
.20223 .52514 Mdot
.93029 .44996 Mdot
.71235 .48334 Mdot
.61819 .55984 Mdot
.61012 .61305 Mdot
.68329 .04522 Mdot
.87276 .1171 Mdot
.15352 .17352 Mdot
.32964 .10885 Mdot
.39405 .03981 Mdot
.37983 .60924 Mdot
.27835 .55532 Mdot
.05156 .47787 Mdot
.78424 .45282 Mdot
.64131 .5297 Mdot
.59715 .59074 Mdot
.62596 .01781 Mdot
.74535 .07379 Mdot
.99201 .15244 Mdot
.24506 .15639 Mdot
.37085 .07774 Mdot
.40428 .02066 Mdot
.36567 .59417 Mdot
.23191 .53536 Mdot
.97164 .45718 Mdot
.73394 .47113 Mdot
.62292 .54942 Mdot
.60075 .60433 Mdot
.6539 .03285 Mdot
.81187 .09763 Mdot
.08765 .17045 Mdot
.29681 .12927 Mdot
.38411 .05395 Mdot
.38668 .00159 Mdot
.30606 .56821 Mdot
.10593 .49435 Mdot
.82718 .44576 Mdot
.66107 .51537 Mdot
.60292 .5821 Mdot
.62149 .01148 Mdot
.72809 .06588 Mdot
.9608 .14383 Mdot
.22456 .16301 Mdot
.36262 .08532 Mdot
.40391 .02552 Mdot
.37293 .59888 Mdot
.25074 .54252 Mdot
.00123 .46383 Mdot
.75074 .46322 Mdot
.62757 .54191 Mdot
.59587 .59844 Mdot
.63631 .02499 Mdot
.77295 .08445 Mdot
.03559 .16232 Mdot
.26999 .14487 Mdot
.37808 .0668 Mdot
.3979 .01225 Mdot
.34152 .58319 Mdot
.17829 .51715 Mdot
.90044 .44632 Mdot
.69715 .49239 Mdot
.61423 .56678 Mdot
.61504 .0005 Mdot
.70007 .05256 Mdot
.90622 .12741 Mdot
.18312 .17114 Mdot
.34378 .09929 Mdot
.39858 .03387 Mdot
.37763 .60508 Mdot
.26815 .55037 Mdot
.03216 .47219 Mdot
.77063 .45639 Mdot
.63534 .53443 Mdot
.59575 .59356 Mdot
.62822 .02007 Mdot
.75253 .07683 Mdot
.00414 .15551 Mdot
.25244 .15346 Mdot
.37343 .07478 Mdot
.40351 .01859 Mdot
.36104 .59179 Mdot
.221 .53148 Mdot
.95574 .4541 Mdot
.72544 .4757 Mdot
.62094 .55345 Mdot
.60415 .60766 Mdot
.66486 .03752 Mdot
.8351 .10522 Mdot
.1149 .17292 Mdot
.31055 .12092 Mdot
.38799 .04786 Mdot
.38304 .61497 Mdot
.29271 .56221 Mdot
.07961 .48633 Mdot
.80545 .44859 Mdot
.65096 .52256 Mdot
.59993 .5865 Mdot
.6237 .01469 Mdot
.73675 .06987 Mdot
.97669 .14829 Mdot
.23521 .15977 Mdot
.36696 .08142 Mdot
.40423 .02304 Mdot
.36944 .59653 Mdot
.24152 .53898 Mdot
.98647 .4604 Mdot
.74222 .46708 Mdot
.62515 .54568 Mdot
.59819 .60137 Mdot
.6449 .02887 Mdot
.79216 .09101 Mdot
.06231 .16696 Mdot
.28387 .13693 Mdot
.38098 .06002 Mdot
.39151 .00651 Mdot
.32181 .57496 Mdot
.13753 .50414 Mdot
.85642 .4443 Mdot
.67521 .50604 Mdot
.60753 .5762 Mdot
.61947 .00738 Mdot
.71825 .06105 Mdot
.94184 .13818 Mdot
.21093 .1663 Mdot
.35651 .08997 Mdot
.40222 .02826 Mdot
.37455 .60093 Mdot
.25659 .54513 Mdot
.01141 .46651 Mdot
.75712 .46087 Mdot
.63001 .53948 Mdot
.59573 .59685 Mdot
.63351 .02334 Mdot
.76599 .08188 Mdot
.02516 .16017 Mdot
.26428 .14779 Mdot
.37659 .06941 Mdot
.39978 .01433 Mdot
.34799 .58602 Mdot
.19225 .52178 Mdot
.91748 .44822 Mdot
.70581 .48721 Mdot
.61658 .56289 Mdot
.6125 .61551 Mdot
.6911 .04858 Mdot
.88841 .12194 Mdot
.16786 .17271 Mdot
.33656 .10427 Mdot
.39632 .03693 Mdot
.37887 .60725 Mdot
.2736 .55298 Mdot
.0424 .47515 Mdot
.77769 .45443 Mdot
.63837 .53193 Mdot
.59632 .59205 Mdot
.62672 .01878 Mdot
.74811 .07502 Mdot
.99681 .15371 Mdot
.24807 .15528 Mdot
.37201 .0766 Mdot
.40424 .01992 Mdot
.36441 .59341 Mdot
.22875 .53419 Mdot
.9669 .4562 Mdot
.73134 .47245 Mdot
.62223 .5506 Mdot
.60158 .60527 Mdot
.65678 .03412 Mdot
.81808 .09969 Mdot
.09524 .17129 Mdot
.30067 .12696 Mdot
.38517 .05223 Mdot
.38558 .00025 Mdot
.30213 .56646 Mdot
.09813 .49195 Mdot
.8205 .44645 Mdot
.65791 .51755 Mdot
.60192 .58343 Mdot
.62201 .01241 Mdot
.73042 .067 Mdot
.96519 .1451 Mdot
.22759 .16217 Mdot
.36392 .08426 Mdot
.40418 .02488 Mdot
.37233 .59835 Mdot
.24896 .54178 Mdot
.99826 .4631 Mdot
.74896 .46395 Mdot
.62697 .54264 Mdot
.59613 .59897 Mdot
.63759 .02563 Mdot
.77592 .08549 Mdot
.03989 .16314 Mdot
.27228 .14363 Mdot
.37859 .06571 Mdot
.39693 .01133 Mdot
.33845 .58189 Mdot
.17181 .51505 Mdot
.89291 .44566 Mdot
.69336 .49471 Mdot
.61315 .56846 Mdot
.61603 .00178 Mdot
.70372 .0542 Mdot
.9134 .12959 Mdot
.18899 .17032 Mdot
.34649 .09734 Mdot
.39937 .03268 Mdot
.37699 .6042 Mdot
.26571 .54926 Mdot
.02773 .47095 Mdot
.76768 .45731 Mdot
.63416 .53552 Mdot
.59571 .59427 Mdot
.6293 .02076 Mdot
.75531 .07788 Mdot
.00858 .15653 Mdot
.25499 .15229 Mdot
.37413 .07364 Mdot
.40276 .01769 Mdot
.35834 .59058 Mdot
.21498 .52943 Mdot
.94736 .45264 Mdot
.72109 .47819 Mdot
.62005 .55559 Mdot
.6062 .60947 Mdot
.67115 .04014 Mdot
.84811 .10937 Mdot
.12896 .17357 Mdot
.31757 .11657 Mdot
.39015 .04486 Mdot
.38167 .61279 Mdot
.287 .55953 Mdot
.06844 .48296 Mdot
.7968 .45015 Mdot
.64701 .52546 Mdot
.59881 .58824 Mdot
.62469 .01599 Mdot
.74041 .07152 Mdot
.98323 .15007 Mdot
.23944 .15835 Mdot
.3686 .07983 Mdot
.4042 .022 Mdot
.36769 .59547 Mdot
.23712 .53733 Mdot
.97963 .4589 Mdot
.7384 .46894 Mdot
.62415 .54742 Mdot
.59946 .60277 Mdot
.64924 .03077 Mdot
.80169 .09421 Mdot
.07479 .16879 Mdot
.29025 .13316 Mdot
.38242 .05697 Mdot
.38887 .00398 Mdot
.31345 .57142 Mdot
.1207 .49891 Mdot
.84038 .44479 Mdot
.6674 .51113 Mdot
.60498 .57946 Mdot
.62059 .00965 Mdot
.72369 .06372 Mdot
.95239 .14134 Mdot
.21861 .16453 Mdot
.35997 .08737 Mdot
.40322 .02673 Mdot
.37372 .5998 Mdot
.25346 .54371 Mdot
.00591 .46504 Mdot
.75363 .46212 Mdot
.62865 .54079 Mdot
.59573 .59769 Mdot
.63487 .02419 Mdot
.76944 .08317 Mdot
.03039 .16128 Mdot
.26718 .14634 Mdot
.37737 .06811 Mdot
.39889 .0133 Mdot
.34486 .58464 Mdot
.18546 .51952 Mdot
.90906 .44721 Mdot
.70152 .48977 Mdot
.61544 .56483 Mdot
.61382 .61703 Mdot
.69569 .0506 Mdot
.89755 .12475 Mdot
.17582 .17198 Mdot
.34035 .10169 Mdot
.39753 .03534 Mdot
.37828 .60614 Mdot
.27086 .55165 Mdot
.03722 .47363 Mdot
.77407 .4554 Mdot
.63679 .53319 Mdot
.59596 .5928 Mdot
.62734 .01939 Mdot
.75006 .07584 Mdot
.0001 .15453 Mdot
.25006 .15449 Mdot
.3727 .0758 Mdot
.40402 .01936 Mdot
.36312 .59276 Mdot
.22573 .53312 Mdot
.96249 .45534 Mdot
.72898 .47372 Mdot
.62169 .55172 Mdot
.60254 .6062 Mdot
.65985 .03542 Mdot
.82461 .10183 Mdot
.10296 .17203 Mdot
.30456 .1246 Mdot
.38625 .05049 Mdot
.3845 .61695 Mdot
.29824 .56472 Mdot
.09045 .48962 Mdot
.81414 .44726 Mdot
.65495 .51965 Mdot
.60105 .58472 Mdot
.62267 .01336 Mdot
.73299 .06818 Mdot
.96991 .14642 Mdot
.23076 .16121 Mdot
.36521 .0831 Mdot
.40427 .02414 Mdot
.37128 .59764 Mdot
.24617 .54072 Mdot
.99378 .46205 Mdot
.74636 .46512 Mdot
.62624 .54379 Mdot
.59684 .59986 Mdot
.64022 .02681 Mdot
.78181 .08751 Mdot
.04819 .16463 Mdot
.27661 .14117 Mdot
.37947 .06358 Mdot
.39488 .00952 Mdot
.33216 .57927 Mdot
.15872 .51084 Mdot
.87832 .44474 Mdot
.5 .15451 Mdot
.75 .15451 Mdot
.12732 .2332 Mdot
.41331 .17675 Mdot
.63333 .13598 Mdot
.94796 .19445 Mdot
.30348 .21973 Mdot
.53881 .14544 Mdot
.80488 .16444 Mdot
.19077 .2385 Mdot
.45806 .16519 Mdot
.69219 .1447 Mdot
.04532 .21825 Mdot
.36269 .19614 Mdot
.58334 .13637 Mdot
.86766 .17572 Mdot
.24606 .23387 Mdot
.49718 .1552 Mdot
.74605 .15381 Mdot
.1222 .23247 Mdot
.40992 .17782 Mdot
.62935 .13562 Mdot
.94125 .19276 Mdot
.29909 .22116 Mdot
.53561 .14618 Mdot
.80038 .16364 Mdot
.18614 .23842 Mdot
.4547 .16598 Mdot
.6875 .14388 Mdot
.03794 .21658 Mdot
.35831 .198 Mdot
.57972 .13684 Mdot
.86227 .17463 Mdot
.24176 .23454 Mdot
.4941 .15595 Mdot
.74171 .15303 Mdot
.11648 .23162 Mdot
.40616 .17903 Mdot
.62504 .13528 Mdot
.93399 .19094 Mdot
.29424 .22265 Mdot
.53205 .14698 Mdot
.79533 .16272 Mdot
.18081 .23824 Mdot
.4508 .16687 Mdot
.68207 .14293 Mdot
.02923 .21456 Mdot
.35314 .20019 Mdot
.57554 .13745 Mdot
.85613 .17341 Mdot
.23677 .23525 Mdot
.49052 .15683 Mdot
.7367 .15214 Mdot
.10975 .23056 Mdot
.4018 .1805 Mdot
.62018 .13497 Mdot
.92582 .1889 Mdot
.28868 .22426 Mdot
.52796 .14788 Mdot
.78949 .16164 Mdot
.17445 .23792 Mdot
.44616 .16793 Mdot
.67561 .14181 Mdot
.01874 .21206 Mdot
.3469 .20282 Mdot
.57063 .13827 Mdot
.84902 .17206 Mdot
.23088 .236 Mdot
.48633 .15788 Mdot
.73086 .15113 Mdot
.1018 .22925 Mdot
.39673 .18228 Mdot
.61474 .13473 Mdot
.91678 .18667 Mdot
.28241 .22597 Mdot
.52334 .14891 Mdot
.78288 .1604 Mdot
.16703 .23742 Mdot
.44078 .16918 Mdot
.66823 .14057 Mdot
.00656 .2091 Mdot
.33965 .20586 Mdot
.56508 .13933 Mdot
.84114 .17061 Mdot
.22421 .23675 Mdot
.48163 .15909 Mdot
.72438 .15003 Mdot
.0928 .2277 Mdot
.39112 .18437 Mdot
.60898 .13464 Mdot
.90736 .18441 Mdot
.27574 .22767 Mdot
.51846 .15001 Mdot
.77591 .15911 Mdot
.159 .23676 Mdot
.43502 .17059 Mdot
.66048 .13935 Mdot
.99366 .20591 Mdot
.33191 .20905 Mdot
.55932 .14055 Mdot
.8331 .16921 Mdot
.21724 .23741 Mdot
.47674 .16038 Mdot
.71771 .14892 Mdot
.08338 .226 Mdot
.38536 .18663 Mdot
.60336 .13473 Mdot
.89835 .18232 Mdot
.26925 .22923 Mdot
.51375 .15111 Mdot
.76923 .1579 Mdot
.15111 .23601 Mdot
.42946 .17203 Mdot
.65321 .13829 Mdot
.98146 .20287 Mdot
.32451 .21201 Mdot
.55393 .14179 Mdot
.82567 .16795 Mdot
.21062 .23791 Mdot
.47212 .16162 Mdot
.71142 .1479 Mdot
.07433 .22429 Mdot
.37991 .18886 Mdot
.59828 .13496 Mdot
.89038 .18052 Mdot
.2634 .23054 Mdot
.50955 .15213 Mdot
.76333 .15685 Mdot
.14399 .23526 Mdot
.42454 .17339 Mdot
.64696 .13746 Mdot
.97094 .20023 Mdot
.31804 .21452 Mdot
.54927 .14291 Mdot
.81929 .16688 Mdot
.20476 .23823 Mdot
.46801 .1627 Mdot
.70585 .14699 Mdot
.06615 .22267 Mdot
.37503 .1909 Mdot
.59391 .13527 Mdot
.88363 .17906 Mdot
.25837 .2316 Mdot
.50596 .15302 Mdot
.75832 .15597 Mdot
.13782 .23455 Mdot
.42035 .17461 Mdot
.64177 .13685 Mdot
.9622 .19803 Mdot
.31258 .21655 Mdot
.54536 .14387 Mdot
.81394 .16599 Mdot
.19971 .23842 Mdot
.46445 .16362 Mdot
.70099 .14619 Mdot
.05887 .22118 Mdot
.37072 .19273 Mdot
.59015 .13561 Mdot
.87789 .17784 Mdot
.25402 .23246 Mdot
.50287 .15379 Mdot
.75401 .15521 Mdot
.13243 .23388 Mdot
.41672 .1757 Mdot
.63738 .13638 Mdot
.9548 .19617 Mdot
.30789 .21823 Mdot
.54199 .14468 Mdot
.8093 .16521 Mdot
.1952 .2385 Mdot
.46124 .16443 Mdot
.69659 .14545 Mdot
.05216 .21975 Mdot
.36674 .19442 Mdot
.58675 .13597 Mdot
.87276 .17677 Mdot
.25007 .23319 Mdot
.50005 .1545 Mdot
.75007 .15452 Mdot
.12741 .23321 Mdot
.41337 .17673 Mdot
.63339 .13598 Mdot
.94807 .19448 Mdot
.30356 .2197 Mdot
.53886 .14543 Mdot
.80495 .16445 Mdot
.19085 .2385 Mdot
.45812 .16518 Mdot
.69226 .14471 Mdot
.04544 .21828 Mdot
.36276 .19611 Mdot
.5834 .13636 Mdot
.86775 .17574 Mdot
.24613 .23386 Mdot
.49723 .15519 Mdot
.74612 .15382 Mdot
.12229 .23249 Mdot
.40998 .1778 Mdot
.62942 .13563 Mdot
.94137 .19279 Mdot
.29916 .22113 Mdot
.53566 .14616 Mdot
.80046 .16365 Mdot
.18623 .23842 Mdot
.45476 .16596 Mdot
.68759 .1439 Mdot
.03808 .21661 Mdot
.35839 .19797 Mdot
.57979 .13683 Mdot
.86237 .17465 Mdot
.24184 .23452 Mdot
.49416 .15594 Mdot
.74179 .15305 Mdot
.11659 .23163 Mdot
.40623 .17901 Mdot
.62512 .13528 Mdot
.93412 .19097 Mdot
.29433 .22262 Mdot
.53212 .14696 Mdot
.79543 .16273 Mdot
.18091 .23824 Mdot
.45088 .16685 Mdot
.68217 .14295 Mdot
.02939 .2146 Mdot
.35324 .20015 Mdot
.57562 .13744 Mdot
.85624 .17344 Mdot
.23686 .23523 Mdot
.49059 .15681 Mdot
.73679 .15216 Mdot
.10988 .23058 Mdot
.40188 .18047 Mdot
.62027 .13497 Mdot
.92597 .18893 Mdot
.28878 .22423 Mdot
.52804 .14787 Mdot
.7896 .16166 Mdot
.17457 .23792 Mdot
.44625 .16791 Mdot
.67573 .14183 Mdot
.01893 .21211 Mdot
.34702 .20277 Mdot
.57072 .13825 Mdot
.84915 .17208 Mdot
.23099 .23599 Mdot
.48641 .15786 Mdot
.73097 .15115 Mdot
.10194 .22928 Mdot
.39683 .18225 Mdot
.61483 .13473 Mdot
.91694 .18671 Mdot
.28252 .22594 Mdot
.52342 .14889 Mdot
.783 .16043 Mdot
.16717 .23743 Mdot
.44087 .16916 Mdot
.66836 .14059 Mdot
.00678 .20916 Mdot
.33978 .2058 Mdot
.56518 .13931 Mdot
.84128 .17064 Mdot
.22433 .23674 Mdot
.48171 .15907 Mdot
.72449 .15005 Mdot
.09296 .22773 Mdot
.39122 .18433 Mdot
.60908 .13464 Mdot
.90752 .18445 Mdot
.27586 .22764 Mdot
.51854 .14999 Mdot
.77603 .15914 Mdot
.15914 .23678 Mdot
.43512 .17056 Mdot
.66062 .13937 Mdot
.99388 .20597 Mdot
.33204 .20899 Mdot
.55942 .14053 Mdot
.83324 .16923 Mdot
.21736 .2374 Mdot
.47683 .16036 Mdot
.71782 .14894 Mdot
.08355 .22603 Mdot
.38546 .18659 Mdot
.60345 .13473 Mdot
.8985 .18235 Mdot
.26935 .2292 Mdot
.51382 .15109 Mdot
.76934 .15792 Mdot
.15124 .23603 Mdot
.42955 .17201 Mdot
.65333 .1383 Mdot
.98166 .20292 Mdot
.32463 .21197 Mdot
.55402 .14177 Mdot
.82579 .16797 Mdot
.21073 .2379 Mdot
.47219 .1616 Mdot
.71152 .14792 Mdot
.07448 .22432 Mdot
.38 .18882 Mdot
.59836 .13496 Mdot
.8905 .18055 Mdot
.26349 .23052 Mdot
.50961 .15211 Mdot
.76342 .15686 Mdot
.1441 .23527 Mdot
.42462 .17337 Mdot
.64706 .13748 Mdot
.9711 .20027 Mdot
.31814 .21448 Mdot
.54934 .14289 Mdot
.81939 .1669 Mdot
.20485 .23823 Mdot
.46808 .16268 Mdot
.70594 .14701 Mdot
.06628 .2227 Mdot
.37511 .19087 Mdot
.59398 .13527 Mdot
.88373 .17908 Mdot
.25845 .23159 Mdot
.50602 .15301 Mdot
.7584 .15598 Mdot
.13792 .23456 Mdot
.42041 .17459 Mdot
.64185 .13686 Mdot
.96234 .19807 Mdot
.31267 .21652 Mdot
.54542 .14385 Mdot
.81403 .16601 Mdot
.19979 .23841 Mdot
.46451 .16361 Mdot
.70107 .1462 Mdot
.05899 .22121 Mdot
.37079 .1927 Mdot
.59021 .13561 Mdot
.87799 .17786 Mdot
.25409 .23245 Mdot
.50292 .15378 Mdot
.75408 .15522 Mdot
.13252 .23389 Mdot
.41678 .17568 Mdot
.63745 .13638 Mdot
.95492 .1962 Mdot
.30797 .2182 Mdot
.54205 .14467 Mdot
.80938 .16522 Mdot
.19527 .2385 Mdot
.4613 .16441 Mdot
.69666 .14546 Mdot
.05227 .21978 Mdot
.36681 .1944 Mdot
.5868 .13596 Mdot
.87285 .17679 Mdot
.25013 .23318 Mdot
.5001 .15448 Mdot
.75013 .15453 Mdot
.1275 .23322 Mdot
.41343 .17671 Mdot
.63346 .13599 Mdot
.94819 .19451 Mdot
.30363 .21968 Mdot
.53892 .14541 Mdot
.80503 .16446 Mdot
.19093 .2385 Mdot
.45817 .16517 Mdot
.69234 .14472 Mdot
.04556 .21831 Mdot
.36283 .19608 Mdot
.58346 .13635 Mdot
.86784 .17575 Mdot
.2462 .23384 Mdot
.49728 .15518 Mdot
.74619 .15383 Mdot
.12238 .2325 Mdot
.41004 .17778 Mdot
.62949 .13563 Mdot
.94149 .19282 Mdot
.29924 .22111 Mdot
.53572 .14615 Mdot
.80054 .16367 Mdot
.18631 .23842 Mdot
.45482 .16595 Mdot
.68768 .14391 Mdot
.03821 .21664 Mdot
.35847 .19793 Mdot
.57985 .13682 Mdot
.86247 .17467 Mdot
.24192 .23451 Mdot
.49421 .15592 Mdot
.74187 .15306 Mdot
.11669 .23165 Mdot
.4063 .17899 Mdot
.6252 .13529 Mdot
.93425 .191 Mdot
.29442 .22259 Mdot
.53218 .14695 Mdot
.79552 .16275 Mdot
.18101 .23825 Mdot
.45095 .16683 Mdot
.68227 .14296 Mdot
.02956 .21464 Mdot
0 .18541 Mdot
.3 .18541 Mdot
.47891 .11057 Mdot
.64099 .10017 Mdot
.90168 .16112 Mdot
.23612 .20669 Mdot
.44372 .1283 Mdot
.60722 .10105 Mdot
.85016 .15014 Mdot
.19603 .21376 Mdot
.42183 .13955 Mdot
.58757 .10244 Mdot
.81989 .14358 Mdot
.16745 .21481 Mdot
.40444 .14646 Mdot
.56948 .102 Mdot
.78836 .13527 Mdot
.13088 .21169 Mdot
.38011 .15403 Mdot
.54224 .1002 Mdot
.73776 .12084 Mdot
.06023 .1993 Mdot
.33566 .17022 Mdot
.50177 .10266 Mdot
.66928 .10353 Mdot
.9481 .17232 Mdot
.2677 .19753 Mdot
.46077 .11932 Mdot
.62277 .10012 Mdot
.87353 .15498 Mdot
.21515 .21113 Mdot
.43248 .13432 Mdot
.59741 .10193 Mdot
.8355 .14714 Mdot
.18297 .21475 Mdot
.41425 .14294 Mdot
.5802 .10256 Mdot
.80762 .14055 Mdot
.15411 .21414 Mdot
.3957 .14931 Mdot
.55969 .10135 Mdot
.77032 .13018 Mdot
.10724 .20823 Mdot
.36471 .15913 Mdot
.52653 .10001 Mdot
.70947 .11306 Mdot
.01562 .18922 Mdot
.3093 .1815 Mdot
.48439 .10821 Mdot
.64701 .10051 Mdot
.91122 .16329 Mdot
.24283 .20494 Mdot
.44724 .12633 Mdot
.6102 .10072 Mdot
.85445 .15096 Mdot
.19958 .2133 Mdot
.42371 .13852 Mdot
.58913 .10223 Mdot
.82219 .14404 Mdot
.16969 .21477 Mdot
.40574 .14589 Mdot
.57071 .10196 Mdot
.79041 .13578 Mdot
.13336 .21195 Mdot
.38167 .15346 Mdot
.54379 .1002 Mdot
.74051 .12158 Mdot
.06433 .20013 Mdot
.33807 .16918 Mdot
.5035 .10224 Mdot
.67171 .10397 Mdot
.95216 .17333 Mdot
.27031 .19662 Mdot
.46216 .11857 Mdot
.62403 .10004 Mdot
.87538 .15534 Mdot
.21655 .21085 Mdot
.43319 .13389 Mdot
.59795 .10182 Mdot
.83621 .14725 Mdot
.18357 .21468 Mdot
.41453 .14274 Mdot
.58037 .10249 Mdot
.80779 .14056 Mdot
.15424 .21412 Mdot
.39572 .14925 Mdot
.55963 .1013 Mdot
.77013 .1301 Mdot
.10693 .20816 Mdot
.36448 .15918 Mdot
.52626 .09998 Mdot
.70894 .11291 Mdot
.01474 .18899 Mdot
.30876 .18172 Mdot
.48404 .10833 Mdot
.64657 .10045 Mdot
.91046 .1631 Mdot
.24227 .20507 Mdot
.4469 .12647 Mdot
.60984 .1007 Mdot
.85385 .1508 Mdot
.19902 .21333 Mdot
.42334 .13864 Mdot
.58869 .10219 Mdot
.82136 .1438 Mdot
.16878 .21471 Mdot
.40509 .14605 Mdot
.5699 .10186 Mdot
.78885 .13532 Mdot
.13135 .21168 Mdot
.3803 .15386 Mdot
.54226 .1001 Mdot
.73763 .12075 Mdot
.05994 .1992 Mdot
.33543 .17026 Mdot
.50149 .10263 Mdot
.66875 .10337 Mdot
.94709 .17203 Mdot
.26699 .19771 Mdot
.46029 .11946 Mdot
.62214 .10003 Mdot
.87239 .15466 Mdot
.21414 .21121 Mdot
.43178 .13451 Mdot
.5965 .1018 Mdot
.83379 .14665 Mdot
.18115 .21468 Mdot
.41292 .14324 Mdot
.57846 .1023 Mdot
.80424 .13954 Mdot
.15003 .21371 Mdot
.39279 .15004 Mdot
.55613 .10095 Mdot
.76346 .12813 Mdot
.09765 .20654 Mdot
.35853 .16123 Mdot
.52057 .10014 Mdot
.69901 .11028 Mdot
.99829 .18497 Mdot
.29894 .18581 Mdot
.47824 .11081 Mdot
.64019 .10009 Mdot
.90035 .16078 Mdot
.23512 .2069 Mdot
.44312 .12855 Mdot
.60657 .10102 Mdot
.84905 .14986 Mdot
.19499 .2138 Mdot
.42113 .13976 Mdot
.58672 .10234 Mdot
.8183 .14313 Mdot
.16566 .21468 Mdot
.40316 .14678 Mdot
.56789 .1018 Mdot
.78528 .13436 Mdot
.12689 .21112 Mdot
.3774 .15482 Mdot
.53925 .10003 Mdot
.73219 .11924 Mdot
.05165 .19744 Mdot
.33051 .17235 Mdot
.498 .10351 Mdot
.66389 .10252 Mdot
.93891 .16997 Mdot
.26162 .19944 Mdot
.45734 .12096 Mdot
.61933 .10012 Mdot
.86809 .15374 Mdot
.21071 .21175 Mdot
.42986 .13544 Mdot
.5947 .10188 Mdot
.8309 .14598 Mdot
.17833 .21472 Mdot
.41113 .14388 Mdot
.57647 .10219 Mdot
.80066 .13856 Mdot
.14578 .21329 Mdot
.38991 .15088 Mdot
.55283 .10069 Mdot
.75724 .12633 Mdot
.08884 .20494 Mdot
.353 .16326 Mdot
.51559 .10048 Mdot
.69063 .10818 Mdot
.98423 .18146 Mdot
.29043 .18924 Mdot
.47339 .11308 Mdot
.63516 .09998 Mdot
.89253 .15906 Mdot
.22948 .20825 Mdot
.44017 .13021 Mdot
.60412 .10132 Mdot
.84555 .14921 Mdot
.19203 .21414 Mdot
.41955 .14061 Mdot
.58541 .10251 Mdot
.81637 .14274 Mdot
.16374 .21469 Mdot
.40203 .14727 Mdot
.56681 .10184 Mdot
.78347 .13391 Mdot
.12466 .21086 Mdot
.376 .15534 Mdot
.53789 .10005 Mdot
.7298 .11861 Mdot
.04801 .19667 Mdot
.32839 .17329 Mdot
.49659 .10395 Mdot
.66205 .10226 Mdot
.93588 .16924 Mdot
.25964 .20009 Mdot
.4563 .12154 Mdot
.61843 .10021 Mdot
.86681 .15351 Mdot
.20973 .21194 Mdot
.42938 .13575 Mdot
.59437 .10197 Mdot
.83051 .14594 Mdot
.17803 .21478 Mdot
.41102 .144 Mdot
.57648 .10226 Mdot
.8008 .13864 Mdot
.14601 .21335 Mdot
.39012 .15087 Mdot
.55315 .10076 Mdot
.75791 .12655 Mdot
.08984 .20514 Mdot
.35365 .16304 Mdot
.5162 .10046 Mdot
.6917 .10846 Mdot
.98606 .18193 Mdot
.29157 .18881 Mdot
.47406 .11279 Mdot
.6359 .10002 Mdot
.89371 .15934 Mdot
.23038 .20807 Mdot
.44069 .12998 Mdot
.60463 .10132 Mdot
.84639 .14941 Mdot
.19282 .21411 Mdot
.42006 .14044 Mdot
.586 .10256 Mdot
.81743 .14304 Mdot
.16494 .21477 Mdot
.40287 .14705 Mdot
.56784 .10196 Mdot
.78545 .13449 Mdot
.12724 .21124 Mdot
.37774 .15482 Mdot
.53977 .10014 Mdot
.73328 .1196 Mdot
.05342 .19786 Mdot
.33162 .17194 Mdot
.49887 .10337 Mdot
.66523 .10281 Mdot
.94126 .1706 Mdot
.26323 .19899 Mdot
.45831 .12057 Mdot
.62043 .10019 Mdot
.86995 .15421 Mdot
.21232 .21159 Mdot
.43091 .1351 Mdot
.59595 .102 Mdot
.83318 .14662 Mdot
.18074 .2148 Mdot
.41285 .14345 Mdot
.57866 .10248 Mdot
.80486 .1398 Mdot
.1509 .21386 Mdot
.39351 .14994 Mdot
.55714 .10113 Mdot
.76552 .12878 Mdot
.10061 .2071 Mdot
.36047 .1606 Mdot
.52246 .10012 Mdot
.70237 .11119 Mdot
.00394 .18638 Mdot
.30236 .18443 Mdot
.48028 .10996 Mdot
.64247 .10024 Mdot
.90401 .16164 Mdot
.23777 .20628 Mdot
.44458 .12782 Mdot
.60795 .10097 Mdot
.85121 .15034 Mdot
.19691 .21365 Mdot
.4223 .1393 Mdot
.58796 .10239 Mdot
.82047 .1437 Mdot
.16803 .2148 Mdot
.40478 .14632 Mdot
.56981 .102 Mdot
.78892 .13542 Mdot
.13156 .21177 Mdot
.38054 .15388 Mdot
.54267 .1002 Mdot
.73854 .12105 Mdot
.06139 .19954 Mdot
.33635 .16993 Mdot
.50226 .10254 Mdot
.66997 .10365 Mdot
.94925 .1726 Mdot
.26844 .19727 Mdot
.46117 .11911 Mdot
.62314 .1001 Mdot
.87407 .15509 Mdot
.21557 .21105 Mdot
.4327 .1342 Mdot
.59759 .10191 Mdot
.83575 .14719 Mdot
.18319 .21473 Mdot
.41437 .14287 Mdot
.5803 .10255 Mdot
.80777 .14059 Mdot
.15427 .21415 Mdot
.3958 .14927 Mdot
.55979 .10135 Mdot
.77049 .13022 Mdot
.10746 .20826 Mdot
.36485 .15907 Mdot
.52665 .1 Mdot
.70967 .11311 Mdot
.01595 .18929 Mdot
.30949 .18142 Mdot
.4845 .10816 Mdot
.64713 .10051 Mdot
.9114 .16333 Mdot
.24294 .20491 Mdot
.44729 .12629 Mdot
.61023 .10071 Mdot
.85448 .15095 Mdot
.19959 .21329 Mdot
.42371 .13851 Mdot
.5891 .10222 Mdot
.82211 .14401 Mdot
.16959 .21476 Mdot
.40566 .1459 Mdot
.5706 .10194 Mdot
.79019 .13571 Mdot
.13306 .21191 Mdot
.38146 .15352 Mdot
.54355 .10018 Mdot
.74006 .12145 Mdot
.06364 .19998 Mdot
.33765 .16935 Mdot
.50317 .1023 Mdot
.67123 .10386 Mdot
.95133 .17311 Mdot
.26976 .1968 Mdot
.46185 .11872 Mdot
.62371 .10004 Mdot
.87488 .15523 Mdot
.21614 .21091 Mdot
.43295 .134 Mdot
.5977 .10182 Mdot
.83578 .14715 Mdot
.18314 .21468 Mdot
.41425 .14283 Mdot
.58002 .10245 Mdot
.80715 .14037 Mdot
.15348 .21404 Mdot
.3952 .14939 Mdot
.55899 .10123 Mdot
.76891 .12974 Mdot
.10525 .20787 Mdot
.3634 .15954 Mdot
.5252 .1 Mdot
.70707 .1124 Mdot
.01165 .18825 Mdot
.30693 .18249 Mdot
.48294 .10878 Mdot
.64532 .10036 Mdot
.90846 .16263 Mdot
.24087 .20544 Mdot
.44616 .12688 Mdot
.60918 .10076 Mdot
.85287 .15061 Mdot
.1982 .21342 Mdot
.42288 .13886 Mdot
.58827 .10221 Mdot
.82069 .14365 Mdot
.16809 .2147 Mdot
.40466 .14621 Mdot
.56943 .10184 Mdot
.788 .13509 Mdot
.13029 .21154 Mdot
.3796 .15408 Mdot
.54152 .10007 Mdot
.73628 .12037 Mdot
.05789 .19877 Mdot
.3342 .17077 Mdot
.5006 .10284 Mdot
.66747 .10313 Mdot
.94494 .17148 Mdot
.26558 .19817 Mdot
.4595 .11985 Mdot
.62138 .10004 Mdot
.87121 .15441 Mdot
.2132 .21136 Mdot
.43124 .13476 Mdot
.59598 .10181 Mdot
.5 .18541 Mdot
.8 .18541 Mdot
.22109 .26025 Mdot
.51696 .18285 Mdot
.82636 .19122 Mdot
.24871 .26103 Mdot
.54374 .18234 Mdot
.87332 .20369 Mdot
.29388 .25992 Mdot
.59192 .1842 Mdot
.95949 .22717 Mdot
.35911 .24698 Mdot
.66018 .18607 Mdot
.06883 .25256 Mdot
.42411 .21958 Mdot
.72096 .18346 Mdot
.14303 .26085 Mdot
.46546 .19927 Mdot
.76047 .18233 Mdot
.18254 .26085 Mdot
.48854 .18912 Mdot
.78539 .18346 Mdot
.20643 .26022 Mdot
.50489 .18446 Mdot
.80726 .18687 Mdot
.22879 .26053 Mdot
.52414 .18253 Mdot
.83872 .19442 Mdot
.26135 .2612 Mdot
.55698 .18271 Mdot
.89723 .21028 Mdot
.31409 .25764 Mdot
.61383 .18524 Mdot
.99705 .23685 Mdot
.38263 .2383 Mdot
.68261 .18539 Mdot
.09866 .25713 Mdot
.44074 .21142 Mdot
.73651 .18279 Mdot
.15914 .2612 Mdot
.47464 .19499 Mdot
.76994 .1825 Mdot
.19156 .26058 Mdot
.49435 .18713 Mdot
.79261 .18434 Mdot
.21366 .26022 Mdot
.5107 .18358 Mdot
.81628 .18886 Mdot
.2383 .26083 Mdot
.53335 .18235 Mdot
.85487 .19871 Mdot
.27707 .26093 Mdot
.57378 .18338 Mdot
.92742 .21856 Mdot
.33713 .25322 Mdot
.63813 .18603 Mdot
.03627 .24606 Mdot
.40564 .22829 Mdot
.70388 .18432 Mdot
.12413 .25973 Mdot
.45485 .20439 Mdot
.74992 .18236 Mdot
.17232 .26106 Mdot
.48226 .19155 Mdot
.77803 .1828 Mdot
.19916 .26027 Mdot
.49941 .18556 Mdot
.79918 .18527 Mdot
.22025 .26023 Mdot
.51621 .18291 Mdot
.82511 .19091 Mdot
.24742 .261 Mdot
.54243 .18232 Mdot
.87097 .20305 Mdot
.29179 .26008 Mdot
.58966 .18409 Mdot
.95552 .22611 Mdot
.35651 .24782 Mdot
.65762 .1861 Mdot
.06521 .25191 Mdot
.42208 .22056 Mdot
.71907 .18355 Mdot
.141 .26076 Mdot
.46431 .19982 Mdot
.7593 .18232 Mdot
.1814 .26087 Mdot
.48782 .18938 Mdot
.78451 .18336 Mdot
.20554 .26021 Mdot
.50418 .18457 Mdot
.80617 .18664 Mdot
.22764 .26048 Mdot
.52303 .18256 Mdot
.83679 .19391 Mdot
.25941 .26119 Mdot
.55492 .18264 Mdot
.89351 .20926 Mdot
.31107 .25807 Mdot
.61057 .1851 Mdot
.99157 .23547 Mdot
.37932 .23964 Mdot
.6795 .18553 Mdot
.09473 .25662 Mdot
.43857 .2125 Mdot
.73447 .18288 Mdot
.15709 .26119 Mdot
.47347 .19554 Mdot
.76873 .18248 Mdot
.19043 .26063 Mdot
.49362 .18738 Mdot
.79171 .18423 Mdot
.21278 .26023 Mdot
.50999 .18369 Mdot
.81518 .18862 Mdot
.23717 .2608 Mdot
.53225 .18237 Mdot
.85294 .1982 Mdot
.27525 .261 Mdot
.57182 .1833 Mdot
.92393 .21761 Mdot
.3346 .25381 Mdot
.63552 .18598 Mdot
.03222 .24517 Mdot
.40332 .22935 Mdot
.70174 .18444 Mdot
.12168 .25954 Mdot
.45349 .20507 Mdot
.74861 .18239 Mdot
.17105 .26108 Mdot
.48151 .19188 Mdot
.77722 .18276 Mdot
.19839 .2603 Mdot
.49887 .18571 Mdot
.79846 .18515 Mdot
.21951 .26022 Mdot
.51557 .18297 Mdot
.82405 .19066 Mdot
.24633 .26098 Mdot
.54132 .18231 Mdot
.86899 .20251 Mdot
.29003 .26022 Mdot
.58775 .184 Mdot
.95217 .22522 Mdot
.35428 .24852 Mdot
.65543 .18612 Mdot
.06208 .25132 Mdot
.42031 .2214 Mdot
.71743 .18363 Mdot
.13922 .26068 Mdot
.4633 .20029 Mdot
.75829 .18231 Mdot
.18042 .26089 Mdot
.4872 .1896 Mdot
.78376 .18328 Mdot
.20479 .26021 Mdot
.5036 .18467 Mdot
.80529 .18645 Mdot
.22669 .26044 Mdot
.52214 .18259 Mdot
.83524 .19351 Mdot
.25783 .26118 Mdot
.55326 .18258 Mdot
.8905 .20843 Mdot
.30859 .2584 Mdot
.60789 .18498 Mdot
.98704 .23433 Mdot
.37655 .24073 Mdot
.6769 .18563 Mdot
.09139 .25617 Mdot
.43671 .21342 Mdot
.73273 .18295 Mdot
.15533 .26118 Mdot
.47247 .196 Mdot
.7677 .18246 Mdot
.18946 .26066 Mdot
.493 .1876 Mdot
.79095 .18414 Mdot
.21203 .26024 Mdot
.50939 .18378 Mdot
.81425 .18842 Mdot
.23621 .26078 Mdot
.53132 .18239 Mdot
.85132 .19777 Mdot
.2737 .26105 Mdot
.57017 .18323 Mdot
.92098 .21681 Mdot
.33244 .2543 Mdot
.63327 .18593 Mdot
.02869 .24438 Mdot
.40128 .23027 Mdot
.69987 .18454 Mdot
.11952 .25936 Mdot
.45229 .20566 Mdot
.74746 .18242 Mdot
.16993 .2611 Mdot
.48086 .19216 Mdot
.77651 .18272 Mdot
.19772 .26032 Mdot
.49842 .18584 Mdot
.79785 .18506 Mdot
.2189 .26022 Mdot
.51504 .18303 Mdot
.8232 .19045 Mdot
.24545 .26097 Mdot
.54043 .18231 Mdot
.86741 .20208 Mdot
.28861 .26032 Mdot
.58621 .18393 Mdot
.94947 .2245 Mdot
.35247 .24907 Mdot
.65364 .18613 Mdot
.0595 .25084 Mdot
.41886 .2221 Mdot
.71609 .1837 Mdot
.13776 .26061 Mdot
.46248 .20069 Mdot
.75745 .18231 Mdot
.17962 .26091 Mdot
.4867 .18979 Mdot
.78316 .18322 Mdot
.2042 .26021 Mdot
.50314 .18476 Mdot
.8046 .18631 Mdot
.22596 .26042 Mdot
.52144 .18262 Mdot
.83404 .19319 Mdot
.25661 .26117 Mdot
.55197 .18254 Mdot
.88817 .20778 Mdot
.30666 .25864 Mdot
.6058 .18488 Mdot
.98348 .23342 Mdot
.37435 .24157 Mdot
.67483 .18571 Mdot
.0887 .25578 Mdot
.43522 .21416 Mdot
.73134 .18301 Mdot
.15391 .26116 Mdot
.47166 .19638 Mdot
.76686 .18245 Mdot
.18868 .26069 Mdot
.4925 .18777 Mdot
.79033 .18407 Mdot
.21141 .26025 Mdot
.5089 .18386 Mdot
.8135 .18825 Mdot
.23542 .26076 Mdot
.53056 .1824 Mdot
.84999 .19742 Mdot
.27243 .26108 Mdot
.56881 .18317 Mdot
.91855 .21615 Mdot
.33063 .25468 Mdot
.63139 .18588 Mdot
.02573 .24371 Mdot
.39957 .23105 Mdot
.69829 .18462 Mdot
.11768 .2592 Mdot
.45127 .20617 Mdot
.74648 .18245 Mdot
.16898 .26112 Mdot
.48031 .19241 Mdot
.77592 .1827 Mdot
.19717 .26035 Mdot
.49804 .18595 Mdot
.79736 .18498 Mdot
.2184 .26022 Mdot
.51461 .18307 Mdot
.82251 .19029 Mdot
.24474 .26095 Mdot
.53972 .18231 Mdot
.86614 .20174 Mdot
.28746 .26039 Mdot
.58498 .18387 Mdot
.94728 .22392 Mdot
.351 .24951 Mdot
.65218 .18614 Mdot
.05737 .25043 Mdot
.41766 .22267 Mdot
.71498 .18375 Mdot
.13654 .26054 Mdot
.46179 .20101 Mdot
.75677 .18231 Mdot
.17895 .26092 Mdot
.48629 .18994 Mdot
.78268 .18318 Mdot
.20371 .26021 Mdot
.50277 .18483 Mdot
.80404 .1862 Mdot
.22537 .26039 Mdot
.52089 .18264 Mdot
.83308 .19294 Mdot
.25564 .26115 Mdot
.55095 .18251 Mdot
.88633 .20728 Mdot
.30511 .25882 Mdot
.60412 .1848 Mdot
.98061 .23269 Mdot
.37258 .24225 Mdot
.67315 .18576 Mdot
.08649 .25546 Mdot
.43399 .21477 Mdot
.73019 .18306 Mdot
.15273 .26114 Mdot
.47099 .1967 Mdot
.76617 .18243 Mdot
.18803 .26072 Mdot
.49208 .18792 Mdot
.78981 .18401 Mdot
.2109 .26025 Mdot
.50849 .18392 Mdot
.81286 .18811 Mdot
.23476 .26075 Mdot
.52992 .18242 Mdot
.84886 .19712 Mdot
.27135 .26111 Mdot
.56766 .18313 Mdot
.91647 .21558 Mdot
.32908 .25501 Mdot
.62977 .18583 Mdot
.02315 .24312 Mdot
.39807 .23172 Mdot
.69691 .18469 Mdot
.11606 .25905 Mdot
.45037 .20662 Mdot
.74563 .18248 Mdot
.16815 .26114 Mdot
.47982 .19262 Mdot
.7754 .18268 Mdot
.19668 .26037 Mdot
.49772 .18605 Mdot
.79692 .18492 Mdot
.21796 .26022 Mdot
.51425 .18311 Mdot
.82192 .19015 Mdot
.24413 .26094 Mdot
.53911 .18231 Mdot
.86505 .20145 Mdot
.28648 .26046 Mdot
.58391 .18382 Mdot
.9454 .22342 Mdot
.34972 .24988 Mdot
.6509 .18614 Mdot
.05552 .25006 Mdot
.41661 .22317 Mdot
.714 .1838 Mdot
.13548 .26049 Mdot
.46119 .2013 Mdot
.75617 .18231 Mdot
.17837 .26094 Mdot
.48593 .19008 Mdot
.78225 .18313 Mdot
.20329 .26022 Mdot
.50244 .18489 Mdot
.80356 .1861 Mdot
.22485 .26038 Mdot
.52041 .18266 Mdot
.83226 .19273 Mdot
.25479 .26114 Mdot
.55006 .18249 Mdot
.88473 .20683 Mdot
.30376 .25897 Mdot
.60266 .18473 Mdot
.9781 .23204 Mdot
.37101 .24283 Mdot
.67166 .18581 Mdot
.08452 .25516 Mdot
.4329 .21531 Mdot
.72917 .18311 Mdot
.15167 .26112 Mdot
.47039 .19698 Mdot
.76555 .18242 Mdot
.18744 .26074 Mdot
.49171 .18805 Mdot
.78934 .18395 Mdot
.21043 .26025 Mdot
.50811 .18398 Mdot
.81228 .18799 Mdot
.23415 .26073 Mdot
.52932 .18243 Mdot
.84782 .19684 Mdot
.27034 .26113 Mdot
.56658 .18308 Mdot
.91453 .21505 Mdot
.32762 .2553 Mdot
.62824 .18579 Mdot
.02069 .24255 Mdot
.39664 .23235 Mdot
.6956 .18476 Mdot
.11451 .2589 Mdot
.44951 .20705 Mdot
.7448 .1825 Mdot
.16735 .26115 Mdot
.47936 .19283 Mdot
.7749 .18266 Mdot
.19621 .26038 Mdot
.4974 .18615 Mdot
.79651 .18486 Mdot
.21755 .26021 Mdot
.5139 .18315 Mdot
.82135 .19002 Mdot
0 .21631 Mdot
.35 .21631 Mdot
.59699 .15265 Mdot
.91687 .19769 Mdot
.30026 .23695 Mdot
.56263 .16215 Mdot
.87382 .19233 Mdot
.27571 .24838 Mdot
.55193 .17071 Mdot
.86896 .19594 Mdot
.27937 .25365 Mdot
.56462 .1763 Mdot
.90017 .20738 Mdot
.31044 .25356 Mdot
.60246 .18048 Mdot
.9709 .22771 Mdot
.36249 .24202 Mdot
.65726 .18218 Mdot
.05835 .24788 Mdot
.41379 .21968 Mdot
.70359 .17911 Mdot
.11535 .25448 Mdot
.44269 .20231 Mdot
.72517 .17458 Mdot
.13343 .25232 Mdot
.44701 .19381 Mdot
.71899 .16809 Mdot
.11588 .24529 Mdot
.42805 .19293 Mdot
.68459 .15855 Mdot
.05785 .23069 Mdot
.38584 .20271 Mdot
.63014 .15099 Mdot
.96734 .2084 Mdot
.33048 .22443 Mdot
.58223 .15559 Mdot
.89688 .19446 Mdot
.28837 .24196 Mdot
.55622 .16554 Mdot
.86812 .19277 Mdot
.27386 .25076 Mdot
.5537 .17295 Mdot
.87569 .199 Mdot
.28732 .2544 Mdot
.57511 .17786 Mdot
.92079 .21364 Mdot
.32725 .25121 Mdot
.62109 .1816 Mdot
.00273 .23587 Mdot
.38218 .23451 Mdot
.67576 .18144 Mdot
.08306 .25172 Mdot
.42688 .2125 Mdot
.71425 .1776 Mdot
.12575 .25432 Mdot
.44679 .19841 Mdot
.72605 .17259 Mdot
.13119 .25039 Mdot
.44287 .19263 Mdot
.70982 .16499 Mdot
.10007 .24118 Mdot
.41543 .1949 Mdot
.66626 .15503 Mdot
.02721 .22308 Mdot
.36649 .20969 Mdot
.61106 .15115 Mdot
.93744 .20171 Mdot
.31259 .23185 Mdot
.57013 .15917 Mdot
.88199 .19274 Mdot
.27983 .24588 Mdot
.55259 .16857 Mdot
.86665 .1941 Mdot
.27534 .25259 Mdot
.55832 .17489 Mdot
.88691 .20308 Mdot
.29856 .25441 Mdot
.58875 .17935 Mdot
.94633 .22099 Mdot
.34603 .24703 Mdot
.6409 .18224 Mdot
.03432 .24315 Mdot
.4005 .22631 Mdot
.69217 .18026 Mdot
.10284 .25381 Mdot
.43685 .20643 Mdot
.72165 .17602 Mdot
.13177 .25346 Mdot
.4481 .19551 Mdot
.72365 .1703 Mdot
.12479 .24791 Mdot
.43601 .19235 Mdot
.69741 .16155 Mdot
.07925 .23599 Mdot
.40027 .1984 Mdot
.64664 .15226 Mdot
.9944 .21493 Mdot
.34665 .2177 Mdot
.59433 .15308 Mdot
.91313 .19703 Mdot
.29803 .23788 Mdot
.56136 .16275 Mdot
.87256 .19234 Mdot
.27517 .24882 Mdot
.55204 .17112 Mdot
.86981 .19639 Mdot
.2805 .25382 Mdot
.56619 .17657 Mdot
.90332 .20836 Mdot
.31312 .25327 Mdot
.60549 .18069 Mdot
.9762 .22911 Mdot
.36588 .24084 Mdot
.66052 .1821 Mdot
.06289 .24868 Mdot
.41624 .21839 Mdot
.70564 .17886 Mdot
.11746 .25451 Mdot
.4436 .20157 Mdot
.72557 .17427 Mdot
.13337 .25203 Mdot
.44652 .19354 Mdot
.7177 .1676 Mdot
.11359 .24467 Mdot
.42612 .19316 Mdot
.68166 .15793 Mdot
.05296 .22948 Mdot
.38267 .20377 Mdot
.62679 .15088 Mdot
.96196 .20714 Mdot
.32726 .22577 Mdot
.57996 .15617 Mdot
.89396 .19407 Mdot
.28666 .2427 Mdot
.5554 .16609 Mdot
.86756 .19293 Mdot
.27386 .25111 Mdot
.55427 .1733 Mdot
.87726 .19962 Mdot
.28899 .25447 Mdot
.5772 .17812 Mdot
.92478 .21482 Mdot
.33032 .25064 Mdot
.62441 .18176 Mdot
.00819 .23719 Mdot
.38542 .23314 Mdot
.67871 .18126 Mdot
.08676 .25219 Mdot
.42879 .21138 Mdot
.71573 .17734 Mdot
.12706 .25421 Mdot
.4472 .19786 Mdot
.72586 .17223 Mdot
.13039 .25001 Mdot
.44189 .19252 Mdot
.70793 .16442 Mdot
.09687 .24038 Mdot
.41301 .19539 Mdot
.66297 .15449 Mdot
.0217 .2217 Mdot
.36312 .21101 Mdot
.60804 .15137 Mdot
.9329 .20078 Mdot
.30987 .23298 Mdot
.56841 .15979 Mdot
.88002 .19258 Mdot
.27878 .24644 Mdot
.55228 .16904 Mdot
.86686 .19442 Mdot
.27596 .25284 Mdot
.55942 .17519 Mdot
.88933 .20389 Mdot
.3008 .25431 Mdot
.59139 .17959 Mdot
.95114 .22234 Mdot
.34936 .24612 Mdot
.64428 .18227 Mdot
.03945 .24423 Mdot
.40338 .22492 Mdot
.69468 .18003 Mdot
.10569 .25402 Mdot
.43823 .20552 Mdot
.72258 .17574 Mdot
.13237 .25326 Mdot
.44805 .19511 Mdot
.72292 .16987 Mdot
.12326 .24743 Mdot
.43457 .1924 Mdot
.69499 .16095 Mdot
.0752 .23499 Mdot
.39747 .19917 Mdot
.64327 .15191 Mdot
.98881 .21356 Mdot
.3433 .21909 Mdot
.59173 .15353 Mdot
.90954 .19642 Mdot
.29588 .23878 Mdot
.56016 .16333 Mdot
.87143 .19237 Mdot
.27473 .24925 Mdot
.55223 .17151 Mdot
.87078 .19687 Mdot
.28171 .25397 Mdot
.56784 .17684 Mdot
.90662 .20937 Mdot
.31588 .25294 Mdot
.60858 .1809 Mdot
.98156 .23051 Mdot
.36926 .23961 Mdot
.66374 .182 Mdot
.06729 .24941 Mdot
.4186 .21712 Mdot
.70759 .17861 Mdot
.11942 .25452 Mdot
.44442 .20086 Mdot
.72587 .17394 Mdot
.13317 .25173 Mdot
.44594 .1933 Mdot
.71629 .16709 Mdot
.11112 .24402 Mdot
.42411 .19343 Mdot
.67864 .15731 Mdot
.04793 .22823 Mdot
.37944 .20489 Mdot
.62347 .15082 Mdot
.95667 .20593 Mdot
.32411 .22709 Mdot
.57777 .15677 Mdot
.8912 .19371 Mdot
.28505 .24341 Mdot
.55465 .16662 Mdot
.86712 .19311 Mdot
.27396 .25144 Mdot
.55492 .17364 Mdot
.87896 .20026 Mdot
.29075 .25451 Mdot
.57938 .17838 Mdot
.92891 .21602 Mdot
.33344 .25001 Mdot
.62775 .18189 Mdot
.01363 .23849 Mdot
.38862 .23176 Mdot
.6816 .18107 Mdot
.09033 .25261 Mdot
.43061 .21031 Mdot
.71713 .17708 Mdot
.12826 .25409 Mdot
.44753 .19732 Mdot
.72559 .17185 Mdot
.12948 .24962 Mdot
.44084 .19243 Mdot
.70595 .16385 Mdot
.09354 .23954 Mdot
.41053 .19591 Mdot
.65966 .15397 Mdot
.01615 .22032 Mdot
.35974 .21235 Mdot
.60509 .15164 Mdot
.92854 .1999 Mdot
.30725 .23406 Mdot
.56679 .16041 Mdot
.87821 .19247 Mdot
.27783 .24698 Mdot
.55206 .16949 Mdot
.86721 .19477 Mdot
.27669 .25307 Mdot
.56062 .17548 Mdot
.89189 .20474 Mdot
.30315 .25417 Mdot
.59412 .17983 Mdot
.95607 .2237 Mdot
.35272 .24514 Mdot
.64765 .18228 Mdot
.04448 .24525 Mdot
.40619 .22355 Mdot
.69711 .1798 Mdot
.1084 .25419 Mdot
.43951 .20464 Mdot
.7234 .17545 Mdot
.13283 .25304 Mdot
.44792 .19473 Mdot
.72207 .16944 Mdot
.12159 .24692 Mdot
.43303 .19248 Mdot
.69246 .16034 Mdot
.07099 .23394 Mdot
.39459 .2 Mdot
.63989 .1516 Mdot
.98324 .2122 Mdot
.33997 .22047 Mdot
.58919 .15403 Mdot
.90608 .19585 Mdot
.29383 .23964 Mdot
.55904 .16391 Mdot
.87041 .19244 Mdot
.27437 .24966 Mdot
.5525 .17189 Mdot
.87187 .19738 Mdot
.28302 .25411 Mdot
.56958 .1771 Mdot
.91006 .21042 Mdot
.31871 .25256 Mdot
.61173 .18109 Mdot
.98697 .23191 Mdot
.37262 .23835 Mdot
.66691 .18188 Mdot
.07155 .25008 Mdot
.42086 .21589 Mdot
.70945 .17835 Mdot
.12124 .2545 Mdot
.44515 .20019 Mdot
.72605 .17361 Mdot
.13284 .25141 Mdot
.44527 .19309 Mdot
.71478 .16656 Mdot
.1085 .24333 Mdot
.42199 .19375 Mdot
.67555 .15671 Mdot
.04275 .22694 Mdot
.37616 .20606 Mdot
.6202 .15082 Mdot
.95151 .20476 Mdot
.32102 .22837 Mdot
.57567 .15738 Mdot
.88859 .1934 Mdot
.28355 .24409 Mdot
.55399 .16714 Mdot
.8668 .19333 Mdot
.27416 .25176 Mdot
.55566 .17398 Mdot
.88079 .20094 Mdot
.29262 .25452 Mdot
.58166 .17864 Mdot
.93319 .21726 Mdot
.33662 .24933 Mdot
.63111 .18201 Mdot
.01903 .23975 Mdot
.39176 .23036 Mdot
.68443 .18088 Mdot
.09376 .25298 Mdot
.43235 .20926 Mdot
.71843 .17681 Mdot
.12933 .25395 Mdot
.44779 .19682 Mdot
.72523 .17147 Mdot
.12845 .2492 Mdot
.43971 .19237 Mdot
.70388 .16327 Mdot
.09007 .23868 Mdot
.40799 .19648 Mdot
.65633 .15348 Mdot
.01057 .21893 Mdot
.35636 .21371 Mdot
.60222 .15195 Mdot
.92434 .19908 Mdot
.30474 .2351 Mdot
.56527 .16102 Mdot
.87656 .19239 Mdot
.277 .24748 Mdot
.55194 .16992 Mdot
.86769 .19515 Mdot
.27752 .25329 Mdot
.56192 .17577 Mdot
.89461 .20562 Mdot
.30559 .254 Mdot
.59693 .18006 Mdot
.96111 .22508 Mdot
.35609 .24411 Mdot
.65101 .18227 Mdot
.0494 .24622 Mdot
.40891 .22219 Mdot
.69945 .17957 Mdot
.11095 .25432 Mdot
.4407 .2038 Mdot
.72411 .17516 Mdot
.13317 .25281 Mdot
.44769 .19439 Mdot
.72111 .16898 Mdot
.11977 .24638 Mdot
.4314 .1926 Mdot
.68984 .15972 Mdot
.0666 .23286 Mdot
.39163 .20088 Mdot
.63651 .15134 Mdot
.97769 .21086 Mdot
.33666 .22186 Mdot
.58672 .15454 Mdot
.90277 .19533 Mdot
.29186 .24047 Mdot
.558 .16448 Mdot
.86951 .19253 Mdot
.27411 .25006 Mdot
.55284 .17227 Mdot
.87308 .19792 Mdot
.28443 .25423 Mdot
.57142 .17737 Mdot
.91364 .21151 Mdot
.32161 .25214 Mdot
.61493 .18128 Mdot
.99241 .2333 Mdot
.37596 .23705 Mdot
.5 .21631 Mdot
.85 .21631 Mdot
.30301 .27997 Mdot
.63569 .20561 Mdot
.06424 .26486 Mdot
.44278 .23395 Mdot
.77653 .20627 Mdot
.23584 .28387 Mdot
.56833 .20549 Mdot
.95381 .23824 Mdot
.37573 .26076 Mdot
.70803 .20537 Mdot
.16326 .28134 Mdot
.50961 .21406 Mdot
.86363 .2188 Mdot
.31389 .27827 Mdot
.64694 .20584 Mdot
.08154 .2686 Mdot
.45373 .23002 Mdot
.78941 .20746 Mdot
.24854 .28376 Mdot
.58034 .20507 Mdot
.97373 .24313 Mdot
.38804 .25606 Mdot
.71998 .20515 Mdot
.17699 .28245 Mdot
.51984 .21189 Mdot
.87852 .22168 Mdot
.32522 .27608 Mdot
.65855 .20601 Mdot
.09876 .27206 Mdot
.46493 .22631 Mdot
.80328 .20911 Mdot
.26189 .28343 Mdot
.59352 .20496 Mdot
.99574 .24859 Mdot
.40137 .25069 Mdot
.73304 .20499 Mdot
.19132 .28323 Mdot
.53083 .20983 Mdot
.89485 .22498 Mdot
.337 .27327 Mdot
.67039 .20604 Mdot
.11549 .27509 Mdot
.4761 .22287 Mdot
.81767 .2111 Mdot
.27522 .28278 Mdot
.60705 .20508 Mdot
.0182 .2541 Mdot
.41482 .24513 Mdot
.74651 .20499 Mdot
.20549 .28367 Mdot
.54209 .20803 Mdot
.91198 .2286 Mdot
.34875 .26994 Mdot
.68192 .20591 Mdot
.13095 .27751 Mdot
.48664 .21983 Mdot
.83167 .21324 Mdot
.28761 .28179 Mdot
.61978 .20529 Mdot
.03897 .25908 Mdot
.4273 .24 Mdot
.75947 .20529 Mdot
.21873 .28384 Mdot
.55312 .20667 Mdot
.92923 .23245 Mdot
.3601 .2663 Mdot
.69293 .2057 Mdot
.14498 .27938 Mdot
.49643 .21721 Mdot
.84503 .21545 Mdot
.29892 .28052 Mdot
.63146 .20552 Mdot
.0576 .26337 Mdot
.43867 .23551 Mdot
.77187 .20593 Mdot
.23119 .28388 Mdot
.56408 .20574 Mdot
.94686 .23657 Mdot
.37137 .26236 Mdot
.70381 .20546 Mdot
.15825 .28086 Mdot
.50595 .21489 Mdot
.8584 .21783 Mdot
.30977 .27896 Mdot
.64268 .20575 Mdot
.07506 .26722 Mdot
.44959 .23147 Mdot
.78446 .20696 Mdot
.24368 .28382 Mdot
.57568 .20519 Mdot
.96597 .24121 Mdot
.38328 .25791 Mdot
.71535 .20523 Mdot
.17174 .28207 Mdot
.5159 .2127 Mdot
.87274 .22054 Mdot
.32089 .27697 Mdot
.65414 .20596 Mdot
.0923 .2708 Mdot
.46069 .22768 Mdot
.79796 .20844 Mdot
.25682 .28359 Mdot
.58846 .20497 Mdot
.98729 .24649 Mdot
.39627 .25277 Mdot
.72803 .20504 Mdot
.1859 .28298 Mdot
.52663 .21058 Mdot
.88857 .22369 Mdot
.33255 .27439 Mdot
.66594 .20605 Mdot
.10932 .27402 Mdot
.47195 .22412 Mdot
.81226 .21032 Mdot
.27028 .28307 Mdot
.602 .20502 Mdot
.00986 .25207 Mdot
.40983 .2472 Mdot
.74147 .20496 Mdot
.20025 .28354 Mdot
.53787 .20866 Mdot
.9055 .22721 Mdot
.34437 .27123 Mdot
.67765 .20598 Mdot
.12532 .27668 Mdot
.48278 .22092 Mdot
.82649 .21242 Mdot
.2831 .2822 Mdot
.61513 .20521 Mdot
.03143 .25729 Mdot
.42276 .24185 Mdot
.75468 .20514 Mdot
.21388 .2838 Mdot
.54901 .20713 Mdot
.92274 .23098 Mdot
.35588 .26769 Mdot
.68884 .20578 Mdot
.13984 .27873 Mdot
.49282 .21815 Mdot
.84005 .2146 Mdot
.29477 .28103 Mdot
.62716 .20543 Mdot
.05081 .26183 Mdot
.43449 .23713 Mdot
.76723 .20565 Mdot
.22656 .28388 Mdot
.55993 .20604 Mdot
.94013 .23498 Mdot
.3671 .26388 Mdot
.69969 .20555 Mdot
.15329 .28034 Mdot
.50236 .21574 Mdot
.85331 .2169 Mdot
.30569 .27959 Mdot
.63847 .20567 Mdot
.06856 .26581 Mdot
.44549 .23295 Mdot
.77965 .20652 Mdot
.23893 .28385 Mdot
.5712 .20535 Mdot
.95855 .23939 Mdot
.37868 .25966 Mdot
.71089 .20532 Mdot
.1666 .28164 Mdot
.51207 .21351 Mdot
.86719 .21947 Mdot
.31665 .27778 Mdot
.64978 .20589 Mdot
.08582 .26949 Mdot
.45648 .22908 Mdot
.79276 .20783 Mdot
.2518 .2837 Mdot
.58352 .20501 Mdot
.97903 .24444 Mdot
.39127 .25478 Mdot
.72313 .2051 Mdot
.18051 .28267 Mdot
.52251 .21137 Mdot
.88245 .22246 Mdot
.32812 .27543 Mdot
.66149 .20603 Mdot
.10299 .27287 Mdot
.46774 .22542 Mdot
.80684 .20958 Mdot
.26524 .28331 Mdot
.5969 .20498 Mdot
.00137 .24998 Mdot
.40475 .2493 Mdot
.73639 .20497 Mdot
.19489 .28337 Mdot
.53363 .20935 Mdot
.89906 .22585 Mdot
.33994 .27248 Mdot
.6733 .20602 Mdot
.11947 .27575 Mdot
.4788 .22207 Mdot
.82121 .21162 Mdot
.27841 .28257 Mdot
.61031 .20513 Mdot
.02357 .2554 Mdot
.41804 .2438 Mdot
.74979 .20504 Mdot
.20888 .28373 Mdot
.54486 .20765 Mdot
.91626 .22954 Mdot
.3516 .26906 Mdot
.6847 .20586 Mdot
.13455 .27802 Mdot
.48913 .21914 Mdot
.83503 .21378 Mdot
.29051 .2815 Mdot
.62276 .20534 Mdot
.04378 .2602 Mdot
.43021 .23883 Mdot
.76258 .20542 Mdot
.22187 .28386 Mdot
.55583 .2064 Mdot
.93354 .23344 Mdot
.36288 .26535 Mdot
.69561 .20564 Mdot
.1483 .27978 Mdot
.49879 .21661 Mdot
.84831 .21601 Mdot
.30163 .28016 Mdot
.63426 .20558 Mdot
.062 .26436 Mdot
.44139 .23447 Mdot
.77494 .20615 Mdot
.23426 .28387 Mdot
.56687 .20557 Mdot
.95143 .23767 Mdot
.37424 .26131 Mdot
.70659 .2054 Mdot
.16155 .28118 Mdot
.50836 .21434 Mdot
.86184 .21846 Mdot
.31248 .27851 Mdot
.64549 .20581 Mdot
.07934 .26814 Mdot
.45232 .23051 Mdot
.78772 .20729 Mdot
.24688 .28378 Mdot
.57874 .2051 Mdot
.97106 .24247 Mdot
.3864 .2567 Mdot
.71839 .20518 Mdot
.1752 .28232 Mdot
.51849 .21216 Mdot
.87654 .22129 Mdot
.32374 .27639 Mdot
.65705 .20599 Mdot
.09657 .27164 Mdot
.46349 .22677 Mdot
.80147 .20888 Mdot
.26016 .28349 Mdot
.59179 .20496 Mdot
.99286 .24787 Mdot
.39963 .2514 Mdot
.73133 .205 Mdot
.18948 .28315 Mdot
.5294 .21008 Mdot
.8927 .22453 Mdot
.33549 .27366 Mdot
.66888 .20605 Mdot
.11342 .27474 Mdot
.4747 .22329 Mdot
.81584 .21083 Mdot
.27356 .28289 Mdot
.60535 .20506 Mdot
.01539 .25342 Mdot
.41314 .24582 Mdot
.74481 .20498 Mdot
.20372 .28363 Mdot
.54066 .20824 Mdot
.90978 .22813 Mdot
.34727 .27038 Mdot
.68048 .20594 Mdot
.12907 .27724 Mdot
.48535 .22019 Mdot
.82992 .21296 Mdot
.2861 .28193 Mdot
.61822 .20526 Mdot
.03645 .25848 Mdot
.42578 .24062 Mdot
.75785 .20523 Mdot
.2171 .28383 Mdot
.55173 .20681 Mdot
.92703 .23194 Mdot
.35867 .26677 Mdot
.69155 .20573 Mdot
.14325 .27917 Mdot
.49521 .21752 Mdot
.84334 .21516 Mdot
.29752 .2807 Mdot
.63001 .20549 Mdot
.05532 .26286 Mdot
.43726 .23605 Mdot
.7703 .20583 Mdot
.22962 .28388 Mdot
.56267 .20583 Mdot
.94456 .23602 Mdot
.36991 .26288 Mdot
.7024 .20549 Mdot
.15657 .28069 Mdot
.50472 .21517 Mdot
.85666 .21751 Mdot
.30838 .27918 Mdot
.64125 .20572 Mdot
.07286 .26675 Mdot
.4482 .23197 Mdot
.78281 .20681 Mdot
.24206 .28383 Mdot
.57414 .20524 Mdot
.96342 .24058 Mdot
.3817 .25851 Mdot
.71382 .20526 Mdot
.16999 .28193 Mdot
.51459 .21297 Mdot
.87084 .22017 Mdot
.31944 .27725 Mdot
.65265 .20594 Mdot
.0901 .27036 Mdot
.45926 .22815 Mdot
.79618 .20823 Mdot
.25511 .28363 Mdot
.58677 .20498 Mdot
.98446 .24579 Mdot
.39456 .25346 Mdot
.72635 .20506 Mdot
.18406 .28288 Mdot
.52522 .21085 Mdot
.88647 .22327 Mdot
.33104 .27476 Mdot
.66443 .20605 Mdot
.10718 .27364 Mdot
.47053 .22456 Mdot
.81042 .21007 Mdot
.26858 .28316 Mdot
.60028 .205 Mdot
.00699 .25136 Mdot
.40812 .24791 Mdot
.73975 .20496 Mdot
.19844 .28349 Mdot
.53643 .20889 Mdot
.90331 .22675 Mdot
.34287 .27166 Mdot
.67618 .206 Mdot
.12336 .27637 Mdot
.48144 .22131 Mdot
.82471 .21215 Mdot
.28153 .28233 Mdot
.61351 .20518 Mdot
.0288 .25666 Mdot
.42118 .2425 Mdot
.75304 .2051 Mdot
.2122 .28378 Mdot
.54761 .2073 Mdot
.92054 .23049 Mdot
.35443 .26816 Mdot
.68744 .20581 Mdot
.13807 .2785 Mdot
.49158 .21848 Mdot
.83836 .21432 Mdot
.29334 .28119 Mdot
.62569 .2054 Mdot
.04845 .26128 Mdot
.43305 .2377 Mdot
.76566 .20556 Mdot
.22498 .28387 Mdot
.55854 .20615 Mdot
.93788 .23445 Mdot
.36567 .26439 Mdot
.6983 .20558 Mdot
.1516 .28015 Mdot
.50115 .21603 Mdot
.85161 .2166 Mdot
.30431 .27979 Mdot
.63704 .20564 Mdot
.06635 .26533 Mdot
.4441 .23346 Mdot
.77804 .20639 Mdot
.23734 .28386 Mdot
.56972 .20542 Mdot
.9561 .2388 Mdot
.37716 .26023 Mdot
.70942 .20535 Mdot
.16488 .28149 Mdot
.5108 .21379 Mdot
.86535 .21913 Mdot
.31523 .27804 Mdot
.64832 .20586 Mdot
.08362 .26903 Mdot
.45507 .22956 Mdot
.79103 .20764 Mdot
.25012 .28373 Mdot
.58188 .20504 Mdot
.97629 .24376 Mdot
.3896 .25544 Mdot
.72151 .20513 Mdot
0 .24721 Mdot
.4 .24721 Mdot
.72516 .20096 Mdot
.1761 .27869 Mdot
.51319 .20834 Mdot
.86083 .21485 Mdot
.30615 .27522 Mdot
.63198 .20138 Mdot
.05171 .25941 Mdot
.43079 .23429 Mdot
.75624 .20114 Mdot
.20891 .27977 Mdot
.53848 .20368 Mdot
.89854 .22253 Mdot
.33438 .26936 Mdot
.66037 .20147 Mdot
.09402 .26801 Mdot
.45675 .22418 Mdot
.78532 .20306 Mdot
.23808 .27982 Mdot
.56388 .20135 Mdot
.93942 .2321 Mdot
.36226 .26133 Mdot
.68816 .20142 Mdot
.1319 .27424 Mdot
.48179 .21624 Mdot
.81713 .20726 Mdot
.26864 .27905 Mdot
.5937 .2009 Mdot
.98947 .2446 Mdot
.39366 .2498 Mdot
.71895 .20105 Mdot
.16916 .27824 Mdot
.50812 .20949 Mdot
.85357 .2135 Mdot
.30032 .27611 Mdot
.62607 .20132 Mdot
.04244 .25733 Mdot
.42526 .2366 Mdot
.75047 .20099 Mdot
.203 .27968 Mdot
.53372 .20439 Mdot
.89121 .22094 Mdot
.32911 .27064 Mdot
.6551 .20147 Mdot
.08643 .26658 Mdot
.45197 .22592 Mdot
.77967 .20253 Mdot
.23249 .27986 Mdot
.55875 .20164 Mdot
.93095 .23003 Mdot
.35668 .26311 Mdot
.68262 .20145 Mdot
.12465 .27319 Mdot
.47685 .21767 Mdot
.81058 .20626 Mdot
.26253 .27932 Mdot
.58755 .20087 Mdot
.97913 .24201 Mdot
.38735 .2523 Mdot
.71281 .20114 Mdot
.16212 .27769 Mdot
.50303 .21069 Mdot
.84637 .21219 Mdot
.29439 .27689 Mdot
.62001 .20124 Mdot
.0328 .25512 Mdot
.41953 .23901 Mdot
.7446 .2009 Mdot
.19692 .27955 Mdot
.52893 .20519 Mdot
.88395 .21942 Mdot
.3238 .27184 Mdot
.64978 .20146 Mdot
.07866 .26506 Mdot
.44714 .22774 Mdot
.77411 .20208 Mdot
.22694 .27987 Mdot
.55379 .202 Mdot
.92285 .22809 Mdot
.35124 .26476 Mdot
.67721 .20146 Mdot
.11742 .27207 Mdot
.47199 .21913 Mdot
.80426 .20536 Mdot
.25653 .27952 Mdot
.58158 .20089 Mdot
.96907 .23948 Mdot
.38115 .25468 Mdot
.70675 .20123 Mdot
.155 .27703 Mdot
.49794 .21195 Mdot
.83923 .21093 Mdot
.28835 .27757 Mdot
.61383 .20116 Mdot
.02281 .25276 Mdot
.4136 .24152 Mdot
.73862 .20087 Mdot
.19064 .27936 Mdot
.52408 .20608 Mdot
.87672 .21794 Mdot
.31842 .27298 Mdot
.64437 .20145 Mdot
.07061 .26343 Mdot
.4422 .22966 Mdot
.76857 .2017 Mdot
.22139 .27986 Mdot
.54894 .20244 Mdot
.91503 .22625 Mdot
.34591 .2663 Mdot
.6719 .20147 Mdot
.11018 .27087 Mdot
.46719 .22065 Mdot
.79814 .20454 Mdot
.25064 .27966 Mdot
.57581 .20097 Mdot
.95937 .23705 Mdot
.37508 .25692 Mdot
.7008 .20131 Mdot
.1478 .27627 Mdot
.49285 .21325 Mdot
.83217 .20971 Mdot
.28222 .27815 Mdot
.60755 .20106 Mdot
.01251 .25028 Mdot
.40748 .2441 Mdot
.73253 .20089 Mdot
.18413 .27911 Mdot
.51916 .20706 Mdot
.86948 .21651 Mdot
.3129 .27405 Mdot
.63881 .20142 Mdot
.06222 .26168 Mdot
.43711 .23169 Mdot
.76299 .2014 Mdot
.21577 .27983 Mdot
.54415 .20295 Mdot
.90741 .22451 Mdot
.34063 .26775 Mdot
.66662 .20147 Mdot
.10286 .26961 Mdot
.46242 .22222 Mdot
.7922 .20381 Mdot
.24485 .27975 Mdot
.57024 .2011 Mdot
.95002 .23472 Mdot
.36913 .25902 Mdot
.69495 .20137 Mdot
.14055 .2754 Mdot
.48777 .21459 Mdot
.82521 .20855 Mdot
.27602 .27862 Mdot
.60121 .20098 Mdot
.00201 .24771 Mdot
.4012 .24672 Mdot
.72634 .20095 Mdot
.1774 .27877 Mdot
.51415 .20812 Mdot
.86221 .21511 Mdot
.30724 .27504 Mdot
.63309 .20139 Mdot
.05343 .25978 Mdot
.43182 .23386 Mdot
.75733 .20117 Mdot
.21002 .27978 Mdot
.53939 .20356 Mdot
.89994 .22284 Mdot
.33537 .26911 Mdot
.66137 .20147 Mdot
.09544 .26827 Mdot
.45766 .22386 Mdot
.7864 .20317 Mdot
.23915 .27982 Mdot
.56488 .20131 Mdot
.94107 .2325 Mdot
.36334 .26098 Mdot
.68923 .20141 Mdot
.13328 .27444 Mdot
.48273 .21597 Mdot
.8184 .20746 Mdot
.26982 .27899 Mdot
.59489 .20091 Mdot
.99146 .24509 Mdot
.39486 .24931 Mdot
.72013 .20103 Mdot
.17049 .27834 Mdot
.50909 .20926 Mdot
.85495 .21375 Mdot
.30144 .27595 Mdot
.6272 .20133 Mdot
.04423 .25774 Mdot
.42633 .23615 Mdot
.75157 .20101 Mdot
.20413 .2797 Mdot
.53462 .20425 Mdot
.89259 .22124 Mdot
.33011 .2704 Mdot
.6561 .20147 Mdot
.08789 .26686 Mdot
.45288 .22558 Mdot
.78074 .20262 Mdot
.23355 .27985 Mdot
.55971 .20158 Mdot
.93253 .23042 Mdot
.35772 .26278 Mdot
.68366 .20144 Mdot
.12603 .27339 Mdot
.47778 .21739 Mdot
.81181 .20644 Mdot
.26368 .27927 Mdot
.5887 .20087 Mdot
.98107 .2425 Mdot
.38855 .25183 Mdot
.71397 .20112 Mdot
.16346 .2778 Mdot
.504 .21046 Mdot
.84773 .21244 Mdot
.29553 .27675 Mdot
.62117 .20126 Mdot
.03466 .25555 Mdot
.42064 .23855 Mdot
.74572 .20091 Mdot
.19809 .27958 Mdot
.52984 .20504 Mdot
.88533 .2197 Mdot
.32482 .27162 Mdot
.6508 .20147 Mdot
.08015 .26536 Mdot
.44807 .22738 Mdot
.77516 .20216 Mdot
.228 .27987 Mdot
.55472 .20193 Mdot
.92436 .22845 Mdot
.35226 .26446 Mdot
.67823 .20146 Mdot
.1188 .27228 Mdot
.47291 .21885 Mdot
.80545 .20552 Mdot
.25766 .27948 Mdot
.5827 .20088 Mdot
.97096 .23996 Mdot
.38232 .25424 Mdot
.70789 .20121 Mdot
.15636 .27717 Mdot
.49891 .21171 Mdot
.84058 .21117 Mdot
.28951 .27745 Mdot
.61502 .20117 Mdot
.02473 .25322 Mdot
.41474 .24104 Mdot
.73976 .20087 Mdot
.19185 .2794 Mdot
.52501 .20591 Mdot
.8781 .21822 Mdot
.31945 .27277 Mdot
.64541 .20145 Mdot
.07217 .26375 Mdot
.44315 .22928 Mdot
.76962 .20177 Mdot
.22245 .27986 Mdot
.54986 .20235 Mdot
.9165 .2266 Mdot
.34692 .26601 Mdot
.6729 .20147 Mdot
.11156 .27111 Mdot
.4681 .22035 Mdot
.79929 .20469 Mdot
.25175 .27963 Mdot
.57689 .20095 Mdot
.96118 .2375 Mdot
.37622 .25651 Mdot
.70192 .20129 Mdot
.14918 .27642 Mdot
.49381 .213 Mdot
.8335 .20994 Mdot
.28339 .27805 Mdot
.60875 .20108 Mdot
.01449 .25076 Mdot
.40866 .24361 Mdot
.73369 .20088 Mdot
.18538 .27916 Mdot
.5201 .20687 Mdot
.87086 .21678 Mdot
.31396 .27385 Mdot
.63988 .20143 Mdot
.06385 .26202 Mdot
.43809 .2313 Mdot
.76405 .20145 Mdot
.21684 .27984 Mdot
.54506 .20285 Mdot
.90885 .22483 Mdot
.34163 .26748 Mdot
.66762 .20147 Mdot
.10426 .26986 Mdot
.46333 .22192 Mdot
.79332 .20394 Mdot
.24594 .27974 Mdot
.57129 .20107 Mdot
.95177 .23515 Mdot
.37025 .25864 Mdot
.69605 .20136 Mdot
.14193 .27557 Mdot
.48873 .21433 Mdot
.82652 .20877 Mdot
.2772 .27853 Mdot
.60241 .20099 Mdot
.00401 .2482 Mdot
.4024 .24622 Mdot
.72752 .20093 Mdot
.17869 .27884 Mdot
.51511 .20792 Mdot
.86359 .21538 Mdot
.30833 .27486 Mdot
.63419 .20139 Mdot
.05513 .26016 Mdot
.43284 .23344 Mdot
.75841 .20121 Mdot
.21112 .27979 Mdot
.54029 .20344 Mdot
.90135 .22315 Mdot
.33637 .26886 Mdot
.66237 .20147 Mdot
.09686 .26853 Mdot
.45857 .22354 Mdot
.78749 .20329 Mdot
.24023 .27981 Mdot
.56588 .20126 Mdot
.94274 .23291 Mdot
.36443 .26062 Mdot
.69031 .2014 Mdot
.13466 .27462 Mdot
.48369 .21571 Mdot
.81968 .20766 Mdot
.27099 .27893 Mdot
.59609 .20092 Mdot
.99346 .24559 Mdot
.39607 .24882 Mdot
.72131 .20101 Mdot
.17181 .27843 Mdot
.51005 .20904 Mdot
.85633 .21401 Mdot
.30255 .27578 Mdot
.62833 .20134 Mdot
.04601 .25814 Mdot
.42739 .23571 Mdot
.75267 .20104 Mdot
.20527 .27972 Mdot
.53553 .20411 Mdot
.89398 .22154 Mdot
.33111 .27016 Mdot
.6571 .20147 Mdot
.08934 .26713 Mdot
.45379 .22525 Mdot
.7818 .20272 Mdot
.23461 .27985 Mdot
.56068 .20152 Mdot
.93412 .2308 Mdot
.35878 .26245 Mdot
.68471 .20144 Mdot
.1274 .2736 Mdot
.47871 .21712 Mdot
.81305 .20663 Mdot
.26484 .27923 Mdot
.58987 .20088 Mdot
.98303 .24299 Mdot
.38974 .25136 Mdot
.71513 .2011 Mdot
.16481 .27791 Mdot
.50497 .21023 Mdot
.8491 .21268 Mdot
.29666 .27661 Mdot
.62233 .20127 Mdot
.0365 .25598 Mdot
.42173 .23808 Mdot
.74684 .20093 Mdot
.19925 .2796 Mdot
.53075 .20488 Mdot
.8867 .21999 Mdot
.32583 .27139 Mdot
.65181 .20147 Mdot
.08164 .26565 Mdot
.44899 .22703 Mdot
.77622 .20224 Mdot
.22905 .27987 Mdot
.55566 .20186 Mdot
.92589 .22882 Mdot
.35329 .26415 Mdot
.67926 .20146 Mdot
.12017 .2725 Mdot
.47383 .21857 Mdot
.80664 .20569 Mdot
.2588 .27945 Mdot
.58383 .20088 Mdot
.97286 .24043 Mdot
.3835 .25379 Mdot
.70904 .2012 Mdot
.15771 .27729 Mdot
.49987 .21147 Mdot
.84193 .2114 Mdot
.29066 .27733 Mdot
.6162 .20119 Mdot
.5 .24721 Mdot
.9 .24721 Mdot
.37484 .29347 Mdot
.75956 .23777 Mdot
.27137 .31632 Mdot
.657 .23833 Mdot
.14883 .30397 Mdot
.53821 .24065 Mdot
.95786 .25936 Mdot
.41083 .27995 Mdot
.79614 .23813 Mdot
.30346 .31354 Mdot
.69057 .23925 Mdot
.19622 .31251 Mdot
.58176 .23827 Mdot
.02986 .27694 Mdot
.45421 .26226 Mdot
.84244 .23994 Mdot
.33711 .30572 Mdot
.72306 .23853 Mdot
.23452 .3161 Mdot
.61925 .23778 Mdot
.0907 .29137 Mdot
.49345 .24892 Mdot
.89097 .24568 Mdot
.36905 .29547 Mdot
.7538 .23779 Mdot
.26583 .31645 Mdot
.65117 .23815 Mdot
.14006 .30215 Mdot
.53082 .2415 Mdot
.94608 .25664 Mdot
.40365 .2828 Mdot
.78877 .23802 Mdot
.29746 .31438 Mdot
.68444 .23917 Mdot
.18809 .31127 Mdot
.57393 .23846 Mdot
.01681 .27372 Mdot
.44627 .26542 Mdot
.83355 .23935 Mdot
.33101 .30745 Mdot
.71729 .23873 Mdot
.22821 .31577 Mdot
.61301 .23781 Mdot
.08079 .28911 Mdot
.48669 .25086 Mdot
.88194 .24428 Mdot
.36322 .29744 Mdot
.74805 .23784 Mdot
.2602 .31652 Mdot
.64528 .23799 Mdot
.13111 .30026 Mdot
.52351 .24252 Mdot
.93466 .2541 Mdot
.39663 .28551 Mdot
.78159 .23792 Mdot
.29137 .31506 Mdot
.6781 .23902 Mdot
.17939 .30981 Mdot
.56568 .23874 Mdot
.00304 .2703 Mdot
.43796 .2688 Mdot
.82451 .2389 Mdot
.32468 .30912 Mdot
.71128 .23894 Mdot
.22146 .31531 Mdot
.60636 .23788 Mdot
.07016 .28664 Mdot
.47962 .25307 Mdot
.87284 .24302 Mdot
.3573 .29941 Mdot
.74229 .23794 Mdot
.25445 .31654 Mdot
.63935 .23788 Mdot
.12201 .2983 Mdot
.51635 .24371 Mdot
.92374 .25178 Mdot
.38983 .28806 Mdot
.77466 .23784 Mdot
.28529 .31559 Mdot
.67172 .23882 Mdot
.17037 .30818 Mdot
.55731 .23914 Mdot
.9891 .26687 Mdot
.42961 .27225 Mdot
.81563 .23857 Mdot
.31829 .31067 Mdot
.70518 .23911 Mdot
.21437 .3147 Mdot
.59942 .23797 Mdot
.05892 .28399 Mdot
.47236 .25552 Mdot
.8638 .24192 Mdot
.35138 .30134 Mdot
.7366 .23808 Mdot
.24869 .31649 Mdot
.63347 .2378 Mdot
.11294 .29633 Mdot
.50945 .24506 Mdot
.91352 .24973 Mdot
.38342 .29041 Mdot
.76817 .23779 Mdot
.27941 .31597 Mdot
.6655 .23862 Mdot
.16139 .30648 Mdot
.54919 .23967 Mdot
.9757 .2636 Mdot
.42158 .27557 Mdot
.80724 .23835 Mdot
.31207 .312 Mdot
.69914 .23922 Mdot
.20708 .31393 Mdot
.59231 .23808 Mdot
.04731 .2812 Mdot
.46501 .25816 Mdot
.85496 .241 Mdot
.34553 .30319 Mdot
.73103 .23825 Mdot
.24295 .31639 Mdot
.62768 .23777 Mdot
.10393 .29434 Mdot
.50283 .24653 Mdot
.90399 .24793 Mdot
.37738 .29257 Mdot
.7621 .23777 Mdot
.27377 .31623 Mdot
.65954 .23842 Mdot
.15261 .30474 Mdot
.54146 .24032 Mdot
.96311 .26059 Mdot
.41401 .27867 Mdot
.79941 .23819 Mdot
.30604 .31312 Mdot
.69317 .23926 Mdot
.19959 .31298 Mdot
.58502 .23821 Mdot
.03528 .27827 Mdot
.45754 .26097 Mdot
.84624 .24023 Mdot
.33969 .30497 Mdot
.7255 .23844 Mdot
.23713 .3162 Mdot
.62184 .23777 Mdot
.09479 .2923 Mdot
.49631 .24815 Mdot
.89488 .24633 Mdot
.37156 .29461 Mdot
.75629 .23777 Mdot
.26824 .3164 Mdot
.65371 .23823 Mdot
.14389 .30295 Mdot
.53402 .24111 Mdot
.95115 .2578 Mdot
.40675 .28158 Mdot
.79195 .23807 Mdot
.30007 .31404 Mdot
.68713 .23921 Mdot
.19169 .31184 Mdot
.57739 .23837 Mdot
.02258 .27514 Mdot
.44977 .26402 Mdot
.83744 .23959 Mdot
.33369 .3067 Mdot
.71983 .23864 Mdot
.23101 .31592 Mdot
.61576 .23779 Mdot
.08518 .29012 Mdot
.48966 .24998 Mdot
.88588 .24487 Mdot
.36576 .29659 Mdot
.75055 .23781 Mdot
.26266 .3165 Mdot
.64785 .23806 Mdot
.13502 .30109 Mdot
.52668 .24206 Mdot
.93957 .25518 Mdot
.39966 .28435 Mdot
.78468 .23796 Mdot
.29402 .31479 Mdot
.68087 .23909 Mdot
.18323 .31047 Mdot
.5693 .23861 Mdot
.00908 .2718 Mdot
.4416 .26731 Mdot
.82844 .23908 Mdot
.32745 .30841 Mdot
.71392 .23885 Mdot
.22445 .31553 Mdot
.60929 .23785 Mdot
.07486 .28774 Mdot
.48272 .25207 Mdot
.87679 .24355 Mdot
.35988 .29856 Mdot
.74479 .23789 Mdot
.25696 .31654 Mdot
.64192 .23792 Mdot
.12597 .29916 Mdot
.51943 .24318 Mdot
.92841 .25276 Mdot
.39274 .28698 Mdot
.77763 .23787 Mdot
.28792 .31538 Mdot
.67448 .23891 Mdot
.1743 .30891 Mdot
.56093 .23895 Mdot
.99513 .26835 Mdot
.43322 .27076 Mdot
.81944 .2387 Mdot
.32106 .31002 Mdot
.70783 .23904 Mdot
.21748 .31498 Mdot
.60246 .23793 Mdot
.06386 .28516 Mdot
.47553 .25443 Mdot
.86771 .24238 Mdot
.35394 .30051 Mdot
.73906 .23801 Mdot
.25119 .31652 Mdot
.63601 .23783 Mdot
.11687 .29719 Mdot
.51241 .24446 Mdot
.91786 .25059 Mdot
.38615 .28942 Mdot
.77093 .23781 Mdot
.28194 .31582 Mdot
.66817 .23871 Mdot
.16527 .30722 Mdot
.55266 .23942 Mdot
.98143 .26499 Mdot
.42501 .27415 Mdot
.81081 .23843 Mdot
.31474 .31145 Mdot
.70175 .23918 Mdot
.21027 .31428 Mdot
.59541 .23803 Mdot
.05239 .28243 Mdot
.46821 .25699 Mdot
.85877 .24138 Mdot
.34806 .3024 Mdot
.73344 .23818 Mdot
.24545 .31644 Mdot
.63019 .23778 Mdot
.10784 .29521 Mdot
.50568 .24587 Mdot
.90805 .24868 Mdot
.37996 .29166 Mdot
.76469 .23777 Mdot
.2762 .31613 Mdot
.6621 .2385 Mdot
.15641 .3055 Mdot
.54477 .24002 Mdot
.96849 .26187 Mdot
.41725 .27735 Mdot
.80275 .23825 Mdot
.30864 .31266 Mdot
.69576 .23925 Mdot
.20288 .31342 Mdot
.58822 .23815 Mdot
.04057 .27957 Mdot
.46081 .25973 Mdot
.85003 .24055 Mdot
.34223 .3042 Mdot
.72791 .23836 Mdot
.23968 .31629 Mdot
.6244 .23777 Mdot
.0988 .2932 Mdot
.49915 .24743 Mdot
.89881 .247 Mdot
.37408 .29373 Mdot
.75879 .23777 Mdot
.27064 .31634 Mdot
.65623 .23831 Mdot
.14769 .30373 Mdot
.53723 .24075 Mdot
.95629 .25899 Mdot
.40988 .28033 Mdot
.79516 .23812 Mdot
.30267 .31366 Mdot
.68977 .23924 Mdot
.19519 .31236 Mdot
.58076 .23829 Mdot
.02819 .27653 Mdot
.45319 .26266 Mdot
.84129 .23985 Mdot
.33633 .30595 Mdot
.72232 .23856 Mdot
.23371 .31606 Mdot
.61845 .23778 Mdot
.08944 .29109 Mdot
.49258 .24916 Mdot
.88979 .24549 Mdot
.36829 .29573 Mdot
.75304 .23779 Mdot
.2651 .31647 Mdot
.6504 .23813 Mdot
.1389 .30191 Mdot
.52986 .24162 Mdot
.94456 .2563 Mdot
.40272 .28316 Mdot
.78782 .238 Mdot
.29666 .31448 Mdot
.68362 .23915 Mdot
.18698 .31109 Mdot
.57287 .23849 Mdot
.01504 .27327 Mdot
.44519 .26585 Mdot
.83237 .23929 Mdot
.33019 .30767 Mdot
.71651 .23876 Mdot
.22735 .31572 Mdot
.61215 .23782 Mdot
.07944 .2888 Mdot
.48577 .25113 Mdot
.88075 .24411 Mdot
.36244 .2977 Mdot
.74729 .23785 Mdot
.25945 .31653 Mdot
.6445 .23798 Mdot
.12991 .3 Mdot
.52256 .24267 Mdot
.93319 .25379 Mdot
.39572 .28585 Mdot
.78066 .23791 Mdot
.29056 .31514 Mdot
.67726 .23899 Mdot
.17822 .30961 Mdot
.56458 .23879 Mdot
.0012 .26985 Mdot
.43686 .26925 Mdot
.82332 .23885 Mdot
.32384 .30933 Mdot
.71048 .23896 Mdot
.22055 .31524 Mdot
.60546 .23789 Mdot
.06871 .2863 Mdot
.47868 .25338 Mdot
.87164 .24287 Mdot
.35652 .29967 Mdot
.74154 .23795 Mdot
.2537 .31653 Mdot
.63857 .23786 Mdot
.12081 .29804 Mdot
.51542 .24388 Mdot
.92235 .2515 Mdot
.38897 .28838 Mdot
.77378 .23783 Mdot
.28451 .31564 Mdot
.67089 .2388 Mdot
.16918 .30796 Mdot
.55622 .2392 Mdot
.9873 .26642 Mdot
.42853 .2727 Mdot
.81449 .23854 Mdot
.31746 .31085 Mdot
.70438 .23913 Mdot
.21342 .31461 Mdot
.59849 .23799 Mdot
.05742 .28363 Mdot
.4714 .25586 Mdot
.86263 .24179 Mdot
.35061 .30159 Mdot
.73586 .2381 Mdot
.24794 .31648 Mdot
.6327 .2378 Mdot
.11175 .29607 Mdot
.50857 .24524 Mdot
.91223 .24948 Mdot
.3826 .29071 Mdot
.76735 .23779 Mdot
.27866 .31601 Mdot
.66471 .23859 Mdot
.16023 .30625 Mdot
.54815 .23975 Mdot
.974 .26319 Mdot
.42056 .27599 Mdot
.80618 .23832 Mdot
.31127 .31216 Mdot
.69835 .23923 Mdot
.20611 .31381 Mdot
.59136 .2381 Mdot
.04575 .28083 Mdot
.46404 .25852 Mdot
.85381 .24089 Mdot
.34476 .30343 Mdot
.73031 .23828 Mdot
.2422 .31637 Mdot
.62692 .23777 Mdot
.10275 .29408 Mdot
.50197 .24673 Mdot
.90277 .24771 Mdot
.37661 .29285 Mdot
.76132 .23777 Mdot
.27304 .31626 Mdot
.65877 .23839 Mdot
.15147 .3045 Mdot
.54047 .24042 Mdot
.96151 .26021 Mdot
.41304 .27906 Mdot
.79841 .23817 Mdot
.30526 .31325 Mdot
0 .27812 Mdot
.45 .27812 Mdot
.86065 .2538 Mdot
.36908 .31422 Mdot
.78419 .25655 Mdot
.32369 .33343 Mdot
.74928 .26303 Mdot
.30219 .34172 Mdot
.73456 .26722 Mdot
.29365 .34554 Mdot
.73019 .26979 Mdot
.29305 .34787 Mdot
.73323 .27204 Mdot
.30003 .3503 Mdot
.74573 .27546 Mdot
.31872 .35412 Mdot
.77607 .28266 Mdot
.35903 .36029 Mdot
.84341 .29936 Mdot
.4338 .36488 Mdot
.97274 .33308 Mdot
.53338 .3465 Mdot
.12054 .36288 Mdot
.62022 .30882 Mdot
.20719 .36277 Mdot
.67142 .28691 Mdot
.24776 .3562 Mdot
.69679 .27752 Mdot
.2661 .35185 Mdot
.70873 .27356 Mdot
.27443 .34962 Mdot
.7143 .27186 Mdot
.2783 .34857 Mdot
.71699 .27112 Mdot
.28027 .34813 Mdot
.71853 .27086 Mdot
.28162 .34801 Mdot
.7199 .27087 Mdot
.28324 .34816 Mdot
.72201 .27118 Mdot
.28615 .34865 Mdot
.72623 .27199 Mdot
.29221 .3498 Mdot
.73533 .27386 Mdot
.30523 .35222 Mdot
.7554 .27822 Mdot
.33281 .35686 Mdot
.79975 .28859 Mdot
.38785 .36346 Mdot
.89347 .31249 Mdot
.47809 .36132 Mdot
.04523 .35052 Mdot
.57668 .32845 Mdot
.16712 .36491 Mdot
.64711 .29665 Mdot
.22874 .35947 Mdot
.68418 .28148 Mdot
.25621 .35353 Mdot
.70101 .2749 Mdot
.26715 .34989 Mdot
.70671 .27166 Mdot
.26891 .34746 Mdot
.70468 .26932 Mdot
.26265 .34484 Mdot
.6937 .2664 Mdot
.24419 .34022 Mdot
.66744 .26158 Mdot
.20126 .32992 Mdot
.61369 .25489 Mdot
.10952 .30644 Mdot
.52449 .25647 Mdot
.95897 .26853 Mdot
.42592 .28859 Mdot
.83571 .25327 Mdot
.35481 .32082 Mdot
.7732 .25858 Mdot
.31757 .33644 Mdot
.74592 .26473 Mdot
.30155 .3434 Mdot
.73648 .2688 Mdot
.29828 .34721 Mdot
.73856 .27211 Mdot
.30584 .3506 Mdot
.75355 .2767 Mdot
.32855 .35537 Mdot
.79142 .28607 Mdot
.37733 .36211 Mdot
.87454 .30729 Mdot
.46204 .36309 Mdot
.01945 .3445 Mdot
.56135 .33491 Mdot
.15111 .36449 Mdot
.63734 .30051 Mdot
.22032 .3603 Mdot
.67817 .28297 Mdot
.25061 .35378 Mdot
.69572 .27509 Mdot
.26082 .34925 Mdot
.69889 .27074 Mdot
.25777 .34541 Mdot
.68949 .26681 Mdot
.23943 .33988 Mdot
.66233 .26137 Mdot
.19372 .32842 Mdot
.60567 .2546 Mdot
.09608 .30309 Mdot
.5142 .25842 Mdot
.94368 .26543 Mdot
.41728 .2927 Mdot
.82764 .25362 Mdot
.35047 .32313 Mdot
.77052 .2596 Mdot
.31684 .33764 Mdot
.74689 .26579 Mdot
.30424 .34446 Mdot
.7416 .2703 Mdot
.3061 .34888 Mdot
.7511 .27503 Mdot
.32343 .35372 Mdot
.78174 .28325 Mdot
.36485 .36038 Mdot
.85238 .30131 Mdot
.44178 .36427 Mdot
.98565 .33613 Mdot
.54098 .34321 Mdot
.12873 .36325 Mdot
.62436 .30632 Mdot
.20967 .36174 Mdot
.67172 .28556 Mdot
.24599 .35492 Mdot
.69299 .27626 Mdot
.25923 .34995 Mdot
.69835 .27139 Mdot
.25816 .34598 Mdot
.6908 .26739 Mdot
.24207 .3407 Mdot
.66617 .26211 Mdot
.20033 .33013 Mdot
.61333 .25524 Mdot
.10951 .30666 Mdot
.52483 .25669 Mdot
.95995 .26892 Mdot
.42677 .28851 Mdot
.83704 .25357 Mdot
.35607 .32078 Mdot
.77502 .25893 Mdot
.31973 .33665 Mdot
.74913 .26539 Mdot
.30586 .34408 Mdot
.74303 .27018 Mdot
.3074 .3488 Mdot
.75263 .27517 Mdot
.32517 .35385 Mdot
.78433 .28378 Mdot
.36786 .36064 Mdot
.85742 .30256 Mdot
.44638 .364 Mdot
.99325 .33799 Mdot
.54552 .34132 Mdot
.13372 .36352 Mdot
.62708 .30492 Mdot
.21166 .36129 Mdot
.67258 .28487 Mdot
.24606 .35443 Mdot
.69225 .27576 Mdot
.25748 .34933 Mdot
.69553 .27073 Mdot
.25352 .34485 Mdot
.68421 .26618 Mdot
.2315 .33825 Mdot
.65233 .26009 Mdot
.17725 .32442 Mdot
.58792 .25381 Mdot
.0654 .2951 Mdot
.49202 .26367 Mdot
.91226 .25972 Mdot
.39919 .30094 Mdot
.81076 .25436 Mdot
.34048 .32739 Mdot
.76291 .26108 Mdot
.31225 .33951 Mdot
.74387 .26676 Mdot
.30273 .34539 Mdot
.74118 .27098 Mdot
.30676 .34955 Mdot
.75303 .27581 Mdot
.3266 .35449 Mdot
.78732 .28474 Mdot
.37187 .36127 Mdot
.86463 .30455 Mdot
.4531 .36369 Mdot
.00459 .34084 Mdot
.55241 .33857 Mdot
.1414 .36402 Mdot
.63157 .30295 Mdot
.21542 .36084 Mdot
.67494 .284 Mdot
.24788 .3541 Mdot
.69351 .27541 Mdot
.25853 .3492 Mdot
.6964 .27062 Mdot
.25445 .34489 Mdot
.68522 .26623 Mdot
.23292 .33849 Mdot
.65402 .26026 Mdot
.17999 .32507 Mdot
.59075 .25387 Mdot
.07025 .29635 Mdot
.49536 .26273 Mdot
.91675 .26043 Mdot
.40174 .29974 Mdot
.81303 .25419 Mdot
.34179 .32679 Mdot
.76382 .26083 Mdot
.31269 .33922 Mdot
.74399 .26656 Mdot
.30253 .34519 Mdot
.74061 .27075 Mdot
.30579 .3493 Mdot
.75139 .2754 Mdot
.32431 .35408 Mdot
.78353 .28382 Mdot
.36726 .36077 Mdot
.8567 .30249 Mdot
.4459 .36415 Mdot
.99264 .33791 Mdot
.54527 .34154 Mdot
.13364 .36363 Mdot
.62722 .30505 Mdot
.21207 .36146 Mdot
.6732 .28499 Mdot
.24712 .3547 Mdot
.69374 .27602 Mdot
.2598 .34985 Mdot
.69878 .27131 Mdot
.25855 .34596 Mdot
.69118 .26738 Mdot
.24254 .34076 Mdot
.66671 .26215 Mdot
.20117 .33031 Mdot
.61425 .2553 Mdot
.11107 .30706 Mdot
.52608 .25649 Mdot
.96186 .26933 Mdot
.42786 .288 Mdot
.8381 .25354 Mdot
.35665 .32048 Mdot
.77542 .25881 Mdot
.31989 .3365 Mdot
.74911 .26527 Mdot
.30565 .34396 Mdot
.74258 .27004 Mdot
.30669 .34864 Mdot
.75147 .27489 Mdot
.32357 .35358 Mdot
.78171 .28314 Mdot
.36465 .36028 Mdot
.8519 .30114 Mdot
.44126 .36424 Mdot
.98469 .33586 Mdot
.54034 .34342 Mdot
.12793 .36315 Mdot
.62384 .30649 Mdot
.20913 .36173 Mdot
.67127 .28562 Mdot
.24547 .35488 Mdot
.6924 .27622 Mdot
.25841 .34981 Mdot
.69726 .27123 Mdot
.25652 .34564 Mdot
.68856 .26701 Mdot
.23855 .33991 Mdot
.66155 .26143 Mdot
.19271 .32827 Mdot
.60471 .25463 Mdot
.09455 .30274 Mdot
.51313 .25869 Mdot
.9422 .26518 Mdot
.4165 .29313 Mdot
.82702 .25372 Mdot
.35025 .32337 Mdot
.77058 .25978 Mdot
.31718 .33781 Mdot
.74762 .26603 Mdot
.30538 .34471 Mdot
.74344 .27074 Mdot
.30871 .34936 Mdot
.75523 .27596 Mdot
.32901 .35461 Mdot
.79082 .28542 Mdot
.3758 .36154 Mdot
.8712 .30617 Mdot
.45875 .36313 Mdot
.01368 .34296 Mdot
.55767 .33621 Mdot
.14681 .3641 Mdot
.63445 .30138 Mdot
.21732 .36023 Mdot
.67553 .28319 Mdot
.24739 .35343 Mdot
.69194 .27475 Mdot
.25543 .34826 Mdot
.69168 .26961 Mdot
.24679 .34308 Mdot
.67461 .26441 Mdot
.21573 .33443 Mdot
.63247 .25756 Mdot
.14336 .31575 Mdot
.55446 .25407 Mdot
.00827 .28047 Mdot
.45548 .27638 Mdot
.86752 .25466 Mdot
.37372 .31285 Mdot
.78918 .25677 Mdot
.32812 .33308 Mdot
.75477 .26368 Mdot
.30869 .34234 Mdot
.74384 .26894 Mdot
.30622 .34757 Mdot
.74914 .27374 Mdot
.31938 .35243 Mdot
.7742 .28109 Mdot
.35487 .35888 Mdot
.83488 .29666 Mdot
.42453 .36442 Mdot
.95604 .32849 Mdot
.52228 .34995 Mdot
.10627 .36093 Mdot
.61143 .3122 Mdot
.19862 .3629 Mdot
.66506 .28828 Mdot
.24113 .35603 Mdot
.69007 .27746 Mdot
.25741 .35064 Mdot
.69756 .27203 Mdot
.25819 .34649 Mdot
.69166 .2679 Mdot
.244 .34137 Mdot
.66911 .26273 Mdot
.20545 .33147 Mdot
.61942 .25585 Mdot
.1202 .3095 Mdot
.53371 .25556 Mdot
.97399 .27211 Mdot
.43499 .28491 Mdot
.8454 .25365 Mdot
.36094 .31862 Mdot
.77886 .25829 Mdot
.32202 .33569 Mdot
.75066 .26492 Mdot
.30663 .34361 Mdot
.74325 .26985 Mdot
.30708 .34847 Mdot
.75168 .27478 Mdot
.32361 .35347 Mdot
.78158 .28304 Mdot
.36438 .36019 Mdot
.85135 .30096 Mdot
.44068 .36423 Mdot
.98366 .33558 Mdot
.53968 .34364 Mdot
.12712 .36306 Mdot
.62334 .30668 Mdot
.20865 .36174 Mdot
.6709 .28569 Mdot
.24508 .35486 Mdot
.692 .27621 Mdot
.25787 .34973 Mdot
.69658 .27114 Mdot
.25551 .34544 Mdot
.68719 .26679 Mdot
.2364 .33943 Mdot
.65876 .26103 Mdot
.18808 .32714 Mdot
.59959 .25433 Mdot
.08568 .30042 Mdot
.50649 .26007 Mdot
.93248 .26328 Mdot
.41089 .29567 Mdot
.82167 .25388 Mdot
.34708 .32472 Mdot
.76813 .26022 Mdot
.31568 .3384 Mdot
.74659 .26632 Mdot
.3048 .34499 Mdot
.74315 .27092 Mdot
.30871 .34954 Mdot
.75552 .27614 Mdot
.32957 .35478 Mdot
.79188 .28572 Mdot
.37713 .36171 Mdot
.87357 .30681 Mdot
.46084 .36295 Mdot
.01711 .34379 Mdot
.55971 .33535 Mdot
.14897 .36418 Mdot
.63571 .30082 Mdot
.21833 .36008 Mdot
.67614 .28294 Mdot
.2478 .35331 Mdot
.69216 .27463 Mdot
.5 .27812 Mdot
.95 .27812 Mdot
.43935 .30243 Mdot
.88133 .27316 Mdot
.4097 .32655 Mdot
.86964 .28426 Mdot
.42259 .34174 Mdot
.91603 .30496 Mdot
.47357 .34458 Mdot
.01007 .33157 Mdot
.53851 .3266 Mdot
.09747 .34546 Mdot
.58324 .30022 Mdot
.1326 .33952 Mdot
.58773 .28129 Mdot
.10955 .3225 Mdot
.55049 .27251 Mdot
.03114 .29706 Mdot
.48704 .28176 Mdot
.93258 .27536 Mdot
.43046 .30771 Mdot
.87446 .27441 Mdot
.4088 .33024 Mdot
.8741 .28757 Mdot
.42994 .34353 Mdot
.93153 .31 Mdot
.48622 .34282 Mdot
.02989 .33601 Mdot
.5498 .32132 Mdot
.10889 .34554 Mdot
.58751 .2958 Mdot
.13267 .33692 Mdot
.58356 .27867 Mdot
.09827 .31811 Mdot
.53926 .27255 Mdot
.01135 .29177 Mdot
.47437 .28616 Mdot
.91697 .27354 Mdot
.42302 .31276 Mdot
.86986 .27616 Mdot
.40959 .33357 Mdot
.88082 .29124 Mdot
.43873 .34481 Mdot
.94883 .31526 Mdot
.49917 .34012 Mdot
.04883 .33971 Mdot
.56004 .31595 Mdot
.11815 .34493 Mdot
.59019 .29173 Mdot
.13057 .33398 Mdot
.57783 .27642 Mdot
.0849 .31339 Mdot
.52722 .27337 Mdot
.99122 .28677 Mdot
.46224 .2911 Mdot
.90333 .27261 Mdot
.41709 .31752 Mdot
.86748 .27836 Mdot
.41205 .33656 Mdot
.8898 .29526 Mdot
.44882 .3455 Mdot
.96761 .32063 Mdot
.51213 .33653 Mdot
.06635 .34252 Mdot
.56901 .31066 Mdot
.12517 .34372 Mdot
.5912 .28802 Mdot
.12626 .33069 Mdot
.57058 .27461 Mdot
.06953 .30837 Mdot
.51461 .27508 Mdot
.97136 .28229 Mdot
.4509 .29637 Mdot
.89178 .27248 Mdot
.41272 .32196 Mdot
.86727 .28093 Mdot
.41613 .33921 Mdot
.90094 .29963 Mdot
.45999 .34551 Mdot
.98736 .32593 Mdot
.52483 .33218 Mdot
.08209 .3444 Mdot
.57655 .30559 Mdot
.12991 .342 Mdot
.59051 .28466 Mdot
.11968 .32704 Mdot
.56187 .27329 Mdot
.05232 .30312 Mdot
.50167 .27771 Mdot
.95235 .27854 Mdot
.44058 .30175 Mdot
.88238 .27304 Mdot
.40994 .32605 Mdot
.86923 .28386 Mdot
.42176 .34148 Mdot
.91418 .30434 Mdot
.47198 .34474 Mdot
.00749 .33096 Mdot
.537 .32726 Mdot
.09585 .34539 Mdot
.58258 .30081 Mdot
.13243 .33983 Mdot
.58815 .28165 Mdot
.11084 .32304 Mdot
.55186 .27256 Mdot
.03363 .29775 Mdot
.48869 .28125 Mdot
.93472 .27566 Mdot
.43152 .30704 Mdot
.87522 .27422 Mdot
.40882 .32978 Mdot
.8734 .28713 Mdot
.42891 .34333 Mdot
.92943 .30934 Mdot
.48457 .3431 Mdot
.02739 .33548 Mdot
.5484 .322 Mdot
.10755 .34557 Mdot
.58705 .29635 Mdot
.13278 .33728 Mdot
.58418 .27898 Mdot
.09983 .31869 Mdot
.54076 .2725 Mdot
.01393 .29244 Mdot
.47597 .28556 Mdot
.91886 .27372 Mdot
.42389 .31212 Mdot
.87032 .27591 Mdot
.40939 .33316 Mdot
.87983 .29075 Mdot
.43753 .34467 Mdot
.94652 .31457 Mdot
.4975 .34052 Mdot
.04647 .33928 Mdot
.55879 .31663 Mdot
.11708 .34504 Mdot
.58993 .29224 Mdot
.13096 .33437 Mdot
.57865 .27669 Mdot
.08673 .31401 Mdot
.52881 .27322 Mdot
.9938 .28738 Mdot
.46376 .29045 Mdot
.90497 .27268 Mdot
.41777 .31693 Mdot
.86766 .27805 Mdot
.41165 .3362 Mdot
.88852 .29473 Mdot
.44746 .34545 Mdot
.96514 .31994 Mdot
.51048 .33704 Mdot
.06419 .34222 Mdot
.56794 .31133 Mdot
.12439 .34391 Mdot
.59116 .28848 Mdot
.12694 .33113 Mdot
.57159 .27481 Mdot
.07161 .30903 Mdot
.51625 .2748 Mdot
.97387 .28283 Mdot
.4523 .29569 Mdot
.89314 .27245 Mdot
.41319 .32141 Mdot
.86718 .28058 Mdot
.41552 .33889 Mdot
.8994 .29905 Mdot
.4585 .34555 Mdot
.98479 .32526 Mdot
.52323 .33277 Mdot
.08018 .34421 Mdot
.57567 .30623 Mdot
.12943 .34225 Mdot
.59069 .28508 Mdot
.12065 .32753 Mdot
.56306 .27343 Mdot
.05462 .3038 Mdot
.50334 .27732 Mdot
.95472 .27897 Mdot
.44184 .30106 Mdot
.88346 .27294 Mdot
.4102 .32554 Mdot
.86886 .28346 Mdot
.42095 .34121 Mdot
.91237 .30372 Mdot
.47041 .34489 Mdot
.0049 .33034 Mdot
.53548 .32791 Mdot
.0942 .34531 Mdot
.58189 .30141 Mdot
.13223 .34013 Mdot
.58855 .28202 Mdot
.1121 .32357 Mdot
.55321 .27262 Mdot
.03609 .29844 Mdot
.49035 .28075 Mdot
.93689 .27598 Mdot
.43261 .30637 Mdot
.87601 .27404 Mdot
.40887 .32932 Mdot
.87274 .28669 Mdot
.42791 .34312 Mdot
.92737 .30868 Mdot
.48293 .34336 Mdot
.02487 .33494 Mdot
.54699 .32269 Mdot
.10616 .34559 Mdot
.58656 .2969 Mdot
.13285 .33762 Mdot
.58478 .27931 Mdot
.10137 .31927 Mdot
.54223 .27247 Mdot
.01649 .29311 Mdot
.47758 .28497 Mdot
.92079 .27392 Mdot
.42479 .31149 Mdot
.87082 .27567 Mdot
.40923 .33275 Mdot
.87888 .29026 Mdot
.43635 .34453 Mdot
.94424 .31389 Mdot
.49583 .3409 Mdot
.04409 .33884 Mdot
.55752 .31732 Mdot
.11598 .34515 Mdot
.58966 .29274 Mdot
.13132 .33477 Mdot
.57945 .27696 Mdot
.08852 .31463 Mdot
.53038 .27308 Mdot
.99639 .28801 Mdot
.46529 .2898 Mdot
.90664 .27277 Mdot
.41847 .31633 Mdot
.86788 .27776 Mdot
.41127 .33583 Mdot
.88728 .2942 Mdot
.44612 .34538 Mdot
.96268 .31925 Mdot
.50882 .33753 Mdot
.06201 .34189 Mdot
.56684 .312 Mdot
.12358 .34409 Mdot
.5911 .28894 Mdot
.12758 .33156 Mdot
.57258 .27503 Mdot
.07365 .30968 Mdot
.51789 .27455 Mdot
.9764 .28337 Mdot
.45372 .295 Mdot
.89454 .27244 Mdot
.41369 .32085 Mdot
.86712 .28024 Mdot
.41493 .33857 Mdot
.89788 .29848 Mdot
.45703 .34558 Mdot
.98223 .32459 Mdot
.52161 .33336 Mdot
.07823 .34401 Mdot
.57476 .30687 Mdot
.12891 .34249 Mdot
.59085 .28549 Mdot
.12158 .32801 Mdot
.56424 .27358 Mdot
.0569 .30448 Mdot
.505 .27694 Mdot
.95711 .27942 Mdot
.44312 .30037 Mdot
.88458 .27284 Mdot
.41049 .32503 Mdot
.86852 .28307 Mdot
.42017 .34094 Mdot
.91059 .3031 Mdot
.46884 .34502 Mdot
.00232 .32971 Mdot
.53394 .32856 Mdot
.09252 .34522 Mdot
.58118 .30201 Mdot
.13199 .34043 Mdot
.58891 .28239 Mdot
.11332 .3241 Mdot
.55454 .27269 Mdot
.03854 .29913 Mdot
.49201 .28026 Mdot
.93909 .27631 Mdot
.43372 .3057 Mdot
.87684 .27386 Mdot
.40894 .32886 Mdot
.87211 .28626 Mdot
.42693 .3429 Mdot
.92533 .30803 Mdot
.4813 .34361 Mdot
.02234 .33438 Mdot
.54556 .32337 Mdot
.10475 .34559 Mdot
.58605 .29746 Mdot
.13289 .33797 Mdot
.58535 .27963 Mdot
.10286 .31984 Mdot
.54369 .27245 Mdot
.01905 .29378 Mdot
.4792 .28439 Mdot
.92275 .27413 Mdot
.42571 .31084 Mdot
.87136 .27543 Mdot
.40908 .33233 Mdot
.87797 .28978 Mdot
.43519 .34438 Mdot
.94197 .31321 Mdot
.49416 .34127 Mdot
.04168 .33839 Mdot
.55624 .31801 Mdot
.11485 .34524 Mdot
.58935 .29326 Mdot
.13164 .33515 Mdot
.58022 .27724 Mdot
.09029 .31524 Mdot
.53194 .27296 Mdot
.99897 .28864 Mdot
.46683 .28915 Mdot
.90834 .27287 Mdot
.41919 .31572 Mdot
.86814 .27746 Mdot
.41091 .33545 Mdot
.88608 .29367 Mdot
.4448 .34531 Mdot
.96024 .31856 Mdot
.50716 .33801 Mdot
.0598 .34155 Mdot
.56572 .31268 Mdot
.12273 .34425 Mdot
.59101 .28941 Mdot
.12818 .33199 Mdot
.57355 .27525 Mdot
.07567 .31033 Mdot
.51952 .27431 Mdot
.97893 .28394 Mdot
.45516 .29432 Mdot
.89597 .27244 Mdot
.41421 .32029 Mdot
.8671 .2799 Mdot
.41437 .33823 Mdot
.8964 .29791 Mdot
.45558 .34559 Mdot
.97968 .32391 Mdot
.51999 .33393 Mdot
.07626 .34379 Mdot
.57382 .30751 Mdot
.12835 .34272 Mdot
.59098 .28592 Mdot
.12248 .32849 Mdot
.56539 .27373 Mdot
.05915 .30516 Mdot
.50667 .27659 Mdot
.95953 .27988 Mdot
.44442 .29968 Mdot
.88574 .27275 Mdot
.41081 .32452 Mdot
.86822 .28269 Mdot
.41941 .34065 Mdot
.90884 .30249 Mdot
.46728 .34513 Mdot
.99973 .32907 Mdot
.5324 .3292 Mdot
.0908 .34511 Mdot
.58044 .30261 Mdot
.13172 .34071 Mdot
.58925 .28277 Mdot
.11451 .32462 Mdot
.55585 .27277 Mdot
.04097 .29982 Mdot
.49367 .27978 Mdot
.94132 .27666 Mdot
.43485 .30502 Mdot
.8777 .2737 Mdot
.40905 .32839 Mdot
.87153 .28583 Mdot
.42598 .34267 Mdot
.92333 .30738 Mdot
.47967 .34384 Mdot
.01979 .33381 Mdot
.54412 .32405 Mdot
.10329 .34559 Mdot
.58551 .29803 Mdot
.1329 .3383 Mdot
.5859 .27997 Mdot
.10433 .32041 Mdot
.54514 .27244 Mdot
.02159 .29446 Mdot
.48082 .28382 Mdot
.92474 .27436 Mdot
.42665 .3102 Mdot
.87194 .2752 Mdot
.40897 .3319 Mdot
.87709 .28931 Mdot
.43405 .34422 Mdot
.93974 .31254 Mdot
.4925 .34162 Mdot
.03926 .33792 Mdot
.55493 .3187 Mdot
.11367 .34532 Mdot
.58902 .29378 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .30902 Mdot
.5 .30902 Mdot
0 .33992 Mdot
.55 .33992 Mdot
.13935 .36424 Mdot
.63092 .30381 Mdot
.21581 .36148 Mdot
.67631 .2846 Mdot
.25072 .35501 Mdot
.69781 .27632 Mdot
.26544 .35081 Mdot
.70635 .27249 Mdot
.26981 .34824 Mdot
.70695 .27016 Mdot
.26677 .34599 Mdot
.69997 .26774 Mdot
.25427 .34257 Mdot
.68128 .26391 Mdot
.22393 .33538 Mdot
.64097 .25774 Mdot
.15659 .31868 Mdot
.5662 .25315 Mdot
.02726 .28495 Mdot
.46662 .27154 Mdot
.87946 .25515 Mdot
.37978 .30921 Mdot
.79281 .25527 Mdot
.32858 .33113 Mdot
.75224 .26184 Mdot
.30321 .34052 Mdot
.7339 .26618 Mdot
.29127 .34447 Mdot
.72557 .26841 Mdot
.2857 .34618 Mdot
.7217 .26946 Mdot
.28301 .34691 Mdot
.71973 .26991 Mdot
.28147 .34718 Mdot
.71838 .27002 Mdot
.2801 .34716 Mdot
.71676 .26988 Mdot
.27799 .34686 Mdot
.71385 .26938 Mdot
.27377 .34605 Mdot
.70779 .26823 Mdot
.26467 .34417 Mdot
.69477 .26582 Mdot
.2446 .33982 Mdot
.66719 .26117 Mdot
.20025 .32945 Mdot
.61215 .25457 Mdot
.10653 .30555 Mdot
.52191 .25672 Mdot
.95477 .26752 Mdot
.42332 .28958 Mdot
.83288 .25312 Mdot
.35289 .32138 Mdot
.77126 .25857 Mdot
.31582 .33656 Mdot
.74379 .2645 Mdot
.29899 .34313 Mdot
.73285 .26814 Mdot
.29329 .34637 Mdot
.73109 .27058 Mdot
.29532 .34871 Mdot
.73735 .27319 Mdot
.3063 .35163 Mdot
.75581 .27781 Mdot
.33256 .35645 Mdot
.79874 .28811 Mdot
.38631 .36314 Mdot
.89048 .31159 Mdot
.47551 .36157 Mdot
.04103 .34951 Mdot
.57408 .32945 Mdot
.16429 .36477 Mdot
.64519 .29721 Mdot
.2268 .35945 Mdot
.68243 .2816 Mdot
.25408 .3533 Mdot
.69845 .27463 Mdot
.26352 .34923 Mdot
.70172 .27083 Mdot
.26144 .34592 Mdot
.69416 .26744 Mdot
.24645 .34133 Mdot
.67145 .26266 Mdot
.20858 .33196 Mdot
.62267 .25592 Mdot
.12546 .31074 Mdot
.53796 .25494 Mdot
.98055 .27353 Mdot
.43865 .28313 Mdot
.84889 .25354 Mdot
.36266 .31752 Mdot
.77968 .25774 Mdot
.32183 .33506 Mdot
.74939 .26425 Mdot
.30428 .34294 Mdot
.73918 .26878 Mdot
.30111 .34729 Mdot
.74223 .27262 Mdot
.31051 .35122 Mdot
.76057 .27815 Mdot
.33767 .35667 Mdot
.80628 .28962 Mdot
.39433 .36344 Mdot
.90392 .31495 Mdot
.4858 .35962 Mdot
.05632 .3526 Mdot
.58272 .32533 Mdot
.17236 .36442 Mdot
.64953 .29491 Mdot
.22948 .35843 Mdot
.68316 .28039 Mdot
.25311 .35225 Mdot
.69576 .27357 Mdot
.2584 .34773 Mdot
.6939 .26915 Mdot
.2489 .34301 Mdot
.67657 .26432 Mdot
.21826 .33478 Mdot
.63515 .25765 Mdot
.14762 .31673 Mdot
.55822 .25376 Mdot
.01435 .28191 Mdot
.45902 .27482 Mdot
.87127 .25478 Mdot
.37564 .31171 Mdot
.79033 .2563 Mdot
.32828 .33247 Mdot
.75401 .26311 Mdot
.30701 .34178 Mdot
.74077 .26808 Mdot
.30165 .34664 Mdot
.74184 .27206 Mdot
.3092 .35064 Mdot
.75793 .27733 Mdot
.33383 .35593 Mdot
.79967 .2879 Mdot
.38667 .36279 Mdot
.89049 .31138 Mdot
.47517 .36135 Mdot
.04005 .34912 Mdot
.57323 .32952 Mdot
.16296 .36447 Mdot
.64393 .29726 Mdot
.22498 .35911 Mdot
.68027 .28139 Mdot
.25087 .35265 Mdot
.69414 .27396 Mdot
.25697 .34785 Mdot
.6926 .26924 Mdot
.24737 .34286 Mdot
.67483 .26418 Mdot
.21567 .33426 Mdot
.63214 .25739 Mdot
.14258 .31547 Mdot
.55362 .25403 Mdot
.00675 .28005 Mdot
.45448 .27671 Mdot
.86628 .25451 Mdot
.37292 .31312 Mdot
.78834 .25675 Mdot
.32742 .33317 Mdot
.75394 .2636 Mdot
.30775 .34227 Mdot
.74252 .2687 Mdot
.30447 .34731 Mdot
.74648 .27318 Mdot
.31579 .35185 Mdot
.7685 .27979 Mdot
.34767 .35795 Mdot
.82275 .29361 Mdot
.41208 .36423 Mdot
.9346 .32293 Mdot
.50798 .35437 Mdot
.08774 .35831 Mdot
.60081 .3171 Mdot
.18924 .36367 Mdot
.65952 .29065 Mdot
.23709 .35696 Mdot
.68775 .27853 Mdot
.25613 .35128 Mdot
.69727 .27264 Mdot
.25882 .34705 Mdot
.69324 .26848 Mdot
.24697 .34222 Mdot
.6734 .26355 Mdot
.21268 .3333 Mdot
.62813 .25676 Mdot
.13537 .31349 Mdot
.5469 .25434 Mdot
.99541 .27719 Mdot
.44759 .27946 Mdot
.8586 .25402 Mdot
.36843 .31509 Mdot
.78458 .2572 Mdot
.32506 .33404 Mdot
.75212 .26394 Mdot
.30649 .34262 Mdot
.74147 .26883 Mdot
.3036 .34741 Mdot
.74555 .27314 Mdot
.31478 .3518 Mdot
.76708 .27954 Mdot
.34598 .35778 Mdot
.82001 .29297 Mdot
.40925 .36417 Mdot
.92975 .32169 Mdot
.50464 .35531 Mdot
.08325 .3576 Mdot
.59826 .31829 Mdot
.18697 .36384 Mdot
.65821 .29124 Mdot
.23618 .35721 Mdot
.68731 .27881 Mdot
.25601 .35148 Mdot
.69747 .27284 Mdot
.25939 .34729 Mdot
.69421 .26873 Mdot
.24861 .34264 Mdot
.67569 .26395 Mdot
.21647 .33422 Mdot
.63274 .25727 Mdot
.1433 .31555 Mdot
.5541 .25389 Mdot
.00736 .28013 Mdot
.45473 .27649 Mdot
.86636 .25441 Mdot
.37278 .31298 Mdot
.78793 .25657 Mdot
.3268 .33304 Mdot
.75288 .26333 Mdot
.30626 .34201 Mdot
.7402 .26819 Mdot
.30122 .34673 Mdot
.74145 .27208 Mdot
.30882 .35065 Mdot
.75746 .27728 Mdot
.33329 .35588 Mdot
.79883 .28772 Mdot
.38575 .36274 Mdot
.88893 .31098 Mdot
.47392 .36154 Mdot
.03814 .34871 Mdot
.57214 .33003 Mdot
.1619 .36449 Mdot
.64335 .29755 Mdot
.22458 .35922 Mdot
.68011 .28153 Mdot
.25089 .35276 Mdot
.69435 .27407 Mdot
.25742 .348 Mdot
.69331 .26939 Mdot
.24853 .34314 Mdot
.67643 .26446 Mdot
.21829 .33489 Mdot
.63535 .25776 Mdot
.1481 .3169 Mdot
.55874 .25379 Mdot
.01531 .28218 Mdot
.45966 .27462 Mdot
.87207 .25488 Mdot
.37616 .31154 Mdot
.79087 .25631 Mdot
.32873 .33242 Mdot
.75453 .26316 Mdot
.3076 .34182 Mdot
.74159 .26822 Mdot
.30274 .3468 Mdot
.74348 .27239 Mdot
.31144 .35102 Mdot
.76145 .27812 Mdot
.33845 .35661 Mdot
.80729 .28976 Mdot
.39529 .36341 Mdot
.90545 .31529 Mdot
.48687 .35934 Mdot
.0578 .35285 Mdot
.5835 .3249 Mdot
.17298 .36432 Mdot
.64975 .29466 Mdot
.22942 .35825 Mdot
.68282 .28022 Mdot
.25238 .352 Mdot
.69462 .27332 Mdot
.25656 .3473 Mdot
.69129 .26867 Mdot
.24477 .34207 Mdot
.67099 .26342 Mdot
.20918 .33261 Mdot
.6242 .2565 Mdot
.1288 .31186 Mdot
.54125 .25491 Mdot
.98632 .27507 Mdot
.44233 .28183 Mdot
.85319 .25393 Mdot
.36555 .31665 Mdot
.78268 .2578 Mdot
.32447 .33484 Mdot
.75261 .26461 Mdot
.30806 .34329 Mdot
.74457 .26978 Mdot
.30832 .34842 Mdot
.75321 .27495 Mdot
.32539 .35363 Mdot
.78427 .2836 Mdot
.36753 .36048 Mdot
.85664 .30228 Mdot
.44554 .36396 Mdot
.99173 .33756 Mdot
.54452 .34165 Mdot
.13248 .36338 Mdot
.62628 .30518 Mdot
.21082 .36127 Mdot
.67188 .28495 Mdot
.24523 .35435 Mdot
.69131 .27569 Mdot
.25616 .3491 Mdot
.69378 .27046 Mdot
.25086 .3443 Mdot
.68062 .26561 Mdot
.2258 .33694 Mdot
.64513 .25916 Mdot
.16512 .32137 Mdot
.57547 .25361 Mdot
.04396 .28954 Mdot
.47772 .26808 Mdot
.89373 .25711 Mdot
.38857 .30583 Mdot
.80138 .25513 Mdot
.33494 .32975 Mdot
.75887 .26201 Mdot
.30993 .34057 Mdot
.74259 .2674 Mdot
.30244 .346 Mdot
.74181 .27155 Mdot
.30834 .35013 Mdot
.756 .27667 Mdot
.33089 .3553 Mdot
.79455 .28656 Mdot
.38058 .36219 Mdot
.8798 .30853 Mdot
.46629 .36247 Mdot
.02601 .34593 Mdot
.56501 .33313 Mdot
.1546 .36438 Mdot
.63906 .29941 Mdot
.22114 .35975 Mdot
.67798 .28235 Mdot
.24934 .35312 Mdot
.69337 .27443 Mdot
.25675 .34819 Mdot
.69292 .26957 Mdot
.24832 .34325 Mdot
.67639 .26457 Mdot
.21842 .33499 Mdot
.63562 .25784 Mdot
.14865 .31707 Mdot
.55932 .2538 Mdot
.01634 .28246 Mdot
.46032 .27439 Mdot
.87288 .25497 Mdot
.37666 .31135 Mdot
.79135 .25629 Mdot
.3291 .33234 Mdot
.75492 .26317 Mdot
.308 .34183 Mdot
.74213 .2683 Mdot
.30342 .3469 Mdot
.74449 .2726 Mdot
.31281 .35124 Mdot
.7636 .2786 Mdot
.34124 .357 Mdot
.81192 .2909 Mdot
.40041 .3637 Mdot
.91432 .31762 Mdot
.49351 .35796 Mdot
.06752 .35475 Mdot
.58911 .32236 Mdot
.17833 .36416 Mdot
.65292 .29331 Mdot
.23187 .35781 Mdot
.68432 .27963 Mdot
.25341 .35172 Mdot
.6952 .27304 Mdot
.25685 .34712 Mdot
.69129 .2685 Mdot
.24448 .34189 Mdot
.67043 .26325 Mdot
.20812 .33231 Mdot
.62287 .25633 Mdot
.12643 .31122 Mdot
.53916 .25508 Mdot
.98289 .27424 Mdot
.44029 .28269 Mdot
.85103 .25385 Mdot
.36429 .31721 Mdot
.78167 .25796 Mdot
.32386 .33509 Mdot
.7522 .26473 Mdot
.30784 .34341 Mdot
.5 .33992 Mdot
.05 .33992 Mdot
.56065 .3156 Mdot
.11867 .34487 Mdot
.5903 .29149 Mdot
.13036 .33378 Mdot
.57741 .27629 Mdot
.08397 .31307 Mdot
.52643 .27345 Mdot
.98993 .28646 Mdot
.46149 .29144 Mdot
.90253 .27258 Mdot
.41676 .31781 Mdot
.8674 .27851 Mdot
.41227 .33675 Mdot
.89045 .29553 Mdot
.44951 .34552 Mdot
.96886 .32097 Mdot
.51296 .33627 Mdot
.06742 .34267 Mdot
.56954 .31033 Mdot
.12554 .34363 Mdot
.5912 .2878 Mdot
.1259 .33046 Mdot
.57006 .2745 Mdot
.06847 .30804 Mdot
.51378 .27522 Mdot
.97011 .28202 Mdot
.4502 .29672 Mdot
.89111 .27249 Mdot
.41249 .32223 Mdot
.86733 .28111 Mdot
.41644 .33937 Mdot
.90173 .29993 Mdot
.46074 .34548 Mdot
.98865 .32627 Mdot
.52563 .33188 Mdot
.08303 .34449 Mdot
.57698 .30528 Mdot
.13014 .34187 Mdot
.59041 .28446 Mdot
.11918 .3268 Mdot
.56127 .27323 Mdot
.05117 .30277 Mdot
.50083 .27791 Mdot
.95117 .27832 Mdot
.43996 .30209 Mdot
.88185 .2731 Mdot
.40981 .3263 Mdot
.86943 .28406 Mdot
.42217 .34161 Mdot
.9151 .30465 Mdot
.47278 .34466 Mdot
.00878 .33127 Mdot
.53776 .32693 Mdot
.09667 .34542 Mdot
.58291 .30051 Mdot
.13252 .33968 Mdot
.58795 .28147 Mdot
.1102 .32277 Mdot
.55118 .27254 Mdot
.03239 .2974 Mdot
.48787 .2815 Mdot
.93365 .27551 Mdot
.43099 .30737 Mdot
.87483 .27431 Mdot
.4088 .33001 Mdot
.87374 .28735 Mdot
.42942 .34343 Mdot
.93047 .30967 Mdot
.48539 .34296 Mdot
.02864 .33575 Mdot
.5491 .32166 Mdot
.10822 .34556 Mdot
.58728 .29608 Mdot
.13273 .3371 Mdot
.58387 .27882 Mdot
.09906 .3184 Mdot
.54001 .27253 Mdot
.01264 .2921 Mdot
.47517 .28586 Mdot
.91791 .27363 Mdot
.42345 .31244 Mdot
.87009 .27604 Mdot
.40949 .33337 Mdot
.88032 .29099 Mdot
.43813 .34474 Mdot
.94768 .31492 Mdot
.49833 .34032 Mdot
.04765 .3395 Mdot
.55942 .31629 Mdot
.11762 .34499 Mdot
.59006 .29198 Mdot
.13077 .33418 Mdot
.57824 .27655 Mdot
.08582 .3137 Mdot
.52802 .27329 Mdot
.99251 .28707 Mdot
.463 .29078 Mdot
.90415 .27264 Mdot
.41742 .31722 Mdot
.86757 .2782 Mdot
.41185 .33638 Mdot
.88916 .29499 Mdot
.44814 .34547 Mdot
.96637 .32028 Mdot
.51131 .33679 Mdot
.06528 .34237 Mdot
.56848 .311 Mdot
.12478 .34382 Mdot
.59118 .28825 Mdot
.1266 .33091 Mdot
.57109 .27471 Mdot
.07057 .3087 Mdot
.51543 .27494 Mdot
.97261 .28255 Mdot
.4516 .29603 Mdot
.89245 .27246 Mdot
.41295 .32168 Mdot
.86722 .28076 Mdot
.41582 .33905 Mdot
.90017 .29934 Mdot
.45924 .34553 Mdot
.98607 .3256 Mdot
.52403 .33248 Mdot
.08114 .34431 Mdot
.57611 .30591 Mdot
.12968 .34212 Mdot
.59061 .28487 Mdot
.12017 .32729 Mdot
.56247 .27336 Mdot
.05348 .30346 Mdot
.5025 .27751 Mdot
.95353 .27875 Mdot
.44121 .3014 Mdot
.88292 .27299 Mdot
.41007 .3258 Mdot
.86904 .28366 Mdot
.42135 .34135 Mdot
.91327 .30402 Mdot
.47119 .34481 Mdot
.0062 .33065 Mdot
.53624 .32759 Mdot
.09503 .34535 Mdot
.58223 .30111 Mdot
.13234 .33998 Mdot
.58835 .28183 Mdot
.11148 .32331 Mdot
.55254 .27259 Mdot
.03486 .29809 Mdot
.48952 .281 Mdot
.93581 .27582 Mdot
.43206 .3067 Mdot
.87561 .27413 Mdot
.40884 .32956 Mdot
.87306 .28691 Mdot
.42841 .34322 Mdot
.92839 .30901 Mdot
.48375 .34323 Mdot
.02613 .33521 Mdot
.5477 .32235 Mdot
.10686 .34558 Mdot
.58681 .29663 Mdot
.13282 .33745 Mdot
.58448 .27914 Mdot
.1006 .31898 Mdot
.5415 .27249 Mdot
.01521 .29277 Mdot
.47677 .28526 Mdot
.91982 .27382 Mdot
.42433 .31181 Mdot
.87057 .27579 Mdot
.40931 .33296 Mdot
.87935 .2905 Mdot
.43694 .3446 Mdot
.94538 .31423 Mdot
.49666 .34071 Mdot
.04528 .33906 Mdot
.55816 .31698 Mdot
.11654 .3451 Mdot
.5898 .29249 Mdot
.13114 .33457 Mdot
.57905 .27682 Mdot
.08763 .31432 Mdot
.52959 .27315 Mdot
.9951 .2877 Mdot
.46452 .29012 Mdot
.9058 .27272 Mdot
.41811 .31663 Mdot
.86777 .2779 Mdot
.41145 .33602 Mdot
.8879 .29446 Mdot
.44679 .34541 Mdot
.96391 .31959 Mdot
.50965 .33729 Mdot
.06311 .34206 Mdot
.56739 .31167 Mdot
.12399 .344 Mdot
.59113 .28871 Mdot
.12726 .33135 Mdot
.57209 .27492 Mdot
.07263 .30935 Mdot
.51707 .27468 Mdot
.97513 .2831 Mdot
.45301 .29534 Mdot
.89384 .27245 Mdot
.41344 .32113 Mdot
.86715 .28041 Mdot
.41522 .33873 Mdot
.89863 .29877 Mdot
.45777 .34556 Mdot
.98351 .32493 Mdot
.52242 .33307 Mdot
.07921 .34411 Mdot
.57521 .30655 Mdot
.12918 .34237 Mdot
.59077 .28528 Mdot
.12112 .32777 Mdot
.56365 .2735 Mdot
.05576 .30414 Mdot
.50417 .27713 Mdot
.95591 .27919 Mdot
.44248 .30071 Mdot
.88402 .27289 Mdot
.41034 .32529 Mdot
.86868 .28327 Mdot
.42055 .34108 Mdot
.91148 .30341 Mdot
.46962 .34495 Mdot
.00361 .33002 Mdot
.53471 .32824 Mdot
.09336 .34527 Mdot
.58153 .30171 Mdot
.13212 .34028 Mdot
.58873 .2822 Mdot
.11272 .32384 Mdot
.55388 .27265 Mdot
.03732 .29878 Mdot
.49118 .2805 Mdot
.93799 .27614 Mdot
.43316 .30603 Mdot
.87642 .27395 Mdot
.4089 .32909 Mdot
.87242 .28647 Mdot
.42742 .34301 Mdot
.92635 .30835 Mdot
.48211 .34348 Mdot
.0236 .33466 Mdot
.54628 .32303 Mdot
.10546 .34559 Mdot
.58631 .29718 Mdot
.13288 .3378 Mdot
.58507 .27947 Mdot
.10212 .31955 Mdot
.54297 .27246 Mdot
.01777 .29344 Mdot
.47839 .28468 Mdot
.92177 .27402 Mdot
.42524 .31117 Mdot
.87109 .27555 Mdot
.40915 .33254 Mdot
.87842 .29002 Mdot
.43576 .34446 Mdot
.9431 .31355 Mdot
.495 .34109 Mdot
.04289 .33862 Mdot
.55688 .31767 Mdot
.11542 .3452 Mdot
.58951 .293 Mdot
.13148 .33496 Mdot
.57983 .2771 Mdot
.08941 .31493 Mdot
.53116 .27302 Mdot
.99768 .28833 Mdot
.46606 .28947 Mdot
.90748 .27282 Mdot
.41882 .31603 Mdot
.86801 .27761 Mdot
.41109 .33564 Mdot
.88668 .29393 Mdot
.44546 .34535 Mdot
.96146 .3189 Mdot
.50799 .33778 Mdot
.06091 .34172 Mdot
.56628 .31234 Mdot
.12316 .34417 Mdot
.59106 .28917 Mdot
.12789 .33178 Mdot
.57307 .27514 Mdot
.07467 .31001 Mdot
.5187 .27443 Mdot
.97766 .28365 Mdot
.45444 .29466 Mdot
.89525 .27244 Mdot
.41395 .32057 Mdot
.86711 .28007 Mdot
.41465 .3384 Mdot
.89714 .29819 Mdot
.45631 .34558 Mdot
.98095 .32425 Mdot
.5208 .33365 Mdot
.07725 .3439 Mdot
.57429 .30719 Mdot
.12864 .3426 Mdot
.59092 .2857 Mdot
.12203 .32825 Mdot
.56481 .27365 Mdot
.05803 .30482 Mdot
.50584 .27676 Mdot
.95832 .27965 Mdot
.44376 .30002 Mdot
.88515 .27279 Mdot
.41065 .32478 Mdot
.86836 .28288 Mdot
.41978 .3408 Mdot
.90971 .30279 Mdot
.46806 .34508 Mdot
.00103 .32939 Mdot
.53317 .32888 Mdot
.09166 .34517 Mdot
.58081 .30231 Mdot
.13186 .34057 Mdot
.58909 .28258 Mdot
.11392 .32436 Mdot
.5552 .27273 Mdot
.03976 .29947 Mdot
.49284 .28002 Mdot
.9402 .27648 Mdot
.43428 .30536 Mdot
.87727 .27378 Mdot
.40899 .32862 Mdot
.87182 .28604 Mdot
.42645 .34279 Mdot
.92433 .3077 Mdot
.48048 .34372 Mdot
.02107 .3341 Mdot
.54484 .32371 Mdot
.10403 .34559 Mdot
.58579 .29774 Mdot
.1329 .33814 Mdot
.58563 .2798 Mdot
.1036 .32012 Mdot
.54442 .27244 Mdot
.02032 .29412 Mdot
.48001 .2841 Mdot
.92374 .27424 Mdot
.42618 .31052 Mdot
.87165 .27532 Mdot
.40902 .33212 Mdot
.87752 .28955 Mdot
.43461 .3443 Mdot
.94085 .31287 Mdot
.49333 .34145 Mdot
.04047 .33815 Mdot
.55558 .31836 Mdot
.11426 .34528 Mdot
.58919 .29352 Mdot
.13178 .33534 Mdot
.58059 .27738 Mdot
.09116 .31555 Mdot
.53272 .2729 Mdot
.00027 .28896 Mdot
.4676 .28883 Mdot
.9092 .27292 Mdot
.41956 .31542 Mdot
.86828 .27732 Mdot
.41075 .33526 Mdot
.88549 .29341 Mdot
.44415 .34527 Mdot
.95903 .31821 Mdot
.50633 .33825 Mdot
.05868 .34138 Mdot
.56515 .31301 Mdot
.1223 .34433 Mdot
.59095 .28965 Mdot
.12847 .33221 Mdot
.57402 .27536 Mdot
.07667 .31065 Mdot
.52033 .2742 Mdot
.98021 .28422 Mdot
.45588 .29398 Mdot
.89671 .27245 Mdot
.41449 .32001 Mdot
.8671 .27973 Mdot
.4141 .33807 Mdot
.89567 .29763 Mdot
.45486 .34559 Mdot
.97841 .32357 Mdot
.51918 .33422 Mdot
.07526 .34367 Mdot
.57335 .30784 Mdot
.12806 .34283 Mdot
.59103 .28613 Mdot
.12291 .32872 Mdot
.56595 .27381 Mdot
.06026 .3055 Mdot
.5075 .27641 Mdot
.96074 .28012 Mdot
.44507 .29933 Mdot
.88633 .27271 Mdot
.41098 .32426 Mdot
0 .37082 Mdot
.6 .37082 Mdot
.27484 .41707 Mdot
.8239 .33934 Mdot
.48681 .4097 Mdot
.13917 .40318 Mdot
.69385 .34281 Mdot
.36802 .41666 Mdot
.94829 .35863 Mdot
.56921 .38375 Mdot
.24376 .4169 Mdot
.79109 .33827 Mdot
.46152 .41435 Mdot
.10146 .39551 Mdot
.66562 .34867 Mdot
.33963 .41656 Mdot
.90598 .35002 Mdot
.54325 .39385 Mdot
.21468 .41497 Mdot
.76192 .33821 Mdot
.43612 .41668 Mdot
.06058 .38594 Mdot
.63774 .3567 Mdot
.31184 .41662 Mdot
.8681 .34379 Mdot
.51821 .40179 Mdot
.18287 .41078 Mdot
.73136 .33898 Mdot
.4063 .41714 Mdot
.01053 .37344 Mdot
.60634 .36823 Mdot
.28105 .41699 Mdot
.83084 .33979 Mdot
.49188 .40855 Mdot
.14643 .40453 Mdot
.69968 .34193 Mdot
.37393 .41671 Mdot
.95756 .3607 Mdot
.57474 .38144 Mdot
.24953 .41705 Mdot
.797 .33836 Mdot
.46628 .41364 Mdot
.10879 .39709 Mdot
.67089 .34739 Mdot
.3449 .41656 Mdot
.91357 .35145 Mdot
.54803 .39212 Mdot
.22033 .41551 Mdot
.76751 .33818 Mdot
.44125 .41639 Mdot
.06905 .388 Mdot
.64332 .35492 Mdot
.31738 .41659 Mdot
.87535 .34485 Mdot
.52315 .40037 Mdot
.18942 .41177 Mdot
.73747 .33872 Mdot
.41245 .41716 Mdot
.02087 .37603 Mdot
.61265 .36573 Mdot
.28719 .41689 Mdot
.83788 .34034 Mdot
.49697 .40734 Mdot
.15363 .40584 Mdot
.70561 .34114 Mdot
.37999 .41679 Mdot
.9672 .36292 Mdot
.58047 .37902 Mdot
.2554 .41713 Mdot
.80308 .33849 Mdot
.47107 .41284 Mdot
.11605 .39862 Mdot
.6762 .34619 Mdot
.35022 .41657 Mdot
.92134 .35297 Mdot
.55286 .3903 Mdot
.22589 .41596 Mdot
.77306 .33817 Mdot
.44621 .41603 Mdot
.07715 .38994 Mdot
.64876 .35327 Mdot
.32279 .41657 Mdot
.88258 .34597 Mdot
.52801 .3989 Mdot
.19574 .41268 Mdot
.74347 .33852 Mdot
.41842 .41714 Mdot
.03093 .37855 Mdot
.61885 .36335 Mdot
.29325 .4168 Mdot
.845 .341 Mdot
.50206 .40608 Mdot
.16077 .4071 Mdot
.71165 .34046 Mdot
.38617 .41688 Mdot
.97719 .36527 Mdot
.5864 .37651 Mdot
.26138 .41716 Mdot
.80936 .33867 Mdot
.47592 .41195 Mdot
.12328 .40009 Mdot
.68158 .34505 Mdot
.35563 .41658 Mdot
.92939 .3546 Mdot
.5578 .38838 Mdot
.23143 .41633 Mdot
.77861 .33817 Mdot
.45106 .4156 Mdot
.08497 .39178 Mdot
.65409 .35173 Mdot
.3281 .41656 Mdot
.88982 .34716 Mdot
.53281 .39739 Mdot
.20186 .41349 Mdot
.74936 .33838 Mdot
.42419 .41707 Mdot
.04063 .38098 Mdot
.62492 .36111 Mdot
.2992 .41673 Mdot
.8522 .34177 Mdot
.50715 .40479 Mdot
.16783 .40832 Mdot
.71778 .33989 Mdot
.39245 .41697 Mdot
.98749 .36775 Mdot
.59252 .37393 Mdot
.26747 .41714 Mdot
.81587 .33893 Mdot
.48084 .41097 Mdot
.13052 .40152 Mdot
.6871 .34399 Mdot
.36119 .41661 Mdot
.93778 .35635 Mdot
.56289 .38634 Mdot
.23701 .41663 Mdot
.78423 .3382 Mdot
.45585 .41508 Mdot
.09259 .39353 Mdot
.65937 .35029 Mdot
.33338 .41656 Mdot
.89714 .34842 Mdot
.53758 .39581 Mdot
.2078 .41422 Mdot
.75515 .33828 Mdot
.42976 .41693 Mdot
.04998 .38332 Mdot
.63087 .35901 Mdot
.30505 .41667 Mdot
.85945 .34264 Mdot
.51223 .40344 Mdot
.17479 .40948 Mdot
.72398 .33942 Mdot
.39879 .41706 Mdot
.99799 .37032 Mdot
.5988 .37132 Mdot
.27366 .41709 Mdot
.8226 .33926 Mdot
.48585 .40991 Mdot
.13779 .40292 Mdot
.69276 .34299 Mdot
.36691 .41665 Mdot
.94657 .35825 Mdot
.56818 .38417 Mdot
.24267 .41686 Mdot
.78998 .33825 Mdot
.46061 .41447 Mdot
.10006 .3952 Mdot
.66463 .34892 Mdot
.33863 .41656 Mdot
.90456 .34976 Mdot
.54234 .39417 Mdot
.2136 .41486 Mdot
.76085 .33822 Mdot
.43512 .41673 Mdot
.05893 .38553 Mdot
.63666 .35706 Mdot
.31077 .41662 Mdot
.86672 .3436 Mdot
.51727 .40206 Mdot
.1816 .41058 Mdot
.73018 .33905 Mdot
.40511 .41713 Mdot
.00854 .37294 Mdot
.60514 .36872 Mdot
.27987 .41701 Mdot
.82951 .3397 Mdot
.49091 .40877 Mdot
.14505 .40428 Mdot
.69856 .34209 Mdot
.3728 .4167 Mdot
.95577 .3603 Mdot
.57367 .38188 Mdot
.24843 .41702 Mdot
.79587 .33834 Mdot
.46538 .41378 Mdot
.10741 .3968 Mdot
.66989 .34763 Mdot
.3439 .41656 Mdot
.91211 .35117 Mdot
.54712 .39245 Mdot
.21926 .41541 Mdot
.76645 .33818 Mdot
.44029 .41645 Mdot
.06747 .38762 Mdot
.64228 .35525 Mdot
.31634 .41659 Mdot
.87397 .34464 Mdot
.52222 .40064 Mdot
.18819 .41159 Mdot
.73632 .33876 Mdot
.4113 .41716 Mdot
.01893 .37554 Mdot
.61145 .3662 Mdot
.28603 .41691 Mdot
.83654 .34023 Mdot
.496 .40757 Mdot
.15227 .4056 Mdot
.70447 .34128 Mdot
.37883 .41677 Mdot
.96534 .36249 Mdot
.57936 .37949 Mdot
.25428 .41712 Mdot
.80191 .33846 Mdot
.47016 .413 Mdot
.11467 .39833 Mdot
.67518 .34641 Mdot
.3492 .41657 Mdot
.91985 .35268 Mdot
.55193 .39065 Mdot
.22484 .41588 Mdot
.772 .33817 Mdot
.44528 .41611 Mdot
.07564 .38958 Mdot
.64774 .35358 Mdot
.32177 .41657 Mdot
.8812 .34575 Mdot
.52709 .39918 Mdot
.19455 .41251 Mdot
.74234 .33855 Mdot
.4173 .41715 Mdot
.02904 .37808 Mdot
.61768 .3638 Mdot
.29211 .41682 Mdot
.84364 .34087 Mdot
.50109 .40633 Mdot
.15942 .40687 Mdot
.71049 .34058 Mdot
.38498 .41686 Mdot
.97527 .36481 Mdot
.58526 .37699 Mdot
.26024 .41716 Mdot
.80815 .33863 Mdot
.47499 .41213 Mdot
.1219 .39981 Mdot
.68055 .34526 Mdot
.35459 .41658 Mdot
.92783 .35428 Mdot
.55685 .38875 Mdot
.23038 .41626 Mdot
.77755 .33817 Mdot
.45014 .41569 Mdot
.0835 .39144 Mdot
.65308 .35202 Mdot
.3271 .41657 Mdot
.88844 .34693 Mdot
.5319 .39768 Mdot
.20071 .41335 Mdot
.74825 .3384 Mdot
.42311 .41709 Mdot
.03882 .38053 Mdot
.62378 .36153 Mdot
.29808 .41674 Mdot
.85082 .34161 Mdot
.50619 .40504 Mdot
.1665 .40809 Mdot
.71661 .33999 Mdot
.39125 .41695 Mdot
.98551 .36727 Mdot
.59134 .37443 Mdot
.26631 .41715 Mdot
.81462 .33887 Mdot
.4799 .41117 Mdot
.12914 .40125 Mdot
.68604 .34418 Mdot
.36012 .4166 Mdot
.93615 .35601 Mdot
.56191 .38674 Mdot
.23595 .41658 Mdot
.78316 .3382 Mdot
.45494 .41518 Mdot
.09115 .3932 Mdot
.65837 .35056 Mdot
.33238 .41656 Mdot
.89574 .34818 Mdot
.53667 .39612 Mdot
.20668 .41409 Mdot
.75406 .3383 Mdot
.42871 .41696 Mdot
.04823 .38288 Mdot
.62975 .3594 Mdot
.30395 .41668 Mdot
.85807 .34246 Mdot
.51127 .4037 Mdot
.17348 .40927 Mdot
.7228 .3395 Mdot
.39759 .41704 Mdot
.99599 .36983 Mdot
.5976 .37181 Mdot
.27248 .4171 Mdot
.82131 .33919 Mdot
.48489 .41012 Mdot
.13641 .40266 Mdot
.69167 .34317 Mdot
.36581 .41664 Mdot
.94487 .35788 Mdot
.56716 .38459 Mdot
.24159 .41682 Mdot
.78888 .33824 Mdot
.45971 .4146 Mdot
.09865 .39489 Mdot
.66363 .34918 Mdot
.33763 .41656 Mdot
.90314 .3495 Mdot
.54143 .39449 Mdot
.21251 .41475 Mdot
.75977 .33823 Mdot
.43412 .41677 Mdot
.05726 .38512 Mdot
.63557 .35742 Mdot
.30969 .41663 Mdot
.86534 .34341 Mdot
.51631 .40232 Mdot
.18032 .41038 Mdot
.72901 .33911 Mdot
.40391 .41712 Mdot
.00654 .37244 Mdot
.60393 .36921 Mdot
.27869 .41702 Mdot
.82819 .33961 Mdot
.48995 .40899 Mdot
.14367 .40402 Mdot
.69745 .34225 Mdot
.37167 .41669 Mdot
.95399 .3599 Mdot
.57261 .38233 Mdot
.24733 .417 Mdot
.79473 .33832 Mdot
.46447 .41392 Mdot
.10602 .3965 Mdot
.66889 .34787 Mdot
.3429 .41656 Mdot
.91066 .3509 Mdot
.54621 .39279 Mdot
.2182 .41531 Mdot
.76539 .33819 Mdot
.43932 .41651 Mdot
.06588 .38723 Mdot
.64122 .35558 Mdot
.31529 .4166 Mdot
.8726 .34444 Mdot
.52129 .40091 Mdot
.18695 .41141 Mdot
.73516 .33881 Mdot
.41013 .41716 Mdot
.01697 .37505 Mdot
.61026 .36667 Mdot
.28487 .41693 Mdot
.83519 .34012 Mdot
.49503 .4078 Mdot
.1509 .40535 Mdot
.70334 .34143 Mdot
.37767 .41676 Mdot
.9635 .36206 Mdot
.57827 .37995 Mdot
.25316 .41711 Mdot
.80075 .33843 Mdot
.46925 .41315 Mdot
.1133 .39804 Mdot
.67417 .34664 Mdot
.34819 .41657 Mdot
.91836 .35238 Mdot
.55101 .391 Mdot
.22378 .41579 Mdot
.77095 .33817 Mdot
.44434 .41618 Mdot
.07411 .38922 Mdot
.64671 .35389 Mdot
.32074 .41658 Mdot
.87983 .34553 Mdot
.52617 .39946 Mdot
.19336 .41234 Mdot
.7412 .33858 Mdot
.41617 .41716 Mdot
.02714 .3776 Mdot
.6165 .36424 Mdot
.29096 .41684 Mdot
.84229 .34074 Mdot
.50013 .40657 Mdot
.15807 .40663 Mdot
.70934 .34071 Mdot
.3838 .41684 Mdot
.5 .37082 Mdot
.1 .37082 Mdot
.62516 .32457 Mdot
.24044 .38027 Mdot
.72863 .30172 Mdot
.343 .3797 Mdot
.85117 .31407 Mdot
.46179 .37739 Mdot
.04214 .35868 Mdot
.58917 .33808 Mdot
.20386 .3799 Mdot
.69654 .30449 Mdot
.30943 .37879 Mdot
.80378 .30552 Mdot
.41824 .37976 Mdot
.97014 .34109 Mdot
.54579 .35577 Mdot
.15756 .3781 Mdot
.66289 .31231 Mdot
.27694 .3795 Mdot
.76548 .30194 Mdot
.38075 .38026 Mdot
.9093 .32666 Mdot
.50655 .36912 Mdot
.10903 .37235 Mdot
.63095 .32257 Mdot
.2462 .38025 Mdot
.73417 .30158 Mdot
.34883 .37988 Mdot
.85994 .31588 Mdot
.46918 .37653 Mdot
.05392 .36139 Mdot
.59635 .33524 Mdot
.21123 .38002 Mdot
.70254 .30365 Mdot
.31556 .37887 Mdot
.81191 .30676 Mdot
.42607 .37957 Mdot
.98319 .34432 Mdot
.55373 .35262 Mdot
.16645 .37868 Mdot
.66899 .31059 Mdot
.28271 .3793 Mdot
.77179 .30227 Mdot
.38699 .38022 Mdot
.91921 .32893 Mdot
.51331 .36718 Mdot
.11806 .37375 Mdot
.63678 .32059 Mdot
.25195 .38019 Mdot
.7398 .30151 Mdot
.35472 .38004 Mdot
.86889 .31778 Mdot
.47649 .37551 Mdot
.06534 .36393 Mdot
.60337 .33252 Mdot
.21841 .38012 Mdot
.70863 .30297 Mdot
.3219 .37902 Mdot
.82061 .30822 Mdot
.43432 .37929 Mdot
.99696 .34773 Mdot
.56204 .34924 Mdot
.17549 .37914 Mdot
.67532 .30891 Mdot
.28872 .3791 Mdot
.77854 .30272 Mdot
.39364 .38015 Mdot
.92984 .33139 Mdot
.52038 .36497 Mdot
.12716 .37501 Mdot
.6427 .31862 Mdot
.25771 .3801 Mdot
.74555 .3015 Mdot
.36065 .38016 Mdot
.87799 .31973 Mdot
.48365 .37432 Mdot
.07626 .36625 Mdot
.61017 .32997 Mdot
.22534 .3802 Mdot
.71471 .30245 Mdot
.32828 .37921 Mdot
.82963 .30985 Mdot
.44269 .37889 Mdot
.0109 .35117 Mdot
.57039 .34579 Mdot
.18437 .37946 Mdot
.68171 .30737 Mdot
.29482 .37893 Mdot
.78563 .30334 Mdot
.40058 .38006 Mdot
.94108 .33404 Mdot
.52764 .36252 Mdot
.1362 .37611 Mdot
.64862 .31669 Mdot
.2634 .37995 Mdot
.75131 .30154 Mdot
.36653 .38023 Mdot
.88706 .32171 Mdot
.49055 .37298 Mdot
.08648 .36831 Mdot
.61658 .32762 Mdot
.23183 .38024 Mdot
.72059 .30207 Mdot
.3345 .37942 Mdot
.83861 .31156 Mdot
.45081 .37836 Mdot
.0243 .35443 Mdot
.57842 .34247 Mdot
.19276 .37969 Mdot
.68793 .30603 Mdot
.30086 .37881 Mdot
.79292 .30411 Mdot
.40769 .37995 Mdot
.95269 .33683 Mdot
.53499 .35988 Mdot
.14504 .37703 Mdot
.65447 .31484 Mdot
.26897 .37978 Mdot
.75705 .30165 Mdot
.37232 .38026 Mdot
.89607 .32369 Mdot
.49717 .3715 Mdot
.09601 .37011 Mdot
.62262 .32546 Mdot
.2379 .38027 Mdot
.72623 .3018 Mdot
.34046 .37962 Mdot
.84739 .3133 Mdot
.45854 .37771 Mdot
.03689 .35744 Mdot
.58599 .33937 Mdot
.20059 .37984 Mdot
.69396 .30491 Mdot
.30683 .37878 Mdot
.80041 .30505 Mdot
.41498 .37983 Mdot
.96472 .33976 Mdot
.54246 .35706 Mdot
.15376 .3778 Mdot
.66031 .31307 Mdot
.2745 .37959 Mdot
.76287 .30183 Mdot
.37816 .38026 Mdot
.90521 .32574 Mdot
.50369 .36988 Mdot
.10512 .3717 Mdot
.62844 .32343 Mdot
.24371 .38026 Mdot
.73176 .30163 Mdot
.34629 .3798 Mdot
.85611 .31508 Mdot
.46598 .37692 Mdot
.04885 .36023 Mdot
.59325 .33646 Mdot
.20805 .37997 Mdot
.69993 .304 Mdot
.31287 .37882 Mdot
.80831 .30619 Mdot
.42261 .37966 Mdot
.97742 .34289 Mdot
.55023 .35402 Mdot
.16256 .37844 Mdot
.66631 .31133 Mdot
.28017 .37939 Mdot
.76899 .30211 Mdot
.38424 .38024 Mdot
.91482 .32792 Mdot
.51034 .36805 Mdot
.11412 .37316 Mdot
.63424 .32145 Mdot
.24945 .38022 Mdot
.73734 .30153 Mdot
.35215 .37997 Mdot
.86498 .31694 Mdot
.47332 .37598 Mdot
.06043 .36285 Mdot
.60034 .33369 Mdot
.21532 .38008 Mdot
.70598 .30325 Mdot
.31913 .37895 Mdot
.81677 .30756 Mdot
.4307 .37943 Mdot
.99092 .34624 Mdot
.5584 .35072 Mdot
.17156 .37895 Mdot
.67255 .30963 Mdot
.28608 .37918 Mdot
.77555 .30251 Mdot
.39071 .38019 Mdot
.92514 .3303 Mdot
.51728 .36596 Mdot
.12321 .37449 Mdot
.64012 .31947 Mdot
.25521 .38015 Mdot
.74304 .3015 Mdot
.35808 .38011 Mdot
.87403 .31888 Mdot
.48057 .37486 Mdot
.07159 .36527 Mdot
.60726 .33106 Mdot
.22237 .38016 Mdot
.71208 .30266 Mdot
.32552 .37912 Mdot
.8257 .30913 Mdot
.43907 .37908 Mdot
.00487 .34969 Mdot
.56678 .34728 Mdot
.18056 .37934 Mdot
.67894 .30802 Mdot
.29217 .379 Mdot
.78252 .30305 Mdot
.39754 .3801 Mdot
.93614 .33287 Mdot
.52447 .36361 Mdot
.13229 .37566 Mdot
.64606 .31752 Mdot
.26094 .38002 Mdot
.74881 .30152 Mdot
.36399 .3802 Mdot
.88313 .32085 Mdot
.48759 .37358 Mdot
.08214 .36745 Mdot
.61385 .32862 Mdot
.22907 .38023 Mdot
.71806 .30222 Mdot
.33183 .37933 Mdot
.83473 .31081 Mdot
.44734 .37861 Mdot
.01857 .35304 Mdot
.57499 .34388 Mdot
.18919 .3796 Mdot
.68526 .30658 Mdot
.29825 .37885 Mdot
.78973 .30375 Mdot
.40459 .38 Mdot
.94761 .3356 Mdot
.53179 .36104 Mdot
.14123 .37665 Mdot
.65194 .31564 Mdot
.26656 .37986 Mdot
.75455 .30159 Mdot
.36981 .38025 Mdot
.89216 .32283 Mdot
.49432 .37216 Mdot
.09195 .36935 Mdot
.62004 .32638 Mdot
.23531 .38026 Mdot
.7238 .3019 Mdot
.3379 .37953 Mdot
.84359 .31254 Mdot
.45523 .37801 Mdot
.03151 .35616 Mdot
.58275 .34068 Mdot
.19725 .37978 Mdot
.69136 .30537 Mdot
.30424 .37878 Mdot
.79712 .30462 Mdot
.41178 .37988 Mdot
.95943 .33847 Mdot
.53919 .35831 Mdot
.14997 .37749 Mdot
.65777 .31383 Mdot
.27209 .37967 Mdot
.76032 .30174 Mdot
.3756 .38027 Mdot
.9012 .32484 Mdot
.50085 .37061 Mdot
.10119 .37103 Mdot
.62592 .3243 Mdot
.24121 .38027 Mdot
.72936 .30169 Mdot
.34377 .37972 Mdot
.85231 .3143 Mdot
.46277 .37728 Mdot
.04371 .35904 Mdot
.59012 .3377 Mdot
.20484 .37992 Mdot
.69733 .30437 Mdot
.31023 .37879 Mdot
.80481 .30567 Mdot
.41924 .37974 Mdot
.97181 .3415 Mdot
.54681 .35537 Mdot
.15871 .37818 Mdot
.66367 .31208 Mdot
.27768 .37948 Mdot
.76629 .30197 Mdot
.38155 .38025 Mdot
.91056 .32695 Mdot
.50742 .36888 Mdot
.11021 .37254 Mdot
.63171 .32231 Mdot
.24696 .38024 Mdot
.7349 .30157 Mdot
.3496 .3799 Mdot
.8611 .31613 Mdot
.47014 .37641 Mdot
.05544 .36173 Mdot
.59728 .33487 Mdot
.21218 .38003 Mdot
.70334 .30355 Mdot
.31638 .37888 Mdot
.81302 .30694 Mdot
.42713 .37954 Mdot
.98496 .34476 Mdot
.55481 .35218 Mdot
.16763 .37875 Mdot
.66981 .31036 Mdot
.28349 .37927 Mdot
.77265 .30232 Mdot
.38785 .38021 Mdot
.92056 .32924 Mdot
.51423 .3669 Mdot
.11925 .37393 Mdot
.63756 .32033 Mdot
.25271 .38018 Mdot
.74055 .30151 Mdot
.3555 .38006 Mdot
.87009 .31803 Mdot
.47744 .37537 Mdot
.06681 .36425 Mdot
.60428 .33218 Mdot
.21934 .38013 Mdot
.70944 .30289 Mdot
.32274 .37904 Mdot
.82178 .30843 Mdot
.43542 .37925 Mdot
.9988 .34819 Mdot
.56314 .34878 Mdot
.17668 .37919 Mdot
.67616 .3087 Mdot
.28952 .37907 Mdot
.77945 .3028 Mdot
.39454 .38014 Mdot
.93129 .33173 Mdot
.52132 .36466 Mdot
.12836 .37517 Mdot
.64348 .31836 Mdot
.25846 .38008 Mdot
.7463 .3015 Mdot
.36143 .38017 Mdot
.87919 .31999 Mdot
.48458 .37415 Mdot
.07765 .36654 Mdot
.61103 .32965 Mdot
.22622 .3802 Mdot
.71549 .30239 Mdot
.32911 .37924 Mdot
.83082 .31007 Mdot
.44378 .37883 Mdot
.0127 .35161 Mdot
.57147 .34534 Mdot
.18551 .3795 Mdot
.68254 .30718 Mdot
.29562 .37891 Mdot
.78658 .30343 Mdot
.40151 .38005 Mdot
.94258 .3344 Mdot
.5286 .36218 Mdot
.13737 .37624 Mdot
.64939 .31645 Mdot
.26414 .37993 Mdot
.75206 .30155 Mdot
.3673 .38024 Mdot
.88825 .32197 Mdot
.49143 .37279 Mdot
.08777 .36856 Mdot
.6174 .32733 Mdot
.23265 .38025 Mdot
.72134 .30203 Mdot
.33529 .37944 Mdot
.83977 .31178 Mdot
.45185 .37829 Mdot
.026 .35484 Mdot
.57944 .34205 Mdot
.19382 .37971 Mdot
.68873 .30587 Mdot
.30165 .3788 Mdot
.79389 .30422 Mdot
.40864 .37994 Mdot
.95425 .33721 Mdot
.53596 .35952 Mdot
.14619 .37714 Mdot
.65524 .31461 Mdot
.26969 .37976 Mdot
.7578 .30167 Mdot
.37308 .38026 Mdot
.89725 .32395 Mdot
.49803 .3713 Mdot
.09723 .37033 Mdot
.62339 .32519 Mdot
.23868 .38027 Mdot
.72696 .30177 Mdot
.34123 .37964 Mdot
.84853 .31353 Mdot
.45953 .37762 Mdot
.03849 .35782 Mdot
.58696 .33897 Mdot
.20159 .37986 Mdot
.69474 .30478 Mdot
0 .40172 Mdot
.65 .40172 Mdot
.40301 .46538 Mdot
.08313 .42034 Mdot
.69974 .38108 Mdot
.43737 .45588 Mdot
.12618 .42571 Mdot
.72429 .36965 Mdot
.44807 .44732 Mdot
.13104 .4221 Mdot
.72063 .36438 Mdot
.43538 .44174 Mdot
.09983 .41066 Mdot
.68956 .36447 Mdot
.39754 .43756 Mdot
.0291 .39032 Mdot
.63751 .37602 Mdot
.34274 .43586 Mdot
.94165 .37015 Mdot
.58621 .39836 Mdot
.29641 .43893 Mdot
.88465 .36356 Mdot
.55731 .41572 Mdot
.27483 .44345 Mdot
.86657 .36572 Mdot
.55299 .42423 Mdot
.28101 .44994 Mdot
.88412 .37274 Mdot
.57195 .42511 Mdot
.31541 .45948 Mdot
.94215 .38735 Mdot
.61416 .41532 Mdot
.36986 .46705 Mdot
.03266 .40964 Mdot
.66952 .3936 Mdot
.41777 .46244 Mdot
.10312 .42357 Mdot
.71163 .37608 Mdot
.44378 .45249 Mdot
.13188 .42527 Mdot
.72614 .36727 Mdot
.4463 .44508 Mdot
.12431 .41903 Mdot
.71268 .36363 Mdot
.42489 .44017 Mdot
.07921 .40439 Mdot
.67275 .36683 Mdot
.37891 .43643 Mdot
.99727 .38217 Mdot
.61782 .38352 Mdot
.32424 .43659 Mdot
.91694 .36631 Mdot
.57312 .40554 Mdot
.28575 .44043 Mdot
.87425 .36372 Mdot
.55321 .41962 Mdot
.27395 .44544 Mdot
.86881 .36764 Mdot
.55713 .42541 Mdot
.29018 .45305 Mdot
.89993 .37685 Mdot
.58457 .42313 Mdot
.33374 .46301 Mdot
.97279 .39496 Mdot
.63351 .40835 Mdot
.38894 .46688 Mdot
.06256 .41632 Mdot
.68741 .38618 Mdot
.42987 .45886 Mdot
.11801 .4253 Mdot
.72017 .37215 Mdot
.44741 .44946 Mdot
.13335 .42393 Mdot
.72466 .36545 Mdot
.44168 .44314 Mdot
.11309 .41495 Mdot
.70144 .36363 Mdot
.41125 .43868 Mdot
.05367 .39704 Mdot
.65397 .371 Mdot
.3591 .4358 Mdot
.96568 .37488 Mdot
.5995 .39172 Mdot
.30783 .43778 Mdot
.89716 .36422 Mdot
.56315 .4116 Mdot
.27835 .44202 Mdot
.86823 .36457 Mdot
.5519 .42253 Mdot
.27635 .44773 Mdot
.87521 .37012 Mdot
.56399 .42569 Mdot
.30259 .45648 Mdot
.92075 .38205 Mdot
.59973 .41963 Mdot
.35336 .46577 Mdot
.0056 .4031 Mdot
.65335 .40034 Mdot
.40567 .46496 Mdot
.08687 .421 Mdot
.70197 .38015 Mdot
.43864 .45529 Mdot
.12744 .4257 Mdot
.72483 .36921 Mdot
.44796 .44692 Mdot
.13019 .42164 Mdot
.7195 .36422 Mdot
.43381 .44147 Mdot
.09668 .40968 Mdot
.68688 .36476 Mdot
.39451 .43734 Mdot
.0238 .38892 Mdot
.63412 .3772 Mdot
.33948 .43594 Mdot
.93711 .36936 Mdot
.58376 .39965 Mdot
.29436 .43917 Mdot
.88254 .36352 Mdot
.5564 .41646 Mdot
.27443 .44377 Mdot
.86663 .366 Mdot
.55348 .42449 Mdot
.2823 .45044 Mdot
.88641 .37336 Mdot
.57388 .42488 Mdot
.31834 .4601 Mdot
.94704 .38856 Mdot
.61733 .41426 Mdot
.37321 .46716 Mdot
.03804 .41089 Mdot
.67274 .39226 Mdot
.42004 .46186 Mdot
.10604 .42397 Mdot
.71334 .37533 Mdot
.4446 .45195 Mdot
.13244 .42511 Mdot
.72614 .36692 Mdot
.44573 .44473 Mdot
.12274 .41842 Mdot
.71101 .36357 Mdot
.4228 .43991 Mdot
.07522 .40322 Mdot
.66968 .3674 Mdot
.37559 .43628 Mdot
.99181 .38084 Mdot
.61458 .38489 Mdot
.32129 .43677 Mdot
.91324 .36584 Mdot
.57121 .40665 Mdot
.28427 .44069 Mdot
.87294 .36382 Mdot
.5528 .42018 Mdot
.27414 .44581 Mdot
.86961 .36802 Mdot
.55811 .42552 Mdot
.29207 .45361 Mdot
.90313 .37766 Mdot
.58699 .42265 Mdot
.33703 .46355 Mdot
.9783 .39633 Mdot
.63688 .40703 Mdot
.39196 .46666 Mdot
.0671 .41726 Mdot
.69013 .38506 Mdot
.43159 .45824 Mdot
.11998 .42545 Mdot
.72122 .37159 Mdot
.44772 .449 Mdot
.13314 .42361 Mdot
.72404 .3652 Mdot
.44058 .44284 Mdot
.11067 .41414 Mdot
.6992 .36373 Mdot
.40861 .43844 Mdot
.04886 .3957 Mdot
.65064 .37192 Mdot
.35572 .43576 Mdot
.96055 .3738 Mdot
.59662 .39311 Mdot
.30532 .438 Mdot
.89431 .36402 Mdot
.56177 .41252 Mdot
.27742 .4423 Mdot
.86763 .36477 Mdot
.55195 .42293 Mdot
.27708 .44816 Mdot
.87674 .37061 Mdot
.56543 .42564 Mdot
.30501 .45709 Mdot
.9248 .38305 Mdot
.60253 .41886 Mdot
.35673 .46612 Mdot
.01119 .40447 Mdot
.6567 .39895 Mdot
.40827 .4645 Mdot
.09046 .42162 Mdot
.70412 .37926 Mdot
.43984 .4547 Mdot
.12857 .42566 Mdot
.72527 .36878 Mdot
.44777 .44653 Mdot
.12922 .42116 Mdot
.71829 .36406 Mdot
.43216 .4412 Mdot
.09338 .40866 Mdot
.68412 .36509 Mdot
.39142 .43714 Mdot
.01844 .38752 Mdot
.63074 .37842 Mdot
.33626 .43604 Mdot
.93271 .36862 Mdot
.5814 .40091 Mdot
.29241 .43943 Mdot
.88058 .36351 Mdot
.55558 .41717 Mdot
.27413 .44409 Mdot
.86683 .36631 Mdot
.55406 .42473 Mdot
.28371 .45095 Mdot
.88888 .37401 Mdot
.57589 .4246 Mdot
.32136 .46072 Mdot
.95207 .38981 Mdot
.62056 .41315 Mdot
.37653 .46721 Mdot
.04333 .41211 Mdot
.67589 .39095 Mdot
.42223 .46126 Mdot
.1088 .42432 Mdot
.71495 .37462 Mdot
.44535 .45141 Mdot
.13288 .42492 Mdot
.72604 .36659 Mdot
.44508 .44439 Mdot
.12104 .41777 Mdot
.70925 .36353 Mdot
.42062 .43965 Mdot
.07109 .40201 Mdot
.66656 .36802 Mdot
.37225 .43614 Mdot
.98637 .37955 Mdot
.61138 .38628 Mdot
.3184 .43696 Mdot
.90967 .36543 Mdot
.56939 .40773 Mdot
.28287 .44096 Mdot
.87174 .36394 Mdot
.55247 .42071 Mdot
.27441 .44618 Mdot
.87052 .36842 Mdot
.55916 .4256 Mdot
.29405 .45419 Mdot
.90646 .37849 Mdot
.58947 .42212 Mdot
.34034 .46406 Mdot
.98385 .39771 Mdot
.64026 .40568 Mdot
.39491 .4664 Mdot
.07146 .41813 Mdot
.69275 .38397 Mdot
.43321 .45763 Mdot
.12179 .42557 Mdot
.72217 .37106 Mdot
.44794 .44855 Mdot
.13279 .42326 Mdot
.72331 .36496 Mdot
.43938 .44255 Mdot
.10811 .4133 Mdot
.69685 .36386 Mdot
.40588 .43821 Mdot
.04393 .39434 Mdot
.64728 .37289 Mdot
.35235 .43575 Mdot
.95552 .37278 Mdot
.59381 .39449 Mdot
.30289 .43823 Mdot
.8916 .36385 Mdot
.56049 .41339 Mdot
.2766 .44258 Mdot
.86717 .36499 Mdot
.55208 .4233 Mdot
.27793 .4486 Mdot
.87841 .37112 Mdot
.56697 .42555 Mdot
.30754 .4577 Mdot
.92901 .38409 Mdot
.60541 .41804 Mdot
.36011 .46643 Mdot
.01676 .40583 Mdot
.66003 .39756 Mdot
.41081 .46401 Mdot
.09392 .42218 Mdot
.70617 .3784 Mdot
.44096 .45412 Mdot
.12959 .4256 Mdot
.72563 .36837 Mdot
.4475 .44614 Mdot
.12813 .42065 Mdot
.71698 .36393 Mdot
.43042 .44093 Mdot
.08994 .40761 Mdot
.68129 .36547 Mdot
.38827 .43694 Mdot
.01303 .38612 Mdot
.62738 .37969 Mdot
.33309 .43616 Mdot
.92845 .36795 Mdot
.57914 .40215 Mdot
.29055 .43968 Mdot
.87876 .36353 Mdot
.55485 .41784 Mdot
.27395 .44443 Mdot
.86716 .36663 Mdot
.55473 .42494 Mdot
.28522 .45147 Mdot
.8915 .3747 Mdot
.57801 .42429 Mdot
.32445 .46133 Mdot
.95725 .39109 Mdot
.62384 .41197 Mdot
.3798 .46721 Mdot
.04849 .41327 Mdot
.67898 .38967 Mdot
.42433 .46065 Mdot
.11141 .42463 Mdot
.71645 .37394 Mdot
.44601 .45089 Mdot
.1332 .42471 Mdot
.72584 .36627 Mdot
.44434 .44406 Mdot
.11921 .41709 Mdot
.70738 .36351 Mdot
.41834 .4394 Mdot
.06681 .40077 Mdot
.66338 .3687 Mdot
.36889 .43602 Mdot
.98097 .37829 Mdot
.60824 .38767 Mdot
.31557 .43716 Mdot
.90624 .36505 Mdot
.56765 .40877 Mdot
.28157 .44123 Mdot
.87067 .36408 Mdot
.55221 .42122 Mdot
.27477 .44657 Mdot
.87155 .36883 Mdot
.56029 .42567 Mdot
.29612 .45477 Mdot
.90993 .37936 Mdot
.59201 .42155 Mdot
.34367 .46455 Mdot
.98943 .3991 Mdot
.64364 .40432 Mdot
.39778 .46609 Mdot
.07566 .41895 Mdot
.69526 .38294 Mdot
.43473 .45702 Mdot
.12344 .42564 Mdot
.723 .37055 Mdot
.44806 .44811 Mdot
.13231 .42289 Mdot
.72248 .36475 Mdot
.43808 .44227 Mdot
.10539 .41242 Mdot
.69441 .36404 Mdot
.40307 .43798 Mdot
.03889 .39296 Mdot
.64391 .37392 Mdot
.34899 .43577 Mdot
.9506 .37181 Mdot
.59109 .39585 Mdot
.30055 .43847 Mdot
.88905 .36371 Mdot
.5593 .41423 Mdot
.27589 .44288 Mdot
.86683 .36523 Mdot
.55231 .42365 Mdot
.27889 .44905 Mdot
.88023 .37165 Mdot
.5686 .42544 Mdot
.31016 .45831 Mdot
.9334 .38518 Mdot
.60837 .41716 Mdot
.36349 .46669 Mdot
.02231 .40717 Mdot
.66334 .39618 Mdot
.41328 .46349 Mdot
.09723 .4227 Mdot
.70814 .37757 Mdot
.442 .45355 Mdot
.13049 .42551 Mdot
.72589 .36798 Mdot
.44716 .44577 Mdot
.12692 .42012 Mdot
.71557 .36381 Mdot
.42858 .44066 Mdot
.08636 .40653 Mdot
.67839 .36589 Mdot
.38507 .43675 Mdot
.00759 .38474 Mdot
.62404 .38099 Mdot
.5 .40172 Mdot
.15 .40172 Mdot
.69699 .33806 Mdot
.36431 .41243 Mdot
.93576 .35318 Mdot
.55722 .38408 Mdot
.22347 .41177 Mdot
.76416 .33417 Mdot
.43167 .41255 Mdot
.04619 .37979 Mdot
.62427 .35727 Mdot
.29197 .41266 Mdot
.83674 .33669 Mdot
.49039 .40398 Mdot
.13637 .39923 Mdot
.68611 .33976 Mdot
.35306 .4122 Mdot
.91846 .34944 Mdot
.54627 .38801 Mdot
.21059 .41057 Mdot
.75146 .33428 Mdot
.41966 .41297 Mdot
.02627 .37491 Mdot
.61196 .36198 Mdot
.28002 .41288 Mdot
.82301 .33559 Mdot
.48016 .40614 Mdot
.12148 .39636 Mdot
.67478 .34196 Mdot
.34145 .41202 Mdot
.90124 .34597 Mdot
.53507 .39172 Mdot
.19672 .40892 Mdot
.73811 .3346 Mdot
.40648 .41307 Mdot
.00426 .36945 Mdot
.59863 .36734 Mdot
.26696 .41305 Mdot
.80868 .3348 Mdot
.46917 .40821 Mdot
.10515 .39306 Mdot
.663 .34477 Mdot
.32961 .41199 Mdot
.88451 .34294 Mdot
.5239 .39516 Mdot
.18233 .40694 Mdot
.72478 .33525 Mdot
.39295 .41296 Mdot
.9818 .36393 Mdot
.58518 .37291 Mdot
.25349 .41304 Mdot
.79451 .33437 Mdot
.45791 .41 Mdot
.08802 .38943 Mdot
.65125 .3481 Mdot
.31808 .41212 Mdot
.86905 .34052 Mdot
.51336 .3982 Mdot
.16833 .4048 Mdot
.71239 .33624 Mdot
.38022 .41275 Mdot
.96103 .35896 Mdot
.5727 .37803 Mdot
.24053 .41274 Mdot
.78127 .33419 Mdot
.44688 .41137 Mdot
.07077 .38559 Mdot
.6399 .35174 Mdot
.30707 .41234 Mdot
.85502 .33865 Mdot
.50357 .40082 Mdot
.15497 .40259 Mdot
.70108 .33751 Mdot
.36854 .41251 Mdot
.9424 .35466 Mdot
.56133 .38252 Mdot
.22813 .4121 Mdot
.76881 .33416 Mdot
.43592 .4123 Mdot
.05314 .38146 Mdot
.62863 .35568 Mdot
.29619 .41257 Mdot
.84175 .33717 Mdot
.49405 .40315 Mdot
.1416 .40021 Mdot
.69023 .33907 Mdot
.35732 .41228 Mdot
.92494 .35081 Mdot
.55041 .38656 Mdot
.21554 .41107 Mdot
.75632 .33422 Mdot
.42432 .41285 Mdot
.03403 .37682 Mdot
.61672 .36013 Mdot
.28465 .4128 Mdot
.82826 .33597 Mdot
.4841 .40534 Mdot
.12726 .39749 Mdot
.67911 .34106 Mdot
.34586 .41208 Mdot
.9077 .34723 Mdot
.53931 .39035 Mdot
.20204 .40959 Mdot
.74318 .33445 Mdot
.41154 .41307 Mdot
.01271 .37155 Mdot
.60373 .36527 Mdot
.27197 .413 Mdot
.8141 .33506 Mdot
.47337 .40745 Mdot
.11143 .39434 Mdot
.66745 .34364 Mdot
.33406 .41198 Mdot
.89068 .34401 Mdot
.52805 .39391 Mdot
.18774 .40771 Mdot
.72972 .33496 Mdot
.398 .41302 Mdot
.99014 .36597 Mdot
.59017 .37084 Mdot
.25853 .41307 Mdot
.79975 .33449 Mdot
.46213 .40937 Mdot
.0945 .39082 Mdot
.65563 .3468 Mdot
.32235 .41206 Mdot
.87468 .34136 Mdot
.51722 .39711 Mdot
.17351 .40561 Mdot
.7169 .33583 Mdot
.38487 .41283 Mdot
.96857 .36074 Mdot
.57724 .37618 Mdot
.24532 .41289 Mdot
.78612 .33424 Mdot
.45099 .41091 Mdot
.07726 .38706 Mdot
.64412 .35034 Mdot
.31116 .41225 Mdot
.86016 .3393 Mdot
.50718 .39988 Mdot
.15995 .40343 Mdot
.70523 .337 Mdot
.37284 .4126 Mdot
.94919 .35621 Mdot
.56551 .3809 Mdot
.23277 .41239 Mdot
.77344 .33416 Mdot
.44007 .412 Mdot
.05987 .38306 Mdot
.6329 .35415 Mdot
.30031 .41249 Mdot
.84671 .33769 Mdot
.49764 .4023 Mdot
.14669 .40113 Mdot
.69431 .33845 Mdot
.36153 .41237 Mdot
.93144 .35222 Mdot
.55451 .38508 Mdot
.22035 .41151 Mdot
.76107 .33418 Mdot
.4288 .41268 Mdot
.04145 .37864 Mdot
.62132 .35838 Mdot
.28911 .41272 Mdot
.8334 .33639 Mdot
.48793 .40452 Mdot
.13281 .39856 Mdot
.68335 .34025 Mdot
.35022 .41215 Mdot
.91418 .34855 Mdot
.54352 .38895 Mdot
.20724 .4102 Mdot
.7482 .33433 Mdot
.41648 .41302 Mdot
.02097 .37359 Mdot
.60873 .36326 Mdot
.27687 .41293 Mdot
.81949 .33536 Mdot
.47749 .40667 Mdot
.11755 .39558 Mdot
.67188 .3426 Mdot
.33851 .412 Mdot
.89701 .34517 Mdot
.53226 .39261 Mdot
.19316 .40845 Mdot
.73476 .33473 Mdot
.4031 .41306 Mdot
.99863 .36806 Mdot
.59525 .36873 Mdot
.26361 .41307 Mdot
.80511 .33466 Mdot
.46637 .40868 Mdot
.10094 .39218 Mdot
.66006 .34556 Mdot
.3267 .41201 Mdot
.88053 .34228 Mdot
.5212 .39596 Mdot
.17879 .40641 Mdot
.72159 .33547 Mdot
.38969 .41291 Mdot
.97643 .36263 Mdot
.58196 .37424 Mdot
.25021 .413 Mdot
.79112 .33431 Mdot
.45514 .41038 Mdot
.08374 .3885 Mdot
.6484 .34898 Mdot
.3153 .41217 Mdot
.86545 .34001 Mdot
.51087 .39889 Mdot
.16497 .40426 Mdot
.70949 .33653 Mdot
.37724 .41269 Mdot
.95622 .35783 Mdot
.56979 .37921 Mdot
.23742 .41262 Mdot
.77813 .33417 Mdot
.44417 .41164 Mdot
.06646 .3846 Mdot
.63712 .35268 Mdot
.30439 .4124 Mdot
.8517 .33826 Mdot
.50121 .40142 Mdot
.15169 .40202 Mdot
.69837 .33787 Mdot
.36574 .41246 Mdot
.938 .35367 Mdot
.55861 .38356 Mdot
.22506 .41189 Mdot
.76574 .33416 Mdot
.43313 .41247 Mdot
.04857 .38037 Mdot
.62576 .35672 Mdot
.29341 .41263 Mdot
.83845 .33685 Mdot
.49164 .4037 Mdot
.13816 .39957 Mdot
.68752 .33952 Mdot
.35451 .41222 Mdot
.92066 .3499 Mdot
.54768 .38752 Mdot
.21228 .41075 Mdot
.75312 .33426 Mdot
.42126 .41293 Mdot
.02894 .37557 Mdot
.6136 .36134 Mdot
.28161 .41285 Mdot
.8248 .33571 Mdot
.48151 .40587 Mdot
.12346 .39675 Mdot
.67626 .34165 Mdot
.34295 .41204 Mdot
.90343 .34639 Mdot
.53651 .39126 Mdot
.19853 .40916 Mdot
.73984 .33454 Mdot
.40821 .41307 Mdot
.00714 .37016 Mdot
.60037 .36663 Mdot
.26867 .41303 Mdot
.81052 .33488 Mdot
.4706 .40795 Mdot
.1073 .3935 Mdot
.66451 .34438 Mdot
.33112 .41199 Mdot
.88658 .3433 Mdot
.5253 .39475 Mdot
.18416 .4072 Mdot
.72644 .33515 Mdot
.39465 .41298 Mdot
.98461 .36461 Mdot
.58686 .37221 Mdot
.25519 .41306 Mdot
.79628 .33441 Mdot
.45934 .40979 Mdot
.09022 .38991 Mdot
.65273 .34765 Mdot
.31952 .4121 Mdot
.87093 .34079 Mdot
.51465 .39784 Mdot
.17008 .40507 Mdot
.7139 .3361 Mdot
.38178 .41277 Mdot
.96355 .35955 Mdot
.57422 .37742 Mdot
.24215 .4128 Mdot
.7829 .3342 Mdot
.44827 .41122 Mdot
.07297 .38609 Mdot
.64133 .35126 Mdot
.30845 .41231 Mdot
.85675 .33887 Mdot
.50479 .40051 Mdot
.15666 .40288 Mdot
.70248 .33734 Mdot
.36999 .41254 Mdot
.94468 .35518 Mdot
.56274 .38198 Mdot
.2297 .41221 Mdot
.77038 .33415 Mdot
.43733 .4122 Mdot
.05544 .38201 Mdot
.63009 .35515 Mdot
.2976 .41254 Mdot
.84343 .33735 Mdot
.49528 .40286 Mdot
.14334 .40053 Mdot
.69162 .33885 Mdot
.35875 .41231 Mdot
.92714 .35129 Mdot
.5518 .38606 Mdot
.21719 .41123 Mdot
.75794 .3342 Mdot
.42586 .4128 Mdot
.03658 .37745 Mdot
.6183 .35952 Mdot
.28618 .41277 Mdot
.83001 .33611 Mdot
.48541 .40506 Mdot
.12916 .39786 Mdot
.68056 .34078 Mdot
.34735 .4121 Mdot
.9099 .34767 Mdot
.54074 .38988 Mdot
.20382 .40981 Mdot
.74489 .3344 Mdot
.41323 .41305 Mdot
.01554 .37225 Mdot
.60544 .36458 Mdot
.27365 .41298 Mdot
.81594 .33515 Mdot
.47478 .40719 Mdot
.11353 .39477 Mdot
.66896 .34328 Mdot
.33557 .41199 Mdot
.89282 .3444 Mdot
.52947 .39348 Mdot
.18958 .40797 Mdot
.73142 .33488 Mdot
.39972 .41303 Mdot
.99301 .36667 Mdot
.59188 .37013 Mdot
.26025 .41307 Mdot
.80156 .33455 Mdot
.46357 .40914 Mdot
.09669 .39129 Mdot
.65713 .34637 Mdot
.32382 .41204 Mdot
.87664 .34166 Mdot
.51856 .39673 Mdot
.17529 .40588 Mdot
.71847 .3357 Mdot
.38649 .41286 Mdot
.9712 .36137 Mdot
.57882 .37553 Mdot
.24696 .41293 Mdot
.7878 .33426 Mdot
.45239 .41074 Mdot
.07946 .38755 Mdot
.64557 .34987 Mdot
.31256 .41222 Mdot
.86193 .33953 Mdot
.50842 .39955 Mdot
.16164 .40371 Mdot
.70666 .33684 Mdot
.37431 .41263 Mdot
.95155 .35675 Mdot
.56695 .38034 Mdot
.23434 .41247 Mdot
.77502 .33416 Mdot
.44146 .41188 Mdot
.06212 .38359 Mdot
.63433 .35365 Mdot
.3017 .41245 Mdot
.8484 .33788 Mdot
.49885 .402 Mdot
.14839 .40144 Mdot
.69569 .33825 Mdot
.36296 .4124 Mdot
.93365 .35271 Mdot
.5559 .38457 Mdot
.22196 .41164 Mdot
.76266 .33417 Mdot
.43028 .41261 Mdot
.0439 .37924 Mdot
.62284 .3578 Mdot
.29058 .41269 Mdot
.83512 .33654 Mdot
.4892 .40424 Mdot
.13465 .39891 Mdot
.68477 .34 Mdot
.35168 .41217 Mdot
.91638 .349 Mdot
.54493 .38847 Mdot
.20897 .41039 Mdot
.74988 .3343 Mdot
.41812 .41299 Mdot
.02371 .37427 Mdot
.6104 .3626 Mdot
.27849 .41291 Mdot
0 .43262 Mdot
.7 .43262 Mdot
.52109 .50746 Mdot
.35901 .51786 Mdot
.09832 .45692 Mdot
.76388 .41134 Mdot
.55628 .48973 Mdot
.39278 .51698 Mdot
.14984 .46789 Mdot
.80397 .40427 Mdot
.57817 .47848 Mdot
.41243 .5156 Mdot
.18011 .47445 Mdot
.83255 .40323 Mdot
.59556 .47157 Mdot
.43052 .51603 Mdot
.21164 .48276 Mdot
.86912 .40634 Mdot
.61989 .464 Mdot
.45776 .51783 Mdot
.26224 .49719 Mdot
.93977 .41874 Mdot
.66434 .44781 Mdot
.49823 .51538 Mdot
.33072 .5145 Mdot
.0519 .44572 Mdot
.7323 .42051 Mdot
.53923 .49871 Mdot
.37723 .51791 Mdot
.12647 .46306 Mdot
.78485 .4069 Mdot
.56752 .48371 Mdot
.40259 .5161 Mdot
.1645 .47089 Mdot
.81703 .40328 Mdot
.58575 .4751 Mdot
.4198 .51547 Mdot
.19238 .47748 Mdot
.84589 .40389 Mdot
.6043 .46872 Mdot
.44031 .51668 Mdot
.22968 .48786 Mdot
.89276 .40981 Mdot
.63529 .45891 Mdot
.47347 .51803 Mdot
.29053 .50497 Mdot
.98438 .42882 Mdot
.6907 .43653 Mdot
.51561 .50982 Mdot
.35299 .51753 Mdot
.08878 .45474 Mdot
.75717 .41309 Mdot
.55276 .4917 Mdot
.3898 .51731 Mdot
.14555 .46708 Mdot
.80042 .40474 Mdot
.57629 .47951 Mdot
.41087 .5158 Mdot
.17781 .474 Mdot
.83031 .40326 Mdot
.59426 .47215 Mdot
.42929 .51607 Mdot
.20959 .48225 Mdot
.86664 .40608 Mdot
.61833 .46457 Mdot
.45621 .51783 Mdot
.25949 .49645 Mdot
.93567 .4179 Mdot
.66193 .44885 Mdot
.4965 .5158 Mdot
.32829 .51407 Mdot
.04784 .44471 Mdot
.72969 .42141 Mdot
.53784 .49946 Mdot
.37597 .51799 Mdot
.12462 .46269 Mdot
.78345 .40718 Mdot
.56681 .48414 Mdot
.40205 .51621 Mdot
.16379 .47078 Mdot
.81643 .40335 Mdot
.58547 .47529 Mdot
.41963 .51554 Mdot
.19221 .47748 Mdot
.84576 .40392 Mdot
.60428 .46879 Mdot
.44037 .51674 Mdot
.22987 .48794 Mdot
.89307 .40988 Mdot
.63552 .45886 Mdot
.47374 .51805 Mdot
.29106 .50513 Mdot
.98526 .42904 Mdot
.69124 .43632 Mdot
.51596 .50971 Mdot
.35343 .51759 Mdot
.08954 .45494 Mdot
.75773 .41297 Mdot
.5531 .49156 Mdot
.39016 .51733 Mdot
.14615 .46723 Mdot
.80098 .40471 Mdot
.57666 .47939 Mdot
.41131 .51585 Mdot
.17864 .47423 Mdot
.83122 .40332 Mdot
.59491 .47198 Mdot
.4301 .51618 Mdot
.21115 .48272 Mdot
.86865 .40636 Mdot
.6197 .46418 Mdot
.45774 .51794 Mdot
.26237 .49729 Mdot
.94006 .41883 Mdot
.66457 .44778 Mdot
.49851 .5154 Mdot
.33125 .51466 Mdot
.05291 .44601 Mdot
.73301 .42033 Mdot
.53971 .49857 Mdot
.37786 .518 Mdot
.12761 .46337 Mdot
.78586 .40682 Mdot
.56822 .48352 Mdot
.4035 .51623 Mdot
.16621 .47139 Mdot
.81885 .40335 Mdot
.58708 .47479 Mdot
.42154 .51573 Mdot
.19576 .47849 Mdot
.84997 .40433 Mdot
.60721 .468 Mdot
.44387 .51708 Mdot
.23654 .4899 Mdot
.90235 .41149 Mdot
.64147 .4568 Mdot
.47943 .51789 Mdot
.30099 .50775 Mdot
.00171 .43307 Mdot
.70106 .43222 Mdot
.52176 .50722 Mdot
.35981 .51794 Mdot
.09965 .45725 Mdot
.76488 .41114 Mdot
.55688 .48948 Mdot
.39343 .51701 Mdot
.15095 .46817 Mdot
.80501 .40424 Mdot
.57887 .47827 Mdot
.41328 .51569 Mdot
.1817 .47491 Mdot
.83434 .40335 Mdot
.59684 .47125 Mdot
.43211 .51623 Mdot
.21472 .48367 Mdot
.87311 .40691 Mdot
.6226 .46321 Mdot
.46075 .51801 Mdot
.26781 .49879 Mdot
.94835 .4206 Mdot
.66949 .44569 Mdot
.502 .51452 Mdot
.33611 .51551 Mdot
.06109 .44806 Mdot
.73838 .41859 Mdot
.54266 .49707 Mdot
.38067 .51792 Mdot
.13191 .46429 Mdot
.78929 .40629 Mdot
.57014 .48259 Mdot
.4053 .51616 Mdot
.1691 .47205 Mdot
.82167 .40331 Mdot
.58887 .47416 Mdot
.42353 .51585 Mdot
.19934 .47948 Mdot
.85422 .40474 Mdot
.61009 .46715 Mdot
.44717 .51735 Mdot
.24276 .4917 Mdot
.91116 .41309 Mdot
.647 .45477 Mdot
.48441 .51755 Mdot
.30937 .50985 Mdot
.01577 .43658 Mdot
.70957 .42879 Mdot
.52661 .50496 Mdot
.36484 .51805 Mdot
.10747 .45897 Mdot
.77052 .40978 Mdot
.55983 .48782 Mdot
.39588 .51671 Mdot
.15445 .46882 Mdot
.80797 .40389 Mdot
.58045 .47742 Mdot
.41459 .51553 Mdot
.18363 .4753 Mdot
.83626 .40335 Mdot
.59797 .47076 Mdot
.43319 .5162 Mdot
.21653 .48413 Mdot
.87534 .40717 Mdot
.624 .46269 Mdot
.46211 .51798 Mdot
.2702 .49943 Mdot
.95199 .42137 Mdot
.67161 .44475 Mdot
.50341 .51408 Mdot
.33795 .51577 Mdot
.06412 .44879 Mdot
.74036 .41794 Mdot
.5437 .49649 Mdot
.38157 .51783 Mdot
.13319 .46453 Mdot
.79027 .4061 Mdot
.57062 .48228 Mdot
.40563 .51606 Mdot
.16949 .47209 Mdot
.82197 .40326 Mdot
.58898 .47404 Mdot
.42352 .51577 Mdot
.1992 .4794 Mdot
.85399 .40468 Mdot
.60988 .46717 Mdot
.44685 .51728 Mdot
.24209 .49148 Mdot
.91016 .41289 Mdot
.64635 .45499 Mdot
.4838 .51757 Mdot
.3083 .50957 Mdot
.01394 .43611 Mdot
.70843 .42922 Mdot
.52594 .50525 Mdot
.3641 .51801 Mdot
.10629 .45869 Mdot
.76962 .40996 Mdot
.55931 .48806 Mdot
.39537 .51671 Mdot
.15361 .46862 Mdot
.80718 .40393 Mdot
.57994 .47759 Mdot
.414 .51548 Mdot
.18257 .475 Mdot
.83506 .40327 Mdot
.59713 .47098 Mdot
.43216 .51608 Mdot
.21455 .48354 Mdot
.87276 .4068 Mdot
.62226 .46322 Mdot
.46023 .51789 Mdot
.26672 .49843 Mdot
.94658 .42018 Mdot
.66838 .4461 Mdot
.50113 .51467 Mdot
.33477 .51522 Mdot
.05874 .44743 Mdot
.73677 .41905 Mdot
.54169 .49747 Mdot
.37957 .51784 Mdot
.13005 .46382 Mdot
.78768 .40644 Mdot
.56909 .48294 Mdot
.40405 .51603 Mdot
.16682 .47142 Mdot
.81926 .40323 Mdot
.58715 .47459 Mdot
.42134 .51556 Mdot
.19514 .47823 Mdot
.8491 .40417 Mdot
.60649 .46809 Mdot
.44286 .5169 Mdot
.23448 .48925 Mdot
.89939 .41094 Mdot
.63953 .45743 Mdot
.47754 .51792 Mdot
.29763 .50685 Mdot
.99606 .43165 Mdot
.69764 .4336 Mdot
.51972 .50807 Mdot
.35753 .5178 Mdot
.09599 .45639 Mdot
.76223 .41176 Mdot
.55542 .49022 Mdot
.39205 .51707 Mdot
.14879 .46769 Mdot
.80309 .40438 Mdot
.5777 .47874 Mdot
.41204 .51565 Mdot
.17953 .47433 Mdot
.83197 .40323 Mdot
.59522 .47172 Mdot
.43019 .51604 Mdot
.21108 .48262 Mdot
.86844 .40627 Mdot
.61946 .46416 Mdot
.45733 .51783 Mdot
.26146 .49698 Mdot
.93861 .4185 Mdot
.66365 .4481 Mdot
.49774 .5155 Mdot
.33003 .51438 Mdot
.05075 .44543 Mdot
.73156 .42076 Mdot
.53883 .49892 Mdot
.37686 .51793 Mdot
.12593 .46295 Mdot
.78443 .40698 Mdot
.5673 .48384 Mdot
.40241 .51613 Mdot
.16425 .47084 Mdot
.81681 .4033 Mdot
.58563 .47516 Mdot
.4197 .51548 Mdot
.19223 .47745 Mdot
.84573 .40388 Mdot
.6042 .46876 Mdot
.44021 .51668 Mdot
.22951 .48781 Mdot
.89254 .40977 Mdot
.63515 .45896 Mdot
.47335 .51804 Mdot
.29033 .50492 Mdot
.98405 .42874 Mdot
.69051 .43662 Mdot
.5155 .50987 Mdot
.35287 .51752 Mdot
.0886 .45471 Mdot
.75706 .41313 Mdot
.55271 .49174 Mdot
.38977 .51733 Mdot
.14552 .46708 Mdot
.80041 .40475 Mdot
.57629 .47952 Mdot
.4109 .51582 Mdot
.17789 .47403 Mdot
.83041 .40328 Mdot
.59434 .47214 Mdot
.4294 .5161 Mdot
.20981 .48232 Mdot
.86694 .40613 Mdot
.61854 .46452 Mdot
.45645 .51785 Mdot
.25994 .49659 Mdot
.93636 .41805 Mdot
.66235 .44868 Mdot
.49683 .51574 Mdot
.32877 .51417 Mdot
.04867 .44492 Mdot
.73024 .42123 Mdot
.53815 .49932 Mdot
.37629 .518 Mdot
.12512 .46281 Mdot
.78386 .40712 Mdot
.56705 .48404 Mdot
.4023 .51622 Mdot
.16422 .47089 Mdot
.81686 .40335 Mdot
.58575 .4752 Mdot
.41998 .51558 Mdot
.19285 .47766 Mdot
.84652 .40399 Mdot
.6048 .46865 Mdot
.44101 .5168 Mdot
.23109 .4883 Mdot
.89475 .41016 Mdot
.6366 .45849 Mdot
.4748 .51804 Mdot
.29293 .50563 Mdot
.98835 .42979 Mdot
.69307 .43554 Mdot
.51706 .50925 Mdot
.35468 .51768 Mdot
.09154 .4554 Mdot
.75913 .4126 Mdot
.55384 .49116 Mdot
.39082 .51728 Mdot
.14713 .46743 Mdot
.8018 .40461 Mdot
.57712 .47917 Mdot
.41173 .51582 Mdot
.17931 .47438 Mdot
.83191 .40333 Mdot
.59534 .47183 Mdot
.43057 .5162 Mdot
.212 .48295 Mdot
.86971 .40649 Mdot
.6204 .46395 Mdot
.45848 .51796 Mdot
.26372 .49767 Mdot
.94211 .41927 Mdot
.6658 .44726 Mdot
.4994 .51519 Mdot
.33253 .5149 Mdot
.05506 .44655 Mdot
.73442 .41987 Mdot
.5405 .49818 Mdot
.37862 .51799 Mdot
.12879 .46363 Mdot
.7868 .40668 Mdot
.56876 .48327 Mdot
.40402 .51622 Mdot
.5 .43262 Mdot
.2 .43262 Mdot
.77891 .35778 Mdot
.48304 .43518 Mdot
.17364 .42681 Mdot
.75129 .35701 Mdot
.45626 .43569 Mdot
.12668 .41434 Mdot
.70612 .35811 Mdot
.40808 .43383 Mdot
.04051 .39087 Mdot
.64089 .37105 Mdot
.33982 .43196 Mdot
.93117 .36548 Mdot
.57589 .39845 Mdot
.27904 .43457 Mdot
.85697 .35719 Mdot
.53454 .41876 Mdot
.23953 .4357 Mdot
.81746 .35718 Mdot
.51146 .42891 Mdot
.21461 .43457 Mdot
.79357 .35782 Mdot
.49511 .43358 Mdot
.19274 .43116 Mdot
.77121 .35751 Mdot
.47586 .4355 Mdot
.16128 .42361 Mdot
.73865 .35683 Mdot
.44302 .43532 Mdot
.10277 .40775 Mdot
.68591 .36039 Mdot
.38617 .43279 Mdot
.00295 .38119 Mdot
.61737 .37973 Mdot
.31739 .43264 Mdot
.90134 .3609 Mdot
.55926 .40662 Mdot
.26349 .43524 Mdot
.84086 .35683 Mdot
.52536 .42305 Mdot
.23006 .43553 Mdot
.80844 .35746 Mdot
.50565 .4309 Mdot
.20739 .4337 Mdot
.78634 .35781 Mdot
.4893 .43446 Mdot
.18372 .42917 Mdot
.7617 .35721 Mdot
.46665 .43569 Mdot
.14513 .41932 Mdot
.72293 .3571 Mdot
.42622 .43466 Mdot
.07258 .39947 Mdot
.66287 .36482 Mdot
.36187 .43201 Mdot
.96373 .37197 Mdot
.59436 .38975 Mdot
.29612 .43371 Mdot
.87587 .3583 Mdot
.54515 .41364 Mdot
.25008 .43567 Mdot
.82768 .35698 Mdot
.51774 .42648 Mdot
.22197 .43523 Mdot
.80084 .35776 Mdot
.50059 .43247 Mdot
.20082 .43276 Mdot
.77975 .3578 Mdot
.48379 .43512 Mdot
.17489 .42712 Mdot
.75258 .35703 Mdot
.45757 .43571 Mdot
.12903 .41498 Mdot
.70821 .35795 Mdot
.41034 .43394 Mdot
.04448 .39192 Mdot
.64349 .37021 Mdot
.34238 .43193 Mdot
.93479 .36613 Mdot
.57792 .39748 Mdot
.28093 .43448 Mdot
.859 .35727 Mdot
.53569 .41822 Mdot
.2407 .43572 Mdot
.8186 .35716 Mdot
.51218 .42865 Mdot
.21549 .43467 Mdot
.79446 .35782 Mdot
.49582 .43346 Mdot
.19383 .43139 Mdot
.77236 .35755 Mdot
.47697 .43547 Mdot
.16321 .42412 Mdot
.74059 .35684 Mdot
.44508 .4354 Mdot
.10649 .40878 Mdot
.68893 .35997 Mdot
.38943 .43293 Mdot
.00843 .38256 Mdot
.62068 .37839 Mdot
.3205 .43251 Mdot
.90527 .36141 Mdot
.56143 .40553 Mdot
.26553 .43516 Mdot
.84291 .35684 Mdot
.52653 .4225 Mdot
.23127 .43555 Mdot
.80957 .35741 Mdot
.50638 .43065 Mdot
.20829 .4338 Mdot
.78722 .3578 Mdot
.49001 .43435 Mdot
.18482 .42941 Mdot
.76283 .35723 Mdot
.46775 .43567 Mdot
.14706 .41983 Mdot
.72475 .35704 Mdot
.42818 .43474 Mdot
.07607 .40042 Mdot
.6654 .36423 Mdot
.36448 .43206 Mdot
.96778 .37286 Mdot
.59668 .38868 Mdot
.29826 .4336 Mdot
.87832 .3585 Mdot
.54651 .41297 Mdot
.25139 .43564 Mdot
.82895 .35695 Mdot
.51849 .42616 Mdot
.22278 .43528 Mdot
.80161 .35774 Mdot
.50113 .43232 Mdot
.20154 .43288 Mdot
.78049 .35781 Mdot
.48443 .43506 Mdot
.17595 .42738 Mdot
.75367 .35705 Mdot
.45868 .43572 Mdot
.13101 .41552 Mdot
.70997 .35782 Mdot
.41225 .43403 Mdot
.04783 .39281 Mdot
.64572 .36952 Mdot
.34457 .43191 Mdot
.93792 .36671 Mdot
.57969 .39663 Mdot
.28257 .4344 Mdot
.86078 .35735 Mdot
.5367 .41774 Mdot
.24171 .43572 Mdot
.81958 .35714 Mdot
.5128 .42843 Mdot
.21624 .43475 Mdot
.79521 .35782 Mdot
.4964 .43336 Mdot
.19471 .43158 Mdot
.77331 .35759 Mdot
.47786 .43544 Mdot
.16476 .42453 Mdot
.74217 .35686 Mdot
.44674 .43545 Mdot
.1095 .40961 Mdot
.69141 .35964 Mdot
.39211 .43306 Mdot
.01296 .38371 Mdot
.62345 .37731 Mdot
.3231 .4324 Mdot
.90861 .36187 Mdot
.56329 .40461 Mdot
.26727 .43508 Mdot
.84467 .35686 Mdot
.52753 .42203 Mdot
.2323 .43557 Mdot
.81054 .35737 Mdot
.507 .43044 Mdot
.20905 .43389 Mdot
.78797 .35779 Mdot
.49061 .43425 Mdot
.18575 .42962 Mdot
.76379 .35725 Mdot
.46868 .43565 Mdot
.14868 .42026 Mdot
.7263 .35699 Mdot
.42983 .43481 Mdot
.07902 .40122 Mdot
.66756 .36374 Mdot
.36673 .43211 Mdot
.97131 .37365 Mdot
.59872 .38776 Mdot
.30013 .4335 Mdot
.88048 .35868 Mdot
.54771 .41237 Mdot
.25254 .43561 Mdot
.83007 .35693 Mdot
.51914 .42587 Mdot
.22349 .43531 Mdot
.80228 .35771 Mdot
.50158 .43219 Mdot
.20215 .43297 Mdot
.7811 .35781 Mdot
.48496 .43501 Mdot
.1768 .42758 Mdot
.75455 .35707 Mdot
.45957 .43573 Mdot
.13259 .41595 Mdot
.71139 .35772 Mdot
.41379 .4341 Mdot
.05053 .39353 Mdot
.64753 .36896 Mdot
.34636 .4319 Mdot
.9405 .3672 Mdot
.58114 .39594 Mdot
.28391 .43434 Mdot
.86224 .35743 Mdot
.53752 .41735 Mdot
.24255 .43573 Mdot
.82038 .35712 Mdot
.5133 .42824 Mdot
.21684 .43481 Mdot
.7958 .35782 Mdot
.49686 .43328 Mdot
.1954 .43172 Mdot
.77404 .35762 Mdot
.47856 .43541 Mdot
.16596 .42484 Mdot
.74339 .35687 Mdot
.44803 .43549 Mdot
.11183 .41025 Mdot
.69334 .3594 Mdot
.3942 .43315 Mdot
.01652 .38461 Mdot
.62565 .37646 Mdot
.32517 .43233 Mdot
.9113 .36225 Mdot
.56478 .40387 Mdot
.26866 .43502 Mdot
.84609 .35687 Mdot
.52834 .42165 Mdot
.23314 .43559 Mdot
.81132 .35734 Mdot
.5075 .43026 Mdot
.20967 .43397 Mdot
.78859 .35779 Mdot
.4911 .43418 Mdot
.1865 .42978 Mdot
.76458 .35727 Mdot
.46944 .43563 Mdot
.15001 .42062 Mdot
.72757 .35695 Mdot
.43119 .43486 Mdot
.08145 .40189 Mdot
.66937 .36335 Mdot
.36861 .43215 Mdot
.97427 .37432 Mdot
.60043 .38699 Mdot
.30171 .43341 Mdot
.88232 .35884 Mdot
.54873 .41186 Mdot
.25352 .43558 Mdot
.83102 .35691 Mdot
.51969 .42563 Mdot
.22408 .43534 Mdot
.80283 .35769 Mdot
.50196 .43208 Mdot
.20264 .43305 Mdot
.7816 .35782 Mdot
.48539 .43496 Mdot
.17749 .42774 Mdot
.75526 .35708 Mdot
.46028 .43573 Mdot
.13386 .41629 Mdot
.71254 .35764 Mdot
.41502 .43416 Mdot
.05272 .39412 Mdot
.649 .36853 Mdot
.34782 .4319 Mdot
.94263 .36761 Mdot
.58234 .39536 Mdot
.28502 .43428 Mdot
.86346 .35749 Mdot
.53821 .41702 Mdot
.24323 .43573 Mdot
.82105 .35711 Mdot
.51371 .42809 Mdot
.21732 .43486 Mdot
.79629 .35782 Mdot
.49723 .43321 Mdot
.19596 .43184 Mdot
.77463 .35764 Mdot
.47911 .43539 Mdot
.16692 .42509 Mdot
.74436 .35688 Mdot
.44905 .43552 Mdot
.11367 .41076 Mdot
.69489 .35921 Mdot
.39588 .43323 Mdot
.01939 .38535 Mdot
.62742 .37579 Mdot
.32685 .43227 Mdot
.91351 .36258 Mdot
.56601 .40326 Mdot
.26981 .43497 Mdot
.84727 .35689 Mdot
.52901 .42134 Mdot
.23383 .4356 Mdot
.81197 .35732 Mdot
.50792 .43012 Mdot
.21019 .43403 Mdot
.7891 .35779 Mdot
.49151 .43411 Mdot
.18714 .42992 Mdot
.76524 .35729 Mdot
.47008 .43562 Mdot
.15114 .42091 Mdot
.72865 .35692 Mdot
.43234 .43491 Mdot
.08353 .40245 Mdot
.67092 .36303 Mdot
.37023 .4322 Mdot
.97685 .37491 Mdot
.60193 .38632 Mdot
.30309 .43334 Mdot
.88394 .35899 Mdot
.54963 .41142 Mdot
.25437 .43556 Mdot
.83185 .3569 Mdot
.52018 .42541 Mdot
.2246 .43536 Mdot
.80332 .35767 Mdot
.50228 .43198 Mdot
.20308 .43311 Mdot
.78204 .35782 Mdot
.48575 .43492 Mdot
.17808 .42788 Mdot
.75587 .35709 Mdot
.46089 .43573 Mdot
.13495 .41659 Mdot
.71352 .35758 Mdot
.41609 .43421 Mdot
.0546 .39462 Mdot
.65028 .36815 Mdot
.3491 .43189 Mdot
.94448 .36797 Mdot
.58339 .39487 Mdot
.286 .43423 Mdot
.86452 .35755 Mdot
.53881 .41673 Mdot
.24383 .43573 Mdot
.82163 .3571 Mdot
.51407 .42795 Mdot
.21775 .4349 Mdot
.79671 .35782 Mdot
.49756 .43314 Mdot
.19644 .43194 Mdot
.77515 .35766 Mdot
.47959 .43537 Mdot
.16774 .4253 Mdot
.74521 .35689 Mdot
.44994 .43555 Mdot
.11527 .4112 Mdot
.69624 .35906 Mdot
.39734 .4333 Mdot
.0219 .386 Mdot
.62899 .3752 Mdot
.32834 .43222 Mdot
.91548 .36287 Mdot
.5671 .40273 Mdot
.27083 .43493 Mdot
.84833 .35691 Mdot
.52961 .42106 Mdot
.23445 .43561 Mdot
.81256 .3573 Mdot
.50829 .42999 Mdot
.21066 .43408 Mdot
.78957 .35779 Mdot
.49189 .43406 Mdot
.18772 .43005 Mdot
.76585 .35731 Mdot
.47068 .43561 Mdot
.15218 .42119 Mdot
.72966 .3569 Mdot
.43342 .43495 Mdot
.08547 .40299 Mdot
.67238 .36273 Mdot
.37176 .43224 Mdot
.97931 .37548 Mdot
.60336 .38568 Mdot
.3044 .43327 Mdot
.88549 .35913 Mdot
.55049 .41099 Mdot
.2552 .43553 Mdot
.83265 .35689 Mdot
.52064 .4252 Mdot
.2251 .43538 Mdot
.80379 .35765 Mdot
.5026 .43189 Mdot
.20349 .43317 Mdot
.78245 .35782 Mdot
.4861 .43488 Mdot
.17865 .42802 Mdot
0 .46353 Mdot
.75 .46353 Mdot
.62732 .54222 Mdot
.59598 .59867 Mdot
.63686 .02526 Mdot
.77422 .08489 Mdot
.03744 .16268 Mdot
.27098 .14433 Mdot
.3783 .06633 Mdot
.39747 .01185 Mdot
.34017 .58262 Mdot
.17545 .51623 Mdot
.89712 .44601 Mdot
.69548 .49341 Mdot
.61376 .56753 Mdot
.6155 .00108 Mdot
.70174 .0533 Mdot
.9095 .1284 Mdot
.18581 .17077 Mdot
.34502 .0984 Mdot
.39894 .03332 Mdot
.37733 .60468 Mdot
.26701 .54985 Mdot
.0301 .47161 Mdot
.76925 .45682 Mdot
.63479 .53494 Mdot
.59574 .5939 Mdot
.62874 .02039 Mdot
.75386 .07733 Mdot
.00626 .156 Mdot
.25366 .1529 Mdot
.37377 .07423 Mdot
.40315 .01816 Mdot
.35974 .59121 Mdot
.2181 .53049 Mdot
.95168 .45338 Mdot
.72333 .47691 Mdot
.62051 .55449 Mdot
.60516 .60855 Mdot
.66795 .0388 Mdot
.84151 .10727 Mdot
.12192 .1733 Mdot
.31406 .11875 Mdot
.38905 .04635 Mdot
.3823 .61386 Mdot
.28974 .56083 Mdot
.0738 .48458 Mdot
.80092 .44938 Mdot
.6489 .52408 Mdot
.59936 .58742 Mdot
.62425 .01538 Mdot
.73874 .07076 Mdot
.98024 .14925 Mdot
.2375 .159 Mdot
.36784 .08055 Mdot
.40419 .02246 Mdot
.36843 .59593 Mdot
.239 .53804 Mdot
.98255 .45954 Mdot
.74003 .46815 Mdot
.62459 .54669 Mdot
.59895 .60219 Mdot
.64746 .02998 Mdot
.79777 .0929 Mdot
.06971 .16807 Mdot
.28765 .13469 Mdot
.38181 .0582 Mdot
.38988 .00499 Mdot
.31671 .57281 Mdot
.12724 .50094 Mdot
.84648 .44451 Mdot
.67036 .50918 Mdot
.60595 .57823 Mdot
.62017 .00879 Mdot
.72165 .06272 Mdot
.94844 .14016 Mdot
.21576 .16521 Mdot
.35869 .08834 Mdot
.40285 .02729 Mdot
.37404 .60022 Mdot
.25465 .54425 Mdot
.00799 .46559 Mdot
.75494 .46164 Mdot
.62915 .54029 Mdot
.59572 .59737 Mdot
.63433 .02386 Mdot
.76809 .08267 Mdot
.02836 .16085 Mdot
.26606 .14691 Mdot
.37708 .06861 Mdot
.39925 .0137 Mdot
.3461 .58518 Mdot
.18813 .52041 Mdot
.91235 .44759 Mdot
.70319 .48877 Mdot
.61589 .56408 Mdot
.61332 .61645 Mdot
.69394 .04983 Mdot
.89407 .12369 Mdot
.17282 .17228 Mdot
.33893 .10266 Mdot
.39708 .03594 Mdot
.37851 .60656 Mdot
.27191 .55215 Mdot
.0392 .47421 Mdot
.77544 .45502 Mdot
.63738 .53271 Mdot
.59609 .59251 Mdot
.62707 .01915 Mdot
.74926 .07551 Mdot
.99877 .1542 Mdot
.24926 .15481 Mdot
.37243 .07612 Mdot
.40413 .01959 Mdot
.36369 .59304 Mdot
.22705 .53359 Mdot
.96441 .45571 Mdot
.73001 .47316 Mdot
.62192 .55123 Mdot
.6021 .60579 Mdot
.65848 .03484 Mdot
.82171 .10088 Mdot
.09956 .17172 Mdot
.30285 .12564 Mdot
.38577 .05125 Mdot
.38496 .61753 Mdot
.29993 .56548 Mdot
.09378 .49063 Mdot
.81688 .4469 Mdot
.65622 .51874 Mdot
.60142 .58416 Mdot
.62237 .01295 Mdot
.73185 .06766 Mdot
.96784 .14584 Mdot
.22937 .16164 Mdot
.36466 .08361 Mdot
.40425 .02447 Mdot
.37178 .59797 Mdot
.24747 .54121 Mdot
.99586 .46253 Mdot
.74756 .46458 Mdot
.62657 .54326 Mdot
.59649 .59944 Mdot
.63896 .02625 Mdot
.779 .08655 Mdot
.04426 .16394 Mdot
.27456 .14234 Mdot
.37906 .06458 Mdot
.39585 .01038 Mdot
.33514 .58051 Mdot
.1649 .51282 Mdot
.8851 .44511 Mdot
.68945 .49711 Mdot
.61201 .57018 Mdot
.61696 .00306 Mdot
.70729 .05583 Mdot
.92039 .1317 Mdot
.19455 .16944 Mdot
.34904 .09548 Mdot
.40007 .03154 Mdot
.3763 .60335 Mdot
.26325 .54816 Mdot
.02331 .46974 Mdot
.76479 .45826 Mdot
.63304 .53661 Mdot
.59577 .59499 Mdot
.63056 .0215 Mdot
.75848 .07906 Mdot
.01353 .15763 Mdot
.25778 .15095 Mdot
.37485 .07235 Mdot
.40181 .01666 Mdot
.3551 .58917 Mdot
.20784 .52702 Mdot
.93769 .45108 Mdot
.71613 .4811 Mdot
.61902 .55802 Mdot
.60849 .61153 Mdot
.67819 .04308 Mdot
.86247 .11389 Mdot
.14358 .17374 Mdot
.32479 .11199 Mdot
.39247 .04183 Mdot
.38053 .61065 Mdot
.28175 .55698 Mdot
.05816 .47985 Mdot
.78907 .45173 Mdot
.64349 .52806 Mdot
.59778 .58978 Mdot
.62545 .0171 Mdot
.74341 .0729 Mdot
.98859 .15153 Mdot
.24288 .15717 Mdot
.36999 .07855 Mdot
.40427 .02119 Mdot
.36649 .59469 Mdot
.23401 .53615 Mdot
.97484 .45786 Mdot
.73572 .47025 Mdot
.62341 .54862 Mdot
.60022 .6037 Mdot
.65201 .03201 Mdot
.80775 .09625 Mdot
.08252 .16982 Mdot
.29419 .13082 Mdot
.38342 .05515 Mdot
.3875 .00252 Mdot
.3089 .56945 Mdot
.11159 .49609 Mdot
.83214 .44533 Mdot
.66344 .51377 Mdot
.60368 .5811 Mdot
.62113 .01078 Mdot
.7264 .06506 Mdot
.9576 .14289 Mdot
.22231 .1636 Mdot
.36163 .0861 Mdot
.40368 .02599 Mdot
.37328 .59925 Mdot
.25189 .54301 Mdot
.00319 .46433 Mdot
.75193 .46275 Mdot
.62799 .54143 Mdot
.59576 .59811 Mdot
.63559 .02462 Mdot
.77125 .08384 Mdot
.0331 .16183 Mdot
.26866 .14558 Mdot
.37777 .06743 Mdot
.39842 .01277 Mdot
.34322 .58392 Mdot
.18192 .51834 Mdot
.90476 .44674 Mdot
.69933 .49107 Mdot
.61483 .56581 Mdot
.61442 .61778 Mdot
.69787 .05157 Mdot
.90187 .12608 Mdot
.1795 .17158 Mdot
.34209 .10049 Mdot
.39808 .0346 Mdot
.37799 .60562 Mdot
.26958 .55103 Mdot
.03481 .47294 Mdot
.77241 .45586 Mdot
.63608 .53377 Mdot
.59582 .59315 Mdot
.62767 .01968 Mdot
.75104 .07625 Mdot
.00174 .15494 Mdot
.25104 .15408 Mdot
.37303 .07539 Mdot
.40387 .01906 Mdot
.36241 .59241 Mdot
.22408 .53254 Mdot
.96011 .45489 Mdot
.72772 .47441 Mdot
.62141 .55233 Mdot
.60307 .6067 Mdot
.66155 .03614 Mdot
.82819 .10299 Mdot
.10709 .17237 Mdot
.30664 .12333 Mdot
.38685 .04957 Mdot
.38397 .61625 Mdot
.29628 .56384 Mdot
.0866 .48845 Mdot
.81101 .44771 Mdot
.65351 .52069 Mdot
.60063 .58536 Mdot
.62301 .01383 Mdot
.73429 .06877 Mdot
.97227 .14708 Mdot
.23232 .16072 Mdot
.36584 .08252 Mdot
.40429 .02376 Mdot
.3707 .59728 Mdot
.24469 .54015 Mdot
.99142 .46151 Mdot
.74501 .46575 Mdot
.62587 .5444 Mdot
.59724 .60034 Mdot
.64166 .02745 Mdot
.78502 .0886 Mdot
.05264 .1654 Mdot
.27891 .13984 Mdot
.37995 .06245 Mdot
.3938 .00856 Mdot
.32885 .5779 Mdot
.15189 .50867 Mdot
.87104 .44446 Mdot
.68243 .50147 Mdot
.60985 .57317 Mdot
.61833 .00524 Mdot
.713 .05851 Mdot
.93156 .13508 Mdot
.2032 .16789 Mdot
.35299 .09257 Mdot
.40119 .02979 Mdot
.37531 .60205 Mdot
.25959 .54651 Mdot
.01677 .46797 Mdot
.76056 .45969 Mdot
.6314 .5382 Mdot
.5958 .59604 Mdot
.63231 .02256 Mdot
.76288 .0807 Mdot
.02037 .15913 Mdot
.2616 .14909 Mdot
.37585 .07061 Mdot
.40054 .01526 Mdot
.35076 .58726 Mdot
.19831 .52382 Mdot
.92521 .44924 Mdot
.70975 .48488 Mdot
.61758 .56107 Mdot
.61113 .61405 Mdot
.68655 .04661 Mdot
.8793 .11913 Mdot
.15962 .17325 Mdot
.3326 .10691 Mdot
.39502 .03858 Mdot
.37941 .60839 Mdot
.27631 .55431 Mdot
.04761 .47669 Mdot
.78139 .4535 Mdot
.64003 .53067 Mdot
.59678 .59131 Mdot
.62628 .01823 Mdot
.74654 .07432 Mdot
.99409 .15299 Mdot
.24637 .15592 Mdot
.37135 .07725 Mdot
.40427 .02034 Mdot
.36513 .59385 Mdot
.23056 .53486 Mdot
.96961 .45676 Mdot
.73282 .47169 Mdot
.62263 .54993 Mdot
.60111 .60473 Mdot
.65514 .03339 Mdot
.81454 .09852 Mdot
.09094 .17082 Mdot
.29848 .12827 Mdot
.38456 .0532 Mdot
.38618 .001 Mdot
.30431 .56743 Mdot
.10245 .49328 Mdot
.82418 .44605 Mdot
.65965 .51635 Mdot
.60247 .5827 Mdot
.62172 .0119 Mdot
.72914 .06638 Mdot
.96278 .1444 Mdot
.22593 .16264 Mdot
.36321 .08484 Mdot
.40404 .02523 Mdot
.37266 .59864 Mdot
.24994 .54219 Mdot
.9999 .4635 Mdot
.74994 .46355 Mdot
.6273 .54224 Mdot
.59598 .59868 Mdot
.63688 .02528 Mdot
.77427 .08491 Mdot
.03751 .16269 Mdot
.27102 .14432 Mdot
.37831 .06631 Mdot
.39746 .01184 Mdot
.34015 .58261 Mdot
.17539 .51621 Mdot
.89704 .44601 Mdot
.69544 .49344 Mdot
.61375 .56755 Mdot
.6155 .00109 Mdot
.70176 .05331 Mdot
.90955 .12842 Mdot
.18586 .17077 Mdot
.34505 .09838 Mdot
.39895 .03331 Mdot
.37733 .60467 Mdot
.26701 .54985 Mdot
.03009 .47161 Mdot
.76924 .45682 Mdot
.63479 .53494 Mdot
.59573 .59389 Mdot
.62872 .02039 Mdot
.75383 .07732 Mdot
.00622 .15599 Mdot
.25364 .15291 Mdot
.37376 .07424 Mdot
.40316 .01817 Mdot
.35978 .59122 Mdot
.21819 .53052 Mdot
.95181 .4534 Mdot
.72339 .47687 Mdot
.62053 .55446 Mdot
.60512 .60852 Mdot
.66784 .03876 Mdot
.84128 .1072 Mdot
.12168 .17329 Mdot
.5 .46353 Mdot
.25 .46353 Mdot
.87268 .38483 Mdot
.58669 .44128 Mdot
.36667 .48206 Mdot
.05204 .42358 Mdot
.69652 .39831 Mdot
.46119 .47259 Mdot
.19512 .4536 Mdot
.80923 .37954 Mdot
.54194 .45284 Mdot
.30781 .47334 Mdot
.95468 .39978 Mdot
.63731 .42189 Mdot
.41666 .48167 Mdot
.13234 .44232 Mdot
.75394 .38417 Mdot
.50282 .46283 Mdot
.25395 .46423 Mdot
.8778 .38556 Mdot
.59008 .44021 Mdot
.37065 .48241 Mdot
.05875 .42527 Mdot
.70091 .39688 Mdot
.46439 .47186 Mdot
.19962 .4544 Mdot
.81386 .37962 Mdot
.5453 .45206 Mdot
.3125 .47415 Mdot
.96206 .40145 Mdot
.64169 .42003 Mdot
.42028 .48119 Mdot
.13773 .44341 Mdot
.75824 .3835 Mdot
.5059 .46208 Mdot
.25829 .465 Mdot
.88352 .38642 Mdot
.59384 .439 Mdot
.37496 .48276 Mdot
.06601 .4271 Mdot
.70576 .39539 Mdot
.46795 .47106 Mdot
.20467 .45532 Mdot
.81919 .3798 Mdot
.5492 .45117 Mdot
.31793 .47511 Mdot
.97077 .40348 Mdot
.64686 .41785 Mdot
.42446 .48058 Mdot
.14387 .44462 Mdot
.76323 .38279 Mdot
.50948 .46121 Mdot
.2633 .46589 Mdot
.89025 .38747 Mdot
.5982 .43754 Mdot
.37982 .48307 Mdot
.07418 .42914 Mdot
.71132 .39377 Mdot
.47204 .47015 Mdot
.21051 .4564 Mdot
.82555 .38012 Mdot
.55384 .45011 Mdot
.32439 .47622 Mdot
.98126 .40597 Mdot
.6531 .41521 Mdot
.42937 .47976 Mdot
.15098 .44598 Mdot
.76912 .38203 Mdot
.51367 .46016 Mdot
.26914 .46691 Mdot
.8982 .38878 Mdot
.60327 .43575 Mdot
.38526 .4833 Mdot
.08322 .43136 Mdot
.71759 .39206 Mdot
.47666 .46913 Mdot
.21712 .45763 Mdot
.83297 .38061 Mdot
.55922 .44885 Mdot
.33177 .47746 Mdot
.99344 .40893 Mdot
.66035 .41217 Mdot
.43492 .47871 Mdot
.15886 .44742 Mdot
.77579 .38128 Mdot
.51837 .45894 Mdot
.27562 .46801 Mdot
.9072 .39033 Mdot
.60888 .43366 Mdot
.39102 .48339 Mdot
.09264 .43362 Mdot
.72426 .39036 Mdot
.48154 .46803 Mdot
.22409 .45892 Mdot
.841 .38127 Mdot
.56498 .44744 Mdot
.33952 .47869 Mdot
.00634 .41212 Mdot
.66809 .40899 Mdot
.44068 .47748 Mdot
.1669 .44883 Mdot
.78276 .38062 Mdot
.52326 .45765 Mdot
.28229 .46911 Mdot
.91662 .39203 Mdot
.61464 .4314 Mdot
.39664 .48331 Mdot
.10165 .43572 Mdot
.73075 .38881 Mdot
.48625 .46692 Mdot
.23077 .46014 Mdot
.84889 .38202 Mdot
.57054 .446 Mdot
.34679 .47975 Mdot
.01854 .41516 Mdot
.67549 .40602 Mdot
.44607 .47624 Mdot
.17433 .45009 Mdot
.78938 .38013 Mdot
.52788 .45642 Mdot
.28858 .47014 Mdot
.92567 .39374 Mdot
.62009 .42917 Mdot
.40172 .48307 Mdot
.10962 .43751 Mdot
.7366 .38749 Mdot
.49045 .46591 Mdot
.23667 .46119 Mdot
.85601 .38277 Mdot
.57546 .44464 Mdot
.35304 .48057 Mdot
.02906 .4178 Mdot
.68196 .40351 Mdot
.45073 .47512 Mdot
.18071 .45115 Mdot
.79524 .3798 Mdot
.53199 .45533 Mdot
.29415 .47104 Mdot
.93385 .39536 Mdot
.62497 .42713 Mdot
.40609 .48276 Mdot
.11637 .43898 Mdot
.74163 .38643 Mdot
.49404 .46501 Mdot
.24168 .46207 Mdot
.86218 .38349 Mdot
.57965 .44343 Mdot
.35823 .48119 Mdot
.0378 .42 Mdot
.68742 .40148 Mdot
.45464 .47417 Mdot
.18606 .45204 Mdot
.80029 .37962 Mdot
.53555 .45441 Mdot
.29901 .47184 Mdot
.94113 .39685 Mdot
.62928 .4253 Mdot
.40985 .48242 Mdot
.12211 .4402 Mdot
.74598 .38557 Mdot
.49713 .46424 Mdot
.24599 .46282 Mdot
.86757 .38416 Mdot
.58328 .44233 Mdot
.36262 .48166 Mdot
.0452 .42186 Mdot
.69211 .39981 Mdot
.45801 .47335 Mdot
.1907 .45283 Mdot
.8048 .37954 Mdot
.53876 .45361 Mdot
.30341 .47258 Mdot
.94784 .39828 Mdot
.63326 .42361 Mdot
.41325 .48206 Mdot
.12724 .44127 Mdot
.74993 .38485 Mdot
.49995 .46354 Mdot
.24993 .46351 Mdot
.87259 .38482 Mdot
.58663 .4413 Mdot
.36661 .48205 Mdot
.05193 .42355 Mdot
.69644 .39833 Mdot
.46114 .47261 Mdot
.19505 .45358 Mdot
.80915 .37954 Mdot
.54188 .45285 Mdot
.30774 .47332 Mdot
.95456 .39976 Mdot
.63724 .42192 Mdot
.4166 .48167 Mdot
.13225 .4423 Mdot
.75387 .38418 Mdot
.50277 .46285 Mdot
.25388 .46421 Mdot
.87771 .38555 Mdot
.59002 .44023 Mdot
.37058 .48241 Mdot
.05863 .42524 Mdot
.70084 .3969 Mdot
.46434 .47187 Mdot
.19954 .45438 Mdot
.81377 .37961 Mdot
.54524 .45207 Mdot
.31241 .47414 Mdot
.96192 .40142 Mdot
.64161 .42007 Mdot
.42021 .4812 Mdot
.13763 .44339 Mdot
.75816 .38351 Mdot
.50584 .4621 Mdot
.25821 .46499 Mdot
.88341 .3864 Mdot
.59377 .43902 Mdot
.37488 .48275 Mdot
.06588 .42706 Mdot
.70567 .39541 Mdot
.46788 .47107 Mdot
.20457 .4553 Mdot
.81909 .37979 Mdot
.54912 .45118 Mdot
.31783 .47509 Mdot
.97061 .40344 Mdot
.64676 .41789 Mdot
.42438 .4806 Mdot
.14376 .4446 Mdot
.76314 .3828 Mdot
.50941 .46122 Mdot
.26321 .46587 Mdot
.89012 .38745 Mdot
.59812 .43757 Mdot
.37973 .48306 Mdot
.07403 .4291 Mdot
.71122 .3938 Mdot
.47196 .47017 Mdot
.2104 .45638 Mdot
.82543 .38011 Mdot
.55375 .45013 Mdot
.32427 .4762 Mdot
.98107 .40593 Mdot
.65298 .41526 Mdot
.42928 .47978 Mdot
.15085 .44595 Mdot
.76901 .38205 Mdot
.51359 .46018 Mdot
.26903 .46689 Mdot
.89806 .38876 Mdot
.60317 .43579 Mdot
.38517 .4833 Mdot
.08306 .43132 Mdot
.71748 .39209 Mdot
.47658 .46915 Mdot
.217 .45761 Mdot
.83283 .3806 Mdot
.55913 .44887 Mdot
.33164 .47744 Mdot
.99322 .40888 Mdot
.66022 .41223 Mdot
.43482 .47873 Mdot
.15872 .44739 Mdot
.77567 .3813 Mdot
.51829 .45896 Mdot
.27551 .46799 Mdot
.90704 .39031 Mdot
.60878 .4337 Mdot
.39092 .48339 Mdot
.09248 .43359 Mdot
.72414 .39039 Mdot
.48146 .46805 Mdot
.22397 .4589 Mdot
.84086 .38126 Mdot
.56488 .44747 Mdot
.33938 .47867 Mdot
.00612 .41206 Mdot
.66796 .40904 Mdot
.44058 .47751 Mdot
.16676 .4488 Mdot
.78264 .38063 Mdot
.52317 .45767 Mdot
.28218 .46909 Mdot
.91645 .392 Mdot
.61454 .43144 Mdot
.39655 .48331 Mdot
.1015 .43569 Mdot
.73065 .38883 Mdot
.48618 .46694 Mdot
.23066 .46012 Mdot
.84876 .38201 Mdot
.57045 .44603 Mdot
.34667 .47973 Mdot
.01834 .41512 Mdot
.67537 .40607 Mdot
.44598 .47626 Mdot
.17421 .45007 Mdot
.78927 .38013 Mdot
.52781 .45644 Mdot
.28848 .47012 Mdot
.92552 .39372 Mdot
.62 .42921 Mdot
.40164 .48308 Mdot
.1095 .43748 Mdot
.73651 .38751 Mdot
.49039 .46592 Mdot
.23658 .46117 Mdot
.8559 .38276 Mdot
.57538 .44467 Mdot
.35294 .48056 Mdot
.0289 .41776 Mdot
.68186 .40355 Mdot
.45066 .47514 Mdot
.18061 .45113 Mdot
.79515 .37981 Mdot
.53192 .45535 Mdot
.29406 .47103 Mdot
.93372 .39533 Mdot
.62489 .42716 Mdot
.40602 .48277 Mdot
.11627 .43896 Mdot
.74155 .38645 Mdot
.49398 .46503 Mdot
.2416 .46205 Mdot
.86208 .38347 Mdot
.57959 .44345 Mdot
.35815 .48118 Mdot
.03766 .41996 Mdot
.68733 .40152 Mdot
.45458 .47418 Mdot
.18597 .45203 Mdot
.80021 .37962 Mdot
.53549 .45443 Mdot
.29893 .47183 Mdot
.94101 .39683 Mdot
.62921 .42533 Mdot
.40979 .48243 Mdot
.12201 .44018 Mdot
.74591 .38559 Mdot
.49708 .46425 Mdot
.24592 .46281 Mdot
.86748 .38414 Mdot
.58322 .44235 Mdot
.36255 .48165 Mdot
.04508 .42183 Mdot
.69203 .39984 Mdot
.45795 .47336 Mdot
.19062 .45282 Mdot
.80473 .37954 Mdot
.5387 .45362 Mdot
.30334 .47257 Mdot
.94773 .39826 Mdot
.63319 .42364 Mdot
.4132 .48207 Mdot
.12715 .44125 Mdot
.74987 .38486 Mdot
.4999 .46355 Mdot
.24987 .4635 Mdot
.8725 .38481 Mdot
.58657 .44132 Mdot
.36654 .48204 Mdot
.05181 .42352 Mdot
.69637 .39836 Mdot
.46108 .47262 Mdot
.19497 .45357 Mdot
.80907 .37954 Mdot
.54183 .45287 Mdot
.30766 .47331 Mdot
.95444 .39973 Mdot
.63717 .42195 Mdot
.41654 .48168 Mdot
.13216 .44228 Mdot
.7538 .38419 Mdot
.50272 .46286 Mdot
.25381 .4642 Mdot
.87762 .38553 Mdot
.58996 .44025 Mdot
.37051 .4824 Mdot
.05851 .42521 Mdot
.70076 .39693 Mdot
.46428 .47188 Mdot
.19946 .45437 Mdot
.81369 .37961 Mdot
.54518 .45209 Mdot
.31232 .47412 Mdot
.96179 .40139 Mdot
.64153 .4201 Mdot
.42015 .48121 Mdot
.13753 .44337 Mdot
.75808 .38352 Mdot
.50579 .46211 Mdot
.25813 .46497 Mdot
.88331 .38638 Mdot
.5937 .43905 Mdot
.3748 .48274 Mdot
.06575 .42703 Mdot
.70558 .39544 Mdot
.46782 .47109 Mdot
.20448 .45528 Mdot
.81899 .37979 Mdot
.54905 .4512 Mdot
.31773 .47507 Mdot
.97044 .4034 Mdot
0 .49443 Mdot
.8 .49443 Mdot
.72109 .56927 Mdot
.76741 .02863 Mdot
.9403 .10685 Mdot
.15983 .13568 Mdot
.27193 .06928 Mdot
.25792 .60937 Mdot
.11674 .53078 Mdot
.89032 .4781 Mdot
.74486 .52814 Mdot
.72666 .60679 Mdot
.83442 .0666 Mdot
.05201 .13448 Mdot
.22872 .10922 Mdot
.27925 .03123 Mdot
.20461 .5719 Mdot
.00778 .49639 Mdot
.80473 .49254 Mdot
.72155 .56663 Mdot
.76367 .02603 Mdot
.93264 .10443 Mdot
.15391 .13675 Mdot
.27036 .07197 Mdot
.26053 .61196 Mdot
.12365 .53344 Mdot
.89751 .47827 Mdot
.74781 .52551 Mdot
.72542 .6042 Mdot
.82884 .06392 Mdot
.04428 .13315 Mdot
.22475 .11154 Mdot
.27949 .03383 Mdot
.20909 .57452 Mdot
.01555 .49842 Mdot
.80959 .49074 Mdot
.72213 .56398 Mdot
.76004 .02343 Mdot
.92503 .10197 Mdot
.1478 .13768 Mdot
.2686 .07466 Mdot
.26296 .61454 Mdot
.13041 .53611 Mdot
.90482 .47861 Mdot
.75092 .52292 Mdot
.72434 .60161 Mdot
.82343 .06124 Mdot
.03654 .13171 Mdot
.22067 .1138 Mdot
.27963 .03644 Mdot
.21347 .57714 Mdot
.02333 .50052 Mdot
.81459 .48903 Mdot
.72283 .56133 Mdot
.75655 .02084 Mdot
.91748 .09946 Mdot
.14151 .13846 Mdot
.26667 .07735 Mdot
.2652 .61713 Mdot
.13699 .5388 Mdot
.91223 .47912 Mdot
.75418 .52035 Mdot
.7234 .59902 Mdot
.81818 .05858 Mdot
.02878 .13016 Mdot
.21648 .116 Mdot
.27967 .03905 Mdot
.21774 .57976 Mdot
.03109 .50268 Mdot
.81973 .48741 Mdot
.72367 .55866 Mdot
.75319 .01825 Mdot
.91001 .09692 Mdot
.13505 .13908 Mdot
.26455 .08004 Mdot
.26727 .00168 Mdot
.1434 .54148 Mdot
.91972 .47979 Mdot
.75758 .51782 Mdot
.72261 .59642 Mdot
.81308 .05592 Mdot
.02101 .12851 Mdot
.21218 .11815 Mdot
.2796 .04167 Mdot
.22189 .58237 Mdot
.03884 .5049 Mdot
.82503 .48589 Mdot
.72465 .55599 Mdot
.74998 .01566 Mdot
.90263 .09435 Mdot
.12841 .13954 Mdot
.26225 .08272 Mdot
.26915 .00426 Mdot
.14964 .54417 Mdot
.92729 .48062 Mdot
.76111 .51533 Mdot
.72194 .59383 Mdot
.80813 .05326 Mdot
.01324 .12677 Mdot
.20777 .12023 Mdot
.27943 .04429 Mdot
.22594 .58498 Mdot
.04658 .50718 Mdot
.83049 .48448 Mdot
.72577 .55332 Mdot
.74691 .01307 Mdot
.89536 .09174 Mdot
.12161 .13983 Mdot
.25977 .08539 Mdot
.27085 .00685 Mdot
.15569 .54686 Mdot
.93492 .48159 Mdot
.76477 .51288 Mdot
.7214 .59123 Mdot
.80331 .05062 Mdot
.00546 .12494 Mdot
.20325 .12224 Mdot
.27916 .04692 Mdot
.22989 .58758 Mdot
.0543 .50952 Mdot
.83611 .48319 Mdot
.72706 .55064 Mdot
.74402 .01048 Mdot
.8882 .08911 Mdot
.11465 .13995 Mdot
.25711 .08804 Mdot
.27237 .00943 Mdot
.16156 .54955 Mdot
.94259 .4827 Mdot
.76855 .51047 Mdot
.72098 .58863 Mdot
.79862 .04798 Mdot
.99768 .12303 Mdot
.1986 .12418 Mdot
.27878 .04955 Mdot
.23371 .59018 Mdot
.06199 .5119 Mdot
.84191 .48202 Mdot
.72852 .54795 Mdot
.74129 .00789 Mdot
.88119 .08646 Mdot
.10755 .1399 Mdot
.25428 .09068 Mdot
.27372 .01202 Mdot
.16726 .55223 Mdot
.95029 .48394 Mdot
.77245 .50812 Mdot
.72066 .58603 Mdot
.79405 .04535 Mdot
.98991 .12105 Mdot
.19384 .12604 Mdot
.27829 .05219 Mdot
.23742 .59278 Mdot
.06963 .51433 Mdot
.84789 .48099 Mdot
.73015 .54526 Mdot
.73873 .00531 Mdot
.87432 .0838 Mdot
.10033 .13968 Mdot
.25128 .0933 Mdot
.27492 .01461 Mdot
.17279 .55491 Mdot
.95802 .4853 Mdot
.77645 .50582 Mdot
.72045 .58342 Mdot
.78959 .04273 Mdot
.98213 .119 Mdot
.18894 .12781 Mdot
.27768 .05484 Mdot
.24101 .59537 Mdot
.07722 .51681 Mdot
.85405 .48011 Mdot
.73195 .54257 Mdot
.73636 .00272 Mdot
.86762 .08112 Mdot
.09299 .13929 Mdot
.24813 .09588 Mdot
.27595 .0172 Mdot
.17815 .55759 Mdot
.96577 .48678 Mdot
.78057 .50357 Mdot
.72035 .58082 Mdot
.78525 .04011 Mdot
.97436 .11688 Mdot
.1839 .1295 Mdot
.27693 .0575 Mdot
.24447 .59797 Mdot
.08475 .51932 Mdot
.86039 .47937 Mdot
.73394 .53988 Mdot
.73416 .00014 Mdot
.86108 .07844 Mdot
.08555 .13873 Mdot
.24483 .09844 Mdot
.27685 .01979 Mdot
.18335 .56025 Mdot
.97353 .48836 Mdot
.78479 .50138 Mdot
.72034 .5782 Mdot
.78101 .0375 Mdot
.9666 .1147 Mdot
.17871 .13109 Mdot
.27606 .06016 Mdot
.24778 .60056 Mdot
.0922 .52188 Mdot
.86691 .4788 Mdot
.73611 .5372 Mdot
.73216 .61559 Mdot
.85472 .07575 Mdot
.07803 .13801 Mdot
.24139 .10096 Mdot
.2776 .02238 Mdot
.18841 .56291 Mdot
.9813 .49004 Mdot
.78912 .49926 Mdot
.72044 .57558 Mdot
.77689 .03489 Mdot
.95885 .11246 Mdot
.17337 .13258 Mdot
.27503 .06284 Mdot
.25095 .60315 Mdot
.09955 .52446 Mdot
.8736 .47839 Mdot
.73847 .53452 Mdot
.73033 .613 Mdot
.84854 .07306 Mdot
.07044 .13714 Mdot
.23781 .10344 Mdot
.27823 .02498 Mdot
.19332 .56556 Mdot
.98908 .4918 Mdot
.79356 .4972 Mdot
.72064 .57296 Mdot
.77287 .03228 Mdot
.95112 .11016 Mdot
.16786 .13395 Mdot
.27386 .06551 Mdot
.25397 .60574 Mdot
.10679 .52707 Mdot
.88045 .47815 Mdot
.741 .53185 Mdot
.72868 .61042 Mdot
.84254 .07037 Mdot
.0628 .13613 Mdot
.23412 .10588 Mdot
.27874 .02758 Mdot
.1981 .5682 Mdot
.99685 .49366 Mdot
.79812 .49521 Mdot
.72094 .57033 Mdot
.76896 .02968 Mdot
.94341 .10781 Mdot
.16218 .13521 Mdot
.27252 .0682 Mdot
.25682 .60833 Mdot
.1139 .52971 Mdot
.88745 .47808 Mdot
.74372 .5292 Mdot
.72721 .60783 Mdot
.83672 .06768 Mdot
.05512 .13498 Mdot
.2303 .10827 Mdot
.27913 .03018 Mdot
.20276 .57083 Mdot
.00463 .49559 Mdot
.8028 .4933 Mdot
.72135 .5677 Mdot
.76517 .02708 Mdot
.93573 .10541 Mdot
.15632 .13633 Mdot
.27102 .07088 Mdot
.25949 .61091 Mdot
.12087 .53236 Mdot
.89459 .47818 Mdot
.7466 .52657 Mdot
.7259 .60524 Mdot
.83108 .065 Mdot
.04741 .1337 Mdot
.22637 .11061 Mdot
.27941 .03278 Mdot
.20729 .57346 Mdot
.01241 .49759 Mdot
.80761 .49146 Mdot
.72188 .56505 Mdot
.76149 .02448 Mdot
.9281 .10297 Mdot
.15029 .13732 Mdot
.26934 .07357 Mdot
.262 .6135 Mdot
.12769 .53503 Mdot
.90185 .47845 Mdot
.74964 .52396 Mdot
.72476 .60266 Mdot
.8256 .06232 Mdot
.03967 .1323 Mdot
.22233 .11289 Mdot
.27959 .03539 Mdot
.21171 .57609 Mdot
.02018 .49966 Mdot
.81255 .48971 Mdot
.72253 .5624 Mdot
.75795 .02189 Mdot
.92053 .10048 Mdot
.14408 .13816 Mdot
.26747 .07626 Mdot
.26432 .61608 Mdot
.13435 .53771 Mdot
.90922 .4789 Mdot
.75284 .52139 Mdot
.72376 .60006 Mdot
.82029 .05965 Mdot
.03192 .1308 Mdot
.21819 .11512 Mdot
.27966 .038 Mdot
.21602 .5787 Mdot
.02795 .5018 Mdot
.81763 .48805 Mdot
.72331 .55974 Mdot
.75453 .01929 Mdot
.91302 .09795 Mdot
.13768 .13885 Mdot
.26543 .07895 Mdot
.26645 .00063 Mdot
.14083 .5404 Mdot
.91668 .4795 Mdot
.75618 .51884 Mdot
.72291 .59747 Mdot
.81513 .05699 Mdot
.02415 .12919 Mdot
.21393 .11729 Mdot
.27964 .04061 Mdot
.22023 .58131 Mdot
.03571 .504 Mdot
.82287 .48649 Mdot
.72423 .55708 Mdot
.75126 .0167 Mdot
.9056 .09539 Mdot
.13112 .13937 Mdot
.2632 .08164 Mdot
.26841 .00322 Mdot
.14714 .54308 Mdot
.92422 .48027 Mdot
.75966 .51633 Mdot
.7222 .59488 Mdot
.81012 .05434 Mdot
.01638 .12748 Mdot
.20957 .11939 Mdot
.27951 .04323 Mdot
.22432 .58392 Mdot
.04346 .50625 Mdot
.82826 .48503 Mdot
.7253 .5544 Mdot
.74813 .01411 Mdot
.89828 .0928 Mdot
.12438 .13973 Mdot
.2608 .08431 Mdot
.27018 .0058 Mdot
.15326 .54578 Mdot
.93183 .48118 Mdot
.76328 .51386 Mdot
.72161 .59228 Mdot
.80524 .05169 Mdot
.00861 .12569 Mdot
.20509 .12143 Mdot
.27929 .04585 Mdot
.22831 .58653 Mdot
.05118 .50857 Mdot
.83382 .48369 Mdot
.72652 .55172 Mdot
.74517 .01152 Mdot
.89108 .09018 Mdot
.11748 .13993 Mdot
.25821 .08697 Mdot
.27177 .00839 Mdot
.15921 .54846 Mdot
.93948 .48223 Mdot
.76701 .51144 Mdot
.72114 .58968 Mdot
.8005 .04905 Mdot
.00083 .12381 Mdot
.2005 .1234 Mdot
.27895 .04849 Mdot
.23218 .58913 Mdot
.05888 .51093 Mdot
.83955 .48248 Mdot
.72791 .54904 Mdot
.74237 .00894 Mdot
.88401 .08754 Mdot
.11044 .13994 Mdot
.25544 .08962 Mdot
.2732 .01097 Mdot
.16498 .55115 Mdot
.94717 .48342 Mdot
.77086 .50907 Mdot
.72078 .58708 Mdot
.79588 .04642 Mdot
.99305 .12186 Mdot
.19578 .12529 Mdot
.2785 .05113 Mdot
.23594 .59173 Mdot
.06655 .51334 Mdot
.5 .49443 Mdot
.3 .49443 Mdot
.97891 .41959 Mdot
.67464 .42999 Mdot
.48369 .50002 Mdot
.27971 .49197 Mdot
.95062 .41464 Mdot
.6604 .43867 Mdot
.47786 .50522 Mdot
.27766 .49431 Mdot
.95206 .4168 Mdot
.66423 .44015 Mdot
.48568 .50768 Mdot
.2957 .50062 Mdot
.9836 .42515 Mdot
.6846 .43324 Mdot
.50232 .50538 Mdot
.3219 .50653 Mdot
.02694 .43573 Mdot
.71052 .42248 Mdot
.51754 .49876 Mdot
.33855 .50741 Mdot
.05144 .44059 Mdot
.72389 .4156 Mdot
.52196 .49323 Mdot
.33754 .50406 Mdot
.04457 .43697 Mdot
.71641 .41522 Mdot
.51275 .49216 Mdot
.31928 .49846 Mdot
.01036 .42711 Mdot
.69316 .42199 Mdot
.49524 .49572 Mdot
.29353 .49337 Mdot
.96922 .4176 Mdot
.66938 .43272 Mdot
.48088 .50153 Mdot
.27712 .4921 Mdot
.94788 .41455 Mdot
.65959 .43986 Mdot
.47864 .5062 Mdot
.28064 .49567 Mdot
.95767 .41843 Mdot
.66817 .43911 Mdot
.48953 .50763 Mdot
.30251 .50245 Mdot
.99505 .42801 Mdot
.69154 .43046 Mdot
.50686 .5039 Mdot
.32768 .50729 Mdot
.03603 .43779 Mdot
.71581 .42012 Mdot
.51998 .49701 Mdot
.34009 .50686 Mdot
.05275 .44044 Mdot
.72397 .41484 Mdot
.52082 .49248 Mdot
.33427 .50274 Mdot
.03783 .43483 Mdot
.71141 .4163 Mdot
.5086 .49269 Mdot
.31265 .49693 Mdot
.99912 .42426 Mdot
.68629 .4247 Mdot
.49073 .49717 Mdot
.28774 .49258 Mdot
.961 .4161 Mdot
.66515 .43519 Mdot
.47894 .50295 Mdot
.27595 .49257 Mdot
.94731 .41493 Mdot
.66006 .4405 Mdot
.48034 .50696 Mdot
.28494 .49727 Mdot
.96527 .42047 Mdot
.67316 .4375 Mdot
.49383 .5072 Mdot
.30955 .50415 Mdot
.00676 .4309 Mdot
.69857 .42756 Mdot
.5111 .50217 Mdot
.33251 .50766 Mdot
.04333 .43931 Mdot
.71991 .41815 Mdot
.52155 .49544 Mdot
.34037 .50606 Mdot
.05184 .43971 Mdot
.72257 .41453 Mdot
.51874 .49206 Mdot
.32987 .5013 Mdot
.02937 .43231 Mdot
.70551 .41788 Mdot
.50403 .49351 Mdot
.30577 .4955 Mdot
.98793 .4216 Mdot
.67973 .42756 Mdot
.48665 .4987 Mdot
.28291 .49211 Mdot
.95455 .4151 Mdot
.66206 .43727 Mdot
.47795 .50425 Mdot
.27625 .49338 Mdot
.94896 .41576 Mdot
.6618 .44056 Mdot
.48292 .50748 Mdot
.29039 .49905 Mdot
.97461 .42287 Mdot
.67906 .43537 Mdot
.4984 .50638 Mdot
.31645 .50558 Mdot
.01811 .43365 Mdot
.70532 .42472 Mdot
.51486 .50033 Mdot
.33628 .50766 Mdot
.04862 .44025 Mdot
.72267 .41659 Mdot
.52218 .49412 Mdot
.33936 .50505 Mdot
.04877 .43844 Mdot
.71977 .4147 Mdot
.51581 .49198 Mdot
.32446 .49978 Mdot
.01948 .42955 Mdot
.69895 .41994 Mdot
.49926 .49461 Mdot
.29896 .49425 Mdot
.97732 .41925 Mdot
.67376 .43042 Mdot
.4832 .50026 Mdot
.27922 .49197 Mdot
.95005 .4146 Mdot
.66019 .43889 Mdot
.47792 .50538 Mdot
.27803 .4945 Mdot
.9528 .41703 Mdot
.66477 .44002 Mdot
.48624 .5077 Mdot
.29673 .50091 Mdot
.98533 .42558 Mdot
.68566 .43282 Mdot
.50304 .50517 Mdot
.32285 .50667 Mdot
.02845 .43608 Mdot
.71141 .42209 Mdot
.51797 .49848 Mdot
.33887 .50735 Mdot
.05179 .44061 Mdot
.724 .41545 Mdot
.52185 .49309 Mdot
.33711 .50386 Mdot
.04365 .43667 Mdot
.71571 .41535 Mdot
.51214 .49222 Mdot
.31828 .49822 Mdot
.00864 .42666 Mdot
.69209 .42239 Mdot
.49452 .49593 Mdot
.29258 .49323 Mdot
.96784 .41733 Mdot
.66865 .43313 Mdot
.48052 .50176 Mdot
.27684 .49215 Mdot
.94764 .41458 Mdot
.65958 .44 Mdot
.47884 .50633 Mdot
.28122 .4959 Mdot
.95873 .41872 Mdot
.66888 .4389 Mdot
.49017 .50759 Mdot
.3036 .50273 Mdot
.99686 .42846 Mdot
.69263 .43001 Mdot
.50755 .50364 Mdot
.32849 .50737 Mdot
.03729 .43806 Mdot
.71653 .41979 Mdot
.52028 .49675 Mdot
.34022 .50675 Mdot
.05275 .44037 Mdot
.72385 .41476 Mdot
.52055 .49239 Mdot
.33366 .50253 Mdot
.03663 .43446 Mdot
.71055 .41651 Mdot
.50791 .49279 Mdot
.31159 .4967 Mdot
.99737 .42383 Mdot
.68525 .42513 Mdot
.49006 .4974 Mdot
.28693 .49249 Mdot
.95988 .41591 Mdot
.66459 .43554 Mdot
.47873 .50316 Mdot
.2759 .49268 Mdot
.94742 .41503 Mdot
.66025 .44055 Mdot
.48069 .50706 Mdot
.28571 .49753 Mdot
.96661 .42082 Mdot
.67402 .4372 Mdot
.49452 .5071 Mdot
.31064 .50439 Mdot
.00857 .43134 Mdot
.69964 .42711 Mdot
.51172 .50189 Mdot
.33317 .50768 Mdot
.04429 .43949 Mdot
.72043 .41788 Mdot
.52171 .49522 Mdot
.34029 .50591 Mdot
.0515 .43955 Mdot
.72222 .41453 Mdot
.51834 .49202 Mdot
.32909 .50107 Mdot
.02792 .4319 Mdot
.70452 .41817 Mdot
.50329 .49367 Mdot
.3047 .4953 Mdot
.98623 .42121 Mdot
.67876 .42801 Mdot
.48607 .49895 Mdot
.28226 .49207 Mdot
.95372 .41499 Mdot
.66169 .43755 Mdot
.47788 .50443 Mdot
.27643 .49353 Mdot
.94941 .41593 Mdot
.66219 .44052 Mdot
.48339 .50753 Mdot
.29132 .49933 Mdot
.9762 .42328 Mdot
.68005 .435 Mdot
.49912 .50621 Mdot
.31748 .50578 Mdot
.01979 .43405 Mdot
.70631 .42429 Mdot
.51539 .50004 Mdot
.33676 .50763 Mdot
.04926 .44035 Mdot
.72298 .41638 Mdot
.52219 .49394 Mdot
.33909 .50487 Mdot
.04811 .43819 Mdot
.71922 .41477 Mdot
.51528 .49199 Mdot
.32355 .49954 Mdot
.01785 .4291 Mdot
.6979 .42029 Mdot
.49851 .49481 Mdot
.29794 .49407 Mdot
.97577 .41892 Mdot
.67291 .43086 Mdot
.48273 .5005 Mdot
.27876 .49197 Mdot
.94954 .41456 Mdot
.66001 .4391 Mdot
.478 .50554 Mdot
.27844 .4947 Mdot
.95358 .41726 Mdot
.66534 .43989 Mdot
.48682 .5077 Mdot
.29777 .50119 Mdot
.98708 .42602 Mdot
.68672 .4324 Mdot
.50375 .50495 Mdot
.32379 .50681 Mdot
.02994 .43642 Mdot
.71228 .42171 Mdot
.51838 .4982 Mdot
.33916 .50727 Mdot
.05208 .44061 Mdot
.72408 .41531 Mdot
.52171 .49296 Mdot
.33665 .50366 Mdot
.04268 .43635 Mdot
.71497 .4155 Mdot
.51152 .49229 Mdot
.31727 .49798 Mdot
.0069 .42622 Mdot
.69102 .4228 Mdot
.49381 .49615 Mdot
.29165 .49309 Mdot
.96649 .41708 Mdot
.66795 .43352 Mdot
.48018 .50199 Mdot
.2766 .49221 Mdot
.94747 .41462 Mdot
.6596 .44012 Mdot
.47907 .50646 Mdot
.28184 .49614 Mdot
.95983 .41902 Mdot
.66961 .43867 Mdot
.49082 .50754 Mdot
.30469 .503 Mdot
.99868 .42891 Mdot
.69373 .42956 Mdot
.50822 .50338 Mdot
.32929 .50745 Mdot
.0385 .43832 Mdot
.71722 .41947 Mdot
.52056 .4965 Mdot
.34032 .50663 Mdot
.0527 .44028 Mdot
.72369 .41469 Mdot
.52027 .49231 Mdot
.33302 .50231 Mdot
.03538 .43408 Mdot
.70967 .41673 Mdot
.50721 .49291 Mdot
.31053 .49648 Mdot
.99562 .42341 Mdot
.68421 .42557 Mdot
.48941 .49764 Mdot
.28613 .4924 Mdot
.9588 .41573 Mdot
.66406 .43588 Mdot
.47853 .50337 Mdot
.27588 .49279 Mdot
.94759 .41514 Mdot
.66047 .44059 Mdot
.48105 .50715 Mdot
.28652 .4978 Mdot
.96799 .42118 Mdot
.6749 .43689 Mdot
.49522 .50699 Mdot
.31172 .50462 Mdot
.01036 .43178 Mdot
.70071 .42666 Mdot
.51233 .50161 Mdot
.3338 .5077 Mdot
.04519 .43967 Mdot
.72092 .41762 Mdot
.52184 .495 Mdot
.34019 .50577 Mdot
.05111 .43938 Mdot
.72185 .41454 Mdot
.51792 .492 Mdot
.32829 .50084 Mdot
.02643 .43148 Mdot
.70353 .41847 Mdot
.50256 .49383 Mdot
.30363 .49509 Mdot
.98455 .42083 Mdot
.6778 .42846 Mdot
.48551 .49919 Mdot
.28163 .49203 Mdot
.95294 .41489 Mdot
.66135 .43782 Mdot
.47784 .50462 Mdot
.27665 .49369 Mdot
.94992 .4161 Mdot
.6626 .44046 Mdot
.48388 .50758 Mdot
.29228 .49962 Mdot
.97782 .42369 Mdot
.68105 .43462 Mdot
.49984 .50604 Mdot
.3185 .50596 Mdot
.02145 .43445 Mdot
.70729 .42387 Mdot
.5159 .49975 Mdot
.33721 .5076 Mdot
.04984 .44043 Mdot
.72324 .41619 Mdot
.52218 .49377 Mdot
.33879 .5047 Mdot
.04739 .43794 Mdot
.71864 .41485 Mdot
.51474 .49202 Mdot
.32262 .4993 Mdot
.0162 .42866 Mdot
.69684 .42066 Mdot
.49777 .495 Mdot
.29692 .4939 Mdot
.97424 .41861 Mdot
.67208 .43129 Mdot
.48228 .50073 Mdot
.27833 .49199 Mdot
.94908 .41454 Mdot
.65987 .43929 Mdot
.4781 .5057 Mdot
.27888 .49491 Mdot
.95442 .41751 Mdot
.66593 .43974 Mdot
.48741 .5077 Mdot
.29882 .50148 Mdot
.98885 .42646 Mdot
.6878 .43197 Mdot
.50446 .50473 Mdot
.3247 .50693 Mdot
.03138 .43675 Mdot
.71312 .42134 Mdot
.51878 .49793 Mdot
.33943 .50719 Mdot
.05232 .4406 Mdot
.72411 .41519 Mdot
.52155 .49284 Mdot
.33616 .50346 Mdot
.04167 .43602 Mdot
.71421 .41566 Mdot
.51088 .49237 Mdot
0 .52533 Mdot
.85 .52533 Mdot
.80301 .58899 Mdot
.87634 .04532 Mdot
.03895 .10049 Mdot
.1707 .08143 Mdot
.19062 .01231 Mdot
.09197 .55706 Mdot
.92377 .51408 Mdot
.81425 .55035 Mdot
.82182 .00468 Mdot
.94397 .07549 Mdot
.11002 .10262 Mdot
.1949 .05246 Mdot
.16001 .59647 Mdot
.01761 .53003 Mdot
.86115 .52134 Mdot
.80221 .58161 Mdot
.8638 .03807 Mdot
.02153 .09748 Mdot
.16209 .08687 Mdot
.19426 .01988 Mdot
.10683 .564 Mdot
.94021 .51506 Mdot
.82031 .54393 Mdot
.81551 .61506 Mdot
.92739 .06915 Mdot
.09537 .10382 Mdot
.19154 .05943 Mdot
.16887 .60403 Mdot
.03507 .53534 Mdot
.87344 .51814 Mdot
.80272 .57432 Mdot
.8524 .0307 Mdot
.00394 .09366 Mdot
.15234 .09171 Mdot
.19664 .02738 Mdot
.1207 .5711 Mdot
.9572 .51698 Mdot
.82753 .53789 Mdot
.81037 .60743 Mdot
.91148 .06249 Mdot
.07982 .10404 Mdot
.18694 .06621 Mdot
.1766 .61164 Mdot
.05224 .54117 Mdot
.88683 .51581 Mdot
.80452 .56716 Mdot
.84213 .02325 Mdot
.98632 .08912 Mdot
.14144 .09587 Mdot
.19773 .03478 Mdot
.13349 .57833 Mdot
.97455 .5198 Mdot
.83588 .53233 Mdot
.80645 .59984 Mdot
.89641 .0556 Mdot
.06352 .10328 Mdot
.18115 .0727 Mdot
.18318 .00126 Mdot
.06895 .54743 Mdot
.90127 .5144 Mdot
.8076 .56014 Mdot
.83301 .0157 Mdot
.96881 .08393 Mdot
.12941 .09925 Mdot
.19751 .04209 Mdot
.14515 .58567 Mdot
.99211 .52345 Mdot
.84538 .52735 Mdot
.80378 .59233 Mdot
.88231 .04853 Mdot
.04664 .10156 Mdot
.17419 .07883 Mdot
.18859 .0089 Mdot
.08502 .55403 Mdot
.91663 .51396 Mdot
.81192 .55332 Mdot
.82503 .0081 Mdot
.95156 .0782 Mdot
.11626 .10178 Mdot
.196 .04928 Mdot
.15567 .59311 Mdot
.00974 .52784 Mdot
.85602 .52303 Mdot
.80241 .5849 Mdot
.86927 .04133 Mdot
.02935 .09894 Mdot
.16608 .0845 Mdot
.19278 .0165 Mdot
.1003 .56087 Mdot
.93278 .5145 Mdot
.81745 .54676 Mdot
.81819 .00045 Mdot
.93474 .07203 Mdot
.10205 .1034 Mdot
.1932 .05633 Mdot
.16505 .60064 Mdot
.02729 .53289 Mdot
.8678 .51947 Mdot
.80233 .57757 Mdot
.85736 .03401 Mdot
.01183 .09547 Mdot
.15684 .08962 Mdot
.19573 .02403 Mdot
.11462 .56791 Mdot
.94954 .51601 Mdot
.82416 .54054 Mdot
.81252 .61084 Mdot
.91851 .06551 Mdot
.08688 .10406 Mdot
.18915 .06321 Mdot
.17329 .60823 Mdot
.04461 .53851 Mdot
.88071 .51674 Mdot
.80355 .57035 Mdot
.84658 .02659 Mdot
.9942 .09123 Mdot
.14646 .0941 Mdot
.1974 .03148 Mdot
.12791 .57508 Mdot
.96675 .51844 Mdot
.832 .53476 Mdot
.80805 .60323 Mdot
.90304 .05871 Mdot
.07089 .10374 Mdot
.18389 .06983 Mdot
.18038 .61587 Mdot
.06154 .54459 Mdot
.89469 .51491 Mdot
.80607 .56326 Mdot
.83695 .01909 Mdot
.97663 .08632 Mdot
.13493 .09784 Mdot
.19777 .03883 Mdot
.14007 .58238 Mdot
.98424 .52172 Mdot
.84099 .5295 Mdot
.80482 .59568 Mdot
.88849 .05171 Mdot
.05425 .10244 Mdot
.17744 .07614 Mdot
.18632 .00548 Mdot
.07792 .55104 Mdot
.90965 .51404 Mdot
.80984 .55635 Mdot
.82846 .01151 Mdot
.95924 .08083 Mdot
.12228 .10076 Mdot
.19683 .04608 Mdot
.15111 .58977 Mdot
.00185 .52579 Mdot
.85112 .52487 Mdot
.80286 .58821 Mdot
.87497 .04457 Mdot
.03713 .10022 Mdot
.16985 .08203 Mdot
.19106 .01311 Mdot
.09357 .55778 Mdot
.92547 .51414 Mdot
.81483 .54966 Mdot
.82111 .00388 Mdot
.9422 .07484 Mdot
.10853 .1028 Mdot
.19461 .0532 Mdot
.16099 .59726 Mdot
.01945 .53056 Mdot
.86239 .52096 Mdot
.8022 .58084 Mdot
.86255 .0373 Mdot
.01969 .09712 Mdot
.16112 .08741 Mdot
.19457 .02067 Mdot
.10834 .56474 Mdot
.94198 .51522 Mdot
.82101 .54327 Mdot
.81491 .61426 Mdot
.92569 .06846 Mdot
.09378 .10389 Mdot
.19111 .06016 Mdot
.16974 .60483 Mdot
.03689 .53593 Mdot
.8748 .51785 Mdot
.80284 .57357 Mdot
.85126 .02992 Mdot
.00209 .09322 Mdot
.15125 .09218 Mdot
.19681 .02816 Mdot
.1221 .57186 Mdot
.95901 .51724 Mdot
.82835 .53728 Mdot
.8099 .60663 Mdot
.90986 .06178 Mdot
.07814 .104 Mdot
.18639 .0669 Mdot
.17735 .61245 Mdot
.05402 .54181 Mdot
.8883 .51561 Mdot
.80478 .56642 Mdot
.84112 .02246 Mdot
.98448 .0886 Mdot
.14023 .09626 Mdot
.19776 .03556 Mdot
.13477 .5791 Mdot
.97639 .52015 Mdot
.83683 .53178 Mdot
.80611 .59905 Mdot
.89488 .05486 Mdot
.06177 .10314 Mdot
.18047 .07336 Mdot
.18381 .00206 Mdot
.07067 .54811 Mdot
.90284 .51431 Mdot
.808 .55942 Mdot
.83212 .01491 Mdot
.96699 .08335 Mdot
.12808 .09956 Mdot
.19741 .04285 Mdot
.14631 .58645 Mdot
.99397 .52388 Mdot
.84645 .52686 Mdot
.80358 .59154 Mdot
.88089 .04778 Mdot
.04484 .10133 Mdot
.17339 .07945 Mdot
.18909 .0097 Mdot
.08667 .55474 Mdot
.91829 .51397 Mdot
.81245 .55262 Mdot
.82425 .00729 Mdot
.94977 .07758 Mdot
.11481 .102 Mdot
.19576 .05003 Mdot
.15671 .5939 Mdot
.01159 .52834 Mdot
.85721 .52262 Mdot
.80234 .58412 Mdot
.86797 .04056 Mdot
.02752 .09861 Mdot
.16517 .08507 Mdot
.19315 .0173 Mdot
.10185 .56161 Mdot
.93452 .51462 Mdot
.8181 .54609 Mdot
.81754 .61768 Mdot
.933 .07136 Mdot
.1005 .10352 Mdot
.19283 .05707 Mdot
.16597 .60143 Mdot
.02912 .53346 Mdot
.86911 .51914 Mdot
.8024 .5768 Mdot
.85617 .03324 Mdot
.00998 .09506 Mdot
.1558 .09013 Mdot
.19597 .02482 Mdot
.11607 .56866 Mdot
.95133 .51622 Mdot
.82493 .53991 Mdot
.81199 .61004 Mdot
.91684 .0648 Mdot
.08524 .10407 Mdot
.18865 .06391 Mdot
.17409 .60903 Mdot
.04641 .53912 Mdot
.88213 .5165 Mdot
.80376 .5696 Mdot
.84552 .02581 Mdot
.99235 .09075 Mdot
.1453 .09453 Mdot
.1975 .03226 Mdot
.12924 .57585 Mdot
.96858 .51874 Mdot
.83289 .53418 Mdot
.80765 .60243 Mdot
.90147 .05798 Mdot
.06917 .10365 Mdot
.18326 .07051 Mdot
.18106 .61667 Mdot
.06329 .54525 Mdot
.89622 .51477 Mdot
.8064 .56253 Mdot
.836 .01829 Mdot
.97479 .08577 Mdot
.13365 .09819 Mdot
.19773 .0396 Mdot
.14129 .58315 Mdot
.98609 .52211 Mdot
.842 .52898 Mdot
.80455 .59489 Mdot
.88702 .05097 Mdot
.05247 .10225 Mdot
.1767 .07678 Mdot
.18687 .00629 Mdot
.0796 .55174 Mdot
.91128 .514 Mdot
.81031 .55563 Mdot
.82763 .01071 Mdot
.95743 .08022 Mdot
.12088 .10102 Mdot
.19666 .04683 Mdot
.1522 .59056 Mdot
.00371 .52626 Mdot
.85225 .52443 Mdot
.80273 .58743 Mdot
.87361 .04381 Mdot
.03531 .09993 Mdot
.16899 .08262 Mdot
.19148 .0139 Mdot
.09517 .55851 Mdot
.92717 .51421 Mdot
.81543 .54897 Mdot
.8204 .00307 Mdot
.94044 .07419 Mdot
.10702 .10295 Mdot
.1943 .05394 Mdot
.16197 .59805 Mdot
.0213 .5311 Mdot
.86364 .5206 Mdot
.80221 .58007 Mdot
.86131 .03653 Mdot
.01784 .09674 Mdot
.16013 .08794 Mdot
.19486 .02146 Mdot
.10983 .56548 Mdot
.94375 .51539 Mdot
.82173 .54262 Mdot
.81433 .61346 Mdot
.92399 .06777 Mdot
.09217 .10394 Mdot
.19067 .06088 Mdot
.17059 .60562 Mdot
.03871 .53653 Mdot
.87617 .51757 Mdot
.80299 .57281 Mdot
.85014 .02914 Mdot
.00024 .09276 Mdot
.15014 .09265 Mdot
.19697 .02894 Mdot
.12348 .57261 Mdot
.96082 .5175 Mdot
.82919 .53668 Mdot
.80944 .60583 Mdot
.90824 .06106 Mdot
.07645 .10396 Mdot
.18582 .0676 Mdot
.17808 .61325 Mdot
.0558 .54246 Mdot
.88979 .51543 Mdot
.80506 .56567 Mdot
.84012 .02167 Mdot
.98263 .08808 Mdot
.13901 .09665 Mdot
.19779 .03633 Mdot
.13604 .57987 Mdot
.97823 .5205 Mdot
.83779 .53123 Mdot
.80578 .59826 Mdot
.89336 .05413 Mdot
.06001 .10299 Mdot
.17978 .07402 Mdot
.18442 .00287 Mdot
.07239 .5488 Mdot
.90442 .51423 Mdot
.80841 .55869 Mdot
.83124 .01411 Mdot
.96516 .08277 Mdot
.12673 .09986 Mdot
.1973 .04361 Mdot
.14746 .58723 Mdot
.99582 .52432 Mdot
.84752 .52638 Mdot
.80339 .59076 Mdot
.87948 .04703 Mdot
.04303 .10108 Mdot
.17258 .08006 Mdot
.18957 .0105 Mdot
.08831 .55545 Mdot
.91997 .51399 Mdot
.81299 .55192 Mdot
.82349 .00649 Mdot
.94799 .07694 Mdot
.11335 .1022 Mdot
.19551 .05078 Mdot
.15774 .59469 Mdot
.01344 .52885 Mdot
.8584 .52222 Mdot
.80228 .58335 Mdot
.86667 .0398 Mdot
.02568 .09827 Mdot
.16424 .08563 Mdot
.19351 .01809 Mdot
.10339 .56234 Mdot
.93626 .51474 Mdot
.81877 .54542 Mdot
.8169 .61688 Mdot
.93127 .07069 Mdot
.09893 .10362 Mdot
.19245 .0578 Mdot
.16687 .60223 Mdot
.03095 .53403 Mdot
.5 .52533 Mdot
.35 .52533 Mdot
.09699 .46167 Mdot
.77111 .41662 Mdot
.57143 .49462 Mdot
.42699 .52877 Mdot
.22616 .49392 Mdot
.89944 .41611 Mdot
.64792 .46259 Mdot
.49842 .52564 Mdot
.34765 .52486 Mdot
.09279 .46052 Mdot
.76782 .4172 Mdot
.56939 .49539 Mdot
.42473 .52863 Mdot
.22206 .49278 Mdot
.89403 .4153 Mdot
.64465 .46391 Mdot
.4957 .52598 Mdot
.34331 .52385 Mdot
.08486 .4583 Mdot
.76169 .41831 Mdot
.56551 .49678 Mdot
.42026 .52827 Mdot
.21385 .49047 Mdot
.88339 .4138 Mdot
.63809 .46643 Mdot
.48992 .52646 Mdot
.33369 .52148 Mdot
.06733 .45342 Mdot
.7487 .42111 Mdot
.55739 .4998 Mdot
.41101 .52756 Mdot
.19709 .48582 Mdot
.86281 .41144 Mdot
.62519 .47118 Mdot
.47771 .52689 Mdot
.31246 .5159 Mdot
.02957 .4432 Mdot
.72316 .42866 Mdot
.54226 .50623 Mdot
.39478 .52688 Mdot
.16912 .47857 Mdot
.83222 .40982 Mdot
.60604 .47824 Mdot
.45854 .52688 Mdot
.27825 .50661 Mdot
.97264 .42915 Mdot
.68881 .44262 Mdot
.523 .51556 Mdot
.37554 .5269 Mdot
.13835 .47144 Mdot
.8039 .41133 Mdot
.58955 .48555 Mdot
.44311 .52753 Mdot
.25212 .5 Mdot
.93381 .42131 Mdot
.66695 .4531 Mdot
.51046 .52132 Mdot
.36233 .52648 Mdot
.11729 .46659 Mdot
.78669 .41371 Mdot
.58004 .49032 Mdot
.43476 .52825 Mdot
.23873 .49688 Mdot
.9157 .41839 Mdot
.657 .45815 Mdot
.5045 .52378 Mdot
.35559 .52601 Mdot
.10637 .46401 Mdot
.77825 .41524 Mdot
.57545 .4927 Mdot
.43078 .52862 Mdot
.23245 .49546 Mdot
.90758 .41725 Mdot
.65256 .46042 Mdot
.50173 .52482 Mdot
.35229 .52567 Mdot
.10092 .46268 Mdot
.77412 .41606 Mdot
.57319 .49385 Mdot
.42876 .52877 Mdot
.22922 .49471 Mdot
.90345 .41669 Mdot
.65026 .46156 Mdot
.50021 .52529 Mdot
.35032 .5254 Mdot
.09757 .46183 Mdot
.77156 .41655 Mdot
.57171 .49452 Mdot
.42732 .52879 Mdot
.22677 .49409 Mdot
.90026 .41624 Mdot
.64842 .46239 Mdot
.49883 .52559 Mdot
.34831 .52501 Mdot
.09399 .46086 Mdot
.76878 .41704 Mdot
.57 .49518 Mdot
.42543 .52869 Mdot
.22338 .49315 Mdot
.89577 .41556 Mdot
.64571 .46349 Mdot
.49661 .52588 Mdot
.34481 .52421 Mdot
.0876 .45907 Mdot
.7638 .41791 Mdot
.56685 .49631 Mdot
.42181 .5284 Mdot
.21672 .49128 Mdot
.88707 .4143 Mdot
.64037 .46557 Mdot
.49197 .52632 Mdot
.33716 .52235 Mdot
.07363 .45517 Mdot
.75328 .42005 Mdot
.56023 .49872 Mdot
.41422 .52779 Mdot
.20285 .4874 Mdot
.86971 .41214 Mdot
.62954 .4696 Mdot
.48194 .52681 Mdot
.31992 .5179 Mdot
.04266 .44668 Mdot
.73168 .42584 Mdot
.54719 .50401 Mdot
.39989 .527 Mdot
.17768 .4807 Mdot
.84107 .41 Mdot
.6115 .47615 Mdot
.46401 .52688 Mdot
.28797 .50924 Mdot
.98821 .43277 Mdot
.69788 .4386 Mdot
.5281 .51311 Mdot
.38068 .52693 Mdot
.14651 .4733 Mdot
.81099 .41067 Mdot
.59356 .48366 Mdot
.44675 .5273 Mdot
.25812 .50146 Mdot
.94234 .42287 Mdot
.67168 .45076 Mdot
.51324 .52011 Mdot
.36538 .52665 Mdot
.12222 .46775 Mdot
.79061 .41309 Mdot
.5822 .48923 Mdot
.43667 .52809 Mdot
.24181 .4976 Mdot
.91979 .41901 Mdot
.65925 .45702 Mdot
.5059 .52326 Mdot
.35728 .52618 Mdot
.10917 .4647 Mdot
.78042 .41485 Mdot
.57667 .49211 Mdot
.43191 .52857 Mdot
.23433 .49592 Mdot
.91004 .41761 Mdot
.65395 .45976 Mdot
.50269 .52455 Mdot
.35358 .52588 Mdot
.10317 .46327 Mdot
.77588 .41576 Mdot
.57424 .49341 Mdot
.42986 .5288 Mdot
.23118 .49524 Mdot
.90606 .4171 Mdot
.6518 .4609 Mdot
.50139 .52508 Mdot
.3521 .52577 Mdot
.1008 .46272 Mdot
.77414 .41615 Mdot
.57334 .49394 Mdot
.42917 .52893 Mdot
.23018 .49505 Mdot
.90485 .41697 Mdot
.65119 .46126 Mdot
.50109 .52527 Mdot
.35187 .52581 Mdot
.10052 .46269 Mdot
.774 .41623 Mdot
.57336 .49403 Mdot
.42934 .52903 Mdot
.23064 .49523 Mdot
.90555 .41712 Mdot
.65167 .46112 Mdot
.50157 .52527 Mdot
.35272 .52604 Mdot
.10216 .46318 Mdot
.77537 .41607 Mdot
.57429 .49376 Mdot
.43051 .52917 Mdot
.23288 .49589 Mdot
.90867 .41766 Mdot
.65357 .46038 Mdot
.50314 .52506 Mdot
.35522 .52662 Mdot
.10681 .46451 Mdot
.77922 .41557 Mdot
.57681 .49294 Mdot
.4335 .52946 Mdot
.23852 .49753 Mdot
.91655 .41904 Mdot
.65832 .45844 Mdot
.50687 .52443 Mdot
.36091 .52783 Mdot
.11731 .46748 Mdot
.78814 .41459 Mdot
.58264 .49103 Mdot
.44034 .53008 Mdot
.25141 .50127 Mdot
.93517 .42258 Mdot
.66937 .45376 Mdot
.51489 .52257 Mdot
.37232 .52992 Mdot
.13821 .47335 Mdot
.80692 .41328 Mdot
.59489 .48699 Mdot
.45436 .53118 Mdot
.27781 .50892 Mdot
.97587 .43143 Mdot
.69317 .44331 Mdot
.52975 .51704 Mdot
.39 .53166 Mdot
.16909 .4815 Mdot
.83695 .41276 Mdot
.61361 .48 Mdot
.47363 .53152 Mdot
.31265 .51854 Mdot
.03408 .44587 Mdot
.72846 .42915 Mdot
.54899 .50712 Mdot
.4081 .53096 Mdot
.19772 .48801 Mdot
.86681 .41352 Mdot
.63045 .47195 Mdot
.48715 .52947 Mdot
.33359 .52313 Mdot
.06986 .45504 Mdot
.75202 .4216 Mdot
.5615 .50028 Mdot
.41895 .52994 Mdot
.21434 .49157 Mdot
.88558 .41485 Mdot
.64068 .46667 Mdot
.49422 .52752 Mdot
.34314 .52466 Mdot
.08593 .45907 Mdot
.76326 .41862 Mdot
.56748 .49703 Mdot
.42408 .52941 Mdot
.22222 .49328 Mdot
.89496 .41578 Mdot
.64577 .46403 Mdot
.49757 .52644 Mdot
.34741 .52523 Mdot
.09305 .46083 Mdot
.76842 .4174 Mdot
.57025 .49556 Mdot
.42649 .52918 Mdot
.22598 .49411 Mdot
.8996 .41632 Mdot
.64831 .46273 Mdot
.49924 .5259 Mdot
.34955 .52552 Mdot
.09665 .46173 Mdot
.77109 .41683 Mdot
.57174 .49483 Mdot
.42786 .52911 Mdot
.22823 .49465 Mdot
.90246 .4167 Mdot
.64993 .46196 Mdot
.50037 .5256 Mdot
.35111 .52579 Mdot
.09937 .46245 Mdot
.7732 .41645 Mdot
.573 .4943 Mdot
.42918 .52915 Mdot
.23055 .49527 Mdot
.90554 .41717 Mdot
.65174 .46118 Mdot
.50177 .52534 Mdot
.35321 .52622 Mdot
.10317 .4635 Mdot
.77625 .41599 Mdot
.57493 .49361 Mdot
.43137 .52931 Mdot
.2346 .49642 Mdot
.9111 .4181 Mdot
.65507 .4598 Mdot
.50439 .52491 Mdot
.35723 .52708 Mdot
.11055 .46558 Mdot
.78238 .41521 Mdot
.57891 .49228 Mdot
.436 .52971 Mdot
.24327 .49892 Mdot
.92333 .4203 Mdot
.66238 .45676 Mdot
.50994 .52382 Mdot
.36545 .52873 Mdot
.12568 .46985 Mdot
.7955 .41397 Mdot
.58748 .48947 Mdot
.44596 .53057 Mdot
.26204 .50437 Mdot
.95116 .4259 Mdot
.67874 .44967 Mdot
.5211 .5206 Mdot
.38028 .531 Mdot
.15247 .47724 Mdot
.8205 .41287 Mdot
.60357 .48396 Mdot
.46377 .53163 Mdot
.29522 .51387 Mdot
.00447 .43834 Mdot
.71013 .43613 Mdot
.53915 .51236 Mdot
.39918 .53153 Mdot
.18384 .48495 Mdot
.85202 .41296 Mdot
.62225 .47603 Mdot
.48094 .5307 Mdot
.32442 .5213 Mdot
.05423 .45105 Mdot
.7415 .42475 Mdot
.55591 .50333 Mdot
.41413 .53041 Mdot
.20694 .48998 Mdot
.87706 .41416 Mdot
.63604 .46907 Mdot
.49107 .52844 Mdot
.33896 .52402 Mdot
.0789 .45731 Mdot
.75827 .41988 Mdot
.5648 .49846 Mdot
.42175 .52962 Mdot
.2186 .49248 Mdot
.89059 .41531 Mdot
.64337 .46525 Mdot
.49596 .52693 Mdot
.34533 .52493 Mdot
.08953 .45994 Mdot
.76582 .41798 Mdot
.56882 .49628 Mdot
.42516 .52925 Mdot
.22382 .4936 Mdot
.89688 .41597 Mdot
.64678 .46346 Mdot
.49815 .52618 Mdot
.34803 .52526 Mdot
.094 .46103 Mdot
.76906 .41721 Mdot
.57053 .49534 Mdot
.42661 .52908 Mdot
.22602 .49407 Mdot
.89955 .41627 Mdot
.64821 .4627 Mdot
.49904 .52584 Mdot
.34909 .52536 Mdot
.09571 .46144 Mdot
.77029 .41692 Mdot
.57117 .49497 Mdot
.4271 .52899 Mdot
.22672 .49419 Mdot
.90038 .41634 Mdot
.64863 .46245 Mdot
.49925 .52571 Mdot
.34926 .52534 Mdot
.09591 .46146 Mdot
.7704 .41686 Mdot
.57116 .4949 Mdot
.42698 .52893 Mdot
.22642 .49408 Mdot
.89992 .41625 Mdot
.64832 .46253 Mdot
.49892 .5257 Mdot
.34866 .52517 Mdot
.09477 .46112 Mdot
.76946 .41698 Mdot
.57053 .49509 Mdot
.42619 .52883 Mdot
.2249 .49363 Mdot
.89786 .41591 Mdot
.64704 .46302 Mdot
.49782 .52581 Mdot
.34686 .52473 Mdot
.09143 .46017 Mdot
.76682 .41741 Mdot
.56881 .49566 Mdot
.42417 .52864 Mdot
.22112 .49254 Mdot
.89284 .41515 Mdot
.64396 .46422 Mdot
.49516 .52608 Mdot
.3425 .52368 Mdot
.08343 .45792 Mdot
.76062 .41853 Mdot
.56486 .49705 Mdot
0 .55623 Mdot
.9 .55623 Mdot
.87484 .60248 Mdot
.9398 .04015 Mdot
.05178 .06921 Mdot
.12306 .04405 Mdot
.10542 .60713 Mdot
.00947 .55873 Mdot
.90595 .55406 Mdot
.87337 .5979 Mdot
.93174 .03607 Mdot
.04306 .0688 Mdot
.12035 .04777 Mdot
.11028 .61181 Mdot
.01888 .56154 Mdot
.91241 .55223 Mdot
.87253 .59339 Mdot
.92407 .03185 Mdot
.03407 .06799 Mdot
.11703 .05127 Mdot
.11457 .61652 Mdot
.02817 .56464 Mdot
.91935 .55078 Mdot
.87232 .58897 Mdot
.91683 .02751 Mdot
.02488 .06678 Mdot
.11311 .05453 Mdot
.11828 .00319 Mdot
.0373 .56798 Mdot
.92675 .54971 Mdot
.87275 .58466 Mdot
.91005 .02305 Mdot
.01554 .06519 Mdot
.10861 .05752 Mdot
.12139 .00789 Mdot
.04619 .57156 Mdot
.93456 .54904 Mdot
.87382 .58049 Mdot
.90377 .01851 Mdot
.0061 .06324 Mdot
.10355 .06023 Mdot
.12388 .01256 Mdot
.05481 .57535 Mdot
.94276 .54878 Mdot
.87551 .57647 Mdot
.89801 .0139 Mdot
.99663 .06095 Mdot
.09794 .06262 Mdot
.12576 .01719 Mdot
.06311 .57932 Mdot
.95129 .54892 Mdot
.87783 .57263 Mdot
.89279 .00924 Mdot
.98717 .05833 Mdot
.09181 .06467 Mdot
.127 .02175 Mdot
.07104 .58345 Mdot
.96011 .54948 Mdot
.88076 .56899 Mdot
.88813 .00455 Mdot
.9778 .05542 Mdot
.08517 .06636 Mdot
.12762 .02623 Mdot
.07856 .58772 Mdot
.96918 .55043 Mdot
.8843 .56558 Mdot
.88404 .61787 Mdot
.96856 .05223 Mdot
.07807 .06768 Mdot
.1276 .03061 Mdot
.08564 .5921 Mdot
.97843 .55177 Mdot
.88842 .56241 Mdot
.88055 .61317 Mdot
.95951 .0488 Mdot
.07052 .06861 Mdot
.12694 .03487 Mdot
.09224 .59659 Mdot
.98781 .55349 Mdot
.89312 .55951 Mdot
.87766 .60847 Mdot
.9507 .04515 Mdot
.06256 .06913 Mdot
.12565 .03899 Mdot
.09834 .60115 Mdot
.99727 .55557 Mdot
.89838 .55692 Mdot
.87538 .60382 Mdot
.94219 .04129 Mdot
.05424 .06925 Mdot
.12373 .04295 Mdot
.10391 .60578 Mdot
.00674 .55798 Mdot
.90418 .55465 Mdot
.87373 .59921 Mdot
.93402 .03726 Mdot
.0456 .06896 Mdot
.1212 .04672 Mdot
.10894 .61046 Mdot
.01618 .5607 Mdot
.9105 .55272 Mdot
.87271 .59468 Mdot
.92623 .03308 Mdot
.03669 .06826 Mdot
.11805 .05028 Mdot
.1134 .61516 Mdot
.02551 .56372 Mdot
.9173 .55116 Mdot
.87232 .59023 Mdot
.91887 .02877 Mdot
.02755 .06717 Mdot
.1143 .05362 Mdot
.11727 .00184 Mdot
.03469 .56699 Mdot
.92457 .54998 Mdot
.87257 .58589 Mdot
.91196 .02435 Mdot
.01825 .06569 Mdot
.10997 .05669 Mdot
.12055 .00654 Mdot
.04366 .57051 Mdot
.93227 .54919 Mdot
.87345 .58168 Mdot
.90553 .01983 Mdot
.00883 .06384 Mdot
.10507 .05948 Mdot
.12323 .01122 Mdot
.05236 .57424 Mdot
.94036 .54881 Mdot
.87496 .57762 Mdot
.89962 .01524 Mdot
.99936 .06164 Mdot
.09961 .06196 Mdot
.12528 .01586 Mdot
.06076 .57816 Mdot
.9488 .54884 Mdot
.8771 .57372 Mdot
.89424 .01059 Mdot
.98989 .05912 Mdot
.09363 .06411 Mdot
.12671 .02044 Mdot
.06879 .58224 Mdot
.95754 .54928 Mdot
.87986 .57002 Mdot
.88941 .00591 Mdot
.98049 .05629 Mdot
.08714 .06591 Mdot
.12751 .02495 Mdot
.07644 .58647 Mdot
.96654 .55012 Mdot
.88322 .56654 Mdot
.88516 .0012 Mdot
.9712 .05318 Mdot
.08016 .06734 Mdot
.12767 .02936 Mdot
.08364 .59083 Mdot
.97574 .55135 Mdot
.88717 .56329 Mdot
.88149 .61452 Mdot
.96209 .04982 Mdot
.07274 .06838 Mdot
.12719 .03366 Mdot
.09039 .59529 Mdot
.9851 .55296 Mdot
.89171 .56032 Mdot
.87843 .60982 Mdot
.95321 .04622 Mdot
.06489 .06902 Mdot
.12609 .03782 Mdot
.09663 .59983 Mdot
.99454 .55494 Mdot
.89681 .55764 Mdot
.87597 .60516 Mdot
.94461 .04242 Mdot
.05668 .06926 Mdot
.12435 .04182 Mdot
.10236 .60444 Mdot
.00401 .55725 Mdot
.90246 .55527 Mdot
.87414 .60053 Mdot
.93634 .03844 Mdot
.04812 .06908 Mdot
.12199 .04565 Mdot
.10754 .60911 Mdot
.01346 .55989 Mdot
.90862 .55324 Mdot
.87294 .59598 Mdot
.92844 .0343 Mdot
.03928 .0685 Mdot
.11902 .04928 Mdot
.11217 .6138 Mdot
.02283 .56282 Mdot
.91529 .55157 Mdot
.87236 .5915 Mdot
.92095 .03003 Mdot
.0302 .06752 Mdot
.11544 .05268 Mdot
.11621 .00048 Mdot
.03206 .56602 Mdot
.92243 .55028 Mdot
.87243 .58713 Mdot
.9139 .02563 Mdot
.02094 .06615 Mdot
.11128 .05583 Mdot
.11967 .00519 Mdot
.04109 .56947 Mdot
.93001 .54938 Mdot
.87313 .58288 Mdot
.90733 .02114 Mdot
.01155 .06441 Mdot
.10654 .0587 Mdot
.12252 .00988 Mdot
.04988 .57314 Mdot
.93799 .54888 Mdot
.87446 .57877 Mdot
.90127 .01657 Mdot
.00209 .06231 Mdot
.10124 .06128 Mdot
.12475 .01453 Mdot
.05837 .57701 Mdot
.94633 .54879 Mdot
.87642 .57483 Mdot
.89573 .01194 Mdot
.99262 .05988 Mdot
.09541 .06353 Mdot
.12636 .01913 Mdot
.06652 .58105 Mdot
.95499 .54911 Mdot
.879 .57107 Mdot
.89074 .00726 Mdot
.98319 .05713 Mdot
.08906 .06543 Mdot
.12734 .02366 Mdot
.07428 .58524 Mdot
.96393 .54983 Mdot
.88219 .56752 Mdot
.88632 .00256 Mdot
.97387 .0541 Mdot
.08222 .06697 Mdot
.12769 .0281 Mdot
.08161 .58956 Mdot
.97307 .55095 Mdot
.88597 .5642 Mdot
.88249 .61588 Mdot
.9647 .05081 Mdot
.07492 .06812 Mdot
.12739 .03243 Mdot
.08849 .59399 Mdot
.98239 .55246 Mdot
.89034 .56115 Mdot
.87925 .61118 Mdot
.95575 .04728 Mdot
.0672 .06888 Mdot
.12647 .03663 Mdot
.09488 .59851 Mdot
.99181 .55433 Mdot
.89528 .55838 Mdot
.87662 .6065 Mdot
.94706 .04354 Mdot
.05908 .06923 Mdot
.12491 .04069 Mdot
.10076 .60311 Mdot
.00128 .55655 Mdot
.90077 .55592 Mdot
.8746 .60186 Mdot
.93869 .03961 Mdot
.05062 .06918 Mdot
.12273 .04457 Mdot
.10611 .60776 Mdot
.01075 .5591 Mdot
.90679 .55379 Mdot
.87322 .59728 Mdot
.93068 .03551 Mdot
.04186 .06871 Mdot
.11994 .04826 Mdot
.11089 .61245 Mdot
.02014 .56195 Mdot
.91332 .55201 Mdot
.87246 .59278 Mdot
.92306 .03127 Mdot
.03284 .06785 Mdot
.11653 .05172 Mdot
.11511 .61715 Mdot
.02942 .56507 Mdot
.92033 .55061 Mdot
.87234 .58838 Mdot
.91588 .02691 Mdot
.02363 .06659 Mdot
.11254 .05495 Mdot
.11873 .00383 Mdot
.03851 .56845 Mdot
.92778 .5496 Mdot
.87286 .58409 Mdot
.90918 .02244 Mdot
.01427 .06495 Mdot
.10796 .05791 Mdot
.12176 .00853 Mdot
.04738 .57206 Mdot
.93565 .54898 Mdot
.87401 .57994 Mdot
.90296 .01789 Mdot
.00482 .06295 Mdot
.10282 .06057 Mdot
.12417 .01319 Mdot
.05596 .57587 Mdot
.94389 .54877 Mdot
.87579 .57594 Mdot
.89727 .01328 Mdot
.99535 .06061 Mdot
.09714 .06291 Mdot
.12596 .01781 Mdot
.06421 .57987 Mdot
.95247 .54898 Mdot
.87819 .57213 Mdot
.89212 .00861 Mdot
.9859 .05796 Mdot
.09094 .06492 Mdot
.12712 .02236 Mdot
.07208 .58402 Mdot
.96133 .54958 Mdot
.88121 .56852 Mdot
.88754 .00391 Mdot
.97654 .055 Mdot
.08424 .06656 Mdot
.12765 .02683 Mdot
.07954 .5883 Mdot
.97042 .55059 Mdot
.88482 .56513 Mdot
.88353 .61724 Mdot
.96732 .05178 Mdot
.07707 .06783 Mdot
.12754 .03119 Mdot
.08656 .5927 Mdot
.97969 .55199 Mdot
.88903 .562 Mdot
.88012 .61253 Mdot
.9583 .04832 Mdot
.06946 .0687 Mdot
.1268 .03544 Mdot
.09309 .5972 Mdot
.98909 .55375 Mdot
.8938 .55915 Mdot
.87731 .60784 Mdot
.94954 .04464 Mdot
.06146 .06917 Mdot
.12543 .03954 Mdot
.09912 .60178 Mdot
.99855 .55588 Mdot
.89914 .55659 Mdot
.87512 .60319 Mdot
.94107 .04076 Mdot
.05309 .06923 Mdot
.12343 .04347 Mdot
.10462 .60641 Mdot
.00802 .55833 Mdot
.90501 .55437 Mdot
.87355 .5986 Mdot
.93295 .03671 Mdot
.04441 .06889 Mdot
.12081 .04721 Mdot
.10957 .61109 Mdot
.01744 .5611 Mdot
.91139 .55249 Mdot
.87262 .59407 Mdot
.92521 .03251 Mdot
.03546 .06814 Mdot
.11758 .05075 Mdot
.11395 .6158 Mdot
.02676 .56415 Mdot
.91826 .55098 Mdot
.87231 .58964 Mdot
.91791 .02818 Mdot
.0263 .06699 Mdot
.11375 .05405 Mdot
.11775 .00247 Mdot
.03591 .56746 Mdot
.92559 .54985 Mdot
.87265 .58531 Mdot
.91106 .02374 Mdot
.01698 .06546 Mdot
.10934 .05708 Mdot
.12095 .00718 Mdot
.04485 .571 Mdot
.93334 .54912 Mdot
.87362 .58112 Mdot
.9047 .01921 Mdot
.00755 .06356 Mdot
.10436 .05983 Mdot
.12354 .01185 Mdot
.05352 .57476 Mdot
.94148 .54879 Mdot
.87521 .57708 Mdot
.89886 .01461 Mdot
.99808 .06132 Mdot
.09884 .06227 Mdot
.12551 .01649 Mdot
.06186 .5787 Mdot
.94996 .54888 Mdot
.87744 .57321 Mdot
.89355 .00996 Mdot
.98862 .05875 Mdot
.5 .55623 Mdot
.4 .55623 Mdot
.22516 .50998 Mdot
.92455 .43224 Mdot
.68206 .46817 Mdot
.55547 .5398 Mdot
.47236 .56667 Mdot
.36724 .55307 Mdot
.16782 .49478 Mdot
.85767 .42635 Mdot
.64681 .48771 Mdot
.53742 .55043 Mdot
.45771 .56877 Mdot
.34455 .5481 Mdot
.12588 .48289 Mdot
.81668 .42694 Mdot
.6238 .49882 Mdot
.52026 .55405 Mdot
.43289 .56404 Mdot
.29342 .53183 Mdot
.03133 .45605 Mdot
.74434 .44066 Mdot
.58459 .5193 Mdot
.48937 .55919 Mdot
.38565 .55393 Mdot
.19812 .50213 Mdot
.88997 .42759 Mdot
.663 .47776 Mdot
.5448 .54498 Mdot
.46196 .56684 Mdot
.34899 .54821 Mdot
.13253 .48426 Mdot
.82188 .42604 Mdot
.62579 .49684 Mdot
.52018 .55276 Mdot
.43068 .56272 Mdot
.28745 .52952 Mdot
.02041 .45299 Mdot
.73708 .44293 Mdot
.58067 .52136 Mdot
.48605 .55956 Mdot
.38029 .55267 Mdot
.18754 .49891 Mdot
.87714 .4262 Mdot
.65556 .48109 Mdot
.53953 .54633 Mdot
.45481 .56567 Mdot
.33442 .54363 Mdot
.10421 .47575 Mdot
.79646 .42783 Mdot
.61064 .5032 Mdot
.50638 .5536 Mdot
.40723 .55675 Mdot
.23799 .51344 Mdot
.94179 .43497 Mdot
.69113 .46311 Mdot
.55917 .53648 Mdot
.47348 .56507 Mdot
.36666 .55202 Mdot
.16523 .49354 Mdot
.85411 .42575 Mdot
.64403 .4882 Mdot
.53407 .55008 Mdot
.45117 .5668 Mdot
.32982 .54303 Mdot
.09682 .47403 Mdot
.79105 .42906 Mdot
.6084 .50515 Mdot
.50592 .5547 Mdot
.40817 .55762 Mdot
.24096 .51469 Mdot
.94663 .43613 Mdot
.6942 .46203 Mdot
.56135 .53593 Mdot
.47638 .56552 Mdot
.37259 .55389 Mdot
.17741 .49741 Mdot
.86793 .42676 Mdot
.65238 .48482 Mdot
.54095 .54917 Mdot
.46193 .56919 Mdot
.35273 .55055 Mdot
.14183 .48769 Mdot
.83189 .42648 Mdot
.6328 .49499 Mdot
.52803 .55329 Mdot
.44558 .56707 Mdot
.32043 .54069 Mdot
.08022 .46958 Mdot
.77852 .43157 Mdot
.6021 .509 Mdot
.50188 .55609 Mdot
.40316 .55702 Mdot
.23166 .51204 Mdot
.93369 .43387 Mdot
.68724 .46572 Mdot
.55834 .53837 Mdot
.47508 .56658 Mdot
.37196 .5543 Mdot
.17712 .49761 Mdot
.86806 .42703 Mdot
.65288 .48504 Mdot
.54204 .54953 Mdot
.46444 .57008 Mdot
.35863 .55264 Mdot
.15401 .49158 Mdot
.84454 .42677 Mdot
.64058 .49198 Mdot
.53502 .55279 Mdot
.45724 .56997 Mdot
.34567 .54908 Mdot
.12909 .48418 Mdot
.8202 .42713 Mdot
.62644 .49829 Mdot
.52353 .55443 Mdot
.43938 .56602 Mdot
.3079 .53677 Mdot
.05742 .46323 Mdot
.762 .43545 Mdot
.59354 .51392 Mdot
.49568 .55755 Mdot
.39435 .55541 Mdot
.21458 .50693 Mdot
.91063 .43018 Mdot
.67447 .47208 Mdot
.55157 .54208 Mdot
.46921 .56713 Mdot
.36237 .552 Mdot
.15864 .49212 Mdot
.848 .42605 Mdot
.6413 .49028 Mdot
.53335 .55132 Mdot
.4519 .56769 Mdot
.33255 .54427 Mdot
.10262 .47593 Mdot
.79616 .42864 Mdot
.61172 .50404 Mdot
.50948 .55485 Mdot
.41483 .55953 Mdot
.25524 .5194 Mdot
.96839 .44075 Mdot
.70667 .45628 Mdot
.56758 .53207 Mdot
.48094 .56449 Mdot
.3791 .55509 Mdot
.18957 .5009 Mdot
.88178 .42781 Mdot
.66011 .48103 Mdot
.54599 .5475 Mdot
.46816 .56993 Mdot
.36501 .55429 Mdot
.16637 .49527 Mdot
.85758 .42719 Mdot
.64812 .48858 Mdot
.54077 .55169 Mdot
.46569 .57163 Mdot
.36336 .55479 Mdot
.16467 .49524 Mdot
.85652 .42759 Mdot
.64823 .4893 Mdot
.5421 .55244 Mdot
.46926 .57301 Mdot
.37197 .55791 Mdot
.18296 .50122 Mdot
.87775 .42941 Mdot
.661 .48408 Mdot
.55219 .55078 Mdot
.48439 .57613 Mdot
.40412 .56842 Mdot
.2517 .52383 Mdot
.97196 .44515 Mdot
.71454 .45894 Mdot
.58129 .53568 Mdot
.51029 .57415 Mdot
.44752 .57924 Mdot
.34353 .55376 Mdot
.13356 .48827 Mdot
.82886 .42972 Mdot
.63616 .49894 Mdot
.53959 .55835 Mdot
.47437 .57772 Mdot
.38872 .5651 Mdot
.22114 .51446 Mdot
.92832 .43706 Mdot
.69092 .47132 Mdot
.57218 .54465 Mdot
.50922 .57912 Mdot
.45364 .58368 Mdot
.36149 .56108 Mdot
.172 .50092 Mdot
.87017 .43149 Mdot
.66107 .4888 Mdot
.55992 .55552 Mdot
.50558 .58445 Mdot
.4557 .58721 Mdot
.37084 .56559 Mdot
.19363 .50851 Mdot
.89699 .4347 Mdot
.67713 .48215 Mdot
.57148 .55274 Mdot
.52111 .5869 Mdot
.48757 .59731 Mdot
.4441 .59117 Mdot
.35683 .5641 Mdot
.16985 .50248 Mdot
.87136 .43355 Mdot
.66493 .49046 Mdot
.56807 .55817 Mdot
.52402 .59081 Mdot
.49912 .60264 Mdot
.47351 .60221 Mdot
.42681 .58917 Mdot
.3236 .55425 Mdot
.10644 .48382 Mdot
.81034 .43503 Mdot
.63252 .50813 Mdot
.54887 .56634 Mdot
.50372 .59013 Mdot
.46154 .59196 Mdot
.38888 .57313 Mdot
.23438 .52255 Mdot
.95317 .44424 Mdot
.70889 .46706 Mdot
.5877 .54314 Mdot
.53317 .58433 Mdot
.50499 .60062 Mdot
.4808 .60308 Mdot
.44128 .59361 Mdot
.35584 .56523 Mdot
.1702 .50331 Mdot
.87292 .4343 Mdot
.66683 .49067 Mdot
.57108 .55886 Mdot
.53032 .59284 Mdot
.51367 .60774 Mdot
.50795 .6145 Mdot
.50857 .00039 Mdot
.51606 .00463 Mdot
.53637 .01255 Mdot
.58552 .03038 Mdot
.69983 .07065 Mdot
.9352 .14547 Mdot
.22099 .17663 Mdot
.38156 .09924 Mdot
.45589 .04594 Mdot
.49538 .0244 Mdot
.53116 .02212 Mdot
.59173 .03743 Mdot
.72168 .08031 Mdot
.97694 .15776 Mdot
.25058 .16912 Mdot
.39691 .09043 Mdot
.46641 .04295 Mdot
.50923 .02647 Mdot
.55943 .03103 Mdot
.65608 .05973 Mdot
.85853 .12512 Mdot
.15982 .18621 Mdot
.35369 .11982 Mdot
.44631 .05724 Mdot
.4968 .0312 Mdot
.54472 .02962 Mdot
.62796 .05144 Mdot
.80288 .10811 Mdot
.09816 .1825 Mdot
.3198 .13698 Mdot
.42617 .06574 Mdot
.47556 .03053 Mdot
.50547 .01849 Mdot
.53976 .02119 Mdot
.60554 .04065 Mdot
.74969 .08909 Mdot
.02117 .16778 Mdot
.27576 .15735 Mdot
.40469 .07968 Mdot
.46185 .03533 Mdot
.48879 .01665 Mdot
.50676 .01111 Mdot
.53014 .01445 Mdot
.57748 .02926 Mdot
.68439 .06607 Mdot
.90796 .13817 Mdot
.20112 .18119 Mdot
.37292 .10618 Mdot
.45352 .04981 Mdot
.49745 .02715 Mdot
.53936 .0259 Mdot
.61242 .04516 Mdot
.76813 .09623 Mdot
.05034 .17441 Mdot
.29294 .14994 Mdot
.41283 .07409 Mdot
.46642 .03312 Mdot
.49334 .01664 Mdot
.51493 .01334 Mdot
.54845 .02072 Mdot
.62013 .0443 Mdot
.77905 .09822 Mdot
.06317 .1756 Mdot
.29808 .14518 Mdot
.41142 .07005 Mdot
.45751 .02848 Mdot
.47 .00772 Mdot
.45864 .61101 Mdot
.41457 .59079 Mdot
.30538 .55055 Mdot
.07651 .47658 Mdot
.78876 .44019 Mdot
.62457 .51656 Mdot
.55017 .57205 Mdot
.51525 .59645 Mdot
.49252 .60398 Mdot
.4638 .60029 Mdot
.40638 .58254 Mdot
.27831 .53888 Mdot
.02492 .46143 Mdot
.75167 .44916 Mdot
.60575 .52785 Mdot
.53834 .57637 Mdot
.5013 .59514 Mdot
.46529 .59578 Mdot
.40174 .57876 Mdot
.26449 .53321 Mdot
.00044 .45484 Mdot
.73604 .45463 Mdot
.59847 .53301 Mdot
.53475 .57865 Mdot
.4986 .59569 Mdot
.46133 .595 Mdot
.39343 .57607 Mdot
.24651 .52723 Mdot
.97229 .44856 Mdot
.72013 .46219 Mdot
.59306 .5395 Mdot
.53626 .58293 Mdot
.50821 .6007 Mdot
.48673 .60476 Mdot
.45465 .59821 Mdot
.38678 .57609 Mdot
.23579 .52471 Mdot
.95797 .44634 Mdot
.71339 .46687 Mdot
.59278 .54349 Mdot
.54227 .58681 Mdot
.52516 .60746 Mdot
.52811 .00182 Mdot
.55343 .01565 Mdot
.62069 .04157 Mdot
.77552 .09569 Mdot
.05604 .17337 Mdot
.29264 .14623 Mdot
.40647 .07035 Mdot
.44971 .02672 Mdot
.45338 .00227 Mdot
.4203 .59758 Mdot
.32608 .5598 Mdot
.11881 .48993 Mdot
.82507 .4365 Mdot
.64476 .50659 Mdot
.56494 .5687 Mdot
.53564 .59992 Mdot
.5346 .6174 Mdot
.56104 .01634 Mdot
.63511 .04578 Mdot
.80475 .10484 Mdot
.09425 .17892 Mdot
.31268 .135 Mdot
.41354 .06233 Mdot
.44858 .02166 Mdot
.4432 .61471 Mdot
.39335 .58722 Mdot
.26441 .53835 Mdot
.00868 .45998 Mdot
.746 .45569 Mdot
.61061 .53436 Mdot
.55676 .58475 Mdot
.54735 .61222 Mdot
.57526 .01725 Mdot
.66117 .05309 Mdot
.85508 .11984 Mdot
.14956 .182 Mdot
.34123 .11846 Mdot
.42594 .05235 Mdot
.45351 .01704 Mdot
.44442 .61242 Mdot
.39177 .58549 Mdot
.25906 .53601 Mdot
.99923 .45745 Mdot
.74002 .45783 Mdot
.60788 .53637 Mdot
.55558 .58571 Mdot
.54684 .61263 Mdot
.57503 .01743 Mdot
.66105 .05316 Mdot
.85503 .11988 Mdot
.1496 .18205 Mdot
.34134 .11851 Mdot
.42617 .05243 Mdot
.45403 .01722 Mdot
.44562 .61284 Mdot
.39455 .58647 Mdot
0 .58713 Mdot
.95 .58713 Mdot
.93935 .61145 Mdot
.97605 .02268 Mdot
.03184 .03448 Mdot
.06233 .01884 Mdot
.04422 .60684 Mdot
.99119 .58526 Mdot
.9452 .58961 Mdot
.94219 .61617 Mdot
.98442 .0261 Mdot
.03909 .03379 Mdot
.0628 .01465 Mdot
.03757 .60244 Mdot
.98255 .58404 Mdot
.94147 .59264 Mdot
.94616 .0029 Mdot
.99311 .02901 Mdot
.04556 .03242 Mdot
.06207 .0102 Mdot
.03016 .59832 Mdot
.97428 .58349 Mdot
.93888 .59616 Mdot
.95118 .00761 Mdot
.00193 .03137 Mdot
.05114 .03041 Mdot
.06013 .00556 Mdot
.02216 .59456 Mdot
.96651 .58365 Mdot
.93746 .60008 Mdot
.95717 .01218 Mdot
.01072 .0331 Mdot
.05571 .0278 Mdot
.05703 .00082 Mdot
.0137 .59125 Mdot
.95942 .58449 Mdot
.93726 .60433 Mdot
.96399 .01653 Mdot
.01929 .03418 Mdot
.05919 .02466 Mdot
.05283 .6141 Mdot
.00497 .58846 Mdot
.95314 .586 Mdot
.93826 .60884 Mdot
.97154 .02057 Mdot
.02747 .03457 Mdot
.06153 .02105 Mdot
.04759 .60941 Mdot
.99613 .58623 Mdot
.94777 .58815 Mdot
.94045 .61351 Mdot
.97966 .02423 Mdot
.0351 .03426 Mdot
.06269 .01705 Mdot
.04141 .60488 Mdot
.98738 .58464 Mdot
.94343 .59088 Mdot
.9438 .00022 Mdot
.98819 .02744 Mdot
.04203 .03327 Mdot
.06263 .01273 Mdot
.03441 .60059 Mdot
.97888 .58371 Mdot
.94019 .59413 Mdot
.94824 .00497 Mdot
.99696 .03012 Mdot
.04812 .03162 Mdot
.06136 .00819 Mdot
.02672 .59663 Mdot
.97081 .58347 Mdot
.93811 .59783 Mdot
.95369 .00963 Mdot
.0058 .0322 Mdot
.05327 .02934 Mdot
.05891 .00349 Mdot
.0185 .59306 Mdot
.96332 .58393 Mdot
.93722 .60191 Mdot
.96006 .01411 Mdot
.01451 .03365 Mdot
.05737 .02649 Mdot
.05532 .61677 Mdot
.0099 .58996 Mdot
.95656 .58507 Mdot
.93755 .60628 Mdot
.96722 .01834 Mdot
.02293 .03443 Mdot
.06036 .02313 Mdot
.05065 .61203 Mdot
.0011 .58741 Mdot
.95067 .58686 Mdot
.93907 .61087 Mdot
.97503 .02223 Mdot
.03089 .03452 Mdot
.06219 .01934 Mdot
.04499 .60741 Mdot
.99228 .58546 Mdot
.94574 .58927 Mdot
.94178 .61558 Mdot
.98336 .0257 Mdot
.03823 .03391 Mdot
.06281 .01519 Mdot
.03844 .60297 Mdot
.98362 .58415 Mdot
.94188 .59224 Mdot
.94561 .00231 Mdot
.99201 .02868 Mdot
.0448 .03263 Mdot
.06222 .01077 Mdot
.03112 .59881 Mdot
.97528 .58352 Mdot
.93914 .59569 Mdot
.9505 .00702 Mdot
.00083 .0311 Mdot
.05049 .03069 Mdot
.06044 .00614 Mdot
.02318 .59501 Mdot
.96745 .58359 Mdot
.93757 .59957 Mdot
.95637 .01162 Mdot
.00963 .03292 Mdot
.0552 .02816 Mdot
.05748 .00141 Mdot
.01477 .59164 Mdot
.96026 .58435 Mdot
.93722 .60379 Mdot
.9631 .016 Mdot
.01824 .03408 Mdot
.05882 .02508 Mdot
.05341 .61469 Mdot
.00607 .58877 Mdot
.95387 .58578 Mdot
.93807 .60827 Mdot
.97057 .02009 Mdot
.02648 .03456 Mdot
.06131 .02152 Mdot
.04829 .60999 Mdot
.99723 .58648 Mdot
.94839 .58785 Mdot
.94011 .61292 Mdot
.97862 .0238 Mdot
.03418 .03434 Mdot
.06261 .01757 Mdot
.04223 .60544 Mdot
.98846 .5848 Mdot
.94392 .59051 Mdot
.94332 .61766 Mdot
.98711 .02707 Mdot
.04121 .03343 Mdot
.0627 .01329 Mdot
.03532 .60111 Mdot
.97992 .58379 Mdot
.94054 .59369 Mdot
.94763 .00438 Mdot
.99586 .02981 Mdot
.04741 .03186 Mdot
.06159 .00876 Mdot
.02772 .5971 Mdot
.97178 .58347 Mdot
.93831 .59734 Mdot
.95296 .00906 Mdot
.0047 .03198 Mdot
.05268 .02965 Mdot
.05928 .00408 Mdot
.01955 .59348 Mdot
.96422 .58384 Mdot
.93727 .60138 Mdot
.95922 .01357 Mdot
.01344 .03351 Mdot
.05692 .02687 Mdot
.05583 .61736 Mdot
.01099 .59032 Mdot
.95736 .58489 Mdot
.93744 .60572 Mdot
.96629 .01783 Mdot
.0219 .03437 Mdot
.06005 .02358 Mdot
.05129 .61262 Mdot
.0022 .5877 Mdot
.95135 .58661 Mdot
.93882 .61029 Mdot
.97403 .02176 Mdot
.02993 .03455 Mdot
.06202 .01984 Mdot
.04575 .60798 Mdot
.99338 .58567 Mdot
.9463 .58894 Mdot
.94138 .61499 Mdot
.9823 .02529 Mdot
.03735 .03403 Mdot
.0628 .01573 Mdot
.0393 .60351 Mdot
.98468 .58428 Mdot
.9423 .59184 Mdot
.94507 .00171 Mdot
.99092 .02834 Mdot
.04403 .03282 Mdot
.06236 .01133 Mdot
.03207 .59931 Mdot
.9763 .58356 Mdot
.93942 .59524 Mdot
.94984 .00644 Mdot
.99973 .03083 Mdot
.04984 .03097 Mdot
.06072 .00673 Mdot
.0242 .59546 Mdot
.96839 .58354 Mdot
.9377 .59907 Mdot
.95559 .01105 Mdot
.00854 .03273 Mdot
.05467 .02851 Mdot
.05791 .002 Mdot
.01584 .59203 Mdot
.96112 .58421 Mdot
.93719 .60325 Mdot
.96222 .01547 Mdot
.01719 .03397 Mdot
.05843 .02549 Mdot
.05397 .61528 Mdot
.00716 .5891 Mdot
.95462 .58556 Mdot
.93789 .6077 Mdot
.9696 .0196 Mdot
.02548 .03453 Mdot
.06106 .02199 Mdot
.04898 .61057 Mdot
.99834 .58673 Mdot
.94902 .58755 Mdot
.93979 .61233 Mdot
.97759 .02336 Mdot
.03326 .0344 Mdot
.06251 .01808 Mdot
.04303 .60599 Mdot
.98954 .58498 Mdot
.94442 .59014 Mdot
.94286 .61707 Mdot
.98604 .02669 Mdot
.04037 .03358 Mdot
.06276 .01383 Mdot
.03623 .60164 Mdot
.98096 .58388 Mdot
.9409 .59327 Mdot
.94703 .00379 Mdot
.99476 .0295 Mdot
.04668 .03209 Mdot
.06179 .00934 Mdot
.0287 .59758 Mdot
.97277 .58347 Mdot
.93852 .59687 Mdot
.95224 .00848 Mdot
.0036 .03174 Mdot
.05208 .02996 Mdot
.05963 .00467 Mdot
.02059 .5939 Mdot
.96512 .58375 Mdot
.93733 .60086 Mdot
.95839 .01301 Mdot
.01236 .03335 Mdot
.05645 .02725 Mdot
.05632 .61796 Mdot
.01207 .59069 Mdot
.95817 .58472 Mdot
.93735 .60517 Mdot
.96536 .01731 Mdot
.02087 .0343 Mdot
.05972 .02401 Mdot
.05192 .61321 Mdot
.00331 .58799 Mdot
.95205 .58636 Mdot
.93858 .60971 Mdot
.97303 .02129 Mdot
.02896 .03456 Mdot
.06184 .02033 Mdot
.04649 .60855 Mdot
.99447 .58589 Mdot
.94688 .58862 Mdot
.94099 .6144 Mdot
.98124 .02488 Mdot
.03646 .03413 Mdot
.06277 .01626 Mdot
.04015 .60406 Mdot
.98575 .58441 Mdot
.94274 .59145 Mdot
.94455 .00112 Mdot
.98983 .02798 Mdot
.04324 .03301 Mdot
.06248 .01189 Mdot
.03301 .59982 Mdot
.97732 .58361 Mdot
.93971 .59479 Mdot
.94919 .00586 Mdot
.99863 .03055 Mdot
.04916 .03123 Mdot
.06099 .00731 Mdot
.02521 .59592 Mdot
.96935 .58351 Mdot
.93785 .59857 Mdot
.95482 .01049 Mdot
.00745 .03253 Mdot
.05412 .02884 Mdot
.05832 .0026 Mdot
.01691 .59244 Mdot
.96199 .58409 Mdot
.93719 .60271 Mdot
.96135 .01493 Mdot
.01612 .03385 Mdot
.05802 .02589 Mdot
.05452 .61587 Mdot
.00826 .58944 Mdot
.95539 .58536 Mdot
.93774 .60713 Mdot
.96864 .0191 Mdot
.02447 .0345 Mdot
.0608 .02245 Mdot
.04966 .61115 Mdot
.99944 .58699 Mdot
.94966 .58727 Mdot
.93949 .61175 Mdot
.97657 .02291 Mdot
.03232 .03446 Mdot
.0624 .01859 Mdot
.04382 .60655 Mdot
.99063 .58516 Mdot
.94493 .58979 Mdot
.94241 .61648 Mdot
.98496 .0263 Mdot
.03953 .03372 Mdot
.06279 .01438 Mdot
.03712 .60217 Mdot
.98202 .58398 Mdot
.94127 .59285 Mdot
.94645 .0032 Mdot
.99367 .02918 Mdot
.04595 .03231 Mdot
.06198 .00991 Mdot
.02967 .59807 Mdot
.97376 .58348 Mdot
.93875 .59639 Mdot
.95154 .0079 Mdot
.0025 .03149 Mdot
.05146 .03026 Mdot
.05997 .00526 Mdot
.02163 .59434 Mdot
.96604 .58368 Mdot
.93741 .60034 Mdot
.95758 .01246 Mdot
.01128 .03319 Mdot
.05596 .02762 Mdot
.0568 .00052 Mdot
.01315 .59106 Mdot
.959 .58456 Mdot
.93728 .60461 Mdot
.96445 .01679 Mdot
.01983 .03422 Mdot
.05938 .02444 Mdot
.05252 .6138 Mdot
.00441 .5883 Mdot
.95277 .58612 Mdot
.93836 .60913 Mdot
.97204 .02082 Mdot
.02798 .03457 Mdot
.06164 .02081 Mdot
.04722 .60912 Mdot
.99557 .58611 Mdot
.94747 .5883 Mdot
.94063 .61381 Mdot
.98019 .02445 Mdot
.03556 .03422 Mdot
.06272 .01678 Mdot
.04099 .6046 Mdot
.98683 .58456 Mdot
.94319 .59107 Mdot
.94405 .00053 Mdot
.98875 .02763 Mdot
.04244 .03319 Mdot
.06258 .01245 Mdot
.03394 .60033 Mdot
.97835 .58368 Mdot
.94003 .59435 Mdot
.94855 .00527 Mdot
.99752 .03027 Mdot
.04848 .03149 Mdot
.06124 .00789 Mdot
.02622 .59639 Mdot
.97031 .58348 Mdot
.93802 .59808 Mdot
.95407 .00992 Mdot
.00636 .03232 Mdot
.05356 .02917 Mdot
.05872 .00319 Mdot
.01796 .59285 Mdot
.96287 .58398 Mdot
.93721 .60218 Mdot
.96049 .01439 Mdot
.01506 .03372 Mdot
.0576 .02629 Mdot
.05506 .61647 Mdot
.00935 .58978 Mdot
.95616 .58516 Mdot
.93761 .60657 Mdot
.9677 .0186 Mdot
.5 .58713 Mdot
.45 .58713 Mdot
.36065 .56282 Mdot
.17354 .50239 Mdot
.87351 .43261 Mdot
.66436 .48877 Mdot
.56453 .55634 Mdot
.51492 .58737 Mdot
.47723 .59474 Mdot
.42138 .58352 Mdot
.30516 .54621 Mdot
.06919 .4722 Mdot
.77959 .43905 Mdot
.61513 .51639 Mdot
.53494 .56847 Mdot
.48248 .58561 Mdot
.41602 .57696 Mdot
.28546 .53734 Mdot
.03072 .4606 Mdot
.75156 .4455 Mdot
.59971 .52419 Mdot
.52252 .57033 Mdot
.46328 .58142 Mdot
.37493 .56343 Mdot
.19651 .50776 Mdot
.89789 .43348 Mdot
.67547 .48057 Mdot
.56666 .55079 Mdot
.50963 .58279 Mdot
.46031 .58755 Mdot
.37956 .56813 Mdot
.2114 .5141 Mdot
.91963 .43772 Mdot
.68947 .47578 Mdot
.57753 .54885 Mdot
.52518 .58568 Mdot
.49291 .59808 Mdot
.45495 .59458 Mdot
.38144 .5726 Mdot
.22162 .51926 Mdot
.93649 .44181 Mdot
.70083 .47239 Mdot
.58647 .54735 Mdot
.53793 .58803 Mdot
.51944 .60661 Mdot
.51647 .6162 Mdot
.52665 .00629 Mdot
.55806 .01941 Mdot
.63488 .04748 Mdot
.80715 .10647 Mdot
.09863 .18014 Mdot
.31615 .13444 Mdot
.4172 .06245 Mdot
.45494 .02333 Mdot
.45712 .00135 Mdot
.42541 .59844 Mdot
.3362 .56289 Mdot
.13788 .49547 Mdot
.84254 .43551 Mdot
.65361 .50127 Mdot
.56935 .56596 Mdot
.53884 .59918 Mdot
.53909 .00016 Mdot
.5703 .01929 Mdot
.65594 .05293 Mdot
.84732 .11827 Mdot
.14294 .18271 Mdot
.33898 .12116 Mdot
.42708 .05445 Mdot
.45886 .01964 Mdot
.4581 .61756 Mdot
.42421 .59709 Mdot
.33196 .56102 Mdot
.1289 .49253 Mdot
.83363 .43555 Mdot
.6485 .50362 Mdot
.56567 .56684 Mdot
.53391 .5984 Mdot
.52907 .61504 Mdot
.54735 .0113 Mdot
.60296 .03437 Mdot
.73532 .0818 Mdot
.99445 .16015 Mdot
.25802 .1629 Mdot
.39444 .08431 Mdot
.45245 .03586 Mdot
.473 .0127 Mdot
.47205 .61745 Mdot
.44885 .6037 Mdot
.38543 .57884 Mdot
.23808 .52696 Mdot
.96376 .44849 Mdot
.71818 .46626 Mdot
.59739 .54338 Mdot
.54974 .58858 Mdot
.54123 .61278 Mdot
.56534 .0149 Mdot
.64027 .04631 Mdot
.81343 .10702 Mdot
.10394 .17955 Mdot
.31709 .13173 Mdot
.41405 .05993 Mdot
.44555 .01947 Mdot
.43433 .6111 Mdot
.37204 .57954 Mdot
.21807 .52287 Mdot
.93933 .44576 Mdot
.70796 .47504 Mdot
.59949 .551 Mdot
.56554 .59705 Mdot
.58254 .01051 Mdot
.66266 .04951 Mdot
.8514 .11665 Mdot
.14249 .1799 Mdot
.33421 .11849 Mdot
.41603 .05056 Mdot
.43374 .01095 Mdot
.39997 .59716 Mdot
.29133 .55089 Mdot
.05964 .47484 Mdot
.78134 .44604 Mdot
.62791 .52321 Mdot
.56615 .57986 Mdot
.55579 .61163 Mdot
.58916 .02062 Mdot
.69018 .06243 Mdot
.90963 .13563 Mdot
.19756 .17795 Mdot
.36501 .10349 Mdot
.43696 .04447 Mdot
.45979 .01411 Mdot
.45079 .61247 Mdot
.40306 .58853 Mdot
.28247 .54351 Mdot
.0372 .46645 Mdot
.76244 .44822 Mdot
.61462 .52667 Mdot
.55076 .57857 Mdot
.52683 .60325 Mdot
.52427 .61645 Mdot
.54105 .01037 Mdot
.5903 .03044 Mdot
.70798 .07273 Mdot
.94857 .14869 Mdot
.2296 .17368 Mdot
.38434 .09564 Mdot
.45448 .04335 Mdot
.48871 .02115 Mdot
.5139 .01557 Mdot
.55021 .02244 Mdot
.62602 .04685 Mdot
.79243 .10285 Mdot
.08167 .17876 Mdot
.3084 .14013 Mdot
.41629 .06668 Mdot
.46025 .02717 Mdot
.47275 .00772 Mdot
.46355 .61235 Mdot
.42545 .59448 Mdot
.32986 .55896 Mdot
.12264 .48997 Mdot
.82673 .43515 Mdot
.64364 .50487 Mdot
.56048 .56664 Mdot
.52455 .59583 Mdot
.50817 .60791 Mdot
.49833 .61195 Mdot
.48716 .61113 Mdot
.46573 .60479 Mdot
.41709 .58797 Mdot
.30509 .54881 Mdot
.07331 .47479 Mdot
.78494 .43981 Mdot
.62083 .51661 Mdot
.54437 .57078 Mdot
.50295 .59243 Mdot
.46388 .59389 Mdot
.39617 .57618 Mdot
.25115 .52841 Mdot
.97882 .44972 Mdot
.72338 .46016 Mdot
.59349 .53776 Mdot
.53416 .58137 Mdot
.50195 .59813 Mdot
.4713 .59909 Mdot
.41781 .58497 Mdot
.30144 .54612 Mdot
.06435 .4715 Mdot
.77717 .44055 Mdot
.61546 .51809 Mdot
.53823 .5703 Mdot
.49129 .58902 Mdot
.43737 .58472 Mdot
.33464 .55454 Mdot
.12218 .48672 Mdot
.82129 .43208 Mdot
.63517 .503 Mdot
.54463 .56208 Mdot
.48935 .58386 Mdot
.42554 .5786 Mdot
.30432 .54311 Mdot
.06311 .46896 Mdot
.77273 .43857 Mdot
.60838 .51646 Mdot
.52418 .566 Mdot
.45925 .5779 Mdot
.36207 .55797 Mdot
.16784 .498 Mdot
.86289 .42956 Mdot
.65455 .48927 Mdot
.55131 .55423 Mdot
.48842 .57916 Mdot
.41626 .57344 Mdot
.28017 .53392 Mdot
.01903 .45664 Mdot
.74271 .44725 Mdot
.59357 .52586 Mdot
.51505 .56951 Mdot
.44855 .57694 Mdot
.34161 .55194 Mdot
.12785 .48593 Mdot
.82247 .4293 Mdot
.63143 .49997 Mdot
.534 .55782 Mdot
.46356 .5745 Mdot
.36421 .55664 Mdot
.16895 .49735 Mdot
.86251 .42865 Mdot
.65289 .48848 Mdot
.54762 .55297 Mdot
.47988 .57617 Mdot
.39608 .56625 Mdot
.23494 .51844 Mdot
.94703 .4401 Mdot
.70073 .46581 Mdot
.57569 .54076 Mdot
.50895 .57679 Mdot
.44937 .58121 Mdot
.34997 .5566 Mdot
.14755 .49293 Mdot
.84328 .42999 Mdot
.64509 .49554 Mdot
.54755 .55775 Mdot
.48748 .58091 Mdot
.41742 .57473 Mdot
.28421 .53571 Mdot
.02661 .45883 Mdot
.74782 .44573 Mdot
.59634 .52442 Mdot
.51732 .56919 Mdot
.45212 .57774 Mdot
.34918 .55442 Mdot
.14286 .49052 Mdot
.83699 .429 Mdot
.6399 .49622 Mdot
.54085 .55682 Mdot
.47413 .5768 Mdot
.3868 .56406 Mdot
.21636 .51269 Mdot
.92142 .43575 Mdot
.68683 .47305 Mdot
.56966 .54562 Mdot
.50645 .57897 Mdot
.44841 .58216 Mdot
.34982 .5571 Mdot
.14813 .49338 Mdot
.84432 .43027 Mdot
.64612 .49554 Mdot
.54908 .55806 Mdot
.49069 .58194 Mdot
.42484 .57734 Mdot
.30108 .54155 Mdot
.0565 .46688 Mdot
.76766 .43952 Mdot
.60536 .51773 Mdot
.52133 .5661 Mdot
.45432 .57662 Mdot
.35126 .55434 Mdot
.14579 .49105 Mdot
.83933 .42863 Mdot
.64065 .49525 Mdot
.54042 .55609 Mdot
.47218 .57586 Mdot
.38179 .56217 Mdot
.2053 .50895 Mdot
.90647 .43335 Mdot
.67823 .47698 Mdot
.56459 .5478 Mdot
.50121 .57887 Mdot
.43881 .57947 Mdot
.32865 .54995 Mdot
.1064 .48068 Mdot
.80523 .4319 Mdot
.6238 .5059 Mdot
.53171 .56112 Mdot
.46481 .57669 Mdot
.37 .55944 Mdot
.18238 .50208 Mdot
.87875 .43038 Mdot
.66301 .4847 Mdot
.55604 .55192 Mdot
.49298 .57906 Mdot
.4243 .57559 Mdot
.29733 .53956 Mdot
.04861 .46432 Mdot
.76161 .44066 Mdot
.6016 .51914 Mdot
.51745 .56603 Mdot
.44723 .57464 Mdot
.33557 .54902 Mdot
.11454 .48143 Mdot
.80959 .42956 Mdot
.62314 .5028 Mdot
.52567 .55779 Mdot
.44865 .57043 Mdot
.33125 .54548 Mdot
.10275 .47682 Mdot
.79765 .42947 Mdot
.61421 .50466 Mdot
.51449 .55641 Mdot
.42636 .56356 Mdot
.28139 .52844 Mdot
.01156 .45127 Mdot
.73249 .44556 Mdot
.57998 .52378 Mdot
.48879 .56168 Mdot
.38865 .55614 Mdot
.20652 .50547 Mdot
.90178 .4297 Mdot
.67073 .47523 Mdot
.55153 .54437 Mdot
.47284 .5694 Mdot
.37253 .55604 Mdot
.18079 .49954 Mdot
.87358 .42817 Mdot
.6572 .4843 Mdot
.54711 .54999 Mdot
.47416 .57295 Mdot
.38064 .56023 Mdot
.20033 .50659 Mdot
.89884 .43171 Mdot
.67294 .47842 Mdot
.55974 .54807 Mdot
.4932 .57691 Mdot
.42123 .57355 Mdot
.28879 .53618 Mdot
.03278 .45981 Mdot
.75074 .44372 Mdot
.59601 .52241 Mdot
.51352 .56705 Mdot
.44184 .57373 Mdot
.32466 .54561 Mdot
.09391 .47542 Mdot
.79232 .43164 Mdot
.61357 .50756 Mdot
.51817 .55907 Mdot
.43727 .56803 Mdot
.30747 .53782 Mdot
.05857 .4642 Mdot
.76386 .43589 Mdot
.59599 .51429 Mdot
.50034 .55892 Mdot
.40496 .55909 Mdot
.23799 .51484 Mdot
.94405 .43637 Mdot
.69396 .46347 Mdot
.56338 .53733 Mdot
.48218 .56785 Mdot
.38674 .55905 Mdot
.20815 .50766 Mdot
.90662 .43168 Mdot
.67558 .47524 Mdot
.55819 .54548 Mdot
.48632 .57362 Mdot
.40352 .56686 Mdot
.24818 .52203 Mdot
.96553 .44334 Mdot
.71023 .46026 Mdot
.57831 .5365 Mdot
.50654 .57368 Mdot
.44001 .57691 Mdot
.32661 .54795 Mdot
.10036 .4782 Mdot
.79903 .43181 Mdot
.61904 .50679 Mdot
.52564 .56031 Mdot
.45267 .57293 Mdot
.34238 .54987 Mdot
.12562 .48407 Mdot
.81848 .42821 Mdot
.62706 .49973 Mdot
.52683 .55609 Mdot
.44795 .56929 Mdot
.32818 .54401 Mdot
.09613 .47462 Mdot
.79177 .42993 Mdot
.61038 .50593 Mdot
.51037 .55623 Mdot
.41867 .56135 Mdot
.26468 .52287 Mdot
.98392 .44451 Mdot
0 .61803 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
0 0 Mdot
.5 .61803 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo000Vooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0=ooooo`0300000?oooooooooo017ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`0400000?l0003oooooo`0000Cooooo00@0
0000ooooool0000000004Oooool00`00003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool03_ooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo
000Vooooobgo000000<00000o`000?l00000@Ol0000200000005o`000000003o0000o`0000000000
M_l00003000000Wooooo000Vooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`03o`000?oo
oooooooo00gooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`0Jooooo`030000
0?l0003o000000[ooooo00@00000ooooooooool000000_ooool2o`0000Gooooo00@00000oooooooo
ool000000_ooool01?l0003oooooooooo`000002ooooo`0500000?ooooooooooooooo`0000001ooo
ool01?l0003oooooooooooooool2o`0001_ooooo0_l0000=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`;o00002_ooool00`00003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0
000>ooooo`;o00004_ooool2o`0001cooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo00?o
000000000?ooool00P000003ooooo`03o`000?oooooo000000?ooooo00@00000o`000?l0003o0000
2?ooool00ol0003oooooooooo`06ooooo`03o`000000003ooooo01[ooooo00<00000o`000?ooool0
4_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0_l00009ooooo`030000
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06ooo
ool00ol000000000ooooo`0:ooooo`;o00000oooool00`00003oooooooooo`02o`00008000000_oo
ool01Ol0003ooooo00000000003o000000Cooooo00<00000o`000?ooool00_l000000ooooooo0000
ooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o000000000?ooool04Oooool00ol000000000
ooooo`0=ooooo`03o`000000003ooooo00_ooooo0ol00007ooooo`0300000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`;o00004_ooool00ol000000000ooooo`0Looooo`03o`000?oooooooooo00Cooooo00<0
0000ooooooooool00_l000001?oooooo0000000000000004ooooo`05o`000?oooooooooo00000?l0
00000P000003ooooo`0800000?ooooooooooo`000?oooooo0000ooooool00002ooooo`05o`000000
003oooooooooool000000_ooool00`00003oooooooooo`03ooooo`;o00007Oooool2o`0001;ooooo
0_l0000>ooooo`;o00003Oooool3o`0000Gooooo00<00000ooooooooool01oooool002Kooooo00?o
0000ooooooooool02oooool2o`0000kooooo00<00000o`000?ooool03_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool01?l0003ooooooooo
ooooool2000000Cooooo00?o0000ooooooooool01?ooool02@00003oooooo`000000003o00000000
0?l0003ooooo00000003ooooo`0300000?oooooooooo00_ooooo0_l0000Looooo`;o00004_ooool2
o`0000kooooo0_l000000`00003oooooooooo`0;ooooo`?o00000oooool00`00003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`09ooooo`?o00004?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool2o`0000[ooooo00Co0000oooo
ool0003o00000_ooool00`00003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00D0
0000ooooool0003ooooo00000004ooooo`0300000?l0003ooooo00;ooooo00<00000ooooooooool0
1oooool3o`0001_ooooo0ol0000Aooooo`;o00003oooool2o`0000kooooo1?l000000`00003ooooo
ooooo`07ooooo`009_ooool6o`0000;ooooo1Ol0000Booooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00?o
0000ooooool000000P000002ooooo`04o`000000003oooooooooo`8000001Oooool300000003oooo
ool00000000000Cooooo00<00000o`000?l000003Oooool00`00003o00000000000Jooooo`030000
0?l0003ooooo017ooooo0_l0000>ooooo`0300000?l0003o000000oooooo0_l00009ooooo`009_oo
ool00ol0003oooooooooo`02ooooo`Co00005Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool06Oooool2o`0000Oooooo00<00000ooooooooool00_oo
ool01?l0003oooooo`0000000005ooooo`0300000?oooooooooo00Sooooo00<00000ooooo`000000
1oooool01000003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00<00000oooooooo
ool01?ooool2o`00000300000?oooooooooo01Sooooo0_l0000Aooooo`0300000?l0003ooooo00ko
oooo00<00000o`000?l000003_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Hooooo`;o00003?ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00@00000
00Kooooo00000?ooool00000ooooo`000002ooooo`0800000?oooooooooo00000?ooool00000oooo
o`000004ooooo`05o`000?oooooooooo00000?l000002_ooool00ol000000000ooooo`0Iooooo`03
00000?l0003ooooo017ooooo0_l0000?ooooo`?o00003?ooool00`00003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`0Jooooo`;o00004?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Oooooo00?o000000000?ooool02Oooool02?l0003ooooooooooooooooo00000000
0?oooooo00001?ooool2000000Sooooo0P0000001Oooool0000000000?ooool0000000Gooooo0`00
0005ooooo`03o`000?oooooo000000?ooooo0_l00008ooooo`03o`000000003o000001Sooooo0_l0
000Aooooo`0300000?l00000000000oooooo0ol0000:ooooo`0300000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo01Wooooo0_l0000Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Co0000
ooooo`00000000000_ooool3000000Wooooo1`000008ooooo`8000001Oooool01000003o0000oooo
ool00006ooooo`03o`000?oooooooooo00Cooooo00<00000o`000?ooool05_ooool00`00003o0000
o`00000Aooooo`?o00003oooool01000003o0000o`000?l00007ooooo`0300000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo01Sooooo0_l0000Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool05_ooool2o`0000Sooooo0_l000001@00003ooooo00000?ooool0000000Go
oooo00<00000ooooooooool02?ooool300000003ooooo`00003ooooo008000000_ooool4000000So
oooo00D00000ooooooooool00000o`000002ooooo`8000000_ooool2o`0000Sooooo0_l0000Goooo
o`?o00004Oooool00ol000000000o`00000@ooooo`Co00001?ooool00`00003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`0Fooooo`0300000?l0003o000001;ooooo00?o0000oooooooo
ool04Oooool00ol000000000ooooo`0Gooooo`03o`000?oooooooooo00Sooooo00L00000oooooooo
ooooooooo`000?ooool0000000Cooooo00<00000ooooooooool01_ooool00`00003oooooooooo`0;
ooooo`0500000?ooooooooooooooo`0000002?ooool200000003ooooo`000000000000Gooooo0P00
0008ooooo`;o00005oooool2o`0001;ooooo0ol0000Aooooo`Co000000?ooooo00000?ooool02?oo
ool002Kooooo0_l0000Eooooo`?o00004oooool2o`0001?ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`05ooooo`;o00000oooool3000000Cooooo100000000oooool0000000000004
000001Cooooo100000000oooool00000ooooo`05000000Cooooo00?o0000ooooo`0000001Oooool0
0ol0003oooooooooo`03ooooo`0300000?l0003ooooo01Kooooo0_l000000`00003oooooooooo`0?
ooooo`0300000?l0003o000001;ooooo0ol00009ooooo`009_ooool00ol0003oooooo`000005o`00
00_ooooo1Ol0000Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`02ooooo`0700000?ooooooooooooooool0003oooooo`000002000000;ooooo2@00
0003ooooo`0300000?oooooooooo01[ooooo0P0000000oooool000000000000400000003ooooo`00
0000000000;ooooo00<00000ooooool000001Oooool01000003oooooooooooooool2o`0001Oooooo
0_l000000`00003oooooooooo`0@ooooo`;o00004_ooool00`00003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`05ooooo`co00006?ooool00ol000000000ooooo`0Booooo`03o`000?oo
oooooooo01Kooooo0_l00006ooooo`;o000000?ooooo00000?ooool00_ooool01000003ooooo0000
0?ooool4000002_ooooo0P0000000oooool0000000000003ooooo`0500000?oooooooooo00000?l0
00001oooool2o`00000300000?oooooooooo01Cooooo0_l000000`00003oooooooooo`0@ooooo`?o
00003oooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Xooooo`03o`00
0000003ooooo01;ooooo0_l0000Gooooo`0300000?l0003ooooo00Gooooo00<00000ooooool00000
0oooool00`00003oooooooooo`02ooooo`800000<_ooool2000000Gooooo00H00000oooooooooooo
0000ooooo`000006ooooo`;o00005_ooool00`00003o0000o`00000Booooo`04o`000000003o0000
o`0000cooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool09_ooool3o`00
01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo0P00000gooooo`0300000?oooooooooo00kooooo0ol000000`00003oooooooooo`0Doooo
o`0300000?l0003ooooo01;ooooo00<00000o`000?l000002_ooool00`00003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`0Uooooo`0300000?l0003ooooo01Cooooo00?o0000oooooooo
ool05Oooool00`00003o0000ooooo`05ooooo`04o`000?oooooooooo000000;ooooo00@00000oooo
oooooooooooo0P00000kooooo`0300000?oooooooooo00;ooooo0P0000001Ol0003ooooooooooooo
oooo000000Gooooo0ol0000Fooooo`03o`000000003o000001?ooooo00Co000000000?l0003o0000
1_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Sooooo`?o00005Ooo
ool00ol0003oooooooooo`0Eooooo`;o00003?ooool01@00003oooooooooooooool0000001Cooooo
0P000002ooooo`0400000?ooool00000ooooo`<000000oooool400000004ooooo`00003ooooo0000
00;ooooo00<00000ooooo`0000004_ooool2000000?ooooo00<00000ooooooooool02?ooool2o`00
000300000?oooooooooo01?ooooo0P0000000ol000000000ooooo`0Booooo`0400000?l0003o0000
o`0000?ooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool08Oooool3o`00
01Kooooo00?o000000000?ooool05Oooool00ol000000000ooooo`05ooooo`0300000?oooooo0000
00?ooooo00<00000ooooooooool04_ooool6000000?ooooo0P000002ooooo`L0000000Cooooo0000
0?oooooooooo0P000003ooooo`80000000?ooooo0000000000000`00000>ooooo`8000001Oooool0
0`00003oooooo`000002ooooo`0300000?oooooooooo00?ooooo00?o000000000?ooool05Oooool3
o`0001Cooooo1?l000000`00003oooooooooo`07ooooo`009_ooool5o`0001cooooo1?l0000Foooo
o`0300000?l0003ooooo01Kooooo00?o0000ooooooooool00_ooool01000003oooooooooool00003
ooooo`8000000_ooool2000000kooooo00<00000ooooo`0000000P00000Sooooo`D0000000?ooooo
00000?ooool04?ooool02@00003ooooooooooooooooo0000ooooool0003ooooo00000003ooooo`03
o`000000003o000001Gooooo0_l000000`00003oooooooooo`0Booooo`03o`000000003ooooo00So
oooo000Vooooo`03o`000?oooooooooo00;ooooo1Ol000000`00003oooooooooo`0@ooooo`Co0000
00<00000ooooooooool05_ooool2o`0001Kooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo
00<00000ooooooooool03?ooool00`00003ooooo00000006ooooo`<000000_ooool300000003oooo
o`000000000000_ooooo0P0000000oooool0000000000002ooooo`<000001oooool00`00003ooooo
0000000=ooooo`8000001_ooool00ol0003oooooooooo`05ooooo`0300000?l0003o000001Gooooo
0ol0000Booooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Oooooo0_l0
00001@00003o0000o`000?l00000000000So000000<00000o`000?l000000_l0000Kooooo`03o`00
0000003ooooo01Gooooo00?o000000000?ooool01?ooool01ol0003oooooooooooooool00000oooo
o`0000000oooool00`00003oooooooooo`0<ooooo`0300000?ooool0000000?ooooo0`00000<oooo
o`0300000?ooool0000000<0000000?ooooo00000?ooool01000000<ooooo`<000000oooool01@00
003oooooooooooooool0000000cooooo0P000003ooooo`0400000?ooool00000o`0000;ooooo00?o
0000ooooooooool00_ooool00`00003o0000ooooo`0Eooooo`?o00003oooool00`00003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`0dooooo`;o00005_ooool00`00003o0000ooooo`08
ooooo`03o`000?ooool0000000?ooooo00<00000ooooooooool03?ooool00`00003oooooooooo`02
ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool00_ooool00`00003ooooo0000000;
ooooo`8000001_ooool3o`0000Gooooo00<00000o`000?ooool05Oooool3o`0000cooooo00<00000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0<_ooool2o`00000300000?oooooooooo
01Cooooo00?o0000ooooooooool01Oooool00`00003ooooo00000004ooooo`8000003Oooool00`00
003ooooo00000003ooooo`8000000oooool70000023ooooo20000002ooooo`<000000_ooool00`00
003oooooooooo`0=ooooo`0400000?ooooooooooooooo`8000002Oooool00`00003oooooooooo`0E
ooooo`04o`000000003o0000000000Sooooo00<00000ooooooooool01oooool001?ooooo0_l00004
ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`0`ooooo`?o00005_oo
ool00`00003oooooooooo`04ooooo`8000000_ooool00`00003ooooo0000000200000003ooooo`00
003ooooo00cooooo00<00000ooooo`0000001oooool2000000Gooooo0P00000Qooooo`<000001?oo
ool4000000Oooooo0P0000000oooool00000ooooo`0:ooooo`80000000Cooooo00000000003ooooo
0P000004ooooo`04o`000?ooooooooooo`0000;ooooo00<00000ooooooooool04oooool01?l00000
0000o`0000000004ooooo`0300000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0^ooooo`?o00005oooool0
0ol0003oooooooooo`02ooooo`?o00000_ooool01_l0003ooooo00000000003ooooo000000gooooo
0`000003ooooo`8000000oooool2000000Gooooo0`00000Uooooo`D000000oooool3000000;ooooo
100000000oooool00000ooooo`03000000[ooooo00<00000ooooooooool00P000003ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool05Oooool01P00003o000000000?l0003ooooo0000
00Wooooo000Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool3o`00
02cooooo0ol0000Gooooo`;o00002oooool3000000cooooo1000000:ooooo`0300000?ooool00000
00D00000;?ooool8000000Wooooo1@00000;ooooo`@000000_ooool01?l000000000ooooo`000003
ooooo`0400000?oooooo0000000001Gooooo00?o000000000?l000002Oooool001;ooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co00009Ooo
ool2o`00000300000?l0003ooooo01Kooooo00<00000o`000?ooool01_ooool200000003ooooo`00
0000000000<000002oooool3000000Cooooo0P000008ooooo`800000=_ooool2000000Sooooo1000
0002ooooo`<000000_ooool00`00003oooooooooo`07ooooo`@0000000Gooooo00000?oooooooooo
00000005ooooo`;o000000<00000ooooooooool04_ooool00`00003oooooooooo`07ooooo`004_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`04ooooo`Go000000<00000ooooooooool06Oooool01?l000000000o`000?l0000Joooo
o`0300000?l0003ooooo00?ooooo00?o0000ooooooooool00_ooool00`00003ooooo000000020000
00Wooooo00D00000ooooo`00003ooooo00000004ooooo`0300000?ooool0000004kooooo00@00000
ooooooooool000000_ooool00`00003ooooo00000002ooooo`0300000?oooooooooo00Oooooo00<0
0000ooooo`0000000P000004ooooo`0300000?oooooooooo00?ooooo00?o000000000?ooool04?oo
ool00`00003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`09ooooo`;o000000H00000o`000000003o
000000000?l0000?ooooo`Go000000<00000ooooooooool06Oooool00`00003o0000ooooo`04oooo
o`?o00000P0000001?ooool00000000000000009ooooo`0300000?oooooooooo00;ooooo00<00000
ooooooooool00_ooool20000023ooooo2P0000000oooool000000000000600000003ooooo`00003o
oooo01kooooo0P000006ooooo`0400000?oooooooooo000000Wooooo00D00000ooooo`00003ooooo
00000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooo`0000003Oooool00`00003ooooo
ooooo`07ooooo`004oooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo017ooooo00H0
0000o`000?l000000000o`0000000009o`0001oooooo0_l00006ooooo`03o`000000003ooooo00?o
oooo0P000009ooooo`0500000?ooool00000ooooo`0000001Oooool2000001kooooo0P0000000ooo
ool00000ooooo`0Eooooo`@000007Oooool3000000Gooooo00D00000oooooooooooooooo0000000:
ooooo`8000002oooool00ol000000000ooooo`09ooooo`0300000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo03gooooo00<00000o`000?ooool00oooool01Ol0003oooooo`000?ooool0
000000?ooooo00<00000ooooooooool02?ooool00`00003oooooooooo`05ooooo`0400000?ooool0
0000000001cooooo1000000Oooooo`D000006oooool200000003ooooo`000000000000Cooooo00<0
0000ooooo`0000002?ooool200000003ooooo`00003ooooo00;ooooo0P0000000ol000000000oooo
o`02ooooo`?o000000<00000ooooooooool01?ooool00`00003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`0kooooo`0300000?l0003o000000Gooooo00?o0000ooooooooool00oooool0
0`00003oooooooooo`08ooooo`0400000?ooool00000000000?ooooo0P0000000oooool00000oooo
o`0Iooooo`D000005?ooool3000001;ooooo0`0000000oooool00000ooooo`0Iooooo`0300000?oo
ool00000008000001?ooool3000000Sooooo00@00000ooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?oooooo0000000000?ooooo00<00000ooooooooool01oooool002Kooooo
00?o0000ooooooooool0>Oooool3o`0000Gooooo00<00000ooooo`0000000oooool2000000Wooooo
0`000003ooooo`8000006oooool40000017ooooo0`0000001?ooool00000000000000003ooooo`03
00000?ooool00000008000000_ooool3000000oooooo1@00000Hooooo`0300000?oooooooooo00<0
000000?ooooo00000?ooool00`000009ooooo`0300000?oooooooooo00;ooooo00<00000oooooooo
ool00oooool01?l000000000o`000?l00009ooooo`009_ooool2o`00000400000?l000000000o`00
03?ooooo0ol000000`00003oooooooooo`03ooooo`04o`000?oooooooooo000000?ooooo00<00000
ooooooooool01oooool3000000;ooooo00<00000ooooo`0000006Oooool40000017ooooo1000000E
ooooo`<000004?ooool300000003ooooo`000000000001Oooooo00H00000oooooooooooooooo0000
0?ooool5000000_ooooo0P0000000ooooooo0000ooooo`02ooooo`03o`000000003ooooo00Sooooo
000Vooooo`03o`000?oooooooooo00?ooooo00D00000o`000?l0003o00000000000[ooooo`?o0000
1Oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo008000002Oooool2000000;ooooo
0`00000Hooooo`@000004oooool2000001gooooo0P0000000oooool00000ooooo`0Aooooo`040000
0?ooool00000000001Oooooo2@000009ooooo`8000001?ooool00ol000000000ooooo`08ooooo`00
9_ooool00ol0003oooooooooo`08ooooo`05o`000000003o0000ooooo`0000008oooool00`00003o
0000o`00000Iooooo`8000006oooool5000001Cooooo0P00000Sooooo`0300000?ooool0000001?o
oooo100000000oooool00000ooooo`0Iooooo`0400000?oooooooooo000000Oooooo00@00000oooo
o`00003ooooo0P000009ooooo`009_ooool00ol0003oooooooooo`0200000005o`000?oooooooooo
ooooo`0000001oooool02?l000000000ooooool000000000o`000000003o00004_ooool01ol00000
0000o`000?oooooo000000000?l000001oooool01000003oooooooooool00003ooooo`0300000?oo
oooooooo00[ooooo00<00000ooooooooool00P00000Fooooo`0400000?ooool00000000001Wooooo
00<00000ooooooooool09?ooool3000001Oooooo00D00000ooooo`00003ooooo0000000Fooooo`<0
00000_ooool00`00003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo00Cooooo00D00000oooooooooooooooo00000002o`000003ooooool0003ooooo00So
oooo00L00000o`000?ooool00000o`000?ooool0000000;ooooo00Wo0000ooooooooool00000o`00
0?ooool00000o`00000000002Oooool01000003oooooooooool00004ooooo`80000000?ooooo0000
000000002Oooool2000000?ooooo0P00000Cooooo`@000007Oooool3000002Kooooo00<00000oooo
ooooool06oooool00`00003ooooo00000002000001;ooooo0`000002ooooo`8000001_ooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`05ooooo`8000001Oooool00`00003o
ooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00?ooooo00?o000000000?ooool01Oooool00`00003oooooooooo`09
ooooo`0300000?oooooooooo00?ooooo1000000?ooooo`8000009?ooool8000001Oooooo10000000
0oooool000000000000Tooooo`<000003_ooool5000000Oooooo0P000009ooooo`009_ooool00ol0
003oooooooooo`0:ooooo`80000000Gooooo00000000003ooooo00000004ooooo`03o`000000003o
oooo00Cooooo00`00000oooooooooooo0000ooooool0003ooooo00000?ooool00000ooooo`000003
ooooo`0300000?oooooo000000;ooooo00<00000ooooooooool00oooool00`00003oooooooooo`0:
ooooo`0500000?ooooooooooooooo`0000000_ooool200000003ooooo`000000000000gooooo0`00
000Hooooo`d0000000Gooooo0000000000000000ooooo`03000000;ooooo200000001Oooool00000
00000000003ooooo00<0000000Kooooo0000000000000000ooooo`000004ooooo`<0000000Gooooo
0000000000000000ooooo`0200000003ooooo`000000000000L000005oooool00`00003ooooo0000
000<ooooo`T000000_ooool00`00003oooooooooo`07ooooo`009_ooool200000005ooooo`00003o
ooooooooo`0000002oooool01000003oooooooooo`000003ooooo`0300000?oooooooooo00@00000
00?ooooo00000?ooool00oooool00ol0003oooooooooo`0300000004ooooo`00003ooooo000000Go
oooo00<00000ooooooooool04?ooool500000004ooooo`0000000000000000cooooo0P00000Goooo
o`@000005oooool3000000?ooooo0`000002ooooo`@0000000?ooooo0000000000000P000002oooo
o`<000005?ooool6000001Kooooo00<00000ooooo`0000003?ooool200000003ooooo`00003ooooo
00<000002Oooool002Kooooo0P0000000oooool0000000000002ooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool02_ooool200000003ooooo`000000000000;ooooo2@000002ooooo`80
000000Cooooo00000?oooooooooo0P00000=ooooo`<000000oooool01P00003ooooo00000?ooool0
0000ooooo`8000003?ooool2000000cooooo0`000008ooooo`<00000C_ooool3000000[ooooo0`00
000:ooooo`0300000?ooool0000000[ooooo0P0000001?ooool00000ooooo`000009ooooo`009_oo
ool200000003ooooo`0000000000008000001Oooool01@00003ooooo00000?ooool0000002_ooooo
00<00000ooooo`0000000_ooool01000003oooooooooooooool3000000;ooooo0`00000:ooooo`<0
00002?ooool700000004ooooo`0000000000000000Cooooo0`00001Dooooo`8000001_ooool20000
0003ooooo`000000000000<0000000?ooooo0000000000001oooool01000003ooooo00000000000:
ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00H0000000?ooooo0000
0000000010000002ooooo`H000007oooool600000003ooooo`00000000000080000000?ooooo0000
000000000_ooool3000000_ooooo0P000007ooooo`<000002_ooool2000000;ooooo0`00000Joooo
o`<000008Oooool3000001Wooooo0P000003ooooo`<000001oooool200000004ooooo`0000000000
000000Kooooo00<00000ooooo`0000001_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`05ooooo`H000001oooool00`00003ooooo0000000500000004ooooo`00003ooooo
000000gooooo00<00000ooooooooool0200000000oooool00000ooooo`06ooooo`D000003?ooool0
0`00003oooooooooo`05ooooo`<000003?ooool200000004ooooo`00003ooooo000000oooooo>@00
00000oooool0000000000006000000oooooo0`0000001?ooool0000000000000000:ooooo`050000
0?ooooooooooooooo`0000001_ooool01@00003oooooooooooooool0000000Wooooo000Vooooo`03
o`000?ooool0000001?ooooo1@000004ooooo`0300000?ooool0000000;ooooo00<00000ooooo`00
00000P000002ooooo`0500000?ooool00000ooooo`0000001oooool4000001Gooooo00<00000oooo
o`0000001oooool00`00003oooooooooo`0<ooooo`0300000?oooooooooo008000003?ooool60000
0003ooooo`000000000000T000001OoooolN000000Kooooo4P00000=ooooo`H000003?ooool30000
00Kooooo0P000009ooooo`009_ooool01?l0003oooooooooooooool2000001Sooooo0`000002oooo
o`0300000?oooooooooo00[ooooo00<00000ooooo`0000000P00000Iooooo`0300000?oooooooooo
00Gooooo0`00000>ooooo`@000002oooool500000003ooooo`000000000000<00000@Oooool70000
0004ooooo`0000000000000000[ooooo00<00000ooooooooool00P00000?ooooo`8000000oooool0
0`00003oooooooooo`07ooooo`009_ooool00`00003oooooooooo`04ooooo`0300000?ooool00000
01[ooooo0P0000001Oooool0000000000000003ooooo0080000000Cooooo00000000000000006_oo
ool2000000Oooooo00<00000ooooo`0000003_ooool00`00003oooooooooo`02000000Wooooo0`00
00000oooool0000000000003000004gooooo1`0000000oooool00000ooooo`09ooooo`D000003?oo
ool01000003ooooo000000000009ooooo`009_ooool2o`000004ooooo`0000000000000000Gooooo
00@00000ooooo`0000000000>Oooool3000000Oooooo0P00000?ooooo`@000002Oooool7000005Oo
oooo2P000006ooooo`8000000oooool00`00003oooooooooo`09ooooo`03o`000000003ooooo00So
oooo000Vooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool01_ooool00`00003ooooo
0000000booooo`0300000?ooool0000000Oooooo00<00000ooooo`0000003oooool200000003oooo
o`000000000000Oooooo1`00001Pooooo`D0000000?ooooo00000?ooool01oooool5000000Sooooo
00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool01oooool200000003ooooo`00
003ooooo00Gooooo00D00000ooooo`00003ooooo0000000Xooooo`80000000?ooooo00000?ooool0
1oooool20000017ooooo0P000008ooooo`L00000J?ooool400000004ooooo`00003ooooo000000Co
oooo0P000002ooooo`8000001Oooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`0;ooooo`0400000?ooool00000000000Sooooo00D00000ooooo`0000000000ooooo`020000
01[ooooo1@00000:ooooo`8000004Oooool4000000Oooooo1P00001_ooooo`@0000000?ooooo0000
0?ooool01oooool400000003ooooo`00003ooooo00Sooooo000Cooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`?o00001?ooool00ol0000000000000000?ooooo`8000003Oooool02@00003o
oooo00000000003ooooo00000?ooool00000ooooo`02000000Gooooo00D00000ooooo`0000000000
ooooo`0200000003ooooo`000000000000gooooo0P00000?ooooo`80000000?ooooo00000?ooool0
1oooool60000023ooooo5000000@oooooa@000007_ooool7000000Gooooo10000009ooooo`004_oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooooooool0
0000ooooo`00000@ooooo`<000005?ooool4000001Cooooo0`00000?ooooo`D000001oooool50000
01Kooooo3P00000Boooooa4000005?ooool>000001Gooooo1`000003ooooo`0300000?oooooooooo
00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo1Ol00004ooooo`03o`000?oooooooooo
00;ooooo1@0000000oooool000000000000=ooooo`@000009Oooool3000000kooooo0`000002oooo
o`0300000?oooooooooo00Gooooo1000000Dooooo`D00000Doooool7000001;ooooo1`000009oooo
o`004_ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo0P000000
0oooool00000ooooo`08ooooo`D000002oooool3000002;ooooo0P00000;ooooo`<0000000?ooooo
0000000000000P000008ooooo`@000004oooool4000005kooooo1@00000Aooooo`<000002Oooool0
01;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`04o`000?ooool0
0000ooooo`<000002?ooool3000000;ooooo0`000002ooooo`P000008Oooool500000004ooooo`00
00000000ooooo`<0000000Cooooo00000000000000002_ooool50000017ooooo1000000;ooooo`04
00000?l0003o0000ooooo`;o000000Cooooo00000?oooooo00000_ooool200000005ooooo`000000
0000ooooo`000000;oooool01000003ooooo00000?ooool300000003ooooo`00003o000000;o0000
00@00000o`000?l0003o00002oooool3000000oooooo00<00000ooooooooool01oooool001;ooooo
00Co0000oooooooooooo00002Oooool2o`0000Gooooo00?o0000ooooooooool00oooool6000000So
oooo1@000002ooooo`800000;?ooool3000000?ooooo00<00000ooooooooool01oooool200000004
ooooo`00000000000000013ooooo0`000009ooooo`0700000?ooool0000000000?ooool00000o`00
000Aooooo`<000001?l000000`00003o0000ooooo`0Looooo`<000000ol000000ooooooo0000oooo
o`0Aooooo`0500000?ooooooooooooooool000002_ooool300000003ooooo`00003ooooo00Sooooo
00<00000ooooooooool01oooool001?ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01oooool01P00003ooooo00000000003ooooo000000cooooo0`000002ooooo`80
000000Gooooo0000000000000000ooooo`0200000003ooooo`000000000000d0000000?ooooo0000
000000000`0000001Oooool0000000000000003ooooo00<000003_ooool60000017ooooo0`000007
ooooo`0400000?oooooooooo000002;ooooo100000000ol0003oooooooooo`0@ooooo`0300000?l0
003o000000<000008Oooool2000000?ooooo00<00000ooooooooool00oooool200000003ooooo`00
0000000000Gooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool02oooool8
000003cooooo1`00000Aooooo`<000002Oooool00`00003oooooooooo`0Xooooo`?o000010000008
ooooo`0300000?oooooo00000080000000?o0000ooooooooool0:_ooool2000000Kooooo00<00000
ooooo`0000000P0000000oooool00000ooooo`08ooooo`009_ooool20000017ooooo1@0000001?oo
ool0000000000000000booooo`P000004_ooool2000000Kooooo00@00000oooooooooooo0000<_oo
ool2o`0000X000000_l0000aooooo`<000001oooool2000000Wooooo000Vooooo`04o`000?ooool0
0000ooooo`8000004_ooool900000003ooooo`00003ooooo02Gooooo2P00000Booooo`<000001_oo
ool2o`0000_ooooo1_l000000`00003o0000o`000002o`000003ooooool0003o000000;o00006ooo
ool2o`00000800000?ooool00000ooooo`00003ooooo00000?ooool2000000;o000000<00000o`00
0?ooool06_ooool7o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000002?ooool2
000000;o00000_ooool00`00003oooooooooo`07ooooo`009_ooool00`00003o0000ooooo`04oooo
o`80000000?ooooo00000?ooool04_oooolO00000003ooooo`000000000000l000005?ooool30000
00Gooooo00?o000000000?l000002Oooool01000003o0000o`000?l0000@ooooo`?o00005_ooool2
o`0000<000003?ooool00`00003o0000o`000002o`0001Kooooo0_l0000?ooooo`;o000000Cooooo
o`000?l0003o00002?ooool00ol000000000ooooo`08ooooo`009_ooool00ol0003oooooo`000002
o`0000Kooooo00@00000ooooo`00000000005OoooolU000001Sooooo0P000006ooooo`0300000?l0
003ooooo00Oooooo00Co0000ooooool0003o00005_ooool00ol000000000ooooo`0Booooo`030000
0?l0003o000001Gooooo00<00000ooooool000004oooool2o`0001Gooooo00?o0000ooooool00000
0_l00004ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Cooooo00<0
0000ooooooooool01Oooool4000004_ooooo0`000006ooooo`8000002Oooool2o`0001[ooooo00?o
0000ooooooooool03oooool00`00003o00000000000Jooooo`8000000_l0000@ooooo`;o00006?oo
ool00ol0003oooooooooo`03o`0000Wooooo000Vooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool01Oooool5000004?ooooo0`000008ooooo`0300000?oooooooooo00Kooooo0_l0
000Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07oooool01000003oooooo`00
0?l0000?ooooo`03o`000000003ooooo01[ooooo00<00000ooooooooool01oooool002Kooooo00Co
0000oooooooooooooooo0_l0000:ooooo`8000001_ooool4000003cooooo10000007ooooo`800000
1oooool2o`0001oooooo0_l0000<ooooo`0300000?l0003o000002Oooooo0_l0000>ooooo`;o0000
6Oooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`04ooooo`0400000?l0
003o0000o`0000[ooooo00<00000ooooooooool01?ooool4000003Gooooo0`000008ooooo`030000
0?oooooooooo00Oooooo0ol0000Oooooo`;o00002oooool3o`0002cooooo00@00000ooooooooool0
00002oooool3o`0001Kooooo00<00000ooooooooool01oooool000Oooooo0ol0000Looooo`03o`00
0?oooooooooo00Wooooo0ol00008ooooo`0300000?oooooooooo00Kooooo1P00000/ooooo`<00000
2oooool00`00003oooooooooo`06ooooo`0300000?l0003ooooo01oooooo0_l0000:ooooo`800000
3_oooolIo`0000cooooo0P0000000ol0003ooooo00000009ooooo`?o00004oooool00`00003ooooo
ooooo`07ooooo`002?ooool00ol0003oooooooooo`0Kooooo`0300000?oooooooooo00_ooooo00Co
0000ooooool0003o00002?ooool2000000[ooooo1@00000Sooooo`@000002oooool00ol0003ooooo
ooooo`07ooooo`;o00003oooool00`00003oooooooooo`0?ooooo`;o00002Oooool00`00003o0000
0000000:ooooo`Go00006Oooool7o`0000[ooooo0P0000000ol0003oooooooooo`08ooooo`;o0000
4?ooool00`00003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`0Kooooo`;o00003ooo
ool2o`000003ooooool0003ooooo00Oooooo00<00000o`000?l000002oooool6000001Sooooo1P00
000;ooooo`03o`000000003ooooo00Wooooo00?o0000ooooooooool07oooool2o`0000Wooooo00<0
0000ooooooooool02Oooool4o`0002Cooooo1Ol00009ooooo`;o000000<00000ooooooooool01Ooo
ool01?l000000000ooooool0000<ooooo`03o`000000003ooooo00Sooooo0008ooooo`;o00007?oo
ool00ol0003oooooooooo`0Aooooo`0300000?l0003o000000Wooooo00Go0000ooooool000000000
o`00000<oooooaT000003Oooool2o`00000300000?oooooooooo00Sooooo0_l0000Pooooo`;o0000
2?ooool00ol0003oooooooooo`09ooooo`?o0000;Oooool5o`0000Sooooo00?o0000ooooooooool0
1_ooool3o`0000_ooooo00<00000ooooooooool01oooool000Oooooo0_l000000ooooooo0000o`00
000Jooooo`03o`000?oooooooooo01Gooooo0_l0000<ooooo`0300000?oooooo000002cooooo0`00
000;ooooo`;o00007oooool00`00003o0000o`000009ooooo`03o`000?oooooooooo00Gooooo1?l0
000eooooo`Co00001oooool00ol0003oooooooooo`07ooooo`Co00001_ooool00`00003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`0Gooooo`;o00003oooool00`00003oooooooooo`0U
ooooo`8000003Oooool2o`0001oooooo0_l00007ooooo`;o00002?ooool3o`0003cooooo1Ol00005
ooooo`;o00002_ooool3o`0000;ooooo00<00000ooooooooool01oooool002Kooooo00?o00000000
0?ooool06_ooool00ol0003oooooooooo`0=ooooo`@000007oooool00ol0003ooooo0000000?oooo
o`03o`000?oooooooooo01_ooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo0ol00014oooo
o`Co00002?ooool00`00003oooooooooo`04ooooo`04o`000?oooooooooo000000Wooooo000Voooo
o`?o00000_ooool00ol0003oooooooooo`0Fooooo`;o00004?ooool2000000;o00006_ooool2o`00
01;ooooo00?o0000ooooooooool06?ooool2o`0000Wooooo0_l00006ooooo`Co0000B_ooool5o`00
00Oooooo00<00000ooooooooool00oooool00`00003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`02ooooo`0600000?l0003o0000ooooo`00003o00005?ooool2o`0001?ooooo00Go0000
ooooool0003ooooo0000000Cooooo`80000000?o0000ooooooooool04_ooool00ol000000000oooo
o`0Dooooo`;o000000?oooooo`000?ooool01oooool2000000Gooooo0ol0000GooooobOo00005?oo
ool01?l0003oooooo`000?l00006ooooo`80000000?o00000000000000002Oooool002Kooooo0P00
0008ooooo`?o000000Coooooo`000?l0003o00003_ooool2o`0001Oooooo0`0000000ol0003ooooo
ooooo`0;ooooo`0400000?l000000000000001Oooooo0_l0000@ooooo`?o00002_ooool00ol00000
000000000005ooooo`?o00005?ooool;o`000003ooooool0003o000000Ko00002Oooool4o`000003
ooooool0003o000000ko00004_ooool01?l0003oooooo`000?l00005ooooo`03o`000000003ooooo
00Sooooo000Vooooo`03o`000?oooooooooo00<0000000?o0000ooooooooool01oooool00ol0003o
ooooo`000002o`000004ooooool0003o0000ooooo`Oo00006oooool2o`0000@0000000Cooooo0000
0?oooooooooo10000002o`0001_ooooo1?l000000ooooooo0000o`000009o`0000[ooooo00<00000
ooooo`0000001_ooool3o`0001;ooooo2_l0000Vooooo`04o`000?oooooo0000ooooo`So00004Ooo
ool4o`000003ooooo`00003ooooo00Sooooo000Vooooo`;o00001oooool2o`00000300000?oooooo
oooo02oooooo00<00000o`000000000020000003o`0003;ooooo00<00000ooooooooool01_ooool3
o`0001;ooooo2?l0000booooo`?o000000?oooooo`000?l000000ol0000Aooooo`;o00002Oooool0
02Kooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`06ooooo`03o`000?oooooo0000
02[ooooo0ol000000`00003ooooo00000008ooooo`8000000_l000000`00003o00000000000Zoooo
o`03o`000?oooooooooo00Oooooo0_l0000Booooo`Ko0000?Oooool00ol0003oooooo`000005o`00
00gooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool01Oooool3o`0000Wo
oooo0_l0000Pooooo`Co00000`00000Booooo`Go000000?ooooo00000?ooool08?ooool00ol0003o
ooooo`000007ooooo`?o00004Oooool3o`000003ooooool0003o000000cooooo00?o0000oooooooo
ool00_l00002ooooo`;o000000?oooooo`000?l000004ol000001?oooooo0000o`000?ooool3o`00
0005ooooool0003o0000o`000?ooool00ol0000<ooooo`03o`000?oooooo000000Co00002?ooool0
0`00003oooooooooo`07ooooo`004oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`00
00Gooooo00?o0000ooooooooool02Oooool3o`0000_ooooo00H00000ooooooooool00000ooooo`00
000@ooooo`0500000?ooool00000o`00000000000_l000000`00003oooooooooo`0Looooo`800000
00Ko000000000000003o0000ooooool0000@ooooo`80000000Ko0000ooooool000000000ooooool0
0009ooooo`?o00004?ooool3o`000003ooooool0003o000000Wooooo00Co0000oooooooooooooooo
0ol0000]ooooo`03o`000?oooooooooo00Go00002?ooool6o`0000Gooooo00<00000ooooooooool0
1oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool03Oooool4o`0000cooooo00?o00000000000000000P0000000ol0003o
ooooo`000002000000;o000000?oooooo`000?ooool0;_ooool01@00003oooooo`000?l0003ooooo
00;o00000_ooool02000003ooooo00000?ooool00000o`000?ooool000003Oooool4o`00017ooooo
0_l000001?oooooo0000o`000?l00009ooooo`[o000000?oooooo`000?l000000ol0000Qooooo`Go
000000?oooooo`000?l000000_ooool3o`0000?ooooo0ol00007ooooo`Go000000?ooooo00000?oo
ool02?ooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo1?l0000@ooooo`Go0000G_ooool5o`0001;ooooo1Ol00007ooooo`Co000000?oooooo`00
0?l000003?ooool2o`0002;ooooo0ol0000;ooooo`Go00002Oooool01?l0003oooooo`000?l00009
ooooo`004_ooool01?l0003oooooooooool00007ooooo`Co00001Oooool8o`00017ooooo2?l0001A
ooooo`Ko00004oooool4o`000003ooooool0003ooooo00Gooooo00Co0000oooooooooooooooo0_l0
000>ooooo`?o00009Oooool4o`0000gooooo0_l000000ooooooo0000o`000003o`0000;ooooo0`00
0009ooooo`004_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool7o`0001Gooooo4Ol0000=oooooaKo00003_ooool@o`0001Kooooo0ol0
00000ooooooo0000ooooo`05ooooo`Ko00003oooool3o`0001?ooooo1Ol000000ooooooo0000oooo
o`0Aooooo`Co00004?ooool2o`0000;ooooo00<00000ooooooooool01oooool001;ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`05ooooo`Co00001Oooool2o`000003ooooool0
003o000000;o00008_ooool>o`0001Gooooo3_l0000Sooooo`Ko00002?ooool00ol0003oooooo`00
000?ooooo`Co00003?ooool2o`000007ooooool0003o0000ooooool0003oooooo`000007ooooo`08
o`000?oooooo0000ooooool0003oooooo`000?ooool2o`0000gooooo0ol0000>ooooo`;o000000<0
0000ooooooooool01oooool001?ooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooo`000003
o`0000Sooooo1_l0001_ooooo`?o000000?oooooo`000?l000001oooool5o`00013ooooo0_l0000:
ooooo`Go00006_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Sooooo00?o0000
ooooool000003Oooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`03oooo
o`;o00000_ooool2o`0000Kooooo1ol0001Wooooo`Oo00002?ooool2o`00017ooooo0_l00008oooo
o`04o`000?oooooo0000o`0002Sooooo00Go0000ooooool0003oooooo`000006ooooo`04o`000?oo
oooo0000o`0000Wooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooo`000002o`0000Sooooo00?o0000ooooool000001Ol0001Oooooo`Oo00002?oo
ool01?l0003oooooo`000?l0000?ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool00000
<_ooool00ol0003oooooo`000009ooooo`;o00001?ooool00`00003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooooooo`;o00001oooool9o`0005Kooooo
2?l00009ooooo`Co00003oooool3o`0000Kooooo0ol0000iooooo`04o`000?oooooo0000o`0000Ko
oooo00Go0000ooooool0003ooooo00000009ooooo`009_ooool2o`000003ooooool0003ooooo00_o
oooo1_l00009ooooo`03o`000?oooooo000000Oo0000C?ooool9o`0000Wooooo0_l00002ooooo`;o
00003_ooool2o`0000Oooooo0_l0000Jooooo`?o000000Coooooo`000?l0003ooooo0ol000001?oo
oooo0000o`000?l0000Iooooo`03o`000?oooooo000000Gooooo00?o000000000?ooool02?ooool0
02Kooooo00Co0000oooooooooooooooo0_l0000?ooooo`;o00000_ooool2o`0000Wooooo3?l00010
ooooo`_o00002oooool5o`0000gooooo0ol00005ooooo`03o`000?oooooo000001Wooooo0ol0000A
ooooo`?o00006Oooool01Ol0003oooooooooool00000000000Wooooo000Vooooo`?o00001Oooool3
o`0000cooooo1_l0000=ooooodKo000000?oooooo`000?l000000ol0000=ooooo`;o00000_ooool0
0ol0003oooooooooo`0;ooooo`;o00002?ooool00ol0003oooooooooo`0Dooooo`Co00001?ooool0
2?l0003oooooooooool0003oooooo`000?oooooo00000_ooool3o`0000;ooooo00Go0000ooooool0
003oooooo`000004ooooo`Co000000?oooooo`000?ooool04oooool00`00003oooooooooo`07oooo
o`009_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_l00009oooo
o`;o000000?oooooo`000?l000000_l0000?ooooo`03o`000?oooooo000001Co000000?oooooo`00
0?l000006ol000000ooooooo0000o`000009o`00013ooooo00Co0000ooooool0003ooooo0ol0000:
ooooo`?o00002?ooool00ol0003oooooooooo`0:ooooo`Go00002Oooool6o`000005ooooool0003o
ooooooooool000003Oooool00ol0003oooooooooo`08o`0000Sooooo1_l00007ooooo`0300000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001oooool2
o`000003ooooool0003o000000Oooooo0ol00003ooooo`?o0000FOooool3o`0000?ooooo00?o0000
ooooooooool01_ooool01?l0003oooooo`000?l00008ooooo`;o00002oooool3o`000005ooooool0
003o0000o`000?ooool01?l000000ooooooo0000o`000003o`00027ooooo1Ol000000ooooooo0000
o`00000<o`0000;ooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool02?oo
ool2o`000003ooooool0003ooooo00Kooooo0_l000000ooooooo0000o`000006o`0000Kooooo0_l0
001Dooooo`?o00001Oooool:o`0000Sooooo0ol0000:ooooo`?o00000_ooool3o`0000Kooooo00Co
0000oooooooooooo0000:oooool2o`0000Oooooo1?l000000ooooooo0000o`000009ooooo`009_oo
ool01?l0003oooooo`000?ooool2o`0000[ooooo00?o0000ooooool000005oooool4o`0004gooooo
0ol0000Gooooo`;o00003?ooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo00;o
oooo0ol0000=ooooo`?o000000?oooooo`000?ooool03Ol000001_oooooo0000o`000?l0003ooooo
o`0000;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
0000o`000?ooool00_l00009ooooo`009_ooool3o`000003ooooool0003o000000;o00003?ooool0
0ol0003oooooo`00000Fooooo`Ko00005?ooool3o`0000;ooooo1?l00002ooooo`?o00000_ooool3
o`0000?ooooo0ol00002ooooo`;o00004oooool4o`0001Oooooo00?o0000ooooool000002oooool3
o`000006ooooool0003o0000o`000?oooooo00004_ooool01Ol0003oooooooooool0003ooooo00;o
00000_ooool00`00003o0000ooooo`04ooooo`06o`000?ooooooooooooooo`00003ooooo0ol00002
ooooo`0400000?oooooo0000ooooo`;o000000Gooooo00000?l0003oooooo`000009ooooo`07o`00
0?ooooooooooo`000?oooooo000000000009ooooo`009_ooool00ol0003oooooooooo`0:o`0000_o
oooo00?o0000ooooool000006?ooool6o`000003ooooool0003o000000;o000000Goooooo`000?l0
003o0000ooooo`03o`0000?ooooo0_l000001Ooooooo0000o`000?l0003ooooo00?o000000Cooooo
o`000?l0003o00000_ooool7o`000003ooooool0003ooooo00;o000000Goooooo`000?l0003o0000
ooooo`03o`000003ooooool0003o000000Oo00006Oooool2o`0000gooooo0_l000001_oooooo0000
o`000?l0003oooooo`0000Cooooo00?o0000ooooooooool01oooool00`00003oooooo`000004oooo
o`0300000?oooooooooo00Cooooo00?o0000ooooooooool00ol000000ooooooo0000ooooo`02oooo
o`0500000?ooooooooooooooool000001?ooool00ol000000000ooooo`03ooooo`05o`000?oooooo
0000ooooo`0000000_l0000<ooooo`0300000?oooooooooo00Oooooo000Vooooo`;o00001oooool5
o`0000kooooo0_l000000ooooooo0000o`00000Rooooo`Oo00006?ooool8o`0002;ooooo1?l0000>
ooooo`Co00001_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooooooo`;o000000D0
0000o`000?l000000000o`000003ooooo`0300000?oooooooooo01?ooooo00<00000ooooooooool0
0oooool01`00003ooooo00000?oooooo0000ooooool000001Oooool00ol0003oooooooooo`04oooo
o`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`?o
00004oooool01?l0003oooooo`000?l0000Mooooo`03o`000?oooooooooo02Gooooo0ol0000Loooo
o`?o00005Oooool01?l0003oooooooooooooool2o`0000Wooooo0_l00002ooooo`04o`000?oooooo
ooooooooo`8000000_ooool00ol0003oooooooooo`06ooooo`0700000?l000000000o`000?ooool0
0000o`000002ooooo`0;00000?ooooooooooo`000?ooool00000ooooool000000000o`0000000000
2Oooool00ol0003oooooooooo`02o`000006ooooool0003o000000000?oooooo00000oooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o
00005_ooool01Ol0003oooooo`000?oooooo000001Oooooo0ol0000Vooooo`;o00006?ooool2o`00
0003ooooool0003ooooo01Gooooo0_l00002ooooo`03o`000?oooooooooo00cooooo00Ko00000000
0?oooooo0000ooooool00007ooooo`0400000?l000000000ooooo`;o00005?ooool01ol000000000
o`000000003oooooo`00000000001oooool01Ol0003oooooo`000?oooooo000000Cooooo00<00000
ooooooooool01oooool002Kooooo00Ko0000oooooooooooo0000ooooool00007ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool04oooool00ol0003oooooo`000003o`0001?ooooo
00Co0000ooooool0003o00008_ooool2o`0001Gooooo1?l0000Fooooo`03o`000?oooooooooo00;o
oooo0_l0000?ooooo`03o`000?oooooooooo00Oooooo00<00000o`000?l000008oooool01_l0003o
ooooooooo`00003o0000000000Wooooo00<00000ooooooooool01oooool002Kooooo00?o00000000
0?ooool00_ooool2o`000003ooooool0003ooooo00Oooooo2?l000000ooooooo0000ooooo`0Eoooo
o`06o`000?oooooo0000o`000?oooooo00004_ooool2o`0001cooooo0ol0000Booooo`03o`000?oo
oooo000000;o00006?ooool3o`0000;ooooo0_l0000:ooooo`03o`000?oooooo000000Gooooo0_l0
0003ooooo`0400000?l0003o0000o`0002cooooo1?l000000`00003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooo000000?ooooo0ol00002ooooo`0300000?oo
oooooooo00Oooooo1Ol00004ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000000_l0
000@ooooo`?o000000?oooooo`000?ooool04_ooool3o`0001;ooooo0ol0000Jooooo`03o`000?oo
oooooooo00;ooooo0ol00008ooooo`;o00000oooool01?l000000000o`000?l00006ooooo`03o`00
0000003o000003Cooooo00Go000000000?l0003o000000000009ooooo`009_ooool3o`0000030000
0?oooooooooo00?ooooo00Ko0000ooooo`00003o0000ooooool0000:ooooo`Co00000_ooool2o`00
00;ooooo00?o0000ooooooooool05_ooool4o`000003ooooool0003ooooo00kooooo0ol000001Ooo
oooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000001Ol0000Aooooo`Co00006Oooool5
o`0000;ooooo0ol00009ooooo`05o`000?oooooo0000o`000?ooool00ol00005ooooo`0300000?l0
003o000003[ooooo0_l00009ooooo`009_ooool02?l0003ooooooooooooooooo000000000?l00000
00001?ooool01000003oooooooooool00003ooooo`03o`000?oooooooooo00Kooooo0ol00002oooo
o`03o`000?oooooo000000;o000000?oooooo`000?l000006Oooool01_l0003oooooo`000?l0003o
ooooo`0002Sooooo0ol000000ooooooo0000ooooo`0Iooooo`Co00000oooool2o`000003ooooool0
003ooooo00Wooooo00Co0000ooooool0000000002?ooool00`00003o0000o`00000mooooo`030000
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Cooooo0ol000001@00003ooooooooo
oooooooo000000;ooooo0_l000001@00003ooooooooooooooooo000000Wooooo00?o0000ooooool0
00001Oooool01?l0003oooooo`000?l0000Kooooo`Go00007oooool5o`0001cooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`07ooooo`;o000000P00000ooooool000000000ooooool0
003oooooo`0000Cooooo0_l0000oooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo00Sooooo00Co000000000?oooooo00000oooool00ol0003oooooooooo`03ooooo`;o0000
2oooool01Ol0003ooooooooooooooooo000000Cooooo0ol0000Mooooo`03o`000?oooooo000000?o
00004oooool2o`000003ooooool0003o000001kooooo0_l00006ooooo`;o000000?oooooo`000?oo
ool02?ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool01?ooool00`00003o
0000ooooo`0Nooooo`0400000?l0003o0000000000;o000000<00000o`000?l000001ol0000Boooo
o`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00gooooo00<00000oooooooo
ool00oooool01000003ooooo00000?ooool2o`0000;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooo`000006ooooo`?o00008?oooolBo`00027ooooo0_l00005ooooo`05o`000?oooooo0000
ooooool000002Oooool01Ol0003oooooo`000?ooool0000000;o000000<00000ooooooooool01?oo
ool00`00003o0000ooooo`0Jooooo`?o000000@00000o`000?l0000000003_ooool00`00003o0000
o`000005o`0000_ooooo00<00000ooooooooool01oooool001?ooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo00oooooo00?o000000000?ooool01ooo
ool00`00003o0000o`000002o`000003ooooool0003ooooo00Sooooo00Ko0000oooooooooooo0000
ooooool00002ooooo`04o`000?ooooooooooo`0004kooooo00?o0000ooooool000001Oooool2o`00
00_ooooo00?o0000ooooool000000_l00004ooooo`0300000?oooooooooo00;ooooo00<00000o`00
0?ooool06?ooool4o`00000300000?oooooooooo01[ooooo00D00000o`000000003o000000000006
ooooo`0300000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01;ooooo00Co000000000?l000000000
1?ooool01Ol0003oooooooooool0003ooooo00;o000000?oooooo`000?l000002oooool3o`0000;o
oooo1?l00007ooooo`?o0000=_ooool3o`0000Oooooo0_l00003ooooo`Co00003?ooool4o`000003
ooooool0003o000000Oooooo0_l0000Hooooo`?o00009Oooool01ol000000000o`000000003o0000
ooooo`0000002Oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Cooooo0ol0000Fooooo`03o`000?oooooo000000?ooooo00Co0000ooooool0003ooooo
0_l000001?ooool00000ooooool0000;ooooo`Go00001Oooool01?l0003oooooooooooooool8o`00
0003ooooool0003ooooo02[ooooo1Ol000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo
00;ooooo1?l0000<ooooo`04o`000?oooooo0000o`0000_ooooo00?o0000ooooooooool05Oooool0
0`00003o0000o`00000/ooooo`0300000?l00000000000Wooooo000Booooo`04o`000?oooooooooo
o`0000Sooooo0ol00005ooooo`03o`000?ooool0000000Co00005_ooool00`00003oooooooooo`05
ooooo`0300000?oooooooooo00;o000000Coooooo`000?oooooo00002oooool2o`0000;ooooo1Ol0
0002ooooo`Co00000oooool4o`0002Gooooo0ol00005ooooo`;o00000oooool2o`0000?ooooo0ol0
000=ooooo`Co00001Oooool2000000Cooooo00<00000o`000?ooool05Oooool00`00003o0000o`00
000`ooooo`0300000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00@00000o`000000003o
00005Oooool00ol0003ooooo00000002ooooo`0300000?oooooooooo00;ooooo0_l000001_oooooo
000000000?l0003oooooo`0000_ooooo00Co0000ooooool0003o00001oooool5o`0000?ooooo0ol0
000Qooooo`;o00001?ooool3o`0000Oooooo00?o0000ooooool000003Oooool01ol000000000oooo
ool0003ooooo00000?l000000_ooool2o`0000Kooooo00?o0000ooooooooool05?ooool2o`000003
00000?oooooooooo033ooooo00<00000ooooooooool01oooool001;ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_ooool4o`00
01Oooooo00?o0000ooooooooool01oooool5o`000003ooooool0003ooooo00gooooo00?o0000oooo
ooooool00ol00003ooooo`Oo00008?ooool7o`0000?ooooo0_l00003ooooo`03o`000?oooooo0000
00cooooo0ol000001@00003o0000o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool0
0`00003oooooooooo`0Dooooo`0300000?l00000000003Cooooo00<00000ooooooooool01oooool0
01?ooooo0_l00009ooooo`?o00001Oooool00ol0003oooooooooo`0:ooooo`?o00005_ooool00`00
003oooooo`000004ooooo`8000001?ooool01P00003o000000000?l0003oooooo`0000cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0_ooooo`06o`000?ooooooooooo`000?oooooo
00003oooool00`00003ooooo0000000<ooooo`0300000?l0003ooooo01Gooooo0_l0000fooooo`03
00000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00gooooo0_l000000`00003o0000
ooooo`0Dooooo`0300000?l00000000000Kooooo00L00000o`000000003o0000ooooo`00003ooooo
00;o00003?ooool01Ol0003ooooooooooooooooo000000?ooooo0ol0000<ooooo`;o000000?ooooo
o`000?ooool01_l000000ooooooo0000o`00000;ooooo`?o00001?ooool2o`0000kooooo00H00000
o`000?ooool00000o`000?ooool3o`000003ooooo`00003ooooo00Cooooo0_l0000Fooooo`;o0000
6oooool00`00003o0000o`00000?o`00000300000?l0003ooooo00Sooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool04?ooool01000003o000000000000000Eooooo`;o0000
1oooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00_ooooo00Ko0000ooooool0
003o0000ooooool00004ooooo`Co000000Coooooo`000?l0003o00003_ooool00ol0003ooooooooo
o`02o`0000;ooooo0ol00006ooooo`03o`000?oooooo000000gooooo0_l00003ooooo`;o00000_oo
ool00ol0003oooooooooo`06ooooo`;o00005_ooool2o`0001Sooooo1?l0000Dooooo`Go000000D0
0000oooooooooooooooo00000009ooooo`009_ooool00ol0003oooooooooo`0Cooooo`03o`000000
003o000001Gooooo00@00000ooooool0000000000_ooool01?l0003oooooooooooooool2o`0000;o
oooo00Go0000ooooooooooooooooo`00000?ooooo`Go00008oooool3o`000003ooooool0003ooooo
00gooooo00Co0000oooooooooooooooo0_l00002ooooo`8000000_ooool01_l0003ooooooooooooo
ool00000o`0001Oooooo00?o000000000?ooool05Oooool3o`0001gooooo1?l000000`00003ooooo
ooooo`07ooooo`009_ooool4o`00000300000?oooooooooo01;ooooo00<00000o`000?l000005_oo
ool00ol0003ooooo00000004ooooo`04o`000?oooooo0000o`0000Oooooo0_l0000>ooooo`Go0000
00?oooooo`000?l000000oooool2o`0000;ooooo00?o0000ooooool000001_l00002ooooo`;o0000
0oooool6o`0001Kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`030000
0?l0003ooooo01Kooooo00?o0000ooooooooool05?ooool3o`0002;ooooo00?o000000000?ooool0
2?ooool002Kooooo00Co0000oooooooooooooooo0_l000000`00003o0000ooooo`0Cooooo`?o0000
5Oooool01?l000000000o`000?l00008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o000000?ooooo
o`000?ooool00oooool2o`000004ooooool0003oooooo`0000;ooooo0_l0000Dooooo`03o`000000
003ooooo00Gooooo00?o000000000?ooool01_ooool2o`0001Oooooo00?o0000ooooooooool04ooo
ool00`00003o00000000000Uooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo00Cooooo0ol000000`00003oooooooooo`0Aooooo`0300000?l0003o000001Kooooo0ol00004
ooooo`03o`000?ooool0000000;ooooo00<00000o`000?l000000_ooool00`00003oooooo`00000k
ooooo`;o00000oooool2o`0000;ooooo00?o0000ooooooooool00_l00004ooooo`03o`000000003o
oooo01Kooooo00?o0000ooooooooool04oooool2o`0002Oooooo00<00000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool02?ooool00ol000000000o`00000Cooooo`;o000000<00000oooo
ooooool05?ooool00`00003o0000o`000002ooooo`05o`000?ooooooooooooooool000000oooool2
o`00000500000?oooooooooo00000?l00000=_ooool3o`0000;ooooo00<00000o`000?ooool00_oo
ool00ol0003oooooooooo`06ooooo`;o00005oooool00ol0003oooooooooo`0Cooooo`03o`000000
003ooooo02Oooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool02_ooool0
1?l000000000o`000000000Booooo`?o00005_ooool2o`00000300000?oooooooooo00?ooooo00Co
000000000000003ooooo0_l00002ooooo`0300000?oooooo000000;o0000<Oooool3o`000005oooo
ool000000000ooooool000000oooool3o`0000Kooooo00?o000000000?ooool05_ooool2o`0001?o
oooo0_l0000Zooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00gooooo
00<00000o`00000000004_ooool3o`0001Kooooo0ol00008ooooo`03o`000000003ooooo00;ooooo
0_l000000`00003o0000o`000003o`0002[ooooo1?l000001@00003oooooo`000?oooooo000000;o
oooo00?o0000ooooool000001oooool00`00003o0000ooooo`0Gooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool05_ooool=o`0000Kooooo00<00000ooooooooool01oooool002Kooooo
00?o0000ooooooooool04?ooool3o`0001;ooooo00?o000000000?ooool05_ooool2o`0000?ooooo
00?o0000ooooooooool01Oooool02?l000000000o`000?oooooo000000000?l0003ooooo1?l00000
1?oooooo0000ooooool0000Kooooo`;o00000_ooool4o`000003ooooool0003ooooo00?o000000?o
ooooo`000?l000000_ooool01@00003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo1Ol0000<ooooo`Go0000
0P000009ooooo`009_ooool3o`0001;ooooo0ol0000Aooooo`03o`000000003o000001Oooooo00<0
0000o`000?ooool01?ooool00`00003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00_o
0000ooooo`00003o0000ooooool0003oooooo`000?oooooo0000ooooo`04o`0001Cooooo1_l00000
1@00003o0000o`000?l0003ooooo00?o000000<00000o`000?ooool00_l00002ooooo`8000001ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo0_l0000Cooooo`?o00005Ooo
ool2o`0000Wooooo000Vooooo`03o`000?oooooooooo00?o000000<00000ooooooooool03_ooool0
0`00003o0000o`00000Booooo`;o00005oooool00`00003o0000ooooo`06ooooo`04o`000?oooooo
0000o`0000Gooooo00Co0000ooooool0000000000ol00003ooooo`03o`000?ooool0000000;o0000
00?oooooo`000?ooool03?ooool2o`00000300000?oooooooooo00;ooooo00So000000000?l0003o
ooooo`000?ooool00000o`00013ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo013ooooo0ol0000Hooooo`0300000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo00?ooooo0ol0000@ooooo`0300000?l00000000001;ooooo00?o00000000
0?ooool05_ooool2o`00000300000?oooooooooo00Oooooo00@00000ooooool0003o00000_ooool2
o`0000;ooooo00Go0000ooooool0003oooooo`000004ooooo`04o`000?oooooo0000ooooo`Co0000
00?oooooo`000?ooool00ol000000`00003oooooooooo`04ooooo`Co00000_ooool01000003ooooo
00000?l00002ooooo`?o000000<00000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo017ooooo0_l0000Aooooo`;o00006_ooool00`00003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`06ooooo`?o00004?ooool2o`00017ooooo00<00000o`000?l00000
5oooool2o`00000300000?oooooooooo00?ooooo00<00000ooooooooool01?ooool01@00003ooooo
00000?l00000000000?ooooo00<00000o`000?ooool01_ooool00ol000000000ooooo`05o`000004
ooooool0003oooooo`0000Kooooo00<00000o`000?l000000_ooool2o`000003ooooool0003ooooo
00?ooooo00Go0000oooooooooooooooo00000006ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`;o00006oooool00`00003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`08ooooo`?o00003oooool3o`00017ooooo0_l000000`00
003oooooooooo`0Fooooo`03o`000000003ooooo00Oooooo00<00000ooooooooool00oooool2o`00
00Kooooo0ol00003ooooo`;o000000?oooooo`000?ooool01?l0000200000005o`000?oooooooooo
ooooo`0000000_l00006ooooo`80000000Co0000ooooooooool000002_ooool00ol000000000oooo
o`0Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool2o`0001cooooo00<0
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool02_ooool3o`0000oooooo0_l0000B
ooooo`;o00006_ooool00ol000000000ooooo`07ooooo`04o`000?ooooooooooooooo`Co00000ooo
ool00ol0003oooooo`000002000000Ko000000?oooooo`000?l000001Ol000001P00003o0000oooo
ool0003ooooo000000?ooooo0_l00002ooooo`03o`000?oooooooooo00[ooooo00<00000o`000?oo
ool06Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool06oooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0<ooooo`?o0000
3oooool2o`0001;ooooo0_l0000Iooooo`03o`000000003o000000cooooo00@00000oooooooooooo
00000_ooool00ol0003oooooooooo`02000000;ooooo0_l000000ooooooo0000ooooo`02ooooo`80
00000_l00003ooooo`04o`000?oooooooooo000000;ooooo0_l000000oooool00000ooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool6o`0000?ooooo00<00000oooo
ooooool01oooool002Kooooo0_l0000?ooooo`?o00003_ooool00`00003o00000000000Aooooo`;o
00006oooool2o`00000300000?oooooooooo00Kooooo0_l00002ooooo`0400000?oooooo00000000
00;ooooo00@00000o`000?oooooooooo0_l000000ooooooo000000000003ooooo`04o`000?ooool0
0000000000;o00000_ooool3o`000004ooooool0003o0000o`0000;ooooo0_l00009ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00oooooo1?l00004ooooo`Go00002Oooool002Kooooo1Ol0000>ooooo`?o00003_oo
ool2o`00017ooooo00<00000o`000?l000006oooool2o`00000300000?oooooooooo00Oooooo00Ko
0000oooooooooooo0000ooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool00004ooooo`07o`000?ooooooooooooooo`00003oooooo`00000:ooooo`;o0000
7?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o000000000?ooool0
3_ooool3o`0000[ooooo00?o000000000?ooool02?ooool002Kooooo00Co0000oooooooooooooooo
0ol0000>ooooo`;o00003_ooool2o`0001;ooooo0_l0000Looooo`;o00003Oooool02Ol0003ooooo
oooooooooooo0000ooooo`00003o0000ooooo`02o`0000;ooooo00?o000000000?ooool00_ooool2
o`0000Cooooo0_l00003ooooo`0300000?oooooooooo00Wooooo00?o0000ooooooooool06oooool2
o`0001;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`;o00003Oooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`03ooooo`?o00003Oooool2o`00
00kooooo0_l0000Booooo`0300000?l0003ooooo01cooooo0_l00005ooooo`05o`000?oooooooooo
00000?ooool00_l000001000003oooooooooo`000002ooooo`06o`000?oooooo0000ooooool00000
00000_ooool2o`0000;ooooo00Co0000ooooo`00003o00000oooool2o`00000400000?oooooooooo
000000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo013ooooo00<00000o`000?ooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool01Oooool3o`00
00gooooo0_l0000>ooooo`;o00004_ooool00ol0003oooooooooo`0Kooooo`;o00003?ooool01@00
003ooooooooooooooooo000000;ooooo00<00000ooooooooool00_l000001?oooooo0000o`000?oo
ool3o`0000Cooooo00Co0000ooooooooool000003Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00cooooo00<00000ooooooooool01oooool001kooooo0ol00005ooooo`03o`000?oo
oooooooo00Oooooo0_l0000=ooooo`03o`000000003ooooo00gooooo0_l0000Booooo`;o00007?oo
ool00ol0003oooooooooo`06ooooo`0300000?oooooooooo00Kooooo0P0000000ooooooo0000oooo
o`08ooooo`;o000000Coooooo`000?l0000000002?ooool00`00003oooooooooo`05ooooo`030000
0?l0003ooooo01_ooooo0_l0000Booooo`;o00003_ooool2o`0000gooooo00?o0000ooooooooool0
3?ooool00`00003oooooooooo`07ooooo`007oooool00ol0003oooooooooo`04ooooo`0300000?oo
oooooooo00Sooooo0_l0000=ooooo`;o00003_ooool2o`0000Cooooo00<00000ooooooooool02ooo
ool2o`0001_ooooo00?o000000000?ooool00_ooool00`00003oooooooooo`05ooooo`03o`000?oo
oooooooo00;o000000?oooooo`000?l000000_ooool01000003ooooo00000?l00002ooooo`03o`00
0?oooooooooo00Cooooo00<00000ooooooooool00_l000000ooooooo0000ooooo`09ooooo`040000
0?oooooo0000000001_ooooo00?o0000ooooooooool03_ooool01000003oooooooooool0000?oooo
o`03o`000?oooooooooo00_ooooo0_l0000=ooooo`0300000?oooooooooo00Oooooo000Oooooo`03
o`000?oooooooooo00Cooooo00<00000ooooooooool02Oooool2o`0000[ooooo00?o0000oooooooo
ool00_l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00`00003o
ooooooooo`09ooooo`03o`000?oooooooooo00;o00001oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo00000009ooooo`03o`000?oooooo0000
00Wooooo00P00000ooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool00`00003ooooo
o`00000;ooooo`0400000?ooooooooooo`0000Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000002oooool01@00003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooo`00000;ooooo`0300000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo
00Cooooo00?o00000000000000002P000002o`0004d0000000?o00000000000000003`0000001?l0
0000000000000?l0000600000003o`0000000000000000D0000000?o00000000000000004@000000
0ol0000000000000000]00000003o`0000000000000000d0000000?o000000000000000030000000
0ol0000000000000000;000000Wooooo000Oooooo`03o`000?oooooooooo0?kooooo000Nooooo`;o
0000ooooool1ooooo`007oooool00ol0003oooooooooo`3nooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.158908, -0.161707, \
0.00416367, 0.00673696}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Area-Preservation (Evolution of a Box of Initial Conditions)", "Section"],

Cell["\<\
To illustrate the area-preserving nature of the Standard Map we \
start with a large number of initial points scattered randomly throughout \
some region.  By applying the map to all of these points we find that this \
region is mapped to a new region that has a different shape but the same \
area.  Repeated application of this procedure further distorts the shape of \
the region, but the area remains constant.\
\>", "Text"],

Cell[TextData[{
  "In the example below we start with 5000 points randomly distributed in \
ther rectangular region 0.4<\[Theta]<0.6 and 0<r<0.12.  The map is iterated 4 \
times (",
  StyleBox["niter=4", "Input"],
  ") for these points and the resulting set of points is plotted."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(K = 1.5; \[Theta]min = 0.4; \[Theta]max = 0.6; rmin = 0; rmax = 0.12; 
    n = 5000; niter = 4;\), "\n", 
    \(\(f[{\[Theta]_, r_}] := 
        N[{Mod[\[Theta] + r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1], 
            Mod[r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1]}];\)\), "\n", 
    \(\(MapData\  = \ 
        Table[Nest[
            f, {Random[Real, {\[Theta]min, \[Theta]max}], 
              Random[Real, {rmin, rmax}]}, niter], {i, 0, n}];\)\), "\n", 
    \(ListPlot[MapData, PlotStyle \[Rule] PointSize[0.002], 
      PlotRange \[Rule] {{0, 1}, {0, 1}}, Frame \[Rule] True, 
      RotateLabel \[Rule] False, 
      FrameLabel \[Rule] {"\<\[Theta]\>", "\<r\>", "\<\>", "\<\>"}]\)}], \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.67702 .42001 Mdot
.60181 .08954 Mdot
.55576 .52438 Mdot
.37096 .13529 Mdot
.58778 .50716 Mdot
.28037 .52599 Mdot
.54402 .50788 Mdot
.63728 .59101 Mdot
.48536 .09201 Mdot
.86373 .37257 Mdot
.38926 .02485 Mdot
.27499 .52375 Mdot
.46537 .07728 Mdot
.33262 .19263 Mdot
.37369 .12616 Mdot
.54928 .51171 Mdot
.37715 .12838 Mdot
.47802 .11791 Mdot
.71623 .35517 Mdot
.42264 .038 Mdot
.44467 .07147 Mdot
.66446 .06973 Mdot
.62255 .09688 Mdot
.62828 .50278 Mdot
.58864 .49977 Mdot
.39844 .12249 Mdot
.43038 .05243 Mdot
.48101 .12735 Mdot
.5398 .50814 Mdot
.40265 .02802 Mdot
.47548 .09554 Mdot
.60923 .50536 Mdot
.6944 .12393 Mdot
.50211 .11545 Mdot
.62962 .58981 Mdot
.50329 .1239 Mdot
.47918 .11408 Mdot
.63255 .58693 Mdot
.58357 .55658 Mdot
.33399 .18072 Mdot
.61712 .09476 Mdot
.41964 .04493 Mdot
.66411 .47361 Mdot
.33376 .16742 Mdot
.68154 .39815 Mdot
.50931 .05307 Mdot
.64979 .49117 Mdot
.66761 .4485 Mdot
.23925 .26857 Mdot
.27593 .26851 Mdot
.77123 .35411 Mdot
.38241 .02728 Mdot
.11443 .24169 Mdot
.60941 .50319 Mdot
.52884 .51827 Mdot
.37842 .1278 Mdot
.41029 .01802 Mdot
.50555 .10518 Mdot
.4164 .02497 Mdot
.88276 .3782 Mdot
.50584 .12888 Mdot
.41846 .059 Mdot
.60822 .50042 Mdot
.55507 .5209 Mdot
.41705 .02462 Mdot
.40023 .04497 Mdot
.46907 .08613 Mdot
.6579 .06738 Mdot
.48248 .11693 Mdot
.41376 .0336 Mdot
.39863 .02305 Mdot
.52475 .12034 Mdot
.94076 .18173 Mdot
.43057 .05061 Mdot
.54138 .51385 Mdot
.4412 .11961 Mdot
.97369 .40729 Mdot
.47305 .0978 Mdot
.3324 .18973 Mdot
.27795 .26636 Mdot
.44043 .06928 Mdot
.43323 .06065 Mdot
.56104 .07303 Mdot
.67232 .44889 Mdot
.32684 .2073 Mdot
.47791 .12569 Mdot
.3728 .13053 Mdot
.39248 .01882 Mdot
.23345 .5069 Mdot
.54135 .51855 Mdot
.43824 .06909 Mdot
.3342 .16639 Mdot
.60312 .50898 Mdot
.40762 .02278 Mdot
.57919 .5537 Mdot
.4275 .04514 Mdot
.85385 .14728 Mdot
.53614 .51681 Mdot
.51205 .05364 Mdot
.09458 .45171 Mdot
.42539 .04569 Mdot
.56123 .5064 Mdot
.46201 .03877 Mdot
.33667 .16664 Mdot
.47696 .04443 Mdot
.4474 .06536 Mdot
.40343 .03725 Mdot
.68219 .11912 Mdot
.69121 .37205 Mdot
.40126 .02154 Mdot
.15066 .25204 Mdot
.49249 .09944 Mdot
.44227 .05957 Mdot
.20334 .26249 Mdot
.46612 .08788 Mdot
.6645 .11268 Mdot
.40738 .02099 Mdot
.61463 .49686 Mdot
.68005 .41098 Mdot
.66926 .44736 Mdot
.38577 .0231 Mdot
.33775 .17196 Mdot
.43218 .12322 Mdot
.47278 .09817 Mdot
.4725 .04197 Mdot
.86703 .15321 Mdot
.5481 .50863 Mdot
.32688 .23448 Mdot
.25779 .51722 Mdot
.6062 .50824 Mdot
.6072 .57338 Mdot
.42347 .05007 Mdot
.68594 .38259 Mdot
.55743 .50118 Mdot
.42168 .11791 Mdot
.09481 .45083 Mdot
.40779 .0471 Mdot
.53163 .51095 Mdot
.42164 .04329 Mdot
.40776 .04732 Mdot
.48988 .12923 Mdot
.4144 .0501 Mdot
.33893 .17271 Mdot
.5784 .50867 Mdot
.5294 .50945 Mdot
.40235 .0262 Mdot
.85396 .14736 Mdot
.71284 .09024 Mdot
.43928 .05868 Mdot
.58444 .50351 Mdot
.7473 .14574 Mdot
.67295 .41435 Mdot
.6775 .07499 Mdot
.50843 .12293 Mdot
.56065 .5401 Mdot
.52489 .12602 Mdot
.37555 .03048 Mdot
.49329 .1104 Mdot
.40914 .12568 Mdot
.14182 .24943 Mdot
.50933 .0576 Mdot
.55335 .50588 Mdot
.46313 .09029 Mdot
.43428 .06465 Mdot
.31357 .25431 Mdot
.67822 .4149 Mdot
.74527 .35361 Mdot
.44545 .06437 Mdot
.46014 .60175 Mdot
.45649 .03434 Mdot
.50812 .0549 Mdot
.49999 .10221 Mdot
.62758 .50207 Mdot
.22701 .26653 Mdot
.24428 .51148 Mdot
.40442 .11972 Mdot
.63319 .10108 Mdot
.30328 .25764 Mdot
.4764 .11913 Mdot
.39532 .02584 Mdot
.81813 .13338 Mdot
.41754 .05819 Mdot
.45162 .12509 Mdot
.63909 .49107 Mdot
.40309 .12704 Mdot
.46179 .04059 Mdot
.53295 .52003 Mdot
.67009 .46266 Mdot
.59832 .50198 Mdot
.49692 .11674 Mdot
.2038 .26234 Mdot
.48317 .04642 Mdot
.62678 .49964 Mdot
.55624 .52432 Mdot
.44885 .0663 Mdot
.44748 .07181 Mdot
.21179 .49827 Mdot
.47727 .0426 Mdot
.59605 .5069 Mdot
.44507 .03773 Mdot
.38104 .02015 Mdot
.55367 .5104 Mdot
.71517 .35625 Mdot
.84901 .36903 Mdot
.67852 .4112 Mdot
.53316 .50339 Mdot
.52266 .12362 Mdot
.37447 .13076 Mdot
.58513 .50006 Mdot
.27107 .26603 Mdot
.58847 .50292 Mdot
.45905 .0849 Mdot
.31688 .25078 Mdot
.44809 .07026 Mdot
.55481 .06917 Mdot
.43515 .12447 Mdot
.49245 .05138 Mdot
.84379 .36746 Mdot
.55473 .50118 Mdot
.48066 .10865 Mdot
.35431 .01345 Mdot
.30707 .53764 Mdot
.40742 .03294 Mdot
.3567 .14284 Mdot
.35115 .14826 Mdot
.49364 .1121 Mdot
.1834 .48606 Mdot
.66954 .45801 Mdot
.42237 .12032 Mdot
.65313 .10847 Mdot
.71008 .35765 Mdot
.70084 .36716 Mdot
.81304 .35953 Mdot
.67488 .11709 Mdot
.49942 .12086 Mdot
.14067 .24794 Mdot
.67956 .40173 Mdot
.4525 .03731 Mdot
.40583 .04367 Mdot
.39421 .12231 Mdot
.52727 .51303 Mdot
.49895 .1188 Mdot
.50896 .05686 Mdot
.33913 .16428 Mdot
.33648 .18029 Mdot
.45262 .12428 Mdot
.44033 .06923 Mdot
.54193 .0643 Mdot
.5027 .12635 Mdot
.68329 .39369 Mdot
.46311 .08538 Mdot
.45314 .12362 Mdot
.33077 .18374 Mdot
.37507 .0265 Mdot
.46507 .08833 Mdot
.31001 .25484 Mdot
.19862 .49245 Mdot
.64315 .10612 Mdot
.32927 .19467 Mdot
.37915 .01753 Mdot
.57721 .54801 Mdot
.4396 .06493 Mdot
.60285 .50012 Mdot
.83008 .36489 Mdot
.39603 .12029 Mdot
.46171 .60255 Mdot
.58883 .08479 Mdot
.39384 .04106 Mdot
.35459 .1399 Mdot
.36457 .00714 Mdot
.38808 .01469 Mdot
.64172 .49654 Mdot
.64524 .10625 Mdot
.79414 .35625 Mdot
.4648 .07849 Mdot
.5653 .504 Mdot
.57934 .07883 Mdot
.4236 .02534 Mdot
.64144 .49674 Mdot
.57561 .54803 Mdot
.36797 .13017 Mdot
.60101 .56729 Mdot
.44138 .05755 Mdot
.41603 .02129 Mdot
.4658 .11796 Mdot
.3333 .17234 Mdot
.56704 .54311 Mdot
.33879 .17409 Mdot
.56642 .50929 Mdot
.27525 .26674 Mdot
.67145 .11504 Mdot
.45361 .12697 Mdot
.15112 .25153 Mdot
.3223 .24139 Mdot
.40419 .04011 Mdot
.86642 .15248 Mdot
.54914 .52662 Mdot
.40737 .04911 Mdot
.3595 .00563 Mdot
.08828 .23309 Mdot
.41806 .02349 Mdot
.35416 .01481 Mdot
.50595 .05246 Mdot
.07086 .22706 Mdot
.22827 .26588 Mdot
.53259 .51134 Mdot
.41466 .0454 Mdot
.42403 .03584 Mdot
.46314 .11967 Mdot
.47878 .04429 Mdot
.41146 .11879 Mdot
.97969 .19581 Mdot
.40956 .04302 Mdot
.23027 .26666 Mdot
.52154 .06096 Mdot
.37871 .01333 Mdot
.77346 .11545 Mdot
.47857 .10287 Mdot
.32435 .22396 Mdot
.60851 .57345 Mdot
.63122 .10136 Mdot
.59759 .50328 Mdot
.92 .38952 Mdot
.48126 .11439 Mdot
.99074 .1998 Mdot
.15132 .47375 Mdot
.47428 .12273 Mdot
.89982 .38243 Mdot
.32806 .54608 Mdot
.35874 .13528 Mdot
.42919 .05841 Mdot
.20129 .26213 Mdot
.40311 .0226 Mdot
.02234 .2117 Mdot
.48121 .09131 Mdot
.51644 .12295 Mdot
.59899 .50213 Mdot
.5834 .50054 Mdot
.48441 .0893 Mdot
.51605 .05613 Mdot
.66419 .4652 Mdot
.97481 .40686 Mdot
.50513 .12749 Mdot
.39727 .04409 Mdot
.46953 .11986 Mdot
.34358 .15021 Mdot
.55927 .53256 Mdot
.51465 .05412 Mdot
.42868 .06282 Mdot
.46506 .08252 Mdot
.60026 .50196 Mdot
.42989 .03357 Mdot
.36863 .02503 Mdot
.05196 .2215 Mdot
.09236 .45018 Mdot
.33944 .16017 Mdot
.46877 .1183 Mdot
.35532 .01046 Mdot
.47272 .08711 Mdot
.48919 .04522 Mdot
.3763 .02137 Mdot
.55408 .50092 Mdot
.36331 .12878 Mdot
.14791 .25011 Mdot
.43694 .03701 Mdot
.59831 .5062 Mdot
.86141 .15081 Mdot
.34951 .14193 Mdot
.50571 .11526 Mdot
.35587 .13512 Mdot
.73398 .14086 Mdot
.50042 .10651 Mdot
.56766 .50972 Mdot
.94435 .18293 Mdot
.3161 .24916 Mdot
.3818 .02053 Mdot
.45483 .07217 Mdot
.40853 .03117 Mdot
.6496 .48176 Mdot
.63141 .49696 Mdot
.47728 .09053 Mdot
.36642 .1307 Mdot
.42977 .05809 Mdot
.53492 .06304 Mdot
.43225 .05299 Mdot
.32248 .22911 Mdot
.62073 .49727 Mdot
.4312 .05645 Mdot
.47245 .12363 Mdot
.6957 .12573 Mdot
.67474 .42333 Mdot
.4318 .0609 Mdot
.50234 .10268 Mdot
.5266 .51159 Mdot
.38724 .03185 Mdot
.66975 .45526 Mdot
.6068 .50249 Mdot
.49624 .11889 Mdot
.36753 .0157 Mdot
.54541 .06648 Mdot
.96889 .19231 Mdot
.55578 .51661 Mdot
.56943 .54456 Mdot
.64675 .48645 Mdot
.32668 .22403 Mdot
.58949 .56144 Mdot
.3686 .12776 Mdot
.42765 .02906 Mdot
.34492 .15471 Mdot
.55783 .50438 Mdot
.36029 .13545 Mdot
.68466 .38526 Mdot
.68616 .38342 Mdot
.95271 .40015 Mdot
.54633 .50702 Mdot
.50731 .05272 Mdot
.42708 .04765 Mdot
.39467 .02183 Mdot
.57604 .51058 Mdot
.57212 .51338 Mdot
.32892 .1965 Mdot
.39505 .02627 Mdot
.55551 .51275 Mdot
.48573 .08953 Mdot
.57313 .07975 Mdot
.67406 .4084 Mdot
.45689 .07566 Mdot
.1271 .24484 Mdot
.55296 .51822 Mdot
.50122 .10153 Mdot
.70993 .1304 Mdot
.30541 .25347 Mdot
.3341 .19637 Mdot
.42416 .05603 Mdot
.67248 .42502 Mdot
.62904 .498 Mdot
.13107 .24556 Mdot
.39839 .03741 Mdot
.39678 .02818 Mdot
.6705 .43317 Mdot
.45833 .04104 Mdot
.46453 .08862 Mdot
.47767 .10311 Mdot
.52928 .50493 Mdot
.90281 .38305 Mdot
.33777 .172 Mdot
.6263 .58646 Mdot
.60822 .49935 Mdot
.51734 .11534 Mdot
.36916 .13358 Mdot
.46464 .0861 Mdot
.59578 .5068 Mdot
.41819 .02096 Mdot
.90636 .3847 Mdot
.58157 .50396 Mdot
.5408 .51651 Mdot
.46227 .08674 Mdot
.46634 .07924 Mdot
.48155 .11581 Mdot
.11366 .24125 Mdot
.53131 .50788 Mdot
.62466 .09802 Mdot
.39561 .12783 Mdot
.42159 .05889 Mdot
.31841 .24499 Mdot
.43567 .12344 Mdot
.59976 .50083 Mdot
.30955 .5379 Mdot
.10971 .45663 Mdot
.41101 .04722 Mdot
.43524 .03724 Mdot
.34194 .16401 Mdot
.51101 .12653 Mdot
.5147 .1307 Mdot
.67313 .45576 Mdot
.45674 .07255 Mdot
.49155 .11677 Mdot
.54831 .53327 Mdot
.9534 .39914 Mdot
.4234 .03871 Mdot
.76736 .15327 Mdot
.4213 .02474 Mdot
.54726 .50108 Mdot
.426 .12372 Mdot
.4922 .10918 Mdot
.55558 .51609 Mdot
.4462 .12233 Mdot
.33907 .17573 Mdot
.37759 .02731 Mdot
.95054 .39927 Mdot
.23445 .5068 Mdot
.52145 .12433 Mdot
.43476 .59056 Mdot
.4625 .12156 Mdot
.52645 .50957 Mdot
.62097 .50217 Mdot
.45917 .12647 Mdot
.67593 .44822 Mdot
.3823 .01736 Mdot
.45843 .11724 Mdot
.64104 .59408 Mdot
.14688 .24987 Mdot
.27829 .26476 Mdot
.3955 .01568 Mdot
.67191 .46053 Mdot
.62659 .49351 Mdot
.52939 .06085 Mdot
.5963 .50273 Mdot
.43324 .12482 Mdot
.53941 .51553 Mdot
.42209 .12159 Mdot
.22422 .50286 Mdot
.33937 .15656 Mdot
.38298 .03193 Mdot
.38502 .01074 Mdot
.61238 .0932 Mdot
.3826 .01985 Mdot
.49632 .09881 Mdot
.54961 .06889 Mdot
.94476 .18296 Mdot
.46451 .12744 Mdot
.61247 .49775 Mdot
.4002 .02127 Mdot
.50698 .05309 Mdot
.67238 .43361 Mdot
.55369 .53013 Mdot
.60616 .49837 Mdot
.60954 .5039 Mdot
.32823 .22256 Mdot
.50338 .12781 Mdot
.51063 .12939 Mdot
.53316 .51446 Mdot
.64477 .49707 Mdot
.40656 .04871 Mdot
.59797 .50336 Mdot
.43064 .02726 Mdot
.38787 .03683 Mdot
.41269 .05516 Mdot
.32596 .21623 Mdot
.44869 .0725 Mdot
.57848 .50581 Mdot
.68074 .39851 Mdot
.50155 .10771 Mdot
.5516 .53004 Mdot
.51223 .12288 Mdot
.5673 .50278 Mdot
.09384 .45069 Mdot
.42645 .58753 Mdot
.16759 .25483 Mdot
.33128 .2067 Mdot
.73275 .1403 Mdot
.48128 .11835 Mdot
.39325 .03128 Mdot
.33861 .16446 Mdot
.71302 .36046 Mdot
.89866 .38161 Mdot
.34463 .14684 Mdot
.88391 .37861 Mdot
.88991 .38047 Mdot
.3722 .02316 Mdot
.43986 .05924 Mdot
.33314 .19185 Mdot
.41827 .03877 Mdot
.44028 .06755 Mdot
.38161 .0167 Mdot
.68666 .07965 Mdot
.44855 .07146 Mdot
.47361 .04413 Mdot
.53403 .5131 Mdot
.45383 .06782 Mdot
.39257 .01516 Mdot
.41385 .0418 Mdot
.72966 .35414 Mdot
.60441 .49967 Mdot
.50321 .1248 Mdot
.46803 .12596 Mdot
.48388 .11927 Mdot
.25181 .51461 Mdot
.57995 .07966 Mdot
.72417 .35287 Mdot
.3899 .03086 Mdot
.46796 .09253 Mdot
.40197 .04783 Mdot
.55736 .5358 Mdot
.49747 .12491 Mdot
.44204 .07209 Mdot
.60152 .50997 Mdot
.70207 .36314 Mdot
.79955 .12606 Mdot
.55074 .51888 Mdot
.66097 .46609 Mdot
.51048 .11796 Mdot
.41925 .12305 Mdot
.39391 .02751 Mdot
.50154 .11113 Mdot
.48667 .10557 Mdot
.65448 .49023 Mdot
.36876 .02641 Mdot
.66108 .4843 Mdot
.50136 .10952 Mdot
.47987 .09897 Mdot
.4667 .07709 Mdot
.87594 .37513 Mdot
.62575 .58172 Mdot
.42575 .02797 Mdot
.68319 .39127 Mdot
.52877 .50505 Mdot
.3248 .23154 Mdot
.53546 .52157 Mdot
.3641 .13392 Mdot
.57632 .5507 Mdot
.61284 .09449 Mdot
.62922 .49278 Mdot
.54543 .50137 Mdot
.59786 .08743 Mdot
.98871 .41234 Mdot
.59596 .5641 Mdot
.62999 .58956 Mdot
.42198 .06076 Mdot
.49121 .12413 Mdot
.41933 .03755 Mdot
.61706 .58122 Mdot
.4963 .10255 Mdot
.52173 .50859 Mdot
.31394 .54015 Mdot
.36066 .02045 Mdot
.33234 .20783 Mdot
.49155 .11587 Mdot
.42165 .58541 Mdot
.42723 .11959 Mdot
.33325 .18756 Mdot
.55744 .51264 Mdot
.40265 .03532 Mdot
.55243 .0689 Mdot
.69139 .37851 Mdot
.40679 .03934 Mdot
.40236 .04282 Mdot
.39833 .02684 Mdot
.28691 .26542 Mdot
.53896 .51804 Mdot
.67556 .45106 Mdot
.55224 .02231 Mdot
.48265 .12324 Mdot
.08348 .2318 Mdot
.49528 .05118 Mdot
.37969 .13056 Mdot
.41773 .03852 Mdot
.47339 .11991 Mdot
.4117 .02283 Mdot
.4246 .02733 Mdot
.50273 .13068 Mdot
.46476 .08711 Mdot
.67048 .43211 Mdot
.62972 .49287 Mdot
.40933 .04304 Mdot
.43546 .02917 Mdot
.53309 .06282 Mdot
.38394 .12849 Mdot
.87725 .37667 Mdot
.39946 .03618 Mdot
.69302 .36919 Mdot
.64714 .10692 Mdot
.38384 .02707 Mdot
.65761 .48333 Mdot
.27159 .2673 Mdot
.40955 .02549 Mdot
.41801 .04283 Mdot
.36754 .02386 Mdot
.47505 .09826 Mdot
.16444 .25456 Mdot
.33748 .16051 Mdot
.4376 .05834 Mdot
.51986 .00926 Mdot
.43655 .03611 Mdot
.13153 .24624 Mdot
.36724 .12935 Mdot
.36111 .01521 Mdot
.40437 .03782 Mdot
.62917 .49606 Mdot
.39217 .02306 Mdot
.71104 .08915 Mdot
.74723 .35179 Mdot
.4165 .05805 Mdot
.48616 .1006 Mdot
.35268 .13752 Mdot
.4369 .02772 Mdot
.67697 .42031 Mdot
.70948 .35796 Mdot
.68679 .3793 Mdot
.50928 .1234 Mdot
.62385 .58239 Mdot
.48602 .11079 Mdot
.48794 .09139 Mdot
.33723 .18318 Mdot
.42033 .03609 Mdot
.49521 .10371 Mdot
.63276 .49961 Mdot
.45629 .11861 Mdot
.37789 .03118 Mdot
.30279 .26124 Mdot
.50162 .10908 Mdot
.47619 .09564 Mdot
.45925 .122 Mdot
.64931 .60161 Mdot
.5722 .5441 Mdot
.40704 .12036 Mdot
.97376 .40683 Mdot
.54648 .06639 Mdot
.74357 .35423 Mdot
.74001 .35331 Mdot
.44251 .59438 Mdot
.52153 .05812 Mdot
.41258 .11978 Mdot
.61064 .50185 Mdot
.57221 .51129 Mdot
.55822 .50486 Mdot
.6137 .57329 Mdot
.2873 .26321 Mdot
.42303 .04868 Mdot
.42916 .12221 Mdot
.52251 .12869 Mdot
.11715 .24288 Mdot
.55111 .50325 Mdot
.71733 .35564 Mdot
.27511 .26542 Mdot
.68377 .39215 Mdot
.32286 .23113 Mdot
.48268 .04255 Mdot
.52449 .12562 Mdot
.13263 .24632 Mdot
.4359 .06873 Mdot
.57721 .0804 Mdot
.67103 .43959 Mdot
.47624 .08348 Mdot
.59879 .56886 Mdot
.76379 .35378 Mdot
.97652 .1942 Mdot
.64054 .49729 Mdot
.64045 .10236 Mdot
.54221 .52461 Mdot
.46113 .12646 Mdot
.43163 .051 Mdot
.47132 .08385 Mdot
.48182 .10636 Mdot
.12509 .46312 Mdot
.52742 .51458 Mdot
.67132 .44812 Mdot
.41805 .02361 Mdot
.47198 .08857 Mdot
.41838 .0281 Mdot
.42674 .05355 Mdot
.47882 .09444 Mdot
.03252 .42822 Mdot
.5509 .52806 Mdot
.32927 .19575 Mdot
.67805 .40067 Mdot
.71033 .36026 Mdot
.54296 .52644 Mdot
.37692 .00945 Mdot
.69695 .3696 Mdot
.36512 .56177 Mdot
.67626 .39797 Mdot
.31357 .24632 Mdot
.47202 .08429 Mdot
.68098 .38774 Mdot
.36792 .1292 Mdot
.48777 .10963 Mdot
.12353 .24455 Mdot
.34583 .15004 Mdot
.67123 .45421 Mdot
.31932 .23951 Mdot
.56357 .51489 Mdot
.67488 .42634 Mdot
.48707 .09401 Mdot
.49595 .11074 Mdot
.35244 .01116 Mdot
.67353 .41232 Mdot
.32449 .23768 Mdot
.45438 .06879 Mdot
.6574 .4884 Mdot
.54204 .50974 Mdot
.38153 .02392 Mdot
.34095 .15137 Mdot
.40271 .02314 Mdot
.0276 .21336 Mdot
.88594 .37909 Mdot
.48603 .12049 Mdot
.02195 .42429 Mdot
.66468 .46363 Mdot
.63088 .10148 Mdot
.49199 .1202 Mdot
.46578 .0921 Mdot
.52257 .11896 Mdot
.52179 .05764 Mdot
.59074 .08451 Mdot
.58431 .55888 Mdot
.32894 .19836 Mdot
.37541 .02494 Mdot
.58744 .08369 Mdot
.49965 .12078 Mdot
.50858 .11723 Mdot
.42164 .05394 Mdot
.3727 .01051 Mdot
.4273 .02502 Mdot
.63428 .05709 Mdot
.66684 .11303 Mdot
.33795 .16686 Mdot
.50506 .05349 Mdot
.38452 .01573 Mdot
.50217 .04928 Mdot
.57465 .54417 Mdot
.67154 .42805 Mdot
.35052 .15095 Mdot
.50752 .12305 Mdot
.33315 .19796 Mdot
.40364 .12027 Mdot
.44072 .02761 Mdot
.48681 .12099 Mdot
.51284 .12933 Mdot
.40401 .03814 Mdot
.48108 .12403 Mdot
.48219 .10702 Mdot
.4768 .08316 Mdot
.41146 .12652 Mdot
.52046 .51102 Mdot
.39877 .03955 Mdot
.43034 .06263 Mdot
.53087 .50893 Mdot
.47443 .0456 Mdot
.51839 .12866 Mdot
.57503 .50064 Mdot
.47178 .09063 Mdot
.47505 .08919 Mdot
.37794 .01075 Mdot
.5601 .50875 Mdot
.33677 .16394 Mdot
.41738 .02465 Mdot
.42874 .035 Mdot
.55577 .53669 Mdot
.50937 .12491 Mdot
.67877 .39562 Mdot
.59577 .5081 Mdot
.6096 .57107 Mdot
.85207 .36916 Mdot
.08541 .23285 Mdot
.68695 .37499 Mdot
.57826 .50252 Mdot
.48673 .04973 Mdot
.88814 .16137 Mdot
.63345 .59198 Mdot
.66861 .45804 Mdot
.28622 .26467 Mdot
.36126 .01778 Mdot
.28386 .26625 Mdot
.56935 .07656 Mdot
.58334 .55764 Mdot
.3177 .23863 Mdot
.42954 .03461 Mdot
.29977 .26225 Mdot
.71486 .13295 Mdot
.6408 .59515 Mdot
.63096 .10072 Mdot
.40502 .03028 Mdot
.30347 .2587 Mdot
.40489 .02461 Mdot
.61523 .5074 Mdot
.58196 .08152 Mdot
.61519 .09437 Mdot
.11885 .24313 Mdot
.813 .36138 Mdot
.35627 .01639 Mdot
.52125 .51025 Mdot
.66231 .1124 Mdot
.63845 .4899 Mdot
.52861 .51157 Mdot
.4149 .02511 Mdot
.38292 .56905 Mdot
.4146 .02589 Mdot
.33751 .17615 Mdot
.5621 .07355 Mdot
.67518 .45303 Mdot
.41269 .03137 Mdot
.68368 .39542 Mdot
.51197 .12603 Mdot
.52573 .51647 Mdot
.73127 .35444 Mdot
.58321 .5109 Mdot
.67706 .39316 Mdot
.49265 .11708 Mdot
.35673 .13735 Mdot
.70081 .36429 Mdot
.50884 .11461 Mdot
.65044 .48771 Mdot
.52474 .06146 Mdot
.5494 .51549 Mdot
.63504 .49142 Mdot
.40604 .02299 Mdot
.55368 .52878 Mdot
.43603 .03183 Mdot
.50394 .11538 Mdot
.56614 .50577 Mdot
.5816 .55654 Mdot
.59593 .08777 Mdot
.3306 .20347 Mdot
.49414 .10787 Mdot
.50487 .11142 Mdot
.47178 .08295 Mdot
.02009 .42321 Mdot
.46231 .08575 Mdot
.21939 .26689 Mdot
.43749 .02881 Mdot
.50331 .11751 Mdot
.47739 .10032 Mdot
.34809 .1451 Mdot
.37184 .02442 Mdot
.64073 .49858 Mdot
.74808 .35394 Mdot
.69205 .0813 Mdot
.2805 .26441 Mdot
.64912 .49276 Mdot
.43624 .03411 Mdot
.46164 .04121 Mdot
.38308 .02901 Mdot
.55701 .50599 Mdot
.57721 .55158 Mdot
.32819 .19767 Mdot
.53245 .52256 Mdot
.29581 .25992 Mdot
.379 .01146 Mdot
.66591 .47447 Mdot
.97198 .40578 Mdot
.63064 .50354 Mdot
.46372 .12265 Mdot
.53898 .50291 Mdot
.48673 .11106 Mdot
.58642 .50833 Mdot
.42916 .04985 Mdot
.36297 .13668 Mdot
.48721 .12823 Mdot
.45375 .03479 Mdot
.41707 .12293 Mdot
.42652 .03154 Mdot
.53505 .51044 Mdot
.41802 .03151 Mdot
.52251 .12253 Mdot
.48323 .12628 Mdot
.42068 .03011 Mdot
.49857 .13033 Mdot
.67525 .44726 Mdot
.63039 .58526 Mdot
.33481 .16259 Mdot
.58679 .50747 Mdot
.54166 .5144 Mdot
.087 .23353 Mdot
.35945 .01196 Mdot
.18321 .25831 Mdot
.2519 .51407 Mdot
.43977 .02758 Mdot
.50041 .12279 Mdot
.34634 .14857 Mdot
.38199 .12839 Mdot
.25524 .26754 Mdot
.42787 .02887 Mdot
.25571 .26866 Mdot
.47528 .09585 Mdot
.61475 .50328 Mdot
.46282 .08932 Mdot
.49498 .12442 Mdot
.33386 .19644 Mdot
.34234 .14916 Mdot
.44133 .07071 Mdot
.58749 .50775 Mdot
.02807 .42628 Mdot
.44353 .1225 Mdot
.45703 .12704 Mdot
.7166 .3597 Mdot
.43835 .06002 Mdot
.60156 .56547 Mdot
.46865 .04132 Mdot
.34871 .15069 Mdot
.48807 .12955 Mdot
.40692 .02576 Mdot
.45683 .07391 Mdot
.43962 .03744 Mdot
.67801 .39215 Mdot
.59544 .50388 Mdot
.36438 .01793 Mdot
.56961 .54194 Mdot
.66269 .4709 Mdot
.64861 .60025 Mdot
.22743 .26718 Mdot
.38414 .12516 Mdot
.51866 .05759 Mdot
.4076 .03475 Mdot
.52633 .50274 Mdot
.5599 .5156 Mdot
.58291 .08285 Mdot
.38962 .0337 Mdot
.58271 .08104 Mdot
.47437 .04481 Mdot
.49088 .10473 Mdot
.41906 .02871 Mdot
.76186 .11062 Mdot
.64576 .48824 Mdot
.407 .12693 Mdot
.36809 .13305 Mdot
.7862 .35699 Mdot
.46255 .12651 Mdot
.59991 .49948 Mdot
.50507 .11675 Mdot
.73407 .35287 Mdot
.41093 .02649 Mdot
.44139 .05849 Mdot
.60127 .50969 Mdot
.67355 .42241 Mdot
.40375 .03687 Mdot
.36908 .01694 Mdot
.15172 .25259 Mdot
.47484 .0937 Mdot
.45659 .08287 Mdot
.69961 .08434 Mdot
.65221 .48756 Mdot
.67536 .4485 Mdot
.33112 .22122 Mdot
.50158 .1303 Mdot
.63553 .49014 Mdot
.66876 .46574 Mdot
.38526 .12543 Mdot
.67317 .43791 Mdot
.68203 .38789 Mdot
.15827 .25273 Mdot
.22547 .26595 Mdot
.64868 .49528 Mdot
.57541 .03257 Mdot
.3655 .02162 Mdot
.58071 .07926 Mdot
.39562 .57399 Mdot
.47543 .08727 Mdot
.70361 .36213 Mdot
.55253 .53456 Mdot
.6535 .49231 Mdot
.45766 .03914 Mdot
.51849 .12612 Mdot
.22293 .50243 Mdot
.48727 .12836 Mdot
.57859 .51154 Mdot
.51689 .12319 Mdot
.62754 .58504 Mdot
.58819 .50657 Mdot
.65055 .06413 Mdot
.43442 .06764 Mdot
.65085 .48356 Mdot
.4707 .09274 Mdot
.27668 .26715 Mdot
.63962 .49179 Mdot
.67818 .4338 Mdot
.43534 .06279 Mdot
.59503 .56475 Mdot
.67774 .4194 Mdot
.64681 .49611 Mdot
.60747 .57281 Mdot
.49415 .10575 Mdot
.71274 .09057 Mdot
.97155 .4055 Mdot
.42339 .12467 Mdot
.56576 .07371 Mdot
.66851 .45929 Mdot
.4696 .04114 Mdot
.52112 .12991 Mdot
.39514 .02899 Mdot
.67193 .43375 Mdot
.4108 .04292 Mdot
.55698 .50174 Mdot
.5948 .5639 Mdot
.64877 .60058 Mdot
.35042 .13755 Mdot
.33374 .17753 Mdot
.49593 .1183 Mdot
.06595 .22671 Mdot
.40127 .02899 Mdot
.49502 .05223 Mdot
.35337 .00702 Mdot
.40273 .12506 Mdot
.67107 .4509 Mdot
.68749 .37946 Mdot
.54304 .50638 Mdot
.66966 .45603 Mdot
.32053 .23762 Mdot
.46886 .11872 Mdot
.56641 .07725 Mdot
.08683 .44798 Mdot
.57971 .55194 Mdot
.40822 .12128 Mdot
.58639 .55775 Mdot
.59181 .50611 Mdot
.4419 .03389 Mdot
.65358 .11027 Mdot
.49968 .1127 Mdot
.50307 .11213 Mdot
.53342 .52173 Mdot
.40635 .01898 Mdot
.66538 .46008 Mdot
.30425 .25544 Mdot
.52742 .01246 Mdot
.62964 .09963 Mdot
.67534 .4347 Mdot
.41722 .05488 Mdot
.3336 .20564 Mdot
.36918 .01227 Mdot
.48343 .09564 Mdot
.34466 .55311 Mdot
.33696 .16611 Mdot
.75412 .35233 Mdot
.55429 .50324 Mdot
.44779 .07659 Mdot
.39049 .01445 Mdot
.3786 .02495 Mdot
.40463 .0342 Mdot
.63013 .58923 Mdot
.33235 .20577 Mdot
.66036 .48237 Mdot
.49153 .10998 Mdot
.44658 .07712 Mdot
.76797 .35481 Mdot
.41934 .12444 Mdot
.56241 .07254 Mdot
.47444 .08752 Mdot
.60017 .56449 Mdot
.41908 .0554 Mdot
.81973 .36198 Mdot
.47461 .09428 Mdot
.55728 .07349 Mdot
.4981 .12084 Mdot
.63792 .49651 Mdot
.40155 .04218 Mdot
.59916 .0874 Mdot
.49107 .61481 Mdot
.35551 .00875 Mdot
.4288 .04551 Mdot
.59628 .08622 Mdot
.44731 .03484 Mdot
.45054 .11876 Mdot
.54332 .5123 Mdot
.41245 .05254 Mdot
.04097 .43036 Mdot
.46635 .08282 Mdot
.48727 .09497 Mdot
.40977 .03373 Mdot
.63438 .49144 Mdot
.40194 .03176 Mdot
.37627 .12476 Mdot
.49789 .05262 Mdot
.41259 .04908 Mdot
.66662 .47229 Mdot
.42181 .04001 Mdot
.91833 .38846 Mdot
.23121 .50621 Mdot
.32647 .2098 Mdot
.34793 .14261 Mdot
.38875 .03491 Mdot
.61453 .49749 Mdot
.55827 .51015 Mdot
.43315 .05033 Mdot
.92089 .38951 Mdot
.41223 .02494 Mdot
.68171 .40414 Mdot
.66517 .47275 Mdot
.39372 .03548 Mdot
.57729 .0795 Mdot
.62655 .49721 Mdot
.40653 .57903 Mdot
.67541 .40272 Mdot
.55656 .53148 Mdot
.72031 .35596 Mdot
.94707 .18386 Mdot
.56703 .51218 Mdot
.52353 .12171 Mdot
.57363 .07848 Mdot
.78397 .35468 Mdot
.54193 .51873 Mdot
.27055 .26772 Mdot
.41132 .05395 Mdot
.67213 .46052 Mdot
.5261 .12852 Mdot
.54998 .53033 Mdot
.65889 .47834 Mdot
.42247 .04627 Mdot
.67685 .42548 Mdot
.7068 .36373 Mdot
.80011 .12645 Mdot
.40367 .02914 Mdot
.62146 .49969 Mdot
.6799 .38943 Mdot
.73178 .35338 Mdot
.631 .4961 Mdot
.39166 .03328 Mdot
.56592 .54701 Mdot
.46772 .07771 Mdot
.47028 .60565 Mdot
.30883 .53761 Mdot
.66768 .45758 Mdot
.54054 .50709 Mdot
.37688 .12969 Mdot
.67128 .11528 Mdot
.56134 .50572 Mdot
.5036 .1163 Mdot
.36588 .02436 Mdot
.4477 .07788 Mdot
.52165 .06136 Mdot
.53931 .50376 Mdot
.29016 .26537 Mdot
.4815 .04834 Mdot
.53932 .51557 Mdot
.50657 .11168 Mdot
.49759 .10107 Mdot
.45968 .07435 Mdot
.19015 .26036 Mdot
.62365 .57989 Mdot
.32976 .20451 Mdot
.53451 .50662 Mdot
.4881 .10107 Mdot
.35395 .01152 Mdot
.66979 .07237 Mdot
.52462 .51113 Mdot
.59101 .50249 Mdot
.42185 .12198 Mdot
.49611 .12359 Mdot
.49934 .05052 Mdot
.53376 .52158 Mdot
.38301 .01532 Mdot
.4686 .08062 Mdot
.48727 .11246 Mdot
.39353 .01564 Mdot
.48243 .10654 Mdot
.50198 .10683 Mdot
.4863 .08972 Mdot
.69116 .081 Mdot
.57212 .54323 Mdot
.463 .04164 Mdot
.65181 .49085 Mdot
.47531 .08601 Mdot
.61575 .50108 Mdot
.59659 .51044 Mdot
.97366 .19355 Mdot
.54867 .51506 Mdot
.48077 .12021 Mdot
.42026 .12572 Mdot
.55215 .53293 Mdot
.55844 .53202 Mdot
.61677 .5048 Mdot
.69973 .36647 Mdot
.74603 .14498 Mdot
.4918 .09368 Mdot
.39693 .03431 Mdot
.28084 .26424 Mdot
.68201 .383 Mdot
.33591 .17079 Mdot
.42331 .04334 Mdot
.54316 .51527 Mdot
.50822 .1232 Mdot
.65039 .49366 Mdot
.50536 .12864 Mdot
.40223 .04445 Mdot
.5214 .12464 Mdot
.65111 .48373 Mdot
.46553 .08556 Mdot
.49439 .11759 Mdot
.75618 .35191 Mdot
.70808 .36289 Mdot
.49303 .11463 Mdot
.54394 .52282 Mdot
.59661 .50601 Mdot
.57153 .54354 Mdot
.50391 .10506 Mdot
.53501 .50547 Mdot
.65194 .49288 Mdot
.65194 .10842 Mdot
.21897 .50093 Mdot
.70222 .36393 Mdot
.4072 .02017 Mdot
.59014 .50733 Mdot
.55642 .50292 Mdot
.62562 .58176 Mdot
.56652 .50769 Mdot
.65478 .10845 Mdot
.47341 .12627 Mdot
.39853 .02954 Mdot
.39798 .12616 Mdot
.45881 .03843 Mdot
.53256 .51994 Mdot
.34083 .1518 Mdot
.73562 .35437 Mdot
.34228 .15539 Mdot
.57311 .54346 Mdot
.18855 .25963 Mdot
.66023 .11256 Mdot
.33382 .1785 Mdot
.8188 .36086 Mdot
.4121 .03844 Mdot
.40812 .02094 Mdot
.41134 .0547 Mdot
.45658 .08 Mdot
.79065 .12259 Mdot
.42874 .12309 Mdot
.43165 .06161 Mdot
.09284 .23409 Mdot
.62581 .49602 Mdot
.35231 .13711 Mdot
.4183 .03401 Mdot
.30523 .53677 Mdot
.65016 .60315 Mdot
.80926 .35928 Mdot
.56234 .54461 Mdot
.32037 .23431 Mdot
.3982 .04351 Mdot
.55587 .53153 Mdot
.62424 .50247 Mdot
.33689 .16718 Mdot
.39157 .02352 Mdot
.37333 .01851 Mdot
.59571 .50656 Mdot
.50088 .1194 Mdot
.55942 .50934 Mdot
.62309 .49491 Mdot
.46519 .03729 Mdot
.44325 .03841 Mdot
.54139 .52212 Mdot
.48004 .09354 Mdot
.56445 .53548 Mdot
.5295 .51953 Mdot
.53416 .52376 Mdot
.42542 .58718 Mdot
.55135 .52985 Mdot
.46711 .1216 Mdot
.65468 .10853 Mdot
.68221 .38456 Mdot
.61043 .57174 Mdot
.3846 .12473 Mdot
.67231 .11679 Mdot
.56566 .07587 Mdot
.38004 .01461 Mdot
.41692 .04306 Mdot
.47016 .09029 Mdot
.46235 .12783 Mdot
.42382 .04614 Mdot
.40411 .02757 Mdot
.44688 .118 Mdot
.2939 .26227 Mdot
.43539 .05816 Mdot
.39489 .04361 Mdot
.41896 .03188 Mdot
.64234 .59432 Mdot
.38666 .02343 Mdot
.68626 .37896 Mdot
.57041 .54754 Mdot
.3838 .02264 Mdot
.43488 .59076 Mdot
.58354 .50928 Mdot
.49462 .11465 Mdot
.40604 .12212 Mdot
.56959 .54072 Mdot
.49655 .11321 Mdot
.84558 .36803 Mdot
.457 .11906 Mdot
.10317 .45432 Mdot
.32364 .23779 Mdot
.62909 .49312 Mdot
.33262 .18044 Mdot
.51611 .05686 Mdot
.33886 .16407 Mdot
.64479 .49005 Mdot
.37035 .02456 Mdot
.89825 .38283 Mdot
.81189 .36069 Mdot
.3613 .0102 Mdot
.46137 .12469 Mdot
.51562 .11256 Mdot
.68655 .38723 Mdot
.20893 .4971 Mdot
.51243 .12259 Mdot
.669 .44643 Mdot
.57663 .55221 Mdot
.63414 .49861 Mdot
.53144 .52213 Mdot
.57494 .07874 Mdot
.37399 .01128 Mdot
.52293 .05799 Mdot
.30994 .25475 Mdot
.32863 .22369 Mdot
.04527 .43275 Mdot
.68925 .38026 Mdot
.43062 .03851 Mdot
.43394 .03175 Mdot
.48994 .0944 Mdot
.43901 .11774 Mdot
.35165 .14712 Mdot
.44764 .0755 Mdot
.33359 .18607 Mdot
.39973 .02432 Mdot
.64137 .49824 Mdot
.3782 .13147 Mdot
.45519 .08039 Mdot
.54007 .50119 Mdot
.56969 .54649 Mdot
.67223 .07301 Mdot
.30962 .25318 Mdot
.4901 .1068 Mdot
.54952 .51677 Mdot
.3685 .02487 Mdot
.31828 .23881 Mdot
.54313 .5124 Mdot
.2068 .26301 Mdot
.47654 .08907 Mdot
.4347 .03704 Mdot
.27478 .26777 Mdot
.47741 .08749 Mdot
.38883 .0123 Mdot
.54917 .5056 Mdot
.07435 .22962 Mdot
.63836 .49697 Mdot
.32576 .23705 Mdot
.47269 .125 Mdot
.67195 .44601 Mdot
.56176 .53734 Mdot
.51357 .11188 Mdot
.85525 .36998 Mdot
.53563 .50897 Mdot
.44572 .0655 Mdot
.54177 .53078 Mdot
.33346 .18248 Mdot
.3919 .04189 Mdot
.3012 .26109 Mdot
.3084 .25166 Mdot
.43702 .07038 Mdot
.40201 .57716 Mdot
.40316 .02934 Mdot
.41028 .03318 Mdot
.81245 .13073 Mdot
.47413 .12344 Mdot
.4051 .04233 Mdot
.18468 .25937 Mdot
.57457 .50069 Mdot
.34946 .1441 Mdot
.37402 .0169 Mdot
.39409 .01413 Mdot
.58498 .55679 Mdot
.47472 .08661 Mdot
.76796 .35377 Mdot
.62459 .0982 Mdot
.40032 .04161 Mdot
.73902 .35291 Mdot
.59891 .50898 Mdot
.63795 .10414 Mdot
.41979 .03322 Mdot
.51078 .00511 Mdot
.39384 .02219 Mdot
.78462 .35485 Mdot
.43938 .06853 Mdot
.44688 .06876 Mdot
.45018 .12513 Mdot
.41018 .02841 Mdot
.4989 .11102 Mdot
.21757 .26491 Mdot
.50404 .11218 Mdot
.4054 .12149 Mdot
.49117 .04829 Mdot
.99681 .41517 Mdot
.61327 .5755 Mdot
.39827 .01965 Mdot
.61522 .04961 Mdot
.75439 .3542 Mdot
.48023 .10244 Mdot
.77791 .3537 Mdot
.59604 .5065 Mdot
.61344 .0938 Mdot
.33989 .55051 Mdot
.01928 .42303 Mdot
.38888 .12454 Mdot
.60067 .50798 Mdot
.29816 .25946 Mdot
.54944 .50619 Mdot
.6605 .47365 Mdot
.45762 .03428 Mdot
.14589 .24969 Mdot
.3694 .12944 Mdot
.07114 .22795 Mdot
.50098 .11312 Mdot
.41289 .0217 Mdot
.32635 .23479 Mdot
.66997 .43775 Mdot
.6151 .49702 Mdot
.49287 .05039 Mdot
.6597 .48134 Mdot
.46303 .12316 Mdot
.53201 .50765 Mdot
.55212 .53415 Mdot
.48405 .08923 Mdot
.42452 .05209 Mdot
.415 .02186 Mdot
.44824 .07616 Mdot
.48725 .12483 Mdot
.11916 .46044 Mdot
.70781 .36033 Mdot
.39258 .12311 Mdot
.67164 .46056 Mdot
.56722 .51389 Mdot
.4935 .04722 Mdot
.44632 .03275 Mdot
.13011 .24615 Mdot
.82232 .36314 Mdot
.33683 .54934 Mdot
.31642 .24943 Mdot
.42709 .02931 Mdot
.48962 .04594 Mdot
.32808 .20635 Mdot
.76354 .35259 Mdot
.9563 .18716 Mdot
.12833 .46435 Mdot
.41898 .12477 Mdot
.41064 .12541 Mdot
.57191 .54991 Mdot
.81412 .13214 Mdot
.42425 .04585 Mdot
.38225 .03216 Mdot
.40677 .04858 Mdot
.47007 .03996 Mdot
.5663 .50091 Mdot
.35674 .13666 Mdot
.42725 .02916 Mdot
.95091 .39957 Mdot
.33491 .19411 Mdot
.48448 .1125 Mdot
.17781 .4844 Mdot
.91353 .17068 Mdot
.49923 .10059 Mdot
.32093 .23141 Mdot
.40892 .03998 Mdot
.49962 .114 Mdot
.34612 .15159 Mdot
.5814 .557 Mdot
.45056 .06521 Mdot
.37195 .02486 Mdot
.54797 .50175 Mdot
.54177 .5299 Mdot
.40279 .01658 Mdot
.42629 .04752 Mdot
.7608 .10994 Mdot
.6535 .49051 Mdot
.46413 .07686 Mdot
.05729 .22324 Mdot
.52928 .5112 Mdot
.69678 .36657 Mdot
.32824 .20945 Mdot
.01294 .42034 Mdot
.64601 .48589 Mdot
.57915 .50228 Mdot
.11938 .24334 Mdot
.34466 .14856 Mdot
.38852 .01559 Mdot
.3217 .23718 Mdot
.80408 .35868 Mdot
.66094 .48413 Mdot
.53611 .51321 Mdot
.40692 .0424 Mdot
.32736 .20708 Mdot
.87214 .37412 Mdot
.12325 .24458 Mdot
.55161 .53754 Mdot
.35177 .00825 Mdot
.51346 .11621 Mdot
.56372 .511 Mdot
.53954 .52149 Mdot
.47935 .10051 Mdot
.57845 .54968 Mdot
.46504 .07793 Mdot
.51332 .00648 Mdot
.56739 .51054 Mdot
.43568 .0305 Mdot
.41524 .03176 Mdot
.43264 .05933 Mdot
.40946 .02976 Mdot
.67709 .4338 Mdot
.46116 .11772 Mdot
.5588 .53254 Mdot
.68291 .12029 Mdot
.36246 .00663 Mdot
.64774 .4837 Mdot
.48379 .1007 Mdot
.67052 .45028 Mdot
.42994 .02946 Mdot
.37029 .13192 Mdot
.56138 .54388 Mdot
.41813 .03661 Mdot
.37682 .00876 Mdot
.67923 .11786 Mdot
.55925 .07143 Mdot
.62869 .50352 Mdot
.48541 .04371 Mdot
.41431 .0359 Mdot
.61637 .49858 Mdot
.31317 .24994 Mdot
.17579 .25773 Mdot
.65018 .10676 Mdot
.68676 .37957 Mdot
.80241 .12743 Mdot
.65836 .47617 Mdot
.57787 .50131 Mdot
.04288 .43183 Mdot
.55334 .50278 Mdot
.64874 .48315 Mdot
.31618 .24549 Mdot
.63137 .50201 Mdot
.60692 .50838 Mdot
.48583 .12029 Mdot
.62551 .58491 Mdot
.33492 .18917 Mdot
.46127 .08567 Mdot
.56833 .50582 Mdot
.05751 .22272 Mdot
.49665 .05113 Mdot
.11058 .24083 Mdot
.49178 .12633 Mdot
.39506 .02977 Mdot
.45744 .12563 Mdot
.40077 .03213 Mdot
.38896 .02638 Mdot
.43938 .06509 Mdot
.33365 .1954 Mdot
.39048 .01489 Mdot
.65472 .4798 Mdot
.50742 .00341 Mdot
.06354 .22533 Mdot
.53912 .51057 Mdot
.50355 .05382 Mdot
.16707 .25615 Mdot
.66796 .44762 Mdot
.32397 .22678 Mdot
.40639 .12355 Mdot
.41134 .02708 Mdot
.66682 .47356 Mdot
.37823 .02346 Mdot
.39805 .02298 Mdot
.94028 .39476 Mdot
.91305 .38601 Mdot
.56281 .02725 Mdot
.35145 .13978 Mdot
.68382 .11971 Mdot
.56702 .50269 Mdot
.33625 .17748 Mdot
.44708 .06834 Mdot
.44286 .05897 Mdot
.51091 .11144 Mdot
.40452 .03584 Mdot
.48297 .10107 Mdot
.22244 .50233 Mdot
.65718 .47504 Mdot
.7354 .14024 Mdot
.42478 .0361 Mdot
.65247 .60529 Mdot
.42484 .12411 Mdot
.38843 .12488 Mdot
.46837 .09248 Mdot
.41217 .02155 Mdot
.58347 .5031 Mdot
.68022 .40614 Mdot
.24915 .51272 Mdot
.40119 .04472 Mdot
.70157 .36691 Mdot
.38947 .03476 Mdot
.46366 .12764 Mdot
.4037 .04667 Mdot
.36922 .01074 Mdot
.52289 .01044 Mdot
.53178 .51946 Mdot
.85591 .36984 Mdot
.64283 .10455 Mdot
.65364 .4842 Mdot
.43802 .12481 Mdot
.75867 .35236 Mdot
.24944 .26972 Mdot
.52807 .12472 Mdot
.60149 .09005 Mdot
.4471 .06569 Mdot
.5184 .05741 Mdot
.67112 .42825 Mdot
.41019 .04378 Mdot
.5547 .51999 Mdot
.41871 .02861 Mdot
.43279 .06567 Mdot
.31307 .25461 Mdot
.46166 .12728 Mdot
.64957 .60605 Mdot
.69767 .12648 Mdot
.54903 .53531 Mdot
.62124 .49655 Mdot
.63612 .4937 Mdot
.3746 .02748 Mdot
.41505 .12496 Mdot
.38688 .01767 Mdot
.38299 .12296 Mdot
.57396 .54987 Mdot
.6678 .45316 Mdot
.43636 .12018 Mdot
.65303 .48 Mdot
.49578 .11365 Mdot
.5395 .52718 Mdot
.94063 .39503 Mdot
.54975 .06906 Mdot
.79129 .12196 Mdot
.47766 .12864 Mdot
.50883 .11637 Mdot
.46313 .04145 Mdot
.34661 .14749 Mdot
.39133 .12631 Mdot
.37602 .02832 Mdot
.64283 .49183 Mdot
.77862 .35564 Mdot
.57218 .54578 Mdot
.40296 .02842 Mdot
.6054 .50459 Mdot
.9183 .38856 Mdot
.4678 .08184 Mdot
.36982 .12628 Mdot
.50872 .05546 Mdot
.61262 .50357 Mdot
.68935 .37118 Mdot
.66934 .45769 Mdot
.67033 .46051 Mdot
.55251 .52092 Mdot
.53519 .5165 Mdot
.60427 .0451 Mdot
.55701 .52592 Mdot
.39478 .01559 Mdot
.64137 .48697 Mdot
.67334 .42871 Mdot
.91293 .17048 Mdot
.67008 .46182 Mdot
.5899 .5627 Mdot
.36396 .01267 Mdot
.39286 .01625 Mdot
.43734 .02938 Mdot
.46207 .08797 Mdot
.47443 .0883 Mdot
.40302 .04234 Mdot
.48866 .10858 Mdot
.28356 .26536 Mdot
.41391 .12561 Mdot
.64654 .59823 Mdot
.6339 .49272 Mdot
.37958 .03176 Mdot
.3337 .20808 Mdot
.58871 .08288 Mdot
.08676 .23277 Mdot
.65954 .48054 Mdot
.42479 .0349 Mdot
.7287 .35327 Mdot
.5566 .52491 Mdot
.58182 .08224 Mdot
.51948 .12124 Mdot
.48351 .04599 Mdot
.90361 .38398 Mdot
.53473 .06188 Mdot
.50712 .0526 Mdot
.58431 .5112 Mdot
.28147 .26495 Mdot
.39361 .03909 Mdot
.43431 .06555 Mdot
.52503 .12899 Mdot
.39778 .03099 Mdot
.33776 .15656 Mdot
.8436 .36764 Mdot
.46877 .08765 Mdot
.35968 .012 Mdot
.40832 .03298 Mdot
.57625 .54576 Mdot
.42058 .0339 Mdot
.27377 .26691 Mdot
.44801 .0338 Mdot
.4229 .1182 Mdot
.27396 .26821 Mdot
.39776 .01909 Mdot
.40219 .03664 Mdot
.46351 .07866 Mdot
.61045 .57313 Mdot
.44836 .07088 Mdot
.70214 .36316 Mdot
.44247 .11767 Mdot
.45707 .12408 Mdot
.72087 .3568 Mdot
.42992 .04776 Mdot
.4654 .12484 Mdot
.66259 .46967 Mdot
.40777 .1202 Mdot
.43132 .1243 Mdot
.4666 .03732 Mdot
.32256 .23727 Mdot
.81687 .13332 Mdot
.53766 .52688 Mdot
.52034 .11606 Mdot
.48912 .12313 Mdot
.67305 .42776 Mdot
.44678 .03091 Mdot
.40378 .03604 Mdot
.47135 .11907 Mdot
.54932 .50822 Mdot
.62618 .49786 Mdot
.71384 .36057 Mdot
.43027 .03441 Mdot
.66764 .11542 Mdot
.5039 .10517 Mdot
.66709 .45047 Mdot
.40961 .01857 Mdot
.58148 .50951 Mdot
.58374 .51118 Mdot
.62671 .49477 Mdot
.78889 .1217 Mdot
.66894 .46516 Mdot
.5378 .51965 Mdot
.55668 .51784 Mdot
.17867 .48441 Mdot
.64511 .49446 Mdot
.40444 .03659 Mdot
.40886 .03473 Mdot
.43915 .06897 Mdot
.42713 .0388 Mdot
.42771 .05934 Mdot
.34539 .15696 Mdot
.34386 .15653 Mdot
.56992 .50207 Mdot
.78133 .35466 Mdot
.65784 .47819 Mdot
.72052 .1347 Mdot
.61426 .50322 Mdot
.59346 .50238 Mdot
.33744 .18051 Mdot
.75816 .35153 Mdot
.42186 .04267 Mdot
.48623 .09542 Mdot
.58197 .50061 Mdot
.04781 .43405 Mdot
.61496 .50652 Mdot
.41421 .02488 Mdot
.395 .03271 Mdot
.45839 .03731 Mdot
.42825 .04985 Mdot
.49778 .11779 Mdot
.25692 .27022 Mdot
.64453 .48905 Mdot
.33372 .16872 Mdot
.51509 .11999 Mdot
.63542 .49041 Mdot
.32069 .24421 Mdot
.62181 .49632 Mdot
.24536 .26732 Mdot
.36143 .13706 Mdot
.50604 .11891 Mdot
.43094 .03221 Mdot
.36026 .00974 Mdot
.4812 .12726 Mdot
.41436 .0377 Mdot
.49168 .04811 Mdot
.55 .53548 Mdot
.50819 .12398 Mdot
.45493 .07878 Mdot
.79272 .35661 Mdot
.56431 .50195 Mdot
.48112 .04673 Mdot
.50906 .11735 Mdot
.64405 .59914 Mdot
.50182 .11652 Mdot
.31914 .24008 Mdot
.49147 .04723 Mdot
.50949 .11994 Mdot
.39696 .0333 Mdot
.62214 .50575 Mdot
.61601 .57675 Mdot
.45994 .07963 Mdot
.47391 .09714 Mdot
.45297 .03528 Mdot
.6097 .50241 Mdot
.41009 .02379 Mdot
.88199 .15826 Mdot
.73808 .35243 Mdot
.4216 .12164 Mdot
.41059 .04041 Mdot
.45684 .0403 Mdot
.41956 .04697 Mdot
.40765 .03775 Mdot
.38667 .01118 Mdot
.5047 .05123 Mdot
.58176 .50718 Mdot
.46734 .09129 Mdot
.53003 .50271 Mdot
.58174 .50078 Mdot
.51193 .05591 Mdot
.44355 .06577 Mdot
.54758 .534 Mdot
.54287 .06664 Mdot
.90467 .16746 Mdot
.53455 .52397 Mdot
.97531 .40675 Mdot
.65072 .48657 Mdot
.99702 .41492 Mdot
.70824 .08811 Mdot
.54175 .51637 Mdot
.53439 .51369 Mdot
.68056 .39977 Mdot
.33281 .19828 Mdot
.55032 .51462 Mdot
.5228 .12729 Mdot
.41832 .12028 Mdot
.30219 .2613 Mdot
.52738 .50709 Mdot
.54221 .50743 Mdot
.43505 .0305 Mdot
.44631 .03909 Mdot
.46289 .08662 Mdot
.51037 .1158 Mdot
.45879 .12302 Mdot
.9059 .38531 Mdot
.52142 .1266 Mdot
.39064 .12132 Mdot
.45601 .03597 Mdot
.672 .4352 Mdot
.47043 .08673 Mdot
.70012 .36829 Mdot
.49281 .05046 Mdot
.39859 .12752 Mdot
.5566 .51223 Mdot
.41952 .05566 Mdot
.80535 .12782 Mdot
.44529 .1207 Mdot
.37818 .01232 Mdot
.36928 .00916 Mdot
.55542 .51352 Mdot
.42779 .04645 Mdot
.67566 .40516 Mdot
.82577 .13593 Mdot
.32359 .23149 Mdot
.58814 .56092 Mdot
.34296 .15871 Mdot
.67349 .07402 Mdot
.48044 .04221 Mdot
.49948 .10922 Mdot
.61946 .57855 Mdot
.49375 .11653 Mdot
.50493 .05084 Mdot
.59957 .5643 Mdot
.48414 .12188 Mdot
.31896 .24041 Mdot
.56564 .54754 Mdot
.0957 .45135 Mdot
.4956 .11317 Mdot
.54211 .50933 Mdot
.41372 .03902 Mdot
.46998 .12758 Mdot
.46329 .08065 Mdot
.40099 .0334 Mdot
.43849 .03829 Mdot
.46871 .08883 Mdot
.56135 .50987 Mdot
.5215 .50448 Mdot
.48849 .04605 Mdot
.45557 .03873 Mdot
.63128 .49489 Mdot
.49375 .10614 Mdot
.36587 .13299 Mdot
.67033 .45517 Mdot
.53799 .06711 Mdot
.42807 .12543 Mdot
.67848 .43021 Mdot
.45589 .07476 Mdot
.59616 .56178 Mdot
.33523 .18049 Mdot
.60624 .50597 Mdot
.46605 .07862 Mdot
.38548 .02472 Mdot
.40399 .01795 Mdot
.29837 .26369 Mdot
.41901 .03462 Mdot
.52626 .12828 Mdot
.18681 .26095 Mdot
.67744 .39159 Mdot
.41654 .12129 Mdot
.18168 .25918 Mdot
.66531 .47444 Mdot
.07655 .23023 Mdot
.52262 .12981 Mdot
.28952 .26433 Mdot
.43794 .12314 Mdot
.57729 .50663 Mdot
.41914 .02916 Mdot
.50788 .11769 Mdot
.48396 .12715 Mdot
.67612 .42158 Mdot
.39318 .01659 Mdot
.54975 .07073 Mdot
.3995 .02889 Mdot
.49723 .09706 Mdot
.2281 .5047 Mdot
.56043 .50753 Mdot
.48409 .11012 Mdot
.75048 .14628 Mdot
.39396 .01532 Mdot
.1927 .49001 Mdot
.32366 .23584 Mdot
.67744 .4284 Mdot
.22734 .26592 Mdot
.13027 .24661 Mdot
.44415 .06746 Mdot
.43092 .03626 Mdot
.38102 .13087 Mdot
.47257 .12299 Mdot
.44528 .06353 Mdot
.49018 .12353 Mdot
.47163 .08734 Mdot
.54229 .50227 Mdot
.77458 .11604 Mdot
.55626 .53643 Mdot
.4053 .03308 Mdot
.41646 .05247 Mdot
.62222 .58234 Mdot
.55019 .52843 Mdot
.4088 .12046 Mdot
.49511 .13037 Mdot
.4184 .02129 Mdot
.38985 .02202 Mdot
.77973 .11814 Mdot
.46465 .12233 Mdot
.60968 .50883 Mdot
.19974 .26164 Mdot
.6268 .49637 Mdot
.41258 .0386 Mdot
.53035 .50602 Mdot
.49374 .11988 Mdot
.50491 .10337 Mdot
.60525 .50186 Mdot
.49477 .1246 Mdot
.32217 .24312 Mdot
.55472 .02383 Mdot
.44154 .06734 Mdot
.54863 .02126 Mdot
.61593 .49976 Mdot
.5497 .52881 Mdot
.351 .14484 Mdot
.37901 .0282 Mdot
.41364 .05292 Mdot
.67652 .4042 Mdot
.46792 .07887 Mdot
.41617 .04385 Mdot
.10361 .23885 Mdot
.70625 .35827 Mdot
.38641 .12598 Mdot
.54364 .52344 Mdot
.66494 .46106 Mdot
.62161 .5063 Mdot
.39868 .02452 Mdot
.66654 .4723 Mdot
.42875 .02363 Mdot
.38985 .02823 Mdot
.70219 .08572 Mdot
.62735 .50152 Mdot
.55268 .50956 Mdot
.43804 .06124 Mdot
.26668 .2664 Mdot
.41555 .12084 Mdot
.30135 .53514 Mdot
.39574 .12261 Mdot
.43649 .59137 Mdot
.33077 .20655 Mdot
.39117 .12831 Mdot
.35512 .13452 Mdot
.56417 .53985 Mdot
.33405 .17534 Mdot
.65476 .10916 Mdot
.41435 .02618 Mdot
.33518 .19146 Mdot
.62941 .49594 Mdot
.70692 .36428 Mdot
.33877 .15294 Mdot
.42178 .04834 Mdot
.61161 .5019 Mdot
.75836 .10931 Mdot
.34901 .14441 Mdot
.66638 .46481 Mdot
.65362 .60682 Mdot
.81404 .36065 Mdot
.57814 .5051 Mdot
.50962 .05486 Mdot
.36494 .02046 Mdot
.40845 .03191 Mdot
.61321 .49772 Mdot
.63648 .59499 Mdot
.59711 .50581 Mdot
.477 .09755 Mdot
.33996 .15512 Mdot
.4873 .12697 Mdot
.33005 .19132 Mdot
.57323 .50182 Mdot
.33263 .20249 Mdot
.00637 .41813 Mdot
.36044 .13733 Mdot
.51196 .12093 Mdot
.65416 .48417 Mdot
.47273 .12529 Mdot
.65668 .48793 Mdot
.40935 .04523 Mdot
.41461 .12389 Mdot
.92026 .38935 Mdot
.43348 .02769 Mdot
.54844 .0666 Mdot
.49054 .12783 Mdot
.42508 .11971 Mdot
.62771 .58522 Mdot
.5482 .52096 Mdot
.4137 .02632 Mdot
.51744 .1295 Mdot
.40835 .03263 Mdot
.46363 .08259 Mdot
.55192 .50159 Mdot
.37614 .13055 Mdot
.19994 .49314 Mdot
.49067 .61417 Mdot
.43807 .03393 Mdot
.50731 .05577 Mdot
.40091 .03313 Mdot
.43317 .06415 Mdot
.71603 .13384 Mdot
.67802 .40135 Mdot
.53786 .50556 Mdot
.50653 .10411 Mdot
.36263 .0161 Mdot
.56106 .54004 Mdot
.50806 .12108 Mdot
.3586 .13336 Mdot
.43775 .03399 Mdot
.44232 .07088 Mdot
.62908 .58599 Mdot
.75387 .14758 Mdot
.57405 .54996 Mdot
.44477 .06826 Mdot
.66261 .11341 Mdot
.63812 .49545 Mdot
.64378 .10443 Mdot
.55875 .53743 Mdot
.7188 .35504 Mdot
.56936 .02953 Mdot
.39127 .12443 Mdot
.42543 .04785 Mdot
.32553 .22312 Mdot
.42335 .04423 Mdot
.9708 .40512 Mdot
.40174 .01686 Mdot
.26087 .26708 Mdot
.42987 .03196 Mdot
.35117 .14057 Mdot
.45823 .07874 Mdot
.52168 .50741 Mdot
.65638 .47845 Mdot
.48744 .09667 Mdot
.43527 .12191 Mdot
.53573 .51224 Mdot
.42314 .02598 Mdot
.49091 .1181 Mdot
.36437 .01439 Mdot
.53571 .52258 Mdot
.54757 .50826 Mdot
.50878 .10747 Mdot
.38882 .12939 Mdot
.31545 .25164 Mdot
.64335 .49383 Mdot
.49001 .11717 Mdot
.33124 .18548 Mdot
.50938 .10769 Mdot
.46801 .08224 Mdot
.44179 .03209 Mdot
.44521 .07014 Mdot
.44696 .07112 Mdot
.32921 .18992 Mdot
.6401 .49446 Mdot
.52185 .50844 Mdot
.42335 .03003 Mdot
.55302 .53132 Mdot
.55331 .50875 Mdot
.17804 .25741 Mdot
.45011 .1237 Mdot
.39308 .02419 Mdot
.4287 .04665 Mdot
.59392 .5646 Mdot
.43109 .02714 Mdot
.43236 .58944 Mdot
.45155 .03971 Mdot
.54655 .50089 Mdot
.36391 .01075 Mdot
.67448 .43878 Mdot
.43375 .03126 Mdot
.4855 .09875 Mdot
.62454 .49499 Mdot
.55958 .07404 Mdot
.37385 .12573 Mdot
.4215 .0312 Mdot
.43873 .06314 Mdot
.53934 .01736 Mdot
.53935 .06433 Mdot
.55692 .51389 Mdot
.58755 .55409 Mdot
.4357 .0698 Mdot
.67715 .42745 Mdot
.63659 .4971 Mdot
.44634 .03418 Mdot
.23155 .50624 Mdot
.67579 .42423 Mdot
.52291 .13026 Mdot
.52617 .12631 Mdot
.54573 .505 Mdot
.33827 .15999 Mdot
.61239 .50288 Mdot
.51936 .12252 Mdot
.81407 .36042 Mdot
.68066 .38342 Mdot
.68926 .37978 Mdot
.33486 .17284 Mdot
.38319 .03572 Mdot
.8625 .15141 Mdot
.76863 .35243 Mdot
.44526 .03651 Mdot
.9313 .39295 Mdot
.67785 .40833 Mdot
.56403 .54278 Mdot
.44203 .06288 Mdot
.41226 .02973 Mdot
.23738 .50856 Mdot
.47204 .08063 Mdot
.45219 .07613 Mdot
.41907 .04068 Mdot
.32877 .2189 Mdot
.57842 .034 Mdot
.46685 .07999 Mdot
.63875 .5966 Mdot
.03811 .42947 Mdot
.609 .0911 Mdot
.45059 .07401 Mdot
.53392 .52435 Mdot
.35743 .1407 Mdot
.32306 .22798 Mdot
.49221 .10667 Mdot
.38358 .03107 Mdot
.07477 .44399 Mdot
.44166 .12199 Mdot
.32756 .20268 Mdot
.36105 .13486 Mdot
.72582 .35648 Mdot
.50916 .12387 Mdot
.22351 .26603 Mdot
.2903 .26473 Mdot
.59512 .08474 Mdot
.38755 .02284 Mdot
.67527 .4153 Mdot
.37431 .00931 Mdot
.55164 .52433 Mdot
.33244 .20636 Mdot
.29803 .26158 Mdot
.38107 .02566 Mdot
.78239 .35574 Mdot
.04158 .43141 Mdot
.43026 .06275 Mdot
.40899 .05213 Mdot
.39702 .02827 Mdot
.55493 .52663 Mdot
.29075 .2627 Mdot
.57536 .54752 Mdot
.36827 .13343 Mdot
.49931 .10585 Mdot
.62284 .58309 Mdot
.44604 .07365 Mdot
.39982 .03965 Mdot
.37231 .13071 Mdot
.64487 .5985 Mdot
.50354 .11787 Mdot
.66745 .46388 Mdot
.46675 .07797 Mdot
.49344 .11337 Mdot
.46034 .12291 Mdot
.68022 .39803 Mdot
.64753 .10641 Mdot
.62293 .49966 Mdot
.64625 .49124 Mdot
.67509 .40372 Mdot
.36285 .12923 Mdot
.33759 .18338 Mdot
.56474 .53693 Mdot
.56451 .50643 Mdot
.29058 .26507 Mdot
.30533 .53614 Mdot
.4405 .07081 Mdot
.67383 .44194 Mdot
.38283 .02689 Mdot
.63874 .59401 Mdot
.43352 .05654 Mdot
.36198 .12975 Mdot
.5603 .5137 Mdot
.61114 .49774 Mdot
.63453 .58918 Mdot
.64295 .4932 Mdot
.50401 .12076 Mdot
.46719 .08589 Mdot
.40304 .04442 Mdot
.50411 .1283 Mdot
.72353 .13608 Mdot
.41393 .12409 Mdot
.64045 .48932 Mdot
.4219 .02799 Mdot
.67387 .43164 Mdot
.44793 .12361 Mdot
.60688 .5002 Mdot
.67121 .42697 Mdot
.49865 .10284 Mdot
.49289 .10057 Mdot
.40657 .04408 Mdot
.67029 .46521 Mdot
.39058 .02824 Mdot
.36374 .12997 Mdot
.33171 .18813 Mdot
.4059 .04268 Mdot
.79437 .12411 Mdot
.2808 .52662 Mdot
.55168 .51902 Mdot
.53829 .0661 Mdot
.38088 .13111 Mdot
.5708 .50303 Mdot
.49919 .12275 Mdot
.54069 .51772 Mdot
.47611 .10133 Mdot
.09462 .23498 Mdot
.92596 .39107 Mdot
.43167 .05389 Mdot
.65745 .10929 Mdot
.4384 .12612 Mdot
.35908 .00964 Mdot
.31844 .23874 Mdot
.32917 .20105 Mdot
.31371 .25366 Mdot
.5454 .06704 Mdot
.67441 .4286 Mdot
.65536 .48592 Mdot
.46032 .08523 Mdot
.41587 .05801 Mdot
.53752 .51811 Mdot
.37822 .02817 Mdot
.49817 .11322 Mdot
.37286 .02817 Mdot
.54053 .52407 Mdot
.32684 .23263 Mdot
.43093 .06148 Mdot
.99847 .41494 Mdot
.52594 .12615 Mdot
.68739 .37699 Mdot
.4136 .03874 Mdot
.91042 .16975 Mdot
.482 .12329 Mdot
.31045 .25062 Mdot
.3657 .0222 Mdot
.34917 .14057 Mdot
.453 .03798 Mdot
.63546 .49328 Mdot
.56469 .53983 Mdot
.43523 .06798 Mdot
.36396 .13348 Mdot
.49039 .12747 Mdot
.40834 .02704 Mdot
.5381 .51844 Mdot
.54443 .50425 Mdot
.32956 .19411 Mdot
.59964 .50026 Mdot
.35561 .01638 Mdot
.09351 .23472 Mdot
.41964 .04754 Mdot
.37213 .13431 Mdot
.42132 .02497 Mdot
.39005 .01981 Mdot
.32111 .24349 Mdot
.60252 .50731 Mdot
.67654 .41028 Mdot
.41146 .02421 Mdot
.49406 .11569 Mdot
.45778 .12239 Mdot
.48546 .10219 Mdot
.54409 .53124 Mdot
.56356 .53527 Mdot
.4871 .10855 Mdot
.58964 .56249 Mdot
.45824 .03766 Mdot
.48831 .10473 Mdot
.48503 .04859 Mdot
.41911 .12525 Mdot
.38216 .01317 Mdot
.41132 .04411 Mdot
.31836 .2488 Mdot
.60353 .56727 Mdot
.71536 .35908 Mdot
.55524 .51697 Mdot
.33771 .17125 Mdot
.4935 .04848 Mdot
.48953 .09218 Mdot
.59842 .50282 Mdot
.48233 .10712 Mdot
.42985 .0586 Mdot
.43872 .03326 Mdot
.7362 .14085 Mdot
.47262 .12739 Mdot
.52795 .05994 Mdot
.58678 .50048 Mdot
.6797 .11938 Mdot
.38856 .02955 Mdot
.6164 .57618 Mdot
.67467 .42808 Mdot
.50178 .05383 Mdot
.31676 .24557 Mdot
.54647 .52695 Mdot
.48294 .09213 Mdot
.53947 .51548 Mdot
.68343 .39285 Mdot
.67109 .46131 Mdot
.50595 .05382 Mdot
.79612 .35806 Mdot
.57257 .54666 Mdot
.65945 .47948 Mdot
.46616 .04241 Mdot
.12266 .24407 Mdot
.88122 .37704 Mdot
.66813 .45742 Mdot
.43673 .05893 Mdot
.7441 .35468 Mdot
.52565 .1261 Mdot
.63306 .58861 Mdot
.3929 .12186 Mdot
.40408 .04437 Mdot
.51011 .10936 Mdot
.48124 .08976 Mdot
.48615 .0502 Mdot
.57588 .50069 Mdot
.31685 .24704 Mdot
.55321 .51998 Mdot
.41361 .03226 Mdot
.46279 .03975 Mdot
.14827 .47272 Mdot
.39613 .0237 Mdot
.51031 .11504 Mdot
.62622 .58303 Mdot
.57967 .51076 Mdot
.73364 .09876 Mdot
.36179 .5604 Mdot
.54118 .51361 Mdot
.40812 .04841 Mdot
.61019 .50565 Mdot
.5447 .52069 Mdot
.52145 .50569 Mdot
.40608 .02507 Mdot
.79229 .12282 Mdot
.32432 .54482 Mdot
.78135 .35432 Mdot
.526 .50808 Mdot
.62559 .09669 Mdot
.37596 .01323 Mdot
.37349 .01858 Mdot
.59092 .56365 Mdot
.39301 .02758 Mdot
.55165 .52523 Mdot
.47652 .12405 Mdot
.03386 .42887 Mdot
.52359 .51354 Mdot
.75997 .15051 Mdot
.46353 .04114 Mdot
.44808 .03758 Mdot
.44566 .07665 Mdot
.40189 .02267 Mdot
.57343 .07777 Mdot
.42408 .05464 Mdot
.54168 .52628 Mdot
.42935 .03705 Mdot
.48686 .12676 Mdot
.7267 .09542 Mdot
.83027 .13839 Mdot
.01854 .20933 Mdot
.51158 .12849 Mdot
.48757 .1085 Mdot
.42888 .05314 Mdot
.43911 .03113 Mdot
.47587 .04716 Mdot
.55341 .53784 Mdot
.47492 .08497 Mdot
.92961 .39139 Mdot
.58992 .56252 Mdot
.37184 .02591 Mdot
.43719 .06548 Mdot
.68379 .37811 Mdot
.68132 .39328 Mdot
.44392 .06113 Mdot
.51832 .12561 Mdot
.46162 .08375 Mdot
.43111 .03307 Mdot
.3877 .12291 Mdot
.55201 .53785 Mdot
.52242 .50973 Mdot
.6518 .49321 Mdot
.17299 .25781 Mdot
.83587 .36537 Mdot
.60291 .08982 Mdot
.65914 .48723 Mdot
.92968 .17779 Mdot
.19741 .26134 Mdot
.41588 .1238 Mdot
.47807 .09417 Mdot
.39192 .01917 Mdot
.36677 .13066 Mdot
.49789 .11139 Mdot
.33228 .1861 Mdot
.69179 .08133 Mdot
.89044 .38032 Mdot
.34544 .15204 Mdot
.6889 .37982 Mdot
.67894 .40484 Mdot
.4718 .08556 Mdot
.4284 .03701 Mdot
.36957 .01045 Mdot
.38908 .02536 Mdot
.34183 .16597 Mdot
.54148 .52912 Mdot
.40278 .02266 Mdot
.40502 .03617 Mdot
.48642 .09297 Mdot
.5835 .50077 Mdot
.46541 .12793 Mdot
.55063 .5278 Mdot
.44035 .0681 Mdot
.23821 .50867 Mdot
.44918 .07784 Mdot
.74938 .10477 Mdot
.32812 .5457 Mdot
.33445 .19905 Mdot
.50596 .12586 Mdot
.3837 .12425 Mdot
.67332 .11678 Mdot
.67155 .43401 Mdot
.51922 .12948 Mdot
.0746 .44387 Mdot
.42819 .05693 Mdot
.3666 .01479 Mdot
.40032 .01808 Mdot
.06614 .44006 Mdot
.17755 .25726 Mdot
.5859 .55561 Mdot
.43725 .02848 Mdot
.90577 .38374 Mdot
.53672 .06213 Mdot
.67314 .45872 Mdot
.39899 .12509 Mdot
.41593 .05549 Mdot
.4842 .10712 Mdot
.65911 .11171 Mdot
.42494 .02937 Mdot
.44365 .12432 Mdot
.03018 .42697 Mdot
.27207 .26733 Mdot
.67346 .41111 Mdot
.59837 .5637 Mdot
.56458 .02779 Mdot
.39996 .0185 Mdot
.52145 .05947 Mdot
.56452 .54247 Mdot
.6297 .49994 Mdot
.54849 .50578 Mdot
.25106 .27004 Mdot
.48549 .09498 Mdot
.44899 .0313 Mdot
.54357 .50457 Mdot
.44573 .12199 Mdot
.71704 .35922 Mdot
.25427 .51579 Mdot
.6744 .4311 Mdot
.67241 .42916 Mdot
.53023 .51091 Mdot
.65925 .47863 Mdot
.71634 .13268 Mdot
.42709 .02666 Mdot
.69562 .36628 Mdot
.36409 .02079 Mdot
.5549 .53973 Mdot
.83249 .13927 Mdot
.35801 .00734 Mdot
.63553 .49746 Mdot
.41522 .04551 Mdot
.39336 .03317 Mdot
.41697 .12174 Mdot
.46524 .07591 Mdot
.4728 .12395 Mdot
.48544 .09964 Mdot
.6113 .49954 Mdot
.44527 .07253 Mdot
.56151 .5417 Mdot
.33166 .20598 Mdot
.57209 .55102 Mdot
.57601 .50041 Mdot
.46426 .60328 Mdot
.33882 .16561 Mdot
.53888 .06783 Mdot
.43104 .02953 Mdot
.66601 .46643 Mdot
.53202 .51041 Mdot
.37659 .00999 Mdot
.35079 .15061 Mdot
.40834 .05249 Mdot
.37927 .01215 Mdot
.46633 .04435 Mdot
.47635 .12084 Mdot
.908 .169 Mdot
.67754 .41991 Mdot
.47055 .12447 Mdot
.64501 .48531 Mdot
.66718 .45241 Mdot
.68168 .3993 Mdot
.32767 .23057 Mdot
.44685 .03743 Mdot
.46142 .12614 Mdot
.39771 .0241 Mdot
.4139 .0346 Mdot
.54392 .50586 Mdot
.75497 .3521 Mdot
.52226 .05702 Mdot
.40547 .02725 Mdot
.49519 .10506 Mdot
.33331 .19023 Mdot
.42438 .12374 Mdot
.61219 .5047 Mdot
.41411 .03763 Mdot
.47283 .08134 Mdot
.37296 .02264 Mdot
.40173 .04741 Mdot
.42817 .03627 Mdot
.50216 .12904 Mdot
.46984 .08837 Mdot
.48333 .11796 Mdot
.62849 .5026 Mdot
.69493 .36993 Mdot
.32746 .21071 Mdot
.68297 .3964 Mdot
.38868 .03177 Mdot
.51919 .11407 Mdot
.36005 .01417 Mdot
.43294 .05326 Mdot
.55946 .50291 Mdot
.54523 .53301 Mdot
.47259 .12719 Mdot
.42539 .12519 Mdot
.42953 .12605 Mdot
.56982 .50334 Mdot
.50157 .05281 Mdot
.55806 .5358 Mdot
.57585 .54717 Mdot
.33921 .16031 Mdot
.55668 .53638 Mdot
.39352 .02073 Mdot
.40852 .05177 Mdot
.47356 .08931 Mdot
.84096 .36597 Mdot
.71139 .35935 Mdot
.37851 .01196 Mdot
.58081 .55215 Mdot
.54371 .51346 Mdot
.74323 .1438 Mdot
.62255 .58389 Mdot
.33045 .20962 Mdot
.62247 .09585 Mdot
.32611 .21396 Mdot
.61377 .50387 Mdot
.43434 .02989 Mdot
.45655 .07837 Mdot
.33295 .16922 Mdot
.47028 .09324 Mdot
.51313 .12328 Mdot
.4486 .06938 Mdot
.51074 .11318 Mdot
.50536 .11312 Mdot
.53645 .52348 Mdot
.44927 .067 Mdot
.29941 .25792 Mdot
.29746 .25921 Mdot
.49278 .10366 Mdot
.41811 .02886 Mdot
.55316 .53016 Mdot
.55446 .52697 Mdot
.41183 .12473 Mdot
.32096 .24613 Mdot
.40884 .05326 Mdot
.49404 .10726 Mdot
.41915 .0343 Mdot
.55123 .52367 Mdot
.68151 .39844 Mdot
.33089 .20121 Mdot
.30045 .25878 Mdot
.443 .06375 Mdot
.40211 .12632 Mdot
.4161 .11939 Mdot
.35533 .01035 Mdot
.67253 .42728 Mdot
.59997 .56878 Mdot
.4687 .08023 Mdot
.68905 .37222 Mdot
.36482 .13041 Mdot
.5958 .50376 Mdot
.64896 .49188 Mdot
.43989 .11899 Mdot
.79685 .35614 Mdot
.60866 .50046 Mdot
.4466 .03748 Mdot
.61403 .49849 Mdot
.34434 .15583 Mdot
.52641 .51465 Mdot
.48566 .04867 Mdot
.50875 .05635 Mdot
.68143 .39534 Mdot
.50236 .1161 Mdot
.66928 .47017 Mdot
.39856 .01519 Mdot
.43592 .0558 Mdot
.4783 .115 Mdot
.41165 .05537 Mdot
.47363 .12733 Mdot
.78218 .11855 Mdot
.66591 .07079 Mdot
.4828 .12309 Mdot
.46307 .12654 Mdot
.3346 .19175 Mdot
.39213 .03403 Mdot
.14627 .25094 Mdot
.42957 .0659 Mdot
.43239 .0497 Mdot
.59886 .56858 Mdot
.4808 .04847 Mdot
.36669 .12938 Mdot
.81344 .13161 Mdot
.74471 .35283 Mdot
.49105 .11108 Mdot
.40382 .02559 Mdot
.79583 .35701 Mdot
.38412 .01069 Mdot
.56464 .53616 Mdot
.53344 .52047 Mdot
.79956 .1259 Mdot
.61692 .57904 Mdot
.50414 .12418 Mdot
.44246 .12593 Mdot
.69438 .0829 Mdot
.56662 .506 Mdot
.48219 .12655 Mdot
.15844 .25399 Mdot
.57701 .50305 Mdot
.35155 .55585 Mdot
.68297 .39085 Mdot
.59419 .50353 Mdot
.42038 .05953 Mdot
.53502 .51724 Mdot
.68031 .39464 Mdot
.49819 .11373 Mdot
.5679 .53895 Mdot
.52385 .1212 Mdot
.45813 .1263 Mdot
.52702 .50589 Mdot
.72033 .35645 Mdot
.40626 .02252 Mdot
.63087 .50249 Mdot
.45994 .11903 Mdot
.73843 .35452 Mdot
.51695 .11592 Mdot
.38104 .01316 Mdot
.39501 .01956 Mdot
.56657 .07512 Mdot
.52962 .01308 Mdot
.46165 .12696 Mdot
.56151 .50626 Mdot
.58095 .50341 Mdot
.78567 .12057 Mdot
.5579 .50602 Mdot
.51554 .11779 Mdot
.49106 .04658 Mdot
.5959 .50999 Mdot
.62385 .58068 Mdot
.55236 .50754 Mdot
.54477 .51547 Mdot
.45429 .03971 Mdot
.50995 .11765 Mdot
.50025 .12095 Mdot
.41737 .58333 Mdot
.79603 .12445 Mdot
.64433 .0619 Mdot
.42755 .03229 Mdot
.67744 .40089 Mdot
.44277 .03687 Mdot
.59898 .49939 Mdot
.49946 .12085 Mdot
.67197 .44889 Mdot
.40204 .02259 Mdot
.47317 .08154 Mdot
.53116 .50364 Mdot
.67205 .45154 Mdot
.39711 .02167 Mdot
.53607 .06341 Mdot
.58932 .50799 Mdot
.48045 .12206 Mdot
.01958 .21078 Mdot
.73894 .35251 Mdot
.49942 .11635 Mdot
.66195 .48008 Mdot
.46001 .04035 Mdot
.51601 .12885 Mdot
.51395 .11651 Mdot
.67605 .40644 Mdot
.48987 .10958 Mdot
.99549 .20185 Mdot
.5028 .11359 Mdot
.48691 .10546 Mdot
.9008 .1663 Mdot
.34994 .15092 Mdot
.48662 .1195 Mdot
.59571 .50033 Mdot
.38388 .02002 Mdot
.47069 .09129 Mdot
.08795 .44894 Mdot
.46261 .12751 Mdot
.40268 .12315 Mdot
.55299 .53192 Mdot
.67117 .11683 Mdot
.67126 .43444 Mdot
.34466 .14891 Mdot
.36925 .01186 Mdot
.40532 .05029 Mdot
.42836 .11898 Mdot
.55835 .52944 Mdot
.62412 .0981 Mdot
.43087 .0364 Mdot
.4814 .1289 Mdot
.60755 .5026 Mdot
.11373 .24123 Mdot
.68868 .37596 Mdot
.55802 .53469 Mdot
.4863 .11603 Mdot
.55705 .539 Mdot
.42582 .0631 Mdot
.89889 .38158 Mdot
.38703 .025 Mdot
.282 .26459 Mdot
.55875 .50819 Mdot
.58337 .55617 Mdot
.36414 .02164 Mdot
.45883 .07652 Mdot
.48864 .09827 Mdot
.40588 .1205 Mdot
.40939 .01979 Mdot
.93548 .1789 Mdot
.5428 .52485 Mdot
.67416 .45909 Mdot
.50782 .00412 Mdot
.52191 .12459 Mdot
.54096 .50732 Mdot
.34949 .14796 Mdot
.58358 .50283 Mdot
.48225 .10742 Mdot
.50158 .12678 Mdot
.67755 .4296 Mdot
.4034 .12155 Mdot
.48339 .09 Mdot
.52737 .12723 Mdot
.51905 .12589 Mdot
.55521 .50223 Mdot
.6 .51013 Mdot
.63007 .50143 Mdot
.33234 .18301 Mdot
.40188 .02206 Mdot
.46228 .08513 Mdot
.09576 .23619 Mdot
.48245 .12236 Mdot
.45636 .07614 Mdot
.56108 .53355 Mdot
.66963 .45912 Mdot
.40119 .12553 Mdot
.43066 .02539 Mdot
.41599 .12471 Mdot
.43988 .03135 Mdot
.42561 .02521 Mdot
.64575 .60005 Mdot
.53156 .50959 Mdot
.4924 .11482 Mdot
.51945 .12686 Mdot
.60259 .08755 Mdot
.31844 .24127 Mdot
.46198 .08668 Mdot
.55137 .52572 Mdot
.42815 .03047 Mdot
.5172 .12207 Mdot
.3614 .01745 Mdot
.44603 .12048 Mdot
.37817 .0328 Mdot
.26066 .51745 Mdot
.75124 .35386 Mdot
.36234 .0121 Mdot
.52518 .50534 Mdot
.39962 .127 Mdot
.40869 .12631 Mdot
.31012 .5383 Mdot
.36031 .13279 Mdot
.39901 .02515 Mdot
.40885 .11945 Mdot
.56338 .50446 Mdot
.48406 .11386 Mdot
.49304 .11017 Mdot
.33014 .1988 Mdot
.4829 .10541 Mdot
.67194 .43423 Mdot
.67565 .40555 Mdot
.37409 .0199 Mdot
.63628 .10196 Mdot
.60478 .49908 Mdot
.53742 .52198 Mdot
.44761 .06241 Mdot
.68106 .11981 Mdot
.58249 .08253 Mdot
.69323 .37194 Mdot
.6825 .07758 Mdot
.33162 .1995 Mdot
.58338 .55343 Mdot
.53498 .51211 Mdot
.54976 .53607 Mdot
.62979 .49753 Mdot
.60188 .0904 Mdot
.58922 .55913 Mdot
.67817 .07617 Mdot
.53725 .51847 Mdot
.67215 .42409 Mdot
.46858 .04086 Mdot
.57677 .54644 Mdot
.91636 .3872 Mdot
.35905 .0084 Mdot
.66659 .07118 Mdot
.44549 .07614 Mdot
.54373 .52407 Mdot
.3578 .01056 Mdot
.63321 .58981 Mdot
.48592 .11593 Mdot
.57387 .07837 Mdot
.67112 .43063 Mdot
.6323 .58955 Mdot
.63131 .05608 Mdot
.45166 .06614 Mdot
.44187 .5938 Mdot
.67035 .43737 Mdot
.3483 .14416 Mdot
.9746 .40736 Mdot
.3504 .14005 Mdot
.68058 .39667 Mdot
.40725 .05191 Mdot
.96168 .18969 Mdot
.527 .12351 Mdot
.01896 .42308 Mdot
.57241 .50517 Mdot
.46882 .08118 Mdot
.50267 .05548 Mdot
.19181 .48994 Mdot
.69364 .37196 Mdot
.62435 .5047 Mdot
.49878 .12222 Mdot
.40988 .04853 Mdot
.44292 .0688 Mdot
.34665 .14942 Mdot
.66705 .46352 Mdot
.92923 .39235 Mdot
.61999 .58248 Mdot
.32271 .22821 Mdot
.58739 .50035 Mdot
.67988 .39434 Mdot
.55704 .53483 Mdot
.67481 .42871 Mdot
.42083 .12552 Mdot
.17142 .48121 Mdot
.4839 .09678 Mdot
.50151 .05094 Mdot
.50764 .13132 Mdot
.41809 .04261 Mdot
.3687 .13613 Mdot
.65331 .48805 Mdot
.6746 .45306 Mdot
.386 .03189 Mdot
.55093 .52595 Mdot
.49152 .09629 Mdot
.51047 .12013 Mdot
.66734 .4668 Mdot
.36929 .02232 Mdot
.81024 .13064 Mdot
.35572 .55719 Mdot
.31077 .24981 Mdot
.60295 .56846 Mdot
.96611 .19088 Mdot
.37943 .01287 Mdot
.322 .23121 Mdot
.53811 .06531 Mdot
.3904 .01475 Mdot
.64389 .48717 Mdot
.40734 .03168 Mdot
.67158 .42386 Mdot
.47604 .12679 Mdot
.62425 .09754 Mdot
.51928 .05658 Mdot
.44767 .03387 Mdot
.32403 .22654 Mdot
.38501 .01394 Mdot
.35124 .0077 Mdot
.54949 .52334 Mdot
.55977 .513 Mdot
.44913 .07388 Mdot
.12478 .24516 Mdot
.11838 .46038 Mdot
.47028 .09134 Mdot
.3015 .25971 Mdot
.39706 .02787 Mdot
.51878 .11647 Mdot
.67016 .45188 Mdot
.50565 .12186 Mdot
.66831 .4565 Mdot
.26079 .26675 Mdot
.68769 .37942 Mdot
.40194 .02584 Mdot
.524 .05852 Mdot
.70458 .08647 Mdot
.61311 .50115 Mdot
.55531 .52 Mdot
.33436 .19566 Mdot
.41259 .12535 Mdot
.54987 .50749 Mdot
.39382 .03805 Mdot
.40985 .05305 Mdot
.65883 .47473 Mdot
.49884 .12112 Mdot
.34301 .15763 Mdot
.43222 .05469 Mdot
.59305 .55896 Mdot
.32026 .2395 Mdot
.55522 .52456 Mdot
.55999 .50877 Mdot
.52003 .12116 Mdot
.35845 .00971 Mdot
.45049 .07211 Mdot
.59281 .5643 Mdot
.70921 .08841 Mdot
.33839 .16852 Mdot
.53764 .06299 Mdot
.42797 .03264 Mdot
.36953 .00963 Mdot
.69178 .37141 Mdot
.47835 .04191 Mdot
.77308 .35521 Mdot
.3273 .22864 Mdot
.7526 .35369 Mdot
.47078 .11943 Mdot
.63246 .49875 Mdot
.5031 .00218 Mdot
.39079 .12086 Mdot
.65629 .47817 Mdot
.37318 .02333 Mdot
.61774 .49651 Mdot
.50059 .10298 Mdot
.29919 .5339 Mdot
.37694 .1323 Mdot
.59947 .08762 Mdot
.53016 .50749 Mdot
.73191 .35437 Mdot
.54854 .52297 Mdot
.55474 .52137 Mdot
.69443 .08247 Mdot
.45255 .0756 Mdot
.20306 .26256 Mdot
.99344 .2008 Mdot
.39471 .01964 Mdot
.65089 .49166 Mdot
.33523 .17871 Mdot
.55095 .537 Mdot
.67667 .4067 Mdot
.38947 .01806 Mdot
.09925 .45348 Mdot
.49082 .04842 Mdot
.38012 .0245 Mdot
.53543 .5101 Mdot
.67803 .39148 Mdot
.42702 .03757 Mdot
.36803 .1329 Mdot
.34483 .1453 Mdot
.64643 .60164 Mdot
.26766 .52038 Mdot
.41445 .04389 Mdot
.5013 .1257 Mdot
.48501 .12816 Mdot
.42255 .04234 Mdot
.50375 .12005 Mdot
.45045 .1237 Mdot
.67145 .44642 Mdot
.41355 .02617 Mdot
.41782 .03206 Mdot
.67198 .4481 Mdot
.41085 .03636 Mdot
.42924 .05974 Mdot
.65243 .60517 Mdot
.69924 .36783 Mdot
.2856 .26425 Mdot
.50922 .12939 Mdot
.49285 .04934 Mdot
.37854 .01128 Mdot
.45027 .12115 Mdot
.612 .50371 Mdot
.39701 .02137 Mdot
.3785 .0308 Mdot
.65768 .48447 Mdot
.64609 .49264 Mdot
.62494 .50123 Mdot
.66861 .11485 Mdot
.47596 .12288 Mdot
.8208 .36083 Mdot
.4129 .04272 Mdot
.40837 .12496 Mdot
.53692 .51676 Mdot
.67282 .42094 Mdot
.19408 .49104 Mdot
.87881 .3756 Mdot
.5675 .54788 Mdot
.68289 .38358 Mdot
.6049 .56647 Mdot
.29935 .53387 Mdot
.36485 .1385 Mdot
.39727 .0172 Mdot
.47142 .1212 Mdot
.34017 .16386 Mdot
.52198 .11748 Mdot
.55485 .50879 Mdot
.62045 .49656 Mdot
.50094 .1102 Mdot
.54 .52854 Mdot
.67634 .40163 Mdot
.66121 .47883 Mdot
.6183 .0944 Mdot
.40481 .03131 Mdot
.579 .55008 Mdot
.54003 .51097 Mdot
.51598 .12021 Mdot
.44272 .12197 Mdot
.96596 .19057 Mdot
.67486 .41576 Mdot
.4203 .02894 Mdot
.53196 .51569 Mdot
.33231 .19404 Mdot
.51281 .0535 Mdot
.4573 .12526 Mdot
.94292 .39685 Mdot
.26295 .26792 Mdot
.54245 .51278 Mdot
.44665 .03316 Mdot
.77935 .11708 Mdot
.94286 .18212 Mdot
.69437 .37164 Mdot
.5097 .11391 Mdot
.54571 .52169 Mdot
.54342 .52912 Mdot
.6612 .48358 Mdot
.48764 .12274 Mdot
.41969 .05972 Mdot
.54318 .53092 Mdot
.40725 .04032 Mdot
.676 .41597 Mdot
.69118 .37374 Mdot
.43915 .07232 Mdot
.59969 .50862 Mdot
.64657 .4883 Mdot
.41616 .02069 Mdot
.56077 .54059 Mdot
.39567 .01903 Mdot
.42129 .1247 Mdot
.57553 .54744 Mdot
.76031 .11 Mdot
.44249 .59443 Mdot
.584 .55536 Mdot
.62066 .57947 Mdot
.56102 .50284 Mdot
.42119 .02166 Mdot
.66139 .11076 Mdot
.62031 .50653 Mdot
.43823 .03029 Mdot
.56792 .50717 Mdot
.35118 .14764 Mdot
.59 .56151 Mdot
.58004 .55615 Mdot
.4091 .04806 Mdot
.59314 .5086 Mdot
.47315 .0962 Mdot
.40218 .02457 Mdot
.41681 .02911 Mdot
.46923 .04252 Mdot
.41352 .02956 Mdot
.36529 .01298 Mdot
.45879 .12006 Mdot
.334 .17991 Mdot
.32487 .22047 Mdot
.42291 .58573 Mdot
.4122 .03089 Mdot
.46158 .60229 Mdot
.56714 .07421 Mdot
.52706 .12619 Mdot
.82858 .36451 Mdot
.45364 .11947 Mdot
.86463 .37197 Mdot
.44164 .03794 Mdot
.4446 .03905 Mdot
.67491 .42906 Mdot
.6887 .3818 Mdot
.4169 .05638 Mdot
.70666 .35849 Mdot
.36703 .13313 Mdot
.93085 .17764 Mdot
.54302 .06472 Mdot
.67119 .45184 Mdot
.78395 .35521 Mdot
.3994 .04132 Mdot
.45109 .12266 Mdot
.54452 .52566 Mdot
.33307 .21073 Mdot
.41903 .02282 Mdot
.48491 .12786 Mdot
.34494 .14839 Mdot
.63746 .59027 Mdot
.68259 .39707 Mdot
.55797 .52916 Mdot
.38412 .01457 Mdot
.47719 .11925 Mdot
.59475 .56622 Mdot
.62626 .50131 Mdot
.55454 .52221 Mdot
.40908 .03068 Mdot
.57979 .55296 Mdot
.85593 .14895 Mdot
.52326 .12781 Mdot
.93366 .39355 Mdot
.67022 .43643 Mdot
.5525 .50136 Mdot
.337 .17638 Mdot
.51318 .11153 Mdot
.73736 .10049 Mdot
.50009 .0002 Mdot
.32094 .24654 Mdot
.49417 .10622 Mdot
.92758 .39167 Mdot
.18288 .2591 Mdot
.41436 .03419 Mdot
.67732 .42823 Mdot
.31422 .25217 Mdot
.51069 .05527 Mdot
.36043 .0186 Mdot
.25726 .26982 Mdot
.46146 .12191 Mdot
.46717 .04065 Mdot
.68647 .37792 Mdot
.55357 .50452 Mdot
.55209 .51429 Mdot
.41632 .03124 Mdot
.0275 .21354 Mdot
.45318 .06641 Mdot
.36575 .02287 Mdot
.49092 .10982 Mdot
.34875 .00968 Mdot
.42589 .58698 Mdot
.07642 .22974 Mdot
.44336 .12386 Mdot
.57892 .55234 Mdot
.78424 .35507 Mdot
.55526 .52718 Mdot
.47926 .1249 Mdot
.41925 .04454 Mdot
.49736 .0488 Mdot
.40885 .03034 Mdot
.64052 .49152 Mdot
.41148 .02932 Mdot
.58368 .08396 Mdot
.81332 .35942 Mdot
.68702 .37647 Mdot
.30649 .25905 Mdot
.74524 .14471 Mdot
.67812 .39558 Mdot
.72349 .09446 Mdot
.49268 .12278 Mdot
.38905 .12786 Mdot
.45014 .03583 Mdot
.65471 .48225 Mdot
.66754 .4758 Mdot
.59938 .0425 Mdot
.44279 .06085 Mdot
.60723 .57302 Mdot
.60102 .49897 Mdot
.58026 .55512 Mdot
.62744 .09788 Mdot
.43618 .05889 Mdot
.7967 .35685 Mdot
.4642 .60377 Mdot
.37873 .12886 Mdot
.57172 .54272 Mdot
.32948 .21705 Mdot
.34432 .14505 Mdot
.41273 .02947 Mdot
.50739 .10474 Mdot
.39785 .12568 Mdot
.42557 .12495 Mdot
.52278 .12825 Mdot
.48003 .10268 Mdot
.64089 .49435 Mdot
.29387 .26092 Mdot
.42905 .04633 Mdot
.43859 .12348 Mdot
.63369 .49474 Mdot
.42995 .02772 Mdot
.33156 .2049 Mdot
.61013 .04718 Mdot
.69374 .12455 Mdot
.50353 .05301 Mdot
.48164 .12934 Mdot
.60506 .50528 Mdot
.67934 .39514 Mdot
.45329 .12314 Mdot
.48463 .12245 Mdot
.61364 .50676 Mdot
.69711 .36319 Mdot
.53715 .50996 Mdot
.42398 .02337 Mdot
.41849 .02977 Mdot
.57776 .54713 Mdot
.69146 .12466 Mdot
.43389 .12239 Mdot
.41511 .05217 Mdot
.59509 .50047 Mdot
.94282 .39671 Mdot
.48169 .09051 Mdot
.86254 .37272 Mdot
.72764 .35534 Mdot
.54675 .51678 Mdot
.65281 .48154 Mdot
.36051 .55985 Mdot
.13736 .4683 Mdot
.30022 .26222 Mdot
.49308 .11489 Mdot
.4098 .12279 Mdot
.05056 .43406 Mdot
.60438 .04487 Mdot
.40981 .0467 Mdot
.66047 .48227 Mdot
.51123 .12608 Mdot
.59218 .56094 Mdot
.69967 .36475 Mdot
.40933 .04599 Mdot
.55377 .51729 Mdot
.32772 .2243 Mdot
.80914 .35935 Mdot
.38895 .0384 Mdot
.37374 .01933 Mdot
.40298 .12256 Mdot
.66813 .47217 Mdot
.33524 .18047 Mdot
.30633 .25381 Mdot
.53992 .01726 Mdot
.84916 .36884 Mdot
.46311 .07444 Mdot
.63521 .05815 Mdot
.55796 .50462 Mdot
.43672 .02939 Mdot
.65951 .47236 Mdot
.61926 .57813 Mdot
.41345 .0381 Mdot
.38501 .01523 Mdot
.62 .49724 Mdot
.77263 .35325 Mdot
.52105 .05989 Mdot
.56823 .5071 Mdot
.47979 .61034 Mdot
.41275 .02338 Mdot
.55048 .51335 Mdot
.75174 .14731 Mdot
.43313 .06295 Mdot
.57537 .07801 Mdot
.5493 .51909 Mdot
.58398 .55364 Mdot
.42284 .0558 Mdot
.41682 .11941 Mdot
.448 .03294 Mdot
.44744 .12378 Mdot
.46822 .08214 Mdot
.37416 .12535 Mdot
.33047 .18352 Mdot
.41995 .11893 Mdot
.4219 .02819 Mdot
.48211 .09698 Mdot
.47109 .09524 Mdot
.39242 .12041 Mdot
.55259 .5216 Mdot
.58816 .51034 Mdot
.58066 .55631 Mdot
.19014 .26006 Mdot
.17075 .2562 Mdot
.4147 .05498 Mdot
.39035 .03384 Mdot
.53355 .52424 Mdot
.58837 .08198 Mdot
.34608 .15232 Mdot
.67428 .4398 Mdot
.40006 .0307 Mdot
.864 .37323 Mdot
.41044 .03179 Mdot
.64569 .49567 Mdot
.69966 .36523 Mdot
.50109 .12094 Mdot
.91549 .17166 Mdot
.46133 .08657 Mdot
.65408 .48141 Mdot
.40098 .03945 Mdot
.40541 .02879 Mdot
.49788 .10011 Mdot
.65332 .60707 Mdot
.36563 .13699 Mdot
.6318 .4947 Mdot
.33549 .1964 Mdot
.62176 .09561 Mdot
.45901 .07823 Mdot
.36166 .13407 Mdot
.38878 .01651 Mdot
.60944 .49802 Mdot
.67945 .41957 Mdot
.33024 .20091 Mdot
.13901 .24761 Mdot
.31919 .24025 Mdot
.55281 .53464 Mdot
.54291 .50086 Mdot
.46937 .0901 Mdot
.66311 .46681 Mdot
.56787 .51089 Mdot
.41744 .03355 Mdot
.53577 .51094 Mdot
.36686 .13538 Mdot
.59086 .55784 Mdot
.40311 .01893 Mdot
.28803 .26366 Mdot
.86528 .37201 Mdot
.68627 .37358 Mdot
.53851 .52639 Mdot
.46816 .08029 Mdot
.54294 .06805 Mdot
.3261 .21317 Mdot
.58113 .55722 Mdot
.36204 .13749 Mdot
.4808 .12009 Mdot
.92127 .17385 Mdot
.41681 .03317 Mdot
.3659 .02224 Mdot
.85742 .1493 Mdot
.07938 .22982 Mdot
.65851 .48075 Mdot
.37449 .02206 Mdot
.74862 .10518 Mdot
.66094 .47059 Mdot
.6793 .40515 Mdot
.38952 .02409 Mdot
.3462 .14828 Mdot
.81899 .36073 Mdot
.39943 .03306 Mdot
.38964 .5714 Mdot
.4378 .1255 Mdot
.3639 .02229 Mdot
.66328 .46765 Mdot
.58097 .50933 Mdot
.48977 .04596 Mdot
.41197 .04598 Mdot
.43607 .03586 Mdot
.37105 .02789 Mdot
.6675 .46291 Mdot
.52026 .12656 Mdot
.41985 .12547 Mdot
.5922 .50838 Mdot
.34872 .00924 Mdot
.64725 .4928 Mdot
.42266 .04939 Mdot
.63216 .59205 Mdot
.48448 .10556 Mdot
.72662 .35457 Mdot
.63649 .58946 Mdot
.32211 .54341 Mdot
.41401 .03041 Mdot
.40246 .02459 Mdot
.27958 .26837 Mdot
.42623 .03279 Mdot
.30559 .25967 Mdot
.37899 .12379 Mdot
.3769 .125 Mdot
.32867 .19732 Mdot
.65063 .10916 Mdot
.02495 .42515 Mdot
.49632 .05054 Mdot
.36121 .01508 Mdot
.67995 .41802 Mdot
.56033 .50823 Mdot
.47955 .10139 Mdot
.97199 .19341 Mdot
.43268 .58975 Mdot
.45985 .07711 Mdot
.46649 .09072 Mdot
.55266 .51008 Mdot
.37044 .02497 Mdot
.48984 .05073 Mdot
.58285 .55307 Mdot
.49287 .04999 Mdot
.39007 .01547 Mdot
.47629 .09496 Mdot
.53265 .50886 Mdot
.22635 .26676 Mdot
.46205 .11707 Mdot
.42719 .03604 Mdot
.66363 .11292 Mdot
.48028 .12234 Mdot
.56755 .51243 Mdot
.38622 .02579 Mdot
.44923 .0308 Mdot
.55379 .06905 Mdot
.62676 .58673 Mdot
.65265 .48335 Mdot
.54781 .06906 Mdot
.47276 .04391 Mdot
.67856 .41766 Mdot
.67181 .46324 Mdot
.07394 .44386 Mdot
.33116 .20177 Mdot
.52572 .50923 Mdot
.35046 .13818 Mdot
.68151 .39615 Mdot
.50018 .11873 Mdot
.63913 .4957 Mdot
.72848 .35237 Mdot
.22903 .50526 Mdot
.34758 .14338 Mdot
.60348 .57223 Mdot
.27726 .26638 Mdot
.39323 .04169 Mdot
.56638 .5138 Mdot
.42466 .0388 Mdot
.30408 .25983 Mdot
.24596 .26756 Mdot
.48351 .09903 Mdot
.81458 .13203 Mdot
.67479 .41601 Mdot
.64118 .49685 Mdot
.46759 .11809 Mdot
.65318 .10742 Mdot
.80697 .3597 Mdot
.62537 .50142 Mdot
.23085 .50612 Mdot
.33583 .18273 Mdot
.40579 .04853 Mdot
.41871 .02334 Mdot
.67401 .45298 Mdot
.50954 .1088 Mdot
.39223 .02523 Mdot
.43514 .5906 Mdot
.5442 .51061 Mdot
.18684 .25946 Mdot
.46859 .04092 Mdot
.86287 .15132 Mdot
.45852 .07401 Mdot
.6334 .1009 Mdot
.3958 .02691 Mdot
.59691 .56192 Mdot
.44077 .0621 Mdot
.3039 .25824 Mdot
.39413 .04001 Mdot
.43838 .02812 Mdot
.40901 .0342 Mdot
.95102 .18495 Mdot
.41182 .05468 Mdot
.59069 .50631 Mdot
.58671 .50287 Mdot
.67833 .41664 Mdot
.32617 .23175 Mdot
.55709 .50613 Mdot
.43415 .03722 Mdot
.41897 .03778 Mdot
.48371 .04649 Mdot
.44257 .0687 Mdot
.58699 .56158 Mdot
.64337 .48847 Mdot
.6922 .082 Mdot
.64783 .49078 Mdot
.55198 .51662 Mdot
.68801 .12161 Mdot
.44597 .06183 Mdot
.38733 .02584 Mdot
.68556 .12236 Mdot
.58883 .50603 Mdot
.60459 .56916 Mdot
.69784 .3635 Mdot
.36596 .01442 Mdot
.67404 .45561 Mdot
.48722 .11945 Mdot
.37493 .01136 Mdot
.49827 .10502 Mdot
.4223 .02276 Mdot
.555 .5248 Mdot
.68588 .38884 Mdot
.59959 .5061 Mdot
.60469 .56685 Mdot
.55243 .5296 Mdot
.41551 .12011 Mdot
.53746 .52256 Mdot
.33032 .19825 Mdot
.47222 .12824 Mdot
.31043 .24921 Mdot
.40728 .04638 Mdot
.51115 .11766 Mdot
.40727 .0277 Mdot
.37819 .12991 Mdot
.4177 .11805 Mdot
.18868 .25998 Mdot
.50357 .11123 Mdot
.43485 .06871 Mdot
.32686 .21985 Mdot
.83747 .14143 Mdot
.56007 .5369 Mdot
.41255 .04006 Mdot
.53696 .50178 Mdot
.56323 .54462 Mdot
.12837 .24511 Mdot
.49525 .12043 Mdot
.45676 .07953 Mdot
.52567 .51656 Mdot
.6513 .49053 Mdot
.33495 .19694 Mdot
.46491 .12277 Mdot
.61285 .57606 Mdot
.1958 .26074 Mdot
.77015 .35353 Mdot
.57947 .50028 Mdot
.57902 .50348 Mdot
.4207 .02751 Mdot
.51731 .11394 Mdot
.54923 .53061 Mdot
.32969 .22415 Mdot
.4856 .04371 Mdot
.59343 .51086 Mdot
.68112 .38322 Mdot
.61272 .09276 Mdot
.4448 .07683 Mdot
.4765 .12271 Mdot
.13968 .24762 Mdot
.82286 .36144 Mdot
.49219 .10591 Mdot
.3913 .03853 Mdot
.33121 .17925 Mdot
.31344 .24849 Mdot
.50719 .11934 Mdot
.32594 .22417 Mdot
.6727 .44234 Mdot
.45018 .12325 Mdot
.86277 .15114 Mdot
.36128 .01511 Mdot
.38359 .02201 Mdot
.95866 .18763 Mdot
.54213 .53038 Mdot
.44306 .06163 Mdot
.5071 .10407 Mdot
.61094 .50293 Mdot
.40841 .02027 Mdot
.42156 .11957 Mdot
.42458 .03961 Mdot
.57428 .50823 Mdot
.74789 .35293 Mdot
.59033 .50486 Mdot
.90355 .38308 Mdot
.49762 .12178 Mdot
.5586 .50081 Mdot
.52131 .05699 Mdot
.45976 .11765 Mdot
.45182 .08123 Mdot
.39737 .02983 Mdot
.71426 .3599 Mdot
.58692 .50695 Mdot
.56674 .54457 Mdot
.44717 .0769 Mdot
.55586 .07107 Mdot
.67438 .40566 Mdot
.67349 .42552 Mdot
.59473 .56653 Mdot
.75131 .10626 Mdot
.36332 .1395 Mdot
.3943 .12559 Mdot
.42334 .12129 Mdot
.02401 .21226 Mdot
.4288 .12432 Mdot
.67728 .41139 Mdot
.47064 .08426 Mdot
.87695 .15714 Mdot
.90895 .38558 Mdot
.50278 .04948 Mdot
.66054 .47822 Mdot
.43365 .05513 Mdot
.39837 .02858 Mdot
.52899 .50983 Mdot
.55404 .50365 Mdot
.38412 .0243 Mdot
.46055 .07995 Mdot
.47722 .08481 Mdot
.60168 .50807 Mdot
.62884 .49338 Mdot
.47178 .09202 Mdot
.96071 .40234 Mdot
.50612 .12497 Mdot
.4866 .09402 Mdot
.48041 .10566 Mdot
.32931 .21406 Mdot
.5146 .11501 Mdot
.34161 .14946 Mdot
.38155 .0272 Mdot
.63646 .59005 Mdot
.39235 .03104 Mdot
.47093 .11888 Mdot
.59276 .56145 Mdot
.17247 .25696 Mdot
.34431 .15412 Mdot
.4294 .03429 Mdot
.46403 .08101 Mdot
.67591 .4109 Mdot
.65194 .4897 Mdot
.48182 .12007 Mdot
.67464 .42591 Mdot
.38425 .12214 Mdot
.46562 .12778 Mdot
.69471 .12468 Mdot
.31777 .24777 Mdot
.36517 .13121 Mdot
.36987 .02364 Mdot
.39086 .03134 Mdot
.67498 .43223 Mdot
.16631 .2545 Mdot
.64942 .49238 Mdot
.50739 .05509 Mdot
.3869 .02992 Mdot
.6922 .37492 Mdot
.60809 .04615 Mdot
.03038 .42751 Mdot
.55618 .52492 Mdot
.50157 .10892 Mdot
.55279 .51023 Mdot
.43668 .06954 Mdot
.62722 .10005 Mdot
.59723 .49964 Mdot
.4717 .09364 Mdot
.4876 .613 Mdot
.58518 .08225 Mdot
.67232 .44349 Mdot
.34588 .14787 Mdot
.55572 .5289 Mdot
.48207 .12621 Mdot
.36583 .13816 Mdot
.28072 .52584 Mdot
.51834 .11702 Mdot
.33027 .18951 Mdot
.34045 .55142 Mdot
.53059 .06492 Mdot
.39664 .02387 Mdot
.38826 .0356 Mdot
.32976 .19097 Mdot
.17997 .2592 Mdot
.45368 .12332 Mdot
.46725 .09007 Mdot
.64791 .48952 Mdot
.64388 .48558 Mdot
.50137 .10581 Mdot
.43056 .03468 Mdot
.32746 .23182 Mdot
.67035 .11535 Mdot
.32889 .20802 Mdot
.58426 .50777 Mdot
.36415 .01317 Mdot
.42337 .03234 Mdot
.18447 .25979 Mdot
.56553 .07341 Mdot
.52472 .50938 Mdot
.48551 .09503 Mdot
.40802 .12229 Mdot
.51835 .05776 Mdot
.67116 .45293 Mdot
.64632 .10579 Mdot
.48561 .11858 Mdot
.39295 .03982 Mdot
.47931 .11413 Mdot
.54169 .52241 Mdot
.22665 .5038 Mdot
.61919 .50305 Mdot
.54594 .50454 Mdot
.10197 .45365 Mdot
.47952 .08735 Mdot
.34236 .15297 Mdot
.23899 .50877 Mdot
.47711 .1239 Mdot
.45804 .11805 Mdot
.48143 .09767 Mdot
.35718 .01629 Mdot
.44513 .06075 Mdot
.51 .12472 Mdot
.32009 .23812 Mdot
.5313 .01368 Mdot
.5904 .56071 Mdot
.40584 .03857 Mdot
.51521 .12808 Mdot
.8424 .36646 Mdot
.38345 .01416 Mdot
.45354 .12063 Mdot
.52131 .5124 Mdot
.48465 .11916 Mdot
.31256 .2467 Mdot
.56975 .50747 Mdot
.58799 .5088 Mdot
.48491 .11536 Mdot
.5232 .05734 Mdot
.46811 .038 Mdot
.37954 .12977 Mdot
.36055 .13228 Mdot
.34247 .15371 Mdot
.69847 .12619 Mdot
.74093 .35266 Mdot
.03914 .43047 Mdot
.46339 .08415 Mdot
.52884 .51754 Mdot
.4692 .08429 Mdot
.47016 .12836 Mdot
.43033 .03844 Mdot
.32807 .21873 Mdot
.60183 .50114 Mdot
.38123 .02783 Mdot
.41865 .04066 Mdot
.38235 .01702 Mdot
.66094 .06845 Mdot
.50309 .10647 Mdot
.37418 .12574 Mdot
.33097 .20801 Mdot
.47188 .03992 Mdot
.56211 .53305 Mdot
.68759 .37864 Mdot
.25283 .26737 Mdot
.61293 .57317 Mdot
.43736 .05758 Mdot
.76601 .35332 Mdot
.4195 .05263 Mdot
.70146 .12817 Mdot
.67253 .45516 Mdot
.93397 .17928 Mdot
.47836 .11785 Mdot
.73263 .35285 Mdot
.46033 .07931 Mdot
.61661 .50377 Mdot
.57835 .5042 Mdot
.54226 .52081 Mdot
.36674 .13262 Mdot
.47898 .04768 Mdot
.48216 .11384 Mdot
.44904 .08016 Mdot
.39605 .12259 Mdot
.30897 .25173 Mdot
.38108 .03099 Mdot
.78802 .357 Mdot
.67054 .46005 Mdot
.5782 .55292 Mdot
.40198 .01587 Mdot
.64607 .10464 Mdot
.41718 .12482 Mdot
.85948 .37174 Mdot
.41748 .04459 Mdot
.33082 .21695 Mdot
.54455 .50923 Mdot
.41674 .02661 Mdot
.60384 .50068 Mdot
.46303 .07737 Mdot
.5477 .51375 Mdot
.47366 .12442 Mdot
.56557 .54344 Mdot
.51651 .11818 Mdot
.48618 .12319 Mdot
.33597 .19235 Mdot
.4965 .05004 Mdot
.36075 .00893 Mdot
.44836 .07493 Mdot
.56987 .50695 Mdot
.11586 .24098 Mdot
.40757 .12524 Mdot
.32301 .23544 Mdot
.37223 .02237 Mdot
.81833 .36075 Mdot
.81582 .36069 Mdot
.41428 .03138 Mdot
.45287 .03263 Mdot
.41105 .05379 Mdot
.62179 .57871 Mdot
.63183 .50063 Mdot
.51623 .05764 Mdot
.51321 .1258 Mdot
.6936 .36557 Mdot
.55647 .53684 Mdot
.49079 .12777 Mdot
.44501 .11777 Mdot
.58275 .50359 Mdot
.36916 .01103 Mdot
.02002 .42369 Mdot
.58326 .55655 Mdot
.67445 .43491 Mdot
.42861 .02376 Mdot
.17084 .25694 Mdot
.33126 .20695 Mdot
.56523 .0748 Mdot
.83623 .36503 Mdot
.41161 .12657 Mdot
.46752 .12166 Mdot
.68115 .39611 Mdot
.43756 .11855 Mdot
.64725 .10535 Mdot
.4747 .08222 Mdot
.46582 .08766 Mdot
.50494 .12259 Mdot
.17393 .25706 Mdot
.75261 .35443 Mdot
.42056 .124 Mdot
.39548 .02506 Mdot
.59872 .50676 Mdot
.54062 .50507 Mdot
.40726 .05157 Mdot
.05277 .22124 Mdot
.37437 .02247 Mdot
.371 .02206 Mdot
.58015 .55679 Mdot
.09159 .45029 Mdot
.46452 .0814 Mdot
.64203 .49522 Mdot
.78359 .35629 Mdot
.64728 .48442 Mdot
.56334 .54395 Mdot
.67658 .44146 Mdot
.53872 .50214 Mdot
.49615 .10013 Mdot
.29059 .26568 Mdot
.44853 .07057 Mdot
.87482 .37584 Mdot
.38934 .12883 Mdot
.32351 .22885 Mdot
.65793 .47473 Mdot
.79767 .35712 Mdot
.35175 .00669 Mdot
.58025 .50264 Mdot
.38799 .0365 Mdot
.36327 .00727 Mdot
.67211 .44227 Mdot
.46974 .12196 Mdot
.52107 .12271 Mdot
.18001 .25865 Mdot
.68134 .40512 Mdot
.38158 .02549 Mdot
.43758 .03261 Mdot
.52654 .12195 Mdot
.42124 .02766 Mdot
.49978 .00062 Mdot
.4577 .03426 Mdot
.06782 .44113 Mdot
.46205 .11825 Mdot
.4773 .11991 Mdot
.53102 .50973 Mdot
.98534 .41099 Mdot
.59623 .56252 Mdot
.6049 .04468 Mdot
.67045 .45722 Mdot
.37273 .01552 Mdot
.33364 .20584 Mdot
.50657 .12077 Mdot
.61679 .04986 Mdot
.28829 .26708 Mdot
.49869 .11609 Mdot
.48694 .0939 Mdot
.12406 .2435 Mdot
.66902 .44456 Mdot
.45002 .12565 Mdot
.57709 .07955 Mdot
.65274 .48132 Mdot
.57608 .54594 Mdot
.37579 .01414 Mdot
.3626 .13967 Mdot
.52206 .12442 Mdot
.67515 .45441 Mdot
.39202 .02054 Mdot
.80337 .12709 Mdot
.88354 .37755 Mdot
.56599 .54539 Mdot
.40415 .02164 Mdot
.5769 .50412 Mdot
.39108 .12292 Mdot
.70479 .36441 Mdot
.42391 .041 Mdot
.46156 .04173 Mdot
.54523 .53213 Mdot
.42104 .03848 Mdot
.83993 .36639 Mdot
.77115 .35443 Mdot
.36776 .01396 Mdot
.58907 .50528 Mdot
.56521 .51153 Mdot
.36058 .01033 Mdot
.24378 .26807 Mdot
.43783 .06741 Mdot
.42288 .05408 Mdot
.44772 .03009 Mdot
.46535 .12255 Mdot
.74817 .35288 Mdot
.16682 .25608 Mdot
.59401 .50896 Mdot
.20865 .26424 Mdot
.37371 .01696 Mdot
.31759 .24933 Mdot
.36054 .01363 Mdot
.38845 .01619 Mdot
.68322 .39389 Mdot
.69644 .37127 Mdot
.58021 .50472 Mdot
.40057 .12329 Mdot
.59042 .08568 Mdot
.69046 .37547 Mdot
.43834 .07151 Mdot
.44614 .07705 Mdot
.57443 .0782 Mdot
.96619 .19065 Mdot
.54919 .06711 Mdot
.51996 .12109 Mdot
.45764 .03902 Mdot
.36296 .1394 Mdot
.4963 .11957 Mdot
.38792 .024 Mdot
.40955 .04559 Mdot
.48547 .09112 Mdot
.40027 .01712 Mdot
.41877 .03064 Mdot
.55639 .5285 Mdot
.98305 .41006 Mdot
.63081 .50348 Mdot
.40733 .03387 Mdot
.53805 .50452 Mdot
.28503 .26695 Mdot
.51796 .12609 Mdot
.32613 .22155 Mdot
.44871 .07401 Mdot
.4033 .01977 Mdot
.53304 .06561 Mdot
.63808 .49673 Mdot
.41508 .05113 Mdot
.43996 .07196 Mdot
.4339 .06346 Mdot
.55186 .53041 Mdot
.33185 .18198 Mdot
.44127 .06474 Mdot
.58584 .55434 Mdot
.56511 .50432 Mdot
.55283 .50107 Mdot
.71162 .09 Mdot
.09386 .45048 Mdot
.53485 .52125 Mdot
.4682 .08188 Mdot
.64242 .48682 Mdot
.37182 .01814 Mdot
.78181 .35556 Mdot
.65824 .47191 Mdot
.20143 .26176 Mdot
.44946 .59726 Mdot
.20989 .26482 Mdot
.55116 .51576 Mdot
.65057 .49233 Mdot
.49796 .12476 Mdot
.52882 .06074 Mdot
.64543 .10613 Mdot
.50864 .11531 Mdot
.55261 .52381 Mdot
.33988 .1731 Mdot
.47138 .08629 Mdot
.50581 .05546 Mdot
.33583 .18839 Mdot
.67541 .07421 Mdot
.67994 .38908 Mdot
.0048 .41744 Mdot
.40889 .04019 Mdot
.33183 .20306 Mdot
.43957 .0335 Mdot
.46222 .08954 Mdot
.45609 .08284 Mdot
.07167 .44195 Mdot
.57771 .50711 Mdot
.3823 .12365 Mdot
.41355 .04192 Mdot
.82877 .36465 Mdot
.89646 .16443 Mdot
.40388 .02868 Mdot
.45601 .07086 Mdot
.66383 .46099 Mdot
.45146 .08006 Mdot
.03063 .21357 Mdot
.61259 .50807 Mdot
.67075 .46926 Mdot
.38384 .0168 Mdot
.38085 .13029 Mdot
.66999 .46176 Mdot
.56493 .02834 Mdot
.46579 .08865 Mdot
.90985 .16926 Mdot
.53682 .51038 Mdot
.55031 .53508 Mdot
.67469 .41332 Mdot
.33255 .17292 Mdot
.67379 .42165 Mdot
.2176 .26441 Mdot
.35846 .14174 Mdot
.55246 .53417 Mdot
.58534 .50187 Mdot
.38828 .03053 Mdot
.02394 .42402 Mdot
.69526 .36603 Mdot
.69391 .08243 Mdot
.5304 .50376 Mdot
.59385 .55895 Mdot
.32927 .18881 Mdot
.47401 .11905 Mdot
.66342 .48082 Mdot
.66836 .45479 Mdot
.56792 .07455 Mdot
.63046 .58838 Mdot
.53292 .51145 Mdot
.3243 .22313 Mdot
.47383 .09759 Mdot
.67047 .45174 Mdot
.49581 .09618 Mdot
.52323 .50367 Mdot
.71946 .13495 Mdot
.52108 .12401 Mdot
.4121 .05511 Mdot
.69605 .36832 Mdot
.37853 .01719 Mdot
.65502 .48203 Mdot
.48448 .11308 Mdot
.48074 .12163 Mdot
.35867 .01825 Mdot
.35633 .14402 Mdot
.67773 .39167 Mdot
.70081 .36756 Mdot
.91832 .38769 Mdot
.33397 .16639 Mdot
.27563 .26543 Mdot
.44216 .59401 Mdot
.46499 .07967 Mdot
.55777 .54138 Mdot
.46411 .03808 Mdot
.42102 .12414 Mdot
.49864 .04894 Mdot
.64304 .49619 Mdot
.47196 .12403 Mdot
.66798 .1149 Mdot
.56504 .5061 Mdot
.16787 .25642 Mdot
.41948 .12148 Mdot
.39981 .01666 Mdot
.52172 .05868 Mdot
.40718 .04728 Mdot
.35771 .00555 Mdot
.29742 .53322 Mdot
.55501 .52922 Mdot
.84459 .36784 Mdot
.91258 .38577 Mdot
.02098 .21127 Mdot
.00245 .41695 Mdot
.75449 .14798 Mdot
.48858 .11454 Mdot
.54996 .52046 Mdot
.39688 .03584 Mdot
.60005 .50189 Mdot
.4096 .04802 Mdot
.49986 .05155 Mdot
.42201 .03169 Mdot
.43237 .04987 Mdot
.04844 .22071 Mdot
.67315 .42021 Mdot
.63031 .58578 Mdot
.67976 .38878 Mdot
.5945 .49986 Mdot
.10129 .45397 Mdot
.35382 .1423 Mdot
.55251 .53376 Mdot
.48427 .11963 Mdot
.66658 .46647 Mdot
.39809 .01892 Mdot
.44859 .12311 Mdot
.51048 .12351 Mdot
.63342 .49516 Mdot
.41264 .12204 Mdot
.38756 .03541 Mdot
.67498 .41906 Mdot
.47797 .12532 Mdot
.42744 .03173 Mdot
.19181 .26063 Mdot
.56361 .50764 Mdot
.19051 .48959 Mdot
.5239 .5067 Mdot
.49323 .11631 Mdot
.48668 .12269 Mdot
.47807 .12804 Mdot
.66115 .48501 Mdot
.50895 .11312 Mdot
.40157 .03419 Mdot
.6281 .58779 Mdot
.66487 .11253 Mdot
.51314 .11706 Mdot
.38028 .02658 Mdot
.31404 .25355 Mdot
.44999 .12004 Mdot
.49386 .1012 Mdot
.57383 .51145 Mdot
.67635 .43206 Mdot
.64682 .1055 Mdot
.28508 .26348 Mdot
.54042 .50432 Mdot
.60109 .04281 Mdot
.62823 .49673 Mdot
.37215 .01532 Mdot
.66873 .44462 Mdot
.3978 .1231 Mdot
.41943 .04316 Mdot
.56938 .07648 Mdot
.38548 .12173 Mdot
.48148 .11355 Mdot
.48697 .11789 Mdot
.05485 .43672 Mdot
.53985 .01691 Mdot
.4256 .03928 Mdot
.93777 .39483 Mdot
.40324 .03017 Mdot
.46342 .03779 Mdot
.57349 .50339 Mdot
.75892 .35393 Mdot
.71298 .35817 Mdot
.50665 .12693 Mdot
.35662 .13816 Mdot
.39299 .02196 Mdot
.00474 .41765 Mdot
.3556 .55748 Mdot
.5046 .11619 Mdot
.63628 .49975 Mdot
.51866 .05895 Mdot
.53194 .51113 Mdot
.49695 .10536 Mdot
.43141 .02699 Mdot
.67323 .41398 Mdot
.32201 .24192 Mdot
.40679 .02436 Mdot
.32417 .2274 Mdot
.09844 .23589 Mdot
.67911 .40961 Mdot
.42699 .02817 Mdot
.67253 .46097 Mdot
.56017 .51625 Mdot
.51731 .05609 Mdot
.69664 .36517 Mdot
.63784 .59285 Mdot
.3657 .00844 Mdot
.4836 .12191 Mdot
.60154 .50485 Mdot
.57139 .54956 Mdot
.49304 .12305 Mdot
.38954 .01573 Mdot
.4217 .03331 Mdot
.39005 .02812 Mdot
.48117 .11472 Mdot
.53743 .06579 Mdot
.3363 .18357 Mdot
.44412 .03419 Mdot
.32354 .23667 Mdot
.59981 .50235 Mdot
.59141 .49989 Mdot
.55894 .53917 Mdot
.48004 .09206 Mdot
.69411 .37351 Mdot
.53158 .0621 Mdot
.85929 .37086 Mdot
.67195 .4541 Mdot
.33439 .18164 Mdot
.43733 .03478 Mdot
.46943 .08069 Mdot
.70271 .36101 Mdot
.19077 .26066 Mdot
.59753 .5654 Mdot
.6778 .39613 Mdot
.1966 .26218 Mdot
.56061 .50524 Mdot
.46096 .12699 Mdot
.55658 .07406 Mdot
.65645 .47747 Mdot
.06666 .44054 Mdot
.32928 .21006 Mdot
.43501 .05961 Mdot
.53689 .52266 Mdot
.6378 .49111 Mdot
.62112 .58384 Mdot
.72081 .1358 Mdot
.49561 .10856 Mdot
.40208 .03448 Mdot
.66983 .45604 Mdot
.51278 .05449 Mdot
.36785 .01073 Mdot
.35367 .13677 Mdot
.40455 .12573 Mdot
.41225 .02248 Mdot
.33725 .54989 Mdot
.44233 .12055 Mdot
.69705 .36784 Mdot
.49547 .11516 Mdot
.32941 .19791 Mdot
.50711 .05331 Mdot
.91459 .1717 Mdot
.35395 .01214 Mdot
.70667 .08755 Mdot
.33001 .22342 Mdot
.50331 .05175 Mdot
.21962 .26547 Mdot
.32955 .18932 Mdot
.4438 .07483 Mdot
.2491 .51312 Mdot
.6703 .46462 Mdot
.43442 .06583 Mdot
.52965 .50463 Mdot
.33237 .19656 Mdot
.5384 .50186 Mdot
.60452 .57144 Mdot
.37938 .0304 Mdot
.56597 .50581 Mdot
.35347 .14488 Mdot
.35136 .14163 Mdot
.50783 .11253 Mdot
.83697 .36634 Mdot
.47913 .12793 Mdot
.2788 .26744 Mdot
.18132 .48581 Mdot
.36232 .01991 Mdot
.55366 .5172 Mdot
.6077 .09263 Mdot
.58586 .50576 Mdot
.45289 .07385 Mdot
.4256 .05051 Mdot
.52843 .5143 Mdot
.59658 .56606 Mdot
.3796 .01091 Mdot
.36993 .12844 Mdot
.49862 .12563 Mdot
.00318 .41712 Mdot
.50655 .1149 Mdot
.86532 .15254 Mdot
.40435 .03756 Mdot
.53683 .50711 Mdot
.62705 .58693 Mdot
.3292 .214 Mdot
.59836 .08845 Mdot
.42368 .58608 Mdot
.48056 .04387 Mdot
.46409 .08812 Mdot
.65123 .47925 Mdot
.34457 .15479 Mdot
.47224 .08868 Mdot
.68307 .3948 Mdot
.63209 .10034 Mdot
.52435 .0577 Mdot
.52421 .06027 Mdot
.07693 .22907 Mdot
.57431 .51293 Mdot
.64323 .49419 Mdot
.56621 .54411 Mdot
.40537 .57847 Mdot
.48413 .10243 Mdot
.58271 .08246 Mdot
.56903 .51208 Mdot
.46501 .11741 Mdot
.66989 .4701 Mdot
.44732 .07146 Mdot
.53066 .50653 Mdot
.62839 .49688 Mdot
.55933 .5044 Mdot
.5865 .50801 Mdot
.58935 .56208 Mdot
.48903 .11175 Mdot
.31899 .24749 Mdot
.3909 .03566 Mdot
.65055 .48054 Mdot
.54121 .52489 Mdot
.55782 .50179 Mdot
.32769 .22936 Mdot
.64675 .4957 Mdot
.57677 .50503 Mdot
.43255 .02958 Mdot
.59744 .50697 Mdot
.40469 .03942 Mdot
.5477 .02074 Mdot
.33183 .20734 Mdot
.2893 .26321 Mdot
.57601 .50848 Mdot
.38059 .13173 Mdot
.39532 .02366 Mdot
.63621 .59056 Mdot
.40149 .03318 Mdot
.46927 .042 Mdot
.39447 .04414 Mdot
.48271 .11009 Mdot
.55279 .50769 Mdot
.15009 .25125 Mdot
.41974 .04663 Mdot
.36926 .01809 Mdot
.34881 .13999 Mdot
.30322 .25679 Mdot
.39678 .03357 Mdot
.77854 .1168 Mdot
.59387 .5099 Mdot
.47296 .12128 Mdot
.6763 .44225 Mdot
.37573 .02396 Mdot
.45353 .03212 Mdot
.40099 .12579 Mdot
.09101 .45012 Mdot
.4434 .12278 Mdot
.49284 .10049 Mdot
.5922 .56039 Mdot
.41771 .05778 Mdot
.32591 .21991 Mdot
.41481 .05402 Mdot
.61435 .0945 Mdot
.49113 .10633 Mdot
.55439 .5249 Mdot
.41966 .03649 Mdot
.52112 .12025 Mdot
.35896 .55859 Mdot
.41251 .01891 Mdot
.3982 .03223 Mdot
.36141 .01914 Mdot
.42776 .02571 Mdot
.34033 .16871 Mdot
.54593 .52856 Mdot
.52151 .12929 Mdot
.36729 .13686 Mdot
.25518 .2679 Mdot
.41078 .11886 Mdot
.41031 .02047 Mdot
.22464 .50351 Mdot
.35875 .01539 Mdot
.96181 .18911 Mdot
.65323 .60851 Mdot
.5003 .12837 Mdot
.35696 .13458 Mdot
.21069 .26446 Mdot
.54947 .53213 Mdot
.55797 .53078 Mdot
.45581 .06907 Mdot
.23568 .50766 Mdot
.48321 .09532 Mdot
.58874 .50706 Mdot
.45566 .07762 Mdot
.48752 .12164 Mdot
.46608 .08522 Mdot
.58736 .50607 Mdot
.54264 .52751 Mdot
.44904 .11793 Mdot
.61656 .50713 Mdot
.48497 .0975 Mdot
.6809 .38282 Mdot
.33423 .20275 Mdot
.45824 .07777 Mdot
.64369 .48896 Mdot
.35456 .00868 Mdot
.46923 .07855 Mdot
.7971 .35787 Mdot
.30158 .25855 Mdot
.55899 .50772 Mdot
.44409 .07151 Mdot
.55496 .50913 Mdot
.64352 .49645 Mdot
.46649 .08358 Mdot
.42416 .03523 Mdot
.76636 .15272 Mdot
.34681 .15049 Mdot
.59034 .51037 Mdot
.44923 .03491 Mdot
.46827 .0906 Mdot
.09052 .44949 Mdot
.47531 .08678 Mdot
.4531 .06609 Mdot
.31977 .23673 Mdot
.27095 .26648 Mdot
.42158 .02752 Mdot
.43203 .06483 Mdot
.43041 .02968 Mdot
.53429 .01514 Mdot
.45739 .03861 Mdot
.48471 .1293 Mdot
.54879 .5146 Mdot
.56312 .50991 Mdot
.36314 .13887 Mdot
.34338 .15679 Mdot
.46808 .04169 Mdot
.42971 .02655 Mdot
.35895 .00555 Mdot
.53689 .52077 Mdot
.57027 .50605 Mdot
.3993 .02791 Mdot
.49353 .61596 Mdot
.84777 .14542 Mdot
.55609 .50191 Mdot
.54802 .50105 Mdot
.4068 .04879 Mdot
.40595 .04452 Mdot
.45563 .03284 Mdot
.56943 .07769 Mdot
.40696 .01702 Mdot
.41128 .04273 Mdot
.51412 .05766 Mdot
.36235 .02181 Mdot
.30691 .25332 Mdot
.43266 .1208 Mdot
.60018 .49914 Mdot
.74467 .35222 Mdot
.41919 .12507 Mdot
.52034 .11728 Mdot
.28125 .26599 Mdot
.38394 .12203 Mdot
.40425 .57757 Mdot
.39309 .01669 Mdot
.39901 .12151 Mdot
.42238 .02253 Mdot
.60716 .57324 Mdot
.67099 .43136 Mdot
.48157 .10628 Mdot
.55852 .51571 Mdot
.67172 .43477 Mdot
.44608 .12556 Mdot
.49865 .05207 Mdot
.44247 .0356 Mdot
.30666 .25804 Mdot
.38396 .01952 Mdot
.41847 .05127 Mdot
.39179 .04182 Mdot
.49442 .10707 Mdot
.52032 .11528 Mdot
.3801 .01523 Mdot
.29532 .26075 Mdot
.33539 .16426 Mdot
.56819 .54304 Mdot
.4699 .08907 Mdot
.68854 .37693 Mdot
.84274 .14332 Mdot
.69733 .36365 Mdot
.33128 .18028 Mdot
.62367 .0524 Mdot
.50086 .05135 Mdot
.35819 .01381 Mdot
.41819 .02043 Mdot
.39597 .12743 Mdot
.91338 .38632 Mdot
.82745 .13711 Mdot
.43745 .05693 Mdot
.6857 .3901 Mdot
.67264 .43235 Mdot
.41984 .03397 Mdot
.48405 .11802 Mdot
.06748 .44123 Mdot
.39921 .03683 Mdot
.33325 .54827 Mdot
.45485 .08166 Mdot
.50574 .05403 Mdot
.36998 .13536 Mdot
.25032 .26771 Mdot
.47985 .11536 Mdot
.86434 .37204 Mdot
.36307 .13735 Mdot
.49251 .12207 Mdot
.42053 .05093 Mdot
.19702 .26231 Mdot
.35895 .01554 Mdot
.67078 .46855 Mdot
.70272 .36657 Mdot
.54029 .50415 Mdot
.4724 .1161 Mdot
.42298 .03734 Mdot
.59702 .51039 Mdot
.70368 .08648 Mdot
.32788 .2082 Mdot
.48992 .11701 Mdot
.3986 .02544 Mdot
.22463 .50321 Mdot
.39736 .02092 Mdot
.70059 .36534 Mdot
.4386 .06383 Mdot
.56649 .54068 Mdot
.49892 .04872 Mdot
.06235 .43895 Mdot
.52142 .05713 Mdot
.68915 .12173 Mdot
.9241 .17502 Mdot
.06097 .43858 Mdot
.50115 .10282 Mdot
.35091 .01041 Mdot
.48415 .10022 Mdot
.45723 .07883 Mdot
.55637 .51982 Mdot
.42784 .03833 Mdot
.62688 .58418 Mdot
.47293 .60702 Mdot
.54815 .5168 Mdot
.07039 .22779 Mdot
.39842 .12093 Mdot
.62442 .58614 Mdot
.57882 .55063 Mdot
.6771 .44337 Mdot
.62917 .49282 Mdot
.6732 .07368 Mdot
.67825 .39615 Mdot
.49203 .1003 Mdot
.61483 .49738 Mdot
.61929 .4966 Mdot
.6749 .42796 Mdot
.41696 .02299 Mdot
.41568 .12111 Mdot
.38606 .0217 Mdot
.50402 .10172 Mdot
.42019 .05287 Mdot
.53654 .01641 Mdot
.37005 .1349 Mdot
.5011 .05119 Mdot
.46059 .08296 Mdot
.50805 .11621 Mdot
.8053 .12781 Mdot
.68442 .37711 Mdot
.4984 .12698 Mdot
.41387 .02971 Mdot
.48999 .1178 Mdot
.78624 .35637 Mdot
.57014 .0767 Mdot
.65157 .10691 Mdot
.51705 .12873 Mdot
.60038 .56844 Mdot
.41169 .04432 Mdot
.3241 .23351 Mdot
.6789 .39697 Mdot
.54666 .52453 Mdot
.4109 .04057 Mdot
.17077 .48151 Mdot
.55895 .535 Mdot
.64872 .49465 Mdot
.61914 .5026 Mdot
.60404 .57023 Mdot
.4985 .10161 Mdot
.34953 .00823 Mdot
.39923 .04372 Mdot
.38764 .1257 Mdot
.51824 .11972 Mdot
.2464 .5116 Mdot
.43861 .07118 Mdot
.57691 .50448 Mdot
.40326 .03045 Mdot
.54601 .50927 Mdot
.358 .13192 Mdot
.5807 .55265 Mdot
.59878 .56528 Mdot
.57713 .55087 Mdot
.52348 .51409 Mdot
.49884 .12768 Mdot
.4187 .12012 Mdot
.57032 .50962 Mdot
.45446 .08179 Mdot
.37369 .01908 Mdot
.57202 .54427 Mdot
.43617 .03499 Mdot
.34792 .55418 Mdot
.44312 .0669 Mdot
.67132 .43599 Mdot
.4734 .12115 Mdot
.54899 .53372 Mdot
.57225 .507 Mdot
.51214 .12988 Mdot
.61299 .50636 Mdot
.42726 .05137 Mdot
.62629 .49949 Mdot
.49314 .11982 Mdot
.29708 .26282 Mdot
.08874 .23412 Mdot
.43098 .11892 Mdot
.5865 .08208 Mdot
.57435 .512 Mdot
.40056 .02389 Mdot
.37238 .01786 Mdot
.87435 .15597 Mdot
.3846 .02395 Mdot
.44401 .06161 Mdot
.42307 .0448 Mdot
.50188 .0496 Mdot
.65624 .47654 Mdot
.4515 .07141 Mdot
.34045 .15063 Mdot
.42341 .0352 Mdot
.37472 .12643 Mdot
.37417 .01837 Mdot
.42314 .0369 Mdot
.48234 .12573 Mdot
.39196 .02062 Mdot
.52829 .0614 Mdot
.66306 .47491 Mdot
.36528 .01596 Mdot
.38465 .01857 Mdot
.67745 .41158 Mdot
.66384 .46834 Mdot
.41048 .12413 Mdot
.39682 .12098 Mdot
.43849 .12106 Mdot
.36559 .01319 Mdot
.56901 .51043 Mdot
.5848 .50857 Mdot
.718 .3592 Mdot
.38386 .03471 Mdot
.78873 .35675 Mdot
.5544 .52171 Mdot
.37311 .00811 Mdot
.45671 .07988 Mdot
.3432 .15492 Mdot
.55575 .53798 Mdot
.38034 .03073 Mdot
.84719 .3689 Mdot
.38814 .02709 Mdot
.54879 .5319 Mdot
.48834 .09951 Mdot
.53277 .50369 Mdot
.36316 .13686 Mdot
.63466 .49495 Mdot
.32907 .21582 Mdot
.16575 .47885 Mdot
.35524 .01601 Mdot
.32122 .2452 Mdot
.63502 .49992 Mdot
.74753 .35459 Mdot
.66211 .47141 Mdot
.56934 .51073 Mdot
.51117 .1098 Mdot
.40567 .02512 Mdot
.56059 .54197 Mdot
.38512 .12349 Mdot
.48961 .09819 Mdot
.52982 .51852 Mdot
.46067 .07797 Mdot
.41893 .05685 Mdot
.49825 .10142 Mdot
.47083 .12041 Mdot
.06748 .44079 Mdot
.50115 .12242 Mdot
.40001 .0357 Mdot
.45966 .04106 Mdot
.49987 .11477 Mdot
.67001 .4619 Mdot
.56367 .51401 Mdot
.52851 .05903 Mdot
.67159 .43415 Mdot
.56727 .50486 Mdot
.47426 .09069 Mdot
.05521 .22203 Mdot
.34461 .16139 Mdot
.44207 .03191 Mdot
.43196 .12183 Mdot
.61991 .50321 Mdot
.38318 .03577 Mdot
.36711 .02433 Mdot
.3727 .0215 Mdot
.42331 .0244 Mdot
.30401 .25486 Mdot
.48394 .10683 Mdot
.42577 .02872 Mdot
.89531 .16454 Mdot
.38175 .12848 Mdot
.02946 .4265 Mdot
.36838 .0188 Mdot
.81162 .3603 Mdot
.64576 .59754 Mdot
.44387 .59482 Mdot
.67639 .44378 Mdot
.74714 .35157 Mdot
.52147 .12341 Mdot
.3396 .15145 Mdot
.4814 .11875 Mdot
.67454 .40506 Mdot
.6668 .46587 Mdot
.55373 .52177 Mdot
.6749 .41588 Mdot
.47939 .11494 Mdot
.64286 .48754 Mdot
.03449 .21545 Mdot
.53884 .50524 Mdot
.60713 .56922 Mdot
.48856 .12165 Mdot
.99951 .41554 Mdot
.36213 .01148 Mdot
.63365 .58731 Mdot
.41406 .0443 Mdot
.52235 .05709 Mdot
.96308 .18965 Mdot
.67739 .41053 Mdot
.53505 .52103 Mdot
.44542 .07603 Mdot
.7258 .13748 Mdot
.43261 .03261 Mdot
.11701 .4601 Mdot
.16675 .25539 Mdot
.13221 .46586 Mdot
.2086 .49629 Mdot
.4896 .09543 Mdot
.33092 .20967 Mdot
.60167 .50285 Mdot
.52398 .50954 Mdot
.60643 .57047 Mdot
.66879 .44191 Mdot
.55969 .53939 Mdot
.33526 .16715 Mdot
.40126 .03026 Mdot
.67033 .46283 Mdot
.28676 .52846 Mdot
.44142 .0664 Mdot
.39848 .03656 Mdot
.04654 .22019 Mdot
.33321 .16941 Mdot
.64092 .49681 Mdot
.51499 .11407 Mdot
.41299 .03814 Mdot
.34525 .15259 Mdot
.62405 .50023 Mdot
.42286 .03888 Mdot
.56506 .51432 Mdot
.07136 .44261 Mdot
.66584 .46221 Mdot
.04295 .21804 Mdot
.43712 .02695 Mdot
.39567 .04196 Mdot
.44247 .03224 Mdot
.67433 .42104 Mdot
.68164 .40027 Mdot
.42677 .03048 Mdot
.63018 .58461 Mdot
.66137 .48089 Mdot
.46708 .03682 Mdot
.42741 .06425 Mdot
.48584 .11658 Mdot
.33045 .22067 Mdot
.41163 .03848 Mdot
.42943 .12392 Mdot
.41536 .05582 Mdot
.61643 .50002 Mdot
.49378 .11614 Mdot
.26361 .26895 Mdot
.42928 .03883 Mdot
.63761 .05902 Mdot
.4651 .08209 Mdot
.34501 .15618 Mdot
.42215 .02206 Mdot
.64046 .49862 Mdot
.72734 .35511 Mdot
.32945 .19797 Mdot
.05454 .22234 Mdot
.2961 .26393 Mdot
.49099 .11505 Mdot
.36126 .00949 Mdot
.62799 .58435 Mdot
.4958 .11461 Mdot
.59877 .04248 Mdot
.69964 .36542 Mdot
.70604 .35993 Mdot
.67636 .42501 Mdot
.58277 .50818 Mdot
.50022 .12028 Mdot
.46446 .11975 Mdot
.96775 .40485 Mdot
.73811 .14207 Mdot
.87441 .37513 Mdot
.58131 .08043 Mdot
.37976 .12418 Mdot
.34775 .14091 Mdot
.01265 .20801 Mdot
.62924 .0554 Mdot
.78801 .35716 Mdot
.52472 .50528 Mdot
.37978 .12762 Mdot
.52246 .12243 Mdot
.29971 .53449 Mdot
.50396 .10327 Mdot
.39756 .01821 Mdot
.36893 .12794 Mdot
.66525 .46334 Mdot
.354 .00632 Mdot
.49693 .04991 Mdot
.49634 .11266 Mdot
.41019 .03774 Mdot
.11393 .24079 Mdot
.55566 .50345 Mdot
.39571 .01692 Mdot
.39969 .01612 Mdot
.36519 .56149 Mdot
.63358 .5016 Mdot
.47517 .09287 Mdot
.4022 .03426 Mdot
.48186 .10022 Mdot
.58674 .08456 Mdot
.62907 .50288 Mdot
.54279 .52769 Mdot
.50385 .12488 Mdot
.69058 .12423 Mdot
.44603 .12002 Mdot
.51588 .05572 Mdot
.48661 .61307 Mdot
.50476 .05306 Mdot
.38476 .12554 Mdot
.56013 .54234 Mdot
.43401 .06697 Mdot
.60115 .50025 Mdot
.46054 .08302 Mdot
.69377 .37512 Mdot
.67262 .45193 Mdot
.40156 .5773 Mdot
.35012 .14382 Mdot
.66928 .45274 Mdot
.73648 .35419 Mdot
.09194 .23464 Mdot
.48682 .11954 Mdot
.67817 .40413 Mdot
.41083 .05356 Mdot
.41375 .01925 Mdot
.6466 .49376 Mdot
.38257 .02516 Mdot
.36515 .02023 Mdot
.4864 .12247 Mdot
.31056 .25477 Mdot
.67038 .43621 Mdot
.80498 .35992 Mdot
.45823 .0342 Mdot
.40875 .12465 Mdot
.43652 .03745 Mdot
.50673 .11213 Mdot
.41835 .04841 Mdot
.51236 .12875 Mdot
.37552 .02483 Mdot
.51321 .116 Mdot
.27832 .52556 Mdot
.5243 .51461 Mdot
.52293 .05962 Mdot
.64246 .59799 Mdot
.37179 .01422 Mdot
.33997 .15753 Mdot
.57416 .50391 Mdot
.52156 .05853 Mdot
.35383 .14365 Mdot
.34647 .15527 Mdot
.42851 .12191 Mdot
.44753 .07703 Mdot
.35414 .55699 Mdot
.33943 .15281 Mdot
.36802 .13568 Mdot
.31808 .23788 Mdot
.36517 .13418 Mdot
.55539 .51308 Mdot
.67219 .43422 Mdot
.68555 .39005 Mdot
.40057 .02304 Mdot
.47914 .11699 Mdot
.59542 .50027 Mdot
.68229 .12103 Mdot
.4445 .0302 Mdot
.05571 .22333 Mdot
.44773 .12358 Mdot
.42053 .04031 Mdot
.63919 .5969 Mdot
.44314 .12002 Mdot
.41 .03631 Mdot
.32036 .23767 Mdot
.37581 .0269 Mdot
.45364 .08027 Mdot
.33769 .15667 Mdot
.37896 .02905 Mdot
.48899 .0978 Mdot
.38276 .12482 Mdot
.58961 .56332 Mdot
.38275 .01682 Mdot
.6712 .46805 Mdot
.57992 .50174 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{292.25, 180.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004T0000]2000`400?l00000o`00003ooooooolU
ooooo`00oooooolUooooo`00oooooolUooooo`00oooooolUooooo`00W_ooool3o`0008?ooooo002M
ooooo`05o`000?ooooooooooooooool00000P_ooool009gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1oooooo`00WOooool6o`00087ooooo002Nooooo`05o`000?oooooooooooooo
ool00000POooool009oooooo0ol00022ooooo`00oooooolUooooo`00oooooolUooooo`00oooooolU
ooooo`00D?ooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Xooooo`?o00002Oooool0
04oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool08?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool00000:?ooool00ol0003oooooooooo`08ooooo`00Coooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00027ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000027ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool02?oo
ool004oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008_ooool01?l0003oooooooooool00007oooo
o`Co00008_ooool01?l0003oooooooooool00008ooooo`?o0000:Oooool00ol0003oooooooooo`08
ooooo`00Coooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Xooooo`03o`000?oooooooooo00Sooooo001?ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Rooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009oooool2o`0000[ooooo001@oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo027ooooo0_l0000:oooo
o`;o00008oooool2o`0000Wooooo0ol0000Yooooo`03o`000?oooooooooo00Sooooo003oooooobGo
oooo003oooooobGooooo003oooooobGooooo003oooooobGooooo000VooooooCo000000<00000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00`00003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool5o`0000Oooooo00<00000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000o`0000Sooooo00?o0000oooo
ooooool02Oooool00`00003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00<00000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0;_ooool00`00003oooooooooo`0Qooooo`_o
000000?ooooo00000?ooool07?ooool00`00003o0000ooooo`0@ooooo`0300000?oooooooooo02ko
oooo00<00000ooooooooool0;_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`1Dooooo`_o00007oooool3o`00073ooooo00<00000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0E?ooool5o`000003ooooool0003o000000Oo00007Oooool2o`0006oooooo00<0
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0EOooool00`00003o0000o`000002
o`00000300000?l0003o000000[o00007?ooool00ol000000000ooooo`1[ooooo`0300000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo05Kooooo00<00000o`000?l000004?l000000`00
003oooooooooo`0Iooooo`03o`000?oooooo000006Wooooo00<00000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0F?oooolDo`0001_ooooo0_l0001Xooooo`0300000?oooooooooo00Oo
oooo000Vooooo`;o0000F_oooolEo`0001cooooo00?o0000ooooooooool0Hoooool00ol000000000
ooooo`08ooooo`009_ooool00ol0003oooooooooo`1LoooooaGo0000P?ooool00`00003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`1Mooooo`Wo00001oooool6o`00000300000?l0003o
oooo01Wooooo0_l0001Pooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
05oooooo2?l00008ooooo`03o`000?oooooo000000Go00006_ooool2o`0005kooooo00<00000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0H?ooool8o`0000_ooooo1_l000000`00003o
ooooooooo`0Gooooo`?o0000Foooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`1Qooooo`So00003_ooool00`00003o0000o`000002o`0001_ooooo00?o0000ooooooooool0
Eoooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Sooooo`;o000000?o
ooooo`000?l000000_l0000?ooooo`8000001?l0000Iooooo`;o0000Eoooool00`00003ooooooooo
o`07ooooo`009_ooool2o`0006Gooooo00<00000o`000?l000001?l0000Aooooo`8000001Ol0000G
ooooo`03o`000?ooool0000005?ooooo00?o000000000?ooool02?ooool002Kooooo00?o0000oooo
ooooool0I_ooool7o`0001;ooooo1Ol0000Jooooo`0300000?l0003ooooo053ooooo00<00000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0J?ooool5o`00000300000?oooooooooo01?o
oooo1?l0000Hooooo`0300000?l00000000004oooooo00<00000ooooooooool01oooool002Kooooo
00?o0000ooooooooool0JOooool7o`0001Gooooo1?l0000Hooooo`0300000?l0003o000004gooooo
00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0J_ooool7o`0001Kooooo00<0
0000o`000?l000000_l0000Hooooo`03o`0000000000000004[ooooo00<00000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0Joooool8o`0001Sooooo1?l0000Gooooo`;o000000<00000
ooooooooool0A_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1^oooo
o`Ko00006Oooool01?l0003oooooo`000?l0000Hooooo`;o000000<00000ooooooooool0@oooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1^ooooo`So00006_ooool01?l0
003oooooo`000?l0000Gooooo`03o`000?oooooooooo04?ooooo00<00000ooooooooool01oooool0
02Kooooo0_l0001aooooo`So00006oooool4o`0001Oooooo0_l00010ooooo`03o`000000003ooooo
00Sooooo000Vooooo`03o`000?oooooooooo077ooooo1ol000000`00003oooooooooo`0Kooooo`03
o`000000003o000001Oooooo0_l0000oooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo07;ooooo2?l0000Oooooo`?o00006?ooool00ol0003oooooooooo`0jooooo`030000
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo07?ooooo2?l0000Oooooo`0300000?l0
003o000000;o00005_ooool2o`0003[ooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0Loooool00ol000000000o`000005o`00000300000?oooooooooo01oooooo00@00000
o`000?l0003o00005_ooool00ol0003oooooooooo`0gooooo`0300000?oooooooooo00Oooooo000C
ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0I?oo
ool01@00003oooooooooooooool0000000?o000000?oooooo`000?l000000_l000000ooooooo0000
o`00000:o`0002;ooooo1?l0000Fooooo`;o0000=Oooool00`00003oooooooooo`07ooooo`004_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0Foooool00ol0003oooooo`00000Qo`0002Cooooo0ol0000Fooooo`?o0000<_ooool00`00003o
ooooooooo`07ooooo`004_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Co
oooo0_l0001IooooobOo00009_ooool3o`0001Kooooo00<00000o`000?l00000;oooool00ol00000
0000ooooo`08ooooo`004_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0E_ooool2o`00000400000?l0003o0000000000Co000000<00000o`00
0?l000002Oooool00`00003o0000o`000007o`000003ooooool0003o000000Ko0000:Oooool00ol0
003oooooooooo`0Fooooo`;o0000;_ooool00`00003oooooooooo`07ooooo`004_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1E
ooooo`Ko00006oooool02?l00000000000000?l0003ooooo00000?oooooo0000;Oooool00`00003o
0000ooooo`0Eooooo`?o0000:oooool00`00003oooooooooo`07ooooo`004_ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Coooo
o`Go000000<00000ooooooooool0D_ooool2o`0001Sooooo0_l0000Xooooo`0300000?oooooooooo
00Oooooo000Cooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0D_ooool5o`0005Wo
oooo00<00000o`000?ooool05Oooool00ol0003oooooo`00000Vooooo`0300000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo057ooooo1?l0001Nooooo`;o00005_ooool2o`0002Cooooo
00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0D?ooool4o`00067ooooo00?o
0000ooooool000005_ooool2o`00027ooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0D?ooool4o`0006Cooooo00?o000000000?ooool05Oooool00ol000000000ooooo`0N
ooooo`0300000?oooooooooo00Oooooo000Vooooo`;o0000DOooool3o`00083ooooo00?o0000oooo
ool000006_ooool00ol000000000ooooo`08ooooo`009_ooool00ol0003oooooooooo`1?ooooo`03
00000?l0003o000008Cooooo00<00000ooooooooool06?ooool00`00003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`1?ooooo`?o0000Q_ooool2o`0001Oooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0C_ooool3o`0008Wooooo0ol0000Dooooo`0300000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo04kooooo0ol0002<ooooo`?o00004Oooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1>ooooo`;o000000<00000oooo
ooooool0SOooool3o`0000kooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0C_ooool3o`0009;ooooo00?o000000000?ooool02oooool00`00003oooooooooo`07ooooo`00
9_ooool2o`0004oooooo0_l0002Dooooo`0400000?l0003oooooo`0000Sooooo00?o000000000?oo
ool02?ooool002Kooooo00?o0000ooooooooool0C_ooool2o`0009Oooooo0ol00007ooooo`030000
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04kooooo0_l0002Jooooo`0300000?l0
0000000000Cooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0COooool3
o`0009cooooo00H00000ooooooooool00000ooooo`000009ooooo`009_ooool00ol0003ooooooooo
o`1=ooooo`?o0000X?ooool00ol000000000ooooo`08ooooo`009_ooool00ol0003oooooooooo`1=
ooooo`?o0000XOooool00`00003oooooooooo`07ooooo`009_ooool01ol0003oooooooooool0003o
ooooo`0000000000BOooool3o`000:7ooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool00oooool3o`0004Oooooo0_l0002Rooooo`0300000?oooooooooo00Oooooo000Voooo
o`;o00002Oooool00ol0003oooooooooo`12ooooo`;o0000XOooool00ol000000000ooooo`08oooo
o`009_ooool00ol0003oooooooooo`09ooooo`?o0000@?ooool3o`000:;ooooo00<00000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool03Oooool2o`0003gooooo00?o0000ooooooooool0
X_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0?ooooo`0300000?l0
0000000003Wooooo0ol0002Sooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo01;ooooo1?l0000eooooo`0300000?l0003o00000:?ooooo00<00000ooooooooool01oooool0
01?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0<_ooool2o`00000300000?oooooooooo0:7ooooo00<00000oooo
ooooool01oooool001;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Sooooo1?l0000_ooooo`;o0000Y?ooool00`00003oooooooooo`07oooo
o`004_ooool01?l0003oooooooooool00007ooooo`Go00001?ooool2o`0001gooooo0_l000000ooo
oooo0000ooooo`0Xooooo`Co0000Xoooool00ol000000000ooooo`08ooooo`004_ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool08?ooool0
1@00003o0000o`000?ooool0000002?ooooo00@00000o`000?l0003o0000YOooool00`00003ooooo
ooooo`07ooooo`004_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Gooooo
00?o0000ooooooooool09?ooool00ol000000000o`000002o`0001kooooo1?l0002Vooooo`030000
0?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03o`00
0?oooooooooo02Oooooo1ol0000Gooooo`Co0000Z?ooool00`00003oooooooooo`07ooooo`004ooo
ool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`Ko00003_oo
ool00`00003o0000o`000004o`000:Wooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0<oooool3o`0000;ooooo00D00000o`000?l0003o000000000008o`000:cooooo00<0
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooo`00002d
ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0?7ooooo00<00000oooo
ooooool01oooool002Kooooo0_l0003aooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`00
0?oooooooooo0?7ooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0lOoo
ool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3aooooo`0300000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo0?7ooooo00<00000ooooooooool01oooool000Oo
oooo0ol0000Looooo`03o`000?oooooooooo0?7ooooo00<00000ooooooooool01oooool000Sooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`3aooooo`0300000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo01_ooooo0_l0003aooooo`03o`000000003ooooo00Sooooo0008
ooooo`;o00007?ooool00ol0003oooooooooo`3aooooo`0300000?oooooooooo00Oooooo0007oooo
o`;o000000?oooooo`000?l000006_ooool00ol0003oooooooooo`3aooooo`0300000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo0?7ooooo00<00000ooooooooool01oooool002Kooooo
00?o0000ooooooooool0lOooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`3aooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0?7ooooo00<00000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0lOooool00`00003oooooooooo`07oooo
o`009_ooool2o`000?7ooooo00?o000000000?ooool02?ooool002Kooooo00?o0000ooooooooool0
lOooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3aooooo`0300000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo0:cooooo00<00000o`00000000002?l00000
0ooooooo0000o`000004o`0003?ooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0Z_ooool6o`0000_ooooo1_l000001?oooooo0000o`000?l0000/ooooo`0300000?oooooo
oooo00Oooooo000Cooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0
003oooooooooo`2Wooooo`Ko00005Oooool5o`0002[ooooo00<00000ooooooooool01oooool001;o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0Yoooool4o`0001gooooo1?l0000Uooooo`0300000?oooooooooo00Oooooo000Boooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo0:Gooooo1?l0000Rooooo`Go00008Oooool00`00003oooooooooo`07ooooo`004_ooool0
1?l0003oooooooooool00007ooooo`Co00001Oooool2o`000:Kooooo0ol0000Wooooo`;o000000Co
ooooo`000?l0003o00006oooool00ol000000000ooooo`08ooooo`004_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Y?ooool2o`0000030000
0?oooooooooo02[ooooo0ol000000`00003oooooooooo`0Hooooo`0300000?oooooooooo00Oooooo
000Booooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2Sooooo`?o0000<?ooool00`00003o0000ooooo`02o`0001Kooooo00<00000ooooooooool0
1oooool001?ooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`2Sooooo`<00000=?oo
ool4o`0001?ooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Xoooool3
o`0003Oooooo1?l0000@ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
0:;ooooo00<00000o`000?l00000>oooool4o`0000gooooo00<00000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0X_ooool00`00003o0000o`00000nooooo`04o`000?oooooo00000000
00[ooooo00<00000ooooooooool01oooool002Kooooo0_l0002Sooooo`;o000000<00000oooooooo
ool0@Oooool00ol0003oooooooooo`05ooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`00
0?oooooooooo0:;ooooo0ol00015ooooo`;o00001Oooool00`00003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`2Rooooo`;o0000BOooool2o`00000300000?ooool0000000Wooooo000V
ooooo`03o`000?oooooooooo0:7ooooo00<00000o`000?l00000COooool00ol0003oooooooooo`07
ooooo`009_ooool4o`000:7ooooo0_l0001=ooooo`0300000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo00;ooooo0_l0002Mooooo`;o0000C_ooool00`00003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`03ooooo`?o0000Voooool3o`0004gooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool01_ooool3o`0009Sooooo0ol0001=ooooo`0300000?oo
oooooooo00Oooooo000Vooooo`;o00002_ooool2o`0009Kooooo0_l000000`00003oooooooooo`1:
ooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`000?oooooooooo00cooooo0ol0002Boooo
o`;o0000C_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0>ooooo`;o
0000T?ooool4o`0004gooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
4_ooool00`00003o0000ooooo`2;ooooo`;o000000<00000ooooooooool0C?ooool00`00003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`0Cooooo`?o0000R_ooool3o`0004kooooo00<0
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool05_ooool00ol0003ooooo00000027
ooooo`?o0000C_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo08;ooooo1?l0001>ooooo`0300000?oooooooooo00Oooooo000Vooooo`;o
00007Oooool00ol0003oooooooooo`20ooooo`0300000?l0003o000004kooooo00?o000000000?oo
ool02?ooool002Kooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00001oooooo`?o0000
Coooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Qooooo`03o`000000
003ooooo07[ooooo1?l0001?ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo09gooooo1?l0001@ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
02Kooooo0_l0001dooooo`Co0000DOooool00`00003oooooooooo`07ooooo`004oooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0:Oooool00ol00000
0000ooooo`1^ooooo`Ko0000DOooool00`00003oooooooooo`07ooooo`004_ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo06Wooooo0P000005o`0005;ooooo00<00000ooooooooool01oooool001;o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooo`00001Wooooo`0300000?l0003o000000Go0000Doooool0
0`00003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00008ooooo`?o00001Oooool2
o`00037ooooo00?o000000000?ooool0G_ooool00`00003o0000o`000009o`0005?ooooo00?o0000
00000?ooool02?ooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0<oooool00ol000000000ooooo`1:oooooa_o0000E_oo
ool00`00003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`0dooooo`?o0000AOoooolLo`0005Wooooo
00<00000ooooooooool01oooool001?ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooooooo
o`0fooooo`0300000?l0003ooooo04?ooooo00<00000o`000?l000005_l0001Looooo`0300000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo03Wooooo0_l000000`00003oooooooooo`0n
ooooo`ko000000<00000ooooool00000I?ooool00`00003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`0kooooo`03o`000000003o0000043ooooo2Ol0001Zooooo`0300000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0?Oooool00`00003o
0000o`000005o`0006_ooooo00<00000ooooooooool01oooool002Kooooo0_l00011ooooo`030000
0?l0003o000003cooooo1ol0001Zooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool0>oooool5o`0006_ooooo00<00000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0A_ooool2o`0003[ooooo1_l0001Yooooo`0300000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo04Sooooo0_l0000iooooo`Ko0000J?ooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1:ooooo`0300000?oooooo000003So
oooo1Ol0001Wooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04cooooo
0_l0000hooooo`Go0000I_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`1>ooooo`?o0000=oooool4o`0006Gooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0DOooool00`00003o0000o`00000fooooo`Co0000Hoooool00`00003oooooooooo`07
ooooo`009_ooool2o`0005Gooooo0_l0000eooooo`Co0000HOooool00ol000000000ooooo`08oooo
o`009_ooool00ol0003oooooooooo`1Eooooo`;o0000=Oooool4o`00067ooooo00<00000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0S_ooool4o`0005oooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0Foooool00`00003o0000ooooo`0aooooo`?o000000<0
0000ooooooooool0G?ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1N
ooooo`0300000?oooooooooo033ooooo1?l0001Looooo`0300000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo05oooooo0_l0000cooooo`;o0000Foooool00`00003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo02kooooo00@00000o`000?l0
003o0000FOooool00`00003oooooooooo`07ooooo`009_ooool2o`0006Gooooo0_l0000`ooooo`?o
0000Eoooool00ol000000000ooooo`08ooooo`009_ooool00ol0003oooooooooo`1Wooooo`;o0000
;_ooool00`00003o0000o`00001Gooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo06Wooooo0_l0000^ooooo`03o`000000003ooooo05Gooooo00<00000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0[ooooo`?o000000<00000
ooooooooool0D_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1]oooo
o`0300000?l0003ooooo02_ooooo00?o000000000?ooool0Doooool00`00003oooooooooo`07oooo
o`007_ooool3o`0000Gooooo00?o0000ooooooooool0L?ooool00`00003o0000ooooo`0Yooooo`;o
0000Doooool00`00003oooooooooo`07ooooo`007oooool00ol0003oooooooooo`04ooooo`030000
0?oooooooooo02kooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0Aooooo`03o`00
0?oooooo000001[ooooo00<00000ooooooooool0;_ooool00`00003oooooooooo`0^ooooo`030000
0?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00`00003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool3o`0000_ooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`0300000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00<00000ooooooooool01oooool001oooooo00?o0000ooooooooool01?oooooe
000000Wooooo000Oooooo`03o`000?oooooooooo0?oooooo0oooool001kooooo0_l0003oooooo`Go
oooo000Oooooo`03o`000?oooooooooo0?oooooo0oooool00?oooooo9Oooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 306.188}, {289.125, 145.688}} -> {-0.533364, \
1.04851, 0.0040998, 0.00663361}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animation", "Subsection"],

Cell[TextData[{
  "To generate an animation we just need to produce a series of plots that \
will constitue the individual frames of the animation.  We accomplish this \
below with the ",
  StyleBox["Table", "Input"],
  " function, which we use to generate a sequence of plots like the one in \
the previous section but with varying values of",
  StyleBox[" niter", "Input"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(K = 1.5; \[Theta]min = 0.4; \[Theta]max = 0.6; rmin = 0; rmax = 0.12; 
    n = 5000; maxiter = 6;\), "\n", 
    \(\(f[{\[Theta]_, r_}] := 
        N[{Mod[\[Theta] + r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1], 
            Mod[r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1]}];\)\), "\n", 
    \(Table[
      ListPlot[Table[
          Nest[f, {Random[Real, {\[Theta]min, \[Theta]max}], 
              Random[Real, {rmin, rmax}]}, niter], {i, 0, n}], 
        PlotStyle \[Rule] PointSize[0.002], 
        PlotRange \[Rule] {{0, 1}, {0, 1}}, Frame \[Rule] True, 
        RotateLabel \[Rule] False, 
        FrameLabel \[Rule] {"\<\[Theta]\>", "\<r\>", "\<\>", "\<\>"}], \
{niter, 0, maxiter}]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.50077 .00614 Mdot
.53881 .02379 Mdot
.58405 .01457 Mdot
.57375 .07108 Mdot
.49515 .0443 Mdot
.55264 .02001 Mdot
.46858 .0109 Mdot
.42006 .03577 Mdot
.52203 .0557 Mdot
.48621 .00996 Mdot
.44648 .0645 Mdot
.50151 .01156 Mdot
.54572 .05836 Mdot
.5627 .06194 Mdot
.56167 .04379 Mdot
.58894 .06502 Mdot
.46652 .07366 Mdot
.43631 .04501 Mdot
.59794 .06276 Mdot
.41625 .00924 Mdot
.47591 .00706 Mdot
.53004 .07345 Mdot
.42942 .01673 Mdot
.42853 .06189 Mdot
.4837 .03253 Mdot
.46583 .07411 Mdot
.52203 .06291 Mdot
.47689 .00909 Mdot
.45551 .06341 Mdot
.44058 .03824 Mdot
.45758 .00065 Mdot
.42434 .029 Mdot
.58167 .06775 Mdot
.4943 .02972 Mdot
.55225 .05102 Mdot
.46577 .042 Mdot
.46855 .01849 Mdot
.59994 .04205 Mdot
.54651 .02975 Mdot
.52305 .03296 Mdot
.491 .0405 Mdot
.48247 .06888 Mdot
.43342 .03985 Mdot
.45813 .03988 Mdot
.45175 .04626 Mdot
.56383 .01015 Mdot
.4995 .0694 Mdot
.49805 .04232 Mdot
.43095 .05091 Mdot
.49811 .00027 Mdot
.48444 .02116 Mdot
.57506 .04147 Mdot
.59344 .05482 Mdot
.4926 .04675 Mdot
.56002 .01497 Mdot
.43447 .00687 Mdot
.50827 .04288 Mdot
.47064 .07088 Mdot
.40877 .04764 Mdot
.57259 .02856 Mdot
.57781 .0709 Mdot
.47448 .0283 Mdot
.49338 .04974 Mdot
.49941 .061 Mdot
.49994 .06908 Mdot
.40682 .01424 Mdot
.53992 .05411 Mdot
.57235 .00737 Mdot
.43166 .01123 Mdot
.50171 .01065 Mdot
.42289 .03775 Mdot
.52912 .05625 Mdot
.44508 .04102 Mdot
.45464 .02795 Mdot
.5517 .06545 Mdot
.55523 .04112 Mdot
.45176 .07054 Mdot
.54841 .02688 Mdot
.51184 .01643 Mdot
.57606 .01951 Mdot
.48018 .0052 Mdot
.47435 .00885 Mdot
.45729 .04161 Mdot
.54523 .02676 Mdot
.41221 .00059 Mdot
.49059 .07298 Mdot
.46051 .0093 Mdot
.53537 .03185 Mdot
.40875 .01293 Mdot
.58696 .00498 Mdot
.49691 .07066 Mdot
.4109 .05964 Mdot
.41673 .06546 Mdot
.53655 .05078 Mdot
.55944 .02385 Mdot
.59131 .02402 Mdot
.54723 .02326 Mdot
.50072 .02521 Mdot
.48672 .01396 Mdot
.56536 .06752 Mdot
.47797 .00103 Mdot
.5784 .06254 Mdot
.58105 .00453 Mdot
.5675 .0029 Mdot
.56432 .01323 Mdot
.43096 .02629 Mdot
.40488 .06354 Mdot
.43964 .00227 Mdot
.45766 .04028 Mdot
.53892 .05123 Mdot
.57094 .02632 Mdot
.57357 .05788 Mdot
.49298 .02528 Mdot
.59517 .0695 Mdot
.51192 .02075 Mdot
.42767 .0666 Mdot
.5476 .00752 Mdot
.59671 .04031 Mdot
.54271 .01815 Mdot
.55707 .03804 Mdot
.48506 .05203 Mdot
.41814 .06098 Mdot
.51412 .02572 Mdot
.44457 .00311 Mdot
.42114 .00043 Mdot
.4494 .00777 Mdot
.50922 .05384 Mdot
.42174 .01534 Mdot
.56162 .04632 Mdot
.42502 .04919 Mdot
.41891 .02818 Mdot
.46796 .01114 Mdot
.53385 .05031 Mdot
.44981 .02433 Mdot
.41973 .02459 Mdot
.40524 .02122 Mdot
.59859 .02416 Mdot
.55583 .01345 Mdot
.48937 .04448 Mdot
.5341 .07228 Mdot
.52774 .07232 Mdot
.50907 .02309 Mdot
.50883 .04415 Mdot
.44112 .01195 Mdot
.57498 .06801 Mdot
.5913 .06178 Mdot
.55525 .04341 Mdot
.58606 .04056 Mdot
.55666 .01926 Mdot
.43023 .02711 Mdot
.46729 .04894 Mdot
.49613 .029 Mdot
.53955 .05078 Mdot
.58706 .00591 Mdot
.43071 .00663 Mdot
.54594 .06813 Mdot
.45573 .01279 Mdot
.55464 .00634 Mdot
.50048 .04354 Mdot
.56857 .03994 Mdot
.54382 .02428 Mdot
.53834 .01283 Mdot
.47653 .04951 Mdot
.44221 .05799 Mdot
.53698 .07289 Mdot
.45516 .05208 Mdot
.50627 .06626 Mdot
.50921 .05812 Mdot
.45054 .05347 Mdot
.55458 .05178 Mdot
.55006 .00993 Mdot
.586 .01184 Mdot
.40624 .05981 Mdot
.44766 .07318 Mdot
.52972 .01031 Mdot
.40544 .01519 Mdot
.59274 .01158 Mdot
.55029 .03727 Mdot
.48647 .01948 Mdot
.44108 .05331 Mdot
.43593 .04017 Mdot
.4865 .00153 Mdot
.48587 .03024 Mdot
.5005 .06386 Mdot
.47963 .04459 Mdot
.45284 .06484 Mdot
.54991 .03428 Mdot
.4474 .04965 Mdot
.55718 .0227 Mdot
.49711 .01238 Mdot
.4707 .00322 Mdot
.45603 .03323 Mdot
.43477 .03721 Mdot
.56953 .0317 Mdot
.5489 .00697 Mdot
.46903 .042 Mdot
.46927 .03655 Mdot
.41619 .05133 Mdot
.51935 .00226 Mdot
.5688 .00168 Mdot
.56218 .05372 Mdot
.47169 .06346 Mdot
.49147 .0505 Mdot
.41566 .03023 Mdot
.4567 .01329 Mdot
.44612 .0727 Mdot
.5078 .00631 Mdot
.57709 .0307 Mdot
.43854 .04393 Mdot
.5609 .05353 Mdot
.51919 .04167 Mdot
.5921 .05186 Mdot
.55701 .06211 Mdot
.52041 .06256 Mdot
.46554 .01162 Mdot
.50475 .03233 Mdot
.40883 .07249 Mdot
.45863 .03379 Mdot
.50103 .06618 Mdot
.48154 .0031 Mdot
.46249 .02225 Mdot
.52064 .02373 Mdot
.54331 .05474 Mdot
.52854 .04603 Mdot
.5863 .06679 Mdot
.40813 .05763 Mdot
.52076 .05518 Mdot
.50338 .02531 Mdot
.51192 .05685 Mdot
.44476 .06568 Mdot
.41089 .06483 Mdot
.56322 .06258 Mdot
.5484 .04258 Mdot
.44258 .03886 Mdot
.4051 .062 Mdot
.51404 .06699 Mdot
.4188 .06937 Mdot
.5059 .00935 Mdot
.49804 .0142 Mdot
.40252 .05821 Mdot
.58612 .03152 Mdot
.55776 .0667 Mdot
.57523 .04085 Mdot
.59454 .00412 Mdot
.42682 .07244 Mdot
.55196 .03942 Mdot
.42173 .01044 Mdot
.43792 .0466 Mdot
.40292 .01523 Mdot
.53201 .03725 Mdot
.50488 .00103 Mdot
.52949 .0532 Mdot
.51876 .04368 Mdot
.57173 .06067 Mdot
.54354 .00283 Mdot
.57719 .05655 Mdot
.51671 .00456 Mdot
.42524 .01712 Mdot
.49498 .06828 Mdot
.58732 .04469 Mdot
.49206 .05306 Mdot
.45531 .00744 Mdot
.58718 .05202 Mdot
.52582 .0284 Mdot
.46842 .00835 Mdot
.55408 .0419 Mdot
.52488 .00552 Mdot
.57689 .05952 Mdot
.40817 .00096 Mdot
.55166 .04239 Mdot
.51318 .00684 Mdot
.56434 .07187 Mdot
.42112 .02795 Mdot
.50903 .06443 Mdot
.43395 .05009 Mdot
.58322 .03602 Mdot
.56553 .04175 Mdot
.42913 .06829 Mdot
.44065 .03623 Mdot
.45224 .00877 Mdot
.43248 .03527 Mdot
.50058 .04054 Mdot
.5193 .02842 Mdot
.53624 .04284 Mdot
.49817 .00047 Mdot
.42721 .05258 Mdot
.46422 .02454 Mdot
.444 .01655 Mdot
.49869 .05696 Mdot
.41487 .02243 Mdot
.45804 .02073 Mdot
.56263 .01366 Mdot
.42556 .05963 Mdot
.46205 .04728 Mdot
.50627 .03121 Mdot
.5258 .00444 Mdot
.4081 .03074 Mdot
.49859 .02603 Mdot
.54387 .00619 Mdot
.45459 .00948 Mdot
.44518 .0234 Mdot
.43972 .06121 Mdot
.58714 .00266 Mdot
.47709 .04755 Mdot
.56157 .0172 Mdot
.41505 .00027 Mdot
.4553 .06015 Mdot
.48924 .06999 Mdot
.44721 .02942 Mdot
.59065 .04395 Mdot
.50334 .02322 Mdot
.53606 .03447 Mdot
.45816 .07399 Mdot
.49634 .04742 Mdot
.47102 .07133 Mdot
.41925 .07404 Mdot
.50945 .05413 Mdot
.4042 .07377 Mdot
.45415 .06814 Mdot
.51496 .00378 Mdot
.40694 .03873 Mdot
.5243 .03399 Mdot
.5036 .0155 Mdot
.58824 .07368 Mdot
.44545 .01568 Mdot
.4919 .02625 Mdot
.57443 .01851 Mdot
.47266 .02638 Mdot
.46498 .03855 Mdot
.46846 .02678 Mdot
.41083 .04457 Mdot
.5535 .023 Mdot
.40389 .00585 Mdot
.4292 .06318 Mdot
.50029 .06451 Mdot
.44095 .06366 Mdot
.45484 .04883 Mdot
.54905 .03741 Mdot
.48042 .03032 Mdot
.4764 .01102 Mdot
.41544 .06593 Mdot
.40794 .05841 Mdot
.40461 .02136 Mdot
.45444 .03541 Mdot
.40072 .01551 Mdot
.42524 .0464 Mdot
.50043 .02517 Mdot
.58429 .0569 Mdot
.44558 .0505 Mdot
.43523 .01949 Mdot
.56516 .02018 Mdot
.55884 .00847 Mdot
.54972 .02842 Mdot
.5509 .02422 Mdot
.54511 .00706 Mdot
.49646 .06298 Mdot
.54439 .06571 Mdot
.47122 .01658 Mdot
.44396 .04054 Mdot
.48693 .03385 Mdot
.59838 .06421 Mdot
.4517 .01436 Mdot
.43321 .04403 Mdot
.49286 .00589 Mdot
.48349 .01561 Mdot
.54196 .05583 Mdot
.53838 .00855 Mdot
.4455 .06701 Mdot
.59399 .01701 Mdot
.57428 .05043 Mdot
.55003 .05063 Mdot
.48735 .01658 Mdot
.55166 .06059 Mdot
.43565 .00222 Mdot
.51845 .01656 Mdot
.54279 .0705 Mdot
.43496 .00095 Mdot
.40083 .01467 Mdot
.49657 .06656 Mdot
.55533 .02182 Mdot
.50258 .04955 Mdot
.58105 .04556 Mdot
.55254 .07309 Mdot
.49371 .02898 Mdot
.40089 .0125 Mdot
.45806 .02676 Mdot
.48244 .0701 Mdot
.51527 .03042 Mdot
.44749 .06915 Mdot
.51445 .01575 Mdot
.55091 .00259 Mdot
.55911 .0681 Mdot
.44834 .0272 Mdot
.57806 .02254 Mdot
.49579 .02828 Mdot
.48435 .06773 Mdot
.4949 .01578 Mdot
.42629 .04097 Mdot
.41246 .01984 Mdot
.51101 .01055 Mdot
.56498 .02485 Mdot
.59657 .06896 Mdot
.41406 .02226 Mdot
.43746 .00086 Mdot
.56573 .06922 Mdot
.4594 .05249 Mdot
.46994 .04094 Mdot
.57505 .05893 Mdot
.57503 .02517 Mdot
.54876 .01796 Mdot
.56257 .00533 Mdot
.43774 .00741 Mdot
.5976 .05465 Mdot
.44117 .01262 Mdot
.58353 .03239 Mdot
.40372 .01175 Mdot
.41781 .03733 Mdot
.54432 .03342 Mdot
.54787 .07055 Mdot
.56928 .04866 Mdot
.57283 .04538 Mdot
.42052 .0307 Mdot
.41026 .04005 Mdot
.58277 .02329 Mdot
.41267 .05957 Mdot
.5416 .01067 Mdot
.42913 .02718 Mdot
.53788 .07309 Mdot
.41133 .06401 Mdot
.59356 .03966 Mdot
.46346 .06762 Mdot
.42429 .06517 Mdot
.49063 .02223 Mdot
.40377 .03447 Mdot
.48036 .05634 Mdot
.42099 .01118 Mdot
.4677 .07094 Mdot
.47939 .00051 Mdot
.43856 .04377 Mdot
.54151 .00159 Mdot
.42723 .05392 Mdot
.54795 .03609 Mdot
.56377 .06047 Mdot
.52366 .04508 Mdot
.47315 .03824 Mdot
.5199 .01062 Mdot
.59278 .05606 Mdot
.4989 .0736 Mdot
.52509 .05928 Mdot
.41951 .07309 Mdot
.48653 .01551 Mdot
.478 .07151 Mdot
.45929 .03575 Mdot
.53005 .03542 Mdot
.49552 .04945 Mdot
.40639 .0645 Mdot
.42237 .01121 Mdot
.48649 .05388 Mdot
.42959 .02932 Mdot
.58759 .05445 Mdot
.5045 .0442 Mdot
.56808 .05552 Mdot
.41797 .02869 Mdot
.49008 .05818 Mdot
.55868 .0671 Mdot
.56003 .02276 Mdot
.46316 .01765 Mdot
.55364 .03242 Mdot
.44078 .00644 Mdot
.46715 .05271 Mdot
.41119 .05129 Mdot
.47957 .07242 Mdot
.50669 .00709 Mdot
.51149 .01691 Mdot
.48872 .05257 Mdot
.42141 .03289 Mdot
.53004 .05963 Mdot
.46139 .01014 Mdot
.46688 .04198 Mdot
.50774 .05188 Mdot
.4261 .03554 Mdot
.44059 .07334 Mdot
.4149 .05841 Mdot
.56102 .00091 Mdot
.50821 .05132 Mdot
.44953 .05817 Mdot
.41949 .07292 Mdot
.42812 .02528 Mdot
.48945 .01329 Mdot
.56673 .01514 Mdot
.42257 .04547 Mdot
.45899 .03742 Mdot
.59647 .00993 Mdot
.4184 .03825 Mdot
.58157 .02569 Mdot
.45737 .03734 Mdot
.47336 .04853 Mdot
.40784 .05333 Mdot
.45387 .04978 Mdot
.57972 .02806 Mdot
.56442 .0365 Mdot
.41299 .01292 Mdot
.54185 .06519 Mdot
.55401 .04966 Mdot
.54538 .05526 Mdot
.53561 .01141 Mdot
.56381 .02957 Mdot
.47824 .04823 Mdot
.49045 .0552 Mdot
.47039 .06906 Mdot
.43658 .00542 Mdot
.49067 .04101 Mdot
.47216 .04309 Mdot
.47768 .02809 Mdot
.53031 .05206 Mdot
.52367 .05259 Mdot
.58493 .07097 Mdot
.58807 .04119 Mdot
.42112 .0414 Mdot
.50983 .06712 Mdot
.53067 .06037 Mdot
.43943 .07222 Mdot
.49409 .05495 Mdot
.54876 .03122 Mdot
.42192 .01186 Mdot
.47108 .00313 Mdot
.49161 .03396 Mdot
.54741 .0247 Mdot
.50667 .03716 Mdot
.55934 .05768 Mdot
.48555 .06992 Mdot
.44951 .06472 Mdot
.55488 .00955 Mdot
.41008 .06666 Mdot
.46079 .02877 Mdot
.46132 .03544 Mdot
.43887 .01691 Mdot
.59023 .03232 Mdot
.54726 .05711 Mdot
.44282 .00762 Mdot
.44059 .01995 Mdot
.48348 .0241 Mdot
.55504 .02419 Mdot
.43396 .03355 Mdot
.40016 .01464 Mdot
.42388 .04105 Mdot
.53937 .06003 Mdot
.56257 .00561 Mdot
.5005 .04312 Mdot
.57234 .04746 Mdot
.55323 .06018 Mdot
.52951 .03984 Mdot
.51265 .04023 Mdot
.44603 .01574 Mdot
.55761 .01604 Mdot
.41207 .05635 Mdot
.55745 .0014 Mdot
.58819 .0153 Mdot
.41809 .01553 Mdot
.42562 .00969 Mdot
.51759 .04657 Mdot
.45328 .0364 Mdot
.56436 .06056 Mdot
.52377 .07072 Mdot
.45171 .02033 Mdot
.47774 .05498 Mdot
.4941 .0043 Mdot
.46567 .0728 Mdot
.53665 .0029 Mdot
.47748 .0575 Mdot
.51856 .06153 Mdot
.45186 .04781 Mdot
.40097 .01496 Mdot
.59858 .01141 Mdot
.43661 .02856 Mdot
.4748 .01486 Mdot
.5849 .00823 Mdot
.59707 .03404 Mdot
.4908 .00394 Mdot
.5314 .0354 Mdot
.55416 .00104 Mdot
.45392 .05207 Mdot
.4356 .01367 Mdot
.40206 .00426 Mdot
.43463 .07288 Mdot
.40348 .06701 Mdot
.59801 .04431 Mdot
.52868 .05215 Mdot
.41311 .03608 Mdot
.53161 .01812 Mdot
.52231 .03214 Mdot
.40021 .05688 Mdot
.56815 .0311 Mdot
.54629 .00481 Mdot
.53256 .01743 Mdot
.54423 .00055 Mdot
.49793 .01871 Mdot
.54075 .0077 Mdot
.49992 .04856 Mdot
.41207 .02971 Mdot
.48681 .01248 Mdot
.48046 .01159 Mdot
.5645 .0545 Mdot
.48025 .02888 Mdot
.59635 .0234 Mdot
.53395 .02408 Mdot
.46379 .00597 Mdot
.58972 .02353 Mdot
.56586 .06142 Mdot
.44897 .01583 Mdot
.46594 .01286 Mdot
.43689 .06029 Mdot
.57913 .00037 Mdot
.55644 .04869 Mdot
.41463 .02004 Mdot
.47619 .01981 Mdot
.41829 .0708 Mdot
.54224 .0699 Mdot
.5545 .06483 Mdot
.55252 .04636 Mdot
.58864 .00341 Mdot
.50355 .03053 Mdot
.5227 .06472 Mdot
.46666 .04441 Mdot
.54357 .06434 Mdot
.51022 .06988 Mdot
.52893 .0443 Mdot
.43403 .05007 Mdot
.51064 .04767 Mdot
.4918 .05434 Mdot
.55615 .057 Mdot
.53928 .00797 Mdot
.56751 .0536 Mdot
.43573 .05161 Mdot
.4448 .06304 Mdot
.56907 .0072 Mdot
.50124 .07287 Mdot
.45885 .01148 Mdot
.57231 .02856 Mdot
.42482 .03558 Mdot
.46166 .05506 Mdot
.53302 .0554 Mdot
.50551 .07222 Mdot
.59374 .04743 Mdot
.53801 .01862 Mdot
.55802 .06999 Mdot
.4932 .02974 Mdot
.58895 .06279 Mdot
.59197 .03104 Mdot
.5301 .05131 Mdot
.41966 .00248 Mdot
.50529 .01573 Mdot
.558 .02158 Mdot
.57227 .03449 Mdot
.45249 .02353 Mdot
.57852 .06123 Mdot
.51448 .0049 Mdot
.42051 .0654 Mdot
.42127 .04932 Mdot
.43156 .00261 Mdot
.42931 .01828 Mdot
.50145 .02547 Mdot
.40965 .01581 Mdot
.59617 .00973 Mdot
.45164 .06839 Mdot
.4239 .0494 Mdot
.59916 .04486 Mdot
.44538 .06234 Mdot
.48468 .03996 Mdot
.42487 .0711 Mdot
.46341 .0648 Mdot
.59331 .06849 Mdot
.4341 .04651 Mdot
.49186 .04302 Mdot
.42445 .0307 Mdot
.49569 .03329 Mdot
.57281 .03648 Mdot
.47179 .05805 Mdot
.57365 .06578 Mdot
.42642 .06988 Mdot
.48897 .02583 Mdot
.40155 .07294 Mdot
.42557 .0352 Mdot
.40823 .00446 Mdot
.59147 .06285 Mdot
.51637 .0356 Mdot
.56701 .03215 Mdot
.42068 .00231 Mdot
.5942 .06983 Mdot
.54889 .01843 Mdot
.42055 .00405 Mdot
.52247 .02271 Mdot
.53158 .05238 Mdot
.52093 .02393 Mdot
.50601 .01718 Mdot
.51269 .01948 Mdot
.51454 .0285 Mdot
.59632 .05804 Mdot
.54753 .07051 Mdot
.57564 .05573 Mdot
.55333 .00068 Mdot
.42675 .0373 Mdot
.53278 .0708 Mdot
.50428 .01459 Mdot
.4012 .01842 Mdot
.58335 .06482 Mdot
.4952 .00124 Mdot
.47065 .04534 Mdot
.58065 .04691 Mdot
.47433 .06147 Mdot
.43312 .05056 Mdot
.49869 .00574 Mdot
.4798 .04987 Mdot
.47194 .0426 Mdot
.54702 .05324 Mdot
.56767 .02801 Mdot
.54581 .03482 Mdot
.58432 .03735 Mdot
.45062 .03358 Mdot
.51367 .06618 Mdot
.46996 .06083 Mdot
.43934 .00471 Mdot
.43684 .01028 Mdot
.54064 .07314 Mdot
.55704 .03457 Mdot
.4687 .03054 Mdot
.41002 .05549 Mdot
.50103 .00253 Mdot
.46421 .02068 Mdot
.51671 .03934 Mdot
.4136 .06126 Mdot
.40304 .04733 Mdot
.54363 .00043 Mdot
.56371 .04262 Mdot
.5068 .06432 Mdot
.42306 .04364 Mdot
.54976 .02975 Mdot
.55437 .0131 Mdot
.53974 .04842 Mdot
.45333 .01057 Mdot
.47553 .02775 Mdot
.53662 .0454 Mdot
.46193 .04065 Mdot
.53358 .07223 Mdot
.5183 .04022 Mdot
.56987 .02961 Mdot
.4115 .05007 Mdot
.54681 .06013 Mdot
.46174 .02032 Mdot
.59244 .04703 Mdot
.522 .04606 Mdot
.53911 .03645 Mdot
.44647 .01831 Mdot
.40249 .06522 Mdot
.58454 .05182 Mdot
.4689 .06716 Mdot
.46625 .0116 Mdot
.49903 .03754 Mdot
.45475 .0357 Mdot
.55222 .05158 Mdot
.59301 .01538 Mdot
.55977 .00455 Mdot
.47101 .04349 Mdot
.42067 .04226 Mdot
.42454 .02518 Mdot
.41818 .0512 Mdot
.43999 .04752 Mdot
.54928 .05821 Mdot
.57375 .03592 Mdot
.45025 .02066 Mdot
.519 .00022 Mdot
.49803 .04325 Mdot
.52599 .059 Mdot
.53825 .0387 Mdot
.45498 .01551 Mdot
.51759 .07061 Mdot
.43045 .06449 Mdot
.49941 .01941 Mdot
.59045 .01697 Mdot
.55013 .03537 Mdot
.4167 .05521 Mdot
.49988 .0147 Mdot
.4977 .05499 Mdot
.40186 .04562 Mdot
.57171 .07015 Mdot
.4636 .00692 Mdot
.51673 .05464 Mdot
.54601 .01048 Mdot
.48628 .06431 Mdot
.44661 .06523 Mdot
.49583 .04734 Mdot
.49647 .02987 Mdot
.47913 .0663 Mdot
.59659 .01516 Mdot
.58143 .01131 Mdot
.59473 .04371 Mdot
.40972 .01532 Mdot
.53113 .03679 Mdot
.49299 .03485 Mdot
.58512 .02631 Mdot
.4067 .0447 Mdot
.53851 .03524 Mdot
.51087 .07152 Mdot
.44204 .00537 Mdot
.43174 .00522 Mdot
.44545 .06437 Mdot
.45031 .06808 Mdot
.45071 .02067 Mdot
.44059 .05276 Mdot
.51958 .05804 Mdot
.5476 .01791 Mdot
.53446 .03173 Mdot
.5409 .04738 Mdot
.59595 .07065 Mdot
.43003 .05002 Mdot
.55392 .06528 Mdot
.59829 .0448 Mdot
.50847 .0009 Mdot
.54798 .05089 Mdot
.45776 .0544 Mdot
.50738 .0723 Mdot
.53818 .07053 Mdot
.55978 .05439 Mdot
.40372 .03879 Mdot
.41888 .00701 Mdot
.40776 .04231 Mdot
.58885 .03115 Mdot
.45385 .05119 Mdot
.59057 .06052 Mdot
.54537 .05029 Mdot
.44259 .00963 Mdot
.48761 .07005 Mdot
.53521 .01149 Mdot
.54943 .07369 Mdot
.57543 .03127 Mdot
.54571 .03489 Mdot
.55655 .02426 Mdot
.53795 .06675 Mdot
.56769 .06727 Mdot
.4841 .01556 Mdot
.57713 .00675 Mdot
.53873 .03944 Mdot
.53454 .07129 Mdot
.45112 .04355 Mdot
.59933 .05979 Mdot
.50168 .04403 Mdot
.4239 .02852 Mdot
.55597 .00914 Mdot
.46735 .00426 Mdot
.41802 .01655 Mdot
.49966 .01116 Mdot
.53391 .00099 Mdot
.52253 .00441 Mdot
.59518 .03572 Mdot
.58799 .00729 Mdot
.54407 .06633 Mdot
.58866 .02166 Mdot
.44239 .0223 Mdot
.56476 .0673 Mdot
.48642 .01316 Mdot
.49741 .06304 Mdot
.4684 .07077 Mdot
.59775 .05188 Mdot
.53449 .06978 Mdot
.47522 .04747 Mdot
.5393 .03406 Mdot
.48723 .04018 Mdot
.59523 .04189 Mdot
.49856 .01852 Mdot
.55285 .01959 Mdot
.5338 .02539 Mdot
.46643 .00643 Mdot
.43639 .03652 Mdot
.59803 .00982 Mdot
.43864 .0588 Mdot
.46354 .01421 Mdot
.56342 .01134 Mdot
.52423 .05432 Mdot
.47619 .04532 Mdot
.529 .01243 Mdot
.57763 .0268 Mdot
.57615 .067 Mdot
.44383 .00141 Mdot
.50972 .06057 Mdot
.40744 .03906 Mdot
.5117 .05075 Mdot
.5688 .05442 Mdot
.44816 .03654 Mdot
.40538 .04308 Mdot
.52393 .05639 Mdot
.52919 .07193 Mdot
.59493 .04396 Mdot
.55156 .04513 Mdot
.41878 .05112 Mdot
.50773 .04371 Mdot
.50906 .06471 Mdot
.50029 .00465 Mdot
.59736 .01396 Mdot
.53149 .0244 Mdot
.5492 .05158 Mdot
.52611 .05548 Mdot
.42527 .06936 Mdot
.59692 .05772 Mdot
.43034 .0254 Mdot
.44536 .01259 Mdot
.41156 .04844 Mdot
.53764 .04304 Mdot
.5025 .05789 Mdot
.43735 .03839 Mdot
.50514 .04393 Mdot
.50587 .01399 Mdot
.55595 .06651 Mdot
.57976 .03268 Mdot
.53068 .07132 Mdot
.58284 .04913 Mdot
.50034 .04592 Mdot
.53748 .03654 Mdot
.48878 .07164 Mdot
.59984 .06766 Mdot
.58628 .01375 Mdot
.56249 .02928 Mdot
.48113 .04398 Mdot
.45662 .01529 Mdot
.52519 .05163 Mdot
.47686 .05677 Mdot
.59451 .05448 Mdot
.49402 .00764 Mdot
.49417 .00856 Mdot
.55654 .04527 Mdot
.40539 .01108 Mdot
.5567 .05177 Mdot
.41911 .07149 Mdot
.59421 .0225 Mdot
.53797 .02751 Mdot
.53759 .00721 Mdot
.41279 .05004 Mdot
.46073 .0246 Mdot
.41828 .06973 Mdot
.56671 .01696 Mdot
.52411 .06117 Mdot
.41016 .04585 Mdot
.51872 .05009 Mdot
.45346 .06824 Mdot
.49962 .05276 Mdot
.45925 .04575 Mdot
.56164 .02526 Mdot
.52166 .03854 Mdot
.54885 .04938 Mdot
.46093 .01393 Mdot
.53057 .05382 Mdot
.49422 .07114 Mdot
.40646 .06682 Mdot
.48406 .02529 Mdot
.48774 .01673 Mdot
.4306 .03121 Mdot
.58812 .03813 Mdot
.57135 .05963 Mdot
.42648 .01287 Mdot
.44969 .02109 Mdot
.47763 .03765 Mdot
.58876 .00716 Mdot
.54705 .058 Mdot
.49454 .01018 Mdot
.54059 .06535 Mdot
.41048 .05906 Mdot
.45286 .04862 Mdot
.57988 .02785 Mdot
.46474 .01049 Mdot
.40853 .04238 Mdot
.43826 .07179 Mdot
.55884 .02129 Mdot
.56063 .03413 Mdot
.57008 .01413 Mdot
.41358 .0503 Mdot
.47554 .00395 Mdot
.47298 .05912 Mdot
.46506 .01906 Mdot
.42013 .0105 Mdot
.48518 .06538 Mdot
.55539 0 Mdot
.47665 .023 Mdot
.51714 .00238 Mdot
.51781 .0017 Mdot
.55651 .04241 Mdot
.54774 .06173 Mdot
.54293 .06628 Mdot
.4722 .05778 Mdot
.46995 .00716 Mdot
.40714 .03872 Mdot
.44982 .07083 Mdot
.52196 .0475 Mdot
.49442 .07082 Mdot
.44531 .02451 Mdot
.57729 .06844 Mdot
.5275 .0228 Mdot
.42078 .02603 Mdot
.57977 .03523 Mdot
.47785 .03392 Mdot
.50757 .05162 Mdot
.4079 .02676 Mdot
.50043 .0129 Mdot
.55809 .0301 Mdot
.57846 .03956 Mdot
.46366 .03344 Mdot
.53315 .01505 Mdot
.48638 .03916 Mdot
.40564 .06641 Mdot
.4656 .01313 Mdot
.42588 .03118 Mdot
.58775 .05338 Mdot
.51831 .05372 Mdot
.57985 .02662 Mdot
.41788 .04082 Mdot
.42176 .07069 Mdot
.43942 .00126 Mdot
.5581 .03725 Mdot
.50627 .06038 Mdot
.47172 .07225 Mdot
.50063 .06813 Mdot
.40613 .05911 Mdot
.47475 .03695 Mdot
.41838 .00573 Mdot
.55644 .05739 Mdot
.43853 .05327 Mdot
.53856 .01657 Mdot
.41677 .05675 Mdot
.49914 .01531 Mdot
.45868 .0195 Mdot
.59286 .0291 Mdot
.58695 .02142 Mdot
.49224 .03513 Mdot
.58083 .03648 Mdot
.41748 .07235 Mdot
.56245 .03075 Mdot
.46104 .01495 Mdot
.52391 .05164 Mdot
.52248 .07255 Mdot
.50714 .06905 Mdot
.42334 .05724 Mdot
.44847 .04955 Mdot
.43048 .02814 Mdot
.46151 .02812 Mdot
.53824 .06717 Mdot
.48069 .06581 Mdot
.52076 .06899 Mdot
.51824 .03506 Mdot
.45972 .05403 Mdot
.59433 .05759 Mdot
.53724 .05565 Mdot
.48718 .06271 Mdot
.5139 .07258 Mdot
.43872 .01316 Mdot
.48342 .04444 Mdot
.5772 .0592 Mdot
.54518 .05144 Mdot
.49652 .06756 Mdot
.42442 .05661 Mdot
.57828 .03249 Mdot
.5647 .00258 Mdot
.58395 .04906 Mdot
.42746 .02109 Mdot
.49677 .06052 Mdot
.51356 .02267 Mdot
.45805 .04736 Mdot
.43014 .05239 Mdot
.48084 .06232 Mdot
.48496 .00096 Mdot
.58433 .06893 Mdot
.46054 .01851 Mdot
.40605 .03644 Mdot
.49583 .01593 Mdot
.4221 .06154 Mdot
.46837 .06901 Mdot
.52534 .00102 Mdot
.55481 .04633 Mdot
.46729 .02783 Mdot
.52467 .0681 Mdot
.58645 .03967 Mdot
.43971 .06715 Mdot
.40212 .0449 Mdot
.57917 .04864 Mdot
.59606 .00846 Mdot
.48334 .03271 Mdot
.57396 .02108 Mdot
.41497 .03787 Mdot
.44862 .02006 Mdot
.46016 .0657 Mdot
.58133 .0664 Mdot
.53549 .07176 Mdot
.59488 .02673 Mdot
.49578 .00461 Mdot
.59276 .05599 Mdot
.51661 .03013 Mdot
.5967 .04752 Mdot
.43327 .07159 Mdot
.42274 .02644 Mdot
.4183 .03373 Mdot
.57412 .00638 Mdot
.55814 .04219 Mdot
.5928 .01415 Mdot
.42265 .0446 Mdot
.59792 .06159 Mdot
.52686 .03999 Mdot
.40515 .0056 Mdot
.41026 .00986 Mdot
.40845 .03224 Mdot
.57699 .01243 Mdot
.58571 .0058 Mdot
.55869 .05287 Mdot
.41159 .07358 Mdot
.40056 .01068 Mdot
.41879 .05943 Mdot
.57791 .04024 Mdot
.42087 .072 Mdot
.45105 .00024 Mdot
.41572 .0664 Mdot
.44079 .06455 Mdot
.40727 .03415 Mdot
.4638 .05211 Mdot
.42155 .02835 Mdot
.5051 .07341 Mdot
.40997 .02893 Mdot
.50455 .06273 Mdot
.59118 .04367 Mdot
.52663 .02249 Mdot
.5703 .04583 Mdot
.47559 .02225 Mdot
.55458 .0536 Mdot
.4348 .03187 Mdot
.54732 .01945 Mdot
.571 .05392 Mdot
.52576 .06526 Mdot
.4659 .05468 Mdot
.5158 .03632 Mdot
.56135 .06611 Mdot
.52462 .06682 Mdot
.43472 .04362 Mdot
.55432 .02099 Mdot
.55913 .02137 Mdot
.59973 .04155 Mdot
.52433 .06366 Mdot
.45242 .02211 Mdot
.55333 .00974 Mdot
.52665 .03101 Mdot
.48744 .02923 Mdot
.41086 .06885 Mdot
.52609 .03728 Mdot
.48624 .00203 Mdot
.49137 .06782 Mdot
.53192 .05521 Mdot
.53224 .04645 Mdot
.53219 .01366 Mdot
.4079 .05695 Mdot
.47977 .06571 Mdot
.45457 .04721 Mdot
.55312 .0347 Mdot
.56713 .01798 Mdot
.54226 .04001 Mdot
.44104 .05487 Mdot
.45602 .03797 Mdot
.54968 .06121 Mdot
.5241 .05693 Mdot
.41744 .01476 Mdot
.59191 .04327 Mdot
.40954 .03197 Mdot
.51213 .05172 Mdot
.55497 .05893 Mdot
.55901 .01703 Mdot
.58784 .04094 Mdot
.41675 .05118 Mdot
.5468 .06024 Mdot
.56074 .01321 Mdot
.59712 .07319 Mdot
.43664 .03045 Mdot
.57968 .05843 Mdot
.44473 .06134 Mdot
.57014 .02645 Mdot
.5326 .00962 Mdot
.41517 .04169 Mdot
.57359 .06675 Mdot
.42732 .00074 Mdot
.55683 .01557 Mdot
.48053 .01467 Mdot
.5961 .00236 Mdot
.4834 .01565 Mdot
.55946 .04607 Mdot
.50372 .03139 Mdot
.51472 .0589 Mdot
.53359 .00493 Mdot
.58212 .04928 Mdot
.51842 .03741 Mdot
.40854 .0567 Mdot
.49109 .03666 Mdot
.45171 .04113 Mdot
.41057 .02199 Mdot
.45561 .03877 Mdot
.52717 .00634 Mdot
.49615 .06686 Mdot
.42344 .04912 Mdot
.58143 .00796 Mdot
.48986 .04419 Mdot
.59931 .03284 Mdot
.57144 .00678 Mdot
.59077 .05031 Mdot
.48034 .04428 Mdot
.53906 .00918 Mdot
.46977 .02229 Mdot
.48345 .04458 Mdot
.54261 .01595 Mdot
.5873 .05188 Mdot
.51917 .04099 Mdot
.40587 .04392 Mdot
.42931 .07096 Mdot
.40656 .01108 Mdot
.45788 .06418 Mdot
.4158 .03493 Mdot
.57753 .0199 Mdot
.47674 .02575 Mdot
.50776 .07177 Mdot
.59328 .05534 Mdot
.56515 .05582 Mdot
.40599 .00346 Mdot
.44599 .01483 Mdot
.40012 .0337 Mdot
.41668 .01803 Mdot
.59355 .02262 Mdot
.5588 .02801 Mdot
.57776 .06186 Mdot
.58127 .00812 Mdot
.50102 .0361 Mdot
.47351 .01052 Mdot
.50774 .05493 Mdot
.50835 .02886 Mdot
.50175 .05147 Mdot
.46237 .01403 Mdot
.50163 .01777 Mdot
.44569 .07017 Mdot
.50808 .06931 Mdot
.48689 .04215 Mdot
.53032 .00745 Mdot
.50562 .03403 Mdot
.4293 .04551 Mdot
.43212 .02352 Mdot
.52157 .06474 Mdot
.52376 .06882 Mdot
.41982 .01327 Mdot
.4614 .05478 Mdot
.51818 .06967 Mdot
.41571 .05878 Mdot
.4101 .00036 Mdot
.52882 .01663 Mdot
.47978 .06708 Mdot
.4232 .05676 Mdot
.45047 .02157 Mdot
.59108 .03325 Mdot
.52891 .03099 Mdot
.46732 .03859 Mdot
.50909 .01771 Mdot
.40592 .05797 Mdot
.59091 .02221 Mdot
.59021 .07336 Mdot
.58081 .02184 Mdot
.46139 .05673 Mdot
.50103 .02893 Mdot
.4382 .07413 Mdot
.45056 .00736 Mdot
.44711 .04089 Mdot
.52165 .05054 Mdot
.57979 .00229 Mdot
.41256 .03283 Mdot
.57387 .01848 Mdot
.42165 .01062 Mdot
.58366 .01929 Mdot
.44084 .06294 Mdot
.52227 .03673 Mdot
.53981 .03401 Mdot
.48407 .03676 Mdot
.48925 .02665 Mdot
.43696 .07004 Mdot
.56759 .05027 Mdot
.45716 .06775 Mdot
.55503 .01745 Mdot
.48329 .04927 Mdot
.53338 .00683 Mdot
.49963 .02997 Mdot
.49254 .01805 Mdot
.57737 .06741 Mdot
.55273 .05821 Mdot
.4933 .03064 Mdot
.46349 .03156 Mdot
.45634 .03476 Mdot
.49589 .05545 Mdot
.59918 .04118 Mdot
.54086 .038 Mdot
.51589 .06608 Mdot
.40748 .03117 Mdot
.41625 .0361 Mdot
.51494 .01311 Mdot
.43889 .04286 Mdot
.56221 .02907 Mdot
.54559 .01222 Mdot
.49873 .07167 Mdot
.48925 .05162 Mdot
.40283 .01623 Mdot
.49007 .01044 Mdot
.46197 .05239 Mdot
.57419 .01853 Mdot
.45448 .02123 Mdot
.55793 .05659 Mdot
.53954 .00811 Mdot
.51904 .01373 Mdot
.57733 .05321 Mdot
.57345 .00151 Mdot
.4786 .0557 Mdot
.4842 .02406 Mdot
.47577 .03947 Mdot
.59413 .01361 Mdot
.4138 .06124 Mdot
.41994 .06924 Mdot
.55932 .04002 Mdot
.46201 .01265 Mdot
.41978 .03191 Mdot
.54297 .07308 Mdot
.44245 .05286 Mdot
.56951 .07157 Mdot
.56385 .07133 Mdot
.48531 .04751 Mdot
.48808 .03185 Mdot
.49118 .0339 Mdot
.47428 .04477 Mdot
.47124 .03882 Mdot
.51496 .00476 Mdot
.40923 .02617 Mdot
.49518 .04702 Mdot
.46626 .02725 Mdot
.45272 .06832 Mdot
.49675 .02985 Mdot
.48887 .07116 Mdot
.41144 .0565 Mdot
.40079 .0393 Mdot
.52026 .0226 Mdot
.52652 .06869 Mdot
.44902 .05794 Mdot
.41156 .06394 Mdot
.4398 .03177 Mdot
.51639 .01692 Mdot
.57353 .00452 Mdot
.46366 .02277 Mdot
.47678 .04884 Mdot
.57479 .02577 Mdot
.46534 .0665 Mdot
.574 .06063 Mdot
.54508 .04391 Mdot
.44748 .06611 Mdot
.49606 .06013 Mdot
.43591 .00217 Mdot
.45627 .02836 Mdot
.51953 .05942 Mdot
.48273 .02384 Mdot
.45586 .03665 Mdot
.40595 .04916 Mdot
.48107 .01088 Mdot
.5406 .05682 Mdot
.50708 .02441 Mdot
.59552 .01291 Mdot
.4596 .03247 Mdot
.49946 .02695 Mdot
.42369 .03029 Mdot
.44319 .07276 Mdot
.50416 .04504 Mdot
.56046 .04892 Mdot
.4483 .00839 Mdot
.55451 .07392 Mdot
.56722 .07167 Mdot
.41391 .0171 Mdot
.46014 .04727 Mdot
.41839 .00418 Mdot
.40054 .0148 Mdot
.51894 .0514 Mdot
.57685 .05867 Mdot
.47575 .05281 Mdot
.47269 .01363 Mdot
.51529 .00389 Mdot
.4244 .00524 Mdot
.56077 .00413 Mdot
.45718 .00773 Mdot
.54686 .0612 Mdot
.59703 .03463 Mdot
.52847 .05702 Mdot
.59649 .01983 Mdot
.40954 .00562 Mdot
.41964 .03532 Mdot
.53379 .02698 Mdot
.54695 .02169 Mdot
.4185 .02309 Mdot
.52255 .01645 Mdot
.45773 .01896 Mdot
.46537 .00872 Mdot
.51086 .03192 Mdot
.46834 .04825 Mdot
.58239 .04907 Mdot
.47184 .02842 Mdot
.57286 .04344 Mdot
.4522 .06726 Mdot
.43907 .01646 Mdot
.50526 .04557 Mdot
.42056 .06753 Mdot
.58271 .02912 Mdot
.56284 .04857 Mdot
.51734 .02041 Mdot
.45197 .01665 Mdot
.449 .04632 Mdot
.46958 .04174 Mdot
.57716 .0179 Mdot
.49673 .07246 Mdot
.52496 .02481 Mdot
.45766 .056 Mdot
.4197 .0534 Mdot
.43709 .06263 Mdot
.43699 .02428 Mdot
.47426 .01406 Mdot
.51966 .00387 Mdot
.42228 .07157 Mdot
.47065 .03171 Mdot
.5527 .02983 Mdot
.49349 .01381 Mdot
.45598 .03153 Mdot
.56853 .06316 Mdot
.59832 .04969 Mdot
.54883 .00976 Mdot
.56123 .06122 Mdot
.51184 .05965 Mdot
.48697 .04717 Mdot
.59218 .05578 Mdot
.46468 .04975 Mdot
.52153 .02407 Mdot
.51198 .01992 Mdot
.42803 .01026 Mdot
.456 .06256 Mdot
.4595 .02126 Mdot
.45768 .01287 Mdot
.51067 .0115 Mdot
.49646 .02581 Mdot
.59883 .02601 Mdot
.40949 .05281 Mdot
.40665 .04439 Mdot
.54481 .00305 Mdot
.48512 .02033 Mdot
.43283 .05729 Mdot
.45709 .01006 Mdot
.57683 .06889 Mdot
.59759 .06297 Mdot
.51914 .05603 Mdot
.48692 .05147 Mdot
.42269 .03022 Mdot
.4881 .02546 Mdot
.4132 .05158 Mdot
.48145 .05523 Mdot
.46839 .04853 Mdot
.59633 .0349 Mdot
.43557 .0654 Mdot
.53924 .02484 Mdot
.45874 .07067 Mdot
.54165 .03604 Mdot
.5396 .01465 Mdot
.45472 .05873 Mdot
.51691 .05859 Mdot
.56663 .03327 Mdot
.50371 .00701 Mdot
.48518 .0522 Mdot
.43532 .03264 Mdot
.48885 .0173 Mdot
.59975 .0414 Mdot
.54961 .06662 Mdot
.54101 .04489 Mdot
.40797 .03059 Mdot
.40142 .03025 Mdot
.55324 .04602 Mdot
.48451 .04582 Mdot
.58662 .01276 Mdot
.5808 .03882 Mdot
.50144 .03472 Mdot
.54548 .00617 Mdot
.41259 .01742 Mdot
.54572 .03893 Mdot
.46297 .02496 Mdot
.40471 .0682 Mdot
.45501 .06853 Mdot
.40329 .03795 Mdot
.50176 .02251 Mdot
.51878 .06629 Mdot
.51514 .00975 Mdot
.53798 .02748 Mdot
.4137 .0492 Mdot
.59251 .0213 Mdot
.40112 .03178 Mdot
.44678 .05654 Mdot
.53814 .00683 Mdot
.44207 .0625 Mdot
.48314 .01246 Mdot
.43878 .02455 Mdot
.58138 .06411 Mdot
.52 .03242 Mdot
.46624 .05436 Mdot
.58202 .00495 Mdot
.45253 .00516 Mdot
.58951 .05781 Mdot
.45142 .04754 Mdot
.54273 .00127 Mdot
.51328 .04071 Mdot
.50065 .01293 Mdot
.43014 .02825 Mdot
.46187 .06254 Mdot
.44876 .0383 Mdot
.54187 .03012 Mdot
.58252 .05811 Mdot
.55985 .02517 Mdot
.52999 .05295 Mdot
.57034 .04153 Mdot
.47857 .00541 Mdot
.42761 .04026 Mdot
.5653 .03886 Mdot
.52695 .02733 Mdot
.53516 .01061 Mdot
.46508 .03895 Mdot
.4864 .04647 Mdot
.52322 .00883 Mdot
.50388 .06252 Mdot
.56337 .05782 Mdot
.57389 .00957 Mdot
.59303 .01629 Mdot
.49531 .00416 Mdot
.56542 .05019 Mdot
.53002 .03946 Mdot
.43847 .02285 Mdot
.59486 .02886 Mdot
.57338 .05806 Mdot
.50846 .05655 Mdot
.45017 .04923 Mdot
.40458 .0682 Mdot
.4868 .06558 Mdot
.4307 .05862 Mdot
.49377 .04929 Mdot
.53538 .05446 Mdot
.52835 .07326 Mdot
.40537 .015 Mdot
.48989 .05041 Mdot
.41051 .0603 Mdot
.51651 .06651 Mdot
.50206 .00375 Mdot
.46634 .01728 Mdot
.49747 .00972 Mdot
.57953 .02587 Mdot
.46678 .02526 Mdot
.48576 .05074 Mdot
.5314 .04496 Mdot
.5574 .05164 Mdot
.52603 .02997 Mdot
.46752 .00123 Mdot
.51552 .04383 Mdot
.55101 .00889 Mdot
.41346 .04008 Mdot
.48467 .06578 Mdot
.51599 .03036 Mdot
.50514 .03991 Mdot
.44921 .0051 Mdot
.41938 .06333 Mdot
.51781 .0343 Mdot
.46198 .01168 Mdot
.59178 .00433 Mdot
.59446 .01045 Mdot
.47626 .03467 Mdot
.44345 .00156 Mdot
.4628 .06876 Mdot
.55877 .00995 Mdot
.54681 .0384 Mdot
.45363 .04421 Mdot
.4976 .0333 Mdot
.43425 .05504 Mdot
.57979 .07317 Mdot
.57228 .04336 Mdot
.58801 .06884 Mdot
.57782 .03291 Mdot
.51174 .03417 Mdot
.53437 .03135 Mdot
.44894 .03958 Mdot
.5756 .0214 Mdot
.50213 .00118 Mdot
.52196 .05135 Mdot
.40453 .04204 Mdot
.48771 .07048 Mdot
.42474 .04303 Mdot
.51543 .02712 Mdot
.43674 .04836 Mdot
.53761 .06838 Mdot
.52499 .01419 Mdot
.40324 .03703 Mdot
.47605 .04878 Mdot
.42765 .01564 Mdot
.57392 .0476 Mdot
.50569 .03845 Mdot
.56938 .00556 Mdot
.41798 .04213 Mdot
.54464 .03669 Mdot
.50255 .01501 Mdot
.50791 .0625 Mdot
.56493 .0208 Mdot
.58291 .04831 Mdot
.56169 .05793 Mdot
.50687 .0737 Mdot
.53404 .0423 Mdot
.53295 .0261 Mdot
.42835 .00385 Mdot
.56356 .02054 Mdot
.41037 .03588 Mdot
.41892 .05801 Mdot
.50783 .02087 Mdot
.51101 .06967 Mdot
.5429 7e-05 Mdot
.5281 .02136 Mdot
.58121 .0163 Mdot
.42124 .02183 Mdot
.44717 .04817 Mdot
.48829 .0699 Mdot
.41882 .04432 Mdot
.52472 .04936 Mdot
.40844 .00844 Mdot
.5058 .06552 Mdot
.50061 .06174 Mdot
.59479 .07001 Mdot
.55772 .06167 Mdot
.46669 .04864 Mdot
.57651 .04537 Mdot
.44545 .02681 Mdot
.52934 .07137 Mdot
.55716 .03108 Mdot
.51052 .02704 Mdot
.43244 .05588 Mdot
.50208 .0186 Mdot
.52664 .06453 Mdot
.40147 .03103 Mdot
.53185 .06869 Mdot
.44375 .04352 Mdot
.46517 .02004 Mdot
.46724 .07232 Mdot
.41972 .06739 Mdot
.53791 .00095 Mdot
.46255 .03631 Mdot
.42738 .04807 Mdot
.43011 .05459 Mdot
.5253 .02947 Mdot
.50347 .06423 Mdot
.52384 .0726 Mdot
.57162 .0697 Mdot
.48008 .02908 Mdot
.50645 .04966 Mdot
.41284 .03093 Mdot
.48674 .05643 Mdot
.47494 .02998 Mdot
.42418 .02012 Mdot
.44755 .05607 Mdot
.59407 .03969 Mdot
.52225 .02661 Mdot
.4906 .04963 Mdot
.59841 .02817 Mdot
.51898 .05409 Mdot
.51833 .07326 Mdot
.41253 .00443 Mdot
.50549 .04233 Mdot
.5258 .02216 Mdot
.43055 .01235 Mdot
.50161 .00204 Mdot
.583 .03045 Mdot
.50754 .03651 Mdot
.46075 .00384 Mdot
.41694 .06105 Mdot
.46234 .04983 Mdot
.49796 .00696 Mdot
.54401 .05074 Mdot
.48542 .00254 Mdot
.43852 .00841 Mdot
.55962 .05454 Mdot
.40797 .07023 Mdot
.45801 .0525 Mdot
.42497 .03978 Mdot
.55047 .01599 Mdot
.56422 .03594 Mdot
.53353 .0291 Mdot
.50189 .06027 Mdot
.43557 .02214 Mdot
.55788 .00953 Mdot
.55015 .0196 Mdot
.51936 .00111 Mdot
.59053 .03922 Mdot
.51138 .00505 Mdot
.53252 .06088 Mdot
.48641 .03943 Mdot
.58205 .04489 Mdot
.52219 .00349 Mdot
.44852 .01579 Mdot
.4203 .01739 Mdot
.41294 .06782 Mdot
.46242 .00786 Mdot
.46279 .04822 Mdot
.54306 .00675 Mdot
.47226 .009 Mdot
.43168 .0017 Mdot
.53975 .02228 Mdot
.54527 .03643 Mdot
.5577 .05155 Mdot
.42308 .03293 Mdot
.50918 .03576 Mdot
.40278 .01555 Mdot
.49624 .0421 Mdot
.54036 .00769 Mdot
.43345 .06805 Mdot
.5973 .00094 Mdot
.56118 .05905 Mdot
.56562 .0734 Mdot
.42144 .03677 Mdot
.42035 .03697 Mdot
.46373 .05938 Mdot
.59727 .00404 Mdot
.55455 .02362 Mdot
.59448 .06266 Mdot
.45831 .05568 Mdot
.45412 .05497 Mdot
.42486 .0618 Mdot
.45682 .05404 Mdot
.46368 .00275 Mdot
.49121 .0548 Mdot
.44224 .04015 Mdot
.47086 .01782 Mdot
.57851 .05493 Mdot
.47359 .01378 Mdot
.42396 .03131 Mdot
.47911 .02529 Mdot
.56565 .04979 Mdot
.42498 .04448 Mdot
.54078 .06216 Mdot
.56816 .06461 Mdot
.4771 .05941 Mdot
.47695 .00981 Mdot
.43486 .01926 Mdot
.40609 .06615 Mdot
.45635 .03849 Mdot
.5325 .05237 Mdot
.43239 .00717 Mdot
.4534 .02708 Mdot
.46674 .03154 Mdot
.42841 .05677 Mdot
.52596 .04355 Mdot
.46026 .06632 Mdot
.44886 .05831 Mdot
.5833 .05651 Mdot
.414 .03905 Mdot
.57721 .06452 Mdot
.55765 .00056 Mdot
.4447 .01215 Mdot
.52526 .06755 Mdot
.59131 .05924 Mdot
.45852 .03601 Mdot
.56289 .00247 Mdot
.53255 .06663 Mdot
.50264 .01031 Mdot
.4837 .00832 Mdot
.51933 .02796 Mdot
.46969 .04344 Mdot
.54213 .0376 Mdot
.51204 .04287 Mdot
.49742 .02545 Mdot
.58678 .04948 Mdot
.50612 .04038 Mdot
.52827 .01347 Mdot
.54323 .03791 Mdot
.59571 .02101 Mdot
.44059 .02759 Mdot
.51202 .01269 Mdot
.52126 .07379 Mdot
.44232 .04341 Mdot
.57913 .03619 Mdot
.53028 .00054 Mdot
.48171 .01074 Mdot
.5435 .02522 Mdot
.57559 .04453 Mdot
.41523 .01175 Mdot
.43237 .00662 Mdot
.41952 .06491 Mdot
.59178 .05319 Mdot
.5075 .05222 Mdot
.47052 .05356 Mdot
.46518 .00881 Mdot
.49139 .01737 Mdot
.5349 .00827 Mdot
.40968 .00663 Mdot
.5914 .05721 Mdot
.43409 .03627 Mdot
.57617 .04546 Mdot
.40173 .02965 Mdot
.55666 .05472 Mdot
.40995 .05063 Mdot
.44916 .0025 Mdot
.53943 .07123 Mdot
.58398 .06786 Mdot
.44803 .05386 Mdot
.44908 .05959 Mdot
.43835 .04723 Mdot
.45768 .00238 Mdot
.40426 .01096 Mdot
.48151 .03109 Mdot
.40253 .05547 Mdot
.52485 .05054 Mdot
.59258 .00485 Mdot
.4757 .04804 Mdot
.45316 .00778 Mdot
.49172 .05435 Mdot
.40512 .02808 Mdot
.44263 .06892 Mdot
.56677 .05501 Mdot
.58495 .06654 Mdot
.56251 .04405 Mdot
.50344 .03545 Mdot
.55998 .06274 Mdot
.57859 .05908 Mdot
.5674 .0579 Mdot
.50289 .01104 Mdot
.51424 .05012 Mdot
.41117 .03086 Mdot
.50912 .02204 Mdot
.56854 .0361 Mdot
.54235 .04119 Mdot
.58359 .04372 Mdot
.57984 .0713 Mdot
.48015 .00827 Mdot
.41986 .00856 Mdot
.50156 .02336 Mdot
.45246 .02482 Mdot
.59867 .01232 Mdot
.53822 .04887 Mdot
.5875 .05562 Mdot
.4291 .02683 Mdot
.41896 .01953 Mdot
.48675 .0598 Mdot
.43537 .04997 Mdot
.50691 .06266 Mdot
.55523 .0417 Mdot
.48705 .0541 Mdot
.45367 .01834 Mdot
.43459 .02928 Mdot
.45499 .00603 Mdot
.49637 .05458 Mdot
.46749 .02457 Mdot
.46727 .02775 Mdot
.44853 .00504 Mdot
.58053 .04211 Mdot
.41316 .02924 Mdot
.47362 .05361 Mdot
.45793 .0617 Mdot
.58657 .07367 Mdot
.40427 .04336 Mdot
.55199 .04439 Mdot
.54927 .03733 Mdot
.45562 .06398 Mdot
.48178 .01276 Mdot
.58835 .03623 Mdot
.43324 .00772 Mdot
.40782 .06828 Mdot
.42008 .05264 Mdot
.5342 .01467 Mdot
.56215 .06511 Mdot
.54763 .01516 Mdot
.55788 .02175 Mdot
.59564 .04493 Mdot
.40861 .05858 Mdot
.54002 .05511 Mdot
.52684 .04582 Mdot
.55167 .01888 Mdot
.49359 .0381 Mdot
.54385 .02476 Mdot
.47351 .05962 Mdot
.40965 .01009 Mdot
.51136 .06868 Mdot
.46202 .06909 Mdot
.55347 .04693 Mdot
.46638 .02416 Mdot
.54486 .06251 Mdot
.52636 .04321 Mdot
.41803 .01669 Mdot
.57469 .02433 Mdot
.52443 .05275 Mdot
.43084 .07374 Mdot
.45092 .06729 Mdot
.42119 .06365 Mdot
.53957 .07277 Mdot
.55916 .06872 Mdot
.58609 .02584 Mdot
.49278 .04456 Mdot
.44123 .03749 Mdot
.56642 .00135 Mdot
.42321 .0208 Mdot
.59174 .05118 Mdot
.49877 .04222 Mdot
.5609 .05161 Mdot
.44785 .04909 Mdot
.53972 .06212 Mdot
.50828 .05048 Mdot
.58055 .06757 Mdot
.52219 .02464 Mdot
.48777 .02301 Mdot
.48096 .06131 Mdot
.52134 .02167 Mdot
.45775 .04051 Mdot
.5296 .04465 Mdot
.55897 .07246 Mdot
.5687 .06721 Mdot
.51112 .02337 Mdot
.42899 .00509 Mdot
.40284 .04706 Mdot
.44844 .01168 Mdot
.48065 .02242 Mdot
.56067 .06283 Mdot
.5997 .03527 Mdot
.43933 .04117 Mdot
.54195 .06892 Mdot
.50972 .07068 Mdot
.58297 .07062 Mdot
.54102 .00347 Mdot
.47185 .04725 Mdot
.51203 .07254 Mdot
.46901 .00019 Mdot
.4636 .06086 Mdot
.58836 .05194 Mdot
.50292 .07219 Mdot
.58866 .01668 Mdot
.4636 .03102 Mdot
.44672 .02192 Mdot
.55387 .03451 Mdot
.46374 .02546 Mdot
.41285 .03104 Mdot
.59189 .05238 Mdot
.50082 .03267 Mdot
.52288 .05218 Mdot
.43723 .04597 Mdot
.53452 .00024 Mdot
.5343 .04794 Mdot
.54586 .05773 Mdot
.4707 .01692 Mdot
.49914 .03581 Mdot
.51683 .05657 Mdot
.4354 .01034 Mdot
.50398 .02553 Mdot
.44351 .03213 Mdot
.40316 .06702 Mdot
.52063 .05411 Mdot
.56593 .02106 Mdot
.58611 .05387 Mdot
.43163 .04728 Mdot
.44025 .07031 Mdot
.56093 .03036 Mdot
.54111 .03451 Mdot
.4441 .04795 Mdot
.50571 .02416 Mdot
.54012 .02243 Mdot
.4622 .0662 Mdot
.53696 .02956 Mdot
.54157 .01209 Mdot
.57103 .00851 Mdot
.55546 .03237 Mdot
.5394 .0354 Mdot
.51521 .03623 Mdot
.57847 .00504 Mdot
.57409 .00172 Mdot
.53437 .03125 Mdot
.46838 .05172 Mdot
.59425 .00882 Mdot
.40618 .05968 Mdot
.45729 .05342 Mdot
.46461 .0476 Mdot
.48626 .04491 Mdot
.50915 .01522 Mdot
.54686 .00952 Mdot
.59394 .05316 Mdot
.56839 .00448 Mdot
.41985 .05144 Mdot
.43402 .04739 Mdot
.55146 .07389 Mdot
.43976 .03857 Mdot
.54528 .01421 Mdot
.58247 .05931 Mdot
.48068 .04077 Mdot
.49621 .0144 Mdot
.57153 .02555 Mdot
.54935 .00488 Mdot
.57759 .04655 Mdot
.58096 .0004 Mdot
.55774 .06927 Mdot
.54694 .02717 Mdot
.40628 .06955 Mdot
.50718 .06276 Mdot
.461 .05534 Mdot
.52471 .00345 Mdot
.58032 .01457 Mdot
.4285 .06322 Mdot
.40879 .06318 Mdot
.47915 .05834 Mdot
.4312 .01663 Mdot
.49819 .05794 Mdot
.47346 .02152 Mdot
.55125 .03077 Mdot
.46718 .02613 Mdot
.44407 .04218 Mdot
.40619 .04496 Mdot
.51936 .03873 Mdot
.42586 .03039 Mdot
.49086 .04967 Mdot
.41707 .04137 Mdot
.41171 .0655 Mdot
.58587 .02474 Mdot
.51352 .00756 Mdot
.51241 .00323 Mdot
.56227 .05095 Mdot
.44522 .05125 Mdot
.5182 .00877 Mdot
.43904 .0063 Mdot
.59885 .04421 Mdot
.41317 .05007 Mdot
.50799 .0687 Mdot
.5961 .0087 Mdot
.49628 .0032 Mdot
.41023 .05812 Mdot
.58276 .06981 Mdot
.49783 .05489 Mdot
.42049 .01886 Mdot
.45261 .00364 Mdot
.50229 .01009 Mdot
.41357 .07151 Mdot
.50344 .04004 Mdot
.4004 .02144 Mdot
.59545 .0455 Mdot
.40429 .01274 Mdot
.49917 .0423 Mdot
.59406 .02878 Mdot
.5164 .04665 Mdot
.49623 .04805 Mdot
.49591 .02779 Mdot
.44363 .04441 Mdot
.59362 .01771 Mdot
.43006 .04707 Mdot
.49018 .05183 Mdot
.42966 .02564 Mdot
.49473 .00632 Mdot
.42537 .0129 Mdot
.59556 .03819 Mdot
.43131 .05828 Mdot
.47916 .0657 Mdot
.53508 .01023 Mdot
.58325 .03791 Mdot
.49145 .03998 Mdot
.58963 .0202 Mdot
.46139 .06707 Mdot
.49944 .04254 Mdot
.43172 .04143 Mdot
.40471 .03621 Mdot
.40636 .02853 Mdot
.40915 .07219 Mdot
.57505 .04441 Mdot
.52999 .00649 Mdot
.43997 .03419 Mdot
.54674 .04275 Mdot
.54852 .06837 Mdot
.55712 .02255 Mdot
.48714 .00131 Mdot
.45767 .05418 Mdot
.45541 .03404 Mdot
.45296 .01796 Mdot
.44906 .00551 Mdot
.44381 .01994 Mdot
.47401 .03526 Mdot
.51382 .01345 Mdot
.43403 .00107 Mdot
.56708 .04487 Mdot
.48551 .00686 Mdot
.40996 .02232 Mdot
.59837 .00556 Mdot
.55229 .0423 Mdot
.54296 .04568 Mdot
.49933 .02434 Mdot
.49391 .04018 Mdot
.45552 .0044 Mdot
.4199 .00492 Mdot
.5417 .06511 Mdot
.58587 .00385 Mdot
.57463 .02025 Mdot
.50036 .07115 Mdot
.56466 .07209 Mdot
.50198 .06559 Mdot
.41237 .02979 Mdot
.55902 .01991 Mdot
.51304 .00545 Mdot
.46511 .0539 Mdot
.45752 .00105 Mdot
.44521 .04898 Mdot
.51581 .0101 Mdot
.45934 .04513 Mdot
.54119 .06402 Mdot
.55899 .04815 Mdot
.57653 .06609 Mdot
.45701 .05672 Mdot
.56415 .0363 Mdot
.49799 .03681 Mdot
.45111 .03085 Mdot
.43288 .05708 Mdot
.5936 .0298 Mdot
.58767 .0081 Mdot
.47778 .0197 Mdot
.52832 .03713 Mdot
.53659 .02984 Mdot
.56933 .06315 Mdot
.56007 .03792 Mdot
.51233 .00643 Mdot
.59591 .00162 Mdot
.41434 .04378 Mdot
.5448 .04493 Mdot
.58147 .06087 Mdot
.5512 .01513 Mdot
.5938 .05277 Mdot
.47342 .0696 Mdot
.46548 .01564 Mdot
.53683 .03976 Mdot
.49615 .02666 Mdot
.57676 .00184 Mdot
.58382 .02023 Mdot
.58085 .00022 Mdot
.56948 .05061 Mdot
.43605 .02945 Mdot
.58801 .06391 Mdot
.48485 .01432 Mdot
.59421 .01113 Mdot
.41143 .01888 Mdot
.52873 .06965 Mdot
.4746 .05329 Mdot
.43259 .043 Mdot
.49784 .05145 Mdot
.44877 .02277 Mdot
.51699 .05124 Mdot
.47929 .04632 Mdot
.48093 .02179 Mdot
.49128 .05658 Mdot
.59608 .00747 Mdot
.49707 .04544 Mdot
.58465 .06275 Mdot
.56833 .04995 Mdot
.51004 .00946 Mdot
.53575 .00696 Mdot
.4122 .03217 Mdot
.48698 .05836 Mdot
.49522 .0551 Mdot
.40769 .01204 Mdot
.41428 .03331 Mdot
.51641 .02963 Mdot
.4182 .02584 Mdot
.41934 .05835 Mdot
.43355 .03725 Mdot
.45101 .00839 Mdot
.52351 .02779 Mdot
.51526 .00143 Mdot
.5113 .06979 Mdot
.42828 .01724 Mdot
.41609 .01469 Mdot
.4206 .0052 Mdot
.40181 .05554 Mdot
.50419 .04974 Mdot
.58361 .0297 Mdot
.48484 .06556 Mdot
.55005 .06661 Mdot
.43384 .05716 Mdot
.42655 .03882 Mdot
.51857 .05573 Mdot
.51525 .0432 Mdot
.49029 .03849 Mdot
.49916 .02851 Mdot
.4697 .03329 Mdot
.49735 .04713 Mdot
.56551 .05772 Mdot
.51375 .01743 Mdot
.48066 .06632 Mdot
.56369 .02499 Mdot
.44683 .00916 Mdot
.53715 .06033 Mdot
.52825 .02759 Mdot
.4219 .01713 Mdot
.43796 .06327 Mdot
.52274 .06279 Mdot
.56827 .02998 Mdot
.42539 .01565 Mdot
.40276 .04643 Mdot
.51164 .07238 Mdot
.52209 .05427 Mdot
.54795 .0474 Mdot
.47526 .04511 Mdot
.4108 .06123 Mdot
.54701 .01752 Mdot
.5889 .0441 Mdot
.50905 .02841 Mdot
.46616 .05547 Mdot
.54078 .0726 Mdot
.44077 .03982 Mdot
.53802 .02617 Mdot
.52913 .0416 Mdot
.41593 .04607 Mdot
.58119 .06837 Mdot
.54067 .00096 Mdot
.57038 .00714 Mdot
.59365 .05761 Mdot
.58148 .03721 Mdot
.48461 .02919 Mdot
.51532 .0559 Mdot
.54383 .03076 Mdot
.47455 .01608 Mdot
.4058 .00459 Mdot
.54542 .04864 Mdot
.58987 .03269 Mdot
.56423 .05444 Mdot
.44921 .03173 Mdot
.59385 .0473 Mdot
.45555 .04829 Mdot
.41237 .01009 Mdot
.57094 .0191 Mdot
.49704 .02836 Mdot
.42712 .0625 Mdot
.4225 .01229 Mdot
.42132 .05791 Mdot
.47708 .03781 Mdot
.43145 .02522 Mdot
.51285 .05753 Mdot
.58224 .06765 Mdot
.519 .01023 Mdot
.52669 .01936 Mdot
.50663 .00014 Mdot
.55574 .00026 Mdot
.40959 .04594 Mdot
.52862 .01193 Mdot
.58709 .03366 Mdot
.50731 .02818 Mdot
.51002 .07001 Mdot
.47586 .00296 Mdot
.59717 .01248 Mdot
.49362 .00947 Mdot
.47817 .00224 Mdot
.56693 .06427 Mdot
.57154 .0021 Mdot
.41119 .06401 Mdot
.56195 .03033 Mdot
.48257 .05208 Mdot
.57485 .07083 Mdot
.57526 .0239 Mdot
.46483 .00082 Mdot
.4994 .02094 Mdot
.46767 .06251 Mdot
.40578 .01147 Mdot
.5895 .06027 Mdot
.43885 .02136 Mdot
.41796 .05816 Mdot
.42766 .03152 Mdot
.45601 .02784 Mdot
.54509 .05361 Mdot
.48116 .03117 Mdot
.56983 .02971 Mdot
.41633 .03034 Mdot
.47043 .00877 Mdot
.54866 .042 Mdot
.46465 .07147 Mdot
.55917 .0559 Mdot
.4258 .0501 Mdot
.54121 .0719 Mdot
.59815 .01858 Mdot
.4852 .04407 Mdot
.45306 .03913 Mdot
.40403 .0129 Mdot
.48323 .00942 Mdot
.58771 .05672 Mdot
.4128 .00065 Mdot
.43905 .01472 Mdot
.54815 .00335 Mdot
.47988 .03298 Mdot
.52235 .02741 Mdot
.53867 .03524 Mdot
.5242 .00883 Mdot
.45348 .06534 Mdot
.47114 .04386 Mdot
.44944 .05244 Mdot
.58791 .03444 Mdot
.46174 .06989 Mdot
.57511 .03379 Mdot
.42269 .05517 Mdot
.42697 .03044 Mdot
.54281 .02219 Mdot
.50462 .00303 Mdot
.40414 .06111 Mdot
.58042 .06836 Mdot
.55066 .06993 Mdot
.50928 .0245 Mdot
.50122 .01748 Mdot
.52137 .06423 Mdot
.43949 .02176 Mdot
.54625 .03044 Mdot
.4168 .04075 Mdot
.51929 0 Mdot
.47399 .01856 Mdot
.41467 .07114 Mdot
.46984 .03162 Mdot
.43425 .00278 Mdot
.51918 .03585 Mdot
.52497 .05244 Mdot
.41796 .01837 Mdot
.4036 .06238 Mdot
.57847 .07077 Mdot
.45735 .03194 Mdot
.56168 .03002 Mdot
.53807 .03194 Mdot
.48769 .01146 Mdot
.5234 .03496 Mdot
.41785 .05401 Mdot
.48915 .03218 Mdot
.49867 .01815 Mdot
.56419 .0539 Mdot
.48071 .07395 Mdot
.56059 .06569 Mdot
.50223 .00317 Mdot
.50324 .03375 Mdot
.54056 .04732 Mdot
.56517 .00181 Mdot
.45287 .03586 Mdot
.44177 .04102 Mdot
.43502 .05602 Mdot
.55262 .00884 Mdot
.53635 .03786 Mdot
.58843 .0291 Mdot
.45565 .03808 Mdot
.42784 .03758 Mdot
.55341 .03491 Mdot
.52461 .00383 Mdot
.41286 .06175 Mdot
.55944 .00202 Mdot
.55999 .0259 Mdot
.51767 .03517 Mdot
.52497 .04405 Mdot
.56505 .02633 Mdot
.58862 .00618 Mdot
.57662 .0714 Mdot
.53297 .04227 Mdot
.54878 .03382 Mdot
.57956 .00736 Mdot
.42417 .02999 Mdot
.5667 .01977 Mdot
.46473 .02797 Mdot
.40671 .06804 Mdot
.54707 .06697 Mdot
.48174 .02399 Mdot
.58202 .04064 Mdot
.49312 .01781 Mdot
.4054 .04341 Mdot
.56015 .04971 Mdot
.45662 .00959 Mdot
.58059 .04234 Mdot
.43245 .05376 Mdot
.41389 .02257 Mdot
.56772 .02579 Mdot
.40719 .0287 Mdot
.42065 .03298 Mdot
.52545 .0047 Mdot
.43863 .0665 Mdot
.43233 .06106 Mdot
.43323 .02309 Mdot
.47219 .01135 Mdot
.57661 .0135 Mdot
.49159 .04317 Mdot
.54415 .03391 Mdot
.4777 .0206 Mdot
.57644 .00812 Mdot
.47051 .06607 Mdot
.55579 .04931 Mdot
.54506 .06136 Mdot
.51716 .05697 Mdot
.51272 .0003 Mdot
.48393 .03388 Mdot
.44054 .06312 Mdot
.50732 .02037 Mdot
.54895 .01995 Mdot
.56317 .06063 Mdot
.47125 .07351 Mdot
.58673 .05251 Mdot
.40074 .00745 Mdot
.43094 .0032 Mdot
.45568 .02025 Mdot
.51379 .02039 Mdot
.54296 .01994 Mdot
.42986 .06068 Mdot
.50242 .03099 Mdot
.52254 .0403 Mdot
.55347 .01104 Mdot
.55937 .05384 Mdot
.48222 .0117 Mdot
.57264 .00133 Mdot
.48149 .00425 Mdot
.54169 .0723 Mdot
.42581 .05817 Mdot
.42791 .0519 Mdot
.48285 .03822 Mdot
.59805 .06539 Mdot
.58043 .00723 Mdot
.47552 .02509 Mdot
.42696 .07035 Mdot
.51615 .04541 Mdot
.54474 .05866 Mdot
.54351 .04408 Mdot
.46325 .05441 Mdot
.40181 .04595 Mdot
.43745 .0704 Mdot
.57391 .06821 Mdot
.55459 .03218 Mdot
.57585 .00282 Mdot
.57416 .02495 Mdot
.50034 .05189 Mdot
.5472 .02876 Mdot
.58419 .00648 Mdot
.40246 .04427 Mdot
.44068 .03657 Mdot
.5392 .06402 Mdot
.43887 .06478 Mdot
.50176 .06778 Mdot
.46496 .07074 Mdot
.54716 .0356 Mdot
.48911 .06793 Mdot
.573 .01065 Mdot
.58877 .01603 Mdot
.42581 .05606 Mdot
.40458 .00955 Mdot
.42335 .01179 Mdot
.5639 .04715 Mdot
.48415 .02193 Mdot
.52504 .05653 Mdot
.58239 .02831 Mdot
.46008 .05995 Mdot
.43523 .06688 Mdot
.57097 .06619 Mdot
.46223 .05622 Mdot
.5822 .05016 Mdot
.43642 .00016 Mdot
.57762 .04061 Mdot
.41307 .06253 Mdot
.41372 .06763 Mdot
.52892 .0406 Mdot
.48868 .0111 Mdot
.54653 .01229 Mdot
.42861 .02531 Mdot
.51131 .01958 Mdot
.45764 .03329 Mdot
.44908 .03752 Mdot
.47544 .0573 Mdot
.41266 .03736 Mdot
.49782 .01669 Mdot
.59959 .04899 Mdot
.4841 .02323 Mdot
.47067 .00839 Mdot
.59542 .01213 Mdot
.52413 .07026 Mdot
.56681 .06098 Mdot
.41283 .05069 Mdot
.50917 .02769 Mdot
.56375 .01317 Mdot
.43373 .04456 Mdot
.55109 .04998 Mdot
.53591 .02786 Mdot
.55149 .00099 Mdot
.45181 .00463 Mdot
.48083 .06677 Mdot
.4564 .06666 Mdot
.55669 .07067 Mdot
.48959 .00568 Mdot
.54386 .01998 Mdot
.58042 .05215 Mdot
.58012 .00681 Mdot
.54668 .0076 Mdot
.42903 .031 Mdot
.41077 .0539 Mdot
.47754 .03001 Mdot
.55895 .04927 Mdot
.59671 .0374 Mdot
.50256 .05677 Mdot
.44002 .0409 Mdot
.41297 .05109 Mdot
.49615 .02092 Mdot
.43255 .0731 Mdot
.51604 .01411 Mdot
.48587 .0655 Mdot
.487 .05728 Mdot
.4751 .0116 Mdot
.40947 .02728 Mdot
.51614 .0365 Mdot
.41275 .06404 Mdot
.41359 .05389 Mdot
.57274 .02314 Mdot
.40062 .0028 Mdot
.47658 .00222 Mdot
.56807 .00386 Mdot
.56054 .06227 Mdot
.4822 .01252 Mdot
.47354 .00499 Mdot
.4071 .00092 Mdot
.46407 .05187 Mdot
.49095 .03859 Mdot
.45132 .062 Mdot
.47737 .05886 Mdot
.47858 .03886 Mdot
.47675 .05606 Mdot
.402 .03664 Mdot
.50868 .0522 Mdot
.44146 .04854 Mdot
.42648 .03968 Mdot
.56792 .04355 Mdot
.41939 .03875 Mdot
.50384 .06584 Mdot
.52843 .00016 Mdot
.45252 .00384 Mdot
.45107 .01546 Mdot
.57394 .03915 Mdot
.57432 .03356 Mdot
.57194 .0025 Mdot
.46564 .05553 Mdot
.53048 .02813 Mdot
.43916 .01585 Mdot
.56256 .05874 Mdot
.41977 .05126 Mdot
.45872 .06706 Mdot
.49134 .05109 Mdot
.40619 .06322 Mdot
.44027 .03563 Mdot
.43225 .02407 Mdot
.46594 .00207 Mdot
.46032 .02157 Mdot
.4003 .0207 Mdot
.52984 .0676 Mdot
.56115 .00486 Mdot
.56727 .00887 Mdot
.54138 .02776 Mdot
.50856 .01597 Mdot
.45004 .05084 Mdot
.50236 .02692 Mdot
.40977 .01521 Mdot
.47011 .00285 Mdot
.54383 .01314 Mdot
.40979 .05545 Mdot
.54353 .0666 Mdot
.47995 .06201 Mdot
.58238 .06174 Mdot
.51268 .05314 Mdot
.441 .03398 Mdot
.40412 .03717 Mdot
.59096 .05731 Mdot
.50176 .01025 Mdot
.58118 .0421 Mdot
.43165 .0074 Mdot
.43735 .02896 Mdot
.42186 .02611 Mdot
.49383 .03653 Mdot
.54191 .03827 Mdot
.51145 .04895 Mdot
.42923 .05929 Mdot
.47045 .01497 Mdot
.4251 .02212 Mdot
.47949 .03182 Mdot
.52334 .01187 Mdot
.4983 .06388 Mdot
.49169 .00448 Mdot
.46095 .03492 Mdot
.46983 .05253 Mdot
.56712 .07256 Mdot
.52792 .01426 Mdot
.45567 .02361 Mdot
.49869 .02913 Mdot
.58522 .00865 Mdot
.47359 .00701 Mdot
.50573 .05099 Mdot
.55024 .0693 Mdot
.40743 .06127 Mdot
.45855 .06482 Mdot
.54648 .02636 Mdot
.58873 .01229 Mdot
.57936 .02796 Mdot
.46081 .07219 Mdot
.52369 .00435 Mdot
.56212 .04306 Mdot
.53847 .06987 Mdot
.48853 .03605 Mdot
.43273 .01888 Mdot
.53829 .04092 Mdot
.42531 .03177 Mdot
.47974 .05026 Mdot
.47883 .00541 Mdot
.49101 .03797 Mdot
.49947 .05161 Mdot
.4302 .03994 Mdot
.57578 .04726 Mdot
.46808 .07104 Mdot
.43731 .05156 Mdot
.57954 .03499 Mdot
.40458 .03268 Mdot
.44125 .06824 Mdot
.57927 .00092 Mdot
.56152 .01798 Mdot
.50045 .06967 Mdot
.47051 .05417 Mdot
.40098 .01806 Mdot
.44031 .01424 Mdot
.4252 .04496 Mdot
.57223 .01736 Mdot
.58788 .06757 Mdot
.59269 .05654 Mdot
.5833 .03489 Mdot
.55144 .06247 Mdot
.40403 .03397 Mdot
.58992 .04449 Mdot
.50358 .03846 Mdot
.51941 .06448 Mdot
.5026 .0204 Mdot
.4791 .05025 Mdot
.4774 .0496 Mdot
.50687 .03288 Mdot
.48952 .05619 Mdot
.51419 .05051 Mdot
.50622 .02131 Mdot
.56275 .0622 Mdot
.50219 .06151 Mdot
.57283 .01771 Mdot
.59861 .02305 Mdot
.45342 .02739 Mdot
.49601 .00265 Mdot
.57431 .05131 Mdot
.4186 .02722 Mdot
.46744 .01843 Mdot
.52908 .04519 Mdot
.55325 .04209 Mdot
.42286 .02388 Mdot
.5905 .05405 Mdot
.52067 .03654 Mdot
.41767 .03633 Mdot
.52206 .01349 Mdot
.56426 .00894 Mdot
.42605 .01084 Mdot
.58994 .03179 Mdot
.40745 .05779 Mdot
.5225 .01336 Mdot
.47837 .0126 Mdot
.56925 .04544 Mdot
.45551 .06288 Mdot
.57874 .06555 Mdot
.53484 .02635 Mdot
.56107 .02922 Mdot
.41278 .01286 Mdot
.59681 .02028 Mdot
.58672 .00202 Mdot
.40687 .06265 Mdot
.57927 .0184 Mdot
.48437 .04929 Mdot
.5009 .0058 Mdot
.51512 .00385 Mdot
.44539 .01708 Mdot
.53637 .01246 Mdot
.51055 .0649 Mdot
.5753 .05741 Mdot
.49777 .05204 Mdot
.57849 .03713 Mdot
.51105 .05002 Mdot
.57162 .04864 Mdot
.53177 .03162 Mdot
.48725 .07351 Mdot
.43087 .02581 Mdot
.57214 .06966 Mdot
.58549 .00873 Mdot
.43576 .05719 Mdot
.47494 .018 Mdot
.46046 .07395 Mdot
.57717 .04013 Mdot
.48198 .03682 Mdot
.46612 .06428 Mdot
.51036 .06235 Mdot
.53435 .03266 Mdot
.42311 .063 Mdot
.50347 .00685 Mdot
.45097 .0675 Mdot
.51799 .07228 Mdot
.41521 .01031 Mdot
.44305 .05427 Mdot
.55474 .01053 Mdot
.46588 .01415 Mdot
.47276 .04787 Mdot
.59976 .02403 Mdot
.56241 .05969 Mdot
.46542 .06554 Mdot
.5393 .07085 Mdot
.56195 .05869 Mdot
.48833 .00335 Mdot
.44396 .06058 Mdot
.47312 .0672 Mdot
.40091 .00631 Mdot
.51838 .05668 Mdot
.53502 .06632 Mdot
.44562 .00881 Mdot
.53526 .04229 Mdot
.48321 .02328 Mdot
.46984 .05091 Mdot
.54391 .0266 Mdot
.5079 .06639 Mdot
.45559 .02325 Mdot
.46394 .0058 Mdot
.58246 .03021 Mdot
.46303 .07366 Mdot
.46408 .0477 Mdot
.528 .00734 Mdot
.41846 .03889 Mdot
.59274 .03921 Mdot
.53525 .01561 Mdot
.5229 .06246 Mdot
.59133 .06318 Mdot
.41501 .07024 Mdot
.53575 .03993 Mdot
.55107 .06444 Mdot
.55329 .00972 Mdot
.48804 .06494 Mdot
.48921 .03618 Mdot
.56004 .0576 Mdot
.47074 .07145 Mdot
.5673 .01839 Mdot
.5355 .05584 Mdot
.44439 .03009 Mdot
.54416 .06683 Mdot
.42939 .03401 Mdot
.40841 .0269 Mdot
.47831 .04373 Mdot
.45513 .01718 Mdot
.59027 .05296 Mdot
.56592 .05517 Mdot
.43023 .06952 Mdot
.49518 .05788 Mdot
.46293 .05114 Mdot
.55968 .00204 Mdot
.41854 .02105 Mdot
.41552 .00938 Mdot
.58915 .06121 Mdot
.4071 .05664 Mdot
.51084 .01748 Mdot
.55198 .03946 Mdot
.52057 .03868 Mdot
.58605 .05845 Mdot
.49034 .04332 Mdot
.49088 .00057 Mdot
.4274 .06635 Mdot
.53119 .07269 Mdot
.40886 .0453 Mdot
.51568 .06331 Mdot
.41971 .05826 Mdot
.50857 .00667 Mdot
.50887 .04078 Mdot
.55659 .04137 Mdot
.5883 .0021 Mdot
.57054 .05708 Mdot
.49797 .03294 Mdot
.47966 .05651 Mdot
.47056 .04075 Mdot
.54847 .05798 Mdot
.4617 .06962 Mdot
.43279 .06884 Mdot
.44199 .01136 Mdot
.52422 .06217 Mdot
.53312 .04474 Mdot
.56763 .0208 Mdot
.54481 .04265 Mdot
.59709 .03788 Mdot
.44685 .00971 Mdot
.51743 .05554 Mdot
.57629 .04312 Mdot
.56896 .07172 Mdot
.51459 .04767 Mdot
.53616 .00288 Mdot
.4726 .03631 Mdot
.41194 .01487 Mdot
.53948 .06573 Mdot
.44431 .06824 Mdot
.59466 .02308 Mdot
.44722 .03035 Mdot
.54781 .01337 Mdot
.5298 .04898 Mdot
.57153 .04442 Mdot
.56084 .05143 Mdot
.45694 .07092 Mdot
.42467 .04855 Mdot
.58435 .03461 Mdot
.41273 .03368 Mdot
.44487 .04305 Mdot
.56842 .03961 Mdot
.45021 .01997 Mdot
.5212 .00926 Mdot
.50239 .00659 Mdot
.59141 .03444 Mdot
.53086 .03634 Mdot
.43057 .05717 Mdot
.47392 .03959 Mdot
.40589 .00862 Mdot
.48958 .00498 Mdot
.59316 .0491 Mdot
.44471 .03609 Mdot
.42474 .00949 Mdot
.5945 .01612 Mdot
.50353 .00024 Mdot
.49211 .00953 Mdot
.51213 .03996 Mdot
.56124 .04735 Mdot
.48156 .05695 Mdot
.48732 .00777 Mdot
.47567 .04833 Mdot
.59774 .00279 Mdot
.48251 .07339 Mdot
.55304 .04087 Mdot
.45777 .0639 Mdot
.55854 .02474 Mdot
.55423 .06366 Mdot
.46643 .01521 Mdot
.44211 .0237 Mdot
.50519 .04202 Mdot
.56055 .04091 Mdot
.41787 .03426 Mdot
.48488 .06675 Mdot
.42012 .03146 Mdot
.40237 .06752 Mdot
.46709 .06476 Mdot
.54461 .00363 Mdot
.50855 .04002 Mdot
.59037 .01413 Mdot
.44212 .02481 Mdot
.54827 .06459 Mdot
.53693 .05695 Mdot
.58772 .02368 Mdot
.51906 .02269 Mdot
.50284 .03109 Mdot
.49894 .06539 Mdot
.50047 .03773 Mdot
.43185 .00063 Mdot
.55586 .03411 Mdot
.5233 .03477 Mdot
.56549 .01998 Mdot
.48118 .00996 Mdot
.41722 .02955 Mdot
.54426 .02718 Mdot
.4295 .00587 Mdot
.4252 .00449 Mdot
.52666 .04894 Mdot
.52626 .01327 Mdot
.42619 .0112 Mdot
.49441 .01264 Mdot
.47034 .05126 Mdot
.57111 .05204 Mdot
.50485 .03129 Mdot
.48992 .04207 Mdot
.48763 .00174 Mdot
.54567 .01489 Mdot
.45813 .07004 Mdot
.52047 .0104 Mdot
.53147 .0211 Mdot
.59421 .07129 Mdot
.50527 .0099 Mdot
.4998 .05865 Mdot
.43494 .0328 Mdot
.52869 .00661 Mdot
.53009 .00151 Mdot
.43877 .0387 Mdot
.44246 .07394 Mdot
.4931 .02381 Mdot
.58433 .0039 Mdot
.57263 .01341 Mdot
.45286 .05696 Mdot
.57842 .01628 Mdot
.54759 .04707 Mdot
.47862 .0318 Mdot
.51265 .01426 Mdot
.54993 .02518 Mdot
.58256 .01275 Mdot
.51116 .06065 Mdot
.5401 .01298 Mdot
.41805 .03684 Mdot
.55577 .00908 Mdot
.44542 .02343 Mdot
.5029 .02628 Mdot
.467 .00714 Mdot
.55531 .05338 Mdot
.58837 .04951 Mdot
.44266 .03911 Mdot
.43844 .02433 Mdot
.4601 .02636 Mdot
.52729 .03785 Mdot
.52 .01338 Mdot
.50923 .00101 Mdot
.56423 .00431 Mdot
.46381 .05175 Mdot
.46132 .0522 Mdot
.59682 .04461 Mdot
.50601 .07298 Mdot
.40845 .06926 Mdot
.46335 .03387 Mdot
.57 .04493 Mdot
.40325 .00751 Mdot
.44272 .00708 Mdot
.48325 .06829 Mdot
.53348 .00607 Mdot
.51902 .06398 Mdot
.46967 .02848 Mdot
.4577 .01179 Mdot
.47285 .05804 Mdot
.55169 .01297 Mdot
.4644 .06294 Mdot
.48834 .05326 Mdot
.4944 .01802 Mdot
.48509 .04574 Mdot
.45169 .01094 Mdot
.40183 .05162 Mdot
.5182 .00487 Mdot
.48281 .0618 Mdot
.44854 .05055 Mdot
.42511 .05001 Mdot
.57569 .06668 Mdot
.47342 .03705 Mdot
.51128 .00374 Mdot
.58508 .05795 Mdot
.41688 .05989 Mdot
.5 .01221 Mdot
.56519 .04895 Mdot
.49816 .03476 Mdot
.44699 .04408 Mdot
.41535 .04712 Mdot
.59845 .06769 Mdot
.59024 .07127 Mdot
.42277 .00101 Mdot
.51682 .03423 Mdot
.51149 .07143 Mdot
.53173 .05044 Mdot
.49461 .01155 Mdot
.43174 .03823 Mdot
.52942 .03676 Mdot
.53358 .00347 Mdot
.48243 .06685 Mdot
.51822 .03052 Mdot
.48398 .07332 Mdot
.52798 .03341 Mdot
.46121 .07231 Mdot
.41117 .07335 Mdot
.54973 .00088 Mdot
.47943 .02291 Mdot
.45512 .0635 Mdot
.44769 .05885 Mdot
.5257 .02674 Mdot
.51412 .05537 Mdot
.44327 .03405 Mdot
.59589 .02486 Mdot
.55929 .0349 Mdot
.46791 .06561 Mdot
.49808 .03675 Mdot
.45674 .06643 Mdot
.54835 .03587 Mdot
.57731 .04352 Mdot
.49323 .04653 Mdot
.52962 .05884 Mdot
.56753 .0198 Mdot
.4155 .00347 Mdot
.52426 .05991 Mdot
.4196 .05277 Mdot
.56496 .02501 Mdot
.55169 .06132 Mdot
.46688 .06243 Mdot
.49495 .06905 Mdot
.51853 .02656 Mdot
.51764 .02553 Mdot
.4253 .0542 Mdot
.58802 .04085 Mdot
.45777 .0344 Mdot
.57252 .03738 Mdot
.53351 .04866 Mdot
.55292 .05878 Mdot
.56855 .02364 Mdot
.40122 .07162 Mdot
.50167 .03538 Mdot
.50627 .00256 Mdot
.58314 .00881 Mdot
.58863 .0512 Mdot
.55784 .02878 Mdot
.40061 .01035 Mdot
.50007 .06854 Mdot
.42809 .04713 Mdot
.56656 .01989 Mdot
.47517 .06251 Mdot
.59801 .07041 Mdot
.47395 .06506 Mdot
.49634 .03503 Mdot
.56768 .0625 Mdot
.5132 .02622 Mdot
.57904 .0113 Mdot
.55535 .07161 Mdot
.57843 .00095 Mdot
.45528 .00306 Mdot
.55034 .02799 Mdot
.48872 .05734 Mdot
.47516 .03964 Mdot
.49071 .06109 Mdot
.40121 .04874 Mdot
.59438 .02606 Mdot
.43353 .06041 Mdot
.48118 .074 Mdot
.45449 .04911 Mdot
.52583 .00239 Mdot
.47606 .04816 Mdot
.47055 .07349 Mdot
.52573 .02017 Mdot
.58183 .01615 Mdot
.45056 .05469 Mdot
.49112 .02922 Mdot
.44935 .00595 Mdot
.49674 .00317 Mdot
.41582 .0197 Mdot
.41556 .00333 Mdot
.56133 .04475 Mdot
.48974 .00094 Mdot
.48526 .07076 Mdot
.41919 .00161 Mdot
.55953 .05059 Mdot
.43736 .05963 Mdot
.50897 .07006 Mdot
.54624 .0304 Mdot
.45962 .06411 Mdot
.4495 .02723 Mdot
.4438 .04441 Mdot
.43393 .0239 Mdot
.48248 .07382 Mdot
.5442 .02296 Mdot
.59722 .00306 Mdot
.52501 .02135 Mdot
.43768 .02664 Mdot
.48765 .03589 Mdot
.52871 .03074 Mdot
.54141 .00549 Mdot
.46909 .04079 Mdot
.49191 .05242 Mdot
.42529 .07054 Mdot
.45798 .02851 Mdot
.54281 .07088 Mdot
.51378 .00555 Mdot
.5456 .06782 Mdot
.58877 .05837 Mdot
.50792 .04118 Mdot
.50112 .02248 Mdot
.57921 .01044 Mdot
.55971 .017 Mdot
.51012 .04382 Mdot
.46779 .03874 Mdot
.48483 .04745 Mdot
.40981 .01023 Mdot
.54202 .05073 Mdot
.49603 .00468 Mdot
.59642 .05708 Mdot
.50726 .02047 Mdot
.48851 .0159 Mdot
.40614 .07216 Mdot
.5093 .00546 Mdot
.44644 .05516 Mdot
.59918 .0358 Mdot
.57865 .01642 Mdot
.51435 .06252 Mdot
.56884 .00619 Mdot
.57233 .01179 Mdot
.47281 .00151 Mdot
.57591 .02887 Mdot
.56555 .0552 Mdot
.48741 .01297 Mdot
.5594 .05721 Mdot
.57811 .00751 Mdot
.51296 .00205 Mdot
.57893 .04588 Mdot
.53432 .0598 Mdot
.46457 .05752 Mdot
.56548 .05361 Mdot
.49224 .04573 Mdot
.49267 .0521 Mdot
.51633 .01686 Mdot
.52713 .07106 Mdot
.42892 .00388 Mdot
.56773 .01386 Mdot
.45082 .07053 Mdot
.45476 .01181 Mdot
.47189 .02466 Mdot
.52045 .02617 Mdot
.40731 .0413 Mdot
.55497 .04673 Mdot
.51507 .06974 Mdot
.46229 .06879 Mdot
.59875 .05288 Mdot
.53516 .07189 Mdot
.56982 .049 Mdot
.56744 .05804 Mdot
.51901 .05263 Mdot
.51267 .04623 Mdot
.44712 .02797 Mdot
.59223 .02005 Mdot
.4398 .06084 Mdot
.43726 .04749 Mdot
.52473 .06526 Mdot
.57497 .05286 Mdot
.52598 .01238 Mdot
.43981 .05513 Mdot
.55616 .03755 Mdot
.47237 .07126 Mdot
.43715 .05908 Mdot
.5597 .02503 Mdot
.59004 .03111 Mdot
.56747 .00498 Mdot
.55023 .04444 Mdot
.53021 .03166 Mdot
.42551 .05334 Mdot
.55524 .05296 Mdot
.49952 .04095 Mdot
.51543 .07199 Mdot
.54336 .00341 Mdot
.44306 .00073 Mdot
.50621 .01849 Mdot
.48336 .04986 Mdot
.51617 .06154 Mdot
.51589 .04488 Mdot
.56594 .01711 Mdot
.58568 .01322 Mdot
.54043 .03793 Mdot
.43043 .03443 Mdot
.44091 .07114 Mdot
.515 .0366 Mdot
.49754 .06774 Mdot
.47194 .03587 Mdot
.59134 .04925 Mdot
.58858 .06017 Mdot
.47516 .06187 Mdot
.47269 .01529 Mdot
.50923 .04477 Mdot
.48702 .00207 Mdot
.5688 .00683 Mdot
.45658 .0418 Mdot
.52789 .00985 Mdot
.54158 .00521 Mdot
.43035 .01628 Mdot
.46964 .0435 Mdot
.43901 .04119 Mdot
.48106 .0575 Mdot
.56385 .05348 Mdot
.40837 .04221 Mdot
.45462 .00871 Mdot
.52135 .04014 Mdot
.48582 .00188 Mdot
.46476 .0725 Mdot
.55793 .06619 Mdot
.52318 .06729 Mdot
.52759 .04992 Mdot
.45354 .02379 Mdot
.48858 .00873 Mdot
.57248 .04046 Mdot
.52473 .02941 Mdot
.56411 .07241 Mdot
.47011 .0207 Mdot
.44276 .03227 Mdot
.58429 .01882 Mdot
.578 .03394 Mdot
.42636 .02679 Mdot
.45481 .04081 Mdot
.49877 .05104 Mdot
.40128 .01702 Mdot
.41019 .04231 Mdot
.4288 .05072 Mdot
.48546 .0129 Mdot
.46469 .05248 Mdot
.41535 .06636 Mdot
.42193 .0202 Mdot
.43106 .04754 Mdot
.44393 .06043 Mdot
.4047 .02074 Mdot
.58911 .01962 Mdot
.50593 .04387 Mdot
.58784 .00261 Mdot
.49574 .00155 Mdot
.55904 .02605 Mdot
.41028 .06282 Mdot
.49435 .04773 Mdot
.59494 .07063 Mdot
.47243 .02753 Mdot
.56388 .02309 Mdot
.4285 .04127 Mdot
.55918 .00235 Mdot
.43938 .02164 Mdot
.45325 .03265 Mdot
.45155 .01904 Mdot
.55751 .0311 Mdot
.4925 .06716 Mdot
.54722 .04244 Mdot
.59815 .01942 Mdot
.55229 .04597 Mdot
.52572 .06605 Mdot
.58841 .02288 Mdot
.49722 .02479 Mdot
.42923 .02053 Mdot
.45784 .00314 Mdot
.57598 .06204 Mdot
.40629 .05827 Mdot
.41848 .03095 Mdot
.51379 .06528 Mdot
.47125 .06268 Mdot
.51564 .04586 Mdot
.51897 .0167 Mdot
.58992 .05397 Mdot
.53056 .06799 Mdot
.49269 .02918 Mdot
.50133 .04746 Mdot
.43486 .02604 Mdot
.52535 .05958 Mdot
.42856 .04194 Mdot
.50687 .02863 Mdot
.51477 .05082 Mdot
.43562 .04012 Mdot
.59913 .00497 Mdot
.51665 .02342 Mdot
.40921 .02516 Mdot
.5861 .0296 Mdot
.51652 .07014 Mdot
.48477 .0563 Mdot
.48166 .0441 Mdot
.55942 .07088 Mdot
.4531 .00217 Mdot
.45255 .04225 Mdot
.53833 .02551 Mdot
.41693 .00213 Mdot
.5392 .02054 Mdot
.50028 .05288 Mdot
.52999 .06954 Mdot
.51418 .02328 Mdot
.41348 .07356 Mdot
.42941 .04114 Mdot
.53182 .02946 Mdot
.46999 .04442 Mdot
.47872 .02729 Mdot
.41744 .00217 Mdot
.54039 .00179 Mdot
.40051 4e-05 Mdot
.40118 .05541 Mdot
.50024 .02133 Mdot
.47119 .06004 Mdot
.58606 .07221 Mdot
.45772 .06064 Mdot
.55665 .03107 Mdot
.5259 .03118 Mdot
.48665 .06081 Mdot
.44719 .00389 Mdot
.46921 .05864 Mdot
.5068 .00211 Mdot
.4687 .0586 Mdot
.50562 .02086 Mdot
.56846 .03727 Mdot
.43442 .03499 Mdot
.5824 .03922 Mdot
.57671 .04851 Mdot
.42575 .00815 Mdot
.4508 .01733 Mdot
.5391 .0215 Mdot
.40362 .01344 Mdot
.46989 .03703 Mdot
.49681 .01133 Mdot
.40119 .0526 Mdot
.5912 .06464 Mdot
.43274 .01533 Mdot
.55677 .02965 Mdot
.45034 .05027 Mdot
.58007 .05531 Mdot
.42459 .04212 Mdot
.52927 .03798 Mdot
.48549 .02062 Mdot
.52565 .02454 Mdot
.4156 .05775 Mdot
.42884 .0132 Mdot
.41441 .00516 Mdot
.43764 .02273 Mdot
.58167 .06399 Mdot
.48087 .06724 Mdot
.53134 .01372 Mdot
.5008 .01193 Mdot
.50675 .04576 Mdot
.57153 .04812 Mdot
.42126 .02514 Mdot
.44588 .02358 Mdot
.40566 .04155 Mdot
.41705 .01038 Mdot
.59125 .03639 Mdot
.57941 .06182 Mdot
.40957 .04656 Mdot
.49854 .06874 Mdot
.47824 .03284 Mdot
.59774 .05681 Mdot
.57149 .06124 Mdot
.42621 .00869 Mdot
.55023 .0361 Mdot
.58032 .05927 Mdot
.54457 .06872 Mdot
.56328 .04889 Mdot
.55333 .03233 Mdot
.58387 .06123 Mdot
.54375 .05993 Mdot
.48533 .06665 Mdot
.46551 .02709 Mdot
.48759 .00985 Mdot
.49402 .04001 Mdot
.46139 .00116 Mdot
.54379 .00391 Mdot
.48106 .01606 Mdot
.59922 .00935 Mdot
.51779 .04134 Mdot
.44589 .05119 Mdot
.53391 .05427 Mdot
.50214 .06542 Mdot
.44858 .06178 Mdot
.43662 .03832 Mdot
.56099 .05193 Mdot
.5426 .07247 Mdot
.4996 .05077 Mdot
.59881 .06856 Mdot
.41854 .03471 Mdot
.5996 .05921 Mdot
.50075 .06754 Mdot
.55371 .00803 Mdot
.56684 .01328 Mdot
.45157 .01677 Mdot
.51826 .02566 Mdot
.41494 .05262 Mdot
.55727 .0479 Mdot
.47234 .05431 Mdot
.45767 .07129 Mdot
.47353 .05991 Mdot
.43913 .03658 Mdot
.47393 .0007 Mdot
.53837 .0432 Mdot
.52023 .06683 Mdot
.57153 .02993 Mdot
.46866 .05006 Mdot
.45327 .00426 Mdot
.45371 .07161 Mdot
.496 .03053 Mdot
.58137 .0173 Mdot
.43833 .0334 Mdot
.50784 .03156 Mdot
.5992 .07099 Mdot
.43391 .03086 Mdot
.46083 .02778 Mdot
.51368 .03819 Mdot
.4893 .07202 Mdot
.44503 .0623 Mdot
.43602 .06776 Mdot
.59131 .06485 Mdot
.54002 .03723 Mdot
.40994 .04755 Mdot
.50169 .00383 Mdot
.5021 .016 Mdot
.50248 .00701 Mdot
.46819 .0593 Mdot
.44165 .05339 Mdot
.55451 .02111 Mdot
.55236 .05553 Mdot
.50948 .03298 Mdot
.51633 .06194 Mdot
.51816 .04229 Mdot
.57631 .0247 Mdot
.50822 .0689 Mdot
.47462 .02087 Mdot
.40612 .0529 Mdot
.57214 .01386 Mdot
.53793 .06776 Mdot
.53049 .03464 Mdot
.58343 .04665 Mdot
.57813 .05327 Mdot
.47395 .01368 Mdot
.4618 .0655 Mdot
.55579 .04555 Mdot
.48548 .04079 Mdot
.44756 .05082 Mdot
.41086 .01992 Mdot
.44144 .07209 Mdot
.43872 .00606 Mdot
.50351 .00433 Mdot
.50823 .04558 Mdot
.52009 .03184 Mdot
.5301 .06647 Mdot
.44614 .01816 Mdot
.4683 .00098 Mdot
.49035 .04677 Mdot
.58282 .03434 Mdot
.44279 .07012 Mdot
.57196 .01442 Mdot
.40134 .07219 Mdot
.53325 .00837 Mdot
.49783 .06787 Mdot
.42501 .03695 Mdot
.57774 .03603 Mdot
.49491 .04464 Mdot
.53161 .01787 Mdot
.42661 .04366 Mdot
.44125 .04526 Mdot
.44379 .00932 Mdot
.59847 .0493 Mdot
.47183 .06906 Mdot
.59712 .05127 Mdot
.53858 .06069 Mdot
.49929 .05757 Mdot
.51357 .02374 Mdot
.52155 .02154 Mdot
.41865 .05327 Mdot
.58994 .00368 Mdot
.59204 .00961 Mdot
.54869 .03259 Mdot
.54825 .00029 Mdot
.55022 .05745 Mdot
.47643 .00539 Mdot
.5531 .00617 Mdot
.53784 .01886 Mdot
.45381 .02276 Mdot
.42428 .06928 Mdot
.53226 .00122 Mdot
.40562 .01601 Mdot
.54232 .07171 Mdot
.41358 .00641 Mdot
.59363 .03912 Mdot
.46533 .00612 Mdot
.4434 .05584 Mdot
.5889 .00073 Mdot
.4903 .04967 Mdot
.45106 .05603 Mdot
.4365 .02691 Mdot
.42678 .06091 Mdot
.50424 .02569 Mdot
.42116 .0449 Mdot
.56192 .02814 Mdot
.40757 .03849 Mdot
.56829 .06319 Mdot
.54225 .03237 Mdot
.52489 .00735 Mdot
.55334 .03164 Mdot
.43459 .03184 Mdot
.50228 .04978 Mdot
.59809 .00494 Mdot
.4755 .06303 Mdot
.49385 .05342 Mdot
.45434 .01813 Mdot
.53193 .02527 Mdot
.44677 .0538 Mdot
.56364 .03625 Mdot
.50452 .02142 Mdot
.43875 .0289 Mdot
.55118 .06394 Mdot
.40416 .07122 Mdot
.4489 .01417 Mdot
.40607 .06628 Mdot
.5734 .0253 Mdot
.51222 .01286 Mdot
.51906 .00718 Mdot
.58028 .06175 Mdot
.47229 .02754 Mdot
.41664 .0255 Mdot
.56777 .00612 Mdot
.57789 .07077 Mdot
.41658 .01634 Mdot
.57373 .07371 Mdot
.56769 .00217 Mdot
.56766 .00743 Mdot
.59429 .05103 Mdot
.45544 .06873 Mdot
.47523 .04386 Mdot
.47516 .00697 Mdot
.40294 .01632 Mdot
.45851 .05563 Mdot
.43517 .0102 Mdot
.48062 .05903 Mdot
.41859 .06802 Mdot
.50689 .05949 Mdot
.4509 .06585 Mdot
.53924 .05206 Mdot
.45662 .01482 Mdot
.4838 .0575 Mdot
.58139 .04513 Mdot
.40864 .05053 Mdot
.57845 .02881 Mdot
.55013 .06906 Mdot
.54327 .01861 Mdot
.46951 .01003 Mdot
.52468 .02475 Mdot
.56262 .0247 Mdot
.47378 .03306 Mdot
.42338 .0468 Mdot
.41716 .01824 Mdot
.53958 .06347 Mdot
.43577 .04728 Mdot
.53094 .01294 Mdot
.45732 .01847 Mdot
.58081 .01805 Mdot
.51405 .07403 Mdot
.5113 .00802 Mdot
.58937 .04928 Mdot
.54868 .05748 Mdot
.51559 .01621 Mdot
.5253 .01068 Mdot
.49842 .07213 Mdot
.58572 .02138 Mdot
.46265 .02485 Mdot
.45478 .00844 Mdot
.40533 .00638 Mdot
.47398 .06456 Mdot
.49128 .00652 Mdot
.56268 .05654 Mdot
.50191 .03141 Mdot
.414 .07322 Mdot
.58633 .01519 Mdot
.4887 .06254 Mdot
.4879 .01722 Mdot
.50299 .04116 Mdot
.42525 .06653 Mdot
.4482 .03272 Mdot
.41992 .06015 Mdot
.57423 .04232 Mdot
.52865 .05363 Mdot
.41155 .05995 Mdot
.42673 .02223 Mdot
.59754 .0609 Mdot
.44041 .00703 Mdot
.50884 .07252 Mdot
.5525 .06397 Mdot
.40585 .03136 Mdot
.52725 .0716 Mdot
.55765 .07281 Mdot
.50733 .01145 Mdot
.58342 .03048 Mdot
.57868 .03198 Mdot
.57187 .0447 Mdot
.55195 .00976 Mdot
.57433 .05797 Mdot
.51154 .00272 Mdot
.46549 .05961 Mdot
.55904 .01291 Mdot
.45964 .02825 Mdot
.43179 .01547 Mdot
.50199 .0296 Mdot
.52446 .00402 Mdot
.51857 .07328 Mdot
.54578 .04621 Mdot
.54669 .02858 Mdot
.59384 .03645 Mdot
.57237 .04478 Mdot
.48229 .03373 Mdot
.50688 .05933 Mdot
.52325 .02081 Mdot
.44724 .03109 Mdot
.49146 .00534 Mdot
.54525 .00149 Mdot
.567 .00132 Mdot
.42668 .00237 Mdot
.42122 .02927 Mdot
.47999 .04795 Mdot
.42738 .06699 Mdot
.50763 .00317 Mdot
.54509 .03326 Mdot
.40075 .018 Mdot
.42183 .01245 Mdot
.55351 .06108 Mdot
.53037 .00711 Mdot
.40826 .05959 Mdot
.56337 .0058 Mdot
.58157 .05722 Mdot
.54215 .05068 Mdot
.50158 .00927 Mdot
.51477 .05786 Mdot
.59396 .00609 Mdot
.56968 .0246 Mdot
.59321 .06225 Mdot
.54784 .01215 Mdot
.4397 .00117 Mdot
.41747 .00503 Mdot
.43144 .01575 Mdot
.45411 .0734 Mdot
.44987 .03269 Mdot
.51196 .02272 Mdot
.54828 .02342 Mdot
.59719 .03902 Mdot
.55433 .01733 Mdot
.42751 .01443 Mdot
.56112 .02924 Mdot
.47967 .00228 Mdot
.52142 .02806 Mdot
.46219 .07141 Mdot
.48998 .01232 Mdot
.40809 .07217 Mdot
.44011 .05379 Mdot
.49613 .04945 Mdot
.49183 .03037 Mdot
.49894 .01043 Mdot
.5375 .01304 Mdot
.47143 .07017 Mdot
.57638 .05797 Mdot
.59176 .06789 Mdot
.45496 .0299 Mdot
.52957 .07064 Mdot
.56499 .01759 Mdot
.52148 .07263 Mdot
.52488 .03796 Mdot
.42535 .02318 Mdot
.43305 .00759 Mdot
.5264 .01275 Mdot
.49555 .06871 Mdot
.45497 .01675 Mdot
.51917 .01074 Mdot
.46321 .02303 Mdot
.4642 .055 Mdot
.53364 .02655 Mdot
.49922 .03742 Mdot
.41216 .02808 Mdot
.57434 .07362 Mdot
.58681 .0049 Mdot
.54129 .06603 Mdot
.46041 .06631 Mdot
.44574 .07148 Mdot
.40544 .04956 Mdot
.52657 .06074 Mdot
.54223 .02653 Mdot
.46236 .00574 Mdot
.40859 .07415 Mdot
.56315 .04248 Mdot
.59643 .04607 Mdot
.58881 .04302 Mdot
.40961 .04117 Mdot
.44752 .05115 Mdot
.54921 .04902 Mdot
.40179 .05383 Mdot
.54377 .07362 Mdot
.47522 .06726 Mdot
.40154 .04709 Mdot
.41286 .06152 Mdot
.59295 .04711 Mdot
.44971 .01904 Mdot
.59652 .00104 Mdot
.4609 .05018 Mdot
.58691 .03404 Mdot
.41338 .07319 Mdot
.4377 .05918 Mdot
.41159 .01936 Mdot
.49394 .05972 Mdot
.53637 .02626 Mdot
.4924 .01263 Mdot
.52352 .0389 Mdot
.49944 .03969 Mdot
.47381 .01986 Mdot
.50292 .03865 Mdot
.41291 .04385 Mdot
.51601 .00461 Mdot
.59953 .04482 Mdot
.4783 .01959 Mdot
.58794 .02546 Mdot
.58437 .03403 Mdot
.45157 .07336 Mdot
.49197 .0214 Mdot
.52805 .03446 Mdot
.59253 .05587 Mdot
.45425 .01459 Mdot
.48961 .01722 Mdot
.44134 .04491 Mdot
.5736 .01262 Mdot
.4418 9e-05 Mdot
.4953 .06719 Mdot
.45386 .0488 Mdot
.51093 .03316 Mdot
.40229 .0496 Mdot
.41896 .01176 Mdot
.47424 .01514 Mdot
.42643 .03005 Mdot
.41999 .00055 Mdot
.53682 .01283 Mdot
.57866 .02981 Mdot
.56322 .00021 Mdot
.53685 .02971 Mdot
.46793 .00719 Mdot
.48299 .05508 Mdot
.557 .04819 Mdot
.4807 .00548 Mdot
.53804 .03643 Mdot
.40646 .0645 Mdot
.5116 .00638 Mdot
.58647 .06395 Mdot
.57478 .06771 Mdot
.40781 .03414 Mdot
.41156 .0675 Mdot
.47096 .00443 Mdot
.54363 .06031 Mdot
.58797 .02351 Mdot
.58664 .01211 Mdot
.50727 .01803 Mdot
.4486 .04985 Mdot
.5008 .0277 Mdot
.537 .04347 Mdot
.51433 .03792 Mdot
.56222 .04992 Mdot
.50652 .00378 Mdot
.55066 .05659 Mdot
.43556 .07351 Mdot
.40703 .07044 Mdot
.4476 .05 Mdot
.42039 .05833 Mdot
.54033 .03196 Mdot
.57179 .00848 Mdot
.43953 .00426 Mdot
.43479 .03918 Mdot
.5252 .04051 Mdot
.47258 .06342 Mdot
.41868 .03673 Mdot
.52192 .00683 Mdot
.58311 .03739 Mdot
.51489 .01056 Mdot
.53552 .06155 Mdot
.4945 .02639 Mdot
.59518 .02959 Mdot
.52271 .01791 Mdot
.55565 .02533 Mdot
.48792 .0529 Mdot
.43046 .05899 Mdot
.41534 .06365 Mdot
.41178 .02225 Mdot
.49342 .05681 Mdot
.42867 .05903 Mdot
.57852 .04626 Mdot
.49315 .07164 Mdot
.48402 .01987 Mdot
.49797 .04205 Mdot
.56131 .00195 Mdot
.54232 .01672 Mdot
.47339 .02322 Mdot
.51186 .0319 Mdot
.45805 .03373 Mdot
.50008 .00964 Mdot
.56464 .05109 Mdot
.47141 .02478 Mdot
.58611 .00483 Mdot
.57825 .0273 Mdot
.50209 .05913 Mdot
.48028 .05941 Mdot
.54079 .05717 Mdot
.53797 .04269 Mdot
.46739 .03396 Mdot
.42611 .01079 Mdot
.40934 .00022 Mdot
.52603 .00114 Mdot
.4447 .0233 Mdot
.45463 .05053 Mdot
.45859 .01847 Mdot
.47638 .02324 Mdot
.55649 .03351 Mdot
.59609 .03799 Mdot
.41571 .0505 Mdot
.45813 .06947 Mdot
.54831 .01654 Mdot
.43202 .05868 Mdot
.53897 .01632 Mdot
.50598 .05754 Mdot
.49427 .06718 Mdot
.45135 .00701 Mdot
.43569 .04871 Mdot
.57498 .05794 Mdot
.4792 .0152 Mdot
.57889 .01995 Mdot
.46349 .03886 Mdot
.52076 .02464 Mdot
.51518 .02232 Mdot
.48874 .04012 Mdot
.5762 .006 Mdot
.58276 .05675 Mdot
.48193 .01299 Mdot
.53141 .04974 Mdot
.44624 .03845 Mdot
.55643 .06596 Mdot
.56705 .02325 Mdot
.57754 .04602 Mdot
.50356 .05855 Mdot
.45678 .02138 Mdot
.58838 .03623 Mdot
.56804 .05542 Mdot
.41218 .03023 Mdot
.58528 .07283 Mdot
.53025 .01724 Mdot
.45387 .0231 Mdot
.48401 .05295 Mdot
.49745 .0313 Mdot
.51696 .0297 Mdot
.5199 .05944 Mdot
.4134 .04531 Mdot
.46312 .03807 Mdot
.42501 .00908 Mdot
.49508 .05681 Mdot
.41283 .05302 Mdot
.5098 .05814 Mdot
.48258 .03578 Mdot
.45592 .03505 Mdot
.59858 .05699 Mdot
.55847 .00375 Mdot
.48162 .02729 Mdot
.43857 .01847 Mdot
.46823 .05614 Mdot
.57545 .05457 Mdot
.44321 .04706 Mdot
.48038 .07192 Mdot
.43038 .06821 Mdot
.57058 .01378 Mdot
.54779 .03243 Mdot
.51466 .0529 Mdot
.54921 .04961 Mdot
.55619 .04915 Mdot
.46759 .02232 Mdot
.51761 .03068 Mdot
.59937 .04035 Mdot
.54216 .05027 Mdot
.55615 .06745 Mdot
.46178 .05252 Mdot
.52578 .07341 Mdot
.4912 .03874 Mdot
.57798 .04098 Mdot
.57654 .06 Mdot
.42877 .06553 Mdot
.42035 .01085 Mdot
.56118 .04321 Mdot
.50274 .05434 Mdot
.56181 .00287 Mdot
.56058 .00406 Mdot
.40566 .00958 Mdot
.49879 .02571 Mdot
.47988 .01034 Mdot
.40759 .06114 Mdot
.5019 .04353 Mdot
.43106 .00114 Mdot
.47313 .05216 Mdot
.4107 .06445 Mdot
.51195 .00895 Mdot
.50797 .01012 Mdot
.55014 .00608 Mdot
.54739 .00605 Mdot
.54449 .07067 Mdot
.4486 .0545 Mdot
.46461 .06033 Mdot
.44101 .06753 Mdot
.56271 .0168 Mdot
.40995 .06639 Mdot
.48958 .03881 Mdot
.59925 .00194 Mdot
.57763 .02986 Mdot
.49128 .06598 Mdot
.42748 .02378 Mdot
.54389 .05993 Mdot
.48299 .02728 Mdot
.49528 .00543 Mdot
.41838 .04111 Mdot
.45428 .01207 Mdot
.45567 .02431 Mdot
.44432 .01984 Mdot
.56609 .05967 Mdot
.44508 .01791 Mdot
.58846 .0298 Mdot
.5538 .02609 Mdot
.56098 .00602 Mdot
.40991 .04032 Mdot
.47798 .05291 Mdot
.51463 .03489 Mdot
.4596 .01179 Mdot
.46035 .02282 Mdot
.40393 .06165 Mdot
.41602 .00298 Mdot
.43784 .00198 Mdot
.57095 .05924 Mdot
.44938 .04634 Mdot
.41715 .03315 Mdot
.4884 .04032 Mdot
.40724 .067 Mdot
.41042 .06158 Mdot
.49262 .03211 Mdot
.55082 .04978 Mdot
.43227 .00929 Mdot
.5469 .0623 Mdot
.41624 .00631 Mdot
.50906 .06032 Mdot
.44529 .02123 Mdot
.45968 .01398 Mdot
.42814 .06225 Mdot
.57128 .04782 Mdot
.4209 .06941 Mdot
.56086 .06041 Mdot
.52828 .0373 Mdot
.41003 .01062 Mdot
.49602 .02801 Mdot
.46314 .02249 Mdot
.47977 .02171 Mdot
.55407 .03633 Mdot
.43448 .00047 Mdot
.49439 .02235 Mdot
.40634 .01239 Mdot
.52311 .0487 Mdot
.58544 .01714 Mdot
.56225 .06245 Mdot
.45716 .05401 Mdot
.55222 .05183 Mdot
.56114 .02599 Mdot
.48908 .02934 Mdot
.48137 .00428 Mdot
.53501 .06717 Mdot
.44689 .00381 Mdot
.44062 .04482 Mdot
.44055 .06558 Mdot
.51751 .07029 Mdot
.45511 .04844 Mdot
.55526 .00784 Mdot
.59795 .0686 Mdot
.40304 .03017 Mdot
.4368 .0426 Mdot
.51396 .00083 Mdot
.55543 .03832 Mdot
.57895 .00782 Mdot
.50854 .03451 Mdot
.53833 .03717 Mdot
.46799 .04309 Mdot
.42082 .04104 Mdot
.41289 .06882 Mdot
.46556 .03321 Mdot
.41494 .00022 Mdot
.46253 .00304 Mdot
.57813 .03178 Mdot
.54857 .00221 Mdot
.4227 .06762 Mdot
.56962 .06855 Mdot
.51416 .03311 Mdot
.43129 .03138 Mdot
.44616 .06419 Mdot
.41047 .0645 Mdot
.43328 .06953 Mdot
.54491 .03129 Mdot
.41834 .06931 Mdot
.48239 .02826 Mdot
.4402 .03753 Mdot
.53382 .02605 Mdot
.4175 .04407 Mdot
.56419 .03167 Mdot
.50335 .01096 Mdot
.5329 .00029 Mdot
.45719 .02093 Mdot
.52243 .00995 Mdot
.42391 .02557 Mdot
.57751 .05282 Mdot
.40557 .03042 Mdot
.49513 .02456 Mdot
.56537 .06705 Mdot
.56131 .07267 Mdot
.54786 .02298 Mdot
.59712 .041 Mdot
.44452 .01203 Mdot
.46422 .04071 Mdot
.58733 .06526 Mdot
.54179 .03076 Mdot
.56342 .03969 Mdot
.56428 .05211 Mdot
.55785 .00927 Mdot
.46915 .02755 Mdot
.59248 .01638 Mdot
.50784 .02904 Mdot
.44462 .06756 Mdot
.51072 .06221 Mdot
.4001 .05553 Mdot
.4465 .02149 Mdot
.41277 .06444 Mdot
.50471 .06489 Mdot
.44935 .02475 Mdot
.54043 .01278 Mdot
.4915 .01548 Mdot
.47128 .0594 Mdot
.49902 .07327 Mdot
.56344 .03035 Mdot
.45441 .0057 Mdot
.45272 .04231 Mdot
.4543 .02433 Mdot
.40622 .02082 Mdot
.44153 .03406 Mdot
.50151 .03009 Mdot
.59218 .0093 Mdot
.56107 .01731 Mdot
.50068 .06799 Mdot
.48979 .03208 Mdot
.40165 .06888 Mdot
.52635 .00172 Mdot
.54725 .06318 Mdot
.47363 .03358 Mdot
.49294 .03884 Mdot
.46741 .01276 Mdot
.45141 .00479 Mdot
.56591 .05684 Mdot
.45923 .06965 Mdot
.40483 .03953 Mdot
.55856 .00166 Mdot
.51504 .00745 Mdot
.5569 .00694 Mdot
.58869 .00573 Mdot
.40966 .01793 Mdot
.51506 .04631 Mdot
.51671 .05325 Mdot
.44765 .03355 Mdot
.4653 .04846 Mdot
.48174 .05088 Mdot
.40607 .05298 Mdot
.47691 .01135 Mdot
.44751 .05131 Mdot
.56187 .0039 Mdot
.49061 .04437 Mdot
.57319 .07233 Mdot
.48095 .02644 Mdot
.45813 .02602 Mdot
.56424 .04736 Mdot
.41048 .06663 Mdot
.49894 .07306 Mdot
.52874 .01575 Mdot
.49287 .02008 Mdot
.45182 .0044 Mdot
.44535 .04294 Mdot
.48995 .0005 Mdot
.55474 .07273 Mdot
.51677 .00234 Mdot
.47379 .04629 Mdot
.45864 .05048 Mdot
.50955 .0731 Mdot
.44816 .05802 Mdot
.41061 4e-05 Mdot
.51943 .04227 Mdot
.51774 .05412 Mdot
.4676 .03787 Mdot
.47239 .01118 Mdot
.57765 .03737 Mdot
.51765 .01262 Mdot
.46088 .03503 Mdot
.44386 .04049 Mdot
.40224 .05871 Mdot
.53431 .04156 Mdot
.55408 .00069 Mdot
.5237 .04152 Mdot
.43466 .03259 Mdot
.40596 .06157 Mdot
.56706 .06888 Mdot
.53357 .05038 Mdot
.58941 .03151 Mdot
.41592 .03776 Mdot
.52852 .07065 Mdot
.57206 .07144 Mdot
.52628 .01193 Mdot
.43774 .02988 Mdot
.5722 .01124 Mdot
.51404 .06252 Mdot
.53754 .05282 Mdot
.50808 .00096 Mdot
.57049 .0581 Mdot
.57451 .02474 Mdot
.58108 .02659 Mdot
.55859 .06114 Mdot
.45256 .03011 Mdot
.58653 .06387 Mdot
.52628 .01817 Mdot
.54878 .03399 Mdot
.55408 .00693 Mdot
.43474 .04563 Mdot
.41654 .02828 Mdot
.52667 .04467 Mdot
.44605 .04434 Mdot
.55216 .01993 Mdot
.46497 .01775 Mdot
.59357 .03295 Mdot
.41241 .06181 Mdot
.40705 .04325 Mdot
.48613 .04364 Mdot
.45827 .00926 Mdot
.53206 .03671 Mdot
.42352 .03779 Mdot
.51552 .00843 Mdot
.49686 .06729 Mdot
.46947 .03826 Mdot
.5447 .04736 Mdot
.4045 .02051 Mdot
.55112 .01441 Mdot
.59209 .03286 Mdot
.54408 .04532 Mdot
.50596 .06339 Mdot
.48581 .03606 Mdot
.5739 .02668 Mdot
.46229 .07243 Mdot
.45838 .01825 Mdot
.56543 .00514 Mdot
.58891 .05416 Mdot
.42073 .03195 Mdot
.58441 .03365 Mdot
.46961 .01754 Mdot
.59232 .00079 Mdot
.52553 .04639 Mdot
.48636 .01156 Mdot
.43972 .01033 Mdot
.51246 .05904 Mdot
.57743 .01206 Mdot
.45408 .04079 Mdot
.412 .00692 Mdot
.46517 .06079 Mdot
.59127 .04913 Mdot
.48076 .02714 Mdot
.52166 .03159 Mdot
.48844 .02635 Mdot
.59613 .05937 Mdot
.40208 .01479 Mdot
.5564 .04904 Mdot
.48962 .02991 Mdot
.57897 .03698 Mdot
.43554 .06329 Mdot
.56697 .03006 Mdot
.57038 .00249 Mdot
.5757 .05509 Mdot
.48962 .04951 Mdot
.45404 .0235 Mdot
.40118 .02316 Mdot
.45791 .0383 Mdot
.5991 .00837 Mdot
.50151 .06343 Mdot
.50947 .05262 Mdot
.52254 .02645 Mdot
.47393 .06349 Mdot
.55558 .07055 Mdot
.50355 .061 Mdot
.57988 .01546 Mdot
.41393 .01149 Mdot
.52584 .06613 Mdot
.41276 .06249 Mdot
.46793 .02783 Mdot
.41366 .05412 Mdot
.56642 .03856 Mdot
.50419 .00151 Mdot
.44388 .01212 Mdot
.43026 .01218 Mdot
.48831 .01573 Mdot
.5267 .02534 Mdot
.50843 .00027 Mdot
.51277 .01385 Mdot
.58259 .00831 Mdot
.50001 .02553 Mdot
.51465 .05464 Mdot
.48635 .04557 Mdot
.54823 .01608 Mdot
.58216 .04406 Mdot
.50435 .00396 Mdot
.5519 .03189 Mdot
.41604 .0624 Mdot
.4252 .00655 Mdot
.50761 .06213 Mdot
.51243 .06686 Mdot
.52503 .05382 Mdot
.41242 .04133 Mdot
.41037 .07335 Mdot
.52607 .06993 Mdot
.46214 .05727 Mdot
.54391 .02586 Mdot
.55779 .0533 Mdot
.592 .06814 Mdot
.54175 .06507 Mdot
.5668 .06159 Mdot
.43414 .00294 Mdot
.45437 .06889 Mdot
.50911 .02328 Mdot
.44195 .02756 Mdot
.49873 .0241 Mdot
.51588 .0318 Mdot
.43659 .041 Mdot
.57198 .00594 Mdot
.4788 .06186 Mdot
.57998 .01197 Mdot
.53705 .07095 Mdot
.41318 .02455 Mdot
.50291 .06801 Mdot
.55881 .02982 Mdot
.5938 .04473 Mdot
.51686 .00226 Mdot
.49507 .02063 Mdot
.40097 .04462 Mdot
.45848 .05379 Mdot
.42899 .03868 Mdot
.57968 .0661 Mdot
.44902 .02671 Mdot
.44263 .06931 Mdot
.43584 .00217 Mdot
.53972 .00131 Mdot
.47703 .04652 Mdot
.54592 .03074 Mdot
.56018 .04426 Mdot
.45086 .01012 Mdot
.55921 .0738 Mdot
.59238 .03049 Mdot
.53021 .03512 Mdot
.4127 .03856 Mdot
.4812 .00841 Mdot
.57006 .04341 Mdot
.44536 .00624 Mdot
.43034 .0421 Mdot
.56832 .03389 Mdot
.48442 .01136 Mdot
.40815 .06379 Mdot
.43356 .00124 Mdot
.44894 .06415 Mdot
.44118 .04491 Mdot
.51873 .02903 Mdot
.42848 .00635 Mdot
.43753 .02063 Mdot
.45842 .03711 Mdot
.59218 .01439 Mdot
.42808 .06918 Mdot
.42385 .05467 Mdot
.54366 .05782 Mdot
.41571 .06504 Mdot
.5101 .05658 Mdot
.56677 .00089 Mdot
.46892 .01167 Mdot
.44804 .04602 Mdot
.44044 .00532 Mdot
.4105 .02539 Mdot
.58202 .04237 Mdot
.41833 .011 Mdot
.55394 .04736 Mdot
.59447 .0305 Mdot
.41027 .0637 Mdot
.57877 .03962 Mdot
.50017 .00712 Mdot
.412 .03873 Mdot
.43125 .06961 Mdot
.56397 .06688 Mdot
.59082 .06429 Mdot
.55346 .04149 Mdot
.4088 .02192 Mdot
.53514 .03049 Mdot
.45487 .04872 Mdot
.54066 .07416 Mdot
.44459 .05919 Mdot
.5619 .03453 Mdot
.54442 .05207 Mdot
.5499 .06996 Mdot
.51316 .05663 Mdot
.58593 .00308 Mdot
.52235 .06651 Mdot
.43247 .03576 Mdot
.51354 .04459 Mdot
.49733 .00527 Mdot
.45868 .07003 Mdot
.55666 .00527 Mdot
.41408 .01084 Mdot
.59477 .0449 Mdot
.46967 .03294 Mdot
.44487 .0491 Mdot
.5565 .05047 Mdot
.45894 .04602 Mdot
.43416 .05813 Mdot
.42648 .01027 Mdot
.52061 .01354 Mdot
.52915 .005 Mdot
.46194 .01767 Mdot
.57248 .07389 Mdot
.44785 .00682 Mdot
.57772 .02898 Mdot
.57819 .04805 Mdot
.53284 .05404 Mdot
.42168 .07175 Mdot
.4739 .00802 Mdot
.58753 .01362 Mdot
.44742 .07192 Mdot
.46692 8e-05 Mdot
.51827 .06692 Mdot
.40498 .05658 Mdot
.54579 .0672 Mdot
.55713 .04976 Mdot
.56807 .03821 Mdot
.57894 .00171 Mdot
.43523 .05833 Mdot
.55726 .00412 Mdot
.56133 .05031 Mdot
.56973 .06467 Mdot
.51391 .05256 Mdot
.50281 .06459 Mdot
.59563 .0598 Mdot
.49783 .00801 Mdot
.44984 .06677 Mdot
.54071 .03241 Mdot
.48177 .02856 Mdot
.56176 .03071 Mdot
.44654 .04439 Mdot
.4045 .02658 Mdot
.48521 .06824 Mdot
.43477 .03607 Mdot
.5713 .01569 Mdot
.53196 .04565 Mdot
.57567 .03005 Mdot
.43412 .03765 Mdot
.52583 .03744 Mdot
.49342 .00524 Mdot
.44406 .00889 Mdot
.53165 .04869 Mdot
.59752 .03866 Mdot
.52715 .02211 Mdot
.51232 .04458 Mdot
.49238 .0602 Mdot
.54102 .0289 Mdot
.56042 .01455 Mdot
.56535 .07301 Mdot
.5263 .05107 Mdot
.43952 .03557 Mdot
.43288 .04583 Mdot
.59546 .02668 Mdot
.50123 .0713 Mdot
.59794 .06218 Mdot
.57408 .04919 Mdot
.48562 .0176 Mdot
.4817 .06315 Mdot
.54461 .06286 Mdot
.52128 .0486 Mdot
.57926 .06401 Mdot
.59498 .07169 Mdot
.53974 .02844 Mdot
.56209 .02586 Mdot
.54428 .00176 Mdot
.46086 .02873 Mdot
.54634 .01374 Mdot
.48679 .0537 Mdot
.46071 .07031 Mdot
.40509 .06472 Mdot
.5161 .00745 Mdot
.48381 .01613 Mdot
.53684 .0176 Mdot
.48883 .0186 Mdot
.59711 .06332 Mdot
.52673 .0669 Mdot
.45283 .06155 Mdot
.46587 .03817 Mdot
.50649 .04781 Mdot
.57908 .05864 Mdot
.44578 .05166 Mdot
.574 .06808 Mdot
.52968 .04422 Mdot
.49019 .05195 Mdot
.59283 .02662 Mdot
.40136 .03335 Mdot
.59573 .03747 Mdot
.47463 .04062 Mdot
.5429 .05008 Mdot
.40876 .00244 Mdot
.4364 .00227 Mdot
.42968 .01797 Mdot
.59062 .02477 Mdot
.45568 .02406 Mdot
.46095 .05472 Mdot
.56549 .04627 Mdot
.46811 .0281 Mdot
.56413 .01292 Mdot
.47238 .06479 Mdot
.4895 .04646 Mdot
.52949 .01471 Mdot
.48074 .04402 Mdot
.49308 .01244 Mdot
.45106 .02605 Mdot
.50246 .06183 Mdot
.59538 .00199 Mdot
.44151 .00712 Mdot
.42989 .02988 Mdot
.5734 .05318 Mdot
.46577 .01697 Mdot
.50102 .06256 Mdot
.57627 .04467 Mdot
.57153 .04785 Mdot
.49553 .00065 Mdot
.47845 .0354 Mdot
.44447 .04877 Mdot
.57599 .04773 Mdot
.44909 .04678 Mdot
.53447 .04062 Mdot
.4192 .0169 Mdot
.56107 .0616 Mdot
.55343 .07409 Mdot
.46006 .0732 Mdot
.57716 .02942 Mdot
.48853 .02536 Mdot
.48163 .02877 Mdot
.41008 .06412 Mdot
.43716 .05417 Mdot
.43409 .01639 Mdot
.58807 .00739 Mdot
.49962 .04993 Mdot
.56887 .06465 Mdot
.53855 .0625 Mdot
.41544 .06472 Mdot
.47849 .06346 Mdot
.43828 .0353 Mdot
.58996 .0381 Mdot
.55665 .00652 Mdot
.57988 .04814 Mdot
.51949 .02652 Mdot
.54579 .03176 Mdot
.53142 .01914 Mdot
.44617 .05599 Mdot
.56255 .02865 Mdot
.50762 .06765 Mdot
.54711 .03809 Mdot
.42913 .0042 Mdot
.50883 .0028 Mdot
.43917 .04026 Mdot
.55219 .07044 Mdot
.45928 .06629 Mdot
.4327 .04392 Mdot
.51349 .03453 Mdot
.50128 .02478 Mdot
.46732 .0527 Mdot
.53873 .0703 Mdot
.5597 .05921 Mdot
.59162 .0322 Mdot
.53057 .05502 Mdot
.48279 .02941 Mdot
.49141 .01475 Mdot
.53061 .03314 Mdot
.43212 .02263 Mdot
.49791 .06338 Mdot
.51863 .06227 Mdot
.59663 .0386 Mdot
.4513 .00956 Mdot
.4579 .04247 Mdot
.4916 .02451 Mdot
.46627 .01027 Mdot
.56103 .04366 Mdot
.58348 .05502 Mdot
.46963 .02891 Mdot
.45287 .02189 Mdot
.4375 .00628 Mdot
.55496 .03267 Mdot
.51888 .01818 Mdot
.55833 .06823 Mdot
.46757 .00861 Mdot
.50044 .02576 Mdot
.57597 .05826 Mdot
.43417 .01549 Mdot
.41494 .0146 Mdot
.45069 .03463 Mdot
.54531 .05985 Mdot
.59782 .01274 Mdot
.50781 .05357 Mdot
.44286 .05424 Mdot
.58893 .0354 Mdot
.48453 .06017 Mdot
.52136 .02678 Mdot
.58409 .03442 Mdot
.54539 .04268 Mdot
.54992 .01893 Mdot
.53045 .02808 Mdot
.49923 .05846 Mdot
.58514 .04239 Mdot
.50142 .04572 Mdot
.47733 .06298 Mdot
.45856 .06565 Mdot
.4884 .02758 Mdot
.57403 .00547 Mdot
.56704 .0008 Mdot
.58994 .04522 Mdot
.42165 .03228 Mdot
.44002 .02629 Mdot
.49119 .0042 Mdot
.54078 .04199 Mdot
.50605 .03598 Mdot
.43937 .07044 Mdot
.42872 .04716 Mdot
.58081 .00479 Mdot
.54031 .01958 Mdot
.40678 .07349 Mdot
.57327 .01878 Mdot
.41684 .02827 Mdot
.55163 .06066 Mdot
.57682 .00198 Mdot
.46043 .05646 Mdot
.43603 .03415 Mdot
.55438 .02048 Mdot
.59666 .03787 Mdot
.52567 .04748 Mdot
.41585 .03308 Mdot
.58536 .0279 Mdot
.40907 .03376 Mdot
.41208 .00912 Mdot
.59224 .00549 Mdot
.46046 .02262 Mdot
.41542 .00352 Mdot
.40002 .04032 Mdot
.57939 .04353 Mdot
.44564 .01984 Mdot
.58272 .00566 Mdot
.51997 .04652 Mdot
.56687 .04674 Mdot
.53461 .01862 Mdot
.5578 .01298 Mdot
.52253 .00949 Mdot
.56556 .00749 Mdot
.46207 .06104 Mdot
.55014 .00398 Mdot
.46205 .02071 Mdot
.57075 .03461 Mdot
.41642 .00087 Mdot
.58802 .02895 Mdot
.49645 .02852 Mdot
.42115 .05637 Mdot
.56184 .0099 Mdot
.46336 .04339 Mdot
.43931 .0004 Mdot
.4978 .0359 Mdot
.57724 .01353 Mdot
.54766 .03192 Mdot
.51518 .06698 Mdot
.57691 .07148 Mdot
.49877 .06611 Mdot
.58889 .04253 Mdot
.40232 .0376 Mdot
.56773 .06032 Mdot
.44048 .0277 Mdot
.50438 .01693 Mdot
.40117 .02729 Mdot
.40658 .0552 Mdot
.42394 .01376 Mdot
.45892 .02328 Mdot
.50875 .02094 Mdot
.48201 .02596 Mdot
.40999 .029 Mdot
.49312 .0576 Mdot
.40766 .06557 Mdot
.52539 .07144 Mdot
.56718 .03787 Mdot
.42101 .05451 Mdot
.56601 .01057 Mdot
.41443 .07348 Mdot
.54207 .07097 Mdot
.55551 .05021 Mdot
.43331 .05003 Mdot
.4735 .02424 Mdot
.42333 .02103 Mdot
.58038 .04081 Mdot
.41566 .02963 Mdot
.45499 .04353 Mdot
.44848 .06593 Mdot
.43399 .06318 Mdot
.48248 .05535 Mdot
.41956 .06386 Mdot
.54041 .05854 Mdot
.46405 .01365 Mdot
.5071 .00852 Mdot
.59055 .06357 Mdot
.48377 .06165 Mdot
.41017 .02276 Mdot
.46811 .03202 Mdot
.55517 .0534 Mdot
.41962 .04025 Mdot
.52119 .06439 Mdot
.53715 .05906 Mdot
.50163 .00053 Mdot
.59674 .00052 Mdot
.43758 .06104 Mdot
.48964 .06617 Mdot
.44703 .07163 Mdot
.40587 .00452 Mdot
.43686 .04887 Mdot
.53777 .04667 Mdot
.48169 .06963 Mdot
.51814 .00642 Mdot
.5605 .00524 Mdot
.58099 .02152 Mdot
.45887 .00471 Mdot
.58425 .021 Mdot
.42129 .01783 Mdot
.49461 .029 Mdot
.57426 .02037 Mdot
.48874 .02448 Mdot
.5374 .04566 Mdot
.55097 .05198 Mdot
.45571 .0502 Mdot
.43283 .04556 Mdot
.49522 .04495 Mdot
.45184 .02405 Mdot
.43635 .04024 Mdot
.46759 .00304 Mdot
.41506 .02241 Mdot
.57298 .04821 Mdot
.4408 .00204 Mdot
.48424 .02373 Mdot
.5034 .03054 Mdot
.53326 .04591 Mdot
.44769 .05451 Mdot
.50043 .00035 Mdot
.55247 .00956 Mdot
.44859 .05047 Mdot
.51612 .04348 Mdot
.581 .04742 Mdot
.50106 .02107 Mdot
.40802 .07338 Mdot
.46026 .01903 Mdot
.52378 .04965 Mdot
.55686 .06265 Mdot
.59052 .00374 Mdot
.50917 .00814 Mdot
.49009 .00339 Mdot
.5567 .07275 Mdot
.4415 .02709 Mdot
.44058 .02927 Mdot
.4605 .05383 Mdot
.53952 .00819 Mdot
.45248 .05462 Mdot
.47926 .06332 Mdot
.52869 .00497 Mdot
.5224 .00067 Mdot
.53817 .00122 Mdot
.41323 .0667 Mdot
.44808 .07199 Mdot
.45653 .06811 Mdot
.40658 .0449 Mdot
.41595 .03885 Mdot
.54608 .06523 Mdot
.47643 .03066 Mdot
.49361 .01061 Mdot
.59717 .0415 Mdot
.56491 .00565 Mdot
.47478 .04082 Mdot
.42674 .00442 Mdot
.46155 .04829 Mdot
.57865 .00659 Mdot
.40503 .05434 Mdot
.57207 .03586 Mdot
.58908 .01549 Mdot
.42599 .04479 Mdot
.51265 .059 Mdot
.53238 .03417 Mdot
.51547 .0175 Mdot
.56746 .02853 Mdot
.4407 .05084 Mdot
.54072 .0241 Mdot
.57914 .00255 Mdot
.56207 .01751 Mdot
.57412 .02237 Mdot
.59 .05582 Mdot
.58504 .00688 Mdot
.56401 .01103 Mdot
.47239 .02204 Mdot
.43164 .05102 Mdot
.55692 .00454 Mdot
.46417 .02249 Mdot
.51622 .02786 Mdot
.52345 .07256 Mdot
.53708 .02531 Mdot
.56138 .05505 Mdot
.56296 .00294 Mdot
.57138 .0734 Mdot
.57792 .07023 Mdot
.40736 .06237 Mdot
.50553 .04819 Mdot
.57573 .01135 Mdot
.54861 .04365 Mdot
.51156 .06302 Mdot
.43238 .01579 Mdot
.58811 .06463 Mdot
.4953 .06464 Mdot
.42673 .00958 Mdot
.53234 .06169 Mdot
.45535 .01035 Mdot
.55442 .06562 Mdot
.44799 .02215 Mdot
.44889 .01744 Mdot
.47226 .0108 Mdot
.50028 .04795 Mdot
.56071 .02195 Mdot
.4679 .03217 Mdot
.5726 .03148 Mdot
.5726 .0417 Mdot
.54587 .0219 Mdot
.44025 .05417 Mdot
.49051 .01155 Mdot
.48583 .06271 Mdot
.44252 .06357 Mdot
.43694 .04527 Mdot
.57026 .05277 Mdot
.53665 .07148 Mdot
.40955 .03083 Mdot
.46875 .03932 Mdot
.43695 .07351 Mdot
.49616 .07179 Mdot
.49108 .05161 Mdot
.45591 .01762 Mdot
.40057 .04005 Mdot
.57007 .02907 Mdot
.55804 .05064 Mdot
.53313 .05797 Mdot
.58778 .07204 Mdot
.59648 .06065 Mdot
.57823 .04121 Mdot
.52772 .02133 Mdot
.54128 .04187 Mdot
.43157 .02371 Mdot
.4502 .06442 Mdot
.57566 .00609 Mdot
.44964 .02437 Mdot
.40559 .05118 Mdot
.4916 .04789 Mdot
.47245 .06738 Mdot
.50381 .05002 Mdot
.47597 .00673 Mdot
.52558 .00881 Mdot
.54825 .05956 Mdot
.58429 .04111 Mdot
.51668 .03586 Mdot
.53409 .05085 Mdot
.54102 .02976 Mdot
.48445 .02648 Mdot
.53544 .05275 Mdot
.59286 .05275 Mdot
.46298 .05953 Mdot
.48904 .00273 Mdot
.58701 .0528 Mdot
.56347 .06808 Mdot
.43876 .0674 Mdot
.57917 .02697 Mdot
.52207 .03155 Mdot
.44508 .05029 Mdot
.58105 .00178 Mdot
.56063 .02381 Mdot
.44562 .0232 Mdot
.56778 .04522 Mdot
.58263 .03783 Mdot
.47873 .04249 Mdot
.59563 .05919 Mdot
.51526 .04857 Mdot
.55687 .06596 Mdot
.53609 .0216 Mdot
.43479 .03441 Mdot
.49101 .04548 Mdot
.45374 .03263 Mdot
.53037 .02166 Mdot
.40813 .00943 Mdot
.5626 .0506 Mdot
.42549 .04576 Mdot
.48386 .00811 Mdot
.42987 .06073 Mdot
.5686 .0337 Mdot
.473 .06894 Mdot
.43251 .0121 Mdot
.4382 .03453 Mdot
.5415 .04079 Mdot
.58446 .0019 Mdot
.41113 .01913 Mdot
.57633 .06664 Mdot
.44853 .04268 Mdot
.55084 .02087 Mdot
.56467 .03457 Mdot
.52097 .0343 Mdot
.59607 .00087 Mdot
.44798 .03953 Mdot
.56356 .06294 Mdot
.40978 .005 Mdot
.42206 .02215 Mdot
.42532 .00309 Mdot
.41093 .00302 Mdot
.44899 .01062 Mdot
.5624 .0345 Mdot
.49815 .06391 Mdot
.59773 .07409 Mdot
.57718 .02961 Mdot
.40165 .07322 Mdot
.5292 .06424 Mdot
.43809 .01028 Mdot
.51942 .05925 Mdot
.41603 .0623 Mdot
.49411 .05615 Mdot
.4051 .05927 Mdot
.44512 .04553 Mdot
.4427 .02477 Mdot
.54697 .05578 Mdot
.44497 .02485 Mdot
.56979 .02618 Mdot
.44332 .02579 Mdot
.4406 .0361 Mdot
.40523 .01551 Mdot
.52117 .05101 Mdot
.5892 .02738 Mdot
.42707 .06902 Mdot
.5841 .04227 Mdot
.58195 .02349 Mdot
.5414 .0175 Mdot
.43498 .04188 Mdot
.49643 .06681 Mdot
.46518 .0157 Mdot
.45311 .04102 Mdot
.42459 .05377 Mdot
.44789 .02551 Mdot
.50341 .00276 Mdot
.45869 .07229 Mdot
.47635 .0079 Mdot
.47458 .03002 Mdot
.4944 .05857 Mdot
.53318 .01252 Mdot
.45942 .01669 Mdot
.43675 .01987 Mdot
.59424 .00099 Mdot
.58363 .05301 Mdot
.56965 .02138 Mdot
.53575 .02751 Mdot
.46624 .01863 Mdot
.47706 .02939 Mdot
.58989 .01073 Mdot
.40248 .07353 Mdot
.49549 .02633 Mdot
.4693 .06101 Mdot
.43607 .00964 Mdot
.43255 .04114 Mdot
.44183 .00865 Mdot
.44892 .06229 Mdot
.47218 .06143 Mdot
.51318 .03478 Mdot
.40594 .0428 Mdot
.43612 .0054 Mdot
.41606 .03207 Mdot
.43364 .00603 Mdot
.52057 .00574 Mdot
.56434 .01918 Mdot
.4845 .07026 Mdot
.53178 .0522 Mdot
.44267 .06161 Mdot
.48286 .06407 Mdot
.57049 .00018 Mdot
.56969 .02929 Mdot
.56455 .03154 Mdot
.53357 .02389 Mdot
.54849 .07363 Mdot
.49994 .01787 Mdot
.42792 .06789 Mdot
.5356 .07285 Mdot
.54343 .0718 Mdot
.40381 .02065 Mdot
.50076 .01019 Mdot
.52095 .03074 Mdot
.53027 .01001 Mdot
.55126 .00145 Mdot
.56572 .05264 Mdot
.41769 .05173 Mdot
.41723 .05317 Mdot
.51775 .03386 Mdot
.58931 .05944 Mdot
.58215 .03517 Mdot
.44588 .0618 Mdot
.57834 .01452 Mdot
.54513 .05162 Mdot
.45739 .05794 Mdot
.41486 .04161 Mdot
.50613 .05648 Mdot
.44914 .06313 Mdot
.48844 .00476 Mdot
.43191 .00997 Mdot
.57069 .04506 Mdot
.4426 .02469 Mdot
.58854 .00989 Mdot
.59672 .03705 Mdot
.4102 .06954 Mdot
.45159 .0596 Mdot
.55281 .0116 Mdot
.43673 .01799 Mdot
.44667 .02929 Mdot
.58759 .02902 Mdot
.55823 .02453 Mdot
.55569 .01906 Mdot
.58754 .05363 Mdot
.51309 .06853 Mdot
.599 .04374 Mdot
.51637 .03147 Mdot
.5888 .04837 Mdot
.46478 .04604 Mdot
.436 .03676 Mdot
.42805 .02805 Mdot
.58932 .00748 Mdot
.44046 .07319 Mdot
.43109 .05711 Mdot
.48477 .05413 Mdot
.44356 .00347 Mdot
.57168 .05977 Mdot
.44456 .0339 Mdot
.4553 .02829 Mdot
.45576 .05969 Mdot
.59052 .05642 Mdot
.41976 .02293 Mdot
.56247 .02837 Mdot
.43044 .01546 Mdot
.52201 .02935 Mdot
.59935 .03251 Mdot
.43724 .04938 Mdot
.55579 .02904 Mdot
.46556 .06378 Mdot
.51123 .06931 Mdot
.41026 .03548 Mdot
.45547 .00961 Mdot
.41974 .05323 Mdot
.43571 .06085 Mdot
.45727 .02485 Mdot
.40527 .04539 Mdot
.53526 .06967 Mdot
.40592 .01288 Mdot
.49803 .02028 Mdot
.45013 .05801 Mdot
.43246 .03067 Mdot
.5389 .06286 Mdot
.42221 .06935 Mdot
.48343 .05325 Mdot
.40247 .01612 Mdot
.44771 .06656 Mdot
.5452 .06544 Mdot
.44244 .02117 Mdot
.40993 .06993 Mdot
.43652 .00829 Mdot
.51191 .04965 Mdot
.58638 .02445 Mdot
.47944 .01898 Mdot
.44748 .03575 Mdot
.45723 .02379 Mdot
.56406 .05666 Mdot
.45477 .00767 Mdot
.51635 .06426 Mdot
.50957 .0164 Mdot
.4739 .04309 Mdot
.49964 .02063 Mdot
.43739 .0348 Mdot
.58773 .04514 Mdot
.451 .01036 Mdot
.50829 .02616 Mdot
.40352 .04877 Mdot
.45105 .00237 Mdot
.43946 .06627 Mdot
.59629 .06886 Mdot
.52311 .00201 Mdot
.48672 .05246 Mdot
.44921 .03308 Mdot
.58708 .03184 Mdot
.41182 .07244 Mdot
.59935 .06086 Mdot
.56082 .06209 Mdot
.49106 .03471 Mdot
.5573 .01331 Mdot
.44 .03234 Mdot
.51784 .0212 Mdot
.44372 .03764 Mdot
.59473 .01919 Mdot
.557 .05934 Mdot
.54552 .06028 Mdot
.56992 .0275 Mdot
.53369 .062 Mdot
.57057 .0408 Mdot
.57287 .07408 Mdot
.47951 .0061 Mdot
.41557 .06076 Mdot
.43951 .04792 Mdot
.49773 .03956 Mdot
.59579 .01028 Mdot
.503 .02036 Mdot
.43879 .0251 Mdot
.55749 .03425 Mdot
.46888 .07176 Mdot
.4238 .04642 Mdot
.49831 .03096 Mdot
.45092 .0465 Mdot
.4188 .02486 Mdot
.43535 .0599 Mdot
.57929 .0511 Mdot
.53762 .02035 Mdot
.5835 .04082 Mdot
.43462 .07415 Mdot
.54471 .01572 Mdot
.47713 .03989 Mdot
.47584 .01812 Mdot
.45333 .06764 Mdot
.57753 .06133 Mdot
.40241 .02114 Mdot
.55873 .03647 Mdot
.56705 .0354 Mdot
.57944 .05953 Mdot
.42943 .01505 Mdot
.59593 .01871 Mdot
.59481 .01507 Mdot
.45122 .00299 Mdot
.51769 .04934 Mdot
.57539 .05903 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo0026ooooo`03o`000?oooooo000000Co000000T00000
o`000?l0003o0000ooooo`00003ooooo00000?ooool00ol0000200000003ooooool0003o000000Co
000000?oooooo`00000000001?l000000`00003o0000o`000004o`000003ooooool0003o000000?o
0000J_ooool002KoooooQOl000000`00003o0000o`00001Yo`0000Wooooo000Vooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;Ooooolao`0002oooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Moooooc7o0000Goooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Mooooob[o000000?oooooo`00
0?l000000ol0001Pooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05go
oooo<Ol0001Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05gooooo
00?o0000ooooool00000;_l0001Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo05gooooo<Ol0001Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000G_oooola
o`0005kooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`1NooooobWo000000<00000o`00
0?l000001?l0001Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05go
oooo5?l000000`00003o0000o`00000Jo`0005oooooo00?o0000ooooooooool01oooool002Kooooo
00?o0000ooooooooool0GOooool7o`00000300000?l0003o000001co000000<00000o`000?l00000
2?l0001Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05gooooo1Ol0
00000`00003o0000o`00000Yo`0005oooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0GOoooolao`0005oooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0GOoooolao`0005oooooo00?o0000ooooooooool01oooool002Kooooo0_l0001Ooooooako
000000<00000o`000?l000003ol0001Nooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0
G_ooool7o`000003ooooool0003o000002Co000000?oooooo`000?ooool0G_ooool00ol0003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`1Moooooa?o000000<00000o`000?l000001ol0
00000`00003o0000o`00000Ao`0005oooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0GOooool5o`00008000002ol000001Ooooooo0000o`000?l00000000001Go000000Go
ooooo`00000000000000o`00001Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo
0_l0003]ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0kOooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Cooooo00Co0000oooooooooooo
oooo1Ol00004ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool001;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
0>gooooo00?o0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`04ooooo`;o0000k?ooool3o`0000Wooooo000Booooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo
00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool001;ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0kOoo
ool00ol0003oooooooooo`07ooooo`004oooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooo
oooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo0_l0
003]ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool0
02Kooooo0_l0003]ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]oooo
o`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_oo
ool2o`000>gooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0kOooool00ol0003ooooo
ooooo`07ooooo`004_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003ooooooooo
ool00007ooooo`Go00001?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo
000Booooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool2o`000>co
oooo0ol00009ooooo`004_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003ooooo
ooooool00009ooooo`;o00001Oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oo
oooo000Cooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>gooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo0_l0003]ooooo`;o
00002Oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oo
oooo0007ooooo`?o00007?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`002?ooool00ol0003oooooooooo`0Kooooo`;o0000kOooool2o`0000Wooooo0008oooo
o`;o00007?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o
000000?oooooo`000?l000006_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000oooo
ooooool01oooool002Kooooo0_l0003]ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0
kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0kOooool00ol0003o
ooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Booooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo0>gooooo00?o0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool4
o`0000Gooooo0_l0003/ooooo`?o00002Oooool001;ooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool0
01;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0>gooooo00?o0000ooooooooool01oooool001?ooooo0_l0000:ooooo`;o00001Oooool00ol0
003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>go
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000V
ooooo`;o0000kOooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`;o0000kOooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0>gooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`00
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01ooo
ool002Kooooo0_l0003]ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0kOooool00ol0
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Cooooo00?o0000
ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07
ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`;o0000k?ooool3o`0000Wooooo
000Booooo`04o`000?ooooooooooo`0000Sooooo0ol00005ooooo`03o`000?oooooooooo0>gooooo
00?o0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`00
4_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Cooooo`;o00002Oooool3o`0000Go
oooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07
ooooo`009_ooool2o`000>gooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03
o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003o
ooooooooo`07ooooo`009_ooool2o`000>gooooo0_l00009ooooo`009_ooool00ol0003ooooooooo
o`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOoo
ool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`;o0000kOooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0>go
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000N
ooooo`?o00001Oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Ooooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`00
0?oooooooooo00CooooolOl00009ooooo`007oooool00ol0003oooooooooo`3nooooo`007_ooool2
o`000?oooooo0Oooool001oooooo00?o0000ooooooooool0o_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 302.812}, {630.188, 488.875}} -> {-0.54256, \
3.96302, 0.00417185, 0.0067502}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.50172 .02309 Mdot
.85185 .15698 Mdot
.4616 .61782 Mdot
.40731 .59837 Mdot
.60615 .06876 Mdot
.48082 .01306 Mdot
.50861 .02667 Mdot
.46054 .61605 Mdot
.49703 .01631 Mdot
.33369 .5693 Mdot
.74127 .11638 Mdot
.41563 .60474 Mdot
.49147 .00177 Mdot
.42446 .60887 Mdot
.40425 .60418 Mdot
.27681 .5418 Mdot
.66393 .08169 Mdot
.65635 .07162 Mdot
.52642 .03716 Mdot
.44705 .5997 Mdot
.77078 .10823 Mdot
.4902 .01608 Mdot
.40837 .59683 Mdot
.33034 .55828 Mdot
.66352 .06764 Mdot
.76771 .11122 Mdot
.63448 .06617 Mdot
.75057 .10073 Mdot
.83195 .14603 Mdot
.47155 .0151 Mdot
.68414 .09566 Mdot
.76976 .1232 Mdot
.65476 .07481 Mdot
.53343 .0168 Mdot
.49861 .00469 Mdot
.45697 .60429 Mdot
.70303 .10265 Mdot
.55261 .03779 Mdot
.32604 .56644 Mdot
.54551 .02573 Mdot
.35463 .58142 Mdot
.4462 .61151 Mdot
.53406 .03063 Mdot
.54226 .03456 Mdot
.6276 .04747 Mdot
.7538 .10735 Mdot
.50092 .02543 Mdot
.55192 .03154 Mdot
.66663 .08888 Mdot
.37653 .5977 Mdot
.59788 .05228 Mdot
.5738 .04218 Mdot
.49949 4e-05 Mdot
.37971 .57534 Mdot
.34146 .57263 Mdot
.70377 .08734 Mdot
.45704 .61365 Mdot
.81192 .14188 Mdot
.33478 .57503 Mdot
.5155 .02103 Mdot
.52961 .02971 Mdot
.51634 .02738 Mdot
.67854 .06816 Mdot
.68945 .07599 Mdot
.43246 .59556 Mdot
.56388 .02854 Mdot
.46765 .0085 Mdot
.72612 .1056 Mdot
.75308 .10093 Mdot
.77663 .12592 Mdot
.79774 .13123 Mdot
.51499 .01456 Mdot
.52425 .0126 Mdot
.37396 .58996 Mdot
.59216 .03495 Mdot
.42756 .60238 Mdot
.53081 .03956 Mdot
.61218 .04758 Mdot
.32018 .56074 Mdot
.74985 .10501 Mdot
.42808 .00306 Mdot
.35221 .58415 Mdot
.37221 .57755 Mdot
.57939 .03942 Mdot
.59521 .03792 Mdot
.58057 .05214 Mdot
.74381 .08997 Mdot
.40582 .59486 Mdot
.59223 .03757 Mdot
.54143 .02058 Mdot
.64872 .08045 Mdot
.65638 .07922 Mdot
.59513 .06162 Mdot
.56209 .0253 Mdot
.47603 .01132 Mdot
.36093 .59046 Mdot
.62956 .06533 Mdot
.64218 .08211 Mdot
.62654 .06237 Mdot
.48854 .01392 Mdot
.77607 .11242 Mdot
.69482 .08463 Mdot
.50553 .01848 Mdot
.41352 .60804 Mdot
.77523 .12054 Mdot
.59793 .05525 Mdot
.67486 .09417 Mdot
.61518 .06933 Mdot
.786 .1158 Mdot
.83502 .14916 Mdot
.53878 .04064 Mdot
.60463 .04757 Mdot
.50451 .01587 Mdot
.7748 .12671 Mdot
.37782 .60233 Mdot
.61737 .04776 Mdot
.34323 .56872 Mdot
.3932 .59433 Mdot
.5338 .02056 Mdot
.64466 .07176 Mdot
.60851 .06589 Mdot
.67148 .08442 Mdot
.44344 .009 Mdot
.32481 .56709 Mdot
.68428 .08296 Mdot
.41134 .60189 Mdot
.68546 .08569 Mdot
.54094 .02693 Mdot
.59756 .04559 Mdot
.52126 .03427 Mdot
.31831 .55317 Mdot
.62547 .05452 Mdot
.57529 .03333 Mdot
.33309 .57522 Mdot
.50546 .00802 Mdot
.74867 .09489 Mdot
.6892 .0907 Mdot
.71619 .09797 Mdot
.74501 .09232 Mdot
.42775 .59791 Mdot
.526 .03349 Mdot
.76808 .10727 Mdot
.46322 .00906 Mdot
.40106 .5833 Mdot
.6363 .06743 Mdot
.44712 .61322 Mdot
.38376 .58655 Mdot
.43984 .60572 Mdot
.56109 .04254 Mdot
.59112 .05502 Mdot
.5576 .03768 Mdot
.41592 .60205 Mdot
.40597 .60638 Mdot
.38916 .58212 Mdot
.80561 .14174 Mdot
.73035 .08673 Mdot
.42473 .60299 Mdot
.66079 .07767 Mdot
.29851 .54643 Mdot
.47217 .61607 Mdot
.60121 .04889 Mdot
.74706 .10742 Mdot
.41775 .61327 Mdot
.5866 .03407 Mdot
.27139 .53815 Mdot
.56922 .05255 Mdot
.32618 .55734 Mdot
.58176 .05412 Mdot
.76435 .11683 Mdot
.66852 .06764 Mdot
.72391 .10071 Mdot
.56856 .05243 Mdot
.37705 .57984 Mdot
.56761 .03531 Mdot
.33742 .57108 Mdot
.72591 .09079 Mdot
.32567 .56421 Mdot
.53154 .02269 Mdot
.74055 .09405 Mdot
.32928 .57393 Mdot
.35512 .58223 Mdot
.4012 .59309 Mdot
.49368 .0257 Mdot
.69883 .08714 Mdot
.37414 .59386 Mdot
.38453 .57921 Mdot
.77705 .10952 Mdot
.52269 .03359 Mdot
.83105 .15077 Mdot
.73696 .10101 Mdot
.83091 .1435 Mdot
.78728 .1325 Mdot
.73538 .09252 Mdot
.64151 .0681 Mdot
.61852 .0525 Mdot
.68722 .07029 Mdot
.62102 .06224 Mdot
.67782 .09375 Mdot
.58433 .03947 Mdot
.40636 .58625 Mdot
.61657 .05142 Mdot
.53481 .03124 Mdot
.6463 .06901 Mdot
.6137 .06324 Mdot
.65406 .06495 Mdot
.7169 .08458 Mdot
.41221 .61606 Mdot
.28872 .54521 Mdot
.53522 .02481 Mdot
.47288 .61337 Mdot
.69675 .07549 Mdot
.32171 .55566 Mdot
.45585 .00903 Mdot
.65186 .07014 Mdot
.55715 .03124 Mdot
.41251 .60908 Mdot
.65006 .05713 Mdot
.43828 .61267 Mdot
.61488 .0449 Mdot
.40808 .59807 Mdot
.45186 .00291 Mdot
.68109 .07485 Mdot
.49981 .01685 Mdot
.61549 .0483 Mdot
.41891 .61037 Mdot
.8242 .13921 Mdot
.60844 .05175 Mdot
.79124 .13552 Mdot
.7037 .08443 Mdot
.60791 .05123 Mdot
.34517 .56878 Mdot
.57209 .05406 Mdot
.75605 .11022 Mdot
.63871 .07049 Mdot
.63102 .07778 Mdot
.76638 .11067 Mdot
.46545 .61284 Mdot
.80257 .13239 Mdot
.72552 .10901 Mdot
.39008 .60178 Mdot
.76465 .11286 Mdot
.52633 .0216 Mdot
.67716 .07416 Mdot
.33213 .57192 Mdot
.78348 .12609 Mdot
.55546 .04534 Mdot
.52752 .03289 Mdot
.53255 .02334 Mdot
.32162 .56931 Mdot
.59328 .05367 Mdot
.45653 .00322 Mdot
.5789 .05492 Mdot
.43565 .59725 Mdot
.79327 .12026 Mdot
.62636 .07061 Mdot
.84077 .15379 Mdot
.58767 .034 Mdot
.54289 .02044 Mdot
.43137 .60136 Mdot
.38632 .60028 Mdot
.48932 .01942 Mdot
.53706 .01759 Mdot
.2911 .54667 Mdot
.33344 .56543 Mdot
.59731 .0371 Mdot
.40062 .60613 Mdot
.34553 .56882 Mdot
.42095 .61371 Mdot
.50344 .00675 Mdot
.62434 .06564 Mdot
.44557 .00704 Mdot
.61405 .06857 Mdot
.69986 .07638 Mdot
.8188 .13863 Mdot
.78769 .13472 Mdot
.74453 .1042 Mdot
.4462 .00852 Mdot
.72147 .10223 Mdot
.35948 .58851 Mdot
.67568 .09121 Mdot
.59827 .05163 Mdot
.30859 .55538 Mdot
.5256 .02784 Mdot
.55745 .03126 Mdot
.57134 .04144 Mdot
.60046 .05443 Mdot
.64993 .07129 Mdot
.6012 .04002 Mdot
.57716 .04635 Mdot
.74342 .10075 Mdot
.59543 .06212 Mdot
.44365 .61269 Mdot
.7421 .10006 Mdot
.39297 .58752 Mdot
.5916 .05683 Mdot
.7032 .10367 Mdot
.76185 .1029 Mdot
.35761 .57757 Mdot
.49051 .01838 Mdot
.50151 .0092 Mdot
.66078 .06314 Mdot
.62301 .07217 Mdot
.4378 .60203 Mdot
.43138 .6041 Mdot
.56025 .04743 Mdot
.29604 .54662 Mdot
.71287 .07973 Mdot
.45582 .60548 Mdot
.81162 .13789 Mdot
.47354 .01267 Mdot
.57823 .03121 Mdot
.71816 .09379 Mdot
.78245 .13185 Mdot
.46864 .00523 Mdot
.59835 .05743 Mdot
.29559 .54965 Mdot
.41279 .61239 Mdot
.74005 .08986 Mdot
.44186 .00236 Mdot
.66252 .089 Mdot
.49244 .02652 Mdot
.44047 .60258 Mdot
.66264 .08704 Mdot
.58903 .0556 Mdot
.74562 .11924 Mdot
.37325 .57746 Mdot
.40014 .58891 Mdot
.3364 .55855 Mdot
.36462 .5805 Mdot
.45748 .01203 Mdot
.78456 .12191 Mdot
.66249 .08838 Mdot
.66932 .0813 Mdot
.47345 .01202 Mdot
.38289 .59758 Mdot
.75184 .12169 Mdot
.50054 .02302 Mdot
.63241 .07191 Mdot
.35711 .58162 Mdot
.54908 .0406 Mdot
.73355 .0883 Mdot
.46549 .01242 Mdot
.3285 .57176 Mdot
.67116 .08978 Mdot
.52031 .03382 Mdot
.44905 .60392 Mdot
.39405 .58369 Mdot
.56532 .0299 Mdot
.75648 .10516 Mdot
.31234 .56331 Mdot
.77799 .12836 Mdot
.62383 .06572 Mdot
.78568 .12735 Mdot
.5302 .0359 Mdot
.71651 .08668 Mdot
.72769 .11216 Mdot
.57091 .03724 Mdot
.53 .0344 Mdot
.42871 .59806 Mdot
.71261 .09593 Mdot
.53554 .0376 Mdot
.65978 .06383 Mdot
.62399 .07391 Mdot
.4099 .60004 Mdot
.58325 .03614 Mdot
.74476 .10992 Mdot
.73144 .11305 Mdot
.39389 .60147 Mdot
.41398 .60327 Mdot
.72821 .11239 Mdot
.72908 .09409 Mdot
.75788 .1044 Mdot
.56812 .04078 Mdot
.35618 .57089 Mdot
.80508 .12815 Mdot
.80758 .13234 Mdot
.48092 .00492 Mdot
.32168 .55322 Mdot
.61803 .05784 Mdot
.30687 .55686 Mdot
.57656 .05562 Mdot
.44024 .60613 Mdot
.59303 .05148 Mdot
.54512 .04609 Mdot
.28257 .54076 Mdot
.44402 .00367 Mdot
.3379 .57356 Mdot
.37787 .57677 Mdot
.59957 .03873 Mdot
.31375 .55355 Mdot
.35841 .58462 Mdot
.38618 .60194 Mdot
.64518 .07372 Mdot
.68858 .08397 Mdot
.30805 .55122 Mdot
.51521 .02041 Mdot
.28482 .54156 Mdot
.44517 .00066 Mdot
.8073 .12892 Mdot
.80773 .12871 Mdot
.46709 .00328 Mdot
.75361 .10644 Mdot
.48593 .02263 Mdot
.74602 .1093 Mdot
.58918 .04064 Mdot
.31491 .55528 Mdot
.53699 .01837 Mdot
.66369 .07998 Mdot
.50959 .00673 Mdot
.59064 .06209 Mdot
.56299 .03893 Mdot
.52338 .02019 Mdot
.34875 .56275 Mdot
.6345 .07737 Mdot
.72497 .0841 Mdot
.63462 .05839 Mdot
.51289 .02931 Mdot
.57588 .03226 Mdot
.72356 .1022 Mdot
.77499 .1147 Mdot
.46656 .00436 Mdot
.5613 .03837 Mdot
.65085 .05646 Mdot
.29535 .5481 Mdot
.55638 .02169 Mdot
.52341 .01496 Mdot
.69435 .10009 Mdot
.75614 .1218 Mdot
.43255 .59679 Mdot
.43478 .61766 Mdot
.57669 .042 Mdot
.40176 .5907 Mdot
.48208 .02031 Mdot
.70791 .0996 Mdot
.57789 .05449 Mdot
.67045 .0817 Mdot
.76827 .12351 Mdot
.3998 .59378 Mdot
.44929 .00819 Mdot
.50951 .01824 Mdot
.7613 .11878 Mdot
.44896 .00268 Mdot
.43845 .60447 Mdot
.78779 .1169 Mdot
.33385 .57025 Mdot
.45926 .00456 Mdot
.61906 .06033 Mdot
.53714 .01454 Mdot
.71629 .10092 Mdot
.50974 .02174 Mdot
.64098 .07665 Mdot
.74195 .09108 Mdot
.62542 .04794 Mdot
.67163 .0752 Mdot
.55868 .04401 Mdot
.74445 .11936 Mdot
.48176 .00337 Mdot
.53762 .02359 Mdot
.73084 .10876 Mdot
.7443 .09794 Mdot
.27386 .53892 Mdot
.61086 .06155 Mdot
.49371 .00545 Mdot
.61069 .05809 Mdot
.61668 .04922 Mdot
.68497 .07306 Mdot
.42978 .6058 Mdot
.31798 .55781 Mdot
.69305 .07404 Mdot
.64444 .07939 Mdot
.33972 .56941 Mdot
.64375 .07021 Mdot
.32538 .5617 Mdot
.40834 .61153 Mdot
.69572 .10142 Mdot
.54241 .02487 Mdot
.82065 .13971 Mdot
.6041 .04244 Mdot
.64944 .06454 Mdot
.66236 .08799 Mdot
.69983 .07916 Mdot
.27653 .53924 Mdot
.73753 .11382 Mdot
.49412 .01251 Mdot
.66881 .08156 Mdot
.4617 .00413 Mdot
.35152 .58485 Mdot
.66694 .07052 Mdot
.39135 .60612 Mdot
.31934 .55742 Mdot
.48448 .01166 Mdot
.52142 .01483 Mdot
.53063 .02273 Mdot
.50346 .00621 Mdot
.66096 .07445 Mdot
.38459 .59645 Mdot
.37098 .59784 Mdot
.66608 .06278 Mdot
.75981 .09973 Mdot
.37702 .59662 Mdot
.74805 .09903 Mdot
.79834 .12614 Mdot
.64045 .07308 Mdot
.53504 .02363 Mdot
.36352 .57797 Mdot
.29031 .54814 Mdot
.56833 .04974 Mdot
.76632 .11275 Mdot
.57604 .05676 Mdot
.35846 .58039 Mdot
.55698 .04402 Mdot
.36067 .58896 Mdot
.55232 .0336 Mdot
.30288 .54968 Mdot
.77752 .1247 Mdot
.6315 .07097 Mdot
.67079 .07625 Mdot
.59994 .05357 Mdot
.47417 .00903 Mdot
.57764 .02983 Mdot
.76335 .11618 Mdot
.59453 .05224 Mdot
.58058 .05623 Mdot
.6115 .0675 Mdot
.77078 .11071 Mdot
.56493 .04705 Mdot
.37228 .59107 Mdot
.67971 .06648 Mdot
.44497 .60349 Mdot
.4541 .61507 Mdot
.34847 .58066 Mdot
.62527 .05918 Mdot
.44648 .00797 Mdot
.40606 .60971 Mdot
.61221 .04216 Mdot
.65944 .08788 Mdot
.70338 .09335 Mdot
.34815 .56841 Mdot
.70782 .10592 Mdot
.41202 .59067 Mdot
.51396 .02844 Mdot
.81883 .13685 Mdot
.42317 .5959 Mdot
.45259 .60858 Mdot
.35293 .57325 Mdot
.42263 .60213 Mdot
.4859 .00277 Mdot
.63149 .06203 Mdot
.6508 .07524 Mdot
.53721 .02134 Mdot
.80503 .13127 Mdot
.37753 .57548 Mdot
.66896 .08916 Mdot
.41953 .59984 Mdot
.49701 .01935 Mdot
.71077 .08016 Mdot
.39982 .59302 Mdot
.66434 .08135 Mdot
.6599 .06243 Mdot
.29213 .55038 Mdot
.38423 .58986 Mdot
.61569 .07217 Mdot
.44054 .00206 Mdot
.49072 .0236 Mdot
.63899 .07817 Mdot
.33014 .57265 Mdot
.39387 .58531 Mdot
.36002 .57943 Mdot
.37259 .59707 Mdot
.56081 .0439 Mdot
.45418 .00405 Mdot
.52791 .02455 Mdot
.32732 .56211 Mdot
.7753 .11497 Mdot
.7487 .10389 Mdot
.66205 .07744 Mdot
.48511 .01052 Mdot
.59073 .03557 Mdot
.34715 .57222 Mdot
.60559 .05866 Mdot
.35375 .58033 Mdot
.41964 .61725 Mdot
.762 .12043 Mdot
.63657 .06419 Mdot
.69187 .08809 Mdot
.7239 .11154 Mdot
.68608 .07253 Mdot
.32005 .56449 Mdot
.57446 .04563 Mdot
.47127 .61664 Mdot
.48215 .00173 Mdot
.73305 .10519 Mdot
.50477 .02483 Mdot
.68994 .09147 Mdot
.60937 .06917 Mdot
.31101 .55733 Mdot
.66523 .07237 Mdot
.44944 .60792 Mdot
.72219 .08825 Mdot
.50755 .02993 Mdot
.52271 .02716 Mdot
.77969 .11996 Mdot
.78104 .11226 Mdot
.42481 .00127 Mdot
.6558 .07477 Mdot
.47972 .61736 Mdot
.41925 .60684 Mdot
.54612 .04608 Mdot
.50053 .00698 Mdot
.35497 .58664 Mdot
.64344 .08257 Mdot
.70898 .10033 Mdot
.37404 .58278 Mdot
.67196 .06854 Mdot
.33341 .55731 Mdot
.62332 .05254 Mdot
.54407 .02918 Mdot
.39498 .57939 Mdot
.49789 .02373 Mdot
.71216 .07801 Mdot
.74332 .10696 Mdot
.73646 .09659 Mdot
.47388 .00832 Mdot
.40438 .60002 Mdot
.35588 .57263 Mdot
.47752 .00312 Mdot
.76312 .10225 Mdot
.60305 .04257 Mdot
.59807 .0601 Mdot
.45934 .60733 Mdot
.47282 .01946 Mdot
.4909 .0001 Mdot
.47436 .00203 Mdot
.6194 .06727 Mdot
.37779 .59772 Mdot
.46802 .61247 Mdot
.76319 .11241 Mdot
.36902 .59607 Mdot
.74059 .09701 Mdot
.5074 .02288 Mdot
.51826 .02192 Mdot
.78994 .12128 Mdot
.41934 .60436 Mdot
.55703 .03341 Mdot
.68984 .07383 Mdot
.79997 .12827 Mdot
.6903 .0807 Mdot
.58968 .04592 Mdot
.78926 .1303 Mdot
.59912 .05456 Mdot
.78942 .12028 Mdot
.46406 .01459 Mdot
.64945 .08495 Mdot
.41555 .59875 Mdot
.48235 .0073 Mdot
.72621 .11275 Mdot
.53886 .02392 Mdot
.66808 .07213 Mdot
.71582 .1084 Mdot
.45226 .01006 Mdot
.67017 .06686 Mdot
.6004 .04651 Mdot
.74186 .10794 Mdot
.5086 .01478 Mdot
.46624 .00682 Mdot
.46684 .01787 Mdot
.72735 .08818 Mdot
.48747 .6139 Mdot
.56444 .0494 Mdot
.68729 .08931 Mdot
.71709 .10692 Mdot
.60837 .06277 Mdot
.79004 .12852 Mdot
.75251 .1056 Mdot
.3066 .5511 Mdot
.49925 .00141 Mdot
.70316 .08867 Mdot
.40542 .5849 Mdot
.71786 .08828 Mdot
.6646 .06164 Mdot
.52759 .02292 Mdot
.35383 .57585 Mdot
.67866 .08173 Mdot
.61081 .05904 Mdot
.75161 .11575 Mdot
.60265 .04266 Mdot
.70243 .09456 Mdot
.35627 .56835 Mdot
.74136 .09371 Mdot
.69447 .07221 Mdot
.40243 .61044 Mdot
.40821 .61522 Mdot
.61868 .05839 Mdot
.7953 .12647 Mdot
.80458 .14017 Mdot
.44185 .5973 Mdot
.31125 .55486 Mdot
.70796 .10272 Mdot
.47179 .00479 Mdot
.60489 .06168 Mdot
.47312 .6173 Mdot
.65566 .07923 Mdot
.4472 .61038 Mdot
.62407 .0676 Mdot
.6973 .10007 Mdot
.57142 .02929 Mdot
.75669 .12305 Mdot
.38119 .57635 Mdot
.70277 .09804 Mdot
.54118 .0212 Mdot
.48236 .0014 Mdot
.31546 .56469 Mdot
.38744 .6067 Mdot
.5206 .0286 Mdot
.68181 .08382 Mdot
.76425 .12646 Mdot
.36193 .58783 Mdot
.44739 .00728 Mdot
.46748 .00882 Mdot
.80852 .13693 Mdot
.63285 .0765 Mdot
.52381 .02702 Mdot
.40407 .60264 Mdot
.46754 .61138 Mdot
.39566 .60102 Mdot
.32559 .56958 Mdot
.45859 .60665 Mdot
.42238 .60445 Mdot
.47381 .0047 Mdot
.35329 .58376 Mdot
.38337 .59971 Mdot
.40566 .60807 Mdot
.61411 .06809 Mdot
.62655 .05245 Mdot
.46369 .61107 Mdot
.41031 .58523 Mdot
.4434 .61286 Mdot
.46347 .00252 Mdot
.72975 .09578 Mdot
.29809 .54576 Mdot
.63039 .0753 Mdot
.32419 .5673 Mdot
.50343 .00487 Mdot
.77934 .12042 Mdot
.75186 .09904 Mdot
.40978 .59762 Mdot
.54573 .01798 Mdot
.74324 .10124 Mdot
.47391 .00559 Mdot
.65523 .08356 Mdot
.48967 .61777 Mdot
.61319 .06687 Mdot
.72398 .08803 Mdot
.54698 .02983 Mdot
.47586 .61177 Mdot
.63174 .07264 Mdot
.58652 .05694 Mdot
.47406 .00164 Mdot
.78616 .12879 Mdot
.59571 .06412 Mdot
.56724 .03358 Mdot
.68676 .07096 Mdot
.33209 .56197 Mdot
.44756 .60605 Mdot
.47033 .01796 Mdot
.76711 .12291 Mdot
.74085 .1147 Mdot
.3894 .57809 Mdot
.40657 .58448 Mdot
.77913 .12144 Mdot
.48529 .00135 Mdot
.55892 .04219 Mdot
.7846 .13251 Mdot
.61846 .06164 Mdot
.70933 .10008 Mdot
.42242 .59989 Mdot
.61204 .06545 Mdot
.52114 .02324 Mdot
.73824 .11581 Mdot
.38608 .59119 Mdot
.58356 .05783 Mdot
.4695 .01399 Mdot
.35614 .58667 Mdot
.65738 .06252 Mdot
.43281 .61564 Mdot
.41299 .60289 Mdot
.58996 .06221 Mdot
.73315 .09112 Mdot
.72231 .08599 Mdot
.58818 .05315 Mdot
.36141 .57422 Mdot
.45573 .60756 Mdot
.64408 .06289 Mdot
.36148 .57829 Mdot
.66608 .08075 Mdot
.44865 .6051 Mdot
.60618 .06641 Mdot
.41084 .6049 Mdot
.39345 .60815 Mdot
.42001 .60174 Mdot
.41224 .60937 Mdot
.69947 .09596 Mdot
.7919 .12234 Mdot
.49502 .01451 Mdot
.40623 .58997 Mdot
.38887 .58288 Mdot
.60856 .05708 Mdot
.80462 .14119 Mdot
.37789 .59357 Mdot
.65031 .06566 Mdot
.36373 .59065 Mdot
.60266 .06487 Mdot
.81254 .14262 Mdot
.65084 .06017 Mdot
.76134 .10723 Mdot
.5276 .02821 Mdot
.61234 .04706 Mdot
.39278 .5912 Mdot
.37919 .59282 Mdot
.45194 .61303 Mdot
.38076 .60459 Mdot
.55012 .0211 Mdot
.75742 .10071 Mdot
.32282 .55903 Mdot
.3242 .56335 Mdot
.41559 .58762 Mdot
.42395 .61747 Mdot
.75208 .10459 Mdot
.55702 .04224 Mdot
.61638 .0431 Mdot
.4331 .59604 Mdot
.53609 .03059 Mdot
.4314 .59654 Mdot
.73246 .10002 Mdot
.53565 .03952 Mdot
.66699 .07086 Mdot
.46837 .00578 Mdot
.50325 .00971 Mdot
.42068 .60971 Mdot
.61561 .06856 Mdot
.72995 .11401 Mdot
.74632 .11636 Mdot
.5482 .04413 Mdot
.4624 .61245 Mdot
.37399 .59539 Mdot
.59627 .05899 Mdot
.70105 .1002 Mdot
.67675 .07927 Mdot
.48402 .00254 Mdot
.42522 .59595 Mdot
.43763 .61301 Mdot
.67728 .07479 Mdot
.57518 .04629 Mdot
.79161 .11951 Mdot
.40147 .60444 Mdot
.58843 .03809 Mdot
.40648 .6141 Mdot
.36631 .58116 Mdot
.44858 .60237 Mdot
.55459 .04766 Mdot
.82641 .14362 Mdot
.3855 .59886 Mdot
.6473 .06121 Mdot
.45143 .61258 Mdot
.44461 .61594 Mdot
.52057 .03618 Mdot
.42032 .61544 Mdot
.68098 .09008 Mdot
.39278 .60636 Mdot
.56905 .03695 Mdot
.68714 .09234 Mdot
.38768 .59078 Mdot
.72238 .11043 Mdot
.38066 .59666 Mdot
.81637 .13654 Mdot
.67228 .07249 Mdot
.63052 .05134 Mdot
.52389 .01911 Mdot
.58533 .03856 Mdot
.7106 .09447 Mdot
.56935 .03589 Mdot
.39477 .58484 Mdot
.74781 .1077 Mdot
.38448 .59811 Mdot
.40187 .60075 Mdot
.26338 .5327 Mdot
.44647 .00746 Mdot
.45171 .00324 Mdot
.56216 .04648 Mdot
.67481 .07498 Mdot
.72412 .09896 Mdot
.82532 .14188 Mdot
.40836 .59062 Mdot
.68936 .08782 Mdot
.52571 .02876 Mdot
.68127 .09314 Mdot
.3784 .5742 Mdot
.67719 .09152 Mdot
.30941 .55282 Mdot
.47728 .61472 Mdot
.61107 .05135 Mdot
.67067 .08747 Mdot
.75203 .11622 Mdot
.58672 .03296 Mdot
.59726 .05315 Mdot
.76048 .10775 Mdot
.44472 .00781 Mdot
.45601 .00027 Mdot
.80901 .13984 Mdot
.64753 .07482 Mdot
.75806 .11757 Mdot
.42222 .60468 Mdot
.40196 .59462 Mdot
.61954 .0648 Mdot
.51537 .02442 Mdot
.77724 .1211 Mdot
.66531 .06224 Mdot
.75743 .10028 Mdot
.59596 .03921 Mdot
.68003 .08679 Mdot
.65056 .06229 Mdot
.2893 .54151 Mdot
.7553 .10714 Mdot
.72919 .09882 Mdot
.6101 .04202 Mdot
.48379 .01804 Mdot
.46598 .61787 Mdot
.45058 .60399 Mdot
.54765 .02844 Mdot
.55471 .04732 Mdot
.69813 .07973 Mdot
.6234 .05244 Mdot
.3047 .54718 Mdot
.59088 .04046 Mdot
.41133 .60192 Mdot
.72687 .10552 Mdot
.5481 .03264 Mdot
.61573 .07058 Mdot
.33598 .56052 Mdot
.41895 .61231 Mdot
.65463 .07863 Mdot
.7295 .11089 Mdot
.70154 .08854 Mdot
.36349 .58835 Mdot
.65331 .07069 Mdot
.51575 .01832 Mdot
.61496 .07011 Mdot
.65686 .07841 Mdot
.32486 .56774 Mdot
.41497 .6097 Mdot
.72988 .09437 Mdot
.37566 .60284 Mdot
.45077 .00061 Mdot
.38653 .57871 Mdot
.49605 .00281 Mdot
.40082 .59466 Mdot
.71073 .09775 Mdot
.63141 .04875 Mdot
.46835 .01069 Mdot
.35024 .57335 Mdot
.40199 .59156 Mdot
.79624 .12493 Mdot
.53631 .04244 Mdot
.80025 .12756 Mdot
.34184 .57105 Mdot
.67213 .07938 Mdot
.59022 .03946 Mdot
.52439 .01196 Mdot
.74432 .10539 Mdot
.64014 .05415 Mdot
.65092 .07923 Mdot
.66559 .08382 Mdot
.5008 .01415 Mdot
.61108 .04648 Mdot
.34174 .57569 Mdot
.67253 .08066 Mdot
.74062 .09161 Mdot
.7411 .08823 Mdot
.52827 .03846 Mdot
.59592 .06343 Mdot
.52965 .02311 Mdot
.70368 .10069 Mdot
.74532 .10865 Mdot
.29539 .54671 Mdot
.49791 .0039 Mdot
.54712 .04462 Mdot
.53325 .03208 Mdot
.62335 .0559 Mdot
.53492 .02841 Mdot
.62298 .05465 Mdot
.38149 .59243 Mdot
.39946 .59219 Mdot
.59709 .04106 Mdot
.56312 .0387 Mdot
.71653 .09603 Mdot
.52464 .02159 Mdot
.47115 .00099 Mdot
.35368 .58027 Mdot
.80102 .13153 Mdot
.47402 .61317 Mdot
.52279 .01455 Mdot
.71953 .10643 Mdot
.5159 .02445 Mdot
.57309 .04143 Mdot
.66745 .07526 Mdot
.38814 .60728 Mdot
.81374 .14166 Mdot
.60531 .05529 Mdot
.59871 .05175 Mdot
.50768 .00409 Mdot
.66086 .08287 Mdot
.40887 .61166 Mdot
.39198 .59606 Mdot
.43337 .59425 Mdot
.74118 .11742 Mdot
.72727 .0998 Mdot
.33229 .57278 Mdot
.71795 .09746 Mdot
.37931 .59227 Mdot
.36643 .56984 Mdot
.52576 .0122 Mdot
.72626 .11305 Mdot
.72986 .09309 Mdot
.5732 .0303 Mdot
.71509 .10097 Mdot
.39125 .58029 Mdot
.35347 .58896 Mdot
.53014 .02696 Mdot
.76152 .10292 Mdot
.67985 .09492 Mdot
.76137 .11581 Mdot
.56535 .05159 Mdot
.48988 .01355 Mdot
.70767 .10454 Mdot
.50486 .00997 Mdot
.391 .6036 Mdot
.65791 .07471 Mdot
.74237 .11145 Mdot
.68399 .09114 Mdot
.46474 .61137 Mdot
.66394 .07565 Mdot
.65339 .06436 Mdot
.76631 .12284 Mdot
.45962 .61323 Mdot
.52976 .01866 Mdot
.62081 .05682 Mdot
.4018 .61244 Mdot
.60612 .05662 Mdot
.48669 .00794 Mdot
.73002 .10974 Mdot
.67153 .08295 Mdot
.51697 .02474 Mdot
.74888 .09462 Mdot
.61208 .05215 Mdot
.36169 .5769 Mdot
.40363 .58301 Mdot
.57808 .03054 Mdot
.65166 .0743 Mdot
.55334 .02196 Mdot
.30139 .54663 Mdot
.43861 .61472 Mdot
.43481 .59971 Mdot
.63485 .07922 Mdot
.78101 .11959 Mdot
.62744 .07204 Mdot
.42587 .59705 Mdot
.51942 .02274 Mdot
.76268 .10084 Mdot
.68951 .08377 Mdot
.49058 .0139 Mdot
.39021 .58964 Mdot
.44559 .61459 Mdot
.81317 .13659 Mdot
.75373 .10323 Mdot
.55595 .04354 Mdot
.8331 .14457 Mdot
.79441 .13584 Mdot
.66671 .07871 Mdot
.5291 .02293 Mdot
.64447 .06466 Mdot
.7075 .10474 Mdot
.52506 .03294 Mdot
.57039 .04234 Mdot
.33527 .5653 Mdot
.61961 .06792 Mdot
.44315 .00571 Mdot
.31795 .55236 Mdot
.3505 .56598 Mdot
.38649 .57904 Mdot
.55047 .03406 Mdot
.72426 .10301 Mdot
.6537 .06068 Mdot
.39316 .60172 Mdot
.50058 .01039 Mdot
.56765 .03089 Mdot
.42064 .59175 Mdot
.32565 .56717 Mdot
.35328 .57108 Mdot
.74867 .10193 Mdot
.74385 .09228 Mdot
.61876 .05229 Mdot
.57158 .04475 Mdot
.75864 .11253 Mdot
.66539 .07523 Mdot
.74312 .11502 Mdot
.4163 .59109 Mdot
.42942 .6119 Mdot
.73675 .08654 Mdot
.36231 .57534 Mdot
.76269 .12066 Mdot
.47618 .01763 Mdot
.75987 .11553 Mdot
.60559 .05692 Mdot
.44225 .59857 Mdot
.5921 .0341 Mdot
.6456 .07139 Mdot
.71268 .08207 Mdot
.48046 .00634 Mdot
.65976 .07368 Mdot
.48486 .00704 Mdot
.55126 .02602 Mdot
.58898 .05128 Mdot
.44706 .6091 Mdot
.69497 .10006 Mdot
.7098 .09998 Mdot
.50392 .02756 Mdot
.37512 .59579 Mdot
.60714 .04815 Mdot
.40382 .6011 Mdot
.49786 .02399 Mdot
.49023 .61776 Mdot
.75641 .10559 Mdot
.80368 .13731 Mdot
.54361 .03958 Mdot
.61238 .05709 Mdot
.71721 .10551 Mdot
.76793 .1211 Mdot
.58496 .06045 Mdot
.65107 .05574 Mdot
.72565 .10366 Mdot
.62238 .05731 Mdot
.60036 .06272 Mdot
.38464 .58445 Mdot
.58783 .04606 Mdot
.44421 .60984 Mdot
.41718 .6078 Mdot
.70048 .10075 Mdot
.56615 .04876 Mdot
.67668 .06873 Mdot
.36084 .59377 Mdot
.28457 .54384 Mdot
.37554 .57685 Mdot
.52368 .03011 Mdot
.64248 .06129 Mdot
.39368 .59189 Mdot
.42878 .61727 Mdot
.69294 .07072 Mdot
.75245 .09652 Mdot
.36866 .5733 Mdot
.56496 .03457 Mdot
.55737 .05056 Mdot
.58376 .04625 Mdot
.53131 .0373 Mdot
.46049 .61417 Mdot
.74898 .09455 Mdot
.56672 .02675 Mdot
.73432 .10772 Mdot
.51142 .01112 Mdot
.78351 .12484 Mdot
.50032 .00196 Mdot
.67148 .08097 Mdot
.7987 .13014 Mdot
.48533 .01263 Mdot
.47168 .61338 Mdot
.81579 .13711 Mdot
.38798 .6029 Mdot
.80718 .12932 Mdot
.56463 .04672 Mdot
.45218 .00881 Mdot
.79472 .12306 Mdot
.41187 .59051 Mdot
.55287 .03363 Mdot
.60888 .05744 Mdot
.6175 .06625 Mdot
.49516 .02727 Mdot
.39912 .59827 Mdot
.42095 .59569 Mdot
.38971 .60016 Mdot
.47456 .00952 Mdot
.6896 .09888 Mdot
.39882 .60418 Mdot
.63627 .06321 Mdot
.73033 .10229 Mdot
.45641 .01289 Mdot
.37539 .57261 Mdot
.58612 .03762 Mdot
.741 .08848 Mdot
.56036 .04093 Mdot
.69923 .09795 Mdot
.54603 .04359 Mdot
.47606 .61462 Mdot
.72509 .11075 Mdot
.45256 .61322 Mdot
.34603 .57733 Mdot
.58895 .05774 Mdot
.75125 .1081 Mdot
.46635 .01219 Mdot
.42046 .5991 Mdot
.46611 .0107 Mdot
.72714 .10518 Mdot
.63489 .07839 Mdot
.55313 .0443 Mdot
.41278 .60957 Mdot
.69659 .09952 Mdot
.70412 .08529 Mdot
.60752 .05182 Mdot
.48826 .01091 Mdot
.72102 .10734 Mdot
.39743 .60163 Mdot
.55275 .03492 Mdot
.7942 .13537 Mdot
.6932 .09512 Mdot
.5338 .04121 Mdot
.51147 .03314 Mdot
.3766 .57845 Mdot
.56359 .02553 Mdot
.53777 .03908 Mdot
.81677 .13483 Mdot
.30819 .55887 Mdot
.47513 .01475 Mdot
.77147 .11836 Mdot
.6696 .07082 Mdot
.35647 .58818 Mdot
.35326 .57944 Mdot
.68412 .09052 Mdot
.7048 .09081 Mdot
.56009 .03899 Mdot
.39562 .59333 Mdot
.39703 .60231 Mdot
.4394 .0015 Mdot
.34816 .57453 Mdot
.82683 .14902 Mdot
.43871 7e-05 Mdot
.41498 .60831 Mdot
.34118 .56079 Mdot
.32027 .55949 Mdot
.5237 .01702 Mdot
.47836 .01312 Mdot
.82417 .13907 Mdot
.3393 .5672 Mdot
.80672 .14217 Mdot
.76176 .1095 Mdot
.71629 .09775 Mdot
.79533 .12142 Mdot
.6517 .08168 Mdot
.75986 .11848 Mdot
.56346 .04804 Mdot
.69719 .08902 Mdot
.78275 .11939 Mdot
.59108 .05875 Mdot
.81895 .14124 Mdot
.50665 .01989 Mdot
.39126 .60413 Mdot
.48885 .61739 Mdot
.41766 .59457 Mdot
.55417 .03902 Mdot
.63456 .06086 Mdot
.66108 .08542 Mdot
.44279 .61336 Mdot
.70922 .08622 Mdot
.52245 .03811 Mdot
.49164 .01109 Mdot
.44598 .60297 Mdot
.84551 .15221 Mdot
.43151 .60252 Mdot
.61612 .066 Mdot
.2733 .53912 Mdot
.31728 .5556 Mdot
.49931 .02126 Mdot
.52076 .01566 Mdot
.31336 .5555 Mdot
.67806 .09416 Mdot
.65391 .06189 Mdot
.43786 .60929 Mdot
.45977 .60342 Mdot
.45284 3e-05 Mdot
.40285 .60322 Mdot
.70487 .09976 Mdot
.3891 .59533 Mdot
.64356 .07318 Mdot
.75402 .11934 Mdot
.37634 .58504 Mdot
.69796 .09369 Mdot
.56472 .03752 Mdot
.78579 .1194 Mdot
.49904 .02907 Mdot
.58377 .0461 Mdot
.7867 .11587 Mdot
.55481 .04477 Mdot
.46133 .00343 Mdot
.42045 .59573 Mdot
.68648 .09633 Mdot
.53341 .02336 Mdot
.56381 .03888 Mdot
.7033 .09521 Mdot
.74028 .08862 Mdot
.65919 .06337 Mdot
.62025 .04658 Mdot
.44862 .00071 Mdot
.69405 .09171 Mdot
.75974 .12029 Mdot
.48452 .61472 Mdot
.59278 .05206 Mdot
.66571 .06578 Mdot
.3158 .558 Mdot
.47465 .01006 Mdot
.47537 .00723 Mdot
.47541 .00861 Mdot
.56392 .03516 Mdot
.60366 .0538 Mdot
.48738 .01719 Mdot
.77523 .12625 Mdot
.5943 .0617 Mdot
.54428 .03907 Mdot
.74534 .09853 Mdot
.62636 .06462 Mdot
.68833 .07129 Mdot
.523 .03682 Mdot
.58721 .04815 Mdot
.30681 .55924 Mdot
.28233 .54391 Mdot
.564 .04862 Mdot
.6558 .06989 Mdot
.65521 .08704 Mdot
.43363 .609 Mdot
.36394 .57515 Mdot
.43129 .59884 Mdot
.60456 .05749 Mdot
.48866 .6176 Mdot
.45343 .00328 Mdot
.76642 .11518 Mdot
.40591 .59315 Mdot
.74354 .10244 Mdot
.70821 .09108 Mdot
.34424 .5619 Mdot
.42668 .60581 Mdot
.77293 .11503 Mdot
.32051 .56079 Mdot
.59837 .04568 Mdot
.57956 .04818 Mdot
.36255 .57319 Mdot
.49849 .02782 Mdot
.45935 .00266 Mdot
.35085 .58314 Mdot
.46045 .60764 Mdot
.38421 .57956 Mdot
.37066 .57383 Mdot
.33721 .57922 Mdot
.46036 .00307 Mdot
.75702 .10516 Mdot
.61067 .04929 Mdot
.55386 .04239 Mdot
.50109 .00326 Mdot
.42943 .61658 Mdot
.41467 .6019 Mdot
.33741 .56422 Mdot
.69979 .08423 Mdot
.69587 .07284 Mdot
.58344 .03839 Mdot
.73835 .0991 Mdot
.49444 .01762 Mdot
.72223 .08102 Mdot
.63266 .06035 Mdot
.54575 .02465 Mdot
.3842 .58405 Mdot
.48959 .00959 Mdot
.83013 .14321 Mdot
.40747 .592 Mdot
.38976 .59013 Mdot
.45593 .60836 Mdot
.5535 .02467 Mdot
.58274 .0551 Mdot
.43089 .60767 Mdot
.60315 .06224 Mdot
.54637 .02084 Mdot
.79867 .1249 Mdot
.53458 .03778 Mdot
.56787 .02803 Mdot
.44519 .59959 Mdot
.53196 .0365 Mdot
.43008 .61182 Mdot
.33536 .57726 Mdot
.62426 .06039 Mdot
.61332 .06524 Mdot
.56506 .05326 Mdot
.38841 .60759 Mdot
.76573 .12329 Mdot
.33015 .56947 Mdot
.48418 .61272 Mdot
.50482 .01149 Mdot
.41456 .61606 Mdot
.34936 .57851 Mdot
.72661 .09208 Mdot
.39359 .60667 Mdot
.47787 .01656 Mdot
.52364 .012 Mdot
.77808 .12725 Mdot
.51346 .00899 Mdot
.39125 .60895 Mdot
.5607 .04358 Mdot
.64898 .08394 Mdot
.31448 .56273 Mdot
.48986 .6146 Mdot
.82564 .14523 Mdot
.62864 .0685 Mdot
.81116 .14369 Mdot
.52234 .03437 Mdot
.54244 .04202 Mdot
.49023 .61537 Mdot
.7746 .12303 Mdot
.47706 .61091 Mdot
.46815 .6074 Mdot
.69386 .07319 Mdot
.53229 .03146 Mdot
.45827 .60459 Mdot
.56937 .04859 Mdot
.69713 .08338 Mdot
.62344 .06882 Mdot
.54752 .03215 Mdot
.45356 .00984 Mdot
.3167 .56596 Mdot
.42291 .59381 Mdot
.58023 .04194 Mdot
.69984 .07607 Mdot
.6317 .05857 Mdot
.54202 .02884 Mdot
.4248 .59818 Mdot
.35108 .58495 Mdot
.59452 .0617 Mdot
.58921 .05976 Mdot
.78755 .11641 Mdot
.38893 .57727 Mdot
.85053 .15593 Mdot
.8279 .14531 Mdot
.52949 .02696 Mdot
.38717 .60019 Mdot
.64611 .06006 Mdot
.5893 .04241 Mdot
.59326 .06257 Mdot
.61668 .06218 Mdot
.7398 .08806 Mdot
.40188 .60463 Mdot
.81258 .13254 Mdot
.75633 .11597 Mdot
.82238 .1375 Mdot
.78957 .13206 Mdot
.55255 .0238 Mdot
.66033 .06209 Mdot
.77261 .12824 Mdot
.44525 .00375 Mdot
.55225 .04892 Mdot
.5762 .03282 Mdot
.55347 .04802 Mdot
.5488 .03045 Mdot
.4817 .00252 Mdot
.65902 .07921 Mdot
.51967 .02592 Mdot
.73384 .11055 Mdot
.71446 .09318 Mdot
.8147 .13572 Mdot
.8024 .12597 Mdot
.74828 .11888 Mdot
.62945 .06425 Mdot
.42664 .6142 Mdot
.44753 .61668 Mdot
.6245 .05637 Mdot
.71103 .08587 Mdot
.34455 .58226 Mdot
.56513 .04374 Mdot
.47151 .01485 Mdot
.59786 .04152 Mdot
.39811 .5845 Mdot
.65615 .07667 Mdot
.51705 .01274 Mdot
.28476 .54272 Mdot
.46386 .00015 Mdot
.69877 .08768 Mdot
.58824 .0358 Mdot
.72995 .0897 Mdot
.62274 .05863 Mdot
.54077 .03109 Mdot
.52295 .02629 Mdot
.69052 .0808 Mdot
.37947 .58802 Mdot
.40984 .607 Mdot
.60846 .04751 Mdot
.38407 .59517 Mdot
.51571 .0295 Mdot
.42915 .59639 Mdot
.67635 .08571 Mdot
.5629 .05163 Mdot
.31104 .557 Mdot
.76522 .10898 Mdot
.65079 .07503 Mdot
.33291 .55858 Mdot
.52522 .01475 Mdot
.30256 .55694 Mdot
.78312 .13187 Mdot
.77895 .12275 Mdot
.52105 .01192 Mdot
.60527 .05507 Mdot
.7116 .09116 Mdot
.41497 .60454 Mdot
.65869 .06452 Mdot
.39184 .58338 Mdot
.38335 .59235 Mdot
.31623 .55464 Mdot
.60387 .04964 Mdot
.39322 .6031 Mdot
.68603 .08173 Mdot
.35617 .56805 Mdot
.41759 .59676 Mdot
.61833 .06022 Mdot
.57235 .05218 Mdot
.57596 .05679 Mdot
.66169 .07915 Mdot
.43802 .00114 Mdot
.53284 .01491 Mdot
.37995 .59491 Mdot
.79284 .12835 Mdot
.84705 .1527 Mdot
.36445 .57667 Mdot
.75055 .11596 Mdot
.80991 .14249 Mdot
.38648 .5837 Mdot
.49246 .00064 Mdot
.67675 .07342 Mdot
.69849 .08695 Mdot
.61308 .05642 Mdot
.41883 .59934 Mdot
.60873 .06446 Mdot
.48915 .01559 Mdot
.62202 .07265 Mdot
.3804 .58581 Mdot
.61832 .04745 Mdot
.43363 .60594 Mdot
.60445 .06486 Mdot
.68785 .07793 Mdot
.67509 .08253 Mdot
.36836 .59604 Mdot
.31765 .55492 Mdot
.69061 .0839 Mdot
.57384 .03616 Mdot
.57355 .05106 Mdot
.32874 .56727 Mdot
.44685 .6109 Mdot
.45312 .60801 Mdot
.27178 .53558 Mdot
.71505 .08976 Mdot
.44514 .00105 Mdot
.41619 .61057 Mdot
.45576 .01006 Mdot
.35741 .58645 Mdot
.51139 .01654 Mdot
.5261 .02035 Mdot
.79984 .12741 Mdot
.57429 .05685 Mdot
.61124 .04694 Mdot
.37781 .5963 Mdot
.59788 .04189 Mdot
.40483 .59435 Mdot
.52481 .02358 Mdot
.36644 .5881 Mdot
.44264 .61524 Mdot
.38843 .60695 Mdot
.67745 .07102 Mdot
.60435 .05634 Mdot
.73884 .10506 Mdot
.40336 .60103 Mdot
.38323 .58693 Mdot
.40412 .60951 Mdot
.53221 .01777 Mdot
.74163 .10313 Mdot
.38303 .59716 Mdot
.75316 .11945 Mdot
.68293 .07001 Mdot
.74329 .11729 Mdot
.38417 .60385 Mdot
.39251 .58848 Mdot
.38667 .58614 Mdot
.3675 .59211 Mdot
.38239 .60423 Mdot
.82412 .14374 Mdot
.59179 .05595 Mdot
.34147 .57148 Mdot
.4644 .60564 Mdot
.45138 .61462 Mdot
.6481 .08239 Mdot
.5758 .04475 Mdot
.52174 .00869 Mdot
.43587 .60123 Mdot
.50766 .02364 Mdot
.44606 .61337 Mdot
.50381 .02418 Mdot
.48406 .01359 Mdot
.65908 .05912 Mdot
.39927 .5896 Mdot
.5673 .05459 Mdot
.81036 .13719 Mdot
.66649 .06324 Mdot
.4913 .00391 Mdot
.39814 .58197 Mdot
.31054 .5492 Mdot
.75353 .10287 Mdot
.7277 .09851 Mdot
.62647 .06432 Mdot
.61729 .06864 Mdot
.71299 .09518 Mdot
.47022 .00572 Mdot
.51787 .0234 Mdot
.52277 .03102 Mdot
.59868 .05119 Mdot
.77476 .11567 Mdot
.45205 .61351 Mdot
.72262 .097 Mdot
.44164 .5991 Mdot
.73564 .08545 Mdot
.68363 .08267 Mdot
.4973 .00381 Mdot
.83256 .14936 Mdot
.40098 .59999 Mdot
.57204 .0378 Mdot
.74322 .11472 Mdot
.83501 .14832 Mdot
.71045 .0868 Mdot
.6415 .06541 Mdot
.36689 .5949 Mdot
.451 .61038 Mdot
.37164 .59621 Mdot
.63564 .07548 Mdot
.61649 .06222 Mdot
.6657 .08843 Mdot
.4689 .6077 Mdot
.35044 .58014 Mdot
.59356 .0405 Mdot
.37605 .59289 Mdot
.74806 .11744 Mdot
.47855 .61648 Mdot
.64006 .05336 Mdot
.40341 .60921 Mdot
.64676 .06179 Mdot
.51231 .00503 Mdot
.40445 .60164 Mdot
.71121 .08014 Mdot
.68145 .08412 Mdot
.73941 .10483 Mdot
.34409 .57278 Mdot
.74083 .11605 Mdot
.45927 .61803 Mdot
.51402 .02599 Mdot
.56702 .03799 Mdot
.48677 .02008 Mdot
.66727 .06706 Mdot
.72228 .10641 Mdot
.63781 .06799 Mdot
.75387 .11453 Mdot
.8202 .14693 Mdot
.75497 .09653 Mdot
.73437 .10458 Mdot
.39357 .5858 Mdot
.52847 .01396 Mdot
.74428 .10539 Mdot
.34103 .58138 Mdot
.63229 .06973 Mdot
.41415 .60109 Mdot
.77558 .12746 Mdot
.64414 .08058 Mdot
.28127 .54418 Mdot
.6882 .09697 Mdot
.26663 .53437 Mdot
.6986 .08186 Mdot
.73377 .1097 Mdot
.42357 .59536 Mdot
.73185 .09229 Mdot
.46214 .00137 Mdot
.47546 .00766 Mdot
.30461 .54773 Mdot
.56613 .04475 Mdot
.52515 .0127 Mdot
.54432 .03174 Mdot
.70279 .08003 Mdot
.53681 .02833 Mdot
.38298 .60309 Mdot
.67087 .08417 Mdot
.70125 .09539 Mdot
.68256 .08059 Mdot
.49078 .00235 Mdot
.579 .05557 Mdot
.44175 .60143 Mdot
.75445 .09833 Mdot
.66373 .06163 Mdot
.58854 .05324 Mdot
.82241 .1432 Mdot
.30849 .55442 Mdot
.81877 .14537 Mdot
.50058 .01473 Mdot
.37467 .57973 Mdot
.56635 .02582 Mdot
.63022 .04978 Mdot
.36014 .57146 Mdot
.56005 .04882 Mdot
.46675 .01644 Mdot
.64364 .07824 Mdot
.62558 .05428 Mdot
.68385 .09735 Mdot
.57419 .02958 Mdot
.60881 .0408 Mdot
.44517 .61531 Mdot
.6074 .06258 Mdot
.62726 .0632 Mdot
.72421 .10367 Mdot
.51992 .01879 Mdot
.53614 .03753 Mdot
.42653 .60392 Mdot
.76036 .12484 Mdot
.54912 .02319 Mdot
.45135 .01194 Mdot
.71873 .08248 Mdot
.58871 .06148 Mdot
.6504 .0709 Mdot
.72571 .08814 Mdot
.40035 .61165 Mdot
.37918 .58872 Mdot
.62343 .0632 Mdot
.70802 .09691 Mdot
.4485 .60362 Mdot
.80926 .13375 Mdot
.767 .1278 Mdot
.73655 .1086 Mdot
.79026 .13308 Mdot
.52028 .0301 Mdot
.39572 .59113 Mdot
.53877 .03107 Mdot
.37365 .5841 Mdot
.41398 .58843 Mdot
.61656 .06747 Mdot
.57409 .0392 Mdot
.42091 .60897 Mdot
.62702 .06749 Mdot
.5193 .02716 Mdot
.75651 .1233 Mdot
.59478 .05832 Mdot
.4883 .00178 Mdot
.45184 .61226 Mdot
.81069 .13212 Mdot
.45416 .01332 Mdot
.65565 .07454 Mdot
.58445 .0366 Mdot
.33619 .56353 Mdot
.53633 .02885 Mdot
.5749 .04223 Mdot
.39329 .60506 Mdot
.68538 .08394 Mdot
.54236 .01761 Mdot
.44876 .60853 Mdot
.46217 .00586 Mdot
.49914 .01973 Mdot
.38493 .59631 Mdot
.59239 .03722 Mdot
.54535 .03121 Mdot
.63074 .07599 Mdot
.38729 .60696 Mdot
.31518 .56485 Mdot
.73457 .08878 Mdot
.49038 .02393 Mdot
.44959 .60107 Mdot
.78445 .12171 Mdot
.36257 .57985 Mdot
.66209 .08763 Mdot
.35689 .58875 Mdot
.8128 .13885 Mdot
.55303 .02695 Mdot
.55878 .04848 Mdot
.54401 .02459 Mdot
.50295 .01473 Mdot
.55213 .02399 Mdot
.38732 .59323 Mdot
.35521 .56794 Mdot
.46474 .01534 Mdot
.37097 .59273 Mdot
.55037 .01901 Mdot
.39358 .60935 Mdot
.60069 .04277 Mdot
.58289 .05234 Mdot
.41343 .59473 Mdot
.78083 .11548 Mdot
.77578 .12592 Mdot
.4868 .00379 Mdot
.64497 .06204 Mdot
.38574 .58178 Mdot
.55322 .03001 Mdot
.39273 .59347 Mdot
.74679 .09997 Mdot
.37793 .58904 Mdot
.40277 .58665 Mdot
.6607 .08286 Mdot
.3685 .59708 Mdot
.62167 .05501 Mdot
.33336 .55808 Mdot
.38637 .57748 Mdot
.55425 .04231 Mdot
.37889 .6003 Mdot
.7458 .10177 Mdot
.72737 .09411 Mdot
.73962 .08872 Mdot
.72648 .10891 Mdot
.71568 .10702 Mdot
.32118 .55473 Mdot
.60631 .0409 Mdot
.56483 .04565 Mdot
.52687 .01058 Mdot
.43177 .61358 Mdot
.34695 .57043 Mdot
.43147 4e-05 Mdot
.46349 .01276 Mdot
.44763 .61267 Mdot
.46493 .01122 Mdot
.58908 .05131 Mdot
.61701 .06969 Mdot
.5223 .02464 Mdot
.75748 .1195 Mdot
.82 .14123 Mdot
.48412 .01839 Mdot
.64647 .05808 Mdot
.39382 .59543 Mdot
.58948 .04226 Mdot
.79234 .12656 Mdot
.5132 .02991 Mdot
.70475 .10134 Mdot
.6717 .06981 Mdot
.46091 .01506 Mdot
.52157 .02797 Mdot
.44855 .60328 Mdot
.56404 .04896 Mdot
.34052 .57012 Mdot
.66579 .08248 Mdot
.80809 .13624 Mdot
.33334 .5699 Mdot
.27542 .54098 Mdot
.68279 .08427 Mdot
.43102 .60055 Mdot
.75353 .1025 Mdot
.34644 .57086 Mdot
.60863 .0601 Mdot
.64236 .05685 Mdot
.41851 .61306 Mdot
.67812 .09011 Mdot
.49852 .00266 Mdot
.61294 .04219 Mdot
.54202 .03648 Mdot
.71718 .10667 Mdot
.60772 .04398 Mdot
.53772 .03242 Mdot
.71697 .10389 Mdot
.44626 .608 Mdot
.36187 .5713 Mdot
.55211 .02472 Mdot
.3217 .56288 Mdot
.73872 .09822 Mdot
.56627 .03063 Mdot
.38252 .58553 Mdot
.39719 .59546 Mdot
.53181 .02551 Mdot
.53613 .02409 Mdot
.37236 .59769 Mdot
.68691 .08567 Mdot
.66761 .07714 Mdot
.57853 .04186 Mdot
.36951 .58023 Mdot
.5137 .00856 Mdot
.49375 .02649 Mdot
.81179 .14131 Mdot
.36855 .58886 Mdot
.67186 .07567 Mdot
.58077 .03433 Mdot
.38798 .5783 Mdot
.58674 .04128 Mdot
.5689 .04012 Mdot
.78396 .1278 Mdot
.73251 .0861 Mdot
.6712 .07707 Mdot
.59666 .06386 Mdot
.5496 .03337 Mdot
.52926 .01179 Mdot
.55695 .04765 Mdot
.72402 .1009 Mdot
.72434 .10489 Mdot
.58929 .04994 Mdot
.39185 .59157 Mdot
.27884 .54038 Mdot
.47144 .00861 Mdot
.28682 .5411 Mdot
.54849 .02316 Mdot
.55332 .02186 Mdot
.37479 .59293 Mdot
.28172 .54013 Mdot
.68159 .09025 Mdot
.41935 .60094 Mdot
.70093 .07416 Mdot
.69803 .09858 Mdot
.686 .08636 Mdot
.6778 .08885 Mdot
.5863 .06028 Mdot
.64804 .07744 Mdot
.7832 .12698 Mdot
.35315 .58612 Mdot
.66651 .06438 Mdot
.81183 .13276 Mdot
.36068 .57718 Mdot
.65156 .06276 Mdot
.40231 .59113 Mdot
.33094 .56825 Mdot
.58377 .05204 Mdot
.51612 .0239 Mdot
.37438 .59553 Mdot
.73624 .1122 Mdot
.45263 .0121 Mdot
.64185 .05681 Mdot
.53106 .0373 Mdot
.69094 .08531 Mdot
.42569 .60676 Mdot
.29848 .5535 Mdot
.76408 .10258 Mdot
.82799 .14622 Mdot
.55944 .03765 Mdot
.56937 .03425 Mdot
.56198 .04589 Mdot
.69951 .08669 Mdot
.48318 .01761 Mdot
.31572 .56018 Mdot
.81569 .14321 Mdot
.4869 .01883 Mdot
.64685 .06601 Mdot
.44747 .61428 Mdot
.62354 .05043 Mdot
.48162 .01204 Mdot
.4366 .61382 Mdot
.66059 .06947 Mdot
.74117 .11463 Mdot
.8233 .14484 Mdot
.5106 .00593 Mdot
.76674 .11565 Mdot
.5591 .026 Mdot
.65545 .08174 Mdot
.77721 .12374 Mdot
.45936 .61168 Mdot
.41008 .60261 Mdot
.35568 .586 Mdot
.8351 .15048 Mdot
.43698 .60423 Mdot
.35228 .56634 Mdot
.47644 .00374 Mdot
.58868 .03323 Mdot
.57453 .05177 Mdot
.40534 .61029 Mdot
.78593 .13495 Mdot
.37031 .57442 Mdot
.57986 .05063 Mdot
.33899 .57672 Mdot
.48186 .61274 Mdot
.36446 .58728 Mdot
.41873 .61039 Mdot
.75394 .10855 Mdot
.68716 .07814 Mdot
.4213 .60438 Mdot
.4851 .00936 Mdot
.3936 .59831 Mdot
.56588 .03925 Mdot
.76539 .1117 Mdot
.36448 .59334 Mdot
.80563 .14017 Mdot
.62414 .06807 Mdot
.69944 .08333 Mdot
.45868 .60307 Mdot
.80721 .13652 Mdot
.63918 .07231 Mdot
.64317 .06195 Mdot
.40552 .58917 Mdot
.62433 .06608 Mdot
.70735 .09733 Mdot
.60275 .04325 Mdot
.72163 .10889 Mdot
.66115 .06626 Mdot
.35153 .56866 Mdot
.82368 .14484 Mdot
.63862 .05569 Mdot
.27598 .53952 Mdot
.37436 .58591 Mdot
.49382 .02085 Mdot
.71204 .08525 Mdot
.61804 .04658 Mdot
.38168 .59173 Mdot
.39282 .60747 Mdot
.52498 .02854 Mdot
.47386 .01105 Mdot
.42794 .60602 Mdot
.51278 .02851 Mdot
.53676 .02343 Mdot
.49575 .01985 Mdot
.53651 .03954 Mdot
.38078 .60397 Mdot
.57029 .04442 Mdot
.50386 .02658 Mdot
.44302 .59878 Mdot
.48872 .02335 Mdot
.77956 .11383 Mdot
.75623 .09966 Mdot
.73037 .11272 Mdot
.6219 .05783 Mdot
.44599 .61609 Mdot
.49728 .02013 Mdot
.77401 .122 Mdot
.49534 .02112 Mdot
.4582 .60568 Mdot
.37108 .59997 Mdot
.27382 .53756 Mdot
.62276 .04536 Mdot
.35468 .58468 Mdot
.72783 .10718 Mdot
.48642 .01592 Mdot
.36123 .57796 Mdot
.29786 .54779 Mdot
.72817 .10309 Mdot
.38544 .58746 Mdot
.60567 .06518 Mdot
.67285 .07177 Mdot
.61417 .07063 Mdot
.65795 .06505 Mdot
.73897 .11646 Mdot
.68126 .08481 Mdot
.75222 .09647 Mdot
.56632 .05126 Mdot
.77018 .12369 Mdot
.52537 .03307 Mdot
.3005 .55117 Mdot
.39487 .59203 Mdot
.55743 .03025 Mdot
.46785 .61038 Mdot
.32068 .5637 Mdot
.67818 .0931 Mdot
.44375 .60918 Mdot
.74062 .09711 Mdot
.43274 .59998 Mdot
.55 .03084 Mdot
.52866 .02272 Mdot
.39847 .59963 Mdot
.4856 .00148 Mdot
.74506 .09503 Mdot
.79404 .13555 Mdot
.53466 .01458 Mdot
.73202 .10253 Mdot
.72061 .08472 Mdot
.54181 .02087 Mdot
.35967 .59309 Mdot
.48116 .02166 Mdot
.55 .03094 Mdot
.6994 .08973 Mdot
.52536 .03317 Mdot
.46566 .61473 Mdot
.52277 .02619 Mdot
.5373 .02535 Mdot
.73476 .10224 Mdot
.67218 .08777 Mdot
.75559 .10494 Mdot
.38524 .59525 Mdot
.7756 .11732 Mdot
.76673 .11787 Mdot
.48177 .61552 Mdot
.32471 .55803 Mdot
.33276 .56773 Mdot
.72335 .10665 Mdot
.67353 .08638 Mdot
.43826 .60799 Mdot
.68327 .07344 Mdot
.63474 .06823 Mdot
.78941 .13027 Mdot
.62424 .07541 Mdot
.75464 .09999 Mdot
.60305 .04748 Mdot
.53066 .01461 Mdot
.53318 .01777 Mdot
.57406 .05018 Mdot
.67703 .07626 Mdot
.64813 .05502 Mdot
.61121 .06927 Mdot
.82603 .14299 Mdot
.72225 .09114 Mdot
.29587 .54377 Mdot
.47229 .61788 Mdot
.40212 .60502 Mdot
.61788 .04423 Mdot
.61699 .06232 Mdot
.4576 .00971 Mdot
.41737 .61438 Mdot
.52715 .02403 Mdot
.51327 .03034 Mdot
.77905 .11737 Mdot
.42884 .59289 Mdot
.31571 .55706 Mdot
.38944 .57845 Mdot
.70679 .10196 Mdot
.36407 .57709 Mdot
.83021 .14506 Mdot
.6137 .06152 Mdot
.75146 .12229 Mdot
.57077 .04938 Mdot
.47624 .00675 Mdot
.43178 .00315 Mdot
.56004 .05182 Mdot
.74754 .11766 Mdot
.50085 .02412 Mdot
.61092 .06628 Mdot
.66271 .0882 Mdot
.50035 .01668 Mdot
.574 .03058 Mdot
.7544 .12064 Mdot
.68768 .07216 Mdot
.43599 .59805 Mdot
.58533 .04928 Mdot
.37969 .57974 Mdot
.39887 .59916 Mdot
.4984 .00861 Mdot
.76211 .12022 Mdot
.75231 .106 Mdot
.47375 .01618 Mdot
.62728 .07407 Mdot
.64807 .07726 Mdot
.61975 .0442 Mdot
.70563 .09486 Mdot
.55526 .04657 Mdot
.37319 .57269 Mdot
.42974 .61276 Mdot
.35179 .57764 Mdot
.67755 .07648 Mdot
.45239 .00174 Mdot
.78783 .13278 Mdot
.35791 .59079 Mdot
.41474 .58663 Mdot
.4507 .60058 Mdot
.54343 .01615 Mdot
.61339 .05352 Mdot
.36071 .57064 Mdot
.49197 .00725 Mdot
.79144 .11885 Mdot
.51613 .03278 Mdot
.3734 .57357 Mdot
.3208 .56072 Mdot
.45038 .60446 Mdot
.34244 .57533 Mdot
.29369 .54813 Mdot
.63476 .06314 Mdot
.49236 .00177 Mdot
.27963 .54006 Mdot
.38512 .57664 Mdot
.64946 .07658 Mdot
.45419 .00076 Mdot
.50451 .02598 Mdot
.33902 .57564 Mdot
.44079 .613 Mdot
.63077 .05902 Mdot
.35618 .56783 Mdot
.59515 .0412 Mdot
.58867 .05182 Mdot
.35525 .56628 Mdot
.56715 .04211 Mdot
.71261 .07769 Mdot
.78365 .1299 Mdot
.63544 .06272 Mdot
.53352 .01392 Mdot
.67427 .09144 Mdot
.46459 .00157 Mdot
.78592 .12044 Mdot
.36445 .58084 Mdot
.44839 .60927 Mdot
.64152 .07522 Mdot
.3492 .57207 Mdot
.32929 .56148 Mdot
.37834 .58199 Mdot
.40836 .59395 Mdot
.61003 .06632 Mdot
.62292 .05351 Mdot
.80123 .13896 Mdot
.52951 .03413 Mdot
.75628 .10565 Mdot
.42033 .59991 Mdot
.56434 .02569 Mdot
.64721 .07254 Mdot
.58962 .05588 Mdot
.57302 .03954 Mdot
.46428 .00108 Mdot
.41665 .59019 Mdot
.72164 .10001 Mdot
.66255 .08478 Mdot
.78251 .12304 Mdot
.38451 .57689 Mdot
.76669 .10421 Mdot
.34356 .58226 Mdot
.46152 .60951 Mdot
.43704 .59667 Mdot
.73745 .09972 Mdot
.73139 .10434 Mdot
.64797 .08307 Mdot
.56768 .04131 Mdot
.67273 .07354 Mdot
.77078 .12071 Mdot
.7527 .11272 Mdot
.64147 .07237 Mdot
.72659 .0954 Mdot
.67721 .09534 Mdot
.5189 .01358 Mdot
.49165 .02491 Mdot
.64705 .07801 Mdot
.50675 .0111 Mdot
.37689 .59926 Mdot
.80244 .13257 Mdot
.44589 .61331 Mdot
.2906 .54271 Mdot
.55885 .04674 Mdot
.51248 .01507 Mdot
.57853 .04174 Mdot
.70243 .08485 Mdot
.31581 .55731 Mdot
.58459 .04375 Mdot
.5325 .02426 Mdot
.332 .56055 Mdot
.53337 .02929 Mdot
.39127 .58973 Mdot
.34146 .5618 Mdot
.35893 .57745 Mdot
.64847 .06133 Mdot
.5918 .03417 Mdot
.44341 .0032 Mdot
.7536 .11263 Mdot
.38571 .59427 Mdot
.42328 .59685 Mdot
.59867 .04187 Mdot
.34765 .56556 Mdot
.43726 .61329 Mdot
.81739 .13715 Mdot
.35369 .58169 Mdot
.7176 .09068 Mdot
.44802 .60862 Mdot
.38156 .58539 Mdot
.38055 .59054 Mdot
.49215 .01801 Mdot
.37441 .60168 Mdot
.32731 .56974 Mdot
.51629 .02864 Mdot
.72068 .09134 Mdot
.33452 .56211 Mdot
.76411 .11539 Mdot
.35973 .58541 Mdot
.30548 .55558 Mdot
.65452 .06505 Mdot
.78509 .1316 Mdot
.64911 .07718 Mdot
.5471 .02346 Mdot
.65415 .08083 Mdot
.59799 .05828 Mdot
.38925 .57838 Mdot
.62324 .05713 Mdot
.43144 .00188 Mdot
.7234 .10508 Mdot
.33042 .56522 Mdot
.67633 .08002 Mdot
.41931 .58879 Mdot
.75451 .11113 Mdot
.63894 .05967 Mdot
.46188 .61576 Mdot
.36058 .58191 Mdot
.73116 .10463 Mdot
.71439 .09194 Mdot
.36315 .57606 Mdot
.6588 .07513 Mdot
.50517 .01698 Mdot
.58458 .03908 Mdot
.57743 .0288 Mdot
.41665 .5945 Mdot
.6874 .08113 Mdot
.64603 .08263 Mdot
.47767 .61006 Mdot
.54064 .02926 Mdot
.61394 .05269 Mdot
.57327 .02818 Mdot
.50423 .00408 Mdot
.77699 .11529 Mdot
.37417 .58975 Mdot
.44979 .6061 Mdot
.54146 .03236 Mdot
.40987 .61525 Mdot
.60197 .04263 Mdot
.50772 .00351 Mdot
.37653 .57731 Mdot
.34446 .5783 Mdot
.63046 .07214 Mdot
.51367 .02015 Mdot
.382 .59696 Mdot
.47944 .61112 Mdot
.74847 .09413 Mdot
.40464 .6076 Mdot
.58563 .04856 Mdot
.37393 .5975 Mdot
.72935 .09596 Mdot
.60845 .06386 Mdot
.60835 .0474 Mdot
.52137 .01545 Mdot
.35356 .57826 Mdot
.38367 .59849 Mdot
.35108 .58668 Mdot
.64818 .07633 Mdot
.34298 .5793 Mdot
.6184 .07123 Mdot
.49919 .00038 Mdot
.50223 .00386 Mdot
.63573 .06874 Mdot
.7565 .10236 Mdot
.76944 .10914 Mdot
.49242 .61675 Mdot
.79493 .13597 Mdot
.48474 .00343 Mdot
.7033 .08046 Mdot
.70473 .09284 Mdot
.73928 .10619 Mdot
.45905 .00474 Mdot
.49339 .01515 Mdot
.70402 .09186 Mdot
.72637 .11247 Mdot
.68928 .07711 Mdot
.69867 .09094 Mdot
.44975 .60551 Mdot
.76659 .11742 Mdot
.82756 .14631 Mdot
.32257 .56802 Mdot
.38104 .58388 Mdot
.44414 .00501 Mdot
.78463 .12342 Mdot
.69552 .07934 Mdot
.33832 .56166 Mdot
.34575 .57043 Mdot
.51341 .02991 Mdot
.51148 .02487 Mdot
.80519 .1299 Mdot
.49026 .61533 Mdot
.3572 .589 Mdot
.5464 .03416 Mdot
.7171 .09223 Mdot
.47571 .01274 Mdot
.79402 .13045 Mdot
.52635 .02374 Mdot
.71318 .09874 Mdot
.43549 .59969 Mdot
.5717 .05149 Mdot
.7858 .11858 Mdot
.50819 .00914 Mdot
.55357 .03355 Mdot
.52953 .02491 Mdot
.3847 .60353 Mdot
.55926 .02344 Mdot
.65089 .06046 Mdot
.62922 .05614 Mdot
.49644 .01936 Mdot
.77913 .12 Mdot
.80128 .12444 Mdot
.58341 .05367 Mdot
.27516 .53717 Mdot
.33402 .57529 Mdot
.58353 .04748 Mdot
.54568 .0196 Mdot
.57636 .04809 Mdot
.72865 .08406 Mdot
.67307 .07885 Mdot
.47753 .01438 Mdot
.54805 .04182 Mdot
.44177 .60103 Mdot
.48711 .00412 Mdot
.72433 .0937 Mdot
.47009 .61535 Mdot
.76957 .12363 Mdot
.75335 .11473 Mdot
.47801 .01387 Mdot
.43032 .59402 Mdot
.49129 .01753 Mdot
.6259 .06318 Mdot
.3916 .60748 Mdot
.44985 .00404 Mdot
.69212 .09439 Mdot
.70859 .09007 Mdot
.71174 .08965 Mdot
.49112 .00166 Mdot
.80289 .12716 Mdot
.60462 .05186 Mdot
.70392 .10033 Mdot
.42579 .60212 Mdot
.46393 .60894 Mdot
.66843 .08688 Mdot
.44989 .60563 Mdot
.47062 .60942 Mdot
.62663 .05937 Mdot
.62946 .0666 Mdot
.65972 .05923 Mdot
.39136 .59214 Mdot
.71759 .09322 Mdot
.53373 .01308 Mdot
.38996 .59627 Mdot
.47965 .01152 Mdot
.67105 .07695 Mdot
.68007 .0908 Mdot
.47254 .61554 Mdot
.46118 .00778 Mdot
.71455 .10416 Mdot
.58009 .03288 Mdot
.79784 .13332 Mdot
.56183 .04215 Mdot
.33863 .57061 Mdot
.77289 .11855 Mdot
.80974 .13568 Mdot
.66894 .09201 Mdot
.39658 .58894 Mdot
.73221 .0898 Mdot
.66945 .06327 Mdot
.64819 .06791 Mdot
.33169 .5628 Mdot
.32521 .56475 Mdot
.3959 .59142 Mdot
.62657 .06723 Mdot
.31529 .5511 Mdot
.59806 .03791 Mdot
.36696 .57698 Mdot
.30516 .54913 Mdot
.83223 .14987 Mdot
.43433 .00283 Mdot
.42136 .61724 Mdot
.5322 .02519 Mdot
.34917 .58565 Mdot
.46381 .60802 Mdot
.69387 .08111 Mdot
.70475 .08809 Mdot
.63475 .05915 Mdot
.3626 .57916 Mdot
.52127 .00965 Mdot
.31639 .56089 Mdot
.55198 .02228 Mdot
.74327 .10147 Mdot
.50518 .00736 Mdot
.58592 .06073 Mdot
.53525 .02691 Mdot
.37981 .60083 Mdot
.58873 .03686 Mdot
.41665 .60025 Mdot
.81654 .13998 Mdot
.3115 .55103 Mdot
.5524 .04203 Mdot
.37429 .5953 Mdot
.7472 .11047 Mdot
.37244 .58124 Mdot
.49531 .01244 Mdot
.65261 .06693 Mdot
.70426 .07465 Mdot
.65081 .07055 Mdot
.49189 .02317 Mdot
.48625 .61495 Mdot
.41777 .58924 Mdot
.42998 .59248 Mdot
.72998 .09271 Mdot
.4329 .60114 Mdot
.36135 .58704 Mdot
.43652 .0051 Mdot
.60899 .04491 Mdot
.52949 .02815 Mdot
.64809 .05886 Mdot
.62712 .04934 Mdot
.52858 .01862 Mdot
.39275 .57892 Mdot
.36406 .57475 Mdot
.70626 .07511 Mdot
.49724 .02666 Mdot
.64975 .07742 Mdot
.39353 .5877 Mdot
.58697 .05609 Mdot
.53221 .01603 Mdot
.31408 .55736 Mdot
.75118 .12222 Mdot
.42979 .59628 Mdot
.47499 .01237 Mdot
.29478 .54747 Mdot
.36767 .58513 Mdot
.32952 .5595 Mdot
.73363 .10312 Mdot
.54538 .0282 Mdot
.59473 .0436 Mdot
.33711 .57698 Mdot
.31805 .55632 Mdot
.76351 .10645 Mdot
.43042 .59699 Mdot
.59135 .04021 Mdot
.33308 .57081 Mdot
.55403 .02267 Mdot
.82629 .1469 Mdot
.59881 .06532 Mdot
.35116 .57437 Mdot
.79553 .12494 Mdot
.50162 .00247 Mdot
.71798 .0792 Mdot
.55905 .04903 Mdot
.81486 .13368 Mdot
.38491 .59928 Mdot
.48281 .00651 Mdot
.31122 .55961 Mdot
.67689 .07538 Mdot
.34559 .5738 Mdot
.45026 .61089 Mdot
.73516 .08641 Mdot
.51659 .02976 Mdot
.61193 .07059 Mdot
.54136 .03878 Mdot
.30834 .55026 Mdot
.46721 .6101 Mdot
.3029 .55632 Mdot
.36214 .58984 Mdot
.85205 .15762 Mdot
.42704 .60209 Mdot
.76587 .11497 Mdot
.83897 .15325 Mdot
.7714 .11551 Mdot
.5799 .03543 Mdot
.53536 .03003 Mdot
.41048 .59734 Mdot
.48267 .00859 Mdot
.68906 .07734 Mdot
.43877 .60119 Mdot
.70536 .09221 Mdot
.44779 .60491 Mdot
.53109 .01716 Mdot
.54667 .03554 Mdot
.55478 .02624 Mdot
.51938 .00909 Mdot
.71776 .07911 Mdot
.35944 .5819 Mdot
.68509 .08609 Mdot
.74051 .11829 Mdot
.73907 .09716 Mdot
.55334 .04341 Mdot
.41132 .60914 Mdot
.36197 .58583 Mdot
.62612 .06411 Mdot
.67899 .09522 Mdot
.3285 .56763 Mdot
.4147 .61461 Mdot
.35158 .57556 Mdot
.31473 .56388 Mdot
.53078 .03477 Mdot
.43504 .60679 Mdot
.53621 .02692 Mdot
.74737 .10954 Mdot
.49925 .01996 Mdot
.64321 .05387 Mdot
.6218 .04773 Mdot
.33899 .56109 Mdot
.67083 .08425 Mdot
.30292 .5513 Mdot
.57456 .0373 Mdot
.36775 .59282 Mdot
.41612 .60347 Mdot
.67463 .07374 Mdot
.62674 .04926 Mdot
.78953 .1263 Mdot
.49894 .01166 Mdot
.40408 .60255 Mdot
.62575 .05577 Mdot
.80569 .12836 Mdot
.33435 .57685 Mdot
.76234 .1083 Mdot
.50039 .00841 Mdot
.77371 .12061 Mdot
.45785 .00665 Mdot
.35656 .57682 Mdot
.57864 .04856 Mdot
.42892 .61239 Mdot
.33477 .56537 Mdot
.28333 .54041 Mdot
.57362 .05509 Mdot
.33805 .57299 Mdot
.49868 .00939 Mdot
.31673 .55185 Mdot
.7395 .08825 Mdot
.4056 .59352 Mdot
.66067 .06864 Mdot
.42647 .00275 Mdot
.45449 .00305 Mdot
.73949 .09612 Mdot
.37687 .58546 Mdot
.71513 .08659 Mdot
.66896 .07656 Mdot
.75549 .11828 Mdot
.42179 .59343 Mdot
.69501 .09563 Mdot
.4234 .59239 Mdot
.54166 .02883 Mdot
.63107 .07156 Mdot
.49001 .01052 Mdot
.42827 .59488 Mdot
.49458 .00343 Mdot
.42697 .61235 Mdot
.64529 .08114 Mdot
.50457 .00833 Mdot
.63602 .05323 Mdot
.33675 .56072 Mdot
.31877 .56188 Mdot
.77772 .13172 Mdot
.6399 .07744 Mdot
.40053 .58789 Mdot
.40207 .5936 Mdot
.7157 .08166 Mdot
.65412 .06276 Mdot
.66591 .07324 Mdot
.3825 .58338 Mdot
.41322 .5914 Mdot
.493 .00267 Mdot
.3329 .55998 Mdot
.55148 .04476 Mdot
.41925 .59146 Mdot
.65884 .05833 Mdot
.39588 .60749 Mdot
.63122 .06698 Mdot
.42153 .61319 Mdot
.7224 .09402 Mdot
.50119 .01188 Mdot
.59525 .03928 Mdot
.34274 .56679 Mdot
.47439 .01939 Mdot
.75032 .09363 Mdot
.66862 .06469 Mdot
.71046 .10747 Mdot
.75019 .09314 Mdot
.57134 .02949 Mdot
.4985 .01352 Mdot
.52339 .01801 Mdot
.52258 .01003 Mdot
.39882 .60972 Mdot
.79296 .13491 Mdot
.79721 .13015 Mdot
.69415 .10042 Mdot
.78729 .12328 Mdot
.77024 .12516 Mdot
.45408 .00174 Mdot
.76045 .11879 Mdot
.63126 .06404 Mdot
.51519 .01457 Mdot
.36097 .57328 Mdot
.73657 .09352 Mdot
.3406 .56828 Mdot
.32252 .56361 Mdot
.40504 .59984 Mdot
.4912 .0076 Mdot
.4799 .02054 Mdot
.58782 .04736 Mdot
.76705 .10608 Mdot
.69349 .09305 Mdot
.51433 .02878 Mdot
.43022 .60499 Mdot
.40869 .60216 Mdot
.43687 .59999 Mdot
.32646 .56438 Mdot
.49178 .02244 Mdot
.78306 .12624 Mdot
.74543 .10436 Mdot
.6791 .09083 Mdot
.53238 .04141 Mdot
.65347 .07215 Mdot
.5876 .04026 Mdot
.51025 .02551 Mdot
.52886 .03568 Mdot
.35676 .56994 Mdot
.35043 .58426 Mdot
.40866 .61022 Mdot
.72003 .10533 Mdot
.36794 .57194 Mdot
.71762 .08936 Mdot
.55664 .02859 Mdot
.55944 .03201 Mdot
.76879 .12061 Mdot
.71572 .08066 Mdot
.51274 .00498 Mdot
.56309 .03029 Mdot
.52898 .03639 Mdot
.59096 .05066 Mdot
.37613 .57313 Mdot
.73769 .11019 Mdot
.38672 .60595 Mdot
.76206 .10859 Mdot
.57208 .04709 Mdot
.45897 .60584 Mdot
.66928 .09087 Mdot
.48714 .6141 Mdot
.4121 .61466 Mdot
.78914 .12961 Mdot
.62688 .04908 Mdot
.45331 .60745 Mdot
.50313 .00274 Mdot
.5833 .04466 Mdot
.4944 .00122 Mdot
.56484 .02482 Mdot
.7836 .11561 Mdot
.47765 .01958 Mdot
.49309 .01163 Mdot
.73755 .11439 Mdot
.45707 .00022 Mdot
.69113 .07299 Mdot
.57833 .0427 Mdot
.61188 .06754 Mdot
.33217 .5696 Mdot
.77112 .11097 Mdot
.58076 .03871 Mdot
.46395 .61622 Mdot
.6584 .08456 Mdot
.36231 .58181 Mdot
.41701 .59931 Mdot
.48883 .01259 Mdot
.82208 .14307 Mdot
.54359 .02976 Mdot
.50102 .01215 Mdot
.79394 .1243 Mdot
.54599 .04646 Mdot
.28245 .5446 Mdot
.71349 .09938 Mdot
.67914 .08947 Mdot
.42962 .61712 Mdot
.57203 .03621 Mdot
.75512 .10588 Mdot
.45517 .00629 Mdot
.79369 .1239 Mdot
.65875 .06748 Mdot
.55058 .02393 Mdot
.72646 .10489 Mdot
.37685 .57836 Mdot
.70344 .09145 Mdot
.52993 .0257 Mdot
.40036 .60522 Mdot
.47426 .01052 Mdot
.57351 .04071 Mdot
.46282 .61148 Mdot
.4905 .01721 Mdot
.53116 .03149 Mdot
.58001 .04136 Mdot
.72737 .09827 Mdot
.72003 .10116 Mdot
.60544 .04829 Mdot
.27609 .54091 Mdot
.44796 .00555 Mdot
.73614 .09663 Mdot
.71692 .08355 Mdot
.53779 .04057 Mdot
.6296 .07496 Mdot
.30479 .55332 Mdot
.35216 .5711 Mdot
.58756 .05634 Mdot
.48868 .01789 Mdot
.61514 .04641 Mdot
.63205 .06158 Mdot
.59852 .03668 Mdot
.55666 .03907 Mdot
.72596 .10296 Mdot
.5844 .04492 Mdot
.56046 .04526 Mdot
.33354 .57485 Mdot
.51295 .02177 Mdot
.72211 .09073 Mdot
.79004 .129 Mdot
.60821 .05725 Mdot
.43149 .61199 Mdot
.72026 .08474 Mdot
.5804 .04838 Mdot
.53921 .0306 Mdot
.72162 .11055 Mdot
.70016 .07551 Mdot
.41282 .59164 Mdot
.74593 .1059 Mdot
.76452 .1154 Mdot
.76423 .10195 Mdot
.83513 .1475 Mdot
.53549 .03201 Mdot
.66267 .06642 Mdot
.55959 .03649 Mdot
.45494 .00115 Mdot
.39727 .60965 Mdot
.60152 .05636 Mdot
.43856 .00353 Mdot
.44049 .60918 Mdot
.43633 .60448 Mdot
.5406 .03929 Mdot
.4126 .58936 Mdot
.56672 .05326 Mdot
.74231 .10321 Mdot
.65217 .07838 Mdot
.55705 .05085 Mdot
.44862 .60342 Mdot
.41697 .589 Mdot
.71454 .09432 Mdot
.35411 .57045 Mdot
.52728 .01246 Mdot
.78152 .12898 Mdot
.36015 .57481 Mdot
.62334 .06768 Mdot
.65896 .06762 Mdot
.62632 .05427 Mdot
.38208 .59201 Mdot
.44046 .60365 Mdot
.67805 .07795 Mdot
.76387 .10139 Mdot
.82548 .14553 Mdot
.66941 .06223 Mdot
.55532 .04477 Mdot
.74875 .09447 Mdot
.4495 .616 Mdot
.50398 .01355 Mdot
.5383 .02167 Mdot
.62623 .0511 Mdot
.53056 .03184 Mdot
.55713 .04779 Mdot
.60085 .04557 Mdot
.53364 .03315 Mdot
.63799 .06234 Mdot
.61096 .06161 Mdot
.45416 .61799 Mdot
.60365 .05455 Mdot
.26403 .5331 Mdot
.35266 .56818 Mdot
.58645 .05455 Mdot
.59273 .06362 Mdot
.31113 .55128 Mdot
.29276 .54558 Mdot
.57494 .05125 Mdot
.62186 .05677 Mdot
.68482 .0803 Mdot
.38637 .59804 Mdot
.60322 .06339 Mdot
.52746 .01491 Mdot
.59846 .06134 Mdot
.42796 .59205 Mdot
.2714 .53793 Mdot
.69994 .074 Mdot
.70068 .07343 Mdot
.78591 .1333 Mdot
.5011 .00696 Mdot
.41927 .60508 Mdot
.68423 .09226 Mdot
.41075 .61139 Mdot
.45421 .01231 Mdot
.62852 .0682 Mdot
.60255 .04169 Mdot
.45225 .00252 Mdot
.59058 .03492 Mdot
.49623 .01748 Mdot
.63354 .05027 Mdot
.57661 .04875 Mdot
.50437 .02596 Mdot
.41019 .58879 Mdot
.56899 .02569 Mdot
.37597 .58093 Mdot
.48776 .61472 Mdot
.61477 .05991 Mdot
.75287 .12042 Mdot
.53422 .03989 Mdot
.41811 .61442 Mdot
.29723 .55346 Mdot
.5291 .03545 Mdot
.58143 .04786 Mdot
.28226 .53947 Mdot
.42351 .60383 Mdot
.45589 .60192 Mdot
.30557 .5532 Mdot
.83126 .14983 Mdot
.55378 .03779 Mdot
.33653 .55977 Mdot
.39429 .60031 Mdot
.29731 .55034 Mdot
.35655 .57805 Mdot
.63016 .05875 Mdot
.64031 .07605 Mdot
.60539 .04923 Mdot
.4686 .61669 Mdot
.40147 .59189 Mdot
.42037 .59336 Mdot
.43255 .6042 Mdot
.73295 .10216 Mdot
.35263 .57384 Mdot
.71527 .10543 Mdot
.31441 .55446 Mdot
.61423 .05612 Mdot
.54837 .04091 Mdot
.35201 .58456 Mdot
.69099 .08315 Mdot
.6252 .0555 Mdot
.543 .01874 Mdot
.45603 .60625 Mdot
.48211 .01506 Mdot
.5899 .05096 Mdot
.38586 .58852 Mdot
.74134 .11037 Mdot
.3298 .56455 Mdot
.38159 .58235 Mdot
.64539 .06875 Mdot
.40833 .60269 Mdot
.69846 .07463 Mdot
.52978 .01978 Mdot
.53043 .04042 Mdot
.32841 .55977 Mdot
.30638 .55567 Mdot
.60396 .05483 Mdot
.78174 .12859 Mdot
.72882 .10898 Mdot
.7097 .09416 Mdot
.60081 .05417 Mdot
.32018 .55437 Mdot
.5655 .05285 Mdot
.48432 .024 Mdot
.78023 .12238 Mdot
.69764 .07242 Mdot
.70967 .09279 Mdot
.77025 .1218 Mdot
.47944 .02172 Mdot
.8489 .15414 Mdot
.49751 .00352 Mdot
.39878 .59123 Mdot
.76193 .11326 Mdot
.33631 .56695 Mdot
.57126 .04486 Mdot
.71452 .08717 Mdot
.65557 .08598 Mdot
.75787 .10188 Mdot
.69207 .08353 Mdot
.36663 .58514 Mdot
.58612 .04542 Mdot
.37811 .59192 Mdot
.34347 .57024 Mdot
.72164 .08865 Mdot
.44386 .00106 Mdot
.76314 .12602 Mdot
.61989 .04724 Mdot
.79065 .12662 Mdot
.33888 .56357 Mdot
.77336 .11163 Mdot
.51147 .02558 Mdot
.78571 .13153 Mdot
.67321 .07153 Mdot
.66489 .06943 Mdot
.70595 .10463 Mdot
.686 .06901 Mdot
.51448 .01234 Mdot
.30079 .54739 Mdot
.64247 .0565 Mdot
.3715 .5823 Mdot
.67856 .09549 Mdot
.45945 .01413 Mdot
.41845 .59608 Mdot
.41793 .58975 Mdot
.49243 .61551 Mdot
.62113 .06798 Mdot
.65389 .05812 Mdot
.68065 .08889 Mdot
.51192 .0288 Mdot
.6362 .07075 Mdot
.6177 .06393 Mdot
.51825 .01598 Mdot
.8019 .13083 Mdot
.43215 .60341 Mdot
.64107 .06479 Mdot
.75625 .10144 Mdot
.40126 .59425 Mdot
.51276 .01965 Mdot
.49321 .00822 Mdot
.70071 .09675 Mdot
.35768 .58287 Mdot
.3198 .5546 Mdot
.60389 .06402 Mdot
.66674 .08448 Mdot
.54484 .02148 Mdot
.48587 .00719 Mdot
.76938 .12085 Mdot
.47192 .61173 Mdot
.6238 .05544 Mdot
.33852 .57933 Mdot
.50201 .02955 Mdot
.4984 .02559 Mdot
.4016 .59454 Mdot
.43511 .00035 Mdot
.66495 .07766 Mdot
.51536 .00671 Mdot
.37416 .58401 Mdot
.40297 .60117 Mdot
.46826 .00797 Mdot
.67669 .07945 Mdot
.5931 .04439 Mdot
.7176 .10544 Mdot
.46248 .6152 Mdot
.59101 .06243 Mdot
.43642 .00554 Mdot
.40951 .58964 Mdot
.51715 .01792 Mdot
.64198 .05626 Mdot
.51712 .03596 Mdot
.61354 .05738 Mdot
.30774 .55881 Mdot
.68211 .0677 Mdot
.45592 .60172 Mdot
.34125 .56591 Mdot
.36966 .58987 Mdot
.61578 .04956 Mdot
.79447 .12775 Mdot
.45766 .60414 Mdot
.53391 .02119 Mdot
.68406 .09572 Mdot
.38951 .58641 Mdot
.32812 .56837 Mdot
.46085 .01467 Mdot
.38741 .58806 Mdot
.75094 .12122 Mdot
.30461 .55271 Mdot
.63821 .06096 Mdot
.55154 .04747 Mdot
.70641 .09556 Mdot
.83559 .14895 Mdot
.42495 .6012 Mdot
.5299 .03986 Mdot
.29314 .54489 Mdot
.4596 .00165 Mdot
.69398 .07391 Mdot
.32878 .56102 Mdot
.32051 .5568 Mdot
.40329 .61345 Mdot
.5467 .04122 Mdot
.59454 .03619 Mdot
.58862 .03734 Mdot
.62051 .04889 Mdot
.53511 .03651 Mdot
.46185 .60929 Mdot
.49901 .0213 Mdot
.37807 .59269 Mdot
.55058 .03735 Mdot
.78979 .11851 Mdot
.48538 .00916 Mdot
.76607 .11047 Mdot
.8013 .13025 Mdot
.42867 .60403 Mdot
.47019 .00485 Mdot
.55633 .02867 Mdot
.79844 .1311 Mdot
.34744 .56458 Mdot
.55602 .02117 Mdot
.34772 .57654 Mdot
.37867 .58531 Mdot
.2984 .54485 Mdot
.75819 .12183 Mdot
.39368 .59591 Mdot
.69848 .0791 Mdot
.70806 .08029 Mdot
.60224 .05815 Mdot
.52669 .03614 Mdot
.66745 .08999 Mdot
.43454 .00015 Mdot
.37109 .60011 Mdot
.34514 .57212 Mdot
.73275 .10153 Mdot
.3062 .55844 Mdot
.35318 .58451 Mdot
.77318 .12364 Mdot
.39603 .59276 Mdot
.80598 .1304 Mdot
.66109 .08179 Mdot
.65773 .08093 Mdot
.3716 .59621 Mdot
.59616 .06407 Mdot
.38018 .60157 Mdot
.5063 .02055 Mdot
.38874 .58737 Mdot
.45911 .61103 Mdot
.41419 .60768 Mdot
.55186 .03371 Mdot
.75934 .10217 Mdot
.60757 .06504 Mdot
.4765 .00693 Mdot
.69545 .0741 Mdot
.48303 .01523 Mdot
.47355 .61215 Mdot
.4811 .01826 Mdot
.34447 .57753 Mdot
.34989 .57891 Mdot
.62792 .05461 Mdot
.79714 .13281 Mdot
.44856 .0039 Mdot
.77848 .11759 Mdot
.70847 .10417 Mdot
.55895 .02226 Mdot
.75683 .11895 Mdot
.44719 .6073 Mdot
.53601 .03381 Mdot
.34317 .57488 Mdot
.44879 .60412 Mdot
.85361 .15686 Mdot
.68971 .09764 Mdot
.31613 .55535 Mdot
.49337 .0024 Mdot
.39897 .59926 Mdot
.65306 .06396 Mdot
.58645 .04947 Mdot
.7588 .10729 Mdot
.39163 .58699 Mdot
.59887 .05869 Mdot
.42646 .61654 Mdot
.4033 .59993 Mdot
.43319 .00255 Mdot
.58028 .04908 Mdot
.37577 .59594 Mdot
.34369 .5762 Mdot
.71811 .08402 Mdot
.43321 .60036 Mdot
.50719 .01943 Mdot
.53798 .03793 Mdot
.37017 .57866 Mdot
.68523 .06954 Mdot
.32271 .56717 Mdot
.65804 .07289 Mdot
.75043 .10783 Mdot
.45059 .00701 Mdot
.75305 .11657 Mdot
.36514 .57927 Mdot
.77674 .12018 Mdot
.67599 .06794 Mdot
.52511 .01148 Mdot
.51097 .0133 Mdot
.52797 .03419 Mdot
.57193 .0341 Mdot
.46369 .6156 Mdot
.77891 .12501 Mdot
.57866 .05375 Mdot
.70439 .10321 Mdot
.57279 .02815 Mdot
.59342 .05185 Mdot
.65993 .07105 Mdot
.66381 .07438 Mdot
.38801 .58686 Mdot
.40461 .58751 Mdot
.72517 .0985 Mdot
.70117 .10131 Mdot
.5146 .01016 Mdot
.66619 .06525 Mdot
.31388 .56081 Mdot
.33789 .5653 Mdot
.48304 .00236 Mdot
.61001 .05954 Mdot
.69173 .09733 Mdot
.69203 .07529 Mdot
.55641 .03745 Mdot
.54172 .01576 Mdot
.57818 .02976 Mdot
.70529 .07807 Mdot
.43694 .00313 Mdot
.41701 .61721 Mdot
.38196 .59118 Mdot
.81989 .1389 Mdot
.64399 .06045 Mdot
.46827 .60988 Mdot
.32947 .56707 Mdot
.64277 .08129 Mdot
.63638 .07433 Mdot
.8427 .15307 Mdot
.80177 .1333 Mdot
.39669 .60606 Mdot
.74256 .1164 Mdot
.84019 .14986 Mdot
.61598 .05387 Mdot
.27994 .54225 Mdot
.71577 .08229 Mdot
.55269 .01952 Mdot
.76498 .12007 Mdot
.28711 .54216 Mdot
.50293 .02988 Mdot
.30498 .55014 Mdot
.44434 .60311 Mdot
.76871 .10502 Mdot
.56987 .03436 Mdot
.30818 .56063 Mdot
.81761 .14348 Mdot
.76857 .10511 Mdot
.36131 .59237 Mdot
.47515 .61665 Mdot
.33705 .55927 Mdot
.44538 .60435 Mdot
.69744 .07409 Mdot
.39711 .5837 Mdot
.62795 .07347 Mdot
.48899 .0217 Mdot
.7998 .12669 Mdot
.44025 .61027 Mdot
.36161 .58853 Mdot
.41234 .59208 Mdot
.37988 .60157 Mdot
.80192 .13904 Mdot
.78395 .12952 Mdot
.61131 .06297 Mdot
.82719 .14237 Mdot
.46604 .00574 Mdot
.57804 .0558 Mdot
.35609 .58913 Mdot
.51996 .0167 Mdot
.65676 .06596 Mdot
.53563 .03216 Mdot
.4966 .00055 Mdot
.53374 .03503 Mdot
.56017 .02558 Mdot
.61566 .06982 Mdot
.32616 .56661 Mdot
.52968 .01472 Mdot
.72225 .10485 Mdot
.32701 .56173 Mdot
.62525 .04667 Mdot
.67154 .09046 Mdot
.82888 .14163 Mdot
.38807 .58496 Mdot
.59187 .05431 Mdot
.71986 .09601 Mdot
.77562 .11767 Mdot
.47738 .00961 Mdot
.70845 .08194 Mdot
.69543 .0862 Mdot
.36345 .58107 Mdot
.62496 .05384 Mdot
.48276 .00571 Mdot
.33027 .5671 Mdot
.51428 .02502 Mdot
.68417 .06988 Mdot
.78891 .13541 Mdot
.3431 .57879 Mdot
.75471 .10514 Mdot
.72748 .11292 Mdot
.30526 .55409 Mdot
.7744 .11471 Mdot
.80277 .1343 Mdot
.40687 .59079 Mdot
.57625 .03974 Mdot
.45422 .00986 Mdot
.43448 .61577 Mdot
.51458 .02931 Mdot
.51024 .0259 Mdot
.42964 .59892 Mdot
.49937 .00966 Mdot
.57063 .03389 Mdot
.4516 .60356 Mdot
.65927 .08176 Mdot
.51262 .01425 Mdot
.50389 .01721 Mdot
.80178 .13855 Mdot
.4242 .60965 Mdot
.62358 .05198 Mdot
.77418 .12581 Mdot
.48449 .00825 Mdot
.59857 .05471 Mdot
.72844 .08717 Mdot
.76979 .10849 Mdot
.53346 .01303 Mdot
.48879 .0133 Mdot
.39535 .60105 Mdot
.72731 .08411 Mdot
.45614 .00675 Mdot
.68134 .07904 Mdot
.58034 .0461 Mdot
.76969 .11548 Mdot
.34882 .56502 Mdot
.54684 .04577 Mdot
.4826 .02188 Mdot
.51883 .0249 Mdot
.69727 .10039 Mdot
.28708 .54128 Mdot
.55679 .02769 Mdot
.42059 .00034 Mdot
.47264 .00363 Mdot
.48314 .01022 Mdot
.75971 .12279 Mdot
.57759 .05799 Mdot
.66567 .08606 Mdot
.28776 .54189 Mdot
.55478 .04671 Mdot
.63183 .06144 Mdot
.72615 .11234 Mdot
.60178 .04983 Mdot
.42322 .61237 Mdot
.55627 .03409 Mdot
.69515 .08006 Mdot
.44624 .00725 Mdot
.3144 .56229 Mdot
.73466 .11366 Mdot
.51023 .01981 Mdot
.70442 .10175 Mdot
.81606 .13417 Mdot
.33059 .57059 Mdot
.46936 .00913 Mdot
.47103 .60865 Mdot
.42283 .00039 Mdot
.77874 .11968 Mdot
.47113 .00899 Mdot
.70997 .0985 Mdot
.41544 .59544 Mdot
.83566 .14575 Mdot
.77029 .12142 Mdot
.51087 .03142 Mdot
.69469 .07406 Mdot
.43841 .60922 Mdot
.60026 .04944 Mdot
.7135 .09086 Mdot
.5521 .0334 Mdot
.79639 .13288 Mdot
.45374 .00758 Mdot
.34364 .56417 Mdot
.78046 .11804 Mdot
.36832 .57932 Mdot
.38904 .60159 Mdot
.72138 .09298 Mdot
.43646 .61536 Mdot
.65743 .08602 Mdot
.58399 .03923 Mdot
.68976 .08528 Mdot
.40652 .60819 Mdot
.75607 .11476 Mdot
.81503 .14466 Mdot
.66847 .07965 Mdot
.77534 .11362 Mdot
.55397 .02802 Mdot
.76532 .1171 Mdot
.69859 .09943 Mdot
.70473 .10486 Mdot
.41671 .61633 Mdot
.37715 .59492 Mdot
.47084 .00194 Mdot
.83152 .14797 Mdot
.58102 .05174 Mdot
.39573 .60851 Mdot
.66005 .06325 Mdot
.36119 .5819 Mdot
.47926 .01865 Mdot
.45829 .00896 Mdot
.52883 .01079 Mdot
.62139 .06963 Mdot
.48723 .61514 Mdot
.50032 .0038 Mdot
.39097 .59749 Mdot
.53121 .01801 Mdot
.67551 .09184 Mdot
.51231 .01322 Mdot
.76053 .11825 Mdot
.5264 .03407 Mdot
.65572 .08382 Mdot
.32334 .55367 Mdot
.38434 .60296 Mdot
.56815 .03053 Mdot
.63968 .07594 Mdot
.32209 .55469 Mdot
.50301 .00644 Mdot
.65659 .08285 Mdot
.69453 .07963 Mdot
.39753 .59697 Mdot
.79483 .12258 Mdot
.73608 .10862 Mdot
.51786 .02564 Mdot
.66827 .0837 Mdot
.51111 .02686 Mdot
.35657 .58248 Mdot
.73976 .11676 Mdot
.77553 .11497 Mdot
.48877 .01886 Mdot
.49615 .01803 Mdot
.54075 .02978 Mdot
.35404 .56776 Mdot
.60721 .06868 Mdot
.48332 .00511 Mdot
.34453 .57158 Mdot
.68381 .08752 Mdot
.69731 .08979 Mdot
.58393 .0345 Mdot
.33698 .57835 Mdot
.67109 .08188 Mdot
.70881 .10252 Mdot
.54608 .04602 Mdot
.42004 .59929 Mdot
.447 .00664 Mdot
.68006 .07773 Mdot
.70906 .09138 Mdot
.59174 .03532 Mdot
.40193 .60748 Mdot
.75798 .10842 Mdot
.56262 .04433 Mdot
.80056 .13548 Mdot
.63955 .05394 Mdot
.3485 .56246 Mdot
.46517 .60847 Mdot
.79074 .12526 Mdot
.39232 .58585 Mdot
.36859 .57775 Mdot
.54938 .04091 Mdot
.5236 .01509 Mdot
.52302 .03636 Mdot
.6301 .07012 Mdot
.70612 .08209 Mdot
.6939 .09804 Mdot
.32381 .55796 Mdot
.59812 .06258 Mdot
.60326 .03887 Mdot
.55073 .02592 Mdot
.58328 .05396 Mdot
.55515 .04952 Mdot
.2904 .5424 Mdot
.77714 .12441 Mdot
.63025 .05047 Mdot
.40192 .58264 Mdot
.78725 .13099 Mdot
.57679 .03267 Mdot
.72084 .10294 Mdot
.35259 .57201 Mdot
.37471 .5938 Mdot
.54801 .01838 Mdot
.65517 .0848 Mdot
.36486 .56959 Mdot
.62128 .07175 Mdot
.45202 .60851 Mdot
.73813 .1122 Mdot
.30793 .55605 Mdot
.81326 .14337 Mdot
.47354 .61138 Mdot
.34988 .57037 Mdot
.49546 .02363 Mdot
.35396 .5815 Mdot
.69605 .09709 Mdot
.56235 .04155 Mdot
.58356 .0543 Mdot
.804 .1323 Mdot
.38548 .59158 Mdot
.44405 .00662 Mdot
.33644 .56635 Mdot
.49375 .02576 Mdot
.60751 .04434 Mdot
.4007 .60297 Mdot
.48336 .00298 Mdot
.30564 .55231 Mdot
.65603 .07197 Mdot
.60662 .05547 Mdot
.44482 .00058 Mdot
.66541 .08558 Mdot
.31706 .55713 Mdot
.59445 .06233 Mdot
.8413 .15189 Mdot
.47374 .0199 Mdot
.49243 .02019 Mdot
.33086 .56513 Mdot
.7533 .10635 Mdot
.28462 .54396 Mdot
.47383 .0199 Mdot
.53953 .03209 Mdot
.76975 .1063 Mdot
.74172 .1119 Mdot
.71219 .08036 Mdot
.51981 .0326 Mdot
.73152 .08955 Mdot
.42171 .61567 Mdot
.61587 .055 Mdot
.34979 .5814 Mdot
.7266 .11183 Mdot
.32473 .56868 Mdot
.62566 .07518 Mdot
.64676 .0802 Mdot
.59686 .05599 Mdot
.65115 .0586 Mdot
.62913 .06491 Mdot
.50346 .00877 Mdot
.64091 .06393 Mdot
.45623 .6134 Mdot
.40231 .61291 Mdot
.48419 .01825 Mdot
.41826 .58918 Mdot
.41818 .59833 Mdot
.65996 .06121 Mdot
.6398 .06596 Mdot
.43623 .60664 Mdot
.73285 .09647 Mdot
.67577 .08974 Mdot
.48383 .61578 Mdot
.77679 .11353 Mdot
.40237 .60482 Mdot
.75378 .10586 Mdot
.78155 .1313 Mdot
.59136 .04562 Mdot
.61774 .06101 Mdot
.67745 .07468 Mdot
.72148 .08376 Mdot
.61391 .0692 Mdot
.36767 .59236 Mdot
.68431 .06979 Mdot
.62649 .06475 Mdot
.76857 .1176 Mdot
.59854 .06216 Mdot
.75548 .09869 Mdot
.68353 .09559 Mdot
.54269 .03983 Mdot
.32308 .56442 Mdot
.61326 .05663 Mdot
.3426 .56781 Mdot
.37449 .5901 Mdot
.35394 .58051 Mdot
.43293 .60854 Mdot
.59131 .0608 Mdot
.52859 .03621 Mdot
.73446 .0862 Mdot
.51449 .0249 Mdot
.42939 .59533 Mdot
.83317 .14661 Mdot
.48387 .01704 Mdot
.47854 .00261 Mdot
.39777 .59662 Mdot
.47985 .01558 Mdot
.30227 .54666 Mdot
.30532 .5556 Mdot
.57539 .03126 Mdot
.63855 .06318 Mdot
.58251 .03255 Mdot
.49524 .02047 Mdot
.52424 .0374 Mdot
.52335 .03534 Mdot
.29842 .55066 Mdot
.78708 .12066 Mdot
.76185 .11548 Mdot
.68516 .09144 Mdot
.71727 .09891 Mdot
.63803 .06623 Mdot
.39659 .59589 Mdot
.7411 .09058 Mdot
.56079 .03598 Mdot
.62425 .05676 Mdot
.40926 .59974 Mdot
.47199 .00355 Mdot
.36945 .57973 Mdot
.54718 .04498 Mdot
.47115 .00909 Mdot
.61084 .04552 Mdot
.50122 .00125 Mdot
.351 .58385 Mdot
.47802 .00695 Mdot
.35041 .58011 Mdot
.66427 .06185 Mdot
.46923 .61178 Mdot
.62968 .06449 Mdot
.37391 .59381 Mdot
.51354 .01214 Mdot
.68994 .09347 Mdot
.4156 .60453 Mdot
.33842 .57904 Mdot
.66143 .07613 Mdot
.84778 .15611 Mdot
.43456 .59521 Mdot
.75676 .10713 Mdot
.63746 .08045 Mdot
.54326 .02423 Mdot
.75226 .10526 Mdot
.54574 .03386 Mdot
.4941 .00373 Mdot
.72382 .10604 Mdot
.45205 .0009 Mdot
.64477 .05811 Mdot
.53887 .0164 Mdot
.65822 .06346 Mdot
.35658 .56595 Mdot
.76383 .11848 Mdot
.58672 .03285 Mdot
.47456 .004 Mdot
.69812 .09055 Mdot
.79403 .13405 Mdot
.45586 .61328 Mdot
.32742 .5578 Mdot
.38093 .59824 Mdot
.54741 .04528 Mdot
.58563 .05254 Mdot
.63727 .07335 Mdot
.48172 .01356 Mdot
.61885 .04474 Mdot
.64381 .07268 Mdot
.5157 .02306 Mdot
.69047 .07161 Mdot
.5871 .05305 Mdot
.60912 .06062 Mdot
.51394 .02322 Mdot
.60462 .06584 Mdot
.34562 .58304 Mdot
.76002 .10046 Mdot
.56928 .05293 Mdot
.65738 .07397 Mdot
.69889 .09994 Mdot
.39066 .60516 Mdot
.43448 .60301 Mdot
.44186 .00307 Mdot
.71483 .09721 Mdot
.58009 .03353 Mdot
.57295 .05673 Mdot
.34932 .56956 Mdot
.48641 .00462 Mdot
.32997 .55603 Mdot
.77869 .11335 Mdot
.53875 .02852 Mdot
.4584 .00019 Mdot
.5249 .02705 Mdot
.7644 .10204 Mdot
.45714 .00797 Mdot
.42912 .61022 Mdot
.62512 .06596 Mdot
.72212 .09983 Mdot
.52955 .02405 Mdot
.48804 .00394 Mdot
.4535 .6138 Mdot
.57093 .05225 Mdot
.7811 .13186 Mdot
.36683 .58006 Mdot
.50933 .01404 Mdot
.34285 .5648 Mdot
.42575 .60775 Mdot
.77571 .11649 Mdot
.66856 .08935 Mdot
.43172 .00315 Mdot
.39205 .59251 Mdot
.68899 .08902 Mdot
.68247 .06765 Mdot
.48968 .01922 Mdot
.28038 .54084 Mdot
.37906 .58637 Mdot
.63277 .07052 Mdot
.29571 .55276 Mdot
.45909 .60741 Mdot
.38041 .59721 Mdot
.65886 .06587 Mdot
.80987 .13745 Mdot
.64104 .07547 Mdot
.37836 .57838 Mdot
.70389 .09763 Mdot
.75176 .10372 Mdot
.68204 .08739 Mdot
.75025 .12151 Mdot
.4245 .00155 Mdot
.71395 .0999 Mdot
.70997 .10152 Mdot
.71056 .10652 Mdot
.79273 .12318 Mdot
.64345 .0573 Mdot
.5297 .03412 Mdot
.63824 .08035 Mdot
.57447 .02837 Mdot
.63059 .0657 Mdot
.75539 .1035 Mdot
.74552 .10807 Mdot
.70932 .08862 Mdot
.40892 .61221 Mdot
.37616 .5908 Mdot
.56258 .05096 Mdot
.3244 .55475 Mdot
.66751 .08536 Mdot
.65964 .06632 Mdot
.4043 .60761 Mdot
.34067 .56669 Mdot
.51879 .01354 Mdot
.44694 .00686 Mdot
.63964 .0701 Mdot
.4825 .00778 Mdot
.60621 .06077 Mdot
.48226 .02014 Mdot
.4174 .61163 Mdot
.41491 .61312 Mdot
.49595 .61654 Mdot
.49965 .01799 Mdot
.46655 .61145 Mdot
.41453 .59809 Mdot
.81259 .14355 Mdot
.34556 .57761 Mdot
.42877 .60238 Mdot
.60579 .04001 Mdot
.69064 .08926 Mdot
.49547 .00252 Mdot
.64783 .07996 Mdot
.45533 .60988 Mdot
.40692 .60989 Mdot
.81652 .13507 Mdot
.68474 .08766 Mdot
.66126 .06804 Mdot
.73547 .10685 Mdot
.69324 .09457 Mdot
.56005 .03186 Mdot
.82797 .14141 Mdot
.73608 .10741 Mdot
.59194 .05202 Mdot
.46229 .01141 Mdot
.38912 .58705 Mdot
.43294 .00569 Mdot
.43328 .61308 Mdot
.49317 .00763 Mdot
.51873 .01769 Mdot
.62516 .06609 Mdot
.69362 .08883 Mdot
.32231 .564 Mdot
.72616 .10841 Mdot
.44814 .00043 Mdot
.38732 .58364 Mdot
.36483 .59406 Mdot
.37723 .60166 Mdot
.79258 .13144 Mdot
.6849 .07569 Mdot
.55445 .03423 Mdot
.53877 .04107 Mdot
.79408 .13179 Mdot
.5936 .044 Mdot
.73055 .09854 Mdot
.73268 .09951 Mdot
.65721 .08255 Mdot
.60054 .0444 Mdot
.55111 .01921 Mdot
.60204 .04763 Mdot
.623 .05122 Mdot
.66252 .06178 Mdot
.44119 8e-05 Mdot
.49637 .00378 Mdot
.51058 .03112 Mdot
.76959 .12469 Mdot
.52591 .02274 Mdot
.77775 .11222 Mdot
.7358 .10528 Mdot
.43593 .59854 Mdot
.43896 .61403 Mdot
.70264 .09898 Mdot
.56373 .03611 Mdot
.7835 .12581 Mdot
.49499 .019 Mdot
.54213 .03241 Mdot
.36315 .59277 Mdot
.63938 .07263 Mdot
.57866 .03939 Mdot
.60294 .04775 Mdot
.70896 .09857 Mdot
.41824 .59333 Mdot
.52278 .01159 Mdot
.58409 .04225 Mdot
.81974 .1366 Mdot
.6652 .07998 Mdot
.7041 .10484 Mdot
.37507 .57413 Mdot
.59964 .04277 Mdot
.60391 .04924 Mdot
.39709 .60665 Mdot
.74167 .08845 Mdot
.43146 .59666 Mdot
.70278 .10039 Mdot
.65596 .05805 Mdot
.37348 .58642 Mdot
.69676 .08248 Mdot
.57366 .05242 Mdot
.36826 .58059 Mdot
.45196 .0057 Mdot
.51483 .01015 Mdot
.596 .04791 Mdot
.49365 .00665 Mdot
.59504 .04642 Mdot
.31812 .55703 Mdot
.75678 .10952 Mdot
.40513 .58733 Mdot
.64077 .05304 Mdot
.57498 .0516 Mdot
.43914 .60136 Mdot
.46075 .61685 Mdot
.36303 .58073 Mdot
.69281 .07946 Mdot
.51258 .00474 Mdot
.57187 .05594 Mdot
.78149 .12145 Mdot
.50972 .02794 Mdot
.28398 .54299 Mdot
.3622 .58867 Mdot
.38456 .57732 Mdot
.65002 .08146 Mdot
.80878 .13872 Mdot
.4407 .60885 Mdot
.70376 .08827 Mdot
.49444 .00193 Mdot
.44423 .61074 Mdot
.29972 .54991 Mdot
.52618 .03406 Mdot
.65242 .06613 Mdot
.50057 .02157 Mdot
.66784 .08166 Mdot
.37273 .59178 Mdot
.39368 .60331 Mdot
.42541 .61465 Mdot
.69605 .08288 Mdot
.46647 .61589 Mdot
.45419 .60787 Mdot
.39901 .60883 Mdot
.41192 .58789 Mdot
.61609 .04527 Mdot
.62794 .06964 Mdot
.48681 .00596 Mdot
.70478 .0774 Mdot
.49044 .0176 Mdot
.68913 .07855 Mdot
.44092 .00608 Mdot
.37275 .60113 Mdot
.71927 .09774 Mdot
.6589 .08 Mdot
.69767 .09298 Mdot
.49813 .01815 Mdot
.34031 .57843 Mdot
.73836 .11425 Mdot
.59494 .04186 Mdot
.77622 .12501 Mdot
.47566 .00643 Mdot
.34535 .57689 Mdot
.41032 .60329 Mdot
.35227 .58123 Mdot
.43621 .59527 Mdot
.5565 .04582 Mdot
.60714 .05026 Mdot
.31489 .55702 Mdot
.64537 .0766 Mdot
.43938 .60523 Mdot
.79222 .12237 Mdot
.52861 .02624 Mdot
.57484 .02836 Mdot
.44005 .5969 Mdot
.53756 .02644 Mdot
.4648 .00147 Mdot
.35621 .57754 Mdot
.77283 .11914 Mdot
.49423 .61699 Mdot
.71634 .09263 Mdot
.71472 .08668 Mdot
.53045 .01489 Mdot
.78339 .12554 Mdot
.37683 .59123 Mdot
.46448 .00815 Mdot
.68104 .08348 Mdot
.67402 .07262 Mdot
.46776 .60828 Mdot
.69384 .0983 Mdot
.55988 .03486 Mdot
.45226 .00828 Mdot
.71017 .10702 Mdot
.48172 .0107 Mdot
.43347 .00174 Mdot
.56288 .04867 Mdot
.31532 .55923 Mdot
.35247 .56836 Mdot
.49679 .01996 Mdot
.54385 .04173 Mdot
.77347 .11897 Mdot
.71876 .10952 Mdot
.46887 .6127 Mdot
.51944 .01036 Mdot
.62743 .05374 Mdot
.41047 .60084 Mdot
.56786 .03587 Mdot
.71377 .09865 Mdot
.50952 .00628 Mdot
.61572 .05835 Mdot
.38588 .58776 Mdot
.44374 .61727 Mdot
.4755 .01335 Mdot
.59264 .05514 Mdot
.75143 .10818 Mdot
.33266 .57596 Mdot
.38027 .58365 Mdot
.66264 .06192 Mdot
.67965 .09491 Mdot
.32719 .5679 Mdot
.42415 .61644 Mdot
.57391 .05371 Mdot
.77961 .11603 Mdot
.38369 .58198 Mdot
.68206 .08905 Mdot
.65858 .07414 Mdot
.67453 .0698 Mdot
.70541 .10355 Mdot
.66895 .08855 Mdot
.78673 .1306 Mdot
.84973 .1546 Mdot
.71826 .09342 Mdot
.68521 .06944 Mdot
.5174 .02306 Mdot
.76668 .11476 Mdot
.38787 .58702 Mdot
.46107 .01116 Mdot
.59639 .05992 Mdot
.5325 .03157 Mdot
.75816 .1215 Mdot
.73162 .10869 Mdot
.71331 .07858 Mdot
.74229 .11503 Mdot
.37348 .58986 Mdot
.79941 .13355 Mdot
.60041 .03797 Mdot
.29221 .54998 Mdot
.58546 .05224 Mdot
.69188 .08193 Mdot
.36832 .59754 Mdot
.5316 .03319 Mdot
.47074 .01905 Mdot
.66806 .09019 Mdot
.50006 .02862 Mdot
.67133 .06513 Mdot
.38349 .5864 Mdot
.7336 .0933 Mdot
.52977 .02105 Mdot
.70087 .0745 Mdot
.80606 .13057 Mdot
.38679 .59689 Mdot
.81737 .13848 Mdot
.71971 .10914 Mdot
.72514 .10615 Mdot
.42714 .0038 Mdot
.59755 .06051 Mdot
.49908 .02723 Mdot
.46721 .00139 Mdot
.50929 .02281 Mdot
.68377 .07078 Mdot
.55317 .03777 Mdot
.73867 .10149 Mdot
.54142 .04348 Mdot
.78225 .12428 Mdot
.57047 .02628 Mdot
.4345 .00416 Mdot
.51836 .00704 Mdot
.58305 .03394 Mdot
.39127 .58054 Mdot
.48697 .01471 Mdot
.74619 .10298 Mdot
.54947 .03432 Mdot
.56794 .04972 Mdot
.55669 .02301 Mdot
.40242 .60938 Mdot
.63875 .06208 Mdot
.57607 .05413 Mdot
.57847 .042 Mdot
.80242 .13652 Mdot
.73977 .09727 Mdot
.66726 .08509 Mdot
.62867 .06765 Mdot
.66519 .07118 Mdot
.33335 .56121 Mdot
.46902 .00401 Mdot
.52252 .01031 Mdot
.4433 .6163 Mdot
.7502 .1129 Mdot
.73383 .1089 Mdot
.42551 .59857 Mdot
.79371 .13449 Mdot
.54967 .04639 Mdot
.382 .57816 Mdot
.6691 .07027 Mdot
.58407 .05413 Mdot
.59123 .03777 Mdot
.36839 .57751 Mdot
.32322 .55557 Mdot
.78722 .12322 Mdot
.43656 .60556 Mdot
.43142 .00074 Mdot
.75143 .09375 Mdot
.50104 .02899 Mdot
.58137 .03476 Mdot
.37725 .59927 Mdot
.77744 .12837 Mdot
.53552 .01508 Mdot
.44141 .00111 Mdot
.54008 .03888 Mdot
.37618 .59383 Mdot
.49616 .00423 Mdot
.68254 .07661 Mdot
.43872 .60545 Mdot
.67148 .06961 Mdot
.31628 .56323 Mdot
.34479 .56308 Mdot
.79942 .12489 Mdot
.43165 .59805 Mdot
.52285 .02264 Mdot
.36615 .58206 Mdot
.36017 .58782 Mdot
.36897 .59328 Mdot
.60664 .05371 Mdot
.42834 .60438 Mdot
.41927 .59246 Mdot
.50368 .00747 Mdot
.48157 .01599 Mdot
.41246 .58996 Mdot
.42307 .59623 Mdot
.84251 .15365 Mdot
.76587 .11974 Mdot
.73532 .10246 Mdot
.66422 .06251 Mdot
.74478 .11388 Mdot
.43174 .61087 Mdot
.5698 .03691 Mdot
.75579 .10699 Mdot
.32142 .55804 Mdot
.65038 .07627 Mdot
.65223 .05662 Mdot
.47852 .00611 Mdot
.67097 .06444 Mdot
.57867 .05079 Mdot
.79638 .12312 Mdot
.66163 .07924 Mdot
.4308 .61442 Mdot
.48205 .61307 Mdot
.60832 .05053 Mdot
.59075 .0515 Mdot
.54236 .02119 Mdot
.80511 .13886 Mdot
.6369 .05528 Mdot
.58196 .04335 Mdot
.70894 .07923 Mdot
.37921 .59572 Mdot
.77312 .11715 Mdot
.46135 .60534 Mdot
.71947 .10664 Mdot
.84174 .15448 Mdot
.36691 .585 Mdot
.50853 .01493 Mdot
.56961 .03542 Mdot
.56831 .03979 Mdot
.67901 .07056 Mdot
.72875 .08444 Mdot
.71182 .07893 Mdot
.72862 .09382 Mdot
.31833 .56723 Mdot
.52175 .01658 Mdot
.4593 .00352 Mdot
.5425 .02433 Mdot
.34924 .56612 Mdot
.40922 .61214 Mdot
.64661 .07767 Mdot
.58565 .04378 Mdot
.71329 .09716 Mdot
.59923 .0473 Mdot
.74377 .10617 Mdot
.61535 .04294 Mdot
.68504 .07021 Mdot
.46571 .00913 Mdot
.60023 .05092 Mdot
.67098 .07613 Mdot
.50399 .01199 Mdot
.63781 .06722 Mdot
.72473 .09954 Mdot
.3085 .5527 Mdot
.38989 .60711 Mdot
.57303 .05037 Mdot
.38744 .58827 Mdot
.70579 .09896 Mdot
.44667 .60723 Mdot
.49217 .61646 Mdot
.71496 .10423 Mdot
.68911 .08788 Mdot
.46253 .0005 Mdot
.30746 .5498 Mdot
.60472 .06593 Mdot
.37837 .60241 Mdot
.5925 .06305 Mdot
.54667 .02135 Mdot
.45857 .00228 Mdot
.70709 .08692 Mdot
.7542 .10103 Mdot
.46802 .61573 Mdot
.4172 .60122 Mdot
.64752 .07583 Mdot
.81803 .14545 Mdot
.5956 .05478 Mdot
.46885 .60827 Mdot
.5959 .05722 Mdot
.73823 .08903 Mdot
.79185 .12401 Mdot
.65807 .0734 Mdot
.34341 .56777 Mdot
.6461 .06027 Mdot
.73999 .11557 Mdot
.60171 .06028 Mdot
.3474 .56812 Mdot
.64807 .07824 Mdot
.61808 .05988 Mdot
.43182 .61494 Mdot
.39767 .60555 Mdot
.43487 .61322 Mdot
.34691 .56874 Mdot
.52435 .01298 Mdot
.38295 .6063 Mdot
.74552 .11789 Mdot
.38367 .57769 Mdot
.3966 .58467 Mdot
.41343 .61349 Mdot
.61701 .05433 Mdot
.54041 .02522 Mdot
.55791 .04056 Mdot
.5182 .02254 Mdot
.37614 .57261 Mdot
.42597 .60006 Mdot
.71956 .10709 Mdot
.42227 .59897 Mdot
.83597 .15107 Mdot
.29742 .55206 Mdot
.69732 .09664 Mdot
.74467 .09968 Mdot
.3374 .57203 Mdot
.45994 .6033 Mdot
.64277 .07615 Mdot
.32086 .56785 Mdot
.51822 .02985 Mdot
.63567 .0548 Mdot
.66728 .08878 Mdot
.58544 .05658 Mdot
.69368 .09986 Mdot
.54655 .03512 Mdot
.73865 .09115 Mdot
.54622 .02466 Mdot
.7804 .12427 Mdot
.34085 .56755 Mdot
.51307 .03294 Mdot
.39946 .60504 Mdot
.73743 .09121 Mdot
.50805 .02137 Mdot
.44744 .60643 Mdot
.78752 .12851 Mdot
.62267 .05473 Mdot
.4959 .00373 Mdot
.62627 .0515 Mdot
.81399 .14243 Mdot
.70926 .09001 Mdot
.73112 .10514 Mdot
.56936 .04049 Mdot
.70814 .10359 Mdot
.57485 .03761 Mdot
.45128 .60829 Mdot
.37922 .57566 Mdot
.52852 .02537 Mdot
.62474 .06864 Mdot
.7736 .10876 Mdot
.74426 .10724 Mdot
.33911 .5717 Mdot
.29371 .54794 Mdot
.47061 .01083 Mdot
.58658 .05148 Mdot
.63078 .07306 Mdot
.75478 .10229 Mdot
.43146 .60935 Mdot
.63317 .05666 Mdot
.64946 .0565 Mdot
.38278 .5902 Mdot
.7366 .10889 Mdot
.50217 .02787 Mdot
.65484 .06706 Mdot
.46669 .01034 Mdot
.55623 .03892 Mdot
.62789 .05019 Mdot
.7903 .12955 Mdot
.73534 .10997 Mdot
.61512 .04941 Mdot
.35911 .58293 Mdot
.7097 .08192 Mdot
.71757 .08002 Mdot
.35103 .57744 Mdot
.59252 .03802 Mdot
.43984 .59916 Mdot
.49742 .01012 Mdot
.74888 .10615 Mdot
.61807 .05173 Mdot
.81924 .1377 Mdot
.74683 .10498 Mdot
.46296 .00104 Mdot
.76573 .12649 Mdot
.49825 .00873 Mdot
.78995 .1341 Mdot
.52315 .03445 Mdot
.45285 .00673 Mdot
.82437 .14051 Mdot
.70137 .08681 Mdot
.33487 .56548 Mdot
.33898 .56392 Mdot
.3763 .58889 Mdot
.4551 .00341 Mdot
.65718 .05871 Mdot
.5559 .04164 Mdot
.53142 .03299 Mdot
.6321 .07203 Mdot
.38545 .60247 Mdot
.55138 .04808 Mdot
.30157 .54879 Mdot
.5976 .05249 Mdot
.82745 .14446 Mdot
.51254 .01631 Mdot
.71012 .08644 Mdot
.43117 .6147 Mdot
.31151 .55835 Mdot
.6217 .04552 Mdot
.64239 .06944 Mdot
.36366 .57549 Mdot
.63407 .07087 Mdot
.67745 .07326 Mdot
.58884 .05133 Mdot
.45336 .0044 Mdot
.6234 .06879 Mdot
.68719 .07855 Mdot
.65918 .07253 Mdot
.63052 .06612 Mdot
.60555 .04438 Mdot
.75366 .11012 Mdot
.34193 .57986 Mdot
.64643 .06393 Mdot
.56917 .05245 Mdot
.71197 .07905 Mdot
.72557 .09089 Mdot
.63539 .0603 Mdot
.47725 .00669 Mdot
.69202 .07064 Mdot
.56682 .0261 Mdot
.4369 .60735 Mdot
.82376 .14394 Mdot
.54818 .04295 Mdot
.74133 .09529 Mdot
.65043 .07091 Mdot
.54863 .02829 Mdot
.68178 .08043 Mdot
.56821 .0271 Mdot
.30343 .54981 Mdot
.46221 .00264 Mdot
.35316 .56678 Mdot
.64414 .06848 Mdot
.7793 .12199 Mdot
.68271 .08666 Mdot
.60657 .06387 Mdot
.68403 .07954 Mdot
.70268 .08353 Mdot
.38812 .57826 Mdot
.39835 .6072 Mdot
.68849 .09911 Mdot
.35445 .58861 Mdot
.4775 .00452 Mdot
.74193 .10875 Mdot
.70224 .10222 Mdot
.82431 .14849 Mdot
.76112 .10306 Mdot
.47359 .61356 Mdot
.4558 .01036 Mdot
.63781 .07695 Mdot
.81021 .13822 Mdot
.49527 .6167 Mdot
.49851 .02476 Mdot
.51992 .01518 Mdot
.76388 .10855 Mdot
.64493 .0714 Mdot
.43896 .61034 Mdot
.68418 .0858 Mdot
.41933 .59474 Mdot
.46202 .61648 Mdot
.34035 .57005 Mdot
.69243 .08727 Mdot
.39161 .59343 Mdot
.44944 .61534 Mdot
.75686 .11364 Mdot
.6766 .07303 Mdot
.73418 .09236 Mdot
.40686 .60433 Mdot
.6719 .08564 Mdot
.46832 .60854 Mdot
.50384 .01702 Mdot
.38185 .59498 Mdot
.41945 .59401 Mdot
.43328 .59662 Mdot
.40409 .60394 Mdot
.36064 .58497 Mdot
.39058 .57889 Mdot
.42678 .60016 Mdot
.51981 .03129 Mdot
.39641 .59933 Mdot
.5968 .03768 Mdot
.6735 .08065 Mdot
.46419 .00288 Mdot
.66745 .08875 Mdot
.30414 .55804 Mdot
.48547 .01827 Mdot
.76052 .11509 Mdot
.38209 .58114 Mdot
.62483 .06454 Mdot
.81802 .14336 Mdot
.47653 .01565 Mdot
.67961 .0743 Mdot
.6281 .06967 Mdot
.38308 .59744 Mdot
.41544 .59306 Mdot
.57981 .05393 Mdot
.49071 .02229 Mdot
.34767 .56305 Mdot
.47534 .61495 Mdot
.82675 .14331 Mdot
.71824 .09784 Mdot
.38816 .60529 Mdot
.61496 .06565 Mdot
.4504 .00062 Mdot
.72894 .0838 Mdot
.44468 .00722 Mdot
.69171 .09531 Mdot
.61129 .04378 Mdot
.57249 .05539 Mdot
.51676 .008 Mdot
.35615 .58937 Mdot
.55173 .02644 Mdot
.37869 .57854 Mdot
.54094 .0252 Mdot
.63149 .06033 Mdot
.46298 .00755 Mdot
.64439 .06419 Mdot
.39548 .60427 Mdot
.33165 .57393 Mdot
.52824 .03148 Mdot
.62028 .06189 Mdot
.75749 .11372 Mdot
.64313 .07757 Mdot
.46007 .61527 Mdot
.5165 .02564 Mdot
.66608 .06285 Mdot
.6338 .05726 Mdot
.57685 .03908 Mdot
.36894 .59845 Mdot
.55681 .03767 Mdot
.77763 .11125 Mdot
.40394 .609 Mdot
.53639 .03641 Mdot
.38894 .58335 Mdot
.76099 .1243 Mdot
.7926 .13107 Mdot
.49678 .00737 Mdot
.38474 .59863 Mdot
.61144 .04186 Mdot
.55212 .03066 Mdot
.62203 .0488 Mdot
.3732 .59736 Mdot
.70526 .09876 Mdot
.82998 .1495 Mdot
.54023 .04465 Mdot
.69853 .0961 Mdot
.52681 .01156 Mdot
.76923 .12777 Mdot
.40448 .60643 Mdot
.64165 .05889 Mdot
.5379 .03606 Mdot
.46225 .01137 Mdot
.66452 .07914 Mdot
.34763 .56268 Mdot
.82149 .14245 Mdot
.37987 .57525 Mdot
.65878 .0839 Mdot
.54927 .02669 Mdot
.38808 .60144 Mdot
.64683 .06382 Mdot
.72454 .08212 Mdot
.74611 .09203 Mdot
.56419 .03218 Mdot
.66301 .06777 Mdot
.76499 .11701 Mdot
.56925 .03281 Mdot
.8045 .13588 Mdot
.44107 .60197 Mdot
.52205 .03735 Mdot
.75923 .12252 Mdot
.39089 .58355 Mdot
.36929 .5883 Mdot
.40828 .58915 Mdot
.36375 .58314 Mdot
.7124 .10477 Mdot
.44465 .60432 Mdot
.691 .07649 Mdot
.74372 .11931 Mdot
.74808 .10228 Mdot
.55432 .0437 Mdot
.60199 .05006 Mdot
.66272 .08658 Mdot
.46284 .61095 Mdot
.54902 .02707 Mdot
.31041 .55075 Mdot
.56026 .0465 Mdot
.46224 .60929 Mdot
.37127 .58904 Mdot
.63813 .07971 Mdot
.49128 .01469 Mdot
.63438 .06664 Mdot
.80091 .13413 Mdot
.29065 .547 Mdot
.5144 .03285 Mdot
.68952 .09779 Mdot
.71308 .09706 Mdot
.63451 .07571 Mdot
.52481 .03325 Mdot
.42504 .6115 Mdot
.40966 .59136 Mdot
.6541 .07889 Mdot
.78165 .12134 Mdot
.76007 .09899 Mdot
.36031 .59261 Mdot
.72909 .0833 Mdot
.70657 .10283 Mdot
.41791 .59015 Mdot
.73661 .09422 Mdot
.65157 .06215 Mdot
.58782 .04615 Mdot
.60042 .05254 Mdot
.42982 .59919 Mdot
.80933 .13621 Mdot
.51166 .02267 Mdot
.78959 .12394 Mdot
.53066 .03529 Mdot
.80097 .12747 Mdot
.6929 .09859 Mdot
.64149 .06785 Mdot
.69969 .09299 Mdot
.73381 .09464 Mdot
.36558 .57446 Mdot
.50889 .02695 Mdot
.79957 .13832 Mdot
.44244 .59708 Mdot
.54231 .02567 Mdot
.51589 .01767 Mdot
.3856 .59231 Mdot
.57666 .05196 Mdot
.55857 .04 Mdot
.68263 .07526 Mdot
.72683 .11261 Mdot
.81089 .14259 Mdot
.61468 .06559 Mdot
.5574 .02627 Mdot
.68052 .09131 Mdot
.36739 .57406 Mdot
.39164 .59309 Mdot
.71793 .10302 Mdot
.38511 .60588 Mdot
.5133 .03376 Mdot
.56816 .03537 Mdot
.57776 .04942 Mdot
.70761 .08733 Mdot
.63179 .07056 Mdot
.46652 .00542 Mdot
.33333 .57515 Mdot
.65475 .08021 Mdot
.7067 .08808 Mdot
.51634 .01444 Mdot
.36645 .5893 Mdot
.50962 .01324 Mdot
.71587 .09987 Mdot
.80694 .14194 Mdot
.51049 .03338 Mdot
.35783 .58519 Mdot
.62725 .05463 Mdot
.63371 .04975 Mdot
.67296 .08456 Mdot
.3539 .57209 Mdot
.71049 .08562 Mdot
.70351 .10399 Mdot
.72208 .10078 Mdot
.4458 .61725 Mdot
.38504 .60585 Mdot
.50318 .02063 Mdot
.73588 .11595 Mdot
.40262 .5833 Mdot
.36637 .59144 Mdot
.51674 .00688 Mdot
.43592 .59496 Mdot
.53657 .03658 Mdot
.59159 .05581 Mdot
.70177 .09867 Mdot
.61676 .04603 Mdot
.50817 .0081 Mdot
.61032 .04499 Mdot
.37934 .58964 Mdot
.73695 .09128 Mdot
.72046 .09518 Mdot
.74974 .10499 Mdot
.45718 .61577 Mdot
.56898 .03855 Mdot
.78448 .12423 Mdot
.35562 .58732 Mdot
.45961 .01129 Mdot
.48038 .01072 Mdot
.69849 .09407 Mdot
.61888 .05771 Mdot
.57411 .03282 Mdot
.62472 .05468 Mdot
.71928 .10181 Mdot
.73872 .11269 Mdot
.51428 .01272 Mdot
.42274 .60132 Mdot
.59413 .05185 Mdot
.44579 .00082 Mdot
.50681 .02343 Mdot
.70897 .07882 Mdot
.55694 .02121 Mdot
.46602 .00624 Mdot
.36207 .5936 Mdot
.58992 .0434 Mdot
.38344 .57871 Mdot
.71703 .09501 Mdot
.73621 .11301 Mdot
.54798 .0213 Mdot
.39536 .58852 Mdot
.47419 .00318 Mdot
.75305 .11052 Mdot
.50969 .01364 Mdot
.4511 .61772 Mdot
.41761 .60934 Mdot
.46837 .01135 Mdot
.57448 .03862 Mdot
.34401 .58161 Mdot
.72385 .10826 Mdot
.46871 .01182 Mdot
.42965 .61462 Mdot
.33184 .57191 Mdot
.70026 .0829 Mdot
.4399 .00474 Mdot
.56351 .05253 Mdot
.73176 .09341 Mdot
.4004 .58934 Mdot
.63945 .06726 Mdot
.69401 .09837 Mdot
.67436 .09066 Mdot
.71322 .07853 Mdot
.45722 .60514 Mdot
.66116 .06809 Mdot
.50344 .01967 Mdot
.82343 .14745 Mdot
.43854 .61751 Mdot
.51596 .00594 Mdot
.45018 .61273 Mdot
.48769 .01741 Mdot
.67954 .09356 Mdot
.66245 .08516 Mdot
.26473 .53413 Mdot
.6926 .09523 Mdot
.66796 .08996 Mdot
.77418 .11535 Mdot
.41603 .59656 Mdot
.33025 .57327 Mdot
.35526 .58334 Mdot
.55536 .03648 Mdot
.64758 .05868 Mdot
.4408 .00246 Mdot
.34345 .56796 Mdot
.64571 .08254 Mdot
.33834 .5651 Mdot
.69867 .07727 Mdot
.53598 .02126 Mdot
.78566 .12332 Mdot
.49229 .02564 Mdot
.71489 .08124 Mdot
.3948 .59047 Mdot
.53521 .02973 Mdot
.49364 .00424 Mdot
.46806 .01099 Mdot
.5249 .03868 Mdot
.69058 .09422 Mdot
.44262 .00265 Mdot
.73594 .10596 Mdot
.65385 .07237 Mdot
.692 .07023 Mdot
.53325 .02923 Mdot
.83785 .15013 Mdot
.3921 .58438 Mdot
.56096 .03284 Mdot
.76489 .12677 Mdot
.46486 .00453 Mdot
.61261 .07116 Mdot
.6429 .07633 Mdot
.42296 .59568 Mdot
.65279 .06049 Mdot
.63784 .07135 Mdot
.70335 .07836 Mdot
.35725 .56909 Mdot
.72628 .0894 Mdot
.82708 .1466 Mdot
.5408 .0414 Mdot
.44049 .00642 Mdot
.33223 .56609 Mdot
.69419 .09985 Mdot
.55354 .03502 Mdot
.52243 .03024 Mdot
.6484 .06579 Mdot
.63298 .0506 Mdot
.68866 .07618 Mdot
.64953 .08334 Mdot
.7041 .07436 Mdot
.56527 .02502 Mdot
.53919 .01806 Mdot
.49828 .00222 Mdot
.58269 .055 Mdot
.6714 .06758 Mdot
.77035 .10724 Mdot
.52152 .02037 Mdot
.50093 .02846 Mdot
.63669 .06134 Mdot
.55864 .04275 Mdot
.36215 .58057 Mdot
.5988 .05754 Mdot
.54223 .02735 Mdot
.8011 .12694 Mdot
.30272 .55588 Mdot
.59692 .05865 Mdot
.3722 .57537 Mdot
.56777 .03868 Mdot
.71727 .10173 Mdot
.43896 .61101 Mdot
.33743 .56995 Mdot
.74692 .115 Mdot
.83617 .15062 Mdot
.40121 .5847 Mdot
.55162 .03531 Mdot
.46137 .0012 Mdot
.50767 .01017 Mdot
.73194 .10787 Mdot
.38868 .58015 Mdot
.41709 .59632 Mdot
.53875 .02561 Mdot
.35741 .59054 Mdot
.4573 .60272 Mdot
.47115 .0186 Mdot
.48341 .6142 Mdot
.81265 .14014 Mdot
.79344 .12256 Mdot
.60792 .05033 Mdot
.54412 .02485 Mdot
.74108 .10631 Mdot
.40763 .58941 Mdot
.57823 .03794 Mdot
.73614 .11095 Mdot
.59998 .05256 Mdot
.53084 .03479 Mdot
.50105 .01679 Mdot
.79131 .12755 Mdot
.55207 .03961 Mdot
.73845 .09187 Mdot
.69168 .08045 Mdot
.57139 .05285 Mdot
.81199 .13569 Mdot
.41778 .60928 Mdot
.49151 .00984 Mdot
.54692 .04425 Mdot
.75917 .12269 Mdot
.27555 .54064 Mdot
.51051 .01467 Mdot
.34462 .57402 Mdot
.8191 .13615 Mdot
.34728 .56936 Mdot
.38689 .58689 Mdot
.64133 .06252 Mdot
.43647 .61286 Mdot
.59727 .05503 Mdot
.69021 .07476 Mdot
.42346 .6122 Mdot
.30951 .5568 Mdot
.40747 .60279 Mdot
.66151 .08633 Mdot
.3213 .55933 Mdot
.58306 .0371 Mdot
.83512 .15134 Mdot
.56872 .05129 Mdot
.45151 .00088 Mdot
.38589 .58405 Mdot
.72229 .11151 Mdot
.44064 .59888 Mdot
.5525 .02691 Mdot
.50881 .02829 Mdot
.51822 .02559 Mdot
.71602 .10803 Mdot
.45312 .61345 Mdot
.38886 .59991 Mdot
.48052 .00632 Mdot
.6845 .09396 Mdot
.40492 .60858 Mdot
.55097 .03671 Mdot
.54706 .04246 Mdot
.36555 .58441 Mdot
.74119 .10617 Mdot
.72043 .10106 Mdot
.59636 .06414 Mdot
.38136 .59681 Mdot
.39691 .59632 Mdot
.85303 .15792 Mdot
.66127 .06151 Mdot
.42759 .59488 Mdot
.6329 .05646 Mdot
.74234 .10436 Mdot
.45713 .6143 Mdot
.63415 .04983 Mdot
.58219 .05464 Mdot
.77468 .11006 Mdot
.36517 .59577 Mdot
.77272 .11855 Mdot
.70876 .08629 Mdot
.78023 .12165 Mdot
.30612 .55545 Mdot
.60864 .05581 Mdot
.4152 .58673 Mdot
.61161 .04125 Mdot
.3371 .57751 Mdot
.83944 .15333 Mdot
.61597 .06618 Mdot
.80518 .13005 Mdot
.63014 .07567 Mdot
.29176 .54258 Mdot
.66758 .07974 Mdot
.37295 .58249 Mdot
.61944 .05455 Mdot
.63094 .07344 Mdot
.45534 .61186 Mdot
.76549 .12252 Mdot
.49727 .02139 Mdot
.78736 .13069 Mdot
.74926 .12082 Mdot
.723 .08767 Mdot
.37218 .57237 Mdot
.68968 .07564 Mdot
.57249 .04016 Mdot
.69251 .09621 Mdot
.69842 .07546 Mdot
.3162 .55096 Mdot
.61782 .06602 Mdot
.41433 .59136 Mdot
.37243 .57112 Mdot
.492 .00644 Mdot
.49029 .61539 Mdot
.51374 .00822 Mdot
.49099 .02626 Mdot
.69071 .09739 Mdot
.66648 .07755 Mdot
.73942 .08845 Mdot
.71176 .0909 Mdot
.68245 .06853 Mdot
.46755 .00858 Mdot
.64244 .07932 Mdot
.35373 .58614 Mdot
.40353 .60012 Mdot
.6052 .05836 Mdot
.63646 .06451 Mdot
.48609 .01473 Mdot
.80634 .12818 Mdot
.56831 .02908 Mdot
.32658 .57103 Mdot
.72222 .10237 Mdot
.38481 .58944 Mdot
.50742 .00279 Mdot
.60909 .05693 Mdot
.53192 .02122 Mdot
.57866 .05822 Mdot
.79034 .12579 Mdot
.69043 .08531 Mdot
.68099 .09669 Mdot
.74463 .11815 Mdot
.3715 .59839 Mdot
.6772 .07811 Mdot
.39023 .58313 Mdot
.66681 .09088 Mdot
.6305 .05359 Mdot
.31665 .5648 Mdot
.47094 .01528 Mdot
.59907 .0499 Mdot
.42337 .59576 Mdot
.77449 .12889 Mdot
.61115 .04715 Mdot
.40768 .61507 Mdot
.61852 .05374 Mdot
.47323 .00715 Mdot
.48012 .61511 Mdot
.67506 .0823 Mdot
.71807 .10941 Mdot
.61744 .04841 Mdot
.49934 .00279 Mdot
.39375 .60133 Mdot
.44927 .00856 Mdot
.48251 .0171 Mdot
.58506 .05222 Mdot
.45232 .00615 Mdot
.71302 .089 Mdot
.72264 .08772 Mdot
.48619 .00125 Mdot
.42423 .60902 Mdot
.63661 .05779 Mdot
.55395 .03353 Mdot
.38942 .58165 Mdot
.53514 .03475 Mdot
.31786 .55932 Mdot
.42772 .00225 Mdot
.59635 .05195 Mdot
.71769 .08404 Mdot
.62933 .05319 Mdot
.37463 .60173 Mdot
.51465 .03432 Mdot
.6909 .07954 Mdot
.62654 .06831 Mdot
.50982 .02925 Mdot
.48885 .01306 Mdot
.71857 .08343 Mdot
.42799 .60143 Mdot
.66874 .06751 Mdot
.69997 .09727 Mdot
.69321 .07133 Mdot
.81112 .13091 Mdot
.69814 .075 Mdot
.67598 .08393 Mdot
.38536 .59997 Mdot
.4243 7e-05 Mdot
.73861 .11527 Mdot
.67976 .0762 Mdot
.7626 .11995 Mdot
.50444 .00176 Mdot
.35225 .58295 Mdot
.6717 .06964 Mdot
.40032 .59894 Mdot
.72103 .09969 Mdot
.44551 .61252 Mdot
.42157 .00126 Mdot
.43741 .61653 Mdot
.73805 .08819 Mdot
.5653 .04793 Mdot
.43716 .61696 Mdot
.54947 .01869 Mdot
.67997 .08818 Mdot
.57459 .03979 Mdot
.7521 .10743 Mdot
.54756 .04237 Mdot
.40892 .61208 Mdot
.35708 .57632 Mdot
.84777 .15374 Mdot
.78169 .12173 Mdot
.36938 .59684 Mdot
.59233 .05892 Mdot
.67313 .06697 Mdot
.78821 .13006 Mdot
.36903 .58191 Mdot
.46853 .00061 Mdot
.47982 .01892 Mdot
.78398 .12078 Mdot
.44813 .01081 Mdot
.68528 .07497 Mdot
.34083 .56192 Mdot
.76538 .11504 Mdot
.35064 .57025 Mdot
.54795 .04061 Mdot
.42169 .59238 Mdot
.6251 .07455 Mdot
.42849 .61357 Mdot
.40936 .601 Mdot
.81106 .13878 Mdot
.48753 .02419 Mdot
.74077 .11428 Mdot
.54837 .03954 Mdot
.65464 .08059 Mdot
.52811 .01418 Mdot
.55778 .03802 Mdot
.35469 .57586 Mdot
.38952 .59111 Mdot
.59506 .04735 Mdot
.82175 .13869 Mdot
.55828 .04744 Mdot
.39022 .60529 Mdot
.44497 .00731 Mdot
.39175 .57896 Mdot
.64257 .05799 Mdot
.60579 .04639 Mdot
.36736 .57093 Mdot
.42104 .60974 Mdot
.39025 .59925 Mdot
.29099 .5498 Mdot
.54025 .02352 Mdot
.32958 .57202 Mdot
.3569 .57861 Mdot
.79982 .1277 Mdot
.77347 .11491 Mdot
.66628 .07914 Mdot
.38853 .58696 Mdot
.31844 .56299 Mdot
.76232 .10326 Mdot
.75866 .11473 Mdot
.75126 .10919 Mdot
.72717 .09612 Mdot
.46526 .61363 Mdot
.77673 .12925 Mdot
.48413 .02004 Mdot
.71805 .08878 Mdot
.45348 .61143 Mdot
.42779 .61285 Mdot
.32081 .55342 Mdot
.36803 .58055 Mdot
.41939 .6114 Mdot
.47287 .01065 Mdot
.41161 .59088 Mdot
.49129 .0045 Mdot
.81009 .14025 Mdot
.58146 .04021 Mdot
.58236 .03146 Mdot
.60871 .04122 Mdot
.49998 .02021 Mdot
.55419 .02989 Mdot
.43481 .61364 Mdot
.55983 .05109 Mdot
.3935 .60672 Mdot
.34241 .56915 Mdot
.72434 .10388 Mdot
.59592 .0361 Mdot
.77658 .12576 Mdot
.38972 .59864 Mdot
.44968 .00496 Mdot
.52559 .02874 Mdot
.69408 .07399 Mdot
.71747 .08912 Mdot
.63486 .0633 Mdot
.5316 .02193 Mdot
.61828 .06035 Mdot
.44407 .59916 Mdot
.75967 .1207 Mdot
.59696 .037 Mdot
.7245 .08234 Mdot
.58249 .04109 Mdot
.65296 .06387 Mdot
.42949 .61345 Mdot
.70191 .07828 Mdot
.45619 .61343 Mdot
.4427 .61796 Mdot
.67111 .06402 Mdot
.57239 .03103 Mdot
.60022 .06631 Mdot
.67832 .07449 Mdot
.75104 .12065 Mdot
.69545 .07968 Mdot
.42236 .60724 Mdot
.29976 .54563 Mdot
.37206 .59896 Mdot
.46005 .01137 Mdot
.65687 .07268 Mdot
.75789 .0983 Mdot
.72974 .09765 Mdot
.44487 .59838 Mdot
.50322 .01508 Mdot
.63446 .07144 Mdot
.62026 .06012 Mdot
.68479 .08186 Mdot
.5702 .05379 Mdot
.64159 .06561 Mdot
.45704 .60369 Mdot
.55393 .03717 Mdot
.66882 .07901 Mdot
.53668 .0258 Mdot
.68291 .07025 Mdot
.34725 .57414 Mdot
.55303 .0387 Mdot
.57741 .0482 Mdot
.67964 .06935 Mdot
.64018 .05754 Mdot
.48252 .61696 Mdot
.37588 .59593 Mdot
.28409 .54392 Mdot
.56519 .02925 Mdot
.47652 .00833 Mdot
.40304 .60575 Mdot
.53987 .02848 Mdot
.31504 .56266 Mdot
.36559 .59468 Mdot
.59922 .05809 Mdot
.42678 .61237 Mdot
.70609 .09143 Mdot
.69037 .08571 Mdot
.70786 .09971 Mdot
.66514 .0726 Mdot
.39714 .59856 Mdot
.56022 .04671 Mdot
.37315 .59789 Mdot
.76304 .10642 Mdot
.31776 .56653 Mdot
.77696 .11712 Mdot
.57917 .05148 Mdot
.72791 .10902 Mdot
.62062 .05124 Mdot
.77791 .11006 Mdot
.77494 .11356 Mdot
.4924 .02488 Mdot
.75631 .11976 Mdot
.67813 .06837 Mdot
.64188 .05259 Mdot
.77643 .12347 Mdot
.70359 .0914 Mdot
.74046 .09349 Mdot
.49675 .02282 Mdot
.39047 .58886 Mdot
.62485 .06349 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002;ooooo`;o000000?oooooo`00000000001_l00000
0ooooooo0000ooooo`03ooooo`?o0000POooool002KooooolOl00009ooooo`009_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01OoooolFo`0001;o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo06Wooooo5Ol0001_ooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo06_ooooo5Ol0001]ooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo06gooooo00<00000o`000?l000005?l0001Yooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo077ooooo5_l0001Vooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo07?ooooo4Ol000000`00003o0000o`000002o`0006Co
oooo00?o0000ooooooooool01oooool002Kooooo0_l0001ioooooaCo0000H?ooool2o`0000Wooooo
000Vooooo`03o`000?oooooooooo07Wooooo5Ol0001Oooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo07_ooooo5_l0001Looooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo07oooooo5Ol0001Iooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo087ooooo5Ol0001Gooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo08?ooooo4_l000001Ooooooo0000o`000?oooooo000005?ooooo00?o0000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0Q_ooool3o`00000300000?l0003o0000013o0000
DOooool00ol0003oooooooooo`07ooooo`009_ooool2o`0008[ooooo00<00000o`000?l000004ol0
001=ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0Roooool7o`00000300000?l0003o
000000_o000000<00000o`000?ooool0B_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`2?ooooo`_o000000<00000o`000?l000001ol00019ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo097ooooo00<00000o`000?l000005?l00015ooooo`03
o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo09Cooooo00?o000000000?l00000
4ol00013ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo09Kooooo2_l0
00000`00003o0000o`00000:o`00043ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0VOooool00`00003o0000o`00000Do`0003gooooo00?o0000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool0W?ooool00`00003o0000o`00000Bo`0003cooooo00?o0000oooo
ooooool01oooool002Kooooo0_l0002Pooooo`0400000?l0003o00000000013o0000>Oooool2o`00
00Wooooo000Vooooo`03o`000?oooooooooo0:7ooooo4?l000001000003o0000o`000?l0000hoooo
o`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0:Cooooo00<00000o`000?l0
00004?l0000fooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0:Oooooo
00<00000o`000?l000003_l0000eooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo0:Wooooo4?l000000`00003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo000C
ooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0[?oo
ool00`00003o0000o`00000<o`0003;ooooo00?o0000ooooooooool01oooool001;ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0:oooooo
3Ol000000`00003oooooooooo`0^ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`000;;ooooo00?o0000ooooool00000
2_l0000]ooooo`?o00002Oooool001;ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0;Cooooo3?l0000]ooooo`03o`000?oooooooooo00Oooooo
000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo0;Sooooo2_l0000[ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
0;[ooooo2Ol0000Zooooo`03o`000?oooooooooo00Oooooo000Cooooo`;o00002Oooool3o`0000Go
oooo00?o0000ooooooooool0_Oooool8o`0002Sooooo00?o0000ooooooooool01oooool002Kooooo
00?o0000ooooooooool0`?ooool7o`0002Kooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0`_ooool6o`0002Gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0a_ooool4o`0002?ooooo00?o0000ooooooooool01oooool002Kooooo0_l0003:oooo
o`;o00008Oooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`;o0000kOooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool0
02Kooooo0_l0003]ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool001?ooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo0>gooooo00?o0000
ooooooooool01oooool001;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool001;ooooo00Co0000oooo
oooooooo00001oooool5o`0000Cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07
ooooo`004_ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo0_l0
003/ooooo`?o00002Oooool001;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool001;ooooo00Co0000
oooooooooooo00002Oooool2o`0000Gooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`004oooool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3]
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000kOoo
ool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`001oooool3o`0001cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07
ooooo`002?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0>gooooo00?o0000oooo
ooooool01oooool000Sooooo00?o0000ooooooooool06oooool2o`000>gooooo0_l00009ooooo`00
2?ooool2o`0001cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`001ooo
ool2o`000003ooooool0003o000001[ooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`00
0?oooooooooo00Oooooo000Vooooo`;o0000kOooool2o`0000Wooooo000Vooooo`03o`000?oooooo
oooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool001?ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0>gooooo00?o
0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`004_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oo
oooo1?l00005ooooo`;o0000k?ooool3o`0000Wooooo000Booooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oo
oooo000Booooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Cooooo`;o00002_ooool2o`0000Gooooo
00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07oooo
o`009_ooool2o`000>gooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`00
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>go
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003ooooo
ooooo`07ooooo`009_ooool2o`000>gooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`3]
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`;o0000kOooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0>gooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool001?ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0>gooooo00?o0000oooooooo
ool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool2o`000>cooooo0ol00009
ooooo`004_ooool01?l0003oooooooooool00008ooooo`?o00001Oooool00ol0003oooooooooo`3]
ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01ooo
ool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Wooooo0ol0
0005ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]oooo
o`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000oooooooo
ool01oooool002Kooooo0_l0003]ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo03gooooo0ol0002]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
03oooooo1?l0002Zooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo047o
oooo00?o000000000?l000000_l0002Wooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo04?ooooo1_l0002Tooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo04Cooooo2?l0002Qooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000Aoooool8
o`00000300000?oooooooooo09_ooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`17oooo
o`Co000000<00000o`000?l000001?l0002Kooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo04Sooooo00<00000o`000?l000002Ol0002Iooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo04[ooooo3Ol0002Fooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo04cooooo3Ol0002Dooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo04gooooo3ol000000`00003oooooooooo`2>ooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo04oooooo4?l0002>ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo057ooooo1Ol000000ooooooo0000o`000006o`000003
00000?l0003o000008_ooooo00?o0000ooooooooool01oooool002Kooooo0_l0001Coooooa7o0000
00?oooooo`000?ooool0Q_ooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo05?ooooo5?l0
0026ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05Gooooo5Ol00023
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05Oooooo5Ol00021oooo
o`03o`000?oooooooooo00Oooooo000Nooooo`?o00001Oooool00ol0003oooooooooo`1Iooooo`So
000000<00000o`000?l000002ol0001nooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0[oooooaOo0000
6oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
1oooool001oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Wooooo6Ol0000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooo
oooo00CoooooI_l00003000000Ko00000P0000001?l00000000000000?l00002000007[o00002Ooo
ool001oooooo00?o0000ooooooooool0o_ooool001kooooo0_l0003oooooo`7ooooo000Oooooo`03
o`000?oooooooooo0?kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.158908, -0.161707, \
0.00416367, 0.00673696}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.07745 .44779 Mdot
.78471 .11888 Mdot
.09586 .23037 Mdot
.06069 .22241 Mdot
.96326 .40779 Mdot
.00449 .4249 Mdot
.18388 .49111 Mdot
.45967 .60804 Mdot
.17859 .48676 Mdot
.28585 .27537 Mdot
.17531 .49284 Mdot
.43556 .59422 Mdot
.19423 .26415 Mdot
.89246 .16191 Mdot
.2113 .26368 Mdot
.24185 .27725 Mdot
.1456 .2506 Mdot
.14375 .25288 Mdot
.82915 .13772 Mdot
.93304 .18603 Mdot
.40511 .57992 Mdot
.60457 .04415 Mdot
.4147 .58676 Mdot
.32684 .55325 Mdot
.73269 .10449 Mdot
.67272 .0771 Mdot
.57913 .03556 Mdot
.88577 .16389 Mdot
.96266 .19474 Mdot
.186 .26831 Mdot
.20838 .26259 Mdot
.52573 .02031 Mdot
.74315 .10432 Mdot
.10794 .24725 Mdot
.4842 .00208 Mdot
.60083 .04427 Mdot
.97043 .18959 Mdot
.12615 .47411 Mdot
.58659 .0444 Mdot
.44457 .59578 Mdot
.84922 .14417 Mdot
.7984 .12469 Mdot
.06356 .22816 Mdot
.43228 .59138 Mdot
.14084 .47411 Mdot
.90883 .16856 Mdot
.16126 .251 Mdot
.09242 .45292 Mdot
.07964 .45115 Mdot
.15848 .48168 Mdot
.06375 .22532 Mdot
.93033 .17645 Mdot
.05829 .44403 Mdot
.96765 .40979 Mdot
.56294 .03306 Mdot
.07517 .23606 Mdot
.19678 .4981 Mdot
.23456 .269 Mdot
.14386 .47342 Mdot
.07273 .23168 Mdot
.25789 .52675 Mdot
.73644 .1013 Mdot
.36712 .56691 Mdot
.99376 .19772 Mdot
.11682 .46365 Mdot
.87427 .15313 Mdot
.11026 .23995 Mdot
.98431 .41663 Mdot
.10843 .24824 Mdot
.14869 .48014 Mdot
.78896 .1286 Mdot
.66037 .07533 Mdot
.2912 .53188 Mdot
.09971 .23861 Mdot
.1199 .47081 Mdot
.202 .26019 Mdot
.13214 .24657 Mdot
.25703 .5216 Mdot
.90136 .3899 Mdot
.10702 .4613 Mdot
.27296 .52424 Mdot
.15065 .48395 Mdot
.06952 .22296 Mdot
.07111 .23469 Mdot
.60627 .04515 Mdot
.10482 .23659 Mdot
.68179 .08018 Mdot
.24991 .27689 Mdot
.0619 .23289 Mdot
.9438 .18464 Mdot
.03424 .22292 Mdot
.62862 .05596 Mdot
.54349 .02683 Mdot
.67094 .07597 Mdot
.64705 .06871 Mdot
.12176 .24586 Mdot
.16912 .2594 Mdot
.13861 .24404 Mdot
.35947 .56161 Mdot
.01938 .43159 Mdot
.90551 .16751 Mdot
.66032 .07555 Mdot
.0526 .44227 Mdot
.16373 .25775 Mdot
.06651 .22649 Mdot
.36077 .56165 Mdot
.64472 .06687 Mdot
.81527 .13581 Mdot
.99011 .2078 Mdot
.80157 .12756 Mdot
.39889 .58331 Mdot
.98286 .20453 Mdot
.73289 .10177 Mdot
.11013 .45997 Mdot
.46826 .60662 Mdot
.47053 .60942 Mdot
.98085 .20181 Mdot
.94931 .4066 Mdot
.12365 .46583 Mdot
.70546 .09175 Mdot
.75994 .10881 Mdot
.07858 .22874 Mdot
.51938 .01154 Mdot
.30761 .54194 Mdot
.24265 .27518 Mdot
.0215 .43185 Mdot
.73231 .10294 Mdot
.09461 .24332 Mdot
.22046 .27353 Mdot
.0132 .21305 Mdot
.00178 .20934 Mdot
.10818 .45995 Mdot
.07448 .45472 Mdot
.60058 .04958 Mdot
.75262 .10763 Mdot
.07763 .45226 Mdot
.94336 .18404 Mdot
.92342 .39617 Mdot
.392 .58081 Mdot
.33152 .54875 Mdot
.66528 .07789 Mdot
.9345 .17957 Mdot
.87548 .15483 Mdot
.6131 .04962 Mdot
.99491 .2034 Mdot
.18428 .49339 Mdot
.05884 .44297 Mdot
.95619 .40639 Mdot
.72614 .10144 Mdot
.9099 .39197 Mdot
.49448 .00699 Mdot
.07869 .23788 Mdot
.02301 .20673 Mdot
.22261 .26613 Mdot
.36011 .56867 Mdot
.56802 .03171 Mdot
.58197 .03808 Mdot
.55663 .03213 Mdot
.30392 .53841 Mdot
.42547 .59472 Mdot
.13498 .24649 Mdot
.37273 .57265 Mdot
.90064 .16826 Mdot
.89575 .17046 Mdot
.03438 .21626 Mdot
.72729 .09698 Mdot
.87881 .1606 Mdot
.32579 .55499 Mdot
.07976 .44993 Mdot
.97532 .19059 Mdot
.23161 .27708 Mdot
.74892 .10566 Mdot
.21503 .26377 Mdot
.53517 .01925 Mdot
.25334 .51631 Mdot
.16815 .25817 Mdot
.83377 .14353 Mdot
.31744 .54573 Mdot
.09656 .22939 Mdot
.17566 .4898 Mdot
.18456 .26741 Mdot
.39757 .57907 Mdot
.28029 .27804 Mdot
.89186 .16108 Mdot
.20289 .25973 Mdot
.52812 .01825 Mdot
.8827 .16024 Mdot
.48435 .61192 Mdot
.23092 .51527 Mdot
.32813 .55334 Mdot
.27247 .53113 Mdot
.98418 .41785 Mdot
.61945 .05769 Mdot
.10681 .24539 Mdot
.72072 .10021 Mdot
.25707 .27055 Mdot
.57431 .03523 Mdot
.7436 .10117 Mdot
.91471 .16859 Mdot
.42012 .59427 Mdot
.87122 .15468 Mdot
.17499 .25231 Mdot
.77518 .11958 Mdot
.08333 .2257 Mdot
.32018 .55099 Mdot
.1714 .48556 Mdot
.15835 .26105 Mdot
.30371 .54175 Mdot
.43158 .59403 Mdot
.81116 .1334 Mdot
.75297 .10909 Mdot
.55473 .02796 Mdot
.05425 .21835 Mdot
.46198 .60434 Mdot
.50815 .00895 Mdot
.53782 .01747 Mdot
.35662 .56641 Mdot
.53578 .02417 Mdot
.75812 .11606 Mdot
.03732 .43852 Mdot
.10298 .46205 Mdot
.82996 .14537 Mdot
.57399 .03102 Mdot
.06725 .44863 Mdot
.06364 .23195 Mdot
.81092 .12978 Mdot
.3474 .55724 Mdot
.43832 .60205 Mdot
.17235 .48888 Mdot
.06765 .22086 Mdot
.02334 .21428 Mdot
.18449 .26136 Mdot
.74087 .10127 Mdot
.66054 .07368 Mdot
.98124 .41528 Mdot
.37918 .57042 Mdot
.46547 .60616 Mdot
.8177 .13196 Mdot
.29167 .54185 Mdot
.54599 .02044 Mdot
.19731 .26108 Mdot
.64777 .06242 Mdot
.47085 .61498 Mdot
.9557 .18878 Mdot
.96378 .19586 Mdot
.4768 .6158 Mdot
.81442 .13646 Mdot
.18568 .25855 Mdot
.12132 .46852 Mdot
.27521 .52845 Mdot
.03585 .43789 Mdot
.95557 .18594 Mdot
.28324 .53769 Mdot
.10516 .45944 Mdot
.25205 .27943 Mdot
.77181 .11951 Mdot
.23095 .50862 Mdot
.4545 .60801 Mdot
.03271 .21658 Mdot
.356 .56234 Mdot
.73106 .09689 Mdot
.92868 .39827 Mdot
.90061 .17054 Mdot
.51369 .01389 Mdot
.79896 .13126 Mdot
.19653 .5008 Mdot
.97726 .20075 Mdot
.03483 .22387 Mdot
.51699 .0131 Mdot
.36136 .56085 Mdot
.69554 .08255 Mdot
.1853 .49572 Mdot
.10169 .23001 Mdot
.11594 .46836 Mdot
.46364 .60607 Mdot
.13717 .25183 Mdot
.18192 .25985 Mdot
.80065 .12402 Mdot
.48975 .00321 Mdot
.96278 .40763 Mdot
.1125 .23538 Mdot
.11945 .2509 Mdot
.27774 .5261 Mdot
.77475 .1169 Mdot
.31312 .54039 Mdot
.84769 .15086 Mdot
.25352 .27 Mdot
.86131 .14853 Mdot
.99125 .41816 Mdot
.91875 .3951 Mdot
.04783 .21911 Mdot
.08007 .22443 Mdot
.06078 .22088 Mdot
.15144 .47633 Mdot
.60335 .04456 Mdot
.00242 .20952 Mdot
.06409 .44388 Mdot
.34813 .56482 Mdot
.19434 .49719 Mdot
.72255 .10155 Mdot
.0464 .44052 Mdot
.6553 .0731 Mdot
.15381 .47644 Mdot
.7332 .1049 Mdot
.67761 .08227 Mdot
.34076 .55895 Mdot
.18588 .26348 Mdot
.95502 .19439 Mdot
.00812 .20908 Mdot
.79076 .12995 Mdot
.60949 .04694 Mdot
.91946 .39506 Mdot
.76864 .11904 Mdot
.82396 .13524 Mdot
.37182 .57207 Mdot
.25736 .5215 Mdot
.2077 .2722 Mdot
.11584 .46984 Mdot
.14412 .24419 Mdot
.76941 .11867 Mdot
.39939 .58222 Mdot
.16636 .48985 Mdot
.00968 .20879 Mdot
.1112 .46856 Mdot
.43633 .59858 Mdot
.49101 .00103 Mdot
.2483 .52456 Mdot
.02858 .43104 Mdot
.13287 .46891 Mdot
.10206 .46199 Mdot
.50099 .00872 Mdot
.94788 .18925 Mdot
.94529 .40561 Mdot
.9682 .19985 Mdot
.46557 .61052 Mdot
.66914 .07348 Mdot
.21783 .51256 Mdot
.33793 .55867 Mdot
.29715 .27673 Mdot
.13203 .47621 Mdot
.15597 .2608 Mdot
.14359 .24468 Mdot
.50118 .00116 Mdot
.47247 .61128 Mdot
.81158 .13714 Mdot
.08265 .23265 Mdot
.11223 .46181 Mdot
.23472 .51033 Mdot
.08904 .45341 Mdot
.09194 .45741 Mdot
.11888 .46466 Mdot
.15273 .48406 Mdot
.50982 .00634 Mdot
.1228 .46977 Mdot
.13148 .24033 Mdot
.17367 .2659 Mdot
.60974 .04894 Mdot
.20041 .2605 Mdot
.26187 .52122 Mdot
.88963 .16173 Mdot
.99781 .41926 Mdot
.97966 .20278 Mdot
.26152 .27644 Mdot
.62898 .05574 Mdot
.74709 .10884 Mdot
.69187 .08712 Mdot
.73852 .10369 Mdot
.03135 .2198 Mdot
.95834 .40837 Mdot
.91954 .17347 Mdot
.17014 .26514 Mdot
.90014 .3895 Mdot
.04215 .2257 Mdot
.4433 .59569 Mdot
.8202 .13239 Mdot
.25729 .27899 Mdot
.24276 .51617 Mdot
.54049 .01899 Mdot
.10201 .24573 Mdot
.0704 .22798 Mdot
.00692 .21163 Mdot
.00266 .42237 Mdot
.23112 .27393 Mdot
.97837 .41384 Mdot
.50131 .00926 Mdot
.07888 .23825 Mdot
.91807 .17893 Mdot
.88586 .15714 Mdot
.43631 .59523 Mdot
.51954 .0158 Mdot
.92278 .1762 Mdot
.63911 .06148 Mdot
.10308 .46471 Mdot
.43502 .59297 Mdot
.30911 .54679 Mdot
.27144 .52444 Mdot
.24901 .27687 Mdot
.80369 .12689 Mdot
.28259 .52835 Mdot
.075 .22501 Mdot
.25166 .26966 Mdot
.79618 .12604 Mdot
.31771 .54442 Mdot
.97201 .41059 Mdot
.41715 .58923 Mdot
.07802 .23577 Mdot
.28511 .53726 Mdot
.60974 .05241 Mdot
.47468 .61634 Mdot
.01724 .21141 Mdot
.23903 .27514 Mdot
.07774 .22883 Mdot
.09183 .2304 Mdot
.51491 .01569 Mdot
.99833 .2105 Mdot
.36066 .56956 Mdot
.35026 .55921 Mdot
.47123 .60747 Mdot
.24387 .51799 Mdot
.06911 .45034 Mdot
.22403 .26797 Mdot
.63247 .06469 Mdot
.17381 .49325 Mdot
.734 .10329 Mdot
.22383 .51046 Mdot
.3776 .57328 Mdot
.8492 .14994 Mdot
.2016 .50276 Mdot
.24971 .51719 Mdot
.94493 .18565 Mdot
.19243 .49946 Mdot
.69042 .07981 Mdot
.03546 .4328 Mdot
.21794 .50256 Mdot
.05349 .44206 Mdot
.07927 .2313 Mdot
.23848 .27005 Mdot
.91792 .17892 Mdot
.35545 .55817 Mdot
.49238 .61626 Mdot
.2791 .53451 Mdot
.11219 .24338 Mdot
.93656 .40032 Mdot
.26001 .52444 Mdot
.03445 .20985 Mdot
.15917 .25285 Mdot
.14673 .25475 Mdot
.31498 .55134 Mdot
.9926 .19654 Mdot
.62898 .05536 Mdot
.83583 .14847 Mdot
.95483 .40491 Mdot
.31395 .54282 Mdot
.34871 .55884 Mdot
.22021 .50414 Mdot
.26848 .5309 Mdot
.36531 .56334 Mdot
.22305 .5076 Mdot
.78392 .12172 Mdot
.10327 .46151 Mdot
.9717 .19371 Mdot
.70233 .08638 Mdot
.31876 .54651 Mdot
.56751 .03033 Mdot
.12911 .23985 Mdot
.3775 .57512 Mdot
.78481 .11769 Mdot
.29375 .54278 Mdot
.57769 .04077 Mdot
.17635 .25979 Mdot
.00826 .20716 Mdot
.96045 .18776 Mdot
.9068 .39135 Mdot
.06314 .4421 Mdot
.07826 .23359 Mdot
.07745 .23555 Mdot
.07163 .22897 Mdot
.90842 .17681 Mdot
.12413 .47039 Mdot
.79759 .13292 Mdot
.10563 .24136 Mdot
.73843 .10256 Mdot
.96514 .41096 Mdot
.96838 .18911 Mdot
.93576 .40146 Mdot
.71577 .09072 Mdot
.36165 .56525 Mdot
.12941 .24267 Mdot
.4794 .6096 Mdot
.48478 .61488 Mdot
.5421 .02294 Mdot
.18143 .25475 Mdot
.99766 .21003 Mdot
.7754 .12395 Mdot
.87888 .16299 Mdot
.99948 .2097 Mdot
.7944 .12785 Mdot
.10918 .46868 Mdot
.18499 .48975 Mdot
.10156 .46176 Mdot
.92906 .17447 Mdot
.82982 .13665 Mdot
.56827 .03378 Mdot
.08553 .23758 Mdot
.12055 .24547 Mdot
.53024 .0201 Mdot
.48346 .00116 Mdot
.10316 .24528 Mdot
.92306 .17373 Mdot
.8491 .14462 Mdot
.50973 .00505 Mdot
.93266 .18301 Mdot
.80736 .1266 Mdot
.19746 .26304 Mdot
.39972 .58064 Mdot
.37982 .57609 Mdot
.85308 .15393 Mdot
.03498 .21084 Mdot
.1329 .46847 Mdot
.10966 .46101 Mdot
.8408 .14848 Mdot
.89153 .1705 Mdot
.12212 .47277 Mdot
.1073 .23658 Mdot
.52229 .0161 Mdot
.25224 .2712 Mdot
.95792 .4097 Mdot
.17145 .26386 Mdot
.67825 .07796 Mdot
.23681 .27421 Mdot
.30192 .53918 Mdot
.04958 .22474 Mdot
.065 .22772 Mdot
.35799 .56563 Mdot
.12194 .24966 Mdot
.40264 .58112 Mdot
.42337 .58717 Mdot
.56542 .0339 Mdot
.71786 .09928 Mdot
.93085 .18343 Mdot
.16179 .25423 Mdot
.10481 .24672 Mdot
.73973 .101 Mdot
.16689 .25064 Mdot
.15927 .25597 Mdot
.06955 .23018 Mdot
.25103 .52348 Mdot
.46831 .60685 Mdot
.02587 .21654 Mdot
.10155 .46293 Mdot
.50619 .01021 Mdot
.78423 .12502 Mdot
.46409 .60575 Mdot
.16447 .2601 Mdot
.95251 .18347 Mdot
.11505 .24199 Mdot
.1943 .26062 Mdot
.25453 .52585 Mdot
.167 .25959 Mdot
.99262 .2047 Mdot
.01635 .42579 Mdot
.7067 .08717 Mdot
.0608 .2221 Mdot
.10774 .46323 Mdot
.82087 .14213 Mdot
.46291 .60843 Mdot
.05091 .22734 Mdot
.51054 .00565 Mdot
.95702 .18764 Mdot
.42971 .59104 Mdot
.19581 .26341 Mdot
.03329 .21795 Mdot
.07296 .23081 Mdot
.14197 .47708 Mdot
.13645 .24464 Mdot
.90511 .39167 Mdot
.59532 .04326 Mdot
.96388 .19182 Mdot
.09073 .23545 Mdot
.22873 .5095 Mdot
.99348 .42014 Mdot
.99884 .19927 Mdot
.2444 .51834 Mdot
.14986 .48053 Mdot
.76741 .12079 Mdot
.12483 .23615 Mdot
.76298 .11575 Mdot
.29623 .27515 Mdot
.99037 .42123 Mdot
.39066 .57719 Mdot
.41657 .59108 Mdot
.98319 .41631 Mdot
.24281 .51824 Mdot
.1364 .47031 Mdot
.11989 .2352 Mdot
.17505 .4911 Mdot
.64469 .06085 Mdot
.16703 .48758 Mdot
.07659 .45161 Mdot
.19471 .4988 Mdot
.95037 .40417 Mdot
.99481 .19788 Mdot
.05406 .21978 Mdot
.17083 .26457 Mdot
.01098 .21068 Mdot
.8974 .17123 Mdot
.01255 .2106 Mdot
.4963 .00115 Mdot
.17207 .48936 Mdot
.50877 .01085 Mdot
.9501 .40583 Mdot
.10033 .45774 Mdot
.12012 .2364 Mdot
.28959 .53142 Mdot
.29459 .54172 Mdot
.67666 .0751 Mdot
.49052 .61641 Mdot
.99674 .42289 Mdot
.05744 .22722 Mdot
.68554 .07739 Mdot
.70398 .08629 Mdot
.33033 .55004 Mdot
.97785 .20339 Mdot
.0405 .4351 Mdot
.98392 .20435 Mdot
.93665 .17635 Mdot
.46885 .60524 Mdot
.44922 .60529 Mdot
.1682 .49101 Mdot
.27314 .52989 Mdot
.2806 .52804 Mdot
.83531 .14362 Mdot
.15128 .26012 Mdot
.25453 .51933 Mdot
.4098 .5899 Mdot
.04025 .43608 Mdot
.65502 .06538 Mdot
.28625 .53086 Mdot
.98792 .41624 Mdot
.04421 .43893 Mdot
.0111 .42724 Mdot
.21513 .2688 Mdot
.90606 .16664 Mdot
.30176 .53717 Mdot
.93739 .40288 Mdot
.2307 .51631 Mdot
.03751 .21437 Mdot
.23892 .27027 Mdot
.19505 .4942 Mdot
.91198 .17315 Mdot
.04452 .43662 Mdot
.67563 .07551 Mdot
.23383 .51722 Mdot
.92793 .17916 Mdot
.54531 .02551 Mdot
.38385 .5731 Mdot
.45506 .60387 Mdot
.33504 .55427 Mdot
.61738 .05142 Mdot
.53552 .02267 Mdot
.17936 .48719 Mdot
.85767 .14945 Mdot
.33459 .55913 Mdot
.99373 .41811 Mdot
.94628 .40435 Mdot
.66196 .07263 Mdot
.95465 .18827 Mdot
.05616 .44138 Mdot
.67976 .08441 Mdot
.1942 .26412 Mdot
.181 .26293 Mdot
.95633 .19364 Mdot
.8826 .16308 Mdot
.19534 .26216 Mdot
.72548 .10026 Mdot
.09509 .23682 Mdot
.61504 .05319 Mdot
.67137 .08121 Mdot
.87827 .15511 Mdot
.39799 .58376 Mdot
.36831 .56412 Mdot
.29702 .53551 Mdot
.72221 .09613 Mdot
.96361 .19011 Mdot
.25131 .27244 Mdot
.17102 .26163 Mdot
.51836 .00847 Mdot
.95845 .41 Mdot
.10192 .46324 Mdot
.85649 .14863 Mdot
.42338 .59058 Mdot
.62789 .05736 Mdot
.16225 .25142 Mdot
.09943 .45811 Mdot
.74691 .11222 Mdot
.75052 .11276 Mdot
.50308 .00354 Mdot
.71263 .08953 Mdot
.11939 .23716 Mdot
.97905 .20229 Mdot
.18483 .26111 Mdot
.20908 .26548 Mdot
.65872 .06744 Mdot
.51106 .00663 Mdot
.98819 .20437 Mdot
.5971 .05013 Mdot
.4267 .59505 Mdot
.0361 .21187 Mdot
.09865 .23832 Mdot
.54889 .02994 Mdot
.10239 .23688 Mdot
.79779 .12396 Mdot
.26095 .27382 Mdot
.02974 .21552 Mdot
.61226 .05332 Mdot
.30803 .54109 Mdot
.15938 .26117 Mdot
.96369 .41252 Mdot
.58513 .03671 Mdot
.0618 .44409 Mdot
.03022 .21664 Mdot
.06866 .22411 Mdot
.06197 .22123 Mdot
.10968 .4606 Mdot
.15018 .24912 Mdot
.68352 .08247 Mdot
.82554 .14143 Mdot
.13834 .47403 Mdot
.13851 .25425 Mdot
.03228 .43106 Mdot
.39344 .58047 Mdot
.1616 .48892 Mdot
.57528 .03281 Mdot
.24477 .51867 Mdot
.05878 .2317 Mdot
.20538 .26139 Mdot
.0329 .21773 Mdot
.87021 .16066 Mdot
.40918 .58858 Mdot
.50187 .00593 Mdot
.4286 .58856 Mdot
.26097 .52437 Mdot
.20393 .49965 Mdot
.29416 .53977 Mdot
.86666 .152 Mdot
.91317 .39452 Mdot
.99658 .4219 Mdot
.10739 .46642 Mdot
.51944 .01444 Mdot
.85093 .15216 Mdot
.2817 .53574 Mdot
.1192 .46576 Mdot
.04911 .22556 Mdot
.25398 .27174 Mdot
.64696 .06537 Mdot
.93902 .17722 Mdot
.98627 .19669 Mdot
.19252 .26915 Mdot
.15464 .26138 Mdot
.97644 .19389 Mdot
.47555 .61093 Mdot
.31281 .54513 Mdot
.36328 .56627 Mdot
.01661 .42883 Mdot
.9229 .18022 Mdot
.14305 .47826 Mdot
.07517 .45101 Mdot
.40244 .58216 Mdot
.26677 .52281 Mdot
.74419 .10722 Mdot
.6845 .07846 Mdot
.96183 .1893 Mdot
.36707 .57097 Mdot
.83218 .14525 Mdot
.13308 .24353 Mdot
.62215 .05663 Mdot
.47462 .61247 Mdot
.24999 .51505 Mdot
.19227 .4931 Mdot
.06022 .44828 Mdot
.07714 .2231 Mdot
.91651 .17979 Mdot
.65031 .07097 Mdot
.11112 .24344 Mdot
.06093 .4412 Mdot
.51612 .01453 Mdot
.44427 .60155 Mdot
.07164 .22504 Mdot
.11171 .23561 Mdot
.64761 .06327 Mdot
.78128 .11632 Mdot
.7986 .12959 Mdot
.85397 .14487 Mdot
.08391 .45819 Mdot
.37053 .5655 Mdot
.10912 .45931 Mdot
.10814 .46044 Mdot
.12336 .23935 Mdot
.16598 .25391 Mdot
.27064 .53351 Mdot
.17135 .251 Mdot
.85553 .15437 Mdot
.30184 .53817 Mdot
.15684 .24657 Mdot
.6951 .08364 Mdot
.22355 .26486 Mdot
.08941 .45276 Mdot
.04553 .22103 Mdot
.17608 .49612 Mdot
.04815 .21875 Mdot
.11457 .46726 Mdot
.98258 .19659 Mdot
.0411 .43707 Mdot
.31486 .54599 Mdot
.20998 .27415 Mdot
.25562 .51989 Mdot
.41274 .58875 Mdot
.4771 .61584 Mdot
.1286 .47428 Mdot
.63711 .05967 Mdot
.14756 .48209 Mdot
.11887 .25076 Mdot
.14426 .24387 Mdot
.22497 .26806 Mdot
.24556 .27857 Mdot
.85483 .14686 Mdot
.2676 .53218 Mdot
.76803 .11955 Mdot
.03384 .2133 Mdot
.06639 .4442 Mdot
.08663 .23555 Mdot
.03046 .22032 Mdot
.12147 .25085 Mdot
.27091 .27654 Mdot
.09627 .24025 Mdot
.9516 .40777 Mdot
.2115 .26929 Mdot
.24785 .51456 Mdot
.17111 .26182 Mdot
.0701 .22477 Mdot
.2285 .26517 Mdot
.84831 .14434 Mdot
.46248 .61142 Mdot
.01033 .42767 Mdot
.51682 .00725 Mdot
.10384 .46238 Mdot
.98364 .19692 Mdot
.015 .42742 Mdot
.16661 .25621 Mdot
.94114 .17896 Mdot
.19147 .49981 Mdot
.25427 .27616 Mdot
.01809 .4291 Mdot
.37931 .57467 Mdot
.08598 .23058 Mdot
.18993 .49479 Mdot
.39542 .57707 Mdot
.28185 .53769 Mdot
.01631 .21711 Mdot
.26958 .27235 Mdot
.97275 .19456 Mdot
.33916 .55776 Mdot
.96945 .19621 Mdot
.51525 .0142 Mdot
.77544 .1182 Mdot
.96076 .40826 Mdot
.85268 .14568 Mdot
.20457 .26703 Mdot
.62216 .05916 Mdot
.15485 .25723 Mdot
.14542 .25687 Mdot
.21517 .27491 Mdot
.04268 .4405 Mdot
.78044 .11899 Mdot
.66164 .07502 Mdot
.42181 .59014 Mdot
.06976 .22652 Mdot
.28793 .53396 Mdot
.06183 .44451 Mdot
.58254 .04112 Mdot
.02388 .21216 Mdot
.96572 .19822 Mdot
.0479 .44373 Mdot
.16981 .26501 Mdot
.12432 .23728 Mdot
.25448 .52337 Mdot
.7537 .10831 Mdot
.02174 .20818 Mdot
.16991 .26494 Mdot
.93238 .18376 Mdot
.97769 .20003 Mdot
.12575 .46643 Mdot
.09722 .23421 Mdot
.79038 .12138 Mdot
.20199 .26844 Mdot
.08767 .22908 Mdot
.19774 .26548 Mdot
.04287 .22028 Mdot
.34811 .5584 Mdot
.14424 .24719 Mdot
.73766 .10275 Mdot
.4819 .61604 Mdot
.216 .2683 Mdot
.14325 .47791 Mdot
.02231 .43248 Mdot
.58197 .03756 Mdot
.27507 .53072 Mdot
.65883 .06776 Mdot
.58027 .04214 Mdot
.13287 .24951 Mdot
.03927 .44045 Mdot
.11063 .2372 Mdot
.49298 .61606 Mdot
.8807 .16302 Mdot
.75966 .11168 Mdot
.51471 .00816 Mdot
.54512 .0193 Mdot
.28439 .27399 Mdot
.43067 .59354 Mdot
.69135 .08666 Mdot
.06648 .45083 Mdot
.71565 .09035 Mdot
.90201 .39055 Mdot
.09919 .24238 Mdot
.9402 .18886 Mdot
.05818 .44134 Mdot
.22676 .26554 Mdot
.10715 .24621 Mdot
.65307 .0688 Mdot
.82436 .13348 Mdot
.01247 .42446 Mdot
.29812 .53723 Mdot
.13669 .47513 Mdot
.83399 .13959 Mdot
.10663 .46307 Mdot
.17861 .2562 Mdot
.78755 .1233 Mdot
.01485 .20825 Mdot
.9818 .2036 Mdot
.08159 .45449 Mdot
.12411 .46936 Mdot
.46251 .6065 Mdot
.19432 .25643 Mdot
.97977 .41467 Mdot
.23681 .27547 Mdot
.74012 .10853 Mdot
.05032 .222 Mdot
.65718 .07 Mdot
.08581 .45061 Mdot
.8437 .14215 Mdot
.72631 .0953 Mdot
.95017 .18919 Mdot
.7835 .12483 Mdot
.25189 .51771 Mdot
.65118 .06707 Mdot
.10504 .45885 Mdot
.87346 .15839 Mdot
.97756 .19367 Mdot
.987 .19489 Mdot
.51412 .0133 Mdot
.71461 .08954 Mdot
.90674 .17254 Mdot
.18153 .49763 Mdot
.29363 .27708 Mdot
.61894 .05115 Mdot
.06056 .22932 Mdot
.15807 .48666 Mdot
.77292 .11935 Mdot
.49829 .00125 Mdot
.98413 .19849 Mdot
.72503 .09484 Mdot
.66042 .07321 Mdot
.12926 .23856 Mdot
.23124 .27795 Mdot
.13969 .243 Mdot
.99716 .19769 Mdot
.40327 .57807 Mdot
.11607 .46488 Mdot
.43605 .59425 Mdot
.96499 .19426 Mdot
.09241 .22901 Mdot
.1151 .23727 Mdot
.62949 .06341 Mdot
.7265 .09976 Mdot
.6186 .05787 Mdot
.96165 .19233 Mdot
.5958 .0464 Mdot
.10806 .24127 Mdot
.22771 .26732 Mdot
.83914 .14229 Mdot
.75244 .10763 Mdot
.25469 .26946 Mdot
.80954 .12955 Mdot
.08347 .45508 Mdot
.3401 .55373 Mdot
.96518 .19722 Mdot
.19724 .25779 Mdot
.13361 .24352 Mdot
.9384 .1854 Mdot
.23674 .51718 Mdot
.76435 .1105 Mdot
.63332 .05999 Mdot
.19706 .50246 Mdot
.77488 .12166 Mdot
.61384 .05347 Mdot
.47584 .61119 Mdot
.06119 .44611 Mdot
.08559 .23312 Mdot
.30623 .54786 Mdot
.075 .22512 Mdot
.59334 .04167 Mdot
.0423 .21879 Mdot
.02614 .20959 Mdot
.62248 .06071 Mdot
.0224 .21104 Mdot
.03973 .21458 Mdot
.6148 .05517 Mdot
.78104 .12494 Mdot
.34185 .5558 Mdot
.8686 .15491 Mdot
.2171 .50532 Mdot
.9471 .18266 Mdot
.86193 .14908 Mdot
.26687 .2734 Mdot
.24721 .27811 Mdot
.03987 .22315 Mdot
.15822 .48476 Mdot
.13441 .24941 Mdot
.11207 .24695 Mdot
.61246 .05421 Mdot
.58922 .04182 Mdot
.96324 .19022 Mdot
.13806 .47117 Mdot
.1341 .24032 Mdot
.90974 .17749 Mdot
.1965 .25674 Mdot
.71883 .09139 Mdot
.46993 .61061 Mdot
.743 .10546 Mdot
.895 .17112 Mdot
.12806 .24807 Mdot
.06996 .44675 Mdot
.37692 .56819 Mdot
.71532 .09772 Mdot
.03908 .43411 Mdot
.69804 .08927 Mdot
.74834 .10369 Mdot
.55685 .02718 Mdot
.89766 .38876 Mdot
.2579 .52649 Mdot
.70276 .08989 Mdot
.98333 .20411 Mdot
.08747 .24074 Mdot
.71648 .09696 Mdot
.51143 .01226 Mdot
.19036 .50068 Mdot
.26651 .52869 Mdot
.71863 .09261 Mdot
.76382 .11559 Mdot
.32505 .55363 Mdot
.73397 .10311 Mdot
.92038 .39458 Mdot
.89876 .38926 Mdot
.47974 .61069 Mdot
.29687 .53464 Mdot
.00085 .42608 Mdot
.01037 .4279 Mdot
.21984 .2647 Mdot
.19407 .26327 Mdot
.45821 .60402 Mdot
.75027 .11373 Mdot
.30222 .54126 Mdot
.14562 .24828 Mdot
.23378 .51363 Mdot
.12781 .24311 Mdot
.97096 .1937 Mdot
.68901 .08114 Mdot
.14425 .25875 Mdot
.89197 .16981 Mdot
.01544 .21002 Mdot
.79787 .12592 Mdot
.33931 .55196 Mdot
.21417 .50333 Mdot
.21293 .50569 Mdot
.6043 .05239 Mdot
.10818 .23188 Mdot
.61907 .05512 Mdot
.38881 .5777 Mdot
.09611 .2336 Mdot
.82075 .13854 Mdot
.4418 .59743 Mdot
.98341 .1951 Mdot
.88489 .15779 Mdot
.42284 .58654 Mdot
.84538 .15008 Mdot
.38171 .57379 Mdot
.40663 .58772 Mdot
.40587 .58352 Mdot
.00102 .20329 Mdot
.20417 .50602 Mdot
.03882 .21152 Mdot
.6095 .04816 Mdot
.82095 .13866 Mdot
.83449 .13807 Mdot
.09959 .23845 Mdot
.57555 .04122 Mdot
.48716 .00187 Mdot
.22116 .26278 Mdot
.25829 .52723 Mdot
.12135 .25185 Mdot
.45427 .60416 Mdot
.76515 .11072 Mdot
.60202 .04772 Mdot
.3233 .55321 Mdot
.24112 .27643 Mdot
.72998 .10323 Mdot
.05721 .44446 Mdot
.31905 .55073 Mdot
.10901 .24233 Mdot
.14032 .47462 Mdot
.05752 .22817 Mdot
.59336 .04227 Mdot
.39461 .57588 Mdot
.02779 .21117 Mdot
.23684 .26963 Mdot
.90962 .1706 Mdot
.19965 .50303 Mdot
.35337 .56294 Mdot
.20911 .26022 Mdot
.21976 .51149 Mdot
.3879 .57925 Mdot
.17883 .258 Mdot
.5333 .01463 Mdot
.48313 .61268 Mdot
.3041 .5457 Mdot
.0332 .22265 Mdot
.1082 .46122 Mdot
.2096 .2641 Mdot
.1013 .4615 Mdot
.12681 .25309 Mdot
.97036 .41003 Mdot
.75391 .10645 Mdot
.09167 .23066 Mdot
.04252 .22143 Mdot
.39478 .57539 Mdot
.34978 .55971 Mdot
.26302 .52246 Mdot
.93124 .18004 Mdot
.98384 .41489 Mdot
.13165 .25419 Mdot
.06947 .45241 Mdot
.20135 .50623 Mdot
.1967 .26307 Mdot
.6689 .07875 Mdot
.00046 .42548 Mdot
.82831 .13744 Mdot
.78176 .11895 Mdot
.64079 .06659 Mdot
.68005 .08471 Mdot
.9275 .17652 Mdot
.50331 .01048 Mdot
.19997 .25818 Mdot
.2391 .51353 Mdot
.19774 .2584 Mdot
.53754 .02275 Mdot
.87302 .15833 Mdot
.35619 .56145 Mdot
.15645 .24891 Mdot
.82495 .13456 Mdot
.81808 .13615 Mdot
.30763 .53908 Mdot
.05735 .22 Mdot
.01751 .42796 Mdot
.2192 .27163 Mdot
.22086 .27276 Mdot
.14126 .24751 Mdot
.6073 .04593 Mdot
.53957 .02488 Mdot
.40605 .58632 Mdot
.49029 .0013 Mdot
.8268 .14142 Mdot
.90645 .16556 Mdot
.27101 .52891 Mdot
.24664 .27614 Mdot
.08335 .45436 Mdot
.91851 .39506 Mdot
.31678 .54735 Mdot
.23101 .51396 Mdot
.94403 .18416 Mdot
.19672 .26756 Mdot
.71843 .09742 Mdot
.60127 .04461 Mdot
.27995 .28006 Mdot
.91101 .16872 Mdot
.99922 .20416 Mdot
.06324 .22371 Mdot
.73572 .09822 Mdot
.01667 .20756 Mdot
.57806 .03741 Mdot
.97872 .19875 Mdot
.85779 .14697 Mdot
.18789 .26585 Mdot
.30867 .54236 Mdot
.47087 .61124 Mdot
.41874 .58782 Mdot
.79696 .12645 Mdot
.02052 .21829 Mdot
.90292 .16443 Mdot
.27987 .2764 Mdot
.26305 .27506 Mdot
.74188 .10444 Mdot
.2644 .52283 Mdot
.06177 .22393 Mdot
.60498 .04819 Mdot
.95897 .19598 Mdot
.30092 .54451 Mdot
.3043 .54253 Mdot
.74706 .10751 Mdot
.90426 .17132 Mdot
.03166 .21524 Mdot
.98369 .20218 Mdot
.12787 .24756 Mdot
.05723 .44383 Mdot
.70767 .08992 Mdot
.55493 .03223 Mdot
.2755 .5346 Mdot
.15065 .26051 Mdot
.10543 .23113 Mdot
.6902 .0833 Mdot
.63787 .06262 Mdot
.23489 .27307 Mdot
.80783 .12771 Mdot
.18268 .48835 Mdot
.14093 .24899 Mdot
.32527 .55306 Mdot
.29307 .53335 Mdot
.23299 .27327 Mdot
.19932 .49651 Mdot
.35145 .56429 Mdot
.22593 .50681 Mdot
.90078 .16737 Mdot
.14627 .25365 Mdot
.07683 .23246 Mdot
.20242 .50181 Mdot
.71099 .09296 Mdot
.19241 .49236 Mdot
.54742 .02721 Mdot
.27913 .27854 Mdot
.78096 .12591 Mdot
.06103 .22937 Mdot
.18678 .49078 Mdot
.63667 .06239 Mdot
.92082 .17909 Mdot
.01695 .21614 Mdot
.00202 .20124 Mdot
.60943 .04866 Mdot
.49537 .00403 Mdot
.17633 .48744 Mdot
.14931 .48482 Mdot
.27456 .52712 Mdot
.97181 .19996 Mdot
.82578 .1394 Mdot
.55857 .03172 Mdot
.35898 .56901 Mdot
.17726 .26744 Mdot
.5574 .02485 Mdot
.25687 .27581 Mdot
.14538 .48242 Mdot
.74882 .10542 Mdot
.10982 .24194 Mdot
.79771 .12667 Mdot
.66792 .07304 Mdot
.03011 .43677 Mdot
.25584 .27401 Mdot
.03242 .21955 Mdot
.18149 .2651 Mdot
.23467 .27128 Mdot
.49974 .00702 Mdot
.28823 .27364 Mdot
.55293 .03138 Mdot
.61437 .05409 Mdot
.61337 .05111 Mdot
.02052 .20934 Mdot
.09511 .22928 Mdot
.15581 .25849 Mdot
.18146 .25304 Mdot
.9937 .41851 Mdot
.21975 .50724 Mdot
.16898 .48605 Mdot
.20744 .26768 Mdot
.21572 .50573 Mdot
.96324 .19517 Mdot
.15418 .25826 Mdot
.1384 .47464 Mdot
.22402 .26482 Mdot
.18167 .49047 Mdot
.34308 .56001 Mdot
.0848 .4501 Mdot
.17411 .49178 Mdot
.06436 .44986 Mdot
.13126 .24326 Mdot
.3077 .5468 Mdot
.1218 .25004 Mdot
.57095 .0305 Mdot
.09136 .22763 Mdot
.6111 .0533 Mdot
.21392 .26325 Mdot
.19645 .49758 Mdot
.14085 .25413 Mdot
.19293 .25766 Mdot
.82764 .13584 Mdot
.26436 .27519 Mdot
.14911 .25676 Mdot
.2218 .27637 Mdot
.23238 .51791 Mdot
.56293 .03506 Mdot
.27975 .53623 Mdot
.10327 .23365 Mdot
.12578 .47016 Mdot
.10624 .24428 Mdot
.5297 .01841 Mdot
.01366 .20846 Mdot
.93445 .1814 Mdot
.11029 .24174 Mdot
.20303 .26667 Mdot
.23572 .26619 Mdot
.18291 .26396 Mdot
.03122 .21814 Mdot
.12811 .25178 Mdot
.06063 .22519 Mdot
.85169 .14893 Mdot
.1357 .47744 Mdot
.48509 .00177 Mdot
.29801 .53705 Mdot
.78689 .12179 Mdot
.76937 .11904 Mdot
.04042 .2208 Mdot
.5473 .0216 Mdot
.23596 .27512 Mdot
.07563 .23106 Mdot
.01398 .42461 Mdot
.13222 .23864 Mdot
.77763 .12057 Mdot
.1742 .25444 Mdot
.45048 .60451 Mdot
.77865 .11613 Mdot
.9048 .16916 Mdot
.18083 .49075 Mdot
.25427 .27416 Mdot
.86646 .15152 Mdot
.24394 .52229 Mdot
.21356 .26642 Mdot
.26302 .278 Mdot
.20242 .26304 Mdot
.47482 .61085 Mdot
.15039 .24452 Mdot
.20039 .50138 Mdot
.26931 .52298 Mdot
.52025 .01032 Mdot
.2691 .52978 Mdot
.6911 .08343 Mdot
.63894 .06333 Mdot
.62665 .05735 Mdot
.89406 .17064 Mdot
.7835 .1227 Mdot
.77438 .11717 Mdot
.08239 .45143 Mdot
.72621 .09593 Mdot
.07825 .45511 Mdot
.2049 .49785 Mdot
.76204 .11247 Mdot
.12516 .47025 Mdot
.25371 .52692 Mdot
.07429 .23564 Mdot
.85422 .15089 Mdot
.3889 .58118 Mdot
.25641 .52794 Mdot
.85829 .15307 Mdot
.23355 .27319 Mdot
.19872 .25832 Mdot
.07366 .22549 Mdot
.92085 .17332 Mdot
.5502 .02895 Mdot
.97604 .20072 Mdot
.47786 .61677 Mdot
.27313 .27892 Mdot
.86446 .15213 Mdot
.18751 .26983 Mdot
.79555 .12494 Mdot
.20375 .50036 Mdot
.99548 .20351 Mdot
.07895 .4479 Mdot
.06084 .22243 Mdot
.78203 .12432 Mdot
.739 .10365 Mdot
.24471 .2777 Mdot
.4172 .5895 Mdot
.28522 .27849 Mdot
.79859 .12664 Mdot
.4299 .59836 Mdot
.12279 .23585 Mdot
.23954 .26671 Mdot
.386 .57589 Mdot
.0998 .23884 Mdot
.51114 .00737 Mdot
.55405 .03032 Mdot
.23705 .2744 Mdot
.77012 .12058 Mdot
.7684 .11317 Mdot
.85256 .15402 Mdot
.16494 .49096 Mdot
.58946 .04623 Mdot
.16038 .48864 Mdot
.35402 .56051 Mdot
.96253 .18893 Mdot
.84115 .14831 Mdot
.63844 .06742 Mdot
.45169 .60744 Mdot
.44877 .59809 Mdot
.91376 .16898 Mdot
.20377 .27218 Mdot
.23726 .51168 Mdot
.9408 .17847 Mdot
.16143 .25001 Mdot
.97126 .19169 Mdot
.06669 .23441 Mdot
.20356 .50695 Mdot
.05408 .44104 Mdot
.12385 .25267 Mdot
.11847 .23788 Mdot
.49519 .00596 Mdot
.07431 .44714 Mdot
.81135 .1374 Mdot
.25148 .27631 Mdot
.05293 .22761 Mdot
.21697 .26498 Mdot
.18976 .26119 Mdot
.46211 .6079 Mdot
.18574 .26112 Mdot
.20334 .50021 Mdot
.30064 .54145 Mdot
.2181 .50382 Mdot
.24451 .27364 Mdot
.98045 .41474 Mdot
.81199 .13798 Mdot
.12207 .46688 Mdot
.94199 .1793 Mdot
.34987 .5623 Mdot
.15821 .25408 Mdot
.06019 .21936 Mdot
.29095 .27586 Mdot
.05396 .22625 Mdot
.01689 .20881 Mdot
.63701 .06187 Mdot
.14585 .25114 Mdot
.46637 .6075 Mdot
.60569 .05024 Mdot
.12836 .46783 Mdot
.88208 .16165 Mdot
.21469 .26137 Mdot
.16655 .26462 Mdot
.07606 .45111 Mdot
.89652 .16169 Mdot
.60174 .04893 Mdot
.25618 .27143 Mdot
.11021 .2353 Mdot
.04481 .43765 Mdot
.90058 .172 Mdot
.02395 .21427 Mdot
.54296 .02461 Mdot
.98173 .41382 Mdot
.36391 .56369 Mdot
.31246 .54033 Mdot
.48728 .00342 Mdot
.03232 .22294 Mdot
.06599 .22349 Mdot
.80202 .1273 Mdot
.07949 .22453 Mdot
.54692 .0205 Mdot
.41982 .58686 Mdot
.08008 .23252 Mdot
.08364 .45663 Mdot
.95195 .18803 Mdot
.90986 .16977 Mdot
.40197 .58174 Mdot
.59775 .04475 Mdot
.97554 .19637 Mdot
.71348 .09035 Mdot
.00531 .42457 Mdot
.79004 .12079 Mdot
.65531 .06605 Mdot
.5282 .02014 Mdot
.09702 .23854 Mdot
.24024 .51381 Mdot
9e-05 .42073 Mdot
.56746 .02827 Mdot
.11884 .24502 Mdot
.15385 .48332 Mdot
.00528 .42294 Mdot
.67184 .0759 Mdot
.19522 .50272 Mdot
.06448 .22446 Mdot
.76628 .1179 Mdot
.76329 .11373 Mdot
.84187 .14198 Mdot
.27166 .5249 Mdot
.6516 .0641 Mdot
.93645 .17789 Mdot
.05263 .22302 Mdot
.96741 .19416 Mdot
.89161 .16367 Mdot
.09122 .45367 Mdot
.88691 .16311 Mdot
.60205 .05021 Mdot
.2955 .54064 Mdot
.03806 .21572 Mdot
.696 .08715 Mdot
.56796 .02994 Mdot
.163 .25395 Mdot
.8509 .14369 Mdot
.3583 .56896 Mdot
.07237 .45121 Mdot
.70304 .09048 Mdot
.11385 .23919 Mdot
.00951 .20337 Mdot
.77154 .11803 Mdot
.91446 .17248 Mdot
.91541 .17117 Mdot
.39513 .58235 Mdot
.12691 .46686 Mdot
.34593 .5572 Mdot
.50498 .00288 Mdot
.17 .48657 Mdot
.63699 .0633 Mdot
.0672 .23146 Mdot
.67781 .0769 Mdot
.1766 .25996 Mdot
.11007 .46859 Mdot
.14733 .47647 Mdot
.38257 .57372 Mdot
.20467 .25979 Mdot
.06335 .44715 Mdot
.80089 .12479 Mdot
.76778 .11394 Mdot
.80486 .13315 Mdot
.29554 .54009 Mdot
.20617 .27331 Mdot
.86163 .1522 Mdot
.15308 .24912 Mdot
.94639 .18777 Mdot
.88947 .15976 Mdot
.3237 .54644 Mdot
.09508 .23951 Mdot
.46553 .61128 Mdot
.13829 .4776 Mdot
.93479 .18124 Mdot
.95071 .19207 Mdot
.81879 .13958 Mdot
.16985 .26416 Mdot
.11182 .23979 Mdot
.13935 .25004 Mdot
.40124 .58408 Mdot
.11787 .46794 Mdot
.18003 .25922 Mdot
.59034 .04517 Mdot
.99409 .20655 Mdot
.23127 .50851 Mdot
.16524 .25029 Mdot
.91195 .16998 Mdot
.66266 .07257 Mdot
.1628 .25091 Mdot
.71059 .0883 Mdot
.24021 .51888 Mdot
.46446 .60638 Mdot
.97045 .41469 Mdot
.80264 .13283 Mdot
.94113 .18435 Mdot
.9899 .19513 Mdot
.47448 .61113 Mdot
.20862 .26802 Mdot
.79971 .12499 Mdot
.46257 .60464 Mdot
.09193 .2402 Mdot
.97472 .19183 Mdot
.67959 .07513 Mdot
.703 .09258 Mdot
.93736 .18507 Mdot
.0665 .22053 Mdot
.12474 .23904 Mdot
.94533 .40245 Mdot
.9181 .17847 Mdot
.16318 .48346 Mdot
.20664 .26597 Mdot
.91785 .17008 Mdot
.3872 .57936 Mdot
.28603 .27595 Mdot
.94521 .18906 Mdot
.64226 .06031 Mdot
.12762 .23789 Mdot
.74247 .10102 Mdot
.20284 .5059 Mdot
.6283 .0537 Mdot
.49682 .61784 Mdot
.63597 .06355 Mdot
.78168 .1212 Mdot
.93435 .18272 Mdot
.55556 .02922 Mdot
.99286 .20526 Mdot
.1551 .25843 Mdot
.15385 .48334 Mdot
.1477 .25492 Mdot
.641 .06423 Mdot
.14214 .25507 Mdot
.14992 .25216 Mdot
.48514 .00046 Mdot
.7908 .1287 Mdot
.93609 .17862 Mdot
.03698 .21398 Mdot
.56072 .03119 Mdot
.24036 .51615 Mdot
.94934 .19038 Mdot
.27869 .5359 Mdot
.94108 .17863 Mdot
.86999 .15512 Mdot
.9721 .41446 Mdot
.16391 .26091 Mdot
.02759 .2158 Mdot
.64468 .06994 Mdot
.18587 .25543 Mdot
.80108 .13204 Mdot
.94604 .18861 Mdot
.3139 .543 Mdot
.19053 .50174 Mdot
.21657 .50455 Mdot
.44198 .60236 Mdot
.97728 .2028 Mdot
.30123 .5417 Mdot
.94875 .18227 Mdot
.48131 .61061 Mdot
.49037 .61554 Mdot
.78282 .12395 Mdot
.18432 .25637 Mdot
.25754 .27877 Mdot
.78494 .11928 Mdot
.2607 .28025 Mdot
.73508 .10587 Mdot
.79345 .12218 Mdot
.22384 .27375 Mdot
.65792 .0707 Mdot
.1943 .50038 Mdot
.21457 .26178 Mdot
.92078 .17694 Mdot
.80256 .13265 Mdot
.82845 .13669 Mdot
.96377 .19607 Mdot
.90533 .39042 Mdot
.09507 .24162 Mdot
.72709 .09605 Mdot
.14529 .48158 Mdot
.96258 .18941 Mdot
.71016 .0896 Mdot
.95564 .19025 Mdot
.932 .18358 Mdot
.90288 .38996 Mdot
.96045 .40671 Mdot
.62159 .05906 Mdot
.57254 .03217 Mdot
.57393 .03907 Mdot
.029 .21333 Mdot
.05265 .22557 Mdot
.06848 .23033 Mdot
.1867 .25576 Mdot
.17811 .49039 Mdot
.5485 .02774 Mdot
.87705 .16095 Mdot
.50656 .01002 Mdot
.74273 .10701 Mdot
.27474 .27684 Mdot
.21257 .26125 Mdot
.7267 .09466 Mdot
.1108 .46066 Mdot
.15447 .25022 Mdot
.63423 .06036 Mdot
.08025 .22429 Mdot
.21703 .50155 Mdot
.7862 .12082 Mdot
.96963 .193 Mdot
.43642 .5963 Mdot
.41401 .58955 Mdot
.55171 .02742 Mdot
.24643 .5164 Mdot
.03515 .218 Mdot
.97541 .41504 Mdot
.00071 .2009 Mdot
.91865 .17871 Mdot
.05139 .21719 Mdot
.46138 .60923 Mdot
.49409 .00595 Mdot
.7206 .09529 Mdot
.16286 .2516 Mdot
.46222 .60808 Mdot
.90563 .17343 Mdot
.02257 .4314 Mdot
.03281 .21263 Mdot
.9194 .39509 Mdot
.90624 .39171 Mdot
.55173 .02415 Mdot
.34198 .56174 Mdot
.25374 .52132 Mdot
.03127 .20984 Mdot
.78213 .11793 Mdot
.23461 .27042 Mdot
.47639 .61325 Mdot
.69494 .09033 Mdot
.25875 .52055 Mdot
.85411 .15271 Mdot
.19469 .49438 Mdot
.81334 .1358 Mdot
.18115 .26705 Mdot
.64061 .0656 Mdot
.80008 .12818 Mdot
.79854 .1298 Mdot
.14182 .24535 Mdot
.99028 .20733 Mdot
.93745 .18553 Mdot
.08862 .45145 Mdot
.43925 .59765 Mdot
.86649 .15305 Mdot
.04683 .44041 Mdot
.23071 .51378 Mdot
.36039 .56373 Mdot
.14982 .25936 Mdot
.14049 .25734 Mdot
.1993 .49738 Mdot
.12215 .24733 Mdot
.83855 .1427 Mdot
.41778 .59273 Mdot
.52149 .01227 Mdot
.12352 .24283 Mdot
.88645 .15782 Mdot
.94629 .18047 Mdot
.83772 .14281 Mdot
.7714 .11911 Mdot
.14434 .24915 Mdot
.12325 .24794 Mdot
.81476 .13118 Mdot
.12036 .2347 Mdot
.16697 .49085 Mdot
.96478 .18749 Mdot
.85948 .15214 Mdot
.22957 .26999 Mdot
.11881 .24193 Mdot
.22128 .50979 Mdot
.13468 .46913 Mdot
.05808 .23136 Mdot
.52426 .01566 Mdot
.07121 .22538 Mdot
.94106 .18281 Mdot
.06998 .22472 Mdot
.96356 .19349 Mdot
.96892 .41146 Mdot
.95271 .40652 Mdot
.14494 .47796 Mdot
.31906 .55014 Mdot
.27738 .27302 Mdot
.23292 .27029 Mdot
.63799 .06596 Mdot
.66976 .07198 Mdot
.74522 .10774 Mdot
.20544 .26722 Mdot
.84721 .14624 Mdot
.14531 .47406 Mdot
.70726 .0884 Mdot
.42844 .59749 Mdot
.74136 .10796 Mdot
.95131 .40744 Mdot
.82322 .14309 Mdot
.11199 .46663 Mdot
.99394 .4191 Mdot
.66599 .07312 Mdot
.85153 .14946 Mdot
.94121 .18612 Mdot
.12795 .23901 Mdot
.57053 .03519 Mdot
.7124 .09737 Mdot
.3071 .54434 Mdot
.11079 .23456 Mdot
.20248 .49994 Mdot
.55871 .02616 Mdot
.28622 .53859 Mdot
.36669 .56296 Mdot
.85765 .15166 Mdot
.10051 .23897 Mdot
.2741 .2727 Mdot
.09378 .2347 Mdot
.74868 .10511 Mdot
.6235 .0564 Mdot
.60338 .04866 Mdot
.6535 .06758 Mdot
.16621 .48277 Mdot
.94006 .40361 Mdot
.07551 .44984 Mdot
.72604 .09523 Mdot
.84094 .14822 Mdot
.12061 .24528 Mdot
.92657 .18394 Mdot
.14478 .24354 Mdot
.23633 .27291 Mdot
.82398 .14034 Mdot
.58976 .03963 Mdot
.99379 .42213 Mdot
.1839 .48875 Mdot
.92874 .39884 Mdot
.30295 .54439 Mdot
.7692 .12127 Mdot
.70658 .08607 Mdot
.80975 .13164 Mdot
.98449 .41487 Mdot
.77517 .11596 Mdot
.15891 .48108 Mdot
.13586 .47575 Mdot
.80752 .12698 Mdot
.99779 .42223 Mdot
.79123 .13018 Mdot
.94291 .40308 Mdot
.24436 .51396 Mdot
.74974 .10494 Mdot
.79085 .12155 Mdot
.13575 .47846 Mdot
.61634 .04971 Mdot
.57448 .03635 Mdot
.62772 .06171 Mdot
.62659 .06256 Mdot
.03159 .2206 Mdot
.43856 .59982 Mdot
.4371 .60014 Mdot
.33502 .55584 Mdot
.23287 .2701 Mdot
.83464 .14279 Mdot
.39918 .58124 Mdot
.89231 .16807 Mdot
.00358 .20559 Mdot
.09786 .45733 Mdot
.57229 .0357 Mdot
.04877 .21763 Mdot
.09909 .24147 Mdot
.83021 .14036 Mdot
.88443 .16643 Mdot
.66002 .07447 Mdot
.70084 .08538 Mdot
.02497 .21099 Mdot
.45513 .60547 Mdot
.33282 .55382 Mdot
.6722 .07383 Mdot
.0518 .44222 Mdot
.26403 .52699 Mdot
.15678 .47878 Mdot
.75373 .11424 Mdot
.95885 .1926 Mdot
.04346 .21309 Mdot
.47917 .61794 Mdot
.57586 .03982 Mdot
.65905 .07218 Mdot
.95451 .40791 Mdot
.09321 .45376 Mdot
.85728 .15688 Mdot
.23813 .51759 Mdot
.34978 .55878 Mdot
.18324 .26083 Mdot
.14443 .24888 Mdot
.5121 .01399 Mdot
.2036 .25953 Mdot
.89913 .38925 Mdot
.96364 .19308 Mdot
.78719 .12306 Mdot
.8604 .15157 Mdot
.4604 .60507 Mdot
.17746 .48992 Mdot
.39624 .58105 Mdot
.01194 .20321 Mdot
.31644 .54206 Mdot
.23568 .26785 Mdot
.01591 .42676 Mdot
.1586 .24698 Mdot
.99231 .41828 Mdot
.48939 .00155 Mdot
.81029 .13465 Mdot
.8685 .15322 Mdot
.11814 .46582 Mdot
.86662 .15914 Mdot
.19897 .26433 Mdot
.02418 .21765 Mdot
.79182 .12652 Mdot
.84057 .14171 Mdot
.5728 .03492 Mdot
.12079 .25192 Mdot
.38322 .57295 Mdot
.44798 .59982 Mdot
.14104 .25323 Mdot
.8221 .13374 Mdot
.88158 .16051 Mdot
.13203 .47101 Mdot
.11491 .24733 Mdot
.72084 .09645 Mdot
.15794 .48036 Mdot
.05955 .2222 Mdot
.14161 .254 Mdot
.11454 .46463 Mdot
.60084 .04582 Mdot
.18293 .26737 Mdot
.99626 .20596 Mdot
.24258 .5202 Mdot
.96523 .41154 Mdot
.19524 .26122 Mdot
.35467 .56145 Mdot
.39175 .57332 Mdot
.01213 .42635 Mdot
.92147 .17954 Mdot
.38226 .57306 Mdot
.58998 .04221 Mdot
.99274 .19663 Mdot
.93258 .18124 Mdot
.18342 .49218 Mdot
.87432 .16108 Mdot
.06796 .44585 Mdot
.76751 .11295 Mdot
.19568 .26672 Mdot
.13472 .47082 Mdot
.07267 .2308 Mdot
.84648 .14636 Mdot
.49546 .61758 Mdot
.42319 .59504 Mdot
.71357 .08978 Mdot
.7274 .09817 Mdot
.7004 .09044 Mdot
.24943 .26836 Mdot
.40824 .585 Mdot
.48867 .61714 Mdot
.73175 .10401 Mdot
.1344 .47139 Mdot
.84421 .1433 Mdot
.92006 .17966 Mdot
.11672 .46254 Mdot
.67102 .0801 Mdot
.0222 .21886 Mdot
.11094 .24155 Mdot
.12209 .46673 Mdot
.20426 .27133 Mdot
.19845 .26551 Mdot
.61001 .05081 Mdot
.78575 .12731 Mdot
.24098 .5137 Mdot
.11103 .24446 Mdot
.95088 .18678 Mdot
.8325 .14348 Mdot
.45937 .60626 Mdot
.23325 .27041 Mdot
.51733 .00741 Mdot
.04056 .21878 Mdot
.8253 .13489 Mdot
.21903 .27104 Mdot
.37914 .57363 Mdot
.77086 .12099 Mdot
.97504 .41667 Mdot
.83017 .13748 Mdot
.58219 .04306 Mdot
.17618 .49097 Mdot
.18983 .25621 Mdot
.38025 .57624 Mdot
.60489 .04713 Mdot
.54065 .0204 Mdot
.98945 .19793 Mdot
.80721 .13252 Mdot
.80498 .13207 Mdot
.21333 .50739 Mdot
.66699 .07225 Mdot
.6162 .05352 Mdot
.24569 .51666 Mdot
.61689 .05842 Mdot
.13356 .46854 Mdot
.03014 .43228 Mdot
.10668 .24271 Mdot
.06057 .23022 Mdot
.20793 .2609 Mdot
.07906 .45083 Mdot
.76306 .11735 Mdot
.06373 .4495 Mdot
.19045 .26129 Mdot
.65073 .06324 Mdot
.84951 .14526 Mdot
.19532 .49309 Mdot
.48021 .61147 Mdot
.36975 .57255 Mdot
.9446 .18521 Mdot
.50955 .00469 Mdot
.80395 .12584 Mdot
.62177 .05891 Mdot
.20842 .50021 Mdot
.35537 .56045 Mdot
.51644 .01325 Mdot
.94076 .18057 Mdot
.90289 .16902 Mdot
.51863 .00963 Mdot
.1887 .49314 Mdot
.31101 .54249 Mdot
.87546 .16189 Mdot
.01068 .20539 Mdot
.18656 .26408 Mdot
.59486 .04355 Mdot
.86537 .15482 Mdot
.02749 .43081 Mdot
.51315 .01357 Mdot
.68614 .08621 Mdot
.84711 .14623 Mdot
.22332 .26924 Mdot
.4168 .58398 Mdot
.84876 .14709 Mdot
.10589 .23612 Mdot
.00504 .20231 Mdot
.08126 .45597 Mdot
.61682 .05605 Mdot
.41295 .58231 Mdot
.37957 .5739 Mdot
.08918 .45444 Mdot
.20171 .26725 Mdot
.86889 .16021 Mdot
.09096 .22758 Mdot
.22123 .51167 Mdot
.49858 .00575 Mdot
.25741 .52275 Mdot
.70359 .0897 Mdot
.38218 .57814 Mdot
.25667 .52533 Mdot
.13105 .25283 Mdot
.04925 .21666 Mdot
.89248 .16678 Mdot
.99473 .42382 Mdot
.20672 .50561 Mdot
.03065 .43512 Mdot
.2997 .27444 Mdot
.07978 .23477 Mdot
.07626 .23027 Mdot
.19205 .49331 Mdot
.91257 .17351 Mdot
.12562 .47048 Mdot
.20527 .26645 Mdot
.23855 .51296 Mdot
.222 .50375 Mdot
.47885 .61787 Mdot
.20063 .49787 Mdot
.25628 .52276 Mdot
.21544 .50409 Mdot
.77515 .12242 Mdot
.73192 .10482 Mdot
.33807 .55721 Mdot
.01507 .20803 Mdot
.03161 .43373 Mdot
.19297 .26345 Mdot
.23147 .27655 Mdot
.86994 .15758 Mdot
.68443 .07723 Mdot
.42734 .59048 Mdot
.59107 .04293 Mdot
.38471 .57958 Mdot
.24232 .26943 Mdot
.88809 .15925 Mdot
.18359 .26888 Mdot
.25741 .27403 Mdot
.02913 .21888 Mdot
.97643 .4141 Mdot
.1859 .26601 Mdot
.69573 .08707 Mdot
.38542 .57791 Mdot
.05303 .44187 Mdot
.00517 .20406 Mdot
.15473 .24858 Mdot
.1334 .24939 Mdot
.15431 .47864 Mdot
.12292 .47196 Mdot
.2997 .53882 Mdot
.68666 .08619 Mdot
.15473 .47937 Mdot
.62226 .05143 Mdot
.06051 .22827 Mdot
.39178 .57533 Mdot
.84396 .14534 Mdot
.98959 .20755 Mdot
.80213 .12546 Mdot
.9984 .20288 Mdot
.8197 .14095 Mdot
.05767 .22823 Mdot
.27234 .52875 Mdot
.58088 .04229 Mdot
.96222 .41122 Mdot
.12957 .25207 Mdot
.42519 .59238 Mdot
.56615 .03327 Mdot
.82742 .13643 Mdot
.1254 .24684 Mdot
.1362 .23982 Mdot
.99608 .42173 Mdot
.6198 .05188 Mdot
.48733 .61751 Mdot
.50693 .00956 Mdot
.1081 .46642 Mdot
.37832 .57153 Mdot
.51845 .01524 Mdot
.15296 .48625 Mdot
.10388 .23391 Mdot
.53346 .02054 Mdot
.16861 .48895 Mdot
.50591 .00818 Mdot
.02308 .43271 Mdot
.0737 .22846 Mdot
.08246 .23817 Mdot
.79327 .12838 Mdot
.81596 .13263 Mdot
.17138 .48618 Mdot
.45677 .60445 Mdot
.21474 .5048 Mdot
.50528 .00478 Mdot
.19152 .26528 Mdot
.5179 .01391 Mdot
.57923 .0345 Mdot
.30182 .53868 Mdot
.05311 .2267 Mdot
.82611 .13865 Mdot
.07781 .44762 Mdot
.13317 .24121 Mdot
.2688 .27166 Mdot
.94672 .18853 Mdot
.04311 .2177 Mdot
.21347 .50472 Mdot
.2216 .2666 Mdot
.19928 .26785 Mdot
.59617 .04465 Mdot
.79443 .12647 Mdot
.09339 .23948 Mdot
.10432 .23123 Mdot
.8496 .15078 Mdot
.15479 .48694 Mdot
.94536 .19066 Mdot
.40187 .57837 Mdot
.06054 .22735 Mdot
.36022 .56659 Mdot
.91904 .16966 Mdot
.67486 .08171 Mdot
.50402 .00693 Mdot
.06731 .22673 Mdot
.98598 .20428 Mdot
.08716 .23209 Mdot
.97415 .41288 Mdot
.11775 .24327 Mdot
.61058 .04792 Mdot
.55212 .02541 Mdot
.08877 .23564 Mdot
.35318 .56369 Mdot
.23425 .26615 Mdot
.19596 .26722 Mdot
.71432 .08916 Mdot
.02013 .43169 Mdot
.95132 .40682 Mdot
.46031 .6111 Mdot
.10062 .23059 Mdot
.50013 .00462 Mdot
.7615 .11727 Mdot
.09785 .23048 Mdot
.84958 .1467 Mdot
.98024 .19709 Mdot
.01617 .21435 Mdot
.18445 .26161 Mdot
.12651 .47495 Mdot
.05494 .22044 Mdot
.23611 .26625 Mdot
.81811 .13378 Mdot
.06303 .44845 Mdot
.47802 .61659 Mdot
.90603 .17179 Mdot
.52837 .01861 Mdot
.16183 .24957 Mdot
.77281 .11575 Mdot
.42226 .5906 Mdot
.05576 .22648 Mdot
.49842 .00678 Mdot
.12991 .24439 Mdot
.27527 .52692 Mdot
.17335 .48519 Mdot
.42151 .59221 Mdot
.17945 .2536 Mdot
.75888 .10827 Mdot
.96148 .1928 Mdot
.06047 .23036 Mdot
.01761 .43034 Mdot
.42884 .59119 Mdot
.51509 .01277 Mdot
.12247 .47059 Mdot
.52932 .01493 Mdot
.02195 .21042 Mdot
.12724 .46782 Mdot
.80466 .13187 Mdot
.42452 .59473 Mdot
.16465 .2547 Mdot
.69664 .08403 Mdot
.35197 .56303 Mdot
.8889 .16834 Mdot
.0912 .23321 Mdot
.14225 .47431 Mdot
.14497 .2563 Mdot
.16057 .2623 Mdot
.2169 .26377 Mdot
.89101 .16799 Mdot
.7781 .12427 Mdot
.63548 .06575 Mdot
.73248 .10065 Mdot
.11411 .24569 Mdot
.5386 .02332 Mdot
.45618 .60776 Mdot
.62099 .05417 Mdot
.11364 .46828 Mdot
.00873 .20881 Mdot
.47689 .61474 Mdot
.86199 .14818 Mdot
.14831 .25784 Mdot
.25347 .51703 Mdot
.76931 .12086 Mdot
.1101 .24406 Mdot
.82517 .13584 Mdot
.80683 .13631 Mdot
.53142 .01678 Mdot
.22564 .26616 Mdot
.61584 .05587 Mdot
.15347 .47651 Mdot
.96136 .4086 Mdot
.5254 .01078 Mdot
.3032 .53856 Mdot
.43199 .59848 Mdot
.10541 .23624 Mdot
.49451 .61776 Mdot
.13274 .46922 Mdot
.17667 .25177 Mdot
.14814 .25508 Mdot
.11302 .46912 Mdot
.79538 .13167 Mdot
.10338 .24136 Mdot
.66014 .07497 Mdot
.40009 .58251 Mdot
.13283 .47538 Mdot
.1602 .48731 Mdot
.16604 .48435 Mdot
.87967 .1606 Mdot
.14522 .24416 Mdot
.78734 .12126 Mdot
.20547 .50183 Mdot
.87041 .15755 Mdot
.02288 .21356 Mdot
.20971 .27269 Mdot
.56363 .03323 Mdot
.71121 .09061 Mdot
.21231 .50023 Mdot
.73955 .10494 Mdot
.23211 .51592 Mdot
.03696 .21124 Mdot
.19656 .49968 Mdot
.47456 .61497 Mdot
.1178 .23605 Mdot
.84545 .14392 Mdot
.33506 .55526 Mdot
.07714 .22785 Mdot
.23865 .27644 Mdot
.19503 .4926 Mdot
.95554 .193 Mdot
.05946 .22482 Mdot
.50506 .00241 Mdot
.14551 .24882 Mdot
.48196 .6147 Mdot
.93596 .18354 Mdot
.49649 .00161 Mdot
.18493 .25704 Mdot
.32621 .5531 Mdot
.00245 .42221 Mdot
.55191 .02969 Mdot
.97318 .19064 Mdot
.82595 .13397 Mdot
.09622 .46249 Mdot
.48719 .00413 Mdot
.069 .44697 Mdot
.14361 .25056 Mdot
.74974 .10945 Mdot
.50374 .00364 Mdot
.65108 .06465 Mdot
.34029 .55632 Mdot
.44698 .59624 Mdot
.23409 .26919 Mdot
.05967 .23157 Mdot
.36968 .57011 Mdot
.80133 .12716 Mdot
.09282 .4616 Mdot
.51482 .00672 Mdot
.0707 .44641 Mdot
.21648 .26226 Mdot
.12401 .25177 Mdot
.52929 .01512 Mdot
.6085 .04955 Mdot
.1688 .25029 Mdot
.8165 .13841 Mdot
.38536 .57333 Mdot
.20001 .49577 Mdot
.83231 .13687 Mdot
.31164 .54422 Mdot
.48452 .00315 Mdot
.05917 .44457 Mdot
.30618 .54276 Mdot
.47971 .61331 Mdot
.99054 .1983 Mdot
.27418 .27897 Mdot
.20982 .27383 Mdot
.46645 .60573 Mdot
.71968 .09767 Mdot
.05224 .43866 Mdot
.07261 .23108 Mdot
.20147 .2641 Mdot
.80796 .13323 Mdot
.04427 .21742 Mdot
.2512 .51584 Mdot
.7799 .12487 Mdot
.88158 .16509 Mdot
.89777 .17233 Mdot
.11869 .24971 Mdot
.20584 .50529 Mdot
.22634 .50758 Mdot
.22361 .26958 Mdot
.75586 .11254 Mdot
.90896 .39311 Mdot
.09321 .2281 Mdot
.35841 .56709 Mdot
.06115 .2324 Mdot
.1469 .25804 Mdot
.01423 .42583 Mdot
.49466 .00715 Mdot
.43421 .59252 Mdot
.08398 .45216 Mdot
.37827 .57686 Mdot
.3034 .54138 Mdot
.86363 .1521 Mdot
.25971 .52263 Mdot
.90994 .16944 Mdot
.10186 .46378 Mdot
.03081 .43468 Mdot
.48438 7e-05 Mdot
.13555 .24244 Mdot
.17668 .49349 Mdot
.57736 .03247 Mdot
.18716 .25954 Mdot
.35873 .55958 Mdot
.79123 .12026 Mdot
.09097 .23893 Mdot
.69725 .08812 Mdot
.03772 .43916 Mdot
.37917 .56775 Mdot
.12652 .23877 Mdot
.08795 .45525 Mdot
.18311 .49852 Mdot
.10482 .46514 Mdot
.82348 .14263 Mdot
.01605 .4265 Mdot
.23115 .5164 Mdot
.42533 .58765 Mdot
.30568 .53845 Mdot
.20483 .26133 Mdot
.48778 .00126 Mdot
.76293 .11349 Mdot
.48677 .61746 Mdot
.45177 .59905 Mdot
.49828 .00496 Mdot
.54875 .02531 Mdot
.18997 .26376 Mdot
.3271 .55014 Mdot
.16993 .26225 Mdot
.07816 .22856 Mdot
.72783 .1015 Mdot
.23104 .27414 Mdot
.02564 .42885 Mdot
.40415 .58175 Mdot
.08879 .23481 Mdot
.10674 .23584 Mdot
.81918 .141 Mdot
.81464 .1374 Mdot
.73648 .10056 Mdot
.2388 .51358 Mdot
.05477 .22284 Mdot
.33152 .54801 Mdot
.54457 .02576 Mdot
.57919 .03477 Mdot
.31173 .54696 Mdot
.33447 .55701 Mdot
.39613 .57652 Mdot
.37551 .57118 Mdot
.12688 .24132 Mdot
.13481 .25232 Mdot
.25467 .51666 Mdot
.73955 .10365 Mdot
.80696 .13272 Mdot
.16631 .48577 Mdot
.42346 .59448 Mdot
.82262 .13516 Mdot
.94996 .40576 Mdot
.65661 .06976 Mdot
.07638 .23746 Mdot
.43882 .60163 Mdot
.078 .23406 Mdot
.46224 .60386 Mdot
.63065 .06093 Mdot
.21469 .26943 Mdot
.01855 .20555 Mdot
.96158 .18936 Mdot
.80915 .12941 Mdot
.97608 .41307 Mdot
.69901 .08326 Mdot
.90794 .17291 Mdot
.11387 .23457 Mdot
.64207 .06614 Mdot
.25773 .5219 Mdot
.2197 .26452 Mdot
.16908 .2608 Mdot
.21803 .51041 Mdot
.24027 .27049 Mdot
.46199 .60652 Mdot
.40181 .5818 Mdot
.302 .53934 Mdot
.94145 .18328 Mdot
.01497 .21336 Mdot
.95594 .1875 Mdot
.16234 .47972 Mdot
.87831 .16472 Mdot
.38773 .57585 Mdot
.84183 .14224 Mdot
.35193 .5632 Mdot
.00804 .20807 Mdot
.06648 .22356 Mdot
.38463 .56992 Mdot
.97504 .20088 Mdot
.04397 .22125 Mdot
.09913 .23181 Mdot
.95141 .40727 Mdot
.79135 .12167 Mdot
.64206 .06194 Mdot
.56179 .0322 Mdot
.99907 .19927 Mdot
.37632 .57616 Mdot
.17929 .49282 Mdot
.48308 4e-05 Mdot
.9954 .20454 Mdot
.09156 .24102 Mdot
.08517 .22527 Mdot
.12111 .24751 Mdot
.251 .27393 Mdot
.17852 .49239 Mdot
.59468 .04459 Mdot
.15964 .26142 Mdot
.80079 .12859 Mdot
.01969 .21785 Mdot
.79969 .13248 Mdot
.31252 .54202 Mdot
.99141 .19942 Mdot
.82404 .13678 Mdot
.0381 .21523 Mdot
.16302 .25696 Mdot
.15034 .25127 Mdot
.8636 .14922 Mdot
.83424 .14752 Mdot
.13745 .2414 Mdot
.16011 .25436 Mdot
.38079 .57029 Mdot
.64794 .06826 Mdot
.91721 .39371 Mdot
.86539 .15357 Mdot
.65552 .07143 Mdot
.98995 .19645 Mdot
.62332 .05195 Mdot
.22185 .26699 Mdot
.23293 .27795 Mdot
.74823 .10941 Mdot
.2178 .27223 Mdot
.71427 .09021 Mdot
.75315 .11126 Mdot
.23106 .51164 Mdot
.68469 .08302 Mdot
.60751 .04554 Mdot
.21596 .5115 Mdot
.14718 .25897 Mdot
.81857 .14055 Mdot
.02108 .21044 Mdot
.03618 .22332 Mdot
.47742 .61531 Mdot
.91724 .16981 Mdot
.99046 .20286 Mdot
.34318 .55708 Mdot
.54276 .01916 Mdot
.1895 .26674 Mdot
.08967 .22765 Mdot
.17699 .26501 Mdot
.12592 .46674 Mdot
.6376 .06688 Mdot
.71026 .09502 Mdot
.81222 .12908 Mdot
.02182 .42807 Mdot
.27649 .27968 Mdot
.62439 .05672 Mdot
.93042 .18027 Mdot
.17385 .2536 Mdot
.16509 .25916 Mdot
.97399 .41548 Mdot
.17777 .49542 Mdot
.99334 .19867 Mdot
.10606 .24561 Mdot
.48201 .61447 Mdot
.14562 .48291 Mdot
.2555 .52031 Mdot
.24419 .52121 Mdot
.175 .26411 Mdot
.53444 .01725 Mdot
.11951 .24335 Mdot
.90443 .17088 Mdot
.01974 .20798 Mdot
.91668 .17737 Mdot
.90029 .38928 Mdot
.23076 .27467 Mdot
.94695 .18727 Mdot
.00827 .20203 Mdot
.45681 .60249 Mdot
.96261 .1883 Mdot
.82602 .13838 Mdot
.61677 .05775 Mdot
.16913 .26403 Mdot
.9347 .17958 Mdot
.23989 .27138 Mdot
.20036 .50132 Mdot
.22634 .26979 Mdot
.43058 .59619 Mdot
.21132 .49995 Mdot
.6252 .0589 Mdot
.22773 .27338 Mdot
.8781 .15937 Mdot
.33173 .55213 Mdot
.42731 .59283 Mdot
.71997 .09635 Mdot
.73048 .09757 Mdot
.91022 .17532 Mdot
.70478 .09096 Mdot
.74837 .10367 Mdot
.43196 .5979 Mdot
.69942 .09264 Mdot
.0117 .2048 Mdot
.537 .0169 Mdot
.33551 .55664 Mdot
.36416 .56861 Mdot
.07462 .22503 Mdot
.88614 .15985 Mdot
.58814 .04633 Mdot
.15536 .48206 Mdot
.06992 .22714 Mdot
.64356 .06357 Mdot
.85962 .15308 Mdot
.12664 .47046 Mdot
.01581 .20912 Mdot
.81638 .13281 Mdot
.8776 .16149 Mdot
.61639 .05368 Mdot
.95874 .19037 Mdot
.94782 .18383 Mdot
.55246 .02695 Mdot
.97289 .19973 Mdot
.6715 .0727 Mdot
.1263 .47122 Mdot
.23491 .26687 Mdot
.12093 .23591 Mdot
.16788 .48401 Mdot
.59018 .04564 Mdot
.92413 .17783 Mdot
.11974 .23998 Mdot
.09922 .22959 Mdot
.03886 .43319 Mdot
.81543 .13521 Mdot
.67747 .07551 Mdot
.20186 .25857 Mdot
.73579 .1048 Mdot
.13449 .47863 Mdot
.73919 .10548 Mdot
.10691 .24162 Mdot
.31382 .54882 Mdot
.03457 .43252 Mdot
.33258 .55333 Mdot
.06549 .44322 Mdot
.10968 .46541 Mdot
.87799 .16003 Mdot
.65671 .06865 Mdot
.73867 .10038 Mdot
.11758 .47022 Mdot
.80337 .12852 Mdot
.59634 .04046 Mdot
.1649 .25947 Mdot
.44367 .59656 Mdot
.00343 .20858 Mdot
.27968 .53406 Mdot
.74529 .10803 Mdot
.00321 .4238 Mdot
.0444 .21462 Mdot
.93904 .18748 Mdot
.53456 .0238 Mdot
.62339 .05382 Mdot
.96127 .19289 Mdot
.14272 .244 Mdot
.20949 .27221 Mdot
.97373 .20189 Mdot
.10116 .45888 Mdot
.46676 .60684 Mdot
.97339 .19702 Mdot
.27159 .52395 Mdot
.07399 .23005 Mdot
.95682 .1858 Mdot
.76484 .11506 Mdot
.5233 .01898 Mdot
.24286 .27685 Mdot
.49441 .00479 Mdot
.92491 .39588 Mdot
.09801 .24115 Mdot
.22673 .27174 Mdot
.44301 .59861 Mdot
.17639 .48694 Mdot
.99617 .42414 Mdot
.69613 .0882 Mdot
.19402 .49422 Mdot
.08872 .22847 Mdot
.16658 .24959 Mdot
.97356 .41429 Mdot
.96957 .19441 Mdot
.1602 .24777 Mdot
.25148 .27311 Mdot
.09455 .45914 Mdot
.79362 .12435 Mdot
.07053 .2255 Mdot
.00594 .21271 Mdot
.60889 .0514 Mdot
.59383 .04618 Mdot
.67953 .07949 Mdot
.51518 .01092 Mdot
.52894 .01455 Mdot
.11606 .25017 Mdot
.46241 .60264 Mdot
.92764 .17525 Mdot
.56357 .03227 Mdot
.32082 .55266 Mdot
.67531 .07611 Mdot
.93092 .18547 Mdot
.23687 .51682 Mdot
.11802 .46545 Mdot
.79793 .12518 Mdot
.14636 .25561 Mdot
.43202 .59915 Mdot
.23501 .51729 Mdot
.13481 .25512 Mdot
.52224 .01512 Mdot
.39931 .57931 Mdot
.37069 .57113 Mdot
.9512 .18175 Mdot
.04686 .22459 Mdot
.90409 .16787 Mdot
.74308 .10567 Mdot
.94964 .4049 Mdot
.09352 .23925 Mdot
.03848 .2132 Mdot
.05718 .23028 Mdot
.07293 .44804 Mdot
.32432 .54781 Mdot
.17989 .26532 Mdot
.14318 .47904 Mdot
.27671 .27351 Mdot
.69019 .08751 Mdot
.40319 .58241 Mdot
.10722 .23773 Mdot
.28792 .53392 Mdot
.21364 .50712 Mdot
.4371 .59417 Mdot
.76171 .11604 Mdot
.15439 .47706 Mdot
.1943 .49732 Mdot
.50508 .00402 Mdot
.24428 .52181 Mdot
.59639 .04391 Mdot
.78792 .11917 Mdot
.35424 .56613 Mdot
.14781 .25409 Mdot
.17118 .25595 Mdot
.80012 .12382 Mdot
.62456 .05431 Mdot
.2068 .49989 Mdot
.22697 .50713 Mdot
.20139 .50392 Mdot
.22111 .27611 Mdot
.29051 .27443 Mdot
.53479 .02041 Mdot
.57547 .04001 Mdot
.34774 .56189 Mdot
.5748 .03325 Mdot
.28293 .53033 Mdot
.98624 .19632 Mdot
.89673 .16125 Mdot
.96338 .19729 Mdot
.84541 .15043 Mdot
.55134 .02286 Mdot
.07582 .2356 Mdot
.5996 .04389 Mdot
.33921 .55329 Mdot
.19193 .49518 Mdot
.17284 .48938 Mdot
.8539 .14655 Mdot
.0581 .22139 Mdot
.264 .27953 Mdot
.01497 .42838 Mdot
.26709 .52172 Mdot
.77436 .1179 Mdot
.21714 .27322 Mdot
.17274 .25854 Mdot
.53133 .01938 Mdot
.71608 .09345 Mdot
.1192 .46639 Mdot
.71882 .09954 Mdot
.48772 .61423 Mdot
.84234 .14691 Mdot
.65333 .06566 Mdot
.6371 .06061 Mdot
.14246 .47349 Mdot
.26844 .27768 Mdot
.40883 .58243 Mdot
.02195 .43158 Mdot
.08644 .45837 Mdot
.90642 .17574 Mdot
.10215 .23545 Mdot
.99945 .42053 Mdot
.45106 .59923 Mdot
.76493 .11447 Mdot
.25396 .2803 Mdot
.95715 .40755 Mdot
.0439 .22518 Mdot
.05347 .4412 Mdot
.41888 .58992 Mdot
.23132 .51693 Mdot
.54203 .02714 Mdot
.94408 .19025 Mdot
.59987 .04826 Mdot
.76125 .11702 Mdot
.20689 .2622 Mdot
.13556 .24596 Mdot
.12116 .46969 Mdot
.05584 .22087 Mdot
.67278 .07832 Mdot
.84543 .14219 Mdot
.03592 .43274 Mdot
.80096 .12571 Mdot
.04935 .21552 Mdot
.04478 .43799 Mdot
.68389 .08039 Mdot
.89582 .16473 Mdot
.934 .18567 Mdot
.19146 .26936 Mdot
.60437 .04737 Mdot
.23424 .26911 Mdot
.13105 .47653 Mdot
.34941 .5612 Mdot
.19366 .2648 Mdot
.7987 .12772 Mdot
.24006 .26864 Mdot
.54354 .02044 Mdot
.54254 .02016 Mdot
.17946 .2661 Mdot
.13914 .24602 Mdot
.29869 .27494 Mdot
.81449 .1396 Mdot
.00227 .42498 Mdot
.47048 .60785 Mdot
.14717 .25479 Mdot
.79084 .12555 Mdot
.20455 .4993 Mdot
.96113 .19604 Mdot
.89229 .16014 Mdot
.20133 .50228 Mdot
.13571 .24106 Mdot
.1862 .49224 Mdot
.14749 .24432 Mdot
.99111 .19986 Mdot
.26406 .27628 Mdot
.29879 .53539 Mdot
.05168 .43966 Mdot
.09873 .23869 Mdot
.25297 .27624 Mdot
.35564 .56452 Mdot
.32718 .55437 Mdot
.97904 .41279 Mdot
.30637 .54429 Mdot
.21953 .26943 Mdot
.26511 .52566 Mdot
.14634 .47786 Mdot
.40645 .58496 Mdot
.02854 .21217 Mdot
.15871 .48355 Mdot
.10967 .46831 Mdot
.3238 .55078 Mdot
.93594 .1764 Mdot
.18648 .49814 Mdot
.78909 .11963 Mdot
.04432 .21497 Mdot
.00844 .20574 Mdot
.98239 .20081 Mdot
.04254 .22567 Mdot
.34441 .55347 Mdot
.14732 .25337 Mdot
.36605 .56772 Mdot
.20444 .27179 Mdot
.22931 .51685 Mdot
.17166 .4935 Mdot
.14821 .24424 Mdot
.59898 .04949 Mdot
.99055 .417 Mdot
.80075 .12945 Mdot
.59166 .04213 Mdot
.20586 .26456 Mdot
.04172 .4391 Mdot
.30134 .54548 Mdot
.16999 .26195 Mdot
.19438 .49258 Mdot
.14709 .25689 Mdot
.21651 .50276 Mdot
.11675 .24558 Mdot
.14752 .24735 Mdot
.98626 .20195 Mdot
.63832 .06552 Mdot
.17859 .48851 Mdot
.50488 .00399 Mdot
.34382 .56174 Mdot
.37336 .56756 Mdot
.30036 .53569 Mdot
.9964 .42142 Mdot
.72578 .09603 Mdot
.94434 .17941 Mdot
.10701 .24098 Mdot
.19989 .26649 Mdot
.34227 .56182 Mdot
.87395 .16274 Mdot
.22344 .26951 Mdot
.15279 .48431 Mdot
.14422 .25606 Mdot
.97206 .19484 Mdot
.68475 .08447 Mdot
.8101 .13043 Mdot
.12026 .24438 Mdot
.0355 .21345 Mdot
.21321 .51078 Mdot
.20688 .26216 Mdot
.03548 .21084 Mdot
.68065 .08095 Mdot
.17882 .25403 Mdot
.71805 .09922 Mdot
.27177 .5286 Mdot
.9503 .18602 Mdot
.14737 .25519 Mdot
.97673 .41392 Mdot
.14654 .24453 Mdot
.48025 .00069 Mdot
.13632 .24267 Mdot
.33169 .55215 Mdot
.98183 .41621 Mdot
.18658 .26655 Mdot
.24573 .52189 Mdot
.76148 .11814 Mdot
.11381 .23903 Mdot
.00779 .209 Mdot
.14985 .48172 Mdot
.8747 .15781 Mdot
.11374 .46561 Mdot
.56193 .03089 Mdot
.0968 .4565 Mdot
.02166 .42835 Mdot
.33064 .55773 Mdot
.32036 .54575 Mdot
.93635 .40177 Mdot
.11826 .23916 Mdot
.29777 .54251 Mdot
.34529 .56056 Mdot
.98424 .41769 Mdot
.71627 .09243 Mdot
.25421 .27514 Mdot
.31597 .54903 Mdot
.09524 .239 Mdot
.11996 .47114 Mdot
.97987 .20009 Mdot
.98225 .19758 Mdot
.90269 .16939 Mdot
.99578 .19868 Mdot
.78367 .12425 Mdot
.84999 .14795 Mdot
.6192 .05428 Mdot
.96598 .4109 Mdot
.79112 .12672 Mdot
.13223 .24553 Mdot
.17674 .26696 Mdot
.18423 .26469 Mdot
.07067 .44875 Mdot
.0879 .45588 Mdot
.78447 .12581 Mdot
.26748 .5243 Mdot
.12545 .23801 Mdot
.03801 .22299 Mdot
.7946 .12835 Mdot
.92345 .17926 Mdot
.1218 .23512 Mdot
.92856 .17623 Mdot
.13675 .47009 Mdot
.16093 .25353 Mdot
.26092 .52664 Mdot
.95721 .18475 Mdot
.07779 .23736 Mdot
.87398 .16184 Mdot
.07499 .23473 Mdot
.25375 .28005 Mdot
.10324 .45851 Mdot
.27863 .52934 Mdot
.0998 .45696 Mdot
.5856 .03634 Mdot
.09908 .23038 Mdot
.93815 .18364 Mdot
.05445 .22159 Mdot
.12243 .24398 Mdot
.16072 .48393 Mdot
.49793 .00537 Mdot
.67951 .08105 Mdot
.69791 .08882 Mdot
.34218 .55723 Mdot
.17699 .48916 Mdot
.05725 .4448 Mdot
.83075 .13891 Mdot
.08879 .45519 Mdot
.26317 .27061 Mdot
.6089 .05473 Mdot
.0975 .45745 Mdot
.22149 .50862 Mdot
.13589 .24936 Mdot
.12147 .25035 Mdot
.70192 .09314 Mdot
.60424 .04723 Mdot
.2865 .53538 Mdot
.75125 .11418 Mdot
.70347 .08755 Mdot
.43872 .59917 Mdot
.8195 .13762 Mdot
.25167 .27236 Mdot
.49504 .00136 Mdot
.99337 .1993 Mdot
.91267 .17626 Mdot
.04233 .4391 Mdot
.38442 .57825 Mdot
.02221 .21912 Mdot
.17696 .25204 Mdot
.46461 .61269 Mdot
.80883 .13738 Mdot
.14346 .24538 Mdot
.13094 .24458 Mdot
.22437 .26479 Mdot
.49198 .61498 Mdot
.17116 .48645 Mdot
.12141 .23959 Mdot
.33507 .55914 Mdot
.98141 .19737 Mdot
.92533 .1835 Mdot
.89731 .16298 Mdot
.22239 .50356 Mdot
.26111 .5206 Mdot
.61066 .05344 Mdot
.68598 .08497 Mdot
.41615 .58504 Mdot
.2346 .2714 Mdot
.42068 .59382 Mdot
.0255 .43524 Mdot
.26899 .53243 Mdot
.20354 .49666 Mdot
.96197 .19709 Mdot
.93901 .18825 Mdot
.50649 .01185 Mdot
.43852 .60005 Mdot
.07083 .22434 Mdot
.96974 .18831 Mdot
.88255 .16685 Mdot
.11907 .23969 Mdot
.2195 .50301 Mdot
.23171 .27331 Mdot
.13836 .47167 Mdot
.95595 .19216 Mdot
.80789 .1285 Mdot
.20335 .50465 Mdot
.46198 .60422 Mdot
.23135 .27795 Mdot
.56989 .02943 Mdot
.18495 .49981 Mdot
.93087 .3981 Mdot
.1936 .49954 Mdot
.17348 .26579 Mdot
.41304 .59021 Mdot
.89921 .17169 Mdot
.69258 .08143 Mdot
.19477 .26451 Mdot
.67067 .07448 Mdot
.6354 .06092 Mdot
.91195 .17104 Mdot
.17045 .25456 Mdot
.92218 .17525 Mdot
.12364 .24281 Mdot
.91236 .17523 Mdot
.12651 .47094 Mdot
.67238 .07998 Mdot
.8534 .15128 Mdot
.13761 .25196 Mdot
.10585 .2465 Mdot
.31188 .54339 Mdot
.28754 .53472 Mdot
.64236 .05955 Mdot
.2215 .50351 Mdot
.2003 .26475 Mdot
.65875 .07256 Mdot
.60303 .0522 Mdot
.30204 .53785 Mdot
.08815 .22798 Mdot
.05797 .22648 Mdot
.13206 .47269 Mdot
.13297 .47636 Mdot
.0007 .1994 Mdot
.01607 .20666 Mdot
.16412 .48064 Mdot
.59399 .04071 Mdot
.45298 .60215 Mdot
.12302 .47034 Mdot
.06056 .44694 Mdot
.00276 .20333 Mdot
.10791 .4627 Mdot
.12824 .4746 Mdot
.17062 .4938 Mdot
.11592 .23327 Mdot
.34149 .56089 Mdot
.34491 .56154 Mdot
.23466 .2744 Mdot
.97749 .19919 Mdot
.72559 .09816 Mdot
.65759 .06733 Mdot
.86593 .16045 Mdot
.16645 .26264 Mdot
.53605 .02144 Mdot
.91542 .17071 Mdot
.56422 .03393 Mdot
.92057 .17264 Mdot
.39038 .58076 Mdot
.75821 .11098 Mdot
.2112 .49903 Mdot
.22595 .27076 Mdot
.08317 .2339 Mdot
.51151 .01034 Mdot
.43674 .59708 Mdot
.89235 .16748 Mdot
.27892 .27656 Mdot
.12334 .24433 Mdot
.75086 .10568 Mdot
.06642 .44674 Mdot
.52027 .01151 Mdot
.92514 .18221 Mdot
.08946 .45541 Mdot
.76977 .11301 Mdot
.57372 .03792 Mdot
.41439 .58777 Mdot
.96277 .40999 Mdot
.10977 .24678 Mdot
.03053 .43378 Mdot
.11486 .24025 Mdot
.48263 .61162 Mdot
.91169 .16811 Mdot
.15582 .48622 Mdot
.16332 .48248 Mdot
.17088 .25551 Mdot
.63812 .05845 Mdot
.893 .16821 Mdot
.3768 .57168 Mdot
.76688 .11621 Mdot
.85818 .15357 Mdot
.53282 .01666 Mdot
.89175 .16232 Mdot
.15296 .24622 Mdot
.11299 .23545 Mdot
.18018 .25662 Mdot
.1435 .2574 Mdot
.21304 .51061 Mdot
.34983 .56394 Mdot
.53494 .01686 Mdot
.1168 .23972 Mdot
.22735 .26889 Mdot
.51513 .01292 Mdot
.64973 .06599 Mdot
.8594 .15172 Mdot
.6001 .04325 Mdot
.88159 .15867 Mdot
.91219 .17526 Mdot
.16872 .25245 Mdot
.89108 .16746 Mdot
.07303 .22987 Mdot
.13705 .47572 Mdot
.08298 .22769 Mdot
.34726 .56283 Mdot
.81163 .13355 Mdot
.93155 .17998 Mdot
.09565 .22932 Mdot
.12011 .46719 Mdot
.4679 .61228 Mdot
.83571 .1445 Mdot
.39592 .57884 Mdot
.28669 .27443 Mdot
.91594 .17923 Mdot
.13008 .24429 Mdot
.98464 .20286 Mdot
.01824 .21225 Mdot
.00505 .42491 Mdot
.94271 .40223 Mdot
.03834 .43535 Mdot
.22731 .27092 Mdot
.10351 .23709 Mdot
.3297 .54822 Mdot
.93934 .18839 Mdot
.39007 .5743 Mdot
.89527 .38795 Mdot
.81606 .13889 Mdot
.42692 .59009 Mdot
.98126 .1959 Mdot
.23357 .50809 Mdot
.89245 .16218 Mdot
.39842 .58394 Mdot
.07814 .23102 Mdot
.45518 .60367 Mdot
.56088 .02898 Mdot
.09341 .23611 Mdot
.98183 .41559 Mdot
.07601 .23049 Mdot
.76299 .1119 Mdot
.45807 .60258 Mdot
.96509 .18642 Mdot
.02359 .43043 Mdot
.26684 .52971 Mdot
.12982 .24358 Mdot
.35981 .56256 Mdot
.93139 .18477 Mdot
.25131 .27847 Mdot
.99398 .20166 Mdot
.17545 .26326 Mdot
.2745 .2768 Mdot
.28642 .5345 Mdot
.8352 .14489 Mdot
.53513 .01945 Mdot
.61221 .05159 Mdot
.43859 .59923 Mdot
.62416 .05317 Mdot
.17404 .25454 Mdot
.17141 .25033 Mdot
.06822 .44979 Mdot
.47357 .61523 Mdot
.38782 .57766 Mdot
.58844 .04618 Mdot
.94391 .404 Mdot
.97219 .19238 Mdot
.9604 .19292 Mdot
.55032 .0286 Mdot
.70144 .09322 Mdot
.10512 .24185 Mdot
.62419 .05723 Mdot
.04055 .21789 Mdot
.34484 .55427 Mdot
.77811 .12067 Mdot
.14073 .47631 Mdot
.34962 .56139 Mdot
.05555 .44288 Mdot
.6012 .04554 Mdot
.7003 .0895 Mdot
.21943 .50821 Mdot
.18014 .49424 Mdot
.6931 .08928 Mdot
.78647 .11947 Mdot
.8483 .14808 Mdot
.19098 .49108 Mdot
.25345 .52609 Mdot
.23673 .51543 Mdot
.06839 .22568 Mdot
.01837 .43017 Mdot
.69806 .09224 Mdot
.9148 .17595 Mdot
.24078 .51549 Mdot
.51626 .00687 Mdot
.11791 .24375 Mdot
.2216 .27396 Mdot
.11822 .46303 Mdot
.9393 .18743 Mdot
.06007 .44217 Mdot
.47164 .60886 Mdot
.55539 .03066 Mdot
.67365 .08196 Mdot
.26134 .27344 Mdot
.97004 .19201 Mdot
.99844 .20257 Mdot
.23367 .51104 Mdot
.25294 .27417 Mdot
.5005 .00411 Mdot
.07833 .23518 Mdot
.12066 .24454 Mdot
.85118 .15084 Mdot
.48557 .61449 Mdot
.45949 .60954 Mdot
.02673 .43273 Mdot
.19298 .49256 Mdot
.64104 .06839 Mdot
.81618 .13798 Mdot
.17986 .49428 Mdot
.97108 .20032 Mdot
.89561 .16403 Mdot
.04474 .21613 Mdot
.20138 .26712 Mdot
.40935 .58551 Mdot
.62123 .05524 Mdot
.14379 .48052 Mdot
.39051 .57418 Mdot
.1002 .23956 Mdot
.98376 .4174 Mdot
.51732 .01544 Mdot
.2164 .26416 Mdot
.11745 .24949 Mdot
.26088 .52156 Mdot
.19011 .26434 Mdot
.5653 .03233 Mdot
.67583 .07475 Mdot
.0932 .22821 Mdot
.72275 .09721 Mdot
.9481 .19059 Mdot
.12817 .25223 Mdot
.79782 .12944 Mdot
.43791 .59231 Mdot
.63305 .05656 Mdot
.89794 .16317 Mdot
.52946 .02051 Mdot
.13182 .24544 Mdot
.11529 .2393 Mdot
.31306 .54295 Mdot
.14167 .2451 Mdot
.15425 .25808 Mdot
.46492 .60748 Mdot
.23125 .51719 Mdot
.19174 .26657 Mdot
.99552 .20869 Mdot
.44896 .60337 Mdot
.20342 .26832 Mdot
.28 .27369 Mdot
.18937 .25593 Mdot
.14081 .47729 Mdot
.80295 .12563 Mdot
.11737 .46498 Mdot
.11046 .23712 Mdot
.17343 .26287 Mdot
.08487 .23106 Mdot
.10022 .2295 Mdot
.3015 .54011 Mdot
.90931 .16979 Mdot
.60533 .05059 Mdot
.9761 .19648 Mdot
.48293 .61407 Mdot
.01605 .21693 Mdot
.91548 .1713 Mdot
.69806 .08965 Mdot
.22144 .27599 Mdot
.03137 .22182 Mdot
.23903 .26833 Mdot
.05967 .23135 Mdot
.90546 .16654 Mdot
.22419 .26651 Mdot
.47384 .6118 Mdot
.18516 .48971 Mdot
.12237 .238 Mdot
.79622 .12362 Mdot
.47211 .61516 Mdot
.26293 .52398 Mdot
.75193 .11376 Mdot
.85347 .14995 Mdot
.52883 .01499 Mdot
.21689 .26507 Mdot
.85323 .14606 Mdot
.29982 .27468 Mdot
.54389 .02456 Mdot
.13153 .25304 Mdot
.55304 .02686 Mdot
.18828 .49803 Mdot
.24873 .52018 Mdot
.08065 .22923 Mdot
.08823 .23679 Mdot
.45878 .60895 Mdot
.37011 .56722 Mdot
.2927 .53467 Mdot
.76531 .11195 Mdot
.30914 .54166 Mdot
.37827 .57282 Mdot
.76049 .11228 Mdot
.02239 .20716 Mdot
.75424 .11252 Mdot
.97199 .19523 Mdot
.84407 .14533 Mdot
.26005 .27581 Mdot
.54858 .02567 Mdot
.87479 .15854 Mdot
.04692 .43977 Mdot
.18513 .2538 Mdot
.2092 .27394 Mdot
.0867 .23735 Mdot
.34423 .55852 Mdot
.18136 .26119 Mdot
.15371 .25849 Mdot
.09627 .45585 Mdot
.17047 .48771 Mdot
.23436 .51121 Mdot
.16316 .26181 Mdot
.98868 .20479 Mdot
.98757 .2021 Mdot
.8878 .1635 Mdot
.18051 .26067 Mdot
.22419 .27145 Mdot
.72762 .09526 Mdot
.93384 .40072 Mdot
.06391 .223 Mdot
.23916 .27901 Mdot
.08133 .23699 Mdot
.92903 .18178 Mdot
.27129 .27819 Mdot
.28639 .27629 Mdot
.26628 .52452 Mdot
.44175 .59786 Mdot
.60724 .05166 Mdot
.69867 .08919 Mdot
.074 .23198 Mdot
.61002 .05105 Mdot
.13611 .24574 Mdot
.84367 .14658 Mdot
.27672 .5313 Mdot
.27475 .27329 Mdot
.40299 .58377 Mdot
.17133 .49349 Mdot
.97194 .41516 Mdot
.92823 .17838 Mdot
.92975 .18076 Mdot
.4069 .58687 Mdot
.25558 .27956 Mdot
.00735 .20462 Mdot
.23771 .26722 Mdot
.36331 .56836 Mdot
.92706 .17277 Mdot
.45815 .60955 Mdot
.7085 .09046 Mdot
.09015 .45242 Mdot
.56894 .02951 Mdot
.78909 .1255 Mdot
.15758 .25256 Mdot
.54202 .02538 Mdot
.03494 .43871 Mdot
.74621 .10759 Mdot
.19175 .50162 Mdot
.54225 .0255 Mdot
.46238 .61094 Mdot
.26067 .52837 Mdot
.98073 .19848 Mdot
.23363 .27432 Mdot
.19882 .49879 Mdot
.38391 .57196 Mdot
.56593 .03695 Mdot
.05415 .44451 Mdot
.3397 .55594 Mdot
.91347 .17784 Mdot
.33988 .55697 Mdot
.14046 .47195 Mdot
.08883 .4602 Mdot
.07392 .4483 Mdot
.28081 .52874 Mdot
.27967 .53014 Mdot
.2632 .52762 Mdot
.06516 .22103 Mdot
.19944 .26735 Mdot
.17133 .25958 Mdot
.76044 .11075 Mdot
.53566 .02237 Mdot
.57898 .04 Mdot
.17852 .4939 Mdot
.28675 .5299 Mdot
.19335 .26033 Mdot
.19504 .5025 Mdot
.82815 .13643 Mdot
.07913 .22595 Mdot
.91898 .17018 Mdot
.02994 .43535 Mdot
.16211 .2519 Mdot
.46392 .60387 Mdot
.91563 .17556 Mdot
.08188 .45358 Mdot
.92112 .18113 Mdot
.97895 .19556 Mdot
.81864 .13552 Mdot
.97581 .196 Mdot
.12563 .24089 Mdot
.03656 .21511 Mdot
.07833 .45019 Mdot
.16794 .26373 Mdot
.40939 .58829 Mdot
.55936 .03277 Mdot
.7352 .09968 Mdot
.26404 .52488 Mdot
.01786 .42979 Mdot
.50351 .00261 Mdot
.80352 .13413 Mdot
.0957 .2393 Mdot
.81476 .13589 Mdot
.17152 .25315 Mdot
.51454 .00981 Mdot
.21834 .50649 Mdot
.27118 .52899 Mdot
.17686 .25978 Mdot
.78569 .12164 Mdot
.80054 .12561 Mdot
.57439 .03177 Mdot
.07194 .44572 Mdot
.99243 .41998 Mdot
.54448 .02227 Mdot
.77634 .12036 Mdot
.46798 .60483 Mdot
.04806 .4392 Mdot
.41618 .58867 Mdot
.21638 .26717 Mdot
.76712 .12036 Mdot
.36491 .5645 Mdot
.13078 .25178 Mdot
.00475 .20319 Mdot
.90874 .1745 Mdot
.85774 .14655 Mdot
.14118 .4757 Mdot
.25446 .52077 Mdot
.89423 .16438 Mdot
.03577 .43497 Mdot
.64775 .06915 Mdot
.25551 .52279 Mdot
.26807 .27373 Mdot
.06473 .22379 Mdot
.09403 .45336 Mdot
.92922 .39805 Mdot
.81775 .13332 Mdot
.22033 .50293 Mdot
.85414 .15443 Mdot
.15344 .48328 Mdot
.1157 .24279 Mdot
.19811 .25834 Mdot
.71943 .09862 Mdot
.17672 .26396 Mdot
.83563 .14784 Mdot
.21611 .26434 Mdot
.51167 .01404 Mdot
.17885 .25726 Mdot
.92951 .1818 Mdot
.85575 .15045 Mdot
.25834 .52676 Mdot
.88596 .16651 Mdot
.29097 .53431 Mdot
.75718 .11094 Mdot
.13529 .2488 Mdot
.06492 .22883 Mdot
.55886 .03051 Mdot
.93095 .17489 Mdot
.22154 .51034 Mdot
.16199 .25607 Mdot
.91838 .18058 Mdot
.18021 .48824 Mdot
.42959 .58993 Mdot
.92712 .17644 Mdot
.30751 .54659 Mdot
.35311 .5657 Mdot
.31256 .54278 Mdot
.47847 .6116 Mdot
.22232 .2683 Mdot
.7781 .11692 Mdot
.21646 .27562 Mdot
.08794 .23591 Mdot
.19391 .49231 Mdot
.73207 .10084 Mdot
.23337 .2755 Mdot
.99566 .19881 Mdot
.86085 .14815 Mdot
.84438 .14387 Mdot
.71677 .09786 Mdot
.52996 .02203 Mdot
.54924 .02177 Mdot
.98036 .20179 Mdot
.83588 .13917 Mdot
.03978 .21437 Mdot
.39582 .57542 Mdot
.52853 .01901 Mdot
.64288 .06163 Mdot
.74469 .10752 Mdot
.98467 .19522 Mdot
.07485 .22803 Mdot
.46436 .60664 Mdot
.77721 .1184 Mdot
.08591 .2296 Mdot
.2251 .26644 Mdot
.09828 .45641 Mdot
.11289 .46536 Mdot
.91088 .16683 Mdot
.12902 .24901 Mdot
.4497 .60497 Mdot
.22592 .50545 Mdot
.68129 .08209 Mdot
.74384 .10826 Mdot
.01881 .43036 Mdot
.11671 .2399 Mdot
.07 .44516 Mdot
.23558 .27201 Mdot
.29473 .27459 Mdot
.04958 .22003 Mdot
.4486 .60545 Mdot
.09536 .46267 Mdot
.12256 .23678 Mdot
.0324 .21811 Mdot
.73161 .10038 Mdot
.49118 .00514 Mdot
.51633 .00799 Mdot
.52379 .01545 Mdot
.22243 .50404 Mdot
.74493 .10979 Mdot
.25458 .51763 Mdot
.88113 .16062 Mdot
.01904 .42909 Mdot
.97952 .20143 Mdot
.01721 .42713 Mdot
.08869 .22897 Mdot
.89517 .16857 Mdot
.84444 .1439 Mdot
.15804 .48455 Mdot
.48313 .61751 Mdot
.09209 .23575 Mdot
.22513 .27369 Mdot
.66135 .07105 Mdot
.26515 .5247 Mdot
.43769 .59364 Mdot
.91341 .17462 Mdot
.21996 .50299 Mdot
.97094 .19417 Mdot
.95565 .18756 Mdot
.9714 .41316 Mdot
.98048 .2019 Mdot
.03088 .21621 Mdot
.03565 .21445 Mdot
.18734 .26291 Mdot
.59034 .04644 Mdot
.81632 .13303 Mdot
.21849 .26944 Mdot
.09921 .46377 Mdot
.91932 .17754 Mdot
.30687 .53987 Mdot
.10788 .23684 Mdot
.16839 .48214 Mdot
.3596 .56452 Mdot
.7529 .10983 Mdot
.52372 .01211 Mdot
.04157 .22415 Mdot
.11733 .46615 Mdot
.06456 .44998 Mdot
.35561 .56388 Mdot
.29106 .27383 Mdot
.04806 .22778 Mdot
.02369 .21594 Mdot
.07598 .23277 Mdot
.6477 .06809 Mdot
.5228 .01079 Mdot
.06904 .22324 Mdot
.18981 .50081 Mdot
.22926 .50961 Mdot
.17577 .25862 Mdot
.37498 .57343 Mdot
.07148 .23593 Mdot
.41728 .59193 Mdot
.89802 .38869 Mdot
.60981 .04761 Mdot
.30713 .54164 Mdot
.14461 .47872 Mdot
.99825 .20131 Mdot
.2304 .51032 Mdot
.00138 .20372 Mdot
.12055 .23485 Mdot
.2144 .2702 Mdot
.99959 .20193 Mdot
.42541 .59483 Mdot
.78274 .12091 Mdot
.39406 .58163 Mdot
.98995 .4195 Mdot
.17822 .25566 Mdot
.24052 .27099 Mdot
.07642 .44887 Mdot
.9626 .19002 Mdot
.67429 .08064 Mdot
.96154 .18935 Mdot
.54022 .01723 Mdot
.09582 .22943 Mdot
.27322 .52625 Mdot
.57735 .03884 Mdot
.07973 .45357 Mdot
.40005 .58068 Mdot
.00391 .42116 Mdot
.60118 .04948 Mdot
.27746 .27458 Mdot
.85943 .15128 Mdot
.64915 .06255 Mdot
.05473 .21706 Mdot
.28308 .53854 Mdot
.28932 .27788 Mdot
.14596 .25531 Mdot
.76597 .11316 Mdot
.93398 .17918 Mdot
.52202 .01745 Mdot
.74691 .10553 Mdot
.08253 .2263 Mdot
.83491 .14245 Mdot
.46692 .61117 Mdot
.01049 .42946 Mdot
.5899 .04404 Mdot
.17906 .2563 Mdot
.66045 .07364 Mdot
.26006 .52569 Mdot
.07594 .22885 Mdot
.55148 .02477 Mdot
.78406 .1228 Mdot
.00657 .20098 Mdot
.85708 .15075 Mdot
.37848 .57279 Mdot
.55368 .02921 Mdot
.19317 .4931 Mdot
.10271 .23053 Mdot
.51421 .01261 Mdot
.71931 .09453 Mdot
.04469 .43551 Mdot
.14535 .25847 Mdot
.06892 .23117 Mdot
.2077 .50217 Mdot
.18001 .26149 Mdot
.59096 .03808 Mdot
.68856 .07955 Mdot
.20123 .49822 Mdot
.65846 .07565 Mdot
.23275 .5104 Mdot
.97263 .41499 Mdot
.10888 .24735 Mdot
.06237 .22277 Mdot
.29133 .27698 Mdot
.18398 .49462 Mdot
.08586 .23434 Mdot
.51295 .01425 Mdot
.31487 .54642 Mdot
.03922 .22292 Mdot
.95685 .40922 Mdot
.58183 .0422 Mdot
.1823 .26793 Mdot
.4374 .59708 Mdot
.95099 .40414 Mdot
.56154 .0284 Mdot
.98927 .41692 Mdot
.55373 .02919 Mdot
.4381 .59722 Mdot
.21976 .51101 Mdot
.29964 .54513 Mdot
.78588 .12811 Mdot
.18959 .49892 Mdot
.00672 .42405 Mdot
.52746 .01915 Mdot
.1015 .2402 Mdot
.40278 .5849 Mdot
.36107 .56338 Mdot
.23231 .51492 Mdot
.23962 .26883 Mdot
.99178 .198 Mdot
.23558 .27481 Mdot
.89236 .1617 Mdot
.80494 .13477 Mdot
.88951 .1634 Mdot
.60178 .04953 Mdot
.52985 .01857 Mdot
.67959 .07589 Mdot
.29763 .54302 Mdot
.4719 .61378 Mdot
.1593 .24663 Mdot
.25116 .51637 Mdot
.06413 .44234 Mdot
.48145 .61297 Mdot
.79573 .13051 Mdot
.17946 .25569 Mdot
.07828 .22976 Mdot
.89148 .16703 Mdot
.77866 .123 Mdot
.23661 .26662 Mdot
.6515 .0719 Mdot
.09663 .24159 Mdot
.58211 .04123 Mdot
.66006 .0732 Mdot
.29788 .54136 Mdot
.99787 .42454 Mdot
.09742 .2432 Mdot
.265 .53109 Mdot
.1464 .25037 Mdot
.60054 .04483 Mdot
.6454 .06775 Mdot
.78795 .1263 Mdot
.18299 .49735 Mdot
.17488 .26542 Mdot
.82019 .13292 Mdot
.37613 .56885 Mdot
.69313 .08442 Mdot
.616 .057 Mdot
.10956 .24108 Mdot
.52879 .02081 Mdot
.08481 .2256 Mdot
.10465 .24122 Mdot
.70138 .08677 Mdot
.55364 .03112 Mdot
.70704 .09074 Mdot
.91717 .18024 Mdot
.0667 .22545 Mdot
.30128 .54282 Mdot
.603 .05215 Mdot
.19895 .26894 Mdot
.6619 .0716 Mdot
.95892 .19556 Mdot
.73039 .09952 Mdot
.0063 .20495 Mdot
.13726 .24002 Mdot
.65483 .06861 Mdot
.73778 .10483 Mdot
.20027 .25967 Mdot
.84963 .14611 Mdot
.14889 .2552 Mdot
.40988 .58352 Mdot
.27907 .27547 Mdot
.23196 .27577 Mdot
.75645 .11583 Mdot
.43404 .59546 Mdot
.94471 .18682 Mdot
.40418 .5822 Mdot
.08493 .45276 Mdot
.19337 .26741 Mdot
.33517 .55739 Mdot
.23529 .51448 Mdot
.32728 .54681 Mdot
.01842 .20789 Mdot
.41945 .58622 Mdot
.16336 .25064 Mdot
.16686 .2496 Mdot
.00736 .21172 Mdot
.52755 .01734 Mdot
.37554 .56968 Mdot
.22531 .50861 Mdot
.70967 .09264 Mdot
.09214 .46018 Mdot
.22905 .50604 Mdot
.95073 .18759 Mdot
.82426 .14151 Mdot
.29517 .53617 Mdot
.76558 .11455 Mdot
.21964 .50309 Mdot
.21142 .26679 Mdot
.18776 .25872 Mdot
.76222 .11146 Mdot
.87107 .15252 Mdot
.2281 .51372 Mdot
.9689 .19415 Mdot
.14025 .25324 Mdot
.21291 .51082 Mdot
.57076 .03887 Mdot
.07834 .23393 Mdot
.01837 .2117 Mdot
.67009 .07667 Mdot
.19246 .26788 Mdot
.56863 .02983 Mdot
.31772 .54785 Mdot
.91676 .16899 Mdot
.2748 .53333 Mdot
.13182 .47392 Mdot
.27757 .52662 Mdot
.11463 .46762 Mdot
.95272 .40627 Mdot
.6081 .05348 Mdot
.47373 .6131 Mdot
.09892 .23375 Mdot
.80821 .13512 Mdot
.36872 .56472 Mdot
.24172 .51345 Mdot
.68898 .07994 Mdot
.15365 .48072 Mdot
.74257 .10675 Mdot
.04967 .21934 Mdot
.40443 .57891 Mdot
.9596 .18658 Mdot
.01436 .42772 Mdot
.67441 .078 Mdot
.4344 .60001 Mdot
.26162 .27272 Mdot
.18257 .26493 Mdot
.00223 .20658 Mdot
.37414 .57221 Mdot
.64929 .06372 Mdot
.87374 .1532 Mdot
.12245 .25009 Mdot
.63887 .06749 Mdot
.23861 .26984 Mdot
.42569 .59432 Mdot
.541 .0184 Mdot
.18134 .49621 Mdot
.67928 .07829 Mdot
.50628 .01221 Mdot
.17994 .26473 Mdot
.96733 .41377 Mdot
.40631 .58552 Mdot
.24722 .51596 Mdot
.86519 .15837 Mdot
.1417 .24488 Mdot
.65988 .06823 Mdot
.97913 .19801 Mdot
.94567 .40245 Mdot
.98642 .20321 Mdot
.84798 .14976 Mdot
.66743 .07697 Mdot
.12745 .25144 Mdot
.53466 .01855 Mdot
.55109 .02293 Mdot
.06859 .44612 Mdot
.17705 .25346 Mdot
.43054 .59786 Mdot
.43267 .5915 Mdot
.67793 .07793 Mdot
.3157 .54271 Mdot
.18472 .26244 Mdot
.06854 .22796 Mdot
.81994 .14139 Mdot
.1182 .47038 Mdot
.0784 .45412 Mdot
.78287 .12176 Mdot
.13303 .24407 Mdot
.69324 .08187 Mdot
.95734 .189 Mdot
.41834 .59355 Mdot
.0765 .44736 Mdot
.20082 .2693 Mdot
.38517 .57378 Mdot
.02456 .43316 Mdot
.12745 .24475 Mdot
.26531 .27094 Mdot
.2076 .2728 Mdot
.51406 .00825 Mdot
.19589 .26319 Mdot
.02144 .2071 Mdot
.14063 .47313 Mdot
.81759 .13193 Mdot
.92642 .3985 Mdot
.06632 .22433 Mdot
.05284 .2268 Mdot
.1948 .26994 Mdot
.05726 .22175 Mdot
.99338 .19896 Mdot
.99783 .42426 Mdot
.67866 .08379 Mdot
.24342 .52004 Mdot
.84969 .15247 Mdot
.19338 .26224 Mdot
.166 .2597 Mdot
.15343 .25128 Mdot
.20506 .26057 Mdot
.34248 .55944 Mdot
.23803 .51525 Mdot
.46998 .60929 Mdot
.44834 .59951 Mdot
.2926 .53219 Mdot
.00322 .42611 Mdot
.22816 .50864 Mdot
.74517 .10682 Mdot
.53281 .02042 Mdot
.07031 .23301 Mdot
.50476 .00432 Mdot
.9519 .18584 Mdot
.3248 .55055 Mdot
.89544 .17001 Mdot
.04174 .21439 Mdot
.21077 .5041 Mdot
.55884 .02567 Mdot
.05082 .43905 Mdot
.49228 .00481 Mdot
.92283 .17825 Mdot
.10466 .23298 Mdot
.24978 .27503 Mdot
.86098 .15737 Mdot
.25456 .52154 Mdot
.28852 .53376 Mdot
.98498 .20214 Mdot
.43365 .59227 Mdot
.55849 .02626 Mdot
.05649 .21832 Mdot
.28769 .53045 Mdot
.79689 .12522 Mdot
.98771 .20026 Mdot
.83364 .13835 Mdot
.11898 .24546 Mdot
.14689 .47627 Mdot
.70583 .08688 Mdot
.26221 .27698 Mdot
.18818 .25829 Mdot
.81842 .13816 Mdot
.54733 .02236 Mdot
.92738 .17963 Mdot
.04562 .43826 Mdot
.97508 .41621 Mdot
.65221 .07083 Mdot
.30314 .53801 Mdot
.70067 .08474 Mdot
.33988 .56099 Mdot
.30328 .27471 Mdot
.09622 .45492 Mdot
.09135 .45931 Mdot
.90746 .16977 Mdot
.75625 .10896 Mdot
.16953 .49178 Mdot
.49732 .61764 Mdot
.04957 .44361 Mdot
.05087 .44176 Mdot
.92442 .17525 Mdot
.56144 .02757 Mdot
.76985 .11526 Mdot
.56681 .02983 Mdot
.43833 .59507 Mdot
.67712 .08017 Mdot
.11363 .24854 Mdot
.0918 .2334 Mdot
.79291 .12196 Mdot
.42025 .58753 Mdot
.94274 .18589 Mdot
.57715 .04165 Mdot
.14289 .24616 Mdot
.15882 .25879 Mdot
.66195 .07694 Mdot
.44819 .60197 Mdot
.24064 .2698 Mdot
.24111 .27738 Mdot
.44638 .60297 Mdot
.06611 .45046 Mdot
.89627 .16849 Mdot
.83842 .14171 Mdot
.09247 .22764 Mdot
.4234 .58886 Mdot
.12639 .47432 Mdot
.82031 .13725 Mdot
.04683 .22467 Mdot
.53215 .02254 Mdot
.86167 .14866 Mdot
.34222 .55234 Mdot
.58459 .03843 Mdot
.48984 6e-05 Mdot
.19143 .26384 Mdot
.88882 .16035 Mdot
.21293 .26671 Mdot
.63547 .06517 Mdot
.25207 .27839 Mdot
.02059 .2106 Mdot
.13998 .47311 Mdot
.69483 .08529 Mdot
.5066 .00391 Mdot
.121 .46859 Mdot
.12769 .47609 Mdot
.16426 .26364 Mdot
.03441 .43335 Mdot
.15042 .48431 Mdot
.26387 .52525 Mdot
.08676 .23997 Mdot
.45342 .60388 Mdot
.18091 .25878 Mdot
.1053 .46199 Mdot
.38395 .57057 Mdot
.82009 .13416 Mdot
.45011 .60383 Mdot
.89004 .1637 Mdot
.84444 .14897 Mdot
.65689 .06837 Mdot
.88606 .1677 Mdot
.5539 .03037 Mdot
.96594 .18714 Mdot
.17614 .25161 Mdot
.18056 .25824 Mdot
.23781 .27627 Mdot
.69616 .08563 Mdot
.35829 .56554 Mdot
.40177 .58405 Mdot
.7131 .09083 Mdot
.1365 .25662 Mdot
.23747 .51966 Mdot
.09416 .45413 Mdot
.89892 .16341 Mdot
.32206 .54413 Mdot
.13835 .25482 Mdot
.65775 .07078 Mdot
.24931 .27877 Mdot
.10491 .23249 Mdot
.84361 .14405 Mdot
.95039 .18593 Mdot
.95989 .40742 Mdot
.99196 .42282 Mdot
.9303 .39973 Mdot
.03857 .21613 Mdot
.17331 .4841 Mdot
.51365 .00869 Mdot
.60635 .04604 Mdot
.26214 .27404 Mdot
.808 .12904 Mdot
.1026 .46541 Mdot
.29261 .27409 Mdot
.33405 .55192 Mdot
.25437 .27582 Mdot
.58361 .04379 Mdot
.21976 .26931 Mdot
.74493 .10742 Mdot
.96613 .19539 Mdot
.02821 .43311 Mdot
.15273 .48194 Mdot
.14137 .47697 Mdot
.57358 .03382 Mdot
.2374 .51789 Mdot
.61258 .05092 Mdot
.07318 .22936 Mdot
.78734 .12434 Mdot
.71641 .09549 Mdot
.01373 .21448 Mdot
.29773 .27559 Mdot
.15336 .24485 Mdot
.21925 .26908 Mdot
.18821 .26226 Mdot
.99627 .20041 Mdot
.51349 .0086 Mdot
.95202 .18735 Mdot
.27921 .27655 Mdot
.2638 .28012 Mdot
.52709 .01475 Mdot
.53126 .01715 Mdot
.08007 .23216 Mdot
.56088 .02976 Mdot
.03768 .21632 Mdot
.81745 .13843 Mdot
.2238 .27054 Mdot
.00229 .20616 Mdot
.64923 .06647 Mdot
.91607 .39417 Mdot
.74571 .10716 Mdot
.0205 .4276 Mdot
.01569 .42736 Mdot
.05742 .22684 Mdot
.48012 .61603 Mdot
.29368 .53429 Mdot
.64703 .06417 Mdot
.07434 .22949 Mdot
.88677 .16371 Mdot
.2795 .5366 Mdot
.03572 .43357 Mdot
.22405 .51402 Mdot
.90476 .17112 Mdot
.24982 .27498 Mdot
.7007 .08765 Mdot
.13198 .46989 Mdot
.37776 .57462 Mdot
.25944 .28002 Mdot
.9615 .1911 Mdot
.12263 .47057 Mdot
.26547 .53077 Mdot
.04939 .44485 Mdot
.25796 .27461 Mdot
.23419 .26982 Mdot
.33563 .55173 Mdot
.16797 .49184 Mdot
.17813 .26385 Mdot
.15597 .25615 Mdot
.67803 .07449 Mdot
.23374 .27008 Mdot
.1922 .26146 Mdot
.04146 .21461 Mdot
.1528 .25457 Mdot
.1562 .25461 Mdot
.23099 .27334 Mdot
.25724 .27771 Mdot
.83116 .14236 Mdot
.0375 .21168 Mdot
.11662 .24758 Mdot
.04435 .44031 Mdot
.27552 .53288 Mdot
.22402 .51163 Mdot
.17261 .48583 Mdot
.35735 .56378 Mdot
.56175 .03133 Mdot
.74821 .11235 Mdot
.80118 .13202 Mdot
.51133 .00504 Mdot
.11055 .23499 Mdot
.03626 .22415 Mdot
.1955 .49666 Mdot
.82441 .13965 Mdot
.116 .46916 Mdot
.77648 .12348 Mdot
.09005 .23347 Mdot
.17765 .48972 Mdot
.76623 .11865 Mdot
.03447 .21617 Mdot
.10466 .23193 Mdot
.31778 .54619 Mdot
.18826 .50044 Mdot
.89974 .16728 Mdot
.12601 .24624 Mdot
.25788 .52661 Mdot
.18153 .26749 Mdot
.07882 .2379 Mdot
.20388 .26289 Mdot
.71572 .09522 Mdot
.77963 .12281 Mdot
.87363 .15393 Mdot
.81418 .13592 Mdot
.72606 .10118 Mdot
.81828 .1384 Mdot
.02039 .20975 Mdot
.8448 .14298 Mdot
.95973 .19049 Mdot
.10882 .23537 Mdot
.06304 .44923 Mdot
.24652 .26974 Mdot
.94551 .1912 Mdot
.86748 .16061 Mdot
.19185 .26796 Mdot
.16175 .25053 Mdot
.34808 .55591 Mdot
.65027 .06875 Mdot
.93529 .18532 Mdot
.01236 .20916 Mdot
.11712 .23992 Mdot
.0349 .21393 Mdot
.20765 .26931 Mdot
.14922 .25312 Mdot
.56898 .03652 Mdot
.5477 .02615 Mdot
.89703 .17199 Mdot
.48991 .61682 Mdot
.3085 .54677 Mdot
.25218 .27065 Mdot
.99292 .20895 Mdot
.20862 .50027 Mdot
.01506 .21268 Mdot
.77904 .12515 Mdot
.20027 .27012 Mdot
.77105 .11579 Mdot
.52356 .01068 Mdot
.38195 .57585 Mdot
.1408 .24215 Mdot
.07414 .22859 Mdot
.07078 .2265 Mdot
.17316 .26093 Mdot
.28352 .53159 Mdot
.84066 .14497 Mdot
.89012 .1664 Mdot
.23272 .51318 Mdot
.13106 .25171 Mdot
.70921 .08861 Mdot
.44119 .60032 Mdot
.48286 .61517 Mdot
.41016 .58594 Mdot
.59654 .0408 Mdot
.52359 .01202 Mdot
.93847 .18087 Mdot
.40211 .5859 Mdot
.28439 .53743 Mdot
.75535 .10791 Mdot
.15777 .24956 Mdot
.10963 .23936 Mdot
.33921 .55256 Mdot
.90769 .1736 Mdot
.25726 .27102 Mdot
.25345 .51746 Mdot
.67669 .08012 Mdot
.22354 .27518 Mdot
.94754 .18414 Mdot
.74292 .10112 Mdot
.851 .14898 Mdot
.1777 .49526 Mdot
.80469 .12717 Mdot
.20746 .50189 Mdot
.21378 .49991 Mdot
.93139 .18252 Mdot
.35197 .55917 Mdot
.43748 .5972 Mdot
.19024 .26271 Mdot
.71155 .0941 Mdot
.13931 .47411 Mdot
.12642 .24677 Mdot
.91939 .17933 Mdot
.1387 .25306 Mdot
.20562 .26615 Mdot
.78218 .12004 Mdot
.90218 .17095 Mdot
.24768 .26883 Mdot
.30412 .54034 Mdot
.80649 .12715 Mdot
.62618 .05991 Mdot
.26225 .52437 Mdot
.25493 .52116 Mdot
.7035 .09344 Mdot
.96367 .19367 Mdot
.72364 .09428 Mdot
.16668 .26411 Mdot
.13966 .48055 Mdot
.12827 .46985 Mdot
.9437 .40416 Mdot
.25113 .27793 Mdot
.29148 .53217 Mdot
.59203 .04021 Mdot
.20863 .50462 Mdot
.49777 .00617 Mdot
.09122 .23876 Mdot
.76667 .11146 Mdot
.19768 .49997 Mdot
.07503 .22487 Mdot
.25553 .52506 Mdot
.12733 .25173 Mdot
.16368 .48714 Mdot
.22838 .27604 Mdot
.04847 .22223 Mdot
.5623 .03334 Mdot
.02952 .22104 Mdot
.91481 .39322 Mdot
.07805 .22648 Mdot
.71059 .09653 Mdot
.07613 .23247 Mdot
.80317 .13279 Mdot
.02034 .21685 Mdot
.15753 .26059 Mdot
.66321 .07034 Mdot
.26861 .27927 Mdot
.13316 .25082 Mdot
.70632 .0878 Mdot
.32577 .55353 Mdot
.64263 .06131 Mdot
.41143 .58678 Mdot
.11296 .46384 Mdot
.92847 .18453 Mdot
.93441 .18162 Mdot
.06294 .22084 Mdot
.19548 .26374 Mdot
.63923 .06683 Mdot
.24961 .27006 Mdot
.66766 .07174 Mdot
.54448 .02314 Mdot
.50223 .00479 Mdot
.0795 .2284 Mdot
.26251 .52826 Mdot
.81091 .12807 Mdot
.95647 .19357 Mdot
.07 .45079 Mdot
.04331 .223 Mdot
.33806 .55924 Mdot
.60885 .05334 Mdot
.1054 .4598 Mdot
.11317 .24378 Mdot
.12013 .2472 Mdot
.43748 .59399 Mdot
.16086 .25229 Mdot
.34752 .5585 Mdot
.23644 .51338 Mdot
.00624 .20834 Mdot
.37194 .57386 Mdot
.15257 .48613 Mdot
.90195 .3907 Mdot
.75723 .10699 Mdot
.20882 .27195 Mdot
.12376 .24338 Mdot
.9784 .41517 Mdot
.53307 .01583 Mdot
.28127 .53523 Mdot
.3466 .56217 Mdot
.15567 .24977 Mdot
.55619 .02573 Mdot
.037 .21701 Mdot
.60389 .047 Mdot
.01075 .20711 Mdot
.04277 .21735 Mdot
.18718 .25846 Mdot
.27085 .27689 Mdot
.10085 .23455 Mdot
.75312 .1118 Mdot
.03521 .21768 Mdot
.569 .03741 Mdot
.99744 .19991 Mdot
.15343 .2552 Mdot
.14707 .48245 Mdot
.40771 .58221 Mdot
.31294 .54401 Mdot
.95938 .19613 Mdot
.62617 .06154 Mdot
.69402 .08142 Mdot
.68547 .08341 Mdot
.12285 .46888 Mdot
.8486 .14396 Mdot
.10862 .24042 Mdot
.25613 .27869 Mdot
.28197 .27342 Mdot
.0505 .2181 Mdot
.91752 .17564 Mdot
.94553 .18932 Mdot
.14165 .47861 Mdot
.49573 .00706 Mdot
.67626 .07859 Mdot
.01795 .20857 Mdot
.32072 .54479 Mdot
.01009 .42555 Mdot
.79311 .1276 Mdot
.15245 .47839 Mdot
.86005 .15598 Mdot
.27458 .52478 Mdot
.09516 .23218 Mdot
.95348 .18479 Mdot
.13537 .25033 Mdot
.64616 .06383 Mdot
.30375 .53759 Mdot
.82686 .13432 Mdot
.29995 .27483 Mdot
.00692 .21193 Mdot
.60265 .04613 Mdot
.64585 .06665 Mdot
.20947 .26347 Mdot
.14243 .47851 Mdot
.01906 .43034 Mdot
.38586 .57386 Mdot
.39243 .57953 Mdot
.9638 .18672 Mdot
.18446 .25955 Mdot
.97673 .4127 Mdot
.1929 .26158 Mdot
.54055 .01916 Mdot
.50235 .00313 Mdot
.0994 .46343 Mdot
.76708 .11752 Mdot
.09108 .22806 Mdot
.55219 .0256 Mdot
.94634 .18829 Mdot
.32245 .55165 Mdot
.12704 .2481 Mdot
.23341 .50995 Mdot
.01674 .21225 Mdot
.53818 .02218 Mdot
.26253 .5233 Mdot
.15594 .25123 Mdot
.36603 .56935 Mdot
.68248 .0832 Mdot
.42413 .59269 Mdot
.19231 .25616 Mdot
.07557 .237 Mdot
.12811 .24765 Mdot
.08218 .22934 Mdot
.74031 .10368 Mdot
.27498 .53212 Mdot
.36108 .56761 Mdot
.13857 .24577 Mdot
.3219 .5472 Mdot
.01729 .21299 Mdot
.17211 .25843 Mdot
.78713 .12858 Mdot
.09075 .23122 Mdot
.89646 .16149 Mdot
.14534 .48075 Mdot
.22432 .27048 Mdot
.63109 .05723 Mdot
.88261 .15615 Mdot
.42686 .59233 Mdot
.17258 .26008 Mdot
.94549 .40477 Mdot
.03424 .4321 Mdot
.22147 .50925 Mdot
.86338 .14929 Mdot
.28477 .53187 Mdot
.10084 .23016 Mdot
.33126 .55443 Mdot
.01555 .42925 Mdot
.93513 .18046 Mdot
.31046 .54196 Mdot
.6846 .08573 Mdot
.67623 .07934 Mdot
.57799 .03964 Mdot
.42408 .59171 Mdot
.13029 .46894 Mdot
.8045 .13057 Mdot
.25574 .27549 Mdot
.84141 .14484 Mdot
.89844 .16396 Mdot
.63922 .0595 Mdot
.1534 .4853 Mdot
.48392 .00166 Mdot
.05533 .2293 Mdot
.01586 .20754 Mdot
.26878 .52358 Mdot
.79472 .1289 Mdot
.32495 .55535 Mdot
.12439 .23969 Mdot
.09533 .45565 Mdot
.55635 .03102 Mdot
.82238 .14278 Mdot
.09909 .23976 Mdot
.45071 .5993 Mdot
.84469 .14953 Mdot
.98465 .19754 Mdot
.00425 .20676 Mdot
.49413 .61732 Mdot
.40384 .5857 Mdot
.33754 .55226 Mdot
.41164 .58673 Mdot
.04875 .43729 Mdot
.26195 .2742 Mdot
.84832 .1435 Mdot
.11544 .46352 Mdot
.56282 .03477 Mdot
.90133 .16775 Mdot
.79741 .12843 Mdot
.27183 .27739 Mdot
.08514 .45473 Mdot
.8723 .15321 Mdot
.93942 .17928 Mdot
.63013 .05954 Mdot
.69718 .08331 Mdot
.77236 .12011 Mdot
.0296 .20908 Mdot
.42111 .59047 Mdot
.69082 .08113 Mdot
.7634 .11049 Mdot
.09469 .46151 Mdot
.87884 .15715 Mdot
.1305 .24175 Mdot
.12807 .23872 Mdot
.06552 .44367 Mdot
.78887 .12534 Mdot
.98428 .2051 Mdot
.20238 .5051 Mdot
.10225 .24471 Mdot
.97555 .19396 Mdot
.23999 .51819 Mdot
.03365 .43335 Mdot
.98659 .41649 Mdot
.76669 .11966 Mdot
.34277 .56111 Mdot
.76106 .1161 Mdot
.26913 .27267 Mdot
.11415 .23673 Mdot
.70754 .09459 Mdot
.11063 .23836 Mdot
.12568 .2527 Mdot
.00059 .42043 Mdot
.72512 .09581 Mdot
.15804 .4886 Mdot
.54608 .02061 Mdot
.99185 .20831 Mdot
.36423 .56422 Mdot
.04348 .43727 Mdot
.47614 .61297 Mdot
.44554 .6049 Mdot
.22881 .26928 Mdot
.48723 .00081 Mdot
.39278 .58042 Mdot
.29089 .53727 Mdot
.91009 .17204 Mdot
.33187 .55508 Mdot
.14286 .47612 Mdot
.95912 .19319 Mdot
.97324 .19007 Mdot
.72464 .09865 Mdot
.6932 .08586 Mdot
.43728 .59715 Mdot
.91004 .17637 Mdot
.29033 .27467 Mdot
.27358 .52561 Mdot
.02683 .21207 Mdot
.98967 .20358 Mdot
.89624 .16818 Mdot
.64216 .06228 Mdot
.28449 .27534 Mdot
.87352 .1551 Mdot
.61778 .05272 Mdot
.35178 .56309 Mdot
.34063 .55983 Mdot
.05092 .22693 Mdot
.3888 .58052 Mdot
.56809 .0348 Mdot
.56279 .03181 Mdot
.13478 .25615 Mdot
.19201 .26996 Mdot
.32618 .55271 Mdot
.95272 .1826 Mdot
.69529 .08579 Mdot
.52541 .01729 Mdot
.50137 .00803 Mdot
.35421 .56614 Mdot
.03525 .22366 Mdot
.29667 .27631 Mdot
.25239 .51869 Mdot
.81112 .13241 Mdot
.7015 .08689 Mdot
.08331 .23221 Mdot
.5345 .02035 Mdot
.99657 .42444 Mdot
.03526 .21249 Mdot
.02182 .2156 Mdot
.75325 .10881 Mdot
.86323 .15753 Mdot
.18162 .25638 Mdot
.89627 .17064 Mdot
.83661 .13929 Mdot
.18188 .25673 Mdot
.30921 .54692 Mdot
.35621 .56798 Mdot
.9836 .19532 Mdot
.19276 .49804 Mdot
.08128 .22454 Mdot
.78332 .12598 Mdot
.58557 .04198 Mdot
.07644 .22346 Mdot
.49157 .61665 Mdot
.42033 .58669 Mdot
.88945 .15978 Mdot
.74398 .10893 Mdot
.76093 .11121 Mdot
.55349 .03004 Mdot
.96179 .18682 Mdot
.13945 .47316 Mdot
.01513 .20502 Mdot
.97602 .19471 Mdot
.64301 .06415 Mdot
.03642 .21496 Mdot
.97416 .41464 Mdot
.41199 .58216 Mdot
.24603 .51416 Mdot
.17311 .25261 Mdot
.08902 .23939 Mdot
.92707 .1789 Mdot
.21962 .26847 Mdot
.56555 .03043 Mdot
.12336 .47152 Mdot
.13905 .25686 Mdot
.70427 .08612 Mdot
.20992 .2669 Mdot
.94924 .19139 Mdot
.72119 .0976 Mdot
.46604 .61121 Mdot
.63841 .0602 Mdot
.96308 .19739 Mdot
.20054 .26666 Mdot
.82049 .1347 Mdot
.54094 .02105 Mdot
.88476 .16455 Mdot
.95893 .18971 Mdot
.22633 .26624 Mdot
.154 .25751 Mdot
.63833 .06447 Mdot
.28621 .53125 Mdot
.33761 .55988 Mdot
.18878 .26915 Mdot
.9901 .20767 Mdot
.10747 .23541 Mdot
.23251 .27039 Mdot
.82575 .14256 Mdot
.29579 .53322 Mdot
.0444 .21873 Mdot
.51887 .01205 Mdot
.05829 .44838 Mdot
.26554 .27162 Mdot
.94377 .18371 Mdot
.21166 .27058 Mdot
.16878 .25478 Mdot
.5222 .01733 Mdot
.94671 .40615 Mdot
.3293 .5482 Mdot
.68882 .08266 Mdot
.14111 .24163 Mdot
.83431 .13753 Mdot
.91469 .17602 Mdot
.9744 .19515 Mdot
.01379 .21585 Mdot
.90102 .38944 Mdot
.90376 .16548 Mdot
.16002 .48515 Mdot
.55705 .02678 Mdot
.07244 .44955 Mdot
.02122 .4293 Mdot
.98943 .2067 Mdot
.99364 .41819 Mdot
.23416 .27549 Mdot
.67885 .07809 Mdot
.18475 .49353 Mdot
.16022 .25211 Mdot
.1525 .48085 Mdot
.14181 .47485 Mdot
.18619 .49917 Mdot
.14473 .25865 Mdot
.19886 .26245 Mdot
.98472 .20363 Mdot
.51699 .01323 Mdot
.81648 .13817 Mdot
.75798 .11444 Mdot
.19952 .25838 Mdot
.33133 .55066 Mdot
.27325 .53436 Mdot
.36343 .56958 Mdot
.20941 .26735 Mdot
.3705 .57372 Mdot
.31345 .54768 Mdot
.24914 .51849 Mdot
.94951 .19172 Mdot
.21656 .27049 Mdot
.96936 .41173 Mdot
.37917 .56781 Mdot
.18939 .49888 Mdot
.22391 .51205 Mdot
.27455 .27233 Mdot
.26334 .27694 Mdot
.99536 .41943 Mdot
.18357 .2674 Mdot
.15698 .25078 Mdot
.80841 .13235 Mdot
.48592 .6168 Mdot
.0402 .22226 Mdot
.3382 .55394 Mdot
.44658 .60255 Mdot
.33488 .55504 Mdot
.40321 .58725 Mdot
.42524 .59451 Mdot
.14964 .4756 Mdot
.24554 .52014 Mdot
.49554 .61778 Mdot
.20085 .49807 Mdot
.19487 .2643 Mdot
.20945 .27039 Mdot
.4305 .59811 Mdot
.77811 .11989 Mdot
.11999 .23865 Mdot
.60333 .05194 Mdot
.96517 .1896 Mdot
.98719 .41697 Mdot
.60392 .04501 Mdot
.18587 .25721 Mdot
.28191 .53808 Mdot
.89443 .16176 Mdot
.1775 .48924 Mdot
.10653 .23647 Mdot
.2032 .25917 Mdot
.58471 .04334 Mdot
.98422 .41697 Mdot
.17727 .49618 Mdot
.58783 .04569 Mdot
.24582 .27404 Mdot
.14171 .25416 Mdot
.18832 .25649 Mdot
.07611 .23472 Mdot
.2104 .50134 Mdot
.71551 .09392 Mdot
.66827 .07949 Mdot
.56553 .02776 Mdot
.93076 .39981 Mdot
.80605 .13503 Mdot
.94518 .40549 Mdot
.38347 .57866 Mdot
.08204 .45422 Mdot
.39119 .57416 Mdot
.98776 .41606 Mdot
.91269 .17188 Mdot
.21587 .27059 Mdot
.3774 .57643 Mdot
.8757 .16247 Mdot
.02691 .22015 Mdot
.79847 .1303 Mdot
.03862 .43388 Mdot
.70021 .08799 Mdot
.14181 .24207 Mdot
.3991 .57641 Mdot
.02046 .21852 Mdot
.22053 .50278 Mdot
.20241 .26356 Mdot
.49342 .61751 Mdot
.09433 .2382 Mdot
.1499 .24949 Mdot
.27172 .53073 Mdot
.63871 .0648 Mdot
.2517 .26882 Mdot
.09792 .23288 Mdot
.0381 .43992 Mdot
.53811 .01765 Mdot
.58902 .04238 Mdot
.09068 .45408 Mdot
.86986 .16157 Mdot
.1451 .2579 Mdot
.94188 .18215 Mdot
.11919 .24386 Mdot
.8538 .15175 Mdot
.73392 .10524 Mdot
.98552 .20619 Mdot
.7931 .12697 Mdot
.77964 .12057 Mdot
.05203 .44329 Mdot
.35677 .56794 Mdot
.09691 .23274 Mdot
.08516 .24085 Mdot
.1326 .47171 Mdot
.22571 .26849 Mdot
.56652 .03543 Mdot
.31633 .5418 Mdot
.26305 .27981 Mdot
.94671 .18009 Mdot
.44996 .60087 Mdot
.35512 .56299 Mdot
.60963 .05538 Mdot
.1835 .49457 Mdot
.67265 .07925 Mdot
.69183 .08573 Mdot
.30562 .54156 Mdot
.91472 .17887 Mdot
.21542 .267 Mdot
.35871 .56835 Mdot
.10816 .46711 Mdot
.63077 .06322 Mdot
.85861 .14976 Mdot
.06267 .44625 Mdot
.41347 .58467 Mdot
.25925 .27261 Mdot
.21295 .26413 Mdot
.57933 .03471 Mdot
.84456 .14244 Mdot
.15999 .24775 Mdot
.05576 .22378 Mdot
.05886 .22227 Mdot
.12437 .24995 Mdot
.6552 .0688 Mdot
.11978 .46948 Mdot
.37647 .56714 Mdot
.90963 .16884 Mdot
.52287 .0126 Mdot
.10539 .24256 Mdot
.09819 .23158 Mdot
.11255 .46746 Mdot
.27498 .27816 Mdot
.21926 .50321 Mdot
.18802 .49684 Mdot
.67758 .07695 Mdot
.7689 .11344 Mdot
.74683 .11017 Mdot
.14823 .47572 Mdot
.0306 .21648 Mdot
.16536 .26142 Mdot
.27437 .27525 Mdot
.18667 .26302 Mdot
.12013 .23982 Mdot
.2369 .27165 Mdot
.76011 .10951 Mdot
.98865 .19599 Mdot
.25924 .52771 Mdot
.42218 .59421 Mdot
.75121 .10506 Mdot
.26287 .27182 Mdot
.18585 .2602 Mdot
.42076 .59387 Mdot
.23373 .27019 Mdot
.33688 .55239 Mdot
.0272 .43477 Mdot
.55257 .0268 Mdot
.45787 .60259 Mdot
.77628 .11827 Mdot
.37308 .56848 Mdot
.51343 .01052 Mdot
.86972 .15377 Mdot
.64324 .06727 Mdot
.11868 .24662 Mdot
.38545 .57876 Mdot
.96888 .18771 Mdot
.16775 .25799 Mdot
.11438 .24368 Mdot
.48976 .61494 Mdot
.48529 .61539 Mdot
.20946 .26828 Mdot
.94175 .40104 Mdot
.61419 .04981 Mdot
.64602 .06839 Mdot
.14954 .47978 Mdot
.69866 .08331 Mdot
.21556 .26554 Mdot
.92106 .1711 Mdot
.28899 .54056 Mdot
.2086 .2616 Mdot
.0071 .21209 Mdot
.6711 .0723 Mdot
.8951 .1619 Mdot
.55836 .02524 Mdot
.45773 .60905 Mdot
.09956 .45936 Mdot
.10659 .46358 Mdot
.6302 .0568 Mdot
.33463 .5579 Mdot
.91989 .17216 Mdot
.2346 .51816 Mdot
.11533 .24597 Mdot
.42764 .58832 Mdot
.27931 .53282 Mdot
.11415 .24926 Mdot
.95034 .18761 Mdot
.47401 .60768 Mdot
.64828 .06391 Mdot
.55898 .03054 Mdot
.2075 .50834 Mdot
.39048 .57972 Mdot
.49078 .0036 Mdot
.34104 .56047 Mdot
.55014 .02151 Mdot
.09415 .24083 Mdot
.4317 .59372 Mdot
.16805 .49183 Mdot
.07631 .2368 Mdot
.9019 .1723 Mdot
.24241 .519 Mdot
.11794 .4646 Mdot
.2284 .51392 Mdot
.19395 .25875 Mdot
.22171 .2759 Mdot
.11282 .24296 Mdot
.58499 .04438 Mdot
.21747 .51008 Mdot
.20715 .2616 Mdot
.24495 .52265 Mdot
.4315 .59487 Mdot
.56731 .02947 Mdot
.36605 .57081 Mdot
.62732 .06241 Mdot
.96957 .41136 Mdot
.5038 .00656 Mdot
.18241 .4891 Mdot
.95565 .19445 Mdot
.13191 .24186 Mdot
.52132 .01044 Mdot
.2586 .27278 Mdot
.45438 .60113 Mdot
.82758 .13666 Mdot
.06357 .22038 Mdot
.63048 .0577 Mdot
.67888 .07588 Mdot
.47766 .6107 Mdot
.3316 .55416 Mdot
.07631 .44749 Mdot
.99453 .20564 Mdot
.45958 .60914 Mdot
.25433 .52179 Mdot
.19853 .49453 Mdot
.00466 .20418 Mdot
.00069 .2102 Mdot
.07492 .22569 Mdot
.16661 .48743 Mdot
.22712 .50596 Mdot
.90683 .1689 Mdot
.09126 .45792 Mdot
.61872 .05219 Mdot
.69812 .08995 Mdot
.31609 .54597 Mdot
.20138 .49755 Mdot
.19143 .25699 Mdot
.81364 .13895 Mdot
.50449 .00676 Mdot
.9035 .17225 Mdot
.51933 .01748 Mdot
.43326 .59662 Mdot
.84702 .14916 Mdot
.1419 .47419 Mdot
.03571 .43717 Mdot
.0438 .21972 Mdot
.19478 .27006 Mdot
.64928 .06446 Mdot
.11805 .244 Mdot
.03879 .43696 Mdot
.44776 .59659 Mdot
.74401 .10671 Mdot
.10828 .4596 Mdot
.46795 .6132 Mdot
.89396 .16517 Mdot
.12474 .47308 Mdot
.67308 .07267 Mdot
.24674 .51523 Mdot
.97137 .19023 Mdot
.16189 .26313 Mdot
.23261 .2666 Mdot
.99233 .20492 Mdot
.76111 .11351 Mdot
.05818 .44189 Mdot
.41486 .5869 Mdot
.11512 .23799 Mdot
.76565 .11015 Mdot
.16536 .25694 Mdot
.27233 .53397 Mdot
.79432 .1256 Mdot
.50198 .00897 Mdot
.10713 .23883 Mdot
.29165 .53416 Mdot
.33834 .55816 Mdot
.11696 .24672 Mdot
.10019 .46328 Mdot
.5269 .01391 Mdot
.11428 .46517 Mdot
.98076 .19516 Mdot
.45992 .6085 Mdot
.90488 .16759 Mdot
.90557 .16861 Mdot
.57629 .03611 Mdot
.22026 .27439 Mdot
.0637 .44429 Mdot
.79794 .12467 Mdot
.49674 .00281 Mdot
.89168 .16588 Mdot
.11198 .23536 Mdot
.55941 .02705 Mdot
.37317 .57423 Mdot
.2613 .52413 Mdot
.70433 .09123 Mdot
.59324 .04031 Mdot
.95908 .40926 Mdot
.86102 .15007 Mdot
.03182 .20937 Mdot
.91911 .39494 Mdot
.75844 .113 Mdot
.58113 .0385 Mdot
.78655 .12276 Mdot
.14165 .2444 Mdot
.5774 .03737 Mdot
.10509 .24368 Mdot
.27089 .27668 Mdot
.33394 .55518 Mdot
.22088 .26897 Mdot
.71882 .09495 Mdot
.10689 .46663 Mdot
.6497 .06594 Mdot
.55965 .02573 Mdot
.24475 .52201 Mdot
.2277 .2685 Mdot
.21788 .50855 Mdot
.60883 .04675 Mdot
.6934 .08909 Mdot
.73409 .09958 Mdot
.12567 .46824 Mdot
.96271 .19244 Mdot
.02111 .21708 Mdot
.04142 .22469 Mdot
.17125 .48854 Mdot
.27996 .53513 Mdot
.1219 .47125 Mdot
.10665 .45992 Mdot
.27688 .27895 Mdot
.73376 .09716 Mdot
.60529 .04488 Mdot
.18536 .49752 Mdot
.65664 .07359 Mdot
.42478 .58874 Mdot
.84544 .1416 Mdot
.98029 .19621 Mdot
.85387 .1506 Mdot
.89148 .16545 Mdot
.91958 .18059 Mdot
.56188 .02964 Mdot
.01684 .21715 Mdot
.03278 .21478 Mdot
.21552 .5104 Mdot
.03764 .21955 Mdot
.7872 .11879 Mdot
.39942 .57963 Mdot
.08642 .22584 Mdot
.64657 .06143 Mdot
.48703 .61735 Mdot
.20954 .2622 Mdot
.12715 .24679 Mdot
.59561 .04091 Mdot
.3356 .55562 Mdot
.10374 .24265 Mdot
.30767 .54557 Mdot
.93685 .40146 Mdot
.76692 .11764 Mdot
.05621 .22799 Mdot
.82886 .14242 Mdot
.22359 .51185 Mdot
.11067 .46195 Mdot
.08251 .45205 Mdot
.53095 .01897 Mdot
.71404 .09036 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002Iooooo`Co0000Poooool002KooooolOl00009oooo
o`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05?ooool3o`00000300000?l0003o000001?ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo07Kooooo
00<00000o`000?l000000ol0001aooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo07Sooooo2?l0001]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo07_ooooo1ol0001[ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
07cooooo2?l0001Yooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo07oo
oooo00?o000000000?l000001Ol0001Vooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000
Poooool7o`0006?ooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`24ooooo`So0000HOoo
ool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`26ooooo`Oo0000H?ooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`29ooooo`Oo0000GOooool00ol0
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2<ooooo`0300000?l0003o000000?o
0000Foooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2>ooooo`Oo0000
F?ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2?ooooo`03o`000?oo
oooo000000Go0000E_ooool00ol0003oooooooooo`07ooooo`009_ooool2o`0009?ooooo00<00000
o`000?l000001Ol0001Booooo`;o00002Oooool002Kooooo00?o0000ooooooooool0UOooool00`00
003o0000o`000004o`00057ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0Uoooool7o`0004oooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
VOooool00ol000000000o`000005o`0004cooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0W?ooool7o`00000300000?oooooooooo04Oooooo00?o0000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0W_ooool00`00003o0000o`000005o`0004Oooooo00?o0000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0X?ooool00`00003o0000o`000006o`00
04Cooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Xoooool7o`000003
00000?oooooooooo043ooooo00?o0000ooooooooool01oooool002Kooooo0_l0002Vooooo`So0000
?oooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0:Sooooo1ol0000nooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo0:_ooooo1Ol000000`00003o0000ooooo`0j
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0:gooooo1ol0000ioooo
o`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0;3ooooo1ol0000fooooo`03
o`000?oooooooooo00Oooooo000Cooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Co
oooo00?o0000ooooooooool0/Oooool8o`00000300000?oooooooooo037ooooo00?o0000oooooooo
ool01oooool001;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo0;Cooooo2?l0000aooooo`03o`000?oooooooooo00Oooooo000Booooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`000;Sooooo2?l0000/oooo
o`?o00002Oooool001;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0;Wooooo2?l0000/ooooo`03o`000?oooooooooo00Oooooo000Booooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo0;_ooooo2Ol0000Yooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0;kooooo2?l0
000Wooooo`03o`000?oooooooooo00Oooooo000Cooooo`;o00002Oooool3o`0000Gooooo00?o0000
ooooooooool0`?ooool9o`0002Cooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0`_ooool2o`00000300000?l0003o000000Go00008Oooool00ol0003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`35ooooo`So00008?ooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`39ooooo`Oo00007Oooool00ol0003oooooooooo`07ooooo`009_oo
ool2o`000<cooooo2?l0000Iooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0cOooool9
o`0001Oooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0d?ooool7o`00
000300000?l0003ooooo01?ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0d_ooool9o`0001;ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
e?ooool:o`0000oooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0eooo
ool00`00003o0000o`000007o`0000cooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0fOooool:o`0000[ooooo00?o0000ooooooooool01oooool002Kooooo0_l0003Moooo
o`_o00001Oooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0=oooooo00<00000o`000?l0
00001_l00005ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>;ooooo
2_l000000ooooooo0000ooooo`08ooooo`009_ooool00ol0003oooooooooo`3Tooooo`03o`000000
003o000000Oo00002Oooool002Kooooo1Ol0003Uooooo`Oo00002Oooool002Kooooo1_l000000`00
003o0000ooooo`3Sooooo`Go00002Oooool002Kooooo0ol000000`00003o0000o`000005o`000>Go
oooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool02ol0003Rooooo`03o`00
0?oooooooooo00Oooooo000Vooooo`;o00000oooool<o`000=kooooo0_l00009ooooo`009_ooool0
0ol0003oooooooooo`05ooooo`ko0000f_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`09ooooo`go0000eoooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`0;ooooo`co000000<00000ooooool00000doooool00ol0003oooooooooo`07ooooo`00
4oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0
3Oooool@o`000=3ooooo00?o0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo3ol0003=ooooo`03o`00
0?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo1Ol00004ooooo`03o`00
0?oooooooooo01Cooooo00?o000000000?l000003Ol00039ooooo`03o`000?oooooooooo00Oooooo
000Booooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool2o`0001Oo
oooo00<00000o`000?l000003_l00034ooooo`?o00002Oooool001;ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo01[ooooo4?l00033ooooo`03
o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03
o`000?oooooooooo01gooooo4_l0002nooooo`03o`000?oooooooooo00Oooooo000Cooooo`;o0000
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00?o000000000?l00000
3_l000000`00003oooooooooo`2hooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo02Cooooo4?l000001000003o0000o`000?l0002eooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo02Wooooo5_l0002^ooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo02kooooo0_l000000ooooooo0000o`000004o`00000300000?l0003o
000000go0000Y_ooool00ol0003oooooooooo`07ooooo`009_ooool2o`0003?ooooo00?o0000oooo
ool000004?l0002Wooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0>_ooool3o`0000?o
oooo00<00000ooooooooool0Z_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo0007ooooo`?o
00007?ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo0008ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`0Kooooo`;o0000kOooool2o`0000Wooooo0008ooooo`;o00007?ooool0
0ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo0007ooooo`;o000000?oooooo`00
0?l000006_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool0
02Kooooo0_l0003]ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0kOooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07oooo
o`004_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0>gooooo00?o
0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo0_l0
003/ooooo`?o00002Oooool001;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool001;ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>gooooo00?o
0000ooooooooool01oooool001?ooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`3D
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0eOooool3o`00000300000?oooooooooo01;ooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0eoooool00ol000000000o`000002o`00017ooooo00?o0000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0foooool3o`00000300000?oooooooooo00cooooo
00?o0000ooooooooool01oooool002Kooooo0_l0003Oooooo`Co000000<00000ooooooooool01ooo
ool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0>3ooooo1Ol00008ooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo0>?ooooo1_l00004ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo0>Gooooo1ol000000ooooooo0000ooooo`08ooooo`00
9_ooool2o`000>[ooooo00?o0000ooooool000000_l00009ooooo`009_ooool01000003o0000o`00
0000003Zooooo`?o00002Oooool002Kooooo00<00000o`000?l000001?l0003Yooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`;o00000_ooool6o`000>Gooooo0_l00009ooooo`009_ooool00ol0
003oooooooooo`03ooooo`;o000000?oooooo`000?l000000_l0003Sooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo00Gooooo2?l0003Pooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo00Sooooo00<00000o`000?l000001?l0003Nooooo`03o`00
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00_ooooo1_l0000200000=[ooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool03Oooool00`00003o0000o`000005
o`000=Sooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool04?ooool7o`00
0=Kooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool04_ooool8o`000=?o
oooo00?o0000ooooooooool01oooool002Kooooo0_l0000Fooooo`Oo0000d?ooool2o`0000Wooooo
000Vooooo`03o`000?oooooooooo01Oooooo2?l0003>ooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo01[ooooo00<00000o`000?l000001Ol0003;ooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo01cooooo2Ol00038ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo01oooooo1ol00037ooooo`03o`000?oooooooooo00Oo
oooo000Cooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooo
ooooo`0Qooooo`Oo000000<00000ooooooooool0`_ooool00ol0003oooooooooo`07ooooo`004_oo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`0Sooooo`03o`000000003o000000Oo0000`?ooool00ol0003oooooooooo`07ooooo`00
4_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool2o`00
02Oooooo2?l0002mooooo`?o00002Oooool001;ooooo00Co0000oooooooooooo00002?ooool3o`00
00Gooooo00?o0000ooooooooool0:Oooool8o`000;cooooo00?o0000ooooooooool01oooool001;o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0:oooool8o`000;[ooooo00?o0000ooooooooool01oooool001;ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0;Ooo
ool00`00003o0000o`000006o`000;Oooooo00?o0000ooooooooool01oooool001?ooooo0_l00009
ooooo`?o00001Oooool00ol0003oooooooooo`0`ooooo`Oo0000]_ooool00ol0003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`0cooooo`So0000/_ooool00ol0003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`0eooooo`So0000/?ooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`0hooooo`03o`000000003o000000Go0000[Oooool00ol0003ooooo
ooooo`07ooooo`009_ooool2o`0003_ooooo1ol000000`00003oooooooooo`2Xooooo`;o00002Ooo
ool002Kooooo00?o0000ooooooooool0?Oooool8o`000:Sooooo00?o0000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool0?oooool8o`000:Kooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0@Oooool2o`00000300000?l0003o000000Co0000Xoooool00ol0003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`14ooooo`So0000XOooool00ol0003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`17ooooo`Oo0000Woooool00ol0003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`19ooooo`0300000?l0003o000000Go0000W?ooool0
0ol0003oooooooooo`07ooooo`009_ooool2o`0004cooooo1ol000000`00003oooooooooo`2Goooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0COooool7o`00000300000?l0003ooooo09Ko
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0DOooool7o`0009Gooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Doooool7o`0009?ooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0E_ooool7o`00093ooooo00?o0000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0Eoooool8o`0008kooooo00?o0000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0F_ooool7o`0008cooooo00?o0000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0GOooool7o`0008Wooooo00?o0000ooooooooool0
1oooool002Kooooo0_l0001Pooooo`Oo0000Q_ooool2o`0000Wooooo000Vooooo`03o`000?oooooo
oooo067ooooo1_l000000`00003o0000ooooo`23ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo06Cooooo1_l00023ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo06Kooooo1ol00020ooooo`03o`000?oooooooooo00Oooooo000Nooooo`?o0000
1Oooool00ol0003oooooooooo`1Xooooo`So0000OOooool00ol0003oooooooooo`07ooooo`007ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0;ooooo`Oo00006oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooooooool7o`000003ooooool0003ooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01ooo
ool001oooooo00?o0000ooooooooool01?oooooao`0000Wooooo000Oooooo`03o`000?oooooooooo
0?kooooo000Nooooo`;o0000ooooool1ooooo`007oooool00ol0003oooooooooo`3nooooo`00oooo
oolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.158908, -0.161707, \
0.00416367, 0.00673696}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.67922 .42178 Mdot
.34504 .14571 Mdot
.36097 .12518 Mdot
.33068 .17535 Mdot
.07319 .23001 Mdot
.75966 .35906 Mdot
.48093 .13062 Mdot
.74115 .36499 Mdot
.35353 .1493 Mdot
.3796 .12719 Mdot
.20272 .49409 Mdot
.05531 .43765 Mdot
.78802 .35634 Mdot
.18858 .48814 Mdot
.72272 .09607 Mdot
.32958 .23849 Mdot
.32866 .17033 Mdot
.64857 .06329 Mdot
.34922 .1339 Mdot
.79299 .12371 Mdot
.82505 .36683 Mdot
.32821 .246 Mdot
.33408 .19036 Mdot
.03645 .4305 Mdot
.83718 .14181 Mdot
.34237 .14748 Mdot
.80346 .36392 Mdot
.17962 .48678 Mdot
.01523 .42327 Mdot
.3351 .17778 Mdot
.00585 .41868 Mdot
.85351 .36998 Mdot
.89782 .38522 Mdot
.32276 .22885 Mdot
.34826 .55434 Mdot
.23473 .27253 Mdot
.44945 .12212 Mdot
.28403 .2685 Mdot
.46863 .13224 Mdot
.88191 .16102 Mdot
.30299 .26119 Mdot
.19989 .26318 Mdot
.94976 .39955 Mdot
.87706 .37742 Mdot
.79716 .36265 Mdot
.63544 .05723 Mdot
.32995 .22211 Mdot
.68035 .43586 Mdot
.35084 .16197 Mdot
.11002 .24159 Mdot
.40888 .12988 Mdot
.88278 .38151 Mdot
.79085 .35971 Mdot
.13963 .24873 Mdot
.32915 .16104 Mdot
.79715 .35751 Mdot
.33664 .17307 Mdot
.30687 .24607 Mdot
.93726 .39913 Mdot
.35876 .15308 Mdot
.13157 .46578 Mdot
.79972 .3604 Mdot
.07908 .23026 Mdot
.73211 .36402 Mdot
.99281 .20313 Mdot
.90446 .16781 Mdot
.19576 .26449 Mdot
.74817 .35619 Mdot
.30458 .25347 Mdot
.45408 .59933 Mdot
.21803 .2648 Mdot
.32267 .23188 Mdot
.73913 .35476 Mdot
.32487 .25697 Mdot
.34679 .17261 Mdot
.67 .07281 Mdot
.77903 .35507 Mdot
.32872 .15344 Mdot
.33175 .178 Mdot
.35296 .15461 Mdot
.68235 .42306 Mdot
.29505 .53352 Mdot
.2563 .27468 Mdot
.10416 .238 Mdot
.21983 .50358 Mdot
.68519 .41477 Mdot
.33277 .24413 Mdot
.34268 .19109 Mdot
.50636 .00549 Mdot
.34973 .16155 Mdot
.95866 .18949 Mdot
.33335 .13877 Mdot
.37107 .56486 Mdot
.32371 .23856 Mdot
.3741 .12654 Mdot
.68696 .40367 Mdot
.3375 .19171 Mdot
.66889 .47793 Mdot
.91237 .38996 Mdot
.10114 .45397 Mdot
.43989 .12602 Mdot
.29793 .26051 Mdot
.62682 .05424 Mdot
.30712 .25403 Mdot
.86185 .37657 Mdot
.74122 .36515 Mdot
.76677 .35663 Mdot
.4001 .12227 Mdot
.21172 .26714 Mdot
.39032 .12372 Mdot
.99781 .2054 Mdot
.12961 .24646 Mdot
.41839 .58397 Mdot
.32517 .17958 Mdot
.5038 .13304 Mdot
.07198 .44544 Mdot
.32693 .17467 Mdot
.20647 .49876 Mdot
.34308 .18377 Mdot
.88682 .38091 Mdot
.69501 .37789 Mdot
.76902 .11553 Mdot
.32745 .19525 Mdot
.33503 .17564 Mdot
.9978 .41532 Mdot
.35446 .13255 Mdot
.16499 .47919 Mdot
.33532 .18854 Mdot
.61756 .04973 Mdot
.27239 .27056 Mdot
.32802 .17306 Mdot
.97155 .4063 Mdot
.37008 .1453 Mdot
.68434 .43879 Mdot
.4249 .12477 Mdot
.36589 .56389 Mdot
.26921 .2716 Mdot
.32688 .54644 Mdot
.77984 .35919 Mdot
.34086 .20583 Mdot
.30909 .25678 Mdot
.68732 .41819 Mdot
.32759 .2007 Mdot
.29382 .26009 Mdot
.68817 .40339 Mdot
.35288 .16274 Mdot
.84465 .37089 Mdot
.31075 .53872 Mdot
.34387 .19189 Mdot
.76274 .36088 Mdot
.90216 .1675 Mdot
.21953 .26951 Mdot
.31627 .22748 Mdot
.77109 .11502 Mdot
.7277 .36755 Mdot
.31867 .23758 Mdot
.3845 .12094 Mdot
.68764 .41066 Mdot
.38638 .13376 Mdot
.20173 .26201 Mdot
.1479 .47516 Mdot
.21257 .2662 Mdot
.32883 .22057 Mdot
.76565 .36115 Mdot
.36187 .13145 Mdot
.25597 .2678 Mdot
.39741 .12768 Mdot
.49322 .13468 Mdot
.34526 .13932 Mdot
.38745 .12831 Mdot
.7187 .36565 Mdot
.92234 .39186 Mdot
.40116 .12105 Mdot
.35858 .15664 Mdot
.72669 .35611 Mdot
.17749 .25786 Mdot
.61301 .04965 Mdot
.32863 .15004 Mdot
.29622 .27094 Mdot
.67305 .46882 Mdot
.30493 .26208 Mdot
.74848 .35719 Mdot
.61314 .04819 Mdot
.4775 .12917 Mdot
.24557 .27083 Mdot
.59555 .04306 Mdot
.23873 .51021 Mdot
.33308 .21172 Mdot
.48553 .13102 Mdot
.33618 .18338 Mdot
.28067 .52587 Mdot
.33211 .20967 Mdot
.34764 .14388 Mdot
.85442 .14774 Mdot
.25046 .51441 Mdot
.15074 .25164 Mdot
.3781 .13334 Mdot
.12461 .46428 Mdot
.84296 .14336 Mdot
.33935 .21277 Mdot
.12505 .24468 Mdot
.33941 .14886 Mdot
.69562 .38217 Mdot
.01579 .42475 Mdot
.51133 .00741 Mdot
.32802 .23627 Mdot
.38249 .12494 Mdot
.68711 .41002 Mdot
.8271 .36876 Mdot
.37659 .13696 Mdot
.28687 .26833 Mdot
.2087 .49958 Mdot
.68299 .44532 Mdot
.38295 .57056 Mdot
.47265 .13087 Mdot
.96488 .40745 Mdot
.15436 .251 Mdot
.77579 .11625 Mdot
.33537 .18541 Mdot
.21336 .26962 Mdot
.33717 .20954 Mdot
.19204 .25965 Mdot
.68307 .43127 Mdot
.61421 .04871 Mdot
.82345 .36967 Mdot
.83552 .3683 Mdot
.68029 .41852 Mdot
.72384 .36728 Mdot
.30274 .27078 Mdot
.1834 .25988 Mdot
.33158 .20161 Mdot
.7427 .35901 Mdot
.78014 .3616 Mdot
.88842 .16171 Mdot
.69597 .39413 Mdot
.68083 .45902 Mdot
.42531 .11859 Mdot
.37381 .13405 Mdot
.36195 .13233 Mdot
.30597 .24872 Mdot
.68693 .08029 Mdot
.99643 .4174 Mdot
.18527 .25777 Mdot
.68414 .42905 Mdot
.16901 .25618 Mdot
.33334 .23954 Mdot
.31771 .25904 Mdot
.29823 .26737 Mdot
.04583 .21953 Mdot
.38636 .13741 Mdot
.34206 .18436 Mdot
.50012 .13187 Mdot
.89558 .38281 Mdot
.3257 .20708 Mdot
.17885 .25818 Mdot
.38651 .13757 Mdot
.78979 .36507 Mdot
.69166 .37888 Mdot
.53865 .01681 Mdot
.27608 .26815 Mdot
.46343 .12883 Mdot
.35345 .13598 Mdot
.73288 .35493 Mdot
.37475 .12674 Mdot
.46623 .1251 Mdot
.69222 .38692 Mdot
.58688 .03816 Mdot
.27188 .52305 Mdot
.5651 .02907 Mdot
.71958 .35976 Mdot
.35401 .13278 Mdot
.32705 .24644 Mdot
.41122 .11835 Mdot
.32009 .24 Mdot
.33047 .20478 Mdot
.39332 .13189 Mdot
.34723 .1576 Mdot
.33334 .21059 Mdot
.13411 .46713 Mdot
.03265 .4288 Mdot
.45884 .12372 Mdot
.68285 .4125 Mdot
.69252 .39215 Mdot
.04833 .22073 Mdot
.87221 .37968 Mdot
.3177 .22225 Mdot
.37735 .56756 Mdot
.67951 .45649 Mdot
.33151 .23629 Mdot
.47162 .60771 Mdot
.02051 .42539 Mdot
.68397 .43833 Mdot
.41768 .58579 Mdot
.33141 .15049 Mdot
.7975 .3613 Mdot
.96844 .19383 Mdot
.73531 .36303 Mdot
.31901 .25598 Mdot
.30557 .25212 Mdot
.25242 .27134 Mdot
.71895 .36463 Mdot
.69509 .37212 Mdot
.44486 .12806 Mdot
.04262 .4345 Mdot
.09733 .23488 Mdot
.21529 .50125 Mdot
.00991 .20811 Mdot
.44276 .12992 Mdot
.10094 .24049 Mdot
.84604 .36869 Mdot
.33847 .19831 Mdot
.33779 .1784 Mdot
.05893 .22415 Mdot
.20261 .26475 Mdot
.31537 .25135 Mdot
.81375 .13334 Mdot
.69067 .4142 Mdot
.67998 .42326 Mdot
.33095 .24579 Mdot
.76794 .35483 Mdot
.20733 .49914 Mdot
.50405 .13281 Mdot
.80456 .128 Mdot
.85924 .37301 Mdot
.49365 .13217 Mdot
.3488 .16304 Mdot
.17304 .48342 Mdot
.92269 .38981 Mdot
.76298 .35334 Mdot
.70435 .36343 Mdot
.30115 .25321 Mdot
.49239 .13084 Mdot
.00285 .20372 Mdot
.51315 .13363 Mdot
.85724 .3757 Mdot
.34137 .1666 Mdot
.04254 .43494 Mdot
.76192 .36231 Mdot
.34495 .14807 Mdot
.34189 .17655 Mdot
.16788 .25674 Mdot
.17068 .25902 Mdot
.33233 .17839 Mdot
.27759 .27329 Mdot
.76048 .3562 Mdot
.29817 .27022 Mdot
.71846 .36578 Mdot
.32341 .22447 Mdot
.41534 .11981 Mdot
.32919 .21957 Mdot
.68303 .40316 Mdot
.71387 .37675 Mdot
.31245 .25865 Mdot
.68345 .07739 Mdot
.32777 .19468 Mdot
.68222 .44542 Mdot
.34295 .2041 Mdot
.02142 .21131 Mdot
.04964 .2219 Mdot
.31167 .24119 Mdot
.32532 .25631 Mdot
.72516 .36595 Mdot
.03008 .21673 Mdot
.82401 .3688 Mdot
.32626 .20701 Mdot
.31626 .2607 Mdot
.51737 .13532 Mdot
.20141 .26521 Mdot
.02547 .42496 Mdot
.37216 .12062 Mdot
.37573 .12586 Mdot
.74014 .35645 Mdot
.68336 .07886 Mdot
.81303 .36505 Mdot
.70474 .38258 Mdot
.77379 .36213 Mdot
.87308 .37674 Mdot
.32599 .25448 Mdot
.92593 .39236 Mdot
.68578 .43613 Mdot
.34325 .14497 Mdot
.67171 .47024 Mdot
.48347 .12994 Mdot
.39287 .12942 Mdot
.1516 .25213 Mdot
.27635 .26421 Mdot
.29517 .26917 Mdot
.27966 .26672 Mdot
.0566 .43797 Mdot
.71119 .36849 Mdot
.67213 .46986 Mdot
.68051 .42482 Mdot
.89854 .38558 Mdot
.67876 .44667 Mdot
.15764 .47847 Mdot
.81629 .36307 Mdot
.30366 .25943 Mdot
.87753 .15692 Mdot
.79083 .36214 Mdot
.44237 .12782 Mdot
.32965 .18132 Mdot
.33421 .18072 Mdot
.32678 .20557 Mdot
.30738 .25603 Mdot
.31899 .25197 Mdot
.19783 .26213 Mdot
.07727 .23253 Mdot
.09657 .23943 Mdot
.33165 .1938 Mdot
.40228 .12842 Mdot
.33757 .2074 Mdot
.49659 .13285 Mdot
.34598 .14762 Mdot
.82585 .36618 Mdot
.68309 .43399 Mdot
.74166 .10179 Mdot
.95995 .19003 Mdot
.45013 .12664 Mdot
.73673 .36506 Mdot
.32162 .25546 Mdot
.94939 .39972 Mdot
.25533 .26527 Mdot
.3219 .24631 Mdot
.30771 .24739 Mdot
.32038 .22031 Mdot
.28854 .2688 Mdot
.37533 .13912 Mdot
.6996 .38559 Mdot
.03712 .4304 Mdot
.84054 .37094 Mdot
.17271 .48364 Mdot
.33515 .23356 Mdot
.36491 .1204 Mdot
.42832 .12793 Mdot
.70773 .08948 Mdot
.8314 .36946 Mdot
.25614 .27101 Mdot
.85297 .14708 Mdot
.36312 .13885 Mdot
.15532 .25472 Mdot
.93334 .17915 Mdot
.0196 .21323 Mdot
.2339 .50927 Mdot
.3132 .23801 Mdot
.99734 .41732 Mdot
.33959 .14063 Mdot
.44559 .13006 Mdot
.33996 .15643 Mdot
.05731 .43821 Mdot
.93312 .39421 Mdot
.2107 .26743 Mdot
.35748 .1423 Mdot
.38552 .11769 Mdot
.0862 .23478 Mdot
.33996 .16366 Mdot
.33356 .2179 Mdot
.33655 .23253 Mdot
.3312 .20288 Mdot
.37146 .14474 Mdot
.32416 .1681 Mdot
.86877 .15495 Mdot
.33402 .22441 Mdot
.47297 .13052 Mdot
.32218 .20793 Mdot
.39648 .12289 Mdot
.43939 .59354 Mdot
.68097 .40882 Mdot
.34593 .16432 Mdot
.98469 .19727 Mdot
.37223 .11977 Mdot
.32599 .17554 Mdot
.6867 .4091 Mdot
.95458 .18767 Mdot
.93999 .18235 Mdot
.24718 .27098 Mdot
.29295 .26522 Mdot
.05633 .22188 Mdot
.72442 .35674 Mdot
.30773 .26879 Mdot
.98502 .19835 Mdot
.45784 .12898 Mdot
.69693 .08312 Mdot
.73641 .36544 Mdot
.16874 .25897 Mdot
.09514 .23547 Mdot
.68267 .45357 Mdot
.71313 .37528 Mdot
.95302 .18815 Mdot
.87498 .15753 Mdot
.88504 .38202 Mdot
.41661 .12333 Mdot
.27715 .2673 Mdot
.73156 .36736 Mdot
.69381 .3847 Mdot
.33454 .1362 Mdot
.32361 .24028 Mdot
.05144 .22351 Mdot
.27286 .26678 Mdot
.11335 .45849 Mdot
.07996 .44719 Mdot
.40072 .11751 Mdot
.89202 .38455 Mdot
.78254 .36235 Mdot
.98655 .19929 Mdot
.87214 .3804 Mdot
.11281 .45856 Mdot
.88788 .38444 Mdot
.33849 .18312 Mdot
.24177 .26701 Mdot
.69064 .40158 Mdot
.76445 .35476 Mdot
.39192 .13315 Mdot
.28861 .53139 Mdot
.20749 .26228 Mdot
.26114 .52087 Mdot
.92146 .39246 Mdot
.06395 .44314 Mdot
.34191 .15704 Mdot
.67478 .46037 Mdot
.85702 .37583 Mdot
.05816 .22603 Mdot
.69364 .3996 Mdot
.87585 .37936 Mdot
.09092 .45175 Mdot
.47303 .13203 Mdot
.264 .2702 Mdot
.24503 .2651 Mdot
.0932 .23763 Mdot
.92946 .17643 Mdot
.23185 .26734 Mdot
.66213 .06847 Mdot
.12723 .24607 Mdot
.68906 .39134 Mdot
.3163 .26433 Mdot
.41405 .11992 Mdot
.91107 .38792 Mdot
.72359 .36633 Mdot
.34801 .17267 Mdot
.60749 .04721 Mdot
.7392 .35448 Mdot
.34095 .16232 Mdot
.33697 .21142 Mdot
.0396 .43222 Mdot
.69488 .38245 Mdot
.70217 .3734 Mdot
.24295 .26792 Mdot
.97511 .41042 Mdot
.0527 .22456 Mdot
.68337 .4172 Mdot
.37525 .14189 Mdot
.33721 .18346 Mdot
.26699 .27452 Mdot
.33055 .14744 Mdot
.32465 .19581 Mdot
.33165 .21402 Mdot
.35486 .15484 Mdot
.05125 .22111 Mdot
.72643 .36454 Mdot
.64743 .06368 Mdot
.33874 .18394 Mdot
.02726 .42675 Mdot
.45291 .12288 Mdot
.3191 .25433 Mdot
.28593 .27186 Mdot
.33031 .23122 Mdot
.33628 .19994 Mdot
.33487 .14214 Mdot
.47264 .12723 Mdot
.04113 .22053 Mdot
.33573 .15169 Mdot
.39155 .11876 Mdot
.86832 .37685 Mdot
.22611 .2649 Mdot
.21891 .50347 Mdot
.69876 .38252 Mdot
.23207 .26539 Mdot
.1356 .25013 Mdot
.40402 .11802 Mdot
.1962 .26445 Mdot
.7071 .38063 Mdot
.8695 .37851 Mdot
.72462 .36212 Mdot
.71831 .3644 Mdot
.47057 .12728 Mdot
.69182 .08165 Mdot
.3901 .13404 Mdot
.02851 .216 Mdot
.85023 .3738 Mdot
.33161 .14586 Mdot
.70084 .37628 Mdot
.79441 .12433 Mdot
.782 .36164 Mdot
.52955 .01431 Mdot
.36303 .12456 Mdot
.73706 .35637 Mdot
.41425 .11813 Mdot
.38001 .13842 Mdot
.98956 .41457 Mdot
.98779 .41175 Mdot
.87213 .37914 Mdot
.11773 .46002 Mdot
.6899 .42188 Mdot
.42783 .12168 Mdot
.42875 .12506 Mdot
.04297 .21745 Mdot
.38579 .12132 Mdot
.07444 .23156 Mdot
.50046 .1335 Mdot
.34631 .17598 Mdot
.32768 .21498 Mdot
.61118 .04946 Mdot
.31828 .25145 Mdot
.42682 .12599 Mdot
.13993 .2477 Mdot
.33618 .14276 Mdot
.32559 .2272 Mdot
.88003 .37721 Mdot
.3907 .13482 Mdot
.34596 .13702 Mdot
.42759 .13121 Mdot
.92064 .39081 Mdot
.72867 .36512 Mdot
.41556 .12125 Mdot
.29555 .53213 Mdot
.78493 .36308 Mdot
.41997 .12977 Mdot
.81926 .36635 Mdot
.7367 .36123 Mdot
.3492 .14737 Mdot
.53468 .01646 Mdot
.34106 .14286 Mdot
.24137 .27062 Mdot
.34362 .18602 Mdot
.29429 .27278 Mdot
.30914 .25209 Mdot
.78835 .36457 Mdot
.3085 .25765 Mdot
.69022 .3773 Mdot
.28447 .27231 Mdot
.71392 .36906 Mdot
.30492 .25481 Mdot
.37412 .13996 Mdot
.42249 .1313 Mdot
.7704 .35675 Mdot
.68676 .38979 Mdot
.32538 .22217 Mdot
.20625 .26741 Mdot
.32618 .22593 Mdot
.33342 .16849 Mdot
.01794 .21033 Mdot
.30465 .53746 Mdot
.16933 .25981 Mdot
.21303 .26455 Mdot
.17111 .25461 Mdot
.32998 .1809 Mdot
.14105 .25125 Mdot
.24529 .26695 Mdot
.3267 .22228 Mdot
.79104 .35942 Mdot
.79296 .36559 Mdot
.99911 .41548 Mdot
.15984 .25563 Mdot
.70361 .37863 Mdot
.76391 .36101 Mdot
.56424 .02784 Mdot
.95794 .18968 Mdot
.34546 .18227 Mdot
.50486 .13499 Mdot
.46197 .12453 Mdot
.03089 .42938 Mdot
.33095 .1876 Mdot
.01244 .42278 Mdot
.47611 .60894 Mdot
.25765 .26504 Mdot
.82157 .13686 Mdot
.26775 .26802 Mdot
.38986 .12635 Mdot
.06023 .4403 Mdot
.20137 .49571 Mdot
.28912 .53137 Mdot
.62883 .05745 Mdot
.67583 .45885 Mdot
.10155 .23918 Mdot
.34196 .15097 Mdot
.68655 .41039 Mdot
.7134 .3673 Mdot
.33046 .20508 Mdot
.52608 .01129 Mdot
.41207 .1273 Mdot
.98907 .41379 Mdot
.09426 .23426 Mdot
.47729 .12754 Mdot
.0186 .42281 Mdot
.44443 .12568 Mdot
.36803 .12918 Mdot
.69402 .38805 Mdot
.32696 .19031 Mdot
.50463 .13363 Mdot
.80511 .36506 Mdot
.27709 .27388 Mdot
.50083 .00338 Mdot
.87911 .37871 Mdot
.341 .20729 Mdot
.12855 .46638 Mdot
.33533 .55113 Mdot
.76558 .11398 Mdot
.21019 .49794 Mdot
.95362 .40184 Mdot
.7912 .1221 Mdot
.11345 .4602 Mdot
.68394 .07853 Mdot
.35349 .14704 Mdot
.81356 .36269 Mdot
.03127 .21434 Mdot
.2813 .26756 Mdot
.39903 .57727 Mdot
.72446 .09629 Mdot
.47478 .12698 Mdot
.68532 .4331 Mdot
.32546 .22126 Mdot
.72514 .0952 Mdot
.2203 .26965 Mdot
.78785 .36375 Mdot
.26389 .2661 Mdot
.34953 .14526 Mdot
.00712 .42218 Mdot
.70538 .36492 Mdot
.32998 .17696 Mdot
.34657 .14757 Mdot
.3502 .14206 Mdot
.32521 .20533 Mdot
.68348 .41112 Mdot
.78777 .35603 Mdot
.27733 .26741 Mdot
.7773 .35606 Mdot
.34809 .13163 Mdot
.9772 .19668 Mdot
.33153 .17499 Mdot
.96627 .4064 Mdot
.33835 .13257 Mdot
.09123 .44986 Mdot
.79947 .36236 Mdot
.33726 .22255 Mdot
.69107 .40456 Mdot
.62837 .0568 Mdot
.13672 .4676 Mdot
.72181 .36898 Mdot
.221 .27008 Mdot
.0299 .21291 Mdot
.31887 .24858 Mdot
.61514 .05011 Mdot
.31643 .25001 Mdot
.40015 .11724 Mdot
.30864 .26665 Mdot
.76322 .11212 Mdot
.95887 .1892 Mdot
.81223 .36562 Mdot
.69452 .3913 Mdot
.67767 .45163 Mdot
.30859 .26017 Mdot
.28796 .52896 Mdot
.33384 .14124 Mdot
.70828 .37637 Mdot
.35721 .5596 Mdot
.68143 .44142 Mdot
.36408 .13954 Mdot
.32923 .23186 Mdot
.00712 .4192 Mdot
.32584 .25228 Mdot
.43318 .59224 Mdot
.25296 .27342 Mdot
.26087 .26734 Mdot
.74623 .36344 Mdot
.28365 .26303 Mdot
.35836 .12284 Mdot
.7334 .09983 Mdot
.32818 .15291 Mdot
.33742 .22131 Mdot
.08864 .4503 Mdot
.24927 .51489 Mdot
.33718 .17854 Mdot
.73537 .36662 Mdot
.33855 .55226 Mdot
.57672 .03424 Mdot
.45605 .60241 Mdot
.31044 .25484 Mdot
.24448 .51343 Mdot
.50274 .00381 Mdot
.47735 .61067 Mdot
.15405 .25065 Mdot
.68493 .44506 Mdot
.46743 .60543 Mdot
.32711 .54745 Mdot
.65592 .06761 Mdot
.78258 .36488 Mdot
.81002 .36775 Mdot
.30673 .24591 Mdot
.59406 .04153 Mdot
.01383 .20827 Mdot
.79587 .36309 Mdot
.04532 .43428 Mdot
.06628 .22822 Mdot
.80058 .35952 Mdot
.68647 .41591 Mdot
.41087 .11812 Mdot
.33893 .18987 Mdot
.41298 .1183 Mdot
.33749 .20042 Mdot
.87579 .37816 Mdot
.87265 .37531 Mdot
.26647 .26709 Mdot
.83525 .36784 Mdot
.9703 .19443 Mdot
.35801 .14625 Mdot
.78141 .3597 Mdot
.32864 .22056 Mdot
.68249 .39836 Mdot
.72466 .36936 Mdot
.82678 .36679 Mdot
.91797 .38813 Mdot
.3332 .14161 Mdot
.80297 .36574 Mdot
.63293 .05868 Mdot
.34703 .14506 Mdot
.32701 .16527 Mdot
.76665 .36116 Mdot
.3386 .17451 Mdot
.22781 .5049 Mdot
.28513 .2687 Mdot
.4617 .60339 Mdot
.11976 .4608 Mdot
.4143 .11799 Mdot
.26777 .27523 Mdot
.41639 .12143 Mdot
.68919 .38577 Mdot
.68305 .41246 Mdot
.7323 .35474 Mdot
.6907 .40948 Mdot
.08509 .23327 Mdot
.23397 .26615 Mdot
.47677 .13074 Mdot
.43465 .59237 Mdot
.30993 .26588 Mdot
.90321 .38428 Mdot
.8474 .37411 Mdot
.58811 .039 Mdot
.43938 .12607 Mdot
.96177 .4043 Mdot
.33769 .20445 Mdot
.52287 .01272 Mdot
.70436 .37064 Mdot
.32947 .24399 Mdot
.82372 .365 Mdot
.8026 .35943 Mdot
.33021 .21674 Mdot
.51071 .13559 Mdot
.32358 .24314 Mdot
.25594 .26966 Mdot
.35192 .1552 Mdot
.86097 .37137 Mdot
.67742 .44654 Mdot
.67829 .43161 Mdot
.44385 .12486 Mdot
.91709 .1723 Mdot
.32544 .22618 Mdot
.74344 .35355 Mdot
.7599 .36354 Mdot
.81332 .36045 Mdot
.32058 .5434 Mdot
.33663 .18899 Mdot
.32171 .24548 Mdot
.69211 .08281 Mdot
.24247 .26993 Mdot
.15864 .47818 Mdot
.33609 .2184 Mdot
.32787 .2181 Mdot
.3598 .13044 Mdot
.7735 .11571 Mdot
.37251 .12827 Mdot
.71509 .36464 Mdot
.8232 .13535 Mdot
.06705 .22861 Mdot
.39011 .1271 Mdot
.68001 .4439 Mdot
.8778 .37679 Mdot
.34293 .15609 Mdot
.31516 .24858 Mdot
.68094 .43532 Mdot
.40492 .13293 Mdot
.33417 .22715 Mdot
.3618 .13177 Mdot
.90535 .16864 Mdot
.23204 .50663 Mdot
.72713 .36765 Mdot
.17027 .2582 Mdot
.42922 .12066 Mdot
.82923 .36667 Mdot
.68986 .38101 Mdot
.68041 .07626 Mdot
.97545 .41148 Mdot
.30064 .25366 Mdot
.70674 .08761 Mdot
.37852 .12936 Mdot
.72815 .3681 Mdot
.90636 .16878 Mdot
.33692 .13407 Mdot
.46942 .12566 Mdot
.69013 .41647 Mdot
.32914 .19273 Mdot
.3366 .15887 Mdot
.85573 .37145 Mdot
.32896 .21303 Mdot
.82203 .13473 Mdot
.78096 .35688 Mdot
.32695 .23389 Mdot
.88307 .38007 Mdot
.70219 .36913 Mdot
.88475 .38031 Mdot
.79433 .36018 Mdot
.45367 .60144 Mdot
.16836 .4803 Mdot
.75318 .1082 Mdot
.96982 .40907 Mdot
.24587 .26725 Mdot
.32734 .24216 Mdot
.21428 .27015 Mdot
.34019 .13721 Mdot
.87732 .37892 Mdot
.40344 .13333 Mdot
.33953 .13518 Mdot
.2861 .26893 Mdot
.30878 .2475 Mdot
.80407 .36233 Mdot
.52492 .01208 Mdot
.71379 .37359 Mdot
.31726 .24201 Mdot
.22073 .27089 Mdot
.99594 .41551 Mdot
.23936 .27209 Mdot
.8409 .37143 Mdot
.3498 .1602 Mdot
.84422 .37135 Mdot
.69337 .38145 Mdot
.69808 .08503 Mdot
.45298 .12414 Mdot
.67158 .47126 Mdot
.33006 .15137 Mdot
.58059 .03629 Mdot
.68585 .07873 Mdot
.6896 .41789 Mdot
.687 .4293 Mdot
.40897 .124 Mdot
.2789 .52684 Mdot
.29595 .25504 Mdot
.72943 .35968 Mdot
.49125 .61583 Mdot
.94254 .39889 Mdot
.3195 .54349 Mdot
.10196 .45577 Mdot
.72327 .37079 Mdot
.33109 .19319 Mdot
.3855 .11788 Mdot
.29426 .25681 Mdot
.76895 .36087 Mdot
.88232 .1599 Mdot
.56575 .02986 Mdot
.83115 .36509 Mdot
.34766 .12947 Mdot
.72456 .36523 Mdot
.33308 .22449 Mdot
.31819 .22226 Mdot
.34367 .19061 Mdot
.72111 .36841 Mdot
.32196 .24622 Mdot
.34961 .55634 Mdot
.32734 .25051 Mdot
.32396 .18549 Mdot
.74734 .35558 Mdot
.33856 .22168 Mdot
.72582 .35587 Mdot
.94012 .18168 Mdot
.24638 .26869 Mdot
.30682 .25528 Mdot
.39832 .11854 Mdot
.3315 .23226 Mdot
.90239 .16907 Mdot
.87982 .37726 Mdot
.42294 .1313 Mdot
.31108 .53862 Mdot
.32759 .24531 Mdot
.32686 .17638 Mdot
.67115 .07443 Mdot
.87811 .15928 Mdot
.32611 .22337 Mdot
.32547 .23355 Mdot
.37766 .13913 Mdot
.76456 .36178 Mdot
.09711 .45212 Mdot
.34243 .16543 Mdot
.01114 .20659 Mdot
.31689 .54267 Mdot
.68532 .44012 Mdot
.78458 .12043 Mdot
.33173 .2189 Mdot
.74071 .36201 Mdot
.34761 .13128 Mdot
.22746 .50443 Mdot
.7607 .35615 Mdot
.25205 .51529 Mdot
.32693 .19387 Mdot
.32898 .24266 Mdot
.72457 .35793 Mdot
.85999 .37227 Mdot
.21898 .50334 Mdot
.39909 .12855 Mdot
.96156 .18945 Mdot
.31567 .23819 Mdot
.92742 .1758 Mdot
.07425 .23225 Mdot
.89046 .16413 Mdot
.70133 .38707 Mdot
.25433 .27108 Mdot
.15029 .25441 Mdot
.28554 .52915 Mdot
.83526 .36921 Mdot
.78532 .36052 Mdot
.69999 .08687 Mdot
.21687 .2651 Mdot
.29156 .26933 Mdot
.68272 .43908 Mdot
.00695 .42121 Mdot
.31814 .24547 Mdot
.69062 .38124 Mdot
.92833 .39558 Mdot
.32231 .23038 Mdot
.33375 .17801 Mdot
.31375 .25837 Mdot
.34238 .19114 Mdot
.52631 .01362 Mdot
.70215 .38534 Mdot
.29859 .25589 Mdot
.38842 .11864 Mdot
.13873 .24901 Mdot
.85385 .15028 Mdot
.29506 .53275 Mdot
.69984 .37039 Mdot
.09747 .23492 Mdot
.94447 .18469 Mdot
.68878 .40886 Mdot
.37143 .14001 Mdot
.33936 .16681 Mdot
.31934 .2365 Mdot
.69108 .40428 Mdot
.37142 .14082 Mdot
.32255 .25968 Mdot
.22373 .27097 Mdot
.83267 .36917 Mdot
.36447 .56314 Mdot
.18476 .26201 Mdot
.3224 .1934 Mdot
.62263 .05279 Mdot
.68497 .40548 Mdot
.34055 .18986 Mdot
.0563 .22592 Mdot
.26959 .26837 Mdot
.08071 .22985 Mdot
.70987 .36859 Mdot
.70048 .36999 Mdot
.70417 .38623 Mdot
.36332 .12812 Mdot
.32826 .25337 Mdot
.68918 .40648 Mdot
.75012 .36155 Mdot
.34262 .13484 Mdot
.1403 .25211 Mdot
.10371 .23801 Mdot
.3411 .16179 Mdot
.34719 .13176 Mdot
.23379 .26617 Mdot
.30823 .2457 Mdot
.32128 .24467 Mdot
.3823 .12941 Mdot
.76624 .35879 Mdot
.32957 .18763 Mdot
.80459 .36536 Mdot
.3255 .18557 Mdot
.34908 .17029 Mdot
.58922 .04044 Mdot
.34951 .13827 Mdot
.55095 .02362 Mdot
.75728 .35527 Mdot
.27269 .27118 Mdot
.31226 .26034 Mdot
.36379 .14907 Mdot
.42156 .58542 Mdot
.40483 .12389 Mdot
.32144 .5439 Mdot
.70196 .38149 Mdot
.32704 .22651 Mdot
.34952 .15063 Mdot
.32014 .21714 Mdot
.27218 .27501 Mdot
.33625 .22695 Mdot
.34986 .13543 Mdot
.67934 .45956 Mdot
.7971 .36037 Mdot
.34159 .21106 Mdot
.49444 .61793 Mdot
.01753 .42452 Mdot
.78379 .35736 Mdot
.81204 .1307 Mdot
.03327 .21666 Mdot
.26951 .26501 Mdot
.45103 .12214 Mdot
.68983 .39152 Mdot
.69239 .39072 Mdot
.68055 .42795 Mdot
.46761 .13142 Mdot
.71327 .09013 Mdot
.12503 .24403 Mdot
.18293 .48765 Mdot
.05253 .22486 Mdot
.32997 .19787 Mdot
.35402 .13298 Mdot
.68575 .41745 Mdot
.41971 .12401 Mdot
.32844 .15026 Mdot
.33489 .16459 Mdot
.44301 .12983 Mdot
.37314 .12417 Mdot
.81763 .13512 Mdot
.03592 .42956 Mdot
.68583 .41745 Mdot
.36073 .12284 Mdot
.71906 .09498 Mdot
.84319 .37276 Mdot
.09711 .4543 Mdot
.69729 .37426 Mdot
.28334 .52887 Mdot
.80806 .13128 Mdot
.02353 .21353 Mdot
.57796 .03421 Mdot
.86564 .37806 Mdot
.68334 .42715 Mdot
.70362 .38348 Mdot
.92662 .39579 Mdot
.34429 .16582 Mdot
.6746 .47182 Mdot
.56425 .02739 Mdot
.43325 .12953 Mdot
.85814 .37341 Mdot
.65334 .06505 Mdot
.36793 .13961 Mdot
.7882 .36223 Mdot
.35405 .15882 Mdot
.69557 .39491 Mdot
.29092 .26318 Mdot
.40314 .12078 Mdot
.41089 .12212 Mdot
.38095 .12225 Mdot
.90488 .16884 Mdot
.72613 .36379 Mdot
.71953 .35813 Mdot
.25122 .26933 Mdot
.67874 .0763 Mdot
.23057 .27038 Mdot
.33112 .19368 Mdot
.62236 .05232 Mdot
.68088 .42503 Mdot
.24325 .2714 Mdot
.79095 .36052 Mdot
.0914 .23415 Mdot
.37308 .14236 Mdot
.182 .26173 Mdot
.28785 .27257 Mdot
.34026 .1474 Mdot
.70401 .38119 Mdot
.69446 .08383 Mdot
.82563 .36387 Mdot
.36053 .13077 Mdot
.68982 .38048 Mdot
.90231 .1686 Mdot
.69871 .39169 Mdot
.3438 .15376 Mdot
.32914 .54793 Mdot
.73978 .10321 Mdot
.37276 .13597 Mdot
.90901 .17019 Mdot
.31854 .23392 Mdot
.85684 .37575 Mdot
.41881 .58375 Mdot
.80409 .36187 Mdot
.78597 .12275 Mdot
.36632 .13726 Mdot
.99378 .41513 Mdot
.67908 .46376 Mdot
.46909 .12562 Mdot
.31148 .25256 Mdot
.68568 .38615 Mdot
.33658 .55197 Mdot
.14387 .25267 Mdot
.68055 .41637 Mdot
.46418 .12686 Mdot
.41501 .12225 Mdot
.34293 .18507 Mdot
.02673 .42933 Mdot
.53014 .01415 Mdot
.87333 .37932 Mdot
.90341 .16883 Mdot
.77432 .11612 Mdot
.0556 .43881 Mdot
.95382 .40192 Mdot
.38312 .13494 Mdot
.71414 .36738 Mdot
.32099 .21236 Mdot
.06893 .44427 Mdot
.70624 .3673 Mdot
.79788 .36485 Mdot
.36967 .13788 Mdot
.33118 .14945 Mdot
.08759 .44849 Mdot
.18649 .26261 Mdot
.76907 .3575 Mdot
.78946 .35798 Mdot
.72776 .09736 Mdot
.91477 .39124 Mdot
.24178 .26937 Mdot
.32705 .15259 Mdot
.38287 .56926 Mdot
.32976 .15896 Mdot
.29966 .26292 Mdot
.33312 .14094 Mdot
.87902 .37869 Mdot
.87106 .1549 Mdot
.67509 .46249 Mdot
.74248 .35462 Mdot
.31781 .25012 Mdot
.69683 .38036 Mdot
.6778 .45098 Mdot
.72407 .36067 Mdot
.34118 .19221 Mdot
.80596 .36004 Mdot
.68713 .42336 Mdot
.85088 .36946 Mdot
.40841 .13097 Mdot
.38718 .13128 Mdot
.37608 .13856 Mdot
.30558 .26363 Mdot
.70461 .37289 Mdot
.77265 .11532 Mdot
.68665 .41593 Mdot
.78833 .35629 Mdot
.66743 .07211 Mdot
.76864 .36324 Mdot
.09039 .44985 Mdot
.34783 .16175 Mdot
.06309 .22499 Mdot
.48387 .13344 Mdot
.33215 .17345 Mdot
.11835 .46133 Mdot
.36468 .14905 Mdot
.46059 .13138 Mdot
.33283 .22393 Mdot
.3379 .22614 Mdot
.7705 .35567 Mdot
.78958 .12121 Mdot
.32319 .1877 Mdot
.33059 .17458 Mdot
.63618 .06009 Mdot
.35127 .13257 Mdot
.03088 .21535 Mdot
.34322 .20293 Mdot
.34098 .16131 Mdot
.26431 .26453 Mdot
.99813 .41883 Mdot
.68507 .39469 Mdot
.40743 .12448 Mdot
.00597 .20471 Mdot
.70732 .37933 Mdot
.3652 .14134 Mdot
.35309 .15423 Mdot
.35121 .141 Mdot
.83682 .36719 Mdot
.02675 .4274 Mdot
.18334 .26224 Mdot
.15889 .25464 Mdot
.83735 .14338 Mdot
.44468 .59576 Mdot
.43756 .59228 Mdot
.32933 .19227 Mdot
.79583 .1256 Mdot
.69589 .39772 Mdot
.34213 .1853 Mdot
.68616 .38872 Mdot
.79034 .12311 Mdot
.39307 .12388 Mdot
.45607 .12557 Mdot
.06624 .44049 Mdot
.34125 .19905 Mdot
.46348 .12419 Mdot
.99498 .41673 Mdot
.81789 .36406 Mdot
.31733 .22746 Mdot
.1784 .48703 Mdot
.69599 .37822 Mdot
.73845 .36542 Mdot
.34397 .16779 Mdot
.68792 .39543 Mdot
.39527 .13379 Mdot
.30112 .2541 Mdot
.68289 .40203 Mdot
.32949 .20662 Mdot
.3782 .123 Mdot
.33594 .23822 Mdot
.71879 .36411 Mdot
.99076 .41294 Mdot
.35231 .12449 Mdot
.12026 .46212 Mdot
.02389 .42613 Mdot
.7135 .36084 Mdot
.08148 .23227 Mdot
.30674 .26932 Mdot
.36997 .56438 Mdot
.33826 .17814 Mdot
.22462 .2718 Mdot
.94103 .3984 Mdot
.27152 .52397 Mdot
.3516 .14123 Mdot
.11813 .46175 Mdot
.79373 .12329 Mdot
.67008 .47556 Mdot
.80728 .35939 Mdot
.1599 .25519 Mdot
.32068 .21351 Mdot
.68842 .38556 Mdot
.70811 .37257 Mdot
.30488 .25113 Mdot
.44573 .12756 Mdot
.95072 .18629 Mdot
.68878 .40822 Mdot
.68552 .39021 Mdot
.90696 .16839 Mdot
.68165 .40523 Mdot
.73901 .3553 Mdot
.31049 .25737 Mdot
.1695 .48075 Mdot
.86592 .15313 Mdot
.44462 .59653 Mdot
.31982 .23734 Mdot
.07874 .23281 Mdot
.4069 .58106 Mdot
.426 .58807 Mdot
.79883 .36358 Mdot
.32916 .17892 Mdot
.43533 .12265 Mdot
.04635 .21891 Mdot
.94587 .39769 Mdot
.68743 .38246 Mdot
.40294 .12664 Mdot
.34819 .13955 Mdot
.74202 .35889 Mdot
.04129 .21931 Mdot
.39392 .12599 Mdot
.68259 .41638 Mdot
.3991 .13269 Mdot
.5891 .04041 Mdot
.32966 .17767 Mdot
.34172 .18384 Mdot
.63995 .05946 Mdot
.22948 .27077 Mdot
.28213 .26692 Mdot
.2518 .26918 Mdot
.30274 .27017 Mdot
.95305 .40328 Mdot
.2091 .26414 Mdot
.72052 .36969 Mdot
.33534 .16392 Mdot
.36445 .14188 Mdot
.34708 .12658 Mdot
.97877 .4128 Mdot
.32096 .26084 Mdot
.17611 .25717 Mdot
.37894 .12852 Mdot
.736 .36693 Mdot
.79979 .12736 Mdot
.32223 .19423 Mdot
.32991 .19179 Mdot
.33496 .16494 Mdot
.50538 .13439 Mdot
.71205 .3735 Mdot
.48297 .12958 Mdot
.42086 .12109 Mdot
.24693 .27354 Mdot
.26067 .51875 Mdot
.16853 .25574 Mdot
.44922 .59817 Mdot
.99629 .4171 Mdot
.01944 .21137 Mdot
.52639 .01203 Mdot
.21966 .26434 Mdot
.76159 .11066 Mdot
.30209 .26306 Mdot
.05877 .22464 Mdot
.3482 .17476 Mdot
.70554 .3797 Mdot
.30278 .53681 Mdot
.65174 .06499 Mdot
.33093 .14467 Mdot
.16327 .48034 Mdot
.05131 .22248 Mdot
.33544 .16627 Mdot
.33702 .16034 Mdot
.92886 .39184 Mdot
.28117 .52875 Mdot
.3698 .13337 Mdot
.33568 .23262 Mdot
.31608 .23155 Mdot
.91868 .38983 Mdot
.76526 .11357 Mdot
.01769 .42325 Mdot
.68028 .42226 Mdot
.38986 .12997 Mdot
.42972 .59034 Mdot
.68745 .43209 Mdot
.41861 .12091 Mdot
.34103 .16067 Mdot
.02596 .42915 Mdot
.02182 .4262 Mdot
.84337 .14583 Mdot
.35951 .12685 Mdot
.34756 .12887 Mdot
.08256 .23032 Mdot
.32451 .18485 Mdot
.32795 .19282 Mdot
.19048 .26157 Mdot
.39867 .13179 Mdot
.33691 .22206 Mdot
.6876 .43095 Mdot
.27719 .27394 Mdot
.36847 .13799 Mdot
.18991 .49204 Mdot
.34608 .14516 Mdot
.11226 .46083 Mdot
.84514 .36995 Mdot
.61593 .05121 Mdot
.28571 .52837 Mdot
.32676 .21057 Mdot
.21245 .26427 Mdot
.77216 .35852 Mdot
.34033 .20742 Mdot
.33231 .21681 Mdot
.32413 .20202 Mdot
.20936 .26649 Mdot
.45144 .12358 Mdot
.74189 .10411 Mdot
.32585 .21599 Mdot
.67292 .47462 Mdot
.98249 .41012 Mdot
.2984 .53568 Mdot
.36249 .14791 Mdot
.68996 .39785 Mdot
.67804 .43324 Mdot
.97513 .19627 Mdot
.64009 .06184 Mdot
.32762 .16686 Mdot
.91775 .38873 Mdot
.10636 .2392 Mdot
.33036 .24471 Mdot
.02157 .21102 Mdot
.13206 .4682 Mdot
.20754 .49735 Mdot
.27717 .27345 Mdot
.73756 .35541 Mdot
.00791 .2086 Mdot
.33885 .15652 Mdot
.9577 .40561 Mdot
.35494 .12857 Mdot
.37259 .13758 Mdot
.12902 .24914 Mdot
.39942 .57838 Mdot
.38323 .13022 Mdot
.68088 .45937 Mdot
.93425 .17901 Mdot
.9891 .19992 Mdot
.82511 .36329 Mdot
.75365 .35932 Mdot
.1525 .25426 Mdot
.70094 .38701 Mdot
.09313 .23558 Mdot
.31685 .54333 Mdot
.74362 .35917 Mdot
.75724 .36334 Mdot
.53861 .01867 Mdot
.70791 .37968 Mdot
.33798 .17049 Mdot
.91639 .17235 Mdot
.90377 .16801 Mdot
.9358 .18149 Mdot
.46895 .12461 Mdot
.0874 .44879 Mdot
.79459 .12418 Mdot
.70989 .36912 Mdot
.84451 .14612 Mdot
.72616 .36419 Mdot
.67783 .45742 Mdot
.84687 .37366 Mdot
.17064 .48288 Mdot
.27567 .27075 Mdot
.32272 .21336 Mdot
.10275 .45735 Mdot
.3349 .1692 Mdot
.36692 .13726 Mdot
.89169 .38039 Mdot
.30787 .2539 Mdot
.3634 .12106 Mdot
.33057 .23961 Mdot
.3389 .13697 Mdot
.31398 .26372 Mdot
.33156 .21783 Mdot
.36133 .12524 Mdot
.35368 .13591 Mdot
.3346 .17504 Mdot
.67657 .45021 Mdot
.46146 .12481 Mdot
.38038 .13821 Mdot
.08974 .4507 Mdot
.35076 .15372 Mdot
.33741 .19058 Mdot
.34938 .14887 Mdot
.03599 .43188 Mdot
.67904 .4266 Mdot
.9094 .38772 Mdot
.07099 .44428 Mdot
.26297 .51856 Mdot
.83701 .36937 Mdot
.71497 .09131 Mdot
.92843 .17836 Mdot
.11342 .46143 Mdot
.35031 .1687 Mdot
.65356 .06543 Mdot
.34156 .14765 Mdot
.11683 .46121 Mdot
.32673 .21589 Mdot
.8967 .38707 Mdot
.25455 .27257 Mdot
.34523 .18824 Mdot
.00637 .4185 Mdot
.88556 .38208 Mdot
.38632 .1219 Mdot
.48123 .12832 Mdot
.16024 .47856 Mdot
.1853 .26185 Mdot
.33254 .54791 Mdot
.72713 .35776 Mdot
.34453 .17693 Mdot
.69244 .38225 Mdot
.68914 .38431 Mdot
.89968 .16571 Mdot
.42775 .13118 Mdot
.59882 .04347 Mdot
.36345 .133 Mdot
.91467 .17328 Mdot
.88469 .15904 Mdot
.32618 .16913 Mdot
.04623 .43599 Mdot
.35221 .16208 Mdot
.44583 .59512 Mdot
.28713 .2705 Mdot
.83909 .14407 Mdot
.6922 .40696 Mdot
.31647 .26221 Mdot
.34702 .17684 Mdot
.30055 .26051 Mdot
.80725 .3606 Mdot
.69281 .39337 Mdot
.04535 .43273 Mdot
.38608 .12452 Mdot
.28374 .26392 Mdot
.82754 .13823 Mdot
.76538 .35876 Mdot
.76199 .36042 Mdot
.67948 .4211 Mdot
.32137 .25332 Mdot
.51258 .00564 Mdot
.36059 .12841 Mdot
.33644 .55186 Mdot
.4547 .13141 Mdot
.40399 .12772 Mdot
.3817 .12209 Mdot
.83548 .36878 Mdot
.31874 .26024 Mdot
.6738 .46913 Mdot
.48779 .61361 Mdot
.32384 .17319 Mdot
.35621 .13753 Mdot
.20373 .26764 Mdot
.33497 .14475 Mdot
.69551 .37106 Mdot
.68238 .42749 Mdot
.16795 .48069 Mdot
.86204 .37617 Mdot
.00541 .42062 Mdot
.337 .22146 Mdot
.88609 .38198 Mdot
.86868 .37694 Mdot
.19536 .49296 Mdot
.87157 .37469 Mdot
.38074 .13089 Mdot
.1328 .25018 Mdot
.32946 .23587 Mdot
.66021 .07001 Mdot
.98642 .41271 Mdot
.69022 .37886 Mdot
.76592 .36131 Mdot
.10265 .23749 Mdot
.32739 .16129 Mdot
.88583 .16171 Mdot
.31118 .25523 Mdot
.72387 .36532 Mdot
.38029 .13319 Mdot
.33488 .20188 Mdot
.69392 .37547 Mdot
.97056 .19492 Mdot
.41871 .12367 Mdot
.0734 .44588 Mdot
.44221 .13044 Mdot
.30354 .26276 Mdot
.47309 .1296 Mdot
.27821 .52786 Mdot
.065 .44123 Mdot
.70369 .37496 Mdot
.14732 .25261 Mdot
.0498 .22314 Mdot
.26014 .5191 Mdot
.81642 .3684 Mdot
.03186 .21726 Mdot
.32736 .17931 Mdot
.32788 .25069 Mdot
.11702 .46192 Mdot
.00555 .20447 Mdot
.73142 .36516 Mdot
.43586 .59279 Mdot
.35774 .12658 Mdot
.44199 .13094 Mdot
.19312 .26251 Mdot
.13278 .24743 Mdot
.14023 .24998 Mdot
.81056 .36398 Mdot
.30088 .25933 Mdot
.32472 .24511 Mdot
.03124 .21642 Mdot
.70111 .38893 Mdot
.97544 .40726 Mdot
.36682 .14806 Mdot
.05098 .22345 Mdot
.32148 .19797 Mdot
.33653 .15298 Mdot
.43975 .5943 Mdot
.81632 .13448 Mdot
.68373 .39255 Mdot
.32374 .23621 Mdot
.14626 .25076 Mdot
.32015 .54449 Mdot
.30473 .2658 Mdot
.40593 .1245 Mdot
.40117 .1278 Mdot
.28411 .27345 Mdot
.46721 .12506 Mdot
.31919 .25131 Mdot
.23944 .26645 Mdot
.46563 .60603 Mdot
.63627 .058 Mdot
.20537 .26421 Mdot
.44761 .12574 Mdot
.49687 .00074 Mdot
.00962 .41923 Mdot
.11667 .45958 Mdot
.97338 .19374 Mdot
.33311 .14696 Mdot
.20933 .26574 Mdot
.28562 .52951 Mdot
.34584 .1406 Mdot
.73047 .36565 Mdot
.26627 .5205 Mdot
.75749 .10889 Mdot
.88539 .16084 Mdot
.85528 .37365 Mdot
.6975 .38388 Mdot
.33966 .17063 Mdot
.90651 .16805 Mdot
.343 .15217 Mdot
.70098 .39045 Mdot
.31935 .26119 Mdot
.69529 .38182 Mdot
.65314 .06547 Mdot
.28418 .26168 Mdot
.51588 .13507 Mdot
.21625 .50155 Mdot
.33549 .16466 Mdot
.71867 .36156 Mdot
.78681 .36304 Mdot
.1383 .24713 Mdot
.85625 .37211 Mdot
.30074 .26227 Mdot
.32807 .2141 Mdot
.77846 .11716 Mdot
.79363 .35756 Mdot
.31743 .23104 Mdot
.83937 .36667 Mdot
.11996 .24381 Mdot
.2066 .26691 Mdot
.0633 .4397 Mdot
.18569 .26396 Mdot
.28422 .26147 Mdot
.87206 .37801 Mdot
.75116 .36032 Mdot
.48107 .61074 Mdot
.24566 .26922 Mdot
.68831 .38751 Mdot
.33072 .17987 Mdot
.32087 .20423 Mdot
.60884 .04871 Mdot
.24925 .51373 Mdot
.42674 .12364 Mdot
.3687 .123 Mdot
.96449 .40615 Mdot
.36404 .13993 Mdot
.678 .43687 Mdot
.45963 .60238 Mdot
.18218 .26098 Mdot
.79347 .35952 Mdot
.31015 .25104 Mdot
.25398 .51585 Mdot
.65386 .06619 Mdot
.3382 .13335 Mdot
.2187 .26879 Mdot
.72396 .36934 Mdot
.81126 .36047 Mdot
.70601 .3624 Mdot
.69482 .37357 Mdot
.36903 .13036 Mdot
.32657 .23095 Mdot
.25452 .26711 Mdot
.35557 .12416 Mdot
.71232 .09204 Mdot
.32189 .25399 Mdot
.70693 .08962 Mdot
.67876 .44426 Mdot
.8064 .35946 Mdot
.40729 .13242 Mdot
.67798 .45117 Mdot
.33843 .22139 Mdot
.85692 .37362 Mdot
.36249 .12977 Mdot
.01248 .20823 Mdot
.34171 .13958 Mdot
.89154 .3826 Mdot
.3835 .57018 Mdot
.40644 .12482 Mdot
.99859 .41682 Mdot
.30911 .26022 Mdot
.99885 .2036 Mdot
.20888 .26581 Mdot
.3807 .1248 Mdot
.06192 .22816 Mdot
.67387 .47221 Mdot
.37154 .13321 Mdot
.86137 .37682 Mdot
.1592 .25285 Mdot
.3294 .20834 Mdot
.3322 .20174 Mdot
.3295 .54619 Mdot
.98204 .41338 Mdot
.42504 .1213 Mdot
.20602 .26399 Mdot
.67903 .45182 Mdot
.84881 .37046 Mdot
.67329 .46776 Mdot
.93294 .18026 Mdot
.3421 .13573 Mdot
.34094 .16211 Mdot
.14167 .47217 Mdot
.67674 .45634 Mdot
.35374 .15187 Mdot
.33683 .14308 Mdot
.32094 .22321 Mdot
.79607 .12641 Mdot
.28548 .2604 Mdot
.71512 .36769 Mdot
.23324 .26457 Mdot
.3437 .17233 Mdot
.36827 .14134 Mdot
.34091 .13954 Mdot
.82128 .13408 Mdot
.32809 .16984 Mdot
.32972 .18345 Mdot
.50444 .13523 Mdot
.67943 .45779 Mdot
.1325 .24594 Mdot
.80439 .35935 Mdot
.23854 .27141 Mdot
.9906 .19938 Mdot
.41702 .13117 Mdot
.32964 .17809 Mdot
.41297 .12608 Mdot
.84025 .36745 Mdot
.69805 .39483 Mdot
.26673 .27475 Mdot
.7195 .36859 Mdot
.13297 .2493 Mdot
.84393 .1444 Mdot
.87671 .37949 Mdot
.44244 .12351 Mdot
.27615 .27012 Mdot
.93324 .39657 Mdot
.32489 .22075 Mdot
.74809 .10728 Mdot
.49661 .61684 Mdot
.98666 .4127 Mdot
.67955 .46036 Mdot
.18022 .48752 Mdot
.19577 .26246 Mdot
.32939 .20475 Mdot
.0204 .21271 Mdot
.36029 .14132 Mdot
.32707 .1836 Mdot
.34656 .17974 Mdot
.88425 .38308 Mdot
.04704 .2229 Mdot
.33683 .22072 Mdot
.72856 .36387 Mdot
.31745 .25478 Mdot
.41769 .12594 Mdot
.6841 .43961 Mdot
.71581 .36546 Mdot
.30058 .26304 Mdot
.63771 .06033 Mdot
.32874 .19798 Mdot
.3429 .17626 Mdot
.32333 .23617 Mdot
.76305 .11287 Mdot
.73289 .36333 Mdot
.80161 .35998 Mdot
.30014 .27081 Mdot
.47903 .61064 Mdot
.11905 .24485 Mdot
.72713 .35664 Mdot
.32712 .18095 Mdot
.3574 .13251 Mdot
.81891 .36792 Mdot
.99114 .41538 Mdot
.48423 .6127 Mdot
.42891 .12744 Mdot
.62827 .0568 Mdot
.3213 .24779 Mdot
.40744 .13055 Mdot
.7665 .35445 Mdot
.07832 .4455 Mdot
.83588 .37208 Mdot
.56841 .02905 Mdot
.79616 .3619 Mdot
.42969 .58879 Mdot
.48832 .13205 Mdot
.75563 .36167 Mdot
.67959 .44139 Mdot
.38292 .13554 Mdot
.88514 .16102 Mdot
.50879 .13478 Mdot
.77276 .35808 Mdot
.33444 .22646 Mdot
.73507 .36004 Mdot
.82578 .36814 Mdot
.49409 .1296 Mdot
.33039 .2248 Mdot
.83843 .37224 Mdot
.3376 .21951 Mdot
.486 .12886 Mdot
.43811 .13059 Mdot
.06776 .22708 Mdot
.46565 .13229 Mdot
.023 .21437 Mdot
.8073 .36071 Mdot
.92696 .39328 Mdot
.76002 .35847 Mdot
.0751 .44589 Mdot
.28074 .2741 Mdot
.95794 .40431 Mdot
.3241 .18328 Mdot
.18241 .48858 Mdot
.67829 .45657 Mdot
.32232 .24303 Mdot
.69185 .37942 Mdot
.28153 .52805 Mdot
.46894 .12998 Mdot
.67972 .44308 Mdot
.33222 .18624 Mdot
.34693 .14629 Mdot
.18631 .48889 Mdot
.33984 .19552 Mdot
.70417 .08727 Mdot
.27098 .27494 Mdot
.37879 .56778 Mdot
.33686 .16451 Mdot
.74357 .35561 Mdot
.29845 .26966 Mdot
.00088 .4173 Mdot
.12971 .24822 Mdot
.32176 .25749 Mdot
.20745 .26355 Mdot
.8789 .37855 Mdot
.39572 .12022 Mdot
.42533 .13102 Mdot
.1108 .24161 Mdot
.96127 .19081 Mdot
.25998 .26601 Mdot
.84424 .37006 Mdot
.725 .35974 Mdot
.33119 .15562 Mdot
.33443 .19191 Mdot
.21826 .50102 Mdot
.69242 .38639 Mdot
.98247 .41342 Mdot
.98393 .41358 Mdot
.83546 .14258 Mdot
.27049 .26691 Mdot
.33833 .14426 Mdot
.34375 .13185 Mdot
.34485 .16949 Mdot
.39046 .13304 Mdot
.3545 .14364 Mdot
.68876 .40652 Mdot
.65966 .06843 Mdot
.33152 .14654 Mdot
.20121 .49484 Mdot
.32779 .19833 Mdot
.42905 .12051 Mdot
.67964 .41829 Mdot
.69198 .39531 Mdot
.09744 .45541 Mdot
.65124 .06573 Mdot
.96489 .40346 Mdot
.7743 .11487 Mdot
.49936 .00175 Mdot
.79982 .3632 Mdot
.67275 .07469 Mdot
.32536 .19931 Mdot
.17359 .2572 Mdot
.36207 .13632 Mdot
.66562 .07076 Mdot
.32251 .22314 Mdot
.06787 .44229 Mdot
.83019 .1395 Mdot
.36383 .128 Mdot
.36858 .13278 Mdot
.32874 .24108 Mdot
.37291 .14182 Mdot
.73429 .35571 Mdot
.43578 .12508 Mdot
.34046 .19634 Mdot
.68277 .42296 Mdot
.86782 .37635 Mdot
.86388 .1542 Mdot
.32891 .15988 Mdot
.35457 .1324 Mdot
.45958 .12414 Mdot
.7637 .36181 Mdot
.13992 .2525 Mdot
.77163 .11645 Mdot
.03224 .43098 Mdot
.17504 .48292 Mdot
.5798 .03389 Mdot
.8732 .15773 Mdot
.28278 .52833 Mdot
.78612 .36467 Mdot
.60118 .04398 Mdot
.75637 .35991 Mdot
.00895 .20832 Mdot
.77665 .36282 Mdot
.72752 .36663 Mdot
.25461 .26501 Mdot
.44014 .12686 Mdot
.80836 .13179 Mdot
.9799 .19818 Mdot
.33325 .13873 Mdot
.68659 .40765 Mdot
.3349 .13946 Mdot
.34591 .17548 Mdot
.35353 .1387 Mdot
.76811 .35562 Mdot
.36009 .14011 Mdot
.8561 .37334 Mdot
.75263 .3607 Mdot
.43044 .59076 Mdot
.35938 .14337 Mdot
.46794 .13094 Mdot
.3642 .13871 Mdot
.36766 .1359 Mdot
.36813 .13373 Mdot
.97501 .41057 Mdot
.34796 .12747 Mdot
.39985 .12335 Mdot
.8128 .36383 Mdot
.2848 .26128 Mdot
.85305 .3749 Mdot
.68013 .07707 Mdot
.87315 .37551 Mdot
.14522 .25087 Mdot
.05655 .22396 Mdot
.34815 .16161 Mdot
.34369 .18221 Mdot
.33996 .22139 Mdot
.33815 .19521 Mdot
.29932 .26089 Mdot
.78766 .121 Mdot
.35242 .13134 Mdot
.56758 .02968 Mdot
.30234 .26983 Mdot
.68698 .39778 Mdot
.39636 .12055 Mdot
.33219 .23264 Mdot
.19429 .4929 Mdot
.48457 .13065 Mdot
.33911 .1956 Mdot
.82675 .36423 Mdot
.68807 .42766 Mdot
.40171 .13305 Mdot
.67991 .43628 Mdot
.62521 .05478 Mdot
.06953 .22684 Mdot
.91238 .38833 Mdot
.33139 .22995 Mdot
.33058 .23218 Mdot
.15889 .25742 Mdot
.34185 .18192 Mdot
.31326 .24412 Mdot
.82748 .13838 Mdot
.35418 .15374 Mdot
.32726 .23875 Mdot
.33589 .21348 Mdot
.74503 .35327 Mdot
.70936 .37481 Mdot
.70586 .38061 Mdot
.17204 .26039 Mdot
.14678 .25414 Mdot
.78947 .36479 Mdot
.29934 .25658 Mdot
.45916 .60301 Mdot
.35295 .55775 Mdot
.33602 .23451 Mdot
.35549 .15918 Mdot
.33851 .14336 Mdot
.15509 .25636 Mdot
.38192 .12923 Mdot
.31875 .54267 Mdot
.10409 .24072 Mdot
.38468 .11953 Mdot
.08775 .23588 Mdot
.81242 .36158 Mdot
.68167 .41185 Mdot
.42449 .12198 Mdot
.97663 .19449 Mdot
.30839 .53949 Mdot
.34811 .17388 Mdot
.40722 .12643 Mdot
.32836 .19219 Mdot
.99617 .20267 Mdot
.53408 .01597 Mdot
.64864 .06283 Mdot
.43895 .12288 Mdot
.44997 .59934 Mdot
.36283 .13625 Mdot
.93006 .39269 Mdot
.0273 .42741 Mdot
.6974 .38942 Mdot
.303 .26193 Mdot
.00915 .42221 Mdot
.32784 .18716 Mdot
.30832 .25435 Mdot
.12768 .24757 Mdot
.7177 .36317 Mdot
.53041 .01302 Mdot
.37032 .12869 Mdot
.31621 .24967 Mdot
.15583 .25299 Mdot
.0128 .4203 Mdot
.30849 .2655 Mdot
.3365 .1726 Mdot
.95739 .40122 Mdot
.35523 .12726 Mdot
.33926 .19172 Mdot
.12124 .24464 Mdot
.08206 .23211 Mdot
.6918 .4105 Mdot
.3439 .18934 Mdot
.91228 .38636 Mdot
.71479 .37133 Mdot
.33067 .14457 Mdot
.29051 .27049 Mdot
.86574 .37587 Mdot
.94611 .40038 Mdot
.80224 .36036 Mdot
.31341 .26507 Mdot
.34903 .15933 Mdot
.41498 .11905 Mdot
.3164 .24287 Mdot
.58157 .03635 Mdot
.18488 .48747 Mdot
.76963 .35394 Mdot
.32484 .54488 Mdot
.32461 .21842 Mdot
.07655 .44667 Mdot
.29372 .26691 Mdot
.39062 .11855 Mdot
.74553 .36143 Mdot
.18518 .48894 Mdot
.68171 .41944 Mdot
.08612 .2331 Mdot
.33531 .18177 Mdot
.69252 .37801 Mdot
.93911 .18182 Mdot
.38429 .1353 Mdot
.30041 .25742 Mdot
.0009 .20351 Mdot
.78929 .36189 Mdot
.32796 .2462 Mdot
.67176 .47186 Mdot
.92693 .39164 Mdot
.47657 .13074 Mdot
.37353 .13735 Mdot
.76302 .35748 Mdot
.32634 .24427 Mdot
.36124 .14963 Mdot
.40202 .12895 Mdot
.70874 .37939 Mdot
.23754 .51004 Mdot
.32333 .17414 Mdot
.34736 .16578 Mdot
.46996 .13255 Mdot
.7844 .12105 Mdot
.33332 .1432 Mdot
.33685 .22183 Mdot
.35432 .14744 Mdot
.35192 .12404 Mdot
.77418 .36213 Mdot
.72965 .35945 Mdot
.67928 .45141 Mdot
.41285 .1252 Mdot
.68459 .39746 Mdot
.23134 .50857 Mdot
.77425 .35532 Mdot
.32868 .1894 Mdot
.82393 .36265 Mdot
.82869 .36654 Mdot
.08073 .23137 Mdot
.76139 .35655 Mdot
.07625 .23097 Mdot
.82961 .37094 Mdot
.77268 .11568 Mdot
.70193 .37252 Mdot
.00535 .4191 Mdot
.37145 .1228 Mdot
.68328 .44384 Mdot
.68433 .39542 Mdot
.30041 .25643 Mdot
.42598 .12167 Mdot
.08519 .45056 Mdot
.32692 .21206 Mdot
.30492 .25499 Mdot
.32313 .23035 Mdot
.44327 .59648 Mdot
.94718 .18318 Mdot
.39807 .11891 Mdot
.3321 .22928 Mdot
.34881 .13073 Mdot
.11448 .24312 Mdot
.71267 .35949 Mdot
.3311 .24878 Mdot
.68293 .42787 Mdot
.3501 .15277 Mdot
.04877 .22336 Mdot
.688 .41632 Mdot
.68204 .41687 Mdot
.68042 .077 Mdot
.82434 .36733 Mdot
.3611 .13807 Mdot
.79421 .36056 Mdot
.03375 .21846 Mdot
.37721 .12324 Mdot
.31765 .22254 Mdot
.33317 .15785 Mdot
.68819 .4077 Mdot
.90361 .16755 Mdot
.806 .36691 Mdot
.25514 .5159 Mdot
.30245 .26514 Mdot
.10006 .45503 Mdot
.29506 .25643 Mdot
.67974 .43451 Mdot
.11056 .45735 Mdot
.8539 .37364 Mdot
.91367 .17047 Mdot
.02211 .42537 Mdot
.26029 .27282 Mdot
.31528 .23588 Mdot
.23618 .27152 Mdot
.06523 .22881 Mdot
.32961 .1543 Mdot
.70605 .37167 Mdot
.68536 .3892 Mdot
.68539 .4317 Mdot
.40491 .13295 Mdot
.39166 .12608 Mdot
.29621 .53525 Mdot
.1612 .25372 Mdot
.28112 .26432 Mdot
.32419 .20022 Mdot
.81843 .36441 Mdot
.53379 .01503 Mdot
.95169 .40055 Mdot
.80407 .12985 Mdot
.69265 .38771 Mdot
.27934 .52713 Mdot
.12189 .4627 Mdot
.18186 .2631 Mdot
.71896 .3641 Mdot
.37128 .13559 Mdot
.49893 .00011 Mdot
.42873 .12005 Mdot
.31143 .54098 Mdot
.08076 .23132 Mdot
.38972 .1191 Mdot
.8921 .38267 Mdot
.3258 .1763 Mdot
.47159 .12981 Mdot
.30938 .26427 Mdot
.32125 .25923 Mdot
.59525 .04153 Mdot
.30391 .25469 Mdot
.35159 .12843 Mdot
.33941 .17737 Mdot
.32957 .21768 Mdot
.73719 .35761 Mdot
.2848 .26102 Mdot
.47519 .12807 Mdot
.45048 .13053 Mdot
.81395 .36781 Mdot
.91827 .38886 Mdot
.61193 .04733 Mdot
.43107 .12505 Mdot
.38595 .13174 Mdot
.40303 .12072 Mdot
.68218 .42243 Mdot
.72625 .35604 Mdot
.45189 .12787 Mdot
.56729 .02848 Mdot
.32724 .15376 Mdot
.16384 .25323 Mdot
.32674 .1638 Mdot
.88658 .16296 Mdot
.059 .43765 Mdot
.33247 .54782 Mdot
.11793 .24244 Mdot
.10604 .24056 Mdot
.59959 .04257 Mdot
.99889 .41769 Mdot
.13821 .24821 Mdot
.33443 .19634 Mdot
.24534 .26791 Mdot
.7032 .37971 Mdot
.31075 .24784 Mdot
.3379 .18147 Mdot
.97697 .40816 Mdot
.16541 .48042 Mdot
.37743 .13664 Mdot
.40615 .1294 Mdot
.43431 .59235 Mdot
.18572 .2597 Mdot
.32707 .22154 Mdot
.41167 .12585 Mdot
.68099 .42747 Mdot
.32768 .18797 Mdot
.0049 .20781 Mdot
.74953 .36075 Mdot
.73032 .36751 Mdot
.32251 .21688 Mdot
.51719 .01011 Mdot
.36775 .12248 Mdot
.35114 .12949 Mdot
.95967 .4017 Mdot
.32697 .54774 Mdot
.82287 .13546 Mdot
.88868 .38325 Mdot
.20214 .26099 Mdot
.37574 .13707 Mdot
.23089 .26806 Mdot
.30135 .25247 Mdot
.32734 .19959 Mdot
.71649 .09148 Mdot
.43008 .13045 Mdot
.33256 .24166 Mdot
.25899 .27493 Mdot
.86528 .37284 Mdot
.43693 .12257 Mdot
.75196 .35673 Mdot
.29449 .53354 Mdot
.73148 .09883 Mdot
.29646 .25893 Mdot
.31301 .25265 Mdot
.4772 .13173 Mdot
.71106 .36619 Mdot
.95341 .40431 Mdot
.23847 .26857 Mdot
.11132 .23914 Mdot
.92148 .3908 Mdot
.31307 .25047 Mdot
.67671 .44872 Mdot
.9526 .18785 Mdot
.32653 .23411 Mdot
.3316 .21445 Mdot
.67419 .47163 Mdot
.34639 .15415 Mdot
.41213 .12712 Mdot
.33528 .2008 Mdot
.96274 .40446 Mdot
.7118 .37341 Mdot
.34077 .12974 Mdot
.19037 .48957 Mdot
.32583 .16231 Mdot
.40492 .11876 Mdot
.03433 .43027 Mdot
.72039 .09566 Mdot
.9225 .39159 Mdot
.94762 .18448 Mdot
.77783 .1184 Mdot
.37434 .13452 Mdot
.69103 .38885 Mdot
.31422 .24067 Mdot
.68732 .39648 Mdot
.08616 .23585 Mdot
.71352 .36202 Mdot
.6251 .05425 Mdot
.4262 .12241 Mdot
.73764 .36076 Mdot
.30098 .25669 Mdot
.1412 .24822 Mdot
.40924 .5814 Mdot
.3369 .16484 Mdot
.77946 .35767 Mdot
.68576 .42216 Mdot
.6813 .42461 Mdot
.30495 .25719 Mdot
.47158 .13152 Mdot
.57994 .03657 Mdot
.36062 .12553 Mdot
.73463 .35942 Mdot
.73645 .3546 Mdot
.95521 .18686 Mdot
.38579 .12305 Mdot
.3544 .15258 Mdot
.30245 .25464 Mdot
.32907 .22453 Mdot
.09765 .23521 Mdot
.67938 .45943 Mdot
.29575 .2575 Mdot
.32267 .22666 Mdot
.37402 .13779 Mdot
.33808 .21966 Mdot
.28129 .27204 Mdot
.72735 .36598 Mdot
.15965 .25352 Mdot
.78624 .12251 Mdot
.32473 .17928 Mdot
.27823 .26699 Mdot
.7187 .35725 Mdot
.17805 .25734 Mdot
.31805 .26088 Mdot
.45338 .13013 Mdot
.30055 .25333 Mdot
.76301 .35395 Mdot
.81077 .36205 Mdot
.84571 .37013 Mdot
.11631 .24071 Mdot
.38171 .1266 Mdot
.39518 .13461 Mdot
.80199 .35986 Mdot
.32126 .25975 Mdot
.08329 .23066 Mdot
.33904 .13249 Mdot
.30929 .24632 Mdot
.55807 .02761 Mdot
.46817 .60471 Mdot
.70726 .38154 Mdot
.21886 .50251 Mdot
.71913 .0941 Mdot
.02432 .42473 Mdot
.32393 .24593 Mdot
.93758 .39845 Mdot
.79339 .36257 Mdot
.2686 .27338 Mdot
.78446 .36106 Mdot
.34609 .15986 Mdot
.39095 .12602 Mdot
.22593 .50536 Mdot
.46091 .13122 Mdot
.78832 .3653 Mdot
.92111 .17439 Mdot
.34422 .18968 Mdot
.40455 .1257 Mdot
.62519 .05321 Mdot
.30434 .24873 Mdot
.37955 .11828 Mdot
.30439 .25873 Mdot
.14832 .47426 Mdot
.36368 .1423 Mdot
.33216 .14001 Mdot
.43835 .12675 Mdot
.33212 .1406 Mdot
.63737 .05946 Mdot
.94955 .39862 Mdot
.28152 .27216 Mdot
.45385 .13147 Mdot
.35237 .15297 Mdot
.38511 .12871 Mdot
.69428 .3867 Mdot
.01742 .20865 Mdot
.41141 .58231 Mdot
.07735 .22868 Mdot
.08578 .23491 Mdot
.13373 .2453 Mdot
.6853 .43265 Mdot
.78891 .12383 Mdot
.13357 .24814 Mdot
.26256 .27495 Mdot
.3625 .14338 Mdot
.17942 .25817 Mdot
.31867 .24571 Mdot
.36437 .12098 Mdot
.89217 .16504 Mdot
.12734 .46445 Mdot
.3301 .15363 Mdot
.30018 .25682 Mdot
.43526 .12688 Mdot
.39544 .57469 Mdot
.3047 .53672 Mdot
.36607 .12485 Mdot
.3025 .26238 Mdot
.93376 .39342 Mdot
.33268 .1454 Mdot
.90121 .16853 Mdot
.1411 .24857 Mdot
.44439 .12142 Mdot
.24498 .2663 Mdot
.06571 .44159 Mdot
.32889 .19356 Mdot
.32886 .16437 Mdot
.09711 .45195 Mdot
.45799 .12686 Mdot
.33979 .16072 Mdot
.32527 .24731 Mdot
.34389 .14608 Mdot
.41848 .58624 Mdot
.79123 .35771 Mdot
.8082 .36096 Mdot
.93765 .17956 Mdot
.46991 .12689 Mdot
.36921 .13737 Mdot
.75024 .36101 Mdot
.89845 .16702 Mdot
.00329 .42053 Mdot
.13229 .24626 Mdot
.90369 .16684 Mdot
.36033 .14832 Mdot
.9836 .41094 Mdot
.1464 .25258 Mdot
.67512 .45756 Mdot
.39433 .12556 Mdot
.68546 .40636 Mdot
.89542 .38619 Mdot
.69686 .39641 Mdot
.29238 .26026 Mdot
.40028 .12695 Mdot
.99374 .41763 Mdot
.38386 .57083 Mdot
.08258 .44664 Mdot
.38907 .11787 Mdot
.36368 .12816 Mdot
.36226 .12751 Mdot
.73452 .36587 Mdot
.32527 .19328 Mdot
.47106 .1289 Mdot
.35637 .14106 Mdot
.14896 .47468 Mdot
.48011 .1295 Mdot
.84911 .3732 Mdot
.25783 .26774 Mdot
.34203 .17005 Mdot
.34515 .17961 Mdot
.32896 .18412 Mdot
.33379 .19478 Mdot
.33928 .16426 Mdot
.35223 .13482 Mdot
.37656 .13102 Mdot
.79487 .36366 Mdot
.34441 .19354 Mdot
.99059 .41646 Mdot
.76009 .10975 Mdot
.13852 .25029 Mdot
.33915 .16896 Mdot
.38678 .13136 Mdot
.35769 .12701 Mdot
.68723 .40288 Mdot
.99617 .41775 Mdot
.22203 .5047 Mdot
.89745 .38234 Mdot
.68231 .41272 Mdot
.29087 .2605 Mdot
.35918 .12239 Mdot
.38332 .57162 Mdot
.16657 .25694 Mdot
.77488 .11633 Mdot
.34392 .17247 Mdot
.64729 .06248 Mdot
.29724 .26441 Mdot
.15936 .4775 Mdot
.91004 .17111 Mdot
.68146 .45279 Mdot
.23478 .50855 Mdot
.81488 .36079 Mdot
.0399 .43142 Mdot
.68106 .42584 Mdot
.37335 .13594 Mdot
.33561 .21598 Mdot
.98781 .41591 Mdot
.81745 .36573 Mdot
.02774 .21422 Mdot
.3297 .18678 Mdot
.8253 .36919 Mdot
.31744 .23209 Mdot
.3299 .19992 Mdot
.44889 .59662 Mdot
.33234 .54756 Mdot
.10248 .2412 Mdot
.27944 .26644 Mdot
.31787 .2384 Mdot
.09308 .2351 Mdot
.31006 .25981 Mdot
.80394 .36529 Mdot
.32936 .18786 Mdot
.77003 .36416 Mdot
.68109 .45377 Mdot
.06689 .44258 Mdot
.8798 .15753 Mdot
.34106 .15835 Mdot
.69748 .37292 Mdot
.69322 .38002 Mdot
.22075 .27057 Mdot
.33774 .22042 Mdot
.33303 .16412 Mdot
.695 .08222 Mdot
.85553 .37645 Mdot
.7445 .10288 Mdot
.74295 .36459 Mdot
.15079 .47476 Mdot
.1638 .25719 Mdot
.43952 .59246 Mdot
.2636 .52053 Mdot
.79711 .12688 Mdot
.38152 .12899 Mdot
.38074 .13913 Mdot
.68707 .43015 Mdot
.33027 .54945 Mdot
.37804 .12046 Mdot
.34644 .17311 Mdot
.40533 .1211 Mdot
.43229 .59046 Mdot
.25364 .27384 Mdot
.35149 .13462 Mdot
.73168 .35874 Mdot
.25386 .27053 Mdot
.4925 .61687 Mdot
.35601 .13944 Mdot
.00288 .41805 Mdot
.32539 .24155 Mdot
.92838 .17944 Mdot
.45386 .12467 Mdot
.47105 .607 Mdot
.19144 .26148 Mdot
.3876 .12425 Mdot
.18823 .25839 Mdot
.31834 .23739 Mdot
.7265 .36377 Mdot
.87238 .15624 Mdot
.66505 .07265 Mdot
.69331 .38409 Mdot
.27762 .2675 Mdot
.32911 .1914 Mdot
.33389 .21385 Mdot
.14532 .2535 Mdot
.68764 .40013 Mdot
.93871 .18114 Mdot
.42578 .58729 Mdot
.31251 .24187 Mdot
.58574 .03841 Mdot
.44631 .59694 Mdot
.75155 .36209 Mdot
.77646 .35697 Mdot
.63258 .05711 Mdot
.2321 .27274 Mdot
.35426 .14949 Mdot
.67406 .47004 Mdot
.32111 .24349 Mdot
.26467 .27267 Mdot
.79922 .35962 Mdot
.34191 .1647 Mdot
.391 .1236 Mdot
.19102 .48932 Mdot
.41816 .12759 Mdot
.1248 .46562 Mdot
.76529 .11267 Mdot
.37124 .13912 Mdot
.33875 .19595 Mdot
.35439 .15072 Mdot
.68382 .45014 Mdot
.70784 .36203 Mdot
.29759 .25394 Mdot
.91827 .17364 Mdot
.34902 .14274 Mdot
.6898 .40449 Mdot
.4442 .12129 Mdot
.36936 .13176 Mdot
.99616 .20168 Mdot
.80144 .36428 Mdot
.36129 .1308 Mdot
.85829 .37064 Mdot
.33094 .1572 Mdot
.00281 .42095 Mdot
.68595 .39636 Mdot
.31874 .2492 Mdot
.3722 .56618 Mdot
.05821 .22311 Mdot
.78644 .3561 Mdot
.33663 .18457 Mdot
.36327 .14688 Mdot
.34015 .19974 Mdot
.34349 .1502 Mdot
.62974 .05735 Mdot
.35399 .12972 Mdot
.17073 .48397 Mdot
.32291 .21154 Mdot
.09128 .2346 Mdot
.1123 .24159 Mdot
.34645 .13077 Mdot
.87016 .37613 Mdot
.05047 .43654 Mdot
.11108 .24156 Mdot
.3305 .23917 Mdot
.21138 .26257 Mdot
.77036 .11632 Mdot
.3532 .15328 Mdot
.68076 .42164 Mdot
.4165 .12258 Mdot
.31312 .26094 Mdot
.30622 .53702 Mdot
.30286 .26322 Mdot
.05261 .43818 Mdot
.07858 .23362 Mdot
.29142 .26271 Mdot
.32279 .22192 Mdot
.36454 .12065 Mdot
.72829 .09679 Mdot
.99266 .41504 Mdot
.1152 .45961 Mdot
.74604 .10588 Mdot
.33742 .16319 Mdot
.40742 .12306 Mdot
.25579 .51836 Mdot
.36172 .14606 Mdot
.42443 .12868 Mdot
.71388 .37058 Mdot
.74731 .36167 Mdot
.68928 .39988 Mdot
.25137 .2693 Mdot
.40608 .12974 Mdot
.77274 .35612 Mdot
.53338 .01428 Mdot
.10684 .24165 Mdot
.21832 .26648 Mdot
.38603 .57273 Mdot
.36184 .13696 Mdot
.99952 .41571 Mdot
.30249 .25143 Mdot
.06519 .44116 Mdot
.34004 .1878 Mdot
.36542 .14865 Mdot
.4336 .12853 Mdot
.18239 .26203 Mdot
.93673 .18219 Mdot
.82828 .37056 Mdot
.33392 .17518 Mdot
.31935 .22015 Mdot
.47012 .1275 Mdot
.22784 .50408 Mdot
.10438 .45758 Mdot
.82586 .36731 Mdot
.62479 .05278 Mdot
.04096 .21949 Mdot
.22644 .26508 Mdot
.49603 .131 Mdot
.97813 .4093 Mdot
.48799 .13175 Mdot
.30455 .26831 Mdot
.96906 .40891 Mdot
.82182 .13436 Mdot
.34913 .16582 Mdot
.18678 .48845 Mdot
.98858 .1992 Mdot
.33141 .17261 Mdot
.74516 .36068 Mdot
.6957 .37586 Mdot
.81931 .36655 Mdot
.43451 .1282 Mdot
.02541 .42811 Mdot
.06351 .22862 Mdot
.80813 .36657 Mdot
.41129 .13033 Mdot
.94545 .39705 Mdot
.05537 .22415 Mdot
.39122 .13096 Mdot
.26079 .26813 Mdot
.30786 .25137 Mdot
.55193 .02237 Mdot
.28976 .26731 Mdot
.19497 .26132 Mdot
.06139 .22692 Mdot
.83428 .36655 Mdot
.99264 .20319 Mdot
.69651 .08391 Mdot
.73731 .36621 Mdot
.46765 .12598 Mdot
.68905 .37938 Mdot
.34728 .55506 Mdot
.2401 .27222 Mdot
.34059 .14876 Mdot
.33774 .14807 Mdot
.74426 .35419 Mdot
.97474 .19519 Mdot
.72749 .36965 Mdot
.75888 .36039 Mdot
.20501 .26448 Mdot
.82355 .36839 Mdot
.31485 .2576 Mdot
.42988 .12659 Mdot
.78568 .35719 Mdot
.06728 .44054 Mdot
.03286 .21751 Mdot
.27056 .27286 Mdot
.89667 .38564 Mdot
.68452 .42877 Mdot
.05975 .44145 Mdot
.42089 .12145 Mdot
.24994 .27025 Mdot
.41868 .12673 Mdot
.48403 .12838 Mdot
.51729 .13514 Mdot
.34068 .17218 Mdot
.34195 .21064 Mdot
.80802 .13121 Mdot
.68444 .4206 Mdot
.6972 .36985 Mdot
.80521 .36689 Mdot
.68005 .43817 Mdot
.6914 .39682 Mdot
.16994 .25812 Mdot
.92007 .3916 Mdot
.28154 .27215 Mdot
.9744 .40935 Mdot
.31957 .22654 Mdot
.32509 .24258 Mdot
.64825 .0636 Mdot
.16756 .25621 Mdot
.80084 .36013 Mdot
.13116 .24683 Mdot
.69583 .37647 Mdot
.42162 .58498 Mdot
.32893 .23181 Mdot
.06546 .4416 Mdot
.94595 .40107 Mdot
.81937 .3681 Mdot
.69776 .08546 Mdot
.52266 .01039 Mdot
.35616 .13162 Mdot
.43978 .12853 Mdot
.22728 .26469 Mdot
.30295 .53656 Mdot
.31661 .26187 Mdot
.34829 .14253 Mdot
.33793 .15105 Mdot
.34148 .21364 Mdot
.33263 .19765 Mdot
.71394 .09032 Mdot
.96071 .19109 Mdot
.83795 .3714 Mdot
.9193 .17399 Mdot
.40597 .58123 Mdot
.33102 .18242 Mdot
.36523 .13044 Mdot
.05006 .43578 Mdot
.67386 .46771 Mdot
.24312 .51078 Mdot
.36166 .55981 Mdot
.33553 .20602 Mdot
.49513 .13363 Mdot
.64634 .06447 Mdot
.32531 .18431 Mdot
.33985 .15739 Mdot
.20319 .26209 Mdot
.67645 .4658 Mdot
.34814 .1563 Mdot
.34339 .16495 Mdot
.33917 .17868 Mdot
.39009 .57315 Mdot
.16399 .48025 Mdot
.3443 .18044 Mdot
.49683 .00051 Mdot
.10819 .24309 Mdot
.99638 .20306 Mdot
.24425 .27034 Mdot
.33412 .16354 Mdot
.144 .25056 Mdot
.74522 .36157 Mdot
.37628 .13534 Mdot
.91062 .3857 Mdot
.65596 .06665 Mdot
.70334 .37644 Mdot
.33463 .17157 Mdot
.36643 .14187 Mdot
.70118 .08602 Mdot
.95936 .40303 Mdot
.43914 .12845 Mdot
.27695 .27536 Mdot
.27766 .52596 Mdot
.33064 .54772 Mdot
.26642 .27196 Mdot
.68704 .4335 Mdot
.69537 .38699 Mdot
.47718 .13138 Mdot
.75663 .11076 Mdot
.68801 .38688 Mdot
.36561 .13286 Mdot
.41981 .12657 Mdot
.45117 .12246 Mdot
.10256 .24036 Mdot
.26072 .26745 Mdot
.69466 .39203 Mdot
.76278 .3596 Mdot
.67783 .4545 Mdot
.68223 .44413 Mdot
.68638 .39495 Mdot
.32035 .23139 Mdot
.33428 .13831 Mdot
.40393 .12483 Mdot
.68848 .3966 Mdot
.48721 .13411 Mdot
.3236 .23809 Mdot
.30465 .53819 Mdot
.04729 .21888 Mdot
.68818 .39108 Mdot
.33879 .22511 Mdot
.97536 .4116 Mdot
.1413 .25181 Mdot
.76033 .11159 Mdot
.17661 .26068 Mdot
.38655 .57035 Mdot
.4952 .61752 Mdot
.84821 .14499 Mdot
.21816 .26332 Mdot
.02189 .42498 Mdot
.67545 .45642 Mdot
.69616 .37496 Mdot
.56771 .02884 Mdot
.6827 .42745 Mdot
.6855 .41868 Mdot
.32895 .21425 Mdot
.28639 .26777 Mdot
.93056 .39359 Mdot
.7069 .36182 Mdot
.31399 .24445 Mdot
.33727 .23258 Mdot
.18604 .26372 Mdot
.30527 .26922 Mdot
.32607 .54702 Mdot
.49942 .13098 Mdot
.883 .38062 Mdot
.41427 .12253 Mdot
.50956 .00448 Mdot
.92878 .39201 Mdot
.12269 .46489 Mdot
.68136 .42438 Mdot
.04151 .21941 Mdot
.88025 .15784 Mdot
.72233 .36947 Mdot
.68278 .43491 Mdot
.40067 .1331 Mdot
.6871 .41147 Mdot
.22557 .26729 Mdot
.83114 .3687 Mdot
.69338 .38394 Mdot
.3462 .15176 Mdot
.37811 .12354 Mdot
.32756 .22392 Mdot
.25093 .27367 Mdot
.71899 .36204 Mdot
.40678 .57909 Mdot
.68133 .41696 Mdot
.25636 .26716 Mdot
.76425 .36216 Mdot
.80472 .36509 Mdot
.33126 .15139 Mdot
.40662 .12035 Mdot
.76065 .35943 Mdot
.67609 .46518 Mdot
.25656 .51626 Mdot
.0182 .20977 Mdot
.4129 .58379 Mdot
.68078 .41823 Mdot
.89209 .38433 Mdot
.2282 .27145 Mdot
.92458 .39513 Mdot
.03228 .42773 Mdot
.06281 .44217 Mdot
.81743 .13418 Mdot
.68549 .42546 Mdot
.58772 .03851 Mdot
.17344 .25609 Mdot
.3288 .17678 Mdot
.33793 .55061 Mdot
.29968 .25594 Mdot
.05871 .43944 Mdot
.88021 .3782 Mdot
.84685 .37157 Mdot
.33382 .15192 Mdot
.47086 .12488 Mdot
.14682 .25251 Mdot
.39189 .12053 Mdot
.68398 .41505 Mdot
.09694 .45301 Mdot
.5815 .03744 Mdot
.32645 .15494 Mdot
.3027 .26773 Mdot
.32693 .22764 Mdot
.0734 .44488 Mdot
.31696 .26071 Mdot
.27794 .52575 Mdot
.8055 .12791 Mdot
.40175 .12562 Mdot
.30417 .26404 Mdot
.33993 .16119 Mdot
.87646 .3775 Mdot
.21855 .26735 Mdot
.0476 .4344 Mdot
.71773 .37288 Mdot
.34019 .20853 Mdot
.31924 .23179 Mdot
.6771 .44825 Mdot
.07377 .23142 Mdot
.33014 .24712 Mdot
.7965 .12441 Mdot
.36078 .12426 Mdot
.34091 .17386 Mdot
.36535 .14689 Mdot
.69778 .37225 Mdot
.84009 .14346 Mdot
.7546 .35777 Mdot
.36616 .13842 Mdot
.32621 .54549 Mdot
.34179 .17287 Mdot
.39573 .11717 Mdot
.03029 .4299 Mdot
.71449 .09095 Mdot
.89643 .38416 Mdot
.33908 .17051 Mdot
.13217 .24808 Mdot
.22709 .2677 Mdot
.94659 .40215 Mdot
.12785 .46395 Mdot
.92538 .39168 Mdot
.72967 .36792 Mdot
.27717 .27036 Mdot
.68838 .42238 Mdot
.01327 .21044 Mdot
.87378 .15532 Mdot
.73902 .35739 Mdot
.34537 .15575 Mdot
.33984 .18512 Mdot
.71651 .36059 Mdot
.32999 .23818 Mdot
.32113 .22273 Mdot
.23782 .50965 Mdot
.33032 .19508 Mdot
.37176 .14054 Mdot
.39191 .1357 Mdot
.96209 .40275 Mdot
.23543 .50994 Mdot
.0168 .425 Mdot
.49068 .61481 Mdot
.48324 .61109 Mdot
.71833 .3584 Mdot
.34108 .14595 Mdot
.24216 .27358 Mdot
.32907 .24675 Mdot
.33076 .22164 Mdot
.42764 .13117 Mdot
.40033 .12234 Mdot
.24663 .27395 Mdot
.34475 .16777 Mdot
.81332 .36132 Mdot
.13719 .46937 Mdot
.31946 .22523 Mdot
.6929 .39664 Mdot
.44283 .12604 Mdot
.29072 .26643 Mdot
.00464 .20782 Mdot
.48587 .13231 Mdot
.33433 .23949 Mdot
.68746 .43464 Mdot
.67791 .43723 Mdot
.30788 .53912 Mdot
.40803 .12941 Mdot
.67657 .46937 Mdot
.73434 .36579 Mdot
.44191 .12383 Mdot
.02156 .4276 Mdot
.05503 .43673 Mdot
.29985 .25305 Mdot
.44425 .59528 Mdot
.70765 .36358 Mdot
.15617 .25647 Mdot
.68093 .4209 Mdot
.69628 .37957 Mdot
.8773 .37711 Mdot
.68461 .40141 Mdot
.99156 .41477 Mdot
.77972 .35875 Mdot
.75732 .35883 Mdot
.32783 .18156 Mdot
.52567 .01229 Mdot
.19904 .26678 Mdot
.74456 .35773 Mdot
.66926 .47817 Mdot
.68609 .41613 Mdot
.41737 .12571 Mdot
.31036 .24252 Mdot
.34277 .16284 Mdot
.20836 .26604 Mdot
.07174 .22764 Mdot
.08779 .44856 Mdot
.38853 .13618 Mdot
.7003 .3892 Mdot
.85232 .36931 Mdot
.32966 .17094 Mdot
.81187 .35998 Mdot
.40616 .13182 Mdot
.51824 .00851 Mdot
.75871 .36384 Mdot
.33509 .20839 Mdot
.84078 .1428 Mdot
.70911 .37227 Mdot
.68743 .40177 Mdot
.38608 .57143 Mdot
.74513 .36191 Mdot
.69121 .41312 Mdot
.88465 .38038 Mdot
.32687 .22856 Mdot
.83756 .1421 Mdot
.80746 .36055 Mdot
.9123 .17193 Mdot
.28739 .26809 Mdot
.35396 .12943 Mdot
.60291 .04374 Mdot
.32107 .2048 Mdot
.83184 .36808 Mdot
.3302 .19314 Mdot
.68619 .39115 Mdot
.33255 .24271 Mdot
.08569 .23433 Mdot
.71488 .36703 Mdot
.83076 .36696 Mdot
.34673 .1692 Mdot
.34104 .20545 Mdot
.33703 .17726 Mdot
.88617 .38315 Mdot
.37878 .12598 Mdot
.35305 .12912 Mdot
.6863 .39623 Mdot
.32267 .21612 Mdot
.10435 .23816 Mdot
.37825 .56816 Mdot
.21746 .26938 Mdot
.68169 .4082 Mdot
.40706 .13283 Mdot
.82834 .13729 Mdot
.69105 .40935 Mdot
.53409 .01545 Mdot
.9987 .41932 Mdot
.44795 .59624 Mdot
.47219 .12547 Mdot
.35155 .16437 Mdot
.78318 .12016 Mdot
.27557 .525 Mdot
.44147 .12345 Mdot
.78645 .35862 Mdot
.98204 .41253 Mdot
.27172 .26574 Mdot
.70811 .36718 Mdot
.50191 .00337 Mdot
.68728 .42056 Mdot
.37527 .13509 Mdot
.70559 .37974 Mdot
.93649 .39814 Mdot
.09117 .23322 Mdot
.33447 .17512 Mdot
.30755 .25557 Mdot
.96596 .19033 Mdot
.17474 .25961 Mdot
.46265 .13015 Mdot
.21776 .50125 Mdot
.11333 .23993 Mdot
.797 .35765 Mdot
.33235 .16936 Mdot
.0094 .42106 Mdot
.32921 .21995 Mdot
.29181 .2647 Mdot
.32588 .16251 Mdot
.33272 .14161 Mdot
.96136 .19195 Mdot
.88376 .16007 Mdot
.27478 .52348 Mdot
.14991 .47623 Mdot
.42647 .13062 Mdot
.44084 .1301 Mdot
.44544 .12175 Mdot
.26256 .27005 Mdot
.84695 .36886 Mdot
.3326 .14324 Mdot
.06755 .44114 Mdot
.33516 .13512 Mdot
.68165 .44951 Mdot
.21519 .26758 Mdot
.04681 .21929 Mdot
.72326 .09585 Mdot
.32129 .2261 Mdot
.26239 .27237 Mdot
.34121 .16155 Mdot
.34487 .13456 Mdot
.93902 .18129 Mdot
.34952 .12683 Mdot
.6916 .38536 Mdot
.34987 .12569 Mdot
.67865 .43323 Mdot
.01564 .21003 Mdot
.31184 .2646 Mdot
.90888 .38992 Mdot
.34758 .15746 Mdot
.05776 .22312 Mdot
.34477 .13075 Mdot
.34869 .17567 Mdot
.21864 .2693 Mdot
.34168 .18955 Mdot
.49159 .61616 Mdot
.336 .20786 Mdot
.01085 .42181 Mdot
.70987 .36411 Mdot
.33975 .17711 Mdot
.68919 .39897 Mdot
.50838 .13422 Mdot
.67958 .07604 Mdot
.72907 .3692 Mdot
.32664 .1746 Mdot
.68289 .07721 Mdot
.78151 .35777 Mdot
.81747 .36457 Mdot
.26787 .27152 Mdot
.49446 .13334 Mdot
.4237 .58708 Mdot
.78737 .3584 Mdot
.81185 .36089 Mdot
.86762 .37513 Mdot
.3055 .24763 Mdot
.01754 .42417 Mdot
.46277 .12957 Mdot
.33127 .20767 Mdot
.33378 .20683 Mdot
.33627 .23778 Mdot
.11096 .46093 Mdot
.98594 .19745 Mdot
.3396 .1648 Mdot
.88337 .16113 Mdot
.97382 .19441 Mdot
.72079 .36349 Mdot
.32563 .22501 Mdot
.44856 .12859 Mdot
.3426 .15323 Mdot
.75518 .35753 Mdot
.97669 .41158 Mdot
.28629 .26623 Mdot
.50334 .13234 Mdot
.68808 .41848 Mdot
.81239 .36299 Mdot
.33151 .22598 Mdot
.23911 .2649 Mdot
.88667 .16066 Mdot
.4424 .12166 Mdot
.27466 .26777 Mdot
.69735 .37409 Mdot
.28278 .27442 Mdot
.68554 .42704 Mdot
.35719 .13884 Mdot
.68968 .40412 Mdot
.3251 .20376 Mdot
.45003 .13082 Mdot
.80652 .36328 Mdot
.11546 .46263 Mdot
.26615 .26816 Mdot
.72315 .36097 Mdot
.7756 .36434 Mdot
.35172 .12417 Mdot
.69556 .08237 Mdot
.47796 .12887 Mdot
.32806 .22304 Mdot
.37266 .12702 Mdot
.34029 .14342 Mdot
.70146 .38306 Mdot
.34811 .15754 Mdot
.3883 .12472 Mdot
.70522 .37286 Mdot
.32088 .23254 Mdot
.70974 .37018 Mdot
.30491 .2513 Mdot
.20068 .26349 Mdot
.32725 .20329 Mdot
.45758 .13121 Mdot
.42338 .12652 Mdot
.44783 .12355 Mdot
.33012 .17575 Mdot
.69544 .37032 Mdot
.42777 .12384 Mdot
.76682 .36011 Mdot
.80199 .3616 Mdot
.36237 .12081 Mdot
.65684 .06716 Mdot
.11972 .24557 Mdot
.17896 .25653 Mdot
.32762 .24767 Mdot
.32625 .20492 Mdot
.07226 .22753 Mdot
.50607 .13451 Mdot
.10621 .45588 Mdot
.68487 .43245 Mdot
.10162 .45551 Mdot
.41531 .12793 Mdot
.90814 .38644 Mdot
.71619 .09255 Mdot
.35349 .13993 Mdot
.33267 .19574 Mdot
.33856 .55205 Mdot
.3509 .12965 Mdot
.33091 .22111 Mdot
.36883 .12012 Mdot
.11863 .46188 Mdot
.50875 .13528 Mdot
.78855 .36474 Mdot
.68398 .40836 Mdot
.34314 .16505 Mdot
.33763 .18857 Mdot
.33057 .15661 Mdot
.3469 .13012 Mdot
.29597 .26426 Mdot
.77868 .36413 Mdot
.48556 .13143 Mdot
.71313 .37534 Mdot
.31386 .25306 Mdot
.74515 .36228 Mdot
.31259 .25591 Mdot
.4061 .12026 Mdot
.44681 .12875 Mdot
.49369 1e-05 Mdot
.462 .12468 Mdot
.42874 .59005 Mdot
.18823 .48888 Mdot
.44319 .59634 Mdot
.57561 .03307 Mdot
.74548 .35417 Mdot
.38302 .13555 Mdot
.78386 .3589 Mdot
.71902 .36325 Mdot
.36068 .56194 Mdot
.0302 .42853 Mdot
.51542 .13562 Mdot
.42866 .59006 Mdot
.30139 .25796 Mdot
.37683 .12438 Mdot
.74143 .10301 Mdot
.66912 .07164 Mdot
.75088 .35799 Mdot
.31596 .24095 Mdot
.33141 .14225 Mdot
.33718 .22477 Mdot
.30873 .24803 Mdot
.20183 .49485 Mdot
.31814 .23245 Mdot
.72302 .36889 Mdot
.85669 .37578 Mdot
.68888 .39316 Mdot
.30897 .2539 Mdot
.09665 .23524 Mdot
.3217 .25834 Mdot
.44756 .12943 Mdot
.33141 .2442 Mdot
.76291 .3537 Mdot
.37925 .1333 Mdot
.42702 .12159 Mdot
.70982 .3761 Mdot
.48131 .13204 Mdot
.45278 .12497 Mdot
.36909 .13648 Mdot
.00848 .42043 Mdot
.92673 .39368 Mdot
.33412 .18487 Mdot
.56411 .02916 Mdot
.93582 .39656 Mdot
.71697 .37097 Mdot
.02697 .21534 Mdot
.67687 .445 Mdot
.09151 .45055 Mdot
.68668 .38705 Mdot
.62574 .05455 Mdot
.31632 .54174 Mdot
.68061 .41686 Mdot
.99618 .41775 Mdot
.62993 .05667 Mdot
.32375 .19807 Mdot
.68127 .40108 Mdot
.3377 .16659 Mdot
.321 .22618 Mdot
.32877 .22245 Mdot
.21271 .26968 Mdot
.09471 .23605 Mdot
.69403 .4013 Mdot
.6846 .39261 Mdot
.36403 .12975 Mdot
.37477 .1186 Mdot
.31701 .26086 Mdot
.69613 .37548 Mdot
.97393 .19631 Mdot
.81151 .13227 Mdot
.32113 .25156 Mdot
.2789 .26511 Mdot
.97807 .41119 Mdot
.97695 .41127 Mdot
.69913 .3732 Mdot
.46725 .1252 Mdot
.35981 .5612 Mdot
.40745 .11822 Mdot
.36605 .14509 Mdot
.33141 .17274 Mdot
.94699 .39753 Mdot
.02008 .21202 Mdot
.32927 .19968 Mdot
.3314 .18868 Mdot
.30988 .26053 Mdot
.31936 .25027 Mdot
.73765 .10118 Mdot
.34024 .19964 Mdot
.9212 .39246 Mdot
.29284 .26343 Mdot
.13774 .25071 Mdot
.32071 .21346 Mdot
.7802 .36202 Mdot
.49299 .61642 Mdot
.13278 .46726 Mdot
.01954 .2095 Mdot
.34779 .16179 Mdot
.40433 .11887 Mdot
.98723 .41259 Mdot
.58821 .0393 Mdot
.80333 .36365 Mdot
.30576 .25514 Mdot
.34919 .16689 Mdot
.33188 .16215 Mdot
.08767 .23249 Mdot
.24664 .27276 Mdot
.4747 .60957 Mdot
.41335 .12549 Mdot
.34047 .22009 Mdot
.34137 .14118 Mdot
.29497 .53383 Mdot
.28412 .26956 Mdot
.19887 .49573 Mdot
.34082 .14561 Mdot
.5351 .01522 Mdot
.67404 .47028 Mdot
.46681 .13219 Mdot
.98452 .1979 Mdot
.11843 .24232 Mdot
.32334 .243 Mdot
.68397 .44496 Mdot
.32343 .22751 Mdot
.33922 .17444 Mdot
.93562 .39711 Mdot
.29985 .26524 Mdot
.03253 .42908 Mdot
.72624 .36339 Mdot
.91049 .3873 Mdot
.9743 .40896 Mdot
.28556 .2604 Mdot
.26859 .26731 Mdot
.71499 .36853 Mdot
.08806 .23198 Mdot
.08058 .44628 Mdot
.35772 .13202 Mdot
.836 .36843 Mdot
.66463 .07191 Mdot
.32795 .16196 Mdot
.76791 .35663 Mdot
.33755 .2119 Mdot
.46972 .1266 Mdot
.42114 .12537 Mdot
.31956 .54362 Mdot
.32762 .19444 Mdot
.3286 .22669 Mdot
.3191 .54199 Mdot
.31781 .23065 Mdot
.1146 .46081 Mdot
.76257 .11107 Mdot
.42743 .58874 Mdot
.72933 .35479 Mdot
.34217 .17081 Mdot
.89375 .38179 Mdot
.43018 .12988 Mdot
.45057 .12359 Mdot
.71745 .37197 Mdot
.86798 .37437 Mdot
.30323 .26381 Mdot
.64299 .06065 Mdot
.86063 .3715 Mdot
.74397 .36381 Mdot
.42265 .12021 Mdot
.36414 .14139 Mdot
.477 .61103 Mdot
.06987 .22868 Mdot
.20014 .26719 Mdot
.29612 .2701 Mdot
.30998 .53887 Mdot
.06359 .44157 Mdot
.35928 .14182 Mdot
.33427 .19503 Mdot
.09341 .2367 Mdot
.34211 .18039 Mdot
.54268 .01822 Mdot
.32383 .17116 Mdot
.76471 .35498 Mdot
.76412 .11225 Mdot
.32706 .18504 Mdot
.40862 .12395 Mdot
.24211 .27346 Mdot
.20316 .26106 Mdot
.26047 .26757 Mdot
.39723 .12031 Mdot
.92011 .39185 Mdot
.36043 .56133 Mdot
.33291 .21081 Mdot
.77592 .11781 Mdot
.77008 .11447 Mdot
.34654 .13309 Mdot
.17032 .25581 Mdot
.70172 .38462 Mdot
.71936 .36224 Mdot
.51277 .00702 Mdot
.61675 .04953 Mdot
.09103 .44973 Mdot
.2315 .507 Mdot
.70355 .37267 Mdot
.34159 .1967 Mdot
.34439 .15979 Mdot
.81676 .36424 Mdot
.33732 .16035 Mdot
.10584 .23859 Mdot
.38259 .13448 Mdot
.19263 .26545 Mdot
.56945 .03032 Mdot
.46173 .12912 Mdot
.68453 .43595 Mdot
.24799 .26956 Mdot
.47291 .13145 Mdot
.41374 .12076 Mdot
.70906 .36796 Mdot
.31399 .23946 Mdot
.83946 .14431 Mdot
.18419 .48939 Mdot
.76034 .10939 Mdot
.39315 .13413 Mdot
.83423 .3701 Mdot
.32312 .19219 Mdot
.70772 .3747 Mdot
.22955 .50683 Mdot
.84317 .37057 Mdot
.83267 .36466 Mdot
.68407 .43921 Mdot
.33387 .24062 Mdot
.32018 .23858 Mdot
.97033 .40556 Mdot
.7201 .36104 Mdot
.0472 .21928 Mdot
.70495 .3767 Mdot
.28772 .26002 Mdot
.77899 .36458 Mdot
.89211 .16351 Mdot
.33996 .15401 Mdot
.73165 .36003 Mdot
.32363 .20901 Mdot
.26919 .26948 Mdot
.85068 .37405 Mdot
.88271 .37953 Mdot
.39493 .12308 Mdot
.25974 .26781 Mdot
.32312 .19713 Mdot
.33743 .14443 Mdot
.32396 .1943 Mdot
.15024 .25406 Mdot
.71057 .37858 Mdot
.068 .44222 Mdot
.90983 .38832 Mdot
.35945 .15251 Mdot
.81632 .36634 Mdot
.99102 .20131 Mdot
.70698 .36551 Mdot
.32923 .1829 Mdot
.92881 .39186 Mdot
.32616 .16604 Mdot
.31905 .26224 Mdot
.6808 .07716 Mdot
.81923 .13403 Mdot
.11189 .46116 Mdot
.45184 .5999 Mdot
.27473 .52337 Mdot
.68418 .39033 Mdot
.40791 .11809 Mdot
.48973 .12889 Mdot
.70598 .36695 Mdot
.3381 .20339 Mdot
.79135 .3574 Mdot
.95927 .40516 Mdot
.39662 .13017 Mdot
.32273 .24107 Mdot
.34733 .17239 Mdot
.89576 .16603 Mdot
.31515 .54295 Mdot
.07721 .44712 Mdot
.86805 .37567 Mdot
.28952 .53235 Mdot
.68334 .43243 Mdot
.92551 .17529 Mdot
.31476 .23651 Mdot
.50601 .00364 Mdot
.35838 .12571 Mdot
.3661 .14436 Mdot
.03812 .43109 Mdot
.02077 .42372 Mdot
.70765 .37441 Mdot
.74155 .35845 Mdot
.32368 .19341 Mdot
.39706 .12098 Mdot
.39579 .13188 Mdot
.47438 .60832 Mdot
.7333 .36692 Mdot
.33462 .13579 Mdot
.70459 .37884 Mdot
.76497 .35482 Mdot
.31729 .23465 Mdot
.32286 .17883 Mdot
.33659 .19681 Mdot
.33973 .17281 Mdot
.36046 .13663 Mdot
.31921 .22586 Mdot
.72675 .36715 Mdot
.96049 .19077 Mdot
.77647 .36352 Mdot
.985 .19981 Mdot
.37924 .12038 Mdot
.82576 .36688 Mdot
.73422 .35689 Mdot
.12857 .46624 Mdot
.17582 .25929 Mdot
.32675 .25385 Mdot
.17638 .25573 Mdot
.36001 .1488 Mdot
.25682 .26845 Mdot
.92136 .38968 Mdot
.26146 .26953 Mdot
.36585 .12746 Mdot
.11109 .23918 Mdot
.36919 .14083 Mdot
.14884 .25412 Mdot
.83335 .13965 Mdot
.34515 .13759 Mdot
.37178 .12103 Mdot
.80731 .36112 Mdot
.96236 .40467 Mdot
.34363 .19673 Mdot
.35462 .13141 Mdot
.69435 .40379 Mdot
.75836 .3643 Mdot
.53007 .01419 Mdot
.73275 .35527 Mdot
.42489 .12216 Mdot
.36153 .14588 Mdot
.68823 .41665 Mdot
.33713 .17161 Mdot
.31897 .22568 Mdot
.68234 .07699 Mdot
.70135 .36874 Mdot
.3283 .2409 Mdot
.89123 .38314 Mdot
.33424 .22891 Mdot
.32188 .21461 Mdot
.76633 .11385 Mdot
.35476 .13735 Mdot
.34069 .20472 Mdot
.32314 .20368 Mdot
.33977 .15236 Mdot
.67164 .47148 Mdot
.09654 .45294 Mdot
.42453 .12875 Mdot
.33733 .18705 Mdot
.28447 .26488 Mdot
.88673 .38338 Mdot
.32754 .17621 Mdot
.30868 .24804 Mdot
.45904 .12343 Mdot
.69457 .38173 Mdot
.85336 .37316 Mdot
.62109 .0539 Mdot
.787 .36094 Mdot
.41183 .12033 Mdot
.42023 .58643 Mdot
.52356 .0128 Mdot
.28776 .26599 Mdot
.68344 .40029 Mdot
.32487 .21429 Mdot
.15128 .25536 Mdot
.34091 .16182 Mdot
.31935 .54404 Mdot
.34343 .19473 Mdot
.4796 .12687 Mdot
.87859 .1579 Mdot
.68394 .4375 Mdot
.97382 .40945 Mdot
.32923 .19325 Mdot
.06629 .22614 Mdot
.24214 .26727 Mdot
.4206 .13173 Mdot
.82789 .36525 Mdot
.69104 .41367 Mdot
.42897 .12101 Mdot
.68364 .07904 Mdot
.47723 .1277 Mdot
.33415 .14916 Mdot
.40747 .12148 Mdot
.3329 .20312 Mdot
.70604 .3684 Mdot
.70742 .3683 Mdot
.59144 .03874 Mdot
.19121 .49015 Mdot
.36187 .56196 Mdot
.84068 .14448 Mdot
.8426 .3674 Mdot
.36064 .1257 Mdot
.08187 .44718 Mdot
.67946 .45142 Mdot
.89207 .16452 Mdot
.47076 .60746 Mdot
.91957 .3909 Mdot
.74046 .35737 Mdot
.32968 .21526 Mdot
.31896 .2187 Mdot
.10844 .24186 Mdot
.674 .07398 Mdot
.81851 .36579 Mdot
.32223 .25722 Mdot
.33137 .17506 Mdot
.23895 .27198 Mdot
.93414 .18027 Mdot
.69515 .37725 Mdot
.70803 .3636 Mdot
.4893 .13007 Mdot
.18119 .26112 Mdot
.0124 .42381 Mdot
.82343 .36929 Mdot
.3346 .21208 Mdot
.34788 .13668 Mdot
.89678 .38566 Mdot
.67665 .44672 Mdot
.35088 .16924 Mdot
.30791 .25661 Mdot
.2591 .2734 Mdot
.65361 .06577 Mdot
.32054 .25929 Mdot
.43073 .12199 Mdot
.01634 .42185 Mdot
.42299 .12441 Mdot
.32625 .22711 Mdot
.68844 .42735 Mdot
.30154 .26549 Mdot
.36404 .12778 Mdot
.42169 .12375 Mdot
.67554 .07707 Mdot
.18061 .26251 Mdot
.3684 .13576 Mdot
.48299 .13339 Mdot
.32205 .19656 Mdot
.32437 .25535 Mdot
.36291 .1253 Mdot
.34665 .14812 Mdot
.48761 .13176 Mdot
.42715 .58978 Mdot
.69592 .39579 Mdot
.96053 .40261 Mdot
.33811 .17217 Mdot
.3418 .14054 Mdot
.47525 .12945 Mdot
.68407 .44743 Mdot
.83523 .3708 Mdot
.85594 .14896 Mdot
.75974 .35886 Mdot
.34334 .18434 Mdot
.9175 .39093 Mdot
.0761 .44391 Mdot
.68659 .38795 Mdot
.82699 .36939 Mdot
.7507 .10688 Mdot
.85268 .37309 Mdot
.11207 .24262 Mdot
.72285 .36171 Mdot
.98611 .20066 Mdot
.3585 .15656 Mdot
.84483 .36918 Mdot
.67831 .46183 Mdot
.742 .36316 Mdot
.11278 .24002 Mdot
.39526 .12528 Mdot
.01087 .20729 Mdot
.55996 .02571 Mdot
.79462 .12525 Mdot
.69079 .41179 Mdot
.81076 .36195 Mdot
.32826 .23602 Mdot
.10352 .23827 Mdot
.39156 .57314 Mdot
.90852 .16895 Mdot
.51106 .00651 Mdot
.32773 .15676 Mdot
.26179 .27523 Mdot
.95826 .19021 Mdot
.48236 .12941 Mdot
.35382 .12373 Mdot
.3775 .12262 Mdot
.37448 .1384 Mdot
.62402 .05484 Mdot
.91406 .38956 Mdot
.37666 .12519 Mdot
.30576 .2568 Mdot
.3356 .23123 Mdot
.32461 .22321 Mdot
.01859 .42627 Mdot
.50385 .00314 Mdot
.68503 .3905 Mdot
.3168 .54191 Mdot
.05699 .43913 Mdot
.28609 .26758 Mdot
.4568 .12797 Mdot
.15039 .25517 Mdot
.68733 .43525 Mdot
.33728 .18231 Mdot
.77328 .11604 Mdot
.37198 .12007 Mdot
.26492 .5212 Mdot
.33686 .21695 Mdot
.75058 .35953 Mdot
.97852 .4101 Mdot
.46028 .12979 Mdot
.34954 .1714 Mdot
.33722 .135 Mdot
.71988 .35666 Mdot
.45099 .12314 Mdot
.09068 .23479 Mdot
.99782 .20239 Mdot
.8458 .14412 Mdot
.20851 .49825 Mdot
.35375 .13184 Mdot
.68357 .39825 Mdot
.34617 .17582 Mdot
.77913 .35624 Mdot
.77047 .36387 Mdot
.7845 .35632 Mdot
.38326 .13677 Mdot
.09294 .45186 Mdot
.95932 .40392 Mdot
.31663 .23954 Mdot
.32036 .24125 Mdot
.08443 .23374 Mdot
.3098 .24392 Mdot
.34545 .55446 Mdot
.68514 .40416 Mdot
.69108 .3975 Mdot
.68804 .39854 Mdot
.32713 .19875 Mdot
.18222 .48667 Mdot
.28186 .27302 Mdot
.88316 .38223 Mdot
.34375 .16144 Mdot
.68857 .08075 Mdot
.76566 .35369 Mdot
.29373 .263 Mdot
.40177 .11962 Mdot
.92063 .17356 Mdot
.3291 .16002 Mdot
.239 .27314 Mdot
.9057 .38897 Mdot
.7515 .3601 Mdot
.00793 .20532 Mdot
.47439 .12603 Mdot
.34331 .14817 Mdot
.16356 .25508 Mdot
.16249 .25505 Mdot
.32383 .16914 Mdot
.33911 .21827 Mdot
.95694 .18985 Mdot
.34362 .17473 Mdot
.47831 .13127 Mdot
.33881 .21956 Mdot
.33247 .17187 Mdot
.49126 .12973 Mdot
.35448 .14158 Mdot
.74186 .35918 Mdot
.80377 .35996 Mdot
.94494 .18236 Mdot
.03708 .42998 Mdot
.35203 .12489 Mdot
.37947 .1202 Mdot
.06051 .43941 Mdot
.69382 .39531 Mdot
.33017 .21531 Mdot
.72815 .35637 Mdot
.33779 .18239 Mdot
.77494 .1169 Mdot
.05542 .22221 Mdot
.72109 .36239 Mdot
.6746 .47268 Mdot
.32346 .20913 Mdot
.78003 .36436 Mdot
.39759 .129 Mdot
.33501 .19536 Mdot
.33022 .18892 Mdot
.67431 .47261 Mdot
.02189 .21107 Mdot
.11156 .45931 Mdot
.8736 .37885 Mdot
.31454 .24722 Mdot
.38556 .11761 Mdot
.29458 .26007 Mdot
.71542 .36166 Mdot
.29742 .25963 Mdot
.34385 .55341 Mdot
.44722 .12296 Mdot
.90557 .1674 Mdot
.42365 .12057 Mdot
.74302 .3651 Mdot
.25169 .26618 Mdot
.3274 .17267 Mdot
.4755 .12639 Mdot
.42266 .12706 Mdot
.26686 .52193 Mdot
.33411 .21024 Mdot
.21968 .26573 Mdot
.98028 .40965 Mdot
.32762 .23756 Mdot
.31296 .24232 Mdot
.1806 .25683 Mdot
.32424 .22489 Mdot
.50306 .13246 Mdot
.32794 .16909 Mdot
.35041 .12564 Mdot
.68648 .43775 Mdot
.3337 .20593 Mdot
.62328 .05431 Mdot
.68769 .40203 Mdot
.69276 .40941 Mdot
.06268 .22684 Mdot
.8977 .38375 Mdot
.34902 .15114 Mdot
.63717 .05815 Mdot
.36528 .13821 Mdot
.34449 .18636 Mdot
.34937 .14689 Mdot
.32165 .24704 Mdot
.03092 .43101 Mdot
.69853 .08629 Mdot
.72134 .37025 Mdot
.03713 .43059 Mdot
.92779 .17587 Mdot
.85811 .37694 Mdot
.3359 .16904 Mdot
.32855 .24951 Mdot
.46761 .12491 Mdot
.48675 .13392 Mdot
.70781 .36569 Mdot
.01199 .42172 Mdot
.68399 .42512 Mdot
.41704 .11989 Mdot
.69675 .39264 Mdot
.26816 .26654 Mdot
.88002 .15885 Mdot
.19884 .26181 Mdot
.15954 .25204 Mdot
.6898 .39852 Mdot
.28865 .26355 Mdot
.73762 .35806 Mdot
.56615 .02825 Mdot
.46514 .13049 Mdot
.16792 .25923 Mdot
.36242 .12762 Mdot
.45505 .60005 Mdot
.77973 .35625 Mdot
.47852 .13016 Mdot
.34538 .18399 Mdot
.59285 .04191 Mdot
.27374 .27105 Mdot
.31346 .25641 Mdot
.31433 .54067 Mdot
.73901 .36028 Mdot
.9004 .16645 Mdot
.33606 .19747 Mdot
.34015 .22272 Mdot
.97007 .40647 Mdot
.66863 .07369 Mdot
.34159 .55244 Mdot
.34842 .16975 Mdot
.71529 .36966 Mdot
.69343 .38495 Mdot
.282 .27451 Mdot
.26593 .26415 Mdot
.35061 .55642 Mdot
.13349 .46846 Mdot
.34128 .1932 Mdot
.33586 .20308 Mdot
.49769 .00068 Mdot
.95916 .19066 Mdot
.35127 .12513 Mdot
.36106 .15119 Mdot
.40212 .12322 Mdot
.31213 .25936 Mdot
.06351 .2271 Mdot
.38288 .12878 Mdot
.68535 .40268 Mdot
.02225 .21022 Mdot
.78538 .12051 Mdot
.36422 .12597 Mdot
.87984 .38125 Mdot
.25023 .27048 Mdot
.80603 .36403 Mdot
.37384 .13004 Mdot
.69738 .36984 Mdot
.66901 .07419 Mdot
.3307 .19797 Mdot
.47891 .60996 Mdot
.23768 .26688 Mdot
.32844 .19091 Mdot
.15188 .47655 Mdot
.44627 .12973 Mdot
.67849 .44795 Mdot
.0832 .44808 Mdot
.37693 .12307 Mdot
.14534 .25302 Mdot
.32739 .21749 Mdot
.07275 .44603 Mdot
.51138 .13436 Mdot
.33861 .17589 Mdot
.69595 .08486 Mdot
.35928 .12751 Mdot
.05956 .44107 Mdot
.69502 .38844 Mdot
.82805 .36907 Mdot
.41058 .13249 Mdot
.73067 .3601 Mdot
.02788 .42653 Mdot
.12302 .46204 Mdot
.74399 .35693 Mdot
.25625 .51584 Mdot
.10329 .24018 Mdot
.69205 .38875 Mdot
.01598 .20965 Mdot
.38037 .12198 Mdot
.25414 .27514 Mdot
.377 .12989 Mdot
.35439 .1634 Mdot
.3073 .2525 Mdot
.68107 .07886 Mdot
.90227 .38437 Mdot
.7474 .35939 Mdot
.32839 .17419 Mdot
.34313 .17938 Mdot
.37537 .13956 Mdot
.76224 .35765 Mdot
.33988 .1604 Mdot
.32991 .20837 Mdot
.47318 .12917 Mdot
.69836 .38332 Mdot
.07806 .44698 Mdot
.3437 .16059 Mdot
.37185 .12365 Mdot
.15942 .25249 Mdot
.68408 .4128 Mdot
.36391 .12399 Mdot
.1421 .47052 Mdot
.39502 .13226 Mdot
.31423 .2613 Mdot
.69753 .38715 Mdot
.34222 .20261 Mdot
.33552 .1362 Mdot
.30011 .53488 Mdot
.85844 .37331 Mdot
.21083 .26908 Mdot
.16958 .25636 Mdot
.69608 .08492 Mdot
.04621 .21852 Mdot
.40661 .11809 Mdot
.32467 .19791 Mdot
.04947 .22247 Mdot
.35142 .15105 Mdot
.38761 .1298 Mdot
.35235 .1478 Mdot
.87051 .15494 Mdot
.05272 .22153 Mdot
.69481 .39548 Mdot
.49707 .13045 Mdot
.34234 .17529 Mdot
.9863 .20083 Mdot
.31419 .24567 Mdot
.29342 .26898 Mdot
.20975 .49871 Mdot
.30796 .24465 Mdot
.18869 .26415 Mdot
.39211 .11755 Mdot
.39627 .11935 Mdot
.363 .56069 Mdot
.49545 .13405 Mdot
.56432 .02809 Mdot
.77455 .35649 Mdot
.69549 .39004 Mdot
.32609 .25524 Mdot
.2602 .27285 Mdot
.88084 .37893 Mdot
.34548 .16376 Mdot
.34331 .15409 Mdot
.32539 .22282 Mdot
.32141 .20753 Mdot
.90029 .38339 Mdot
.32669 .16407 Mdot
.44198 .12843 Mdot
.34492 .17578 Mdot
.33925 .15841 Mdot
.0683 .44429 Mdot
.48913 .61558 Mdot
.37994 .12444 Mdot
.34167 .21493 Mdot
.02422 .42863 Mdot
.37472 .13219 Mdot
.66077 .07073 Mdot
.15932 .25491 Mdot
.98179 .19919 Mdot
.33099 .22756 Mdot
.22756 .26417 Mdot
.32679 .18517 Mdot
.86702 .15266 Mdot
.16058 .25509 Mdot
.32704 .24164 Mdot
.39799 .12001 Mdot
.22599 .26966 Mdot
.91801 .39231 Mdot
.21465 .50124 Mdot
.20748 .26397 Mdot
.43752 .12902 Mdot
.43753 .12328 Mdot
.09294 .45369 Mdot
.73437 .36137 Mdot
.33361 .22588 Mdot
.90885 .16852 Mdot
.67168 .47521 Mdot
.31146 .25714 Mdot
.98102 .19697 Mdot
.2282 .27027 Mdot
.24417 .51275 Mdot
.35752 .13244 Mdot
.01061 .20907 Mdot
.44186 .12398 Mdot
.43665 .59375 Mdot
.32767 .18268 Mdot
.14293 .24832 Mdot
.78338 .35683 Mdot
.07109 .22681 Mdot
.32815 .23726 Mdot
.80578 .36426 Mdot
.03724 .43302 Mdot
.32247 .20333 Mdot
.98767 .41352 Mdot
.58548 .03728 Mdot
.56077 .02811 Mdot
.80717 .36325 Mdot
.03262 .21628 Mdot
.11689 .24291 Mdot
.82252 .36487 Mdot
.35873 .13078 Mdot
.32397 .25048 Mdot
.36316 .14018 Mdot
.18756 .26375 Mdot
.42711 .12168 Mdot
.77648 .35764 Mdot
.99996 .20342 Mdot
.3867 .12482 Mdot
.87414 .15744 Mdot
.26056 .27536 Mdot
.33369 .16031 Mdot
.03382 .43039 Mdot
.48287 .13057 Mdot
.34175 .19041 Mdot
.69508 .37751 Mdot
.42748 .59039 Mdot
.90441 .38676 Mdot
.70397 .38509 Mdot
.28265 .26544 Mdot
.68078 .42186 Mdot
.19594 .49304 Mdot
.2165 .26362 Mdot
.51111 .00559 Mdot
.85757 .15015 Mdot
.89381 .16404 Mdot
.35616 .14516 Mdot
.97509 .40788 Mdot
.31069 .26121 Mdot
.80549 .36399 Mdot
.85768 .14858 Mdot
.80387 .12808 Mdot
.27384 .27509 Mdot
.08858 .45166 Mdot
.38924 .13301 Mdot
.33597 .17593 Mdot
.26701 .52128 Mdot
.80942 .36011 Mdot
.30476 .2642 Mdot
.48963 .13025 Mdot
.51898 .13462 Mdot
.32943 .17116 Mdot
.22425 .27134 Mdot
.038 .21934 Mdot
.51201 .13458 Mdot
.6962 .37158 Mdot
.69756 .37175 Mdot
.91531 .17299 Mdot
.39108 .12986 Mdot
.7529 .35857 Mdot
.75492 .35403 Mdot
.86347 .37568 Mdot
.76688 .35467 Mdot
.14284 .47117 Mdot
.32606 .1908 Mdot
.39318 .12237 Mdot
.32874 .17311 Mdot
.33157 .20269 Mdot
.2099 .26259 Mdot
.71631 .09381 Mdot
.33401 .16399 Mdot
.74942 .35799 Mdot
.08945 .23353 Mdot
.48219 .12775 Mdot
.87646 .37626 Mdot
.31869 .24574 Mdot
.29978 .27091 Mdot
.37232 .14127 Mdot
.33546 .21858 Mdot
.69011 .41808 Mdot
.43687 .12192 Mdot
.33372 .20094 Mdot
.7065 .37 Mdot
.91641 .17181 Mdot
.88771 .16054 Mdot
.12805 .24547 Mdot
.56919 .03225 Mdot
.45419 .12888 Mdot
.29841 .25373 Mdot
.17203 .4849 Mdot
.69796 .37768 Mdot
.78241 .36 Mdot
.86575 .37651 Mdot
.25142 .27488 Mdot
.68613 .43086 Mdot
.43918 .12776 Mdot
.63467 .05758 Mdot
.32296 .54509 Mdot
.76833 .35619 Mdot
.95763 .18942 Mdot
.61256 .04828 Mdot
.27887 .52726 Mdot
.92947 .1798 Mdot
.6844 .40361 Mdot
.73186 .35863 Mdot
.26926 .26591 Mdot
.17161 .48479 Mdot
.33016 .18368 Mdot
.34175 .18114 Mdot
.24032 .27211 Mdot
.97211 .19425 Mdot
.6806 .43889 Mdot
.68431 .44754 Mdot
.3372 .16463 Mdot
.30345 .2578 Mdot
.30228 .25754 Mdot
.52385 .0102 Mdot
.35082 .12451 Mdot
.90401 .38389 Mdot
.15144 .47614 Mdot
.28042 .26573 Mdot
.25507 .26534 Mdot
.09841 .45536 Mdot
.34523 .1824 Mdot
.84223 .36985 Mdot
.34863 .1438 Mdot
.7985 .12523 Mdot
.69567 .3764 Mdot
.6783 .46079 Mdot
.68371 .39551 Mdot
.22826 .26482 Mdot
.35531 .12659 Mdot
.73657 .36606 Mdot
.79459 .35851 Mdot
.31888 .21957 Mdot
.21071 .2643 Mdot
.31636 .25207 Mdot
.37003 .13973 Mdot
.70524 .37241 Mdot
.32052 .25089 Mdot
.68668 .40336 Mdot
.99495 .20294 Mdot
.29931 .53403 Mdot
.8845 .16021 Mdot
.47441 .60827 Mdot
.74323 .35494 Mdot
.15738 .25338 Mdot
.3403 .20325 Mdot
.45757 .12668 Mdot
.32213 .1961 Mdot
.34018 .15562 Mdot
.92206 .39126 Mdot
.31025 .248 Mdot
.38488 .13275 Mdot
.82099 .36202 Mdot
.22719 .50531 Mdot
.41917 .12379 Mdot
.68961 .39812 Mdot
.21676 .50073 Mdot
.88043 .159 Mdot
.76905 .11451 Mdot
.25331 .26957 Mdot
.00673 .20526 Mdot
.89075 .37985 Mdot
.44061 .12976 Mdot
.96551 .19069 Mdot
.32485 .25401 Mdot
.21066 .49966 Mdot
.19014 .25999 Mdot
.74737 .35868 Mdot
.5735 .03369 Mdot
.36424 .15062 Mdot
.3385 .14871 Mdot
.73409 .36262 Mdot
.86974 .37467 Mdot
.33667 .1793 Mdot
.55599 .02442 Mdot
.77538 .35734 Mdot
.353 .13319 Mdot
.42163 .11956 Mdot
.82543 .36366 Mdot
.32345 .19844 Mdot
.68485 .44492 Mdot
.68561 .3927 Mdot
.67859 .42342 Mdot
.70502 .37806 Mdot
.40579 .12906 Mdot
.88879 .16411 Mdot
.73341 .09996 Mdot
.78267 .36122 Mdot
.71601 .09165 Mdot
.68272 .40638 Mdot
.69883 .37045 Mdot
.76029 .35321 Mdot
.10697 .45882 Mdot
.03494 .43215 Mdot
.78181 .36295 Mdot
.69441 .38902 Mdot
.4941 .00052 Mdot
.33153 .19161 Mdot
.33986 .15306 Mdot
.3383 .20181 Mdot
.05881 .43783 Mdot
.24838 .27167 Mdot
.68457 .39011 Mdot
.12526 .46528 Mdot
.35997 .12204 Mdot
.81286 .36597 Mdot
.36911 .12477 Mdot
.68784 .42471 Mdot
.32603 .22632 Mdot
.60631 .04791 Mdot
.3217 .19299 Mdot
.14022 .24821 Mdot
.3006 .26946 Mdot
.71638 .36918 Mdot
.80663 .1308 Mdot
.42429 .12899 Mdot
.57608 .03415 Mdot
.30817 .24847 Mdot
.36547 .56201 Mdot
.349 .15991 Mdot
.34955 .16504 Mdot
.2216 .26995 Mdot
.40241 .13019 Mdot
.37766 .1289 Mdot
.87792 .15988 Mdot
.31498 .23412 Mdot
.34643 .12913 Mdot
.34219 .13454 Mdot
.31374 .25393 Mdot
.6946 .37183 Mdot
.7872 .35781 Mdot
.76854 .11332 Mdot
.12833 .24587 Mdot
.69074 .41227 Mdot
.33406 .19172 Mdot
.01656 .42528 Mdot
.83684 .14192 Mdot
.85955 .15192 Mdot
.7657 .11257 Mdot
.8705 .15572 Mdot
.40583 .13026 Mdot
.94 .3981 Mdot
.30105 .26532 Mdot
.32227 .23558 Mdot
.68451 .43791 Mdot
.35491 .15822 Mdot
.49708 .00104 Mdot
.77765 .11645 Mdot
.33136 .16267 Mdot
.72894 .35878 Mdot
.11633 .24483 Mdot
.34934 .15158 Mdot
.34313 .20032 Mdot
.91447 .17064 Mdot
.68635 .42865 Mdot
.39321 .12616 Mdot
.67009 .47892 Mdot
.04066 .4335 Mdot
.31647 .24377 Mdot
.33355 .21984 Mdot
.32299 .19856 Mdot
.8632 .15197 Mdot
.46574 .60424 Mdot
.34217 .17844 Mdot
.33014 .17626 Mdot
.8222 .36747 Mdot
.41439 .13112 Mdot
.71817 .35859 Mdot
.40193 .13132 Mdot
.68781 .41724 Mdot
.73965 .36176 Mdot
.8524 .1487 Mdot
.02068 .42531 Mdot
.3487 .1348 Mdot
.32995 .17916 Mdot
.96579 .40621 Mdot
.33463 .13534 Mdot
.88603 .38295 Mdot
.69233 .37595 Mdot
.41257 .12522 Mdot
.20059 .49348 Mdot
.34014 .15087 Mdot
.29939 .53535 Mdot
.13233 .24865 Mdot
.67627 .45659 Mdot
.13693 .24832 Mdot
.25701 .51851 Mdot
.77995 .11991 Mdot
.27905 .52756 Mdot
.69675 .37015 Mdot
.73482 .36454 Mdot
.08365 .44795 Mdot
.32594 .23698 Mdot
.28579 .27399 Mdot
.04594 .22265 Mdot
.68408 .44927 Mdot
.77226 .11709 Mdot
.23598 .27259 Mdot
.68265 .43338 Mdot
.68037 .41635 Mdot
.33863 .16005 Mdot
.32424 .16738 Mdot
.35643 .14789 Mdot
.32241 .25018 Mdot
.68563 .40462 Mdot
.86416 .37675 Mdot
.31956 .23358 Mdot
.73204 .36117 Mdot
.63626 .05841 Mdot
.33103 .2221 Mdot
.12283 .46226 Mdot
.21805 .26722 Mdot
.30848 .26178 Mdot
.31144 .25628 Mdot
.41807 .1297 Mdot
.7566 .36296 Mdot
.34312 .16961 Mdot
.32733 .16204 Mdot
.40316 .11905 Mdot
.34867 .1519 Mdot
.86651 .15261 Mdot
.6796 .42698 Mdot
.68333 .40403 Mdot
.246 .27032 Mdot
.18013 .25957 Mdot
.32589 .15931 Mdot
.33474 .19245 Mdot
.33393 .15162 Mdot
.73617 .36707 Mdot
.34635 .12754 Mdot
.68801 .42013 Mdot
.88489 .38074 Mdot
.74305 .10256 Mdot
.71056 .37015 Mdot
.01478 .42125 Mdot
.32865 .24942 Mdot
.36138 .13756 Mdot
.34056 .20704 Mdot
.67955 .42903 Mdot
.34132 .17514 Mdot
.68582 .4041 Mdot
.33616 .18747 Mdot
.82015 .36797 Mdot
.68702 .07908 Mdot
.30351 .26487 Mdot
.91879 .17463 Mdot
.9405 .39825 Mdot
.40769 .1264 Mdot
.94075 .39538 Mdot
.47662 .61074 Mdot
.63555 .06021 Mdot
.90924 .16915 Mdot
.962 .40595 Mdot
.35571 .14133 Mdot
.89383 .38575 Mdot
.22664 .5052 Mdot
.8902 .16202 Mdot
.44428 .12752 Mdot
.48184 .6122 Mdot
.6767 .46376 Mdot
.42295 .12101 Mdot
.3243 .21835 Mdot
.33695 .19269 Mdot
.713 .36051 Mdot
.32482 .25421 Mdot
.69156 .08226 Mdot
.27224 .27547 Mdot
.67746 .44117 Mdot
.44213 .12529 Mdot
.71695 .36061 Mdot
.08985 .23323 Mdot
.68858 .38327 Mdot
.32037 .24765 Mdot
.08497 .23499 Mdot
.48195 .13088 Mdot
.03824 .43267 Mdot
.06751 .44061 Mdot
.32605 .20658 Mdot
.3289 .14802 Mdot
.29436 .2605 Mdot
.68421 .4377 Mdot
.53634 .01557 Mdot
.30724 .53718 Mdot
.91088 .17279 Mdot
.34547 .1537 Mdot
.33264 .15148 Mdot
.38171 .12943 Mdot
.32825 .21792 Mdot
.05889 .2256 Mdot
.33927 .1391 Mdot
.17072 .25855 Mdot
.53064 .01583 Mdot
.82072 .13496 Mdot
.37446 .13911 Mdot
.68498 .43342 Mdot
.20986 .26857 Mdot
.20633 .49772 Mdot
.28414 .2713 Mdot
.05234 .43508 Mdot
.33094 .17848 Mdot
.37215 .12412 Mdot
.3278 .16946 Mdot
.13876 .2509 Mdot
.20308 .26243 Mdot
.38669 .11866 Mdot
.34147 .14638 Mdot
.33559 .14034 Mdot
.76163 .11112 Mdot
.32541 .22776 Mdot
.41822 .12479 Mdot
.12295 .46318 Mdot
.69939 .38054 Mdot
.11399 .24458 Mdot
.76031 .35584 Mdot
.34119 .13662 Mdot
.95323 .18541 Mdot
.4662 .12679 Mdot
.34257 .17163 Mdot
.7095 .37975 Mdot
.90817 .38626 Mdot
.97792 .40929 Mdot
.66844 .07271 Mdot
.50998 .13489 Mdot
.84891 .36907 Mdot
.91604 .17135 Mdot
.86271 .37739 Mdot
.34205 .19441 Mdot
.27719 .27353 Mdot
.22089 .26397 Mdot
.31871 .23027 Mdot
.30979 .25415 Mdot
.2861 .27303 Mdot
.02457 .42486 Mdot
.69701 .38173 Mdot
.18267 .48603 Mdot
.32599 .19999 Mdot
.32054 .21243 Mdot
.32267 .23202 Mdot
.71401 .36175 Mdot
.93155 .39471 Mdot
.72449 .09465 Mdot
.7324 .09873 Mdot
.39183 .12811 Mdot
.39506 .1198 Mdot
.1372 .24981 Mdot
.32543 .18099 Mdot
.71418 .37071 Mdot
.82822 .36997 Mdot
.98495 .41262 Mdot
.47427 .60889 Mdot
.68769 .41609 Mdot
.68114 .42042 Mdot
.91418 .1714 Mdot
.33791 .20383 Mdot
.32819 .23089 Mdot
.30499 .25561 Mdot
.22121 .50441 Mdot
.32583 .19265 Mdot
.70364 .37345 Mdot
.32586 .21267 Mdot
.43568 .1275 Mdot
.04001 .21934 Mdot
.35058 .14284 Mdot
.45549 .601 Mdot
.99544 .41511 Mdot
.34539 .17512 Mdot
.3354 .21389 Mdot
.42423 .11946 Mdot
.20494 .26702 Mdot
.74034 .35839 Mdot
.34283 .5531 Mdot
.13582 .46744 Mdot
.0688 .22867 Mdot
.38453 .12078 Mdot
.13778 .24698 Mdot
.33941 .20468 Mdot
.73299 .10063 Mdot
.50659 .13468 Mdot
.23524 .26612 Mdot
.39076 .11927 Mdot
.78149 .35827 Mdot
.3182 .22375 Mdot
.43791 .12935 Mdot
.1959 .26609 Mdot
.36607 .56241 Mdot
.96742 .19251 Mdot
.32051 .22955 Mdot
.37615 .13222 Mdot
.70659 .08802 Mdot
.40151 .12624 Mdot
.32348 .21482 Mdot
.34317 .14077 Mdot
.33402 .23258 Mdot
.68646 .40626 Mdot
.37161 .1417 Mdot
.29485 .26202 Mdot
.5743 .03326 Mdot
.16444 .4813 Mdot
.23276 .26802 Mdot
.06501 .44015 Mdot
.68171 .40566 Mdot
.00036 .20423 Mdot
.93073 .18002 Mdot
.07051 .22704 Mdot
.30365 .25018 Mdot
.30728 .26718 Mdot
.67922 .45796 Mdot
.36296 .13501 Mdot
.32953 .22622 Mdot
.33736 .20783 Mdot
.68223 .42521 Mdot
.26086 .51963 Mdot
.33311 .14528 Mdot
.32351 .2162 Mdot
.11646 .24168 Mdot
.69062 .37862 Mdot
.32591 .19357 Mdot
.26352 .26647 Mdot
.31523 .23279 Mdot
.36263 .13658 Mdot
.74103 .35991 Mdot
.14662 .47438 Mdot
.68766 .41567 Mdot
.33897 .14377 Mdot
.68805 .39699 Mdot
.6798 .42004 Mdot
.60568 .04472 Mdot
.49873 .13456 Mdot
.34817 .16565 Mdot
.41744 .58561 Mdot
.43368 .12613 Mdot
.42188 .58563 Mdot
.32746 .2051 Mdot
.86853 .37552 Mdot
.37576 .141 Mdot
.94476 .39726 Mdot
.33285 .22836 Mdot
.70743 .36347 Mdot
.8044 .36425 Mdot
.78849 .35685 Mdot
.13072 .24926 Mdot
.68527 .43733 Mdot
.67802 .07533 Mdot
.01138 .20672 Mdot
.35594 .15066 Mdot
.744 .10471 Mdot
.73954 .36592 Mdot
.70007 .38914 Mdot
.11913 .46092 Mdot
.34246 .15485 Mdot
.02701 .42716 Mdot
.08582 .23312 Mdot
.36688 .13147 Mdot
.6833 .07752 Mdot
.39942 .57686 Mdot
.32439 .16614 Mdot
.32554 .24363 Mdot
.11122 .24048 Mdot
.33633 .22262 Mdot
.29278 .26925 Mdot
.11807 .46263 Mdot
.31635 .24024 Mdot
.35552 .12833 Mdot
.20969 .49951 Mdot
.77683 .36186 Mdot
.34165 .18001 Mdot
.31943 .23852 Mdot
.36002 .14408 Mdot
.76985 .36053 Mdot
.84431 .36997 Mdot
.27353 .27374 Mdot
.33783 .20166 Mdot
.79352 .35786 Mdot
.3872 .12328 Mdot
.7986 .1276 Mdot
.34099 .17484 Mdot
.75105 .35429 Mdot
.79267 .36496 Mdot
.30692 .26589 Mdot
.79497 .35843 Mdot
.38304 .56908 Mdot
.74761 .36278 Mdot
.36021 .1269 Mdot
.02003 .42296 Mdot
.25921 .2668 Mdot
.96629 .19204 Mdot
.18694 .4885 Mdot
.36203 .14544 Mdot
.68482 .40801 Mdot
.36147 .14885 Mdot
.17667 .25832 Mdot
.14027 .251 Mdot
.69279 .38293 Mdot
.19258 .26558 Mdot
.24256 .5131 Mdot
.79321 .36521 Mdot
.27008 .27266 Mdot
.196 .26288 Mdot
.76993 .35797 Mdot
.35864 .14101 Mdot
.68462 .41763 Mdot
.79514 .3634 Mdot
.29279 .27126 Mdot
.08204 .23028 Mdot
.71058 .09057 Mdot
.70765 .36326 Mdot
.98887 .41495 Mdot
.70443 .36659 Mdot
.35427 .16331 Mdot
.33264 .22667 Mdot
.10493 .24001 Mdot
.32074 .21289 Mdot
.53875 .01745 Mdot
.32435 .2248 Mdot
.377 .12587 Mdot
.69152 .38798 Mdot
.32113 .25763 Mdot
.33274 .15253 Mdot
.04393 .43235 Mdot
.2547 .26531 Mdot
.28332 .26324 Mdot
.69089 .39631 Mdot
.97325 .40898 Mdot
.8385 .36758 Mdot
.3271 .1975 Mdot
.32517 .25657 Mdot
.42033 .12541 Mdot
.93258 .18018 Mdot
.94308 .18473 Mdot
.1091 .24116 Mdot
.70967 .38011 Mdot
.33977 .16368 Mdot
.28591 .52973 Mdot
.29366 .25971 Mdot
.94231 .4006 Mdot
.24275 .27328 Mdot
.45239 .60003 Mdot
.48581 .13111 Mdot
.17334 .26115 Mdot
.96382 .1899 Mdot
.67816 .45463 Mdot
.72395 .36719 Mdot
.68947 .40845 Mdot
.79033 .35714 Mdot
.36131 .14676 Mdot
.33816 .22683 Mdot
.34372 .18588 Mdot
.67978 .42459 Mdot
.04539 .43296 Mdot
.69356 .37814 Mdot
.34755 .13185 Mdot
.34432 .19364 Mdot
.32928 .15886 Mdot
.10597 .23911 Mdot
.40106 .12736 Mdot
.85669 .37155 Mdot
.97393 .41076 Mdot
.3134 .24725 Mdot
.39883 .57534 Mdot
.14473 .24954 Mdot
.93397 .39742 Mdot
.2811 .52624 Mdot
.90235 .3866 Mdot
.32308 .206 Mdot
.10797 .45802 Mdot
.42535 .58883 Mdot
.05247 .22394 Mdot
.42756 .1193 Mdot
.6679 .07348 Mdot
.91998 .39001 Mdot
.40211 .12941 Mdot
.2285 .26451 Mdot
.36821 .14632 Mdot
.61472 .05147 Mdot
.04552 .21967 Mdot
.17547 .26101 Mdot
.44463 .59712 Mdot
.6864 .38843 Mdot
.32227 .20128 Mdot
.81959 .36522 Mdot
.96172 .1892 Mdot
.33592 .15017 Mdot
.32572 .22569 Mdot
.7226 .35906 Mdot
.68874 .4225 Mdot
.34782 .132 Mdot
.49319 .61534 Mdot
.00123 .20433 Mdot
.76201 .35573 Mdot
.15782 .47681 Mdot
.15419 .47495 Mdot
.02531 .42814 Mdot
.43969 .13087 Mdot
.189 .49015 Mdot
.76402 .35985 Mdot
.69296 .39092 Mdot
.6851 .40745 Mdot
.68576 .39529 Mdot
.13019 .24508 Mdot
.33581 .21914 Mdot
.1046 .24153 Mdot
.09243 .45184 Mdot
.71823 .37263 Mdot
.79805 .3631 Mdot
.03952 .43313 Mdot
.32423 .19832 Mdot
.68164 .43031 Mdot
.35611 .14951 Mdot
.50549 .13307 Mdot
.32147 .24965 Mdot
.88901 .16359 Mdot
.49406 .13044 Mdot
.49346 .13136 Mdot
.32535 .23066 Mdot
.34393 .13384 Mdot
.32587 .24713 Mdot
.33278 .18743 Mdot
.34291 .16289 Mdot
.30495 .25586 Mdot
.74171 .36548 Mdot
.32173 .23643 Mdot
.28762 .52932 Mdot
.48669 .61408 Mdot
.52973 .01356 Mdot
.77079 .11554 Mdot
.36255 .14829 Mdot
.77237 .11559 Mdot
.68638 .39537 Mdot
.17665 .25599 Mdot
.60286 .04515 Mdot
.46065 .12449 Mdot
.75843 .11062 Mdot
.97179 .40747 Mdot
.40101 .12009 Mdot
.45725 .12725 Mdot
.92025 .17346 Mdot
.94672 .18345 Mdot
.33017 .17693 Mdot
.83181 .36903 Mdot
.26565 .26573 Mdot
.10048 .2391 Mdot
.40818 .58097 Mdot
.29021 .27302 Mdot
.48519 .13016 Mdot
.92478 .39297 Mdot
.68765 .43364 Mdot
.40434 .57985 Mdot
.56471 .02798 Mdot
.33581 .18882 Mdot
.34448 .18636 Mdot
.33863 .21768 Mdot
.45817 .12655 Mdot
.69328 .38148 Mdot
.1936 .26074 Mdot
.28147 .26544 Mdot
.29626 .26172 Mdot
.13766 .25037 Mdot
.35173 .16661 Mdot
.28681 .53154 Mdot
.10884 .45933 Mdot
.8289 .13833 Mdot
.3296 .2452 Mdot
.36222 .13409 Mdot
.0779 .22901 Mdot
.32117 .23546 Mdot
.73259 .36811 Mdot
.67636 .45643 Mdot
.39029 .57318 Mdot
.2117 .26469 Mdot
.33007 .22286 Mdot
.56352 .02792 Mdot
.22612 .27033 Mdot
.49848 .1328 Mdot
.47566 .13112 Mdot
.70511 .37381 Mdot
.67133 .07495 Mdot
.07665 .44439 Mdot
.78177 .35531 Mdot
.85638 .37042 Mdot
.40533 .1205 Mdot
.34565 .16435 Mdot
.73799 .10313 Mdot
.10082 .45477 Mdot
.32589 .20462 Mdot
.3493 .55581 Mdot
.33941 .148 Mdot
.71988 .35729 Mdot
.23417 .26854 Mdot
.45194 .13065 Mdot
.04145 .43244 Mdot
.32524 .25405 Mdot
.83508 .1424 Mdot
.32503 .20288 Mdot
.81041 .36669 Mdot
.27024 .27343 Mdot
.23461 .50899 Mdot
.72699 .3606 Mdot
.41687 .58391 Mdot
.34921 .13504 Mdot
.40932 .13051 Mdot
.68894 .4083 Mdot
.15354 .25343 Mdot
.09702 .23697 Mdot
.95051 .40154 Mdot
.31245 .248 Mdot
.89656 .38556 Mdot
.86805 .37605 Mdot
.32533 .1768 Mdot
.6799 .44633 Mdot
.22635 .27019 Mdot
.95841 .40505 Mdot
.34586 .17294 Mdot
.70742 .373 Mdot
.72429 .36118 Mdot
.34215 .21206 Mdot
.44823 .12387 Mdot
.40221 .12669 Mdot
.43229 .13064 Mdot
.27 .267 Mdot
.47856 .12979 Mdot
.09356 .23433 Mdot
.47052 .60593 Mdot
.74454 .10371 Mdot
.32754 .20213 Mdot
.99586 .20446 Mdot
.34479 .18839 Mdot
.39494 .13232 Mdot
.26909 .26679 Mdot
.33589 .14421 Mdot
.33102 .16947 Mdot
.5874 .03974 Mdot
.35446 .13401 Mdot
.33968 .1934 Mdot
.53536 .01577 Mdot
.83516 .36782 Mdot
.35208 .16688 Mdot
.35755 .13837 Mdot
.67275 .47008 Mdot
.7231 .3683 Mdot
.9005 .16807 Mdot
.74068 .36013 Mdot
.17959 .25997 Mdot
.37139 .13155 Mdot
.17069 .25543 Mdot
.14294 .47288 Mdot
.22728 .50679 Mdot
.39146 .11847 Mdot
.32788 .25031 Mdot
.00547 .42136 Mdot
.30467 .26796 Mdot
.68456 .40896 Mdot
.68306 .40044 Mdot
.44871 .12286 Mdot
.31048 .25768 Mdot
.6817 .41154 Mdot
.39227 .11794 Mdot
.34836 .13273 Mdot
.34122 .15917 Mdot
.47463 .12875 Mdot
.1378 .47002 Mdot
.42908 .13134 Mdot
.35024 .15601 Mdot
.34896 .16257 Mdot
.31838 .25427 Mdot
.29895 .25573 Mdot
.34422 .13077 Mdot
.01634 .2083 Mdot
.4638 .12482 Mdot
.34163 .18534 Mdot
.72362 .35944 Mdot
.36902 .14467 Mdot
.41565 .12213 Mdot
.47964 .13217 Mdot
.2312 .50839 Mdot
.71311 .36158 Mdot
.14892 .25053 Mdot
.39393 .57323 Mdot
.12137 .24227 Mdot
.46205 .13171 Mdot
.2838 .26578 Mdot
.71817 .36038 Mdot
.43439 .59058 Mdot
.71416 .09084 Mdot
.13402 .24808 Mdot
.11107 .24042 Mdot
.4528 .59989 Mdot
.06257 .4393 Mdot
.32708 .2218 Mdot
.3285 .16382 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002Mooooo`;o0000POooool002KooooolOl00009oooo
o`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool05oooool00`00003o0000o`00000Cooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1iooooo`04o`00
0?oooooo0000o`00073ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
Noooool01000003o0000o`000?l0001^ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo07kooooo0_l0001]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo087ooooo00<00000o`000?l00000JOooool00ol0003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`23ooooo`?o0000Ioooool00ol0003oooooooooo`07ooooo`009_ooool2o`00
08Oooooo0ol0001Sooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0R?ooool3o`0006;o
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0R_ooool4o`0005oooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0S?ooool00`00003o0000o`00
001Nooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo08oooooo0ol0001K
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo097ooooo0ol000000`00
003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo09Co
oooo0ol0001Fooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000Uoooool4o`0005;ooooo
0_l00009ooooo`009_ooool00ol0003oooooooooo`2Hooooo`Co0000DOooool00ol0003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`2Kooooo`Co0000C_ooool00ol0003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`2Mooooo`Co0000C?ooool00ol0003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`2Oooooo`Co0000B_ooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`2Rooooo`?o0000B?ooool00ol0003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`2Tooooo`Co0000AOooool00ol0003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`2Wooooo`?o0000@oooool00ol0003oooooooooo`07ooooo`009_ooool2o`00
0:[ooooo1?l0000oooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0[?ooool00`00003o
0000ooooo`0nooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0:kooooo
0ol0000looooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0;3ooooo0_l0
00000`00003o0000ooooo`0hooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo0;?ooooo1?l0000fooooo`03o`000?oooooooooo00Oooooo000Cooooo`;o00001?ooool01?l0
003oooooooooooooool5o`0000Cooooo00?o0000ooooooooool0F_ooool3o`00000300000?oooooo
oooo05Gooooo1?l0000dooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Doooooa7o00000_oo
ool2o`0004kooooo1?l000000`00003oooooooooo`0_ooooo`03o`000?oooooooooo00Oooooo000B
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2o`0005;ooooo7_l0
001;ooooo`04o`000000003o0000o`0002gooooo0ol00009ooooo`004_ooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0CooooolVo`0004Oooooo
0ol0000^ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo04kooooo00?o0000ooooool0
00005ol000000ooooooo0000o`00000=o`00000300000?oooooooooo04Cooooo1?l0000Zooooo`03
o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo04gooooo4?l0000Fooooo`0300000?oooooo0000
00Go0000A_ooool4o`0002Sooooo00?o0000ooooooooool01oooool001?ooooo0_l00009ooooo`?o
00001Oooool00ol0003oooooooooo`1=ooooo`co0000Joooool3o`0002Kooooo00?o0000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0C?ooool;o`0006oooooo00@00000o`000?l0003o
00008oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1<ooooo`[o0000
M?ooool2o`00027ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Booo
ool:o`0007Kooooo1?l0000Nooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000COooool8
o`0007[ooooo1?l0000Jooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0Boooool8o`00
07gooooo1?l0000Iooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04_o
oooo2?l0001oooooo`Go00005_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`1;ooooo`Oo0000Poooool5o`0001?ooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0Boooool7o`0008Kooooo1Ol0000@ooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo04_ooooo0_l000001000003o0000o`000?l0002;ooooo`?o00003_oo
ool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1;ooooo`;o000000@00000
o`000?l0003o0000S?ooool4o`0000cooooo00?o0000ooooooooool01oooool002Kooooo0_l0001<
ooooo`Ko0000S_ooool01?l000000000o`000?l00009ooooo`;o00002Oooool002Kooooo00?o0000
ooooooooool0Boooool6o`0009;ooooo0ol00007ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo04[ooooo1ol0002Eooooo`?o00001?ooool00ol0003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`1:ooooo`Oo0000Uoooool4o`000003ooooool0003ooooo00So
oooo000Vooooo`;o0000Boooool6o`0009_ooooo0ol00009ooooo`009_ooool5o`0004Sooooo1_l0
002Mooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00?o000000?ooooo
00000?ooool0A?ooool2o`00000400000?l0003o0000o`0009gooooo00?o0000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool00oooool3o`000003ooooo`00003ooooo047ooooo1_l0002M
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o00001_ooool4o`00000300000?l0003ooooo
03kooooo1_l0002Looooo`;o00002Oooool002Kooooo00?o0000ooooooooool02?ooool4o`000003
00000?oooooooooo03[ooooo1?l000000`00003o0000o`00002Mooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo00_ooooo00H00000o`000?l0003o000000000?l0000hoooo
o`0300000?l0003o000000?o0000W_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`0?ooooo`Go0000=Oooool6o`0009kooooo00?o0000ooooooooool01oooool001?ooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
1?l000000ooooooo0000ooooo`0`ooooo`0300000?l0003o000000;o000000<00000o`000?ooool0
WOooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00`00003o0000o`000004o`0002gooooo
1_l0002Oooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo
1Ol00004ooooo`03o`000?oooooooooo01Oooooo1?l000000`00003o0000o`00000Yooooo`Oo0000
Woooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Gooooo0_l0000Mooooo`Ko000000<00000ooooooooool08Oooool8o`0009go
oooo0ol00009ooooo`004_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool07_ooool7o`000003ooooo`00003ooooo01cooooo2?l000000`00003o
ooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Wo
oooo0_l00005ooooo`03o`000?oooooooooo027ooooo2?l000000`00003o0000ooooo`0Hooooo`So
0000XOooool00ol0003oooooooooo`07ooooo`004oooool2o`0000_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Uooooo`go00003oooool:o`000:;ooooo00?o0000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0:_oooolEo`00000300000?l0003o000000Oo000000<0
0000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0^
ooooo`Wo000000<00000o`000?l000003Ol000000`00003oooooooooo`2Sooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo03?ooooo00<00000ooooool000003_l000000`00
003oooooooooo`2Vooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000kOooool2o`0000Wo
oooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`00
1oooool3o`0001cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`002?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01ooo
ool000Sooooo00?o0000ooooooooool06oooool2o`000>gooooo0_l00009ooooo`002?ooool2o`00
01cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`001oooool2o`000003
ooooool0003o000001[ooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`;o0000kOooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo0>gooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`2/ooooo`03o`000000003o000000Co000000Cooooo
o`000?l0003o0000=_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2Y
oooooaCo0000<?ooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0YooooolMo`0002Wooooo00?o0000oooo
ooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0Y_ooool;o`0000;ooooo00?o0000ooooooooool00ol00000
0`00003o0000o`00000:o`00000300000?l0003ooooo02Cooooo00?o0000ooooooooool01oooool0
01;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0Y?ooool2o`00000300000?l0003o000000Go00004_ooool=o`00023ooooo00?o
0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo0_l0
002Uooooo`Ko00007?ooool00ol000000000o`000007o`0001_ooooo0ol00009ooooo`004_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0X_oo
ool7o`00027ooooo2?l000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Oooooo000B
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Rooooo`Co000000<00000o`000?ooool09Oooool00`00003oooooo`000006o`0001Kooooo00?o
0000ooooooooool01oooool001?ooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`2R
ooooo`Go0000:oooool01000003o0000o`0000000003o`00000300000?oooooooooo017ooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0XOooool5o`00037ooooo1_l0000@
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0:7ooooo1Ol0000doooo
o`Ko00003Oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2Qooooo`?o
000000<00000ooooooooool0=_ooool6o`0000[ooooo00?o0000ooooooooool01oooool002Kooooo
0_l0002Rooooo`Co0000>oooool6o`0000Kooooo0_l00009ooooo`009_ooool00ol0003ooooooooo
o`2Qooooo`?o0000?oooool6o`0000Cooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0XOooool3o`0004?ooooo1?l000000`00003oooooo`000009ooooo`009_ooool00ol0
003oooooooooo`2Pooooo`Co0000AOooool5o`0000Wooooo000Vooooo`Go0000W_ooool4o`0004So
oooo0_l00009ooooo`009_ooool00ol0003oooooo`000004o`0009cooooo0ol000000`00003ooooo
ooooo`17ooooo`03o`000?oooooooooo00Oooooo000Vooooo`04o`000?ooooooooooooooo`Go0000
00<00000ooooooooool0Uoooool3o`0004[ooooo00?o0000ooooooooool01oooool002Kooooo0_l0
0005ooooo`Go0000Uoooool3o`0004Wooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`07
ooooo`0300000?l0003o000000;o0000U?ooool3o`0004[ooooo00?o0000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool02_ooool01000003o0000o`000?l0002Booooo`;o000000<00000
ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0<oooo
o`0300000?l0003o000000;o0000Soooool2o`0004_ooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool03oooool5o`0008_ooooo0ol0001;ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo01;ooooo1?l0002:ooooo`;o0000Boooool00ol0003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`0Dooooo`Go0000Q_ooool2o`0004cooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool05oooool5o`0008?ooooo00<00000
o`000?l00000Boooool00ol0003oooooooooo`07ooooo`009_ooool2o`0001_ooooo1?l00021oooo
o`;o0000Boooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo01gooooo0ol0001nooooo`;o
0000COooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Oooooo`Co0000
Noooool2o`0004gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool08Ooo
ool01Ol0003oooooo`000?ooool0000007Sooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`0Tooooo`Co0000aOooool00ol0003ooooooooo
o`07ooooo`004oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool09_ooool01Ol0003oooooo`000?l0000000000<;ooooo00?o0000ooooooooool01ooo
ool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool0:Oooool3o`000<7ooooo00?o0000ooooooooool01oooool001;ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0000]ooooo`;o
000000<00000ooooooooool0^_ooool3o`0000Wooooo000Booooo`04o`000?ooooooooooo`0000So
oooo0ol00005ooooo`03o`000?oooooooooo02oooooo0_l0002looooo`03o`000?oooooooooo00Oo
oooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo037ooooo0_l000000ooooooo0000ooooo`2gooooo`03o`000?oooooooooo
00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo03?ooooo0ol0002gooooo`03o`000?oooooooooo00Oooooo000Coooo
o`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0=Oooool01000003o0000o`000?l0002d
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo03Sooooo00@00000o`00
0?l0003o0000/Oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0joooo
o`Co0000[oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0mooooo`03
o`000000003o00000:gooooo00?o0000ooooooooool01oooool002Kooooo0_l00011ooooo`?o0000
ZOooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo04;ooooo0ol0002Xooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Cooooo1?l0002Uooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo04Kooooo1Ol0002Rooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo04Wooooo1?l0002Pooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo04_ooooo1?l0002Nooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo04kooooo0ol000000`00003oooooooooo`2Iooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`;o0000DOooool3o`0009Wooooo0_l00009ooooo`009_ooool00ol0
003oooooooooo`1Cooooo`?o0000Uoooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`1Eooooo`0300000?l0003ooooo09Gooooo00?o0000ooooooooool01oooool002Kooooo
00?o0000ooooooooool0F?ooool3o`0009;ooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0FOooool5o`0008oooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0GOooool00ol0003oooooo`00002=ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo05kooooo1?l000000`00003oooooooooo`28ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo067ooooo0ol00029ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`;o0000I?ooool3o`0008Kooooo0_l00009ooooo`009_ooool00ol0003ooooooooo
o`1Uooooo`Go0000Poooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1W
ooooo`Co0000P_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Zoooo
o`;o000000<00000o`000?ooool0O_ooool00ol0003oooooooooo`07ooooo`007_ooool3o`0000Go
oooo00?o0000ooooooooool0KOooool3o`0007gooooo00?o0000ooooooooool01oooool001oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool03oooool3o`0001_ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01_ooool4o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool001oooooo00?o0000
ooooooooool01?oooooao`0000Wooooo000Oooooo`03o`000?oooooooooo0?kooooo000Nooooo`;o
0000ooooool1ooooo`007oooool00ol0003oooooooooo`3nooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.158908, -0.161707, \
0.00416367, 0.00673696}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.54899 .53003 Mdot
.63595 .59088 Mdot
.47111 .12838 Mdot
.55162 .07216 Mdot
.69572 .12466 Mdot
.12524 .24487 Mdot
.27448 .26706 Mdot
.41486 .0496 Mdot
.67286 .45565 Mdot
.45163 .59781 Mdot
.92105 .17382 Mdot
.26978 .26668 Mdot
.65616 .47475 Mdot
.52826 .12461 Mdot
.39009 .03956 Mdot
.40263 .11913 Mdot
.37056 .02107 Mdot
.70641 .35955 Mdot
.37532 .13203 Mdot
.51761 .11731 Mdot
.59434 .49976 Mdot
.60343 .50391 Mdot
.44313 .03284 Mdot
.4659 .12205 Mdot
.4364 .12301 Mdot
.53756 .51426 Mdot
.50257 .11344 Mdot
.8854 .15995 Mdot
.4707 .09064 Mdot
.59991 .56874 Mdot
.7872 .35567 Mdot
.3131 .24826 Mdot
.58568 .55414 Mdot
.25827 .26928 Mdot
.67157 .45904 Mdot
.46001 .08187 Mdot
.35441 .13627 Mdot
.44144 .05808 Mdot
.54592 .06677 Mdot
.67534 .43149 Mdot
.62305 .49878 Mdot
.5708 .50699 Mdot
.63986 .10475 Mdot
.39066 .12315 Mdot
.40778 .02348 Mdot
.67742 .41193 Mdot
.41638 .04034 Mdot
.07845 .22979 Mdot
.59338 .50656 Mdot
.39506 .03938 Mdot
.71956 .35874 Mdot
.49658 .10261 Mdot
.47093 .03965 Mdot
.12945 .245 Mdot
.54905 .51464 Mdot
.59218 .08549 Mdot
.52396 .51537 Mdot
.48989 .11845 Mdot
.0642 .22513 Mdot
.52133 .51092 Mdot
.98778 .19901 Mdot
.28298 .26731 Mdot
.68063 .39593 Mdot
.48227 .11622 Mdot
.57723 .5005 Mdot
.31901 .54264 Mdot
.65957 .47648 Mdot
.64645 .48522 Mdot
.57702 .54839 Mdot
.47329 .08203 Mdot
.32475 .22409 Mdot
.34792 .15296 Mdot
.66137 .47801 Mdot
.63114 .58927 Mdot
.36631 .02322 Mdot
.31145 .2565 Mdot
.35035 .13792 Mdot
.67979 .41937 Mdot
.30159 .26018 Mdot
.45504 .03903 Mdot
.77863 .3539 Mdot
.9298 .39272 Mdot
.45273 .08263 Mdot
.47422 .09699 Mdot
.49763 .1179 Mdot
.46971 .11666 Mdot
.47787 .09529 Mdot
.76094 .35175 Mdot
.55542 .53591 Mdot
.6385 .48892 Mdot
.46001 .07659 Mdot
.28441 .26439 Mdot
.71627 .35689 Mdot
.67904 .39261 Mdot
.30811 .25487 Mdot
.30895 .25164 Mdot
.47025 .09402 Mdot
.45272 .08022 Mdot
.59134 .50858 Mdot
.68492 .37657 Mdot
.46634 .03741 Mdot
.62677 .58695 Mdot
.84779 .14562 Mdot
.52058 .12532 Mdot
.43431 .0256 Mdot
.67448 .43669 Mdot
.52344 .12035 Mdot
.50024 .1133 Mdot
.41775 .03364 Mdot
.38112 .02809 Mdot
.42015 .11844 Mdot
.01116 .20693 Mdot
.4453 .06854 Mdot
.99871 .41503 Mdot
.33562 .18272 Mdot
.3731 .02008 Mdot
.8341 .13957 Mdot
.45108 .07001 Mdot
.38325 .01669 Mdot
.62374 .58067 Mdot
.61999 .50107 Mdot
.72547 .35726 Mdot
.32907 .21403 Mdot
.44837 .06633 Mdot
.44753 .03874 Mdot
.70884 .361 Mdot
.6751 .40997 Mdot
.84053 .36612 Mdot
.60899 .0925 Mdot
.46935 .0824 Mdot
.4948 .04674 Mdot
.50003 .11949 Mdot
.56569 .07715 Mdot
.33402 .1802 Mdot
.42156 .58527 Mdot
.41657 .02661 Mdot
.50283 .12315 Mdot
.45865 .07066 Mdot
.66999 .44945 Mdot
.75299 .35313 Mdot
.50923 .00431 Mdot
.47441 .08301 Mdot
.34752 .15436 Mdot
.43772 .02771 Mdot
.51217 .10927 Mdot
.00405 .41678 Mdot
.62842 .49756 Mdot
.46133 .12179 Mdot
.49235 .09511 Mdot
.5983 .56225 Mdot
.05423 .43597 Mdot
.41501 .03465 Mdot
.36421 .01792 Mdot
.68141 .40609 Mdot
.32539 .22319 Mdot
.59906 .50423 Mdot
.39843 .01538 Mdot
.48028 .09314 Mdot
.44782 .03782 Mdot
.6021 .56891 Mdot
.00557 .41864 Mdot
.58099 .50935 Mdot
.38329 .019 Mdot
.29162 .26596 Mdot
.37416 .01145 Mdot
.09819 .45322 Mdot
.70974 .35662 Mdot
.55527 .53191 Mdot
.33977 .16637 Mdot
.33682 .18582 Mdot
.44444 .06329 Mdot
.73025 .09766 Mdot
.44484 .12539 Mdot
.5291 .50268 Mdot
.44615 .12182 Mdot
.36924 .02374 Mdot
.39822 .12079 Mdot
.48349 .11728 Mdot
.54471 .50262 Mdot
.46541 .07952 Mdot
.40935 .04603 Mdot
.66889 .07207 Mdot
.60761 .50423 Mdot
.76974 .15393 Mdot
.45641 .07227 Mdot
.45702 .04131 Mdot
.56278 .53933 Mdot
.49563 .0513 Mdot
.11776 .45996 Mdot
.63601 .49759 Mdot
.52506 .51369 Mdot
.5025 .13069 Mdot
.29273 .26424 Mdot
.52887 .50982 Mdot
.56 .50104 Mdot
.53002 .50889 Mdot
.4039 .12124 Mdot
.25057 .51351 Mdot
.51721 .11445 Mdot
.40776 .12229 Mdot
.64918 .49057 Mdot
.35108 .14717 Mdot
.49685 .04858 Mdot
.62184 .0957 Mdot
.51106 .10824 Mdot
.39603 .02878 Mdot
.99505 .20209 Mdot
.47315 .12218 Mdot
.47021 .08414 Mdot
.53122 .50422 Mdot
.64162 .49565 Mdot
.4836 .09232 Mdot
.35122 .00973 Mdot
.04536 .43314 Mdot
.57421 .54562 Mdot
.56201 .50252 Mdot
.32955 .21259 Mdot
.32073 .24165 Mdot
.66559 .47082 Mdot
.43724 .06861 Mdot
.52856 .12605 Mdot
.32908 .19543 Mdot
.94165 .39554 Mdot
.408 .01953 Mdot
.03777 .42941 Mdot
.44363 .06887 Mdot
.3234 .23952 Mdot
.31287 .24898 Mdot
.3695 .01559 Mdot
.58386 .50826 Mdot
.41673 .0468 Mdot
.6899 .37426 Mdot
.69532 .36989 Mdot
.49652 .11036 Mdot
.38351 .02716 Mdot
.44976 .03988 Mdot
.22691 .50367 Mdot
.57975 .54834 Mdot
.5606 .53796 Mdot
.17528 .25684 Mdot
.54193 .52959 Mdot
.2084 .26405 Mdot
.03626 .21607 Mdot
.55903 .54285 Mdot
.69364 .37354 Mdot
.34124 .16144 Mdot
.90379 .38374 Mdot
.42675 .05339 Mdot
.37462 .01977 Mdot
.48512 .11724 Mdot
.53721 .06683 Mdot
.2257 .50404 Mdot
.43111 .0524 Mdot
.40225 .04043 Mdot
.67195 .44365 Mdot
.50007 .11883 Mdot
.55529 .5109 Mdot
.69681 .36977 Mdot
.48712 .10888 Mdot
.61716 .04967 Mdot
.51929 .05936 Mdot
.45667 .04067 Mdot
.60584 .508 Mdot
.50722 .10481 Mdot
.66765 .44794 Mdot
.41639 .04946 Mdot
.58207 .50705 Mdot
.57597 .55303 Mdot
.64496 .60194 Mdot
.37543 .0149 Mdot
.85157 .14713 Mdot
.41128 .58068 Mdot
.75091 .35122 Mdot
.48381 .12098 Mdot
.73454 .35207 Mdot
.5409 .52133 Mdot
.63717 .59308 Mdot
.26813 .26946 Mdot
.42399 .02507 Mdot
.78288 .35595 Mdot
.40219 .02071 Mdot
.75815 .35284 Mdot
.51156 .11963 Mdot
.37902 .02888 Mdot
.66298 .47556 Mdot
.10034 .45396 Mdot
.40752 .04281 Mdot
.57487 .50661 Mdot
.45001 .07399 Mdot
.40458 .02837 Mdot
.51251 .05783 Mdot
.50869 .10666 Mdot
.40417 .01897 Mdot
.6761 .41659 Mdot
.10448 .23878 Mdot
.82908 .36319 Mdot
.5306 .51851 Mdot
.54872 .50702 Mdot
.2045 .26364 Mdot
.58066 .51131 Mdot
.42436 .11977 Mdot
.56026 .50265 Mdot
.40718 .04714 Mdot
.47213 .12059 Mdot
.58385 .08293 Mdot
.33683 .17943 Mdot
.30395 .25524 Mdot
.55464 .5301 Mdot
.372 .13475 Mdot
.38081 .03272 Mdot
.61187 .57173 Mdot
.37733 .02599 Mdot
.67985 .38734 Mdot
.3735 .12537 Mdot
.52041 .12412 Mdot
.66159 .11104 Mdot
.43004 .04909 Mdot
.30905 .25049 Mdot
.66239 .48046 Mdot
.40477 .12356 Mdot
.41741 .03762 Mdot
.4971 .12147 Mdot
.46173 .08012 Mdot
.47976 .09959 Mdot
.85385 .36945 Mdot
.5743 .55159 Mdot
.39597 .03102 Mdot
.53706 .51957 Mdot
.6172 .5024 Mdot
.32933 .2017 Mdot
.56659 .51226 Mdot
.55447 .52061 Mdot
.25146 .2698 Mdot
.84452 .36686 Mdot
.45377 .1218 Mdot
.33865 .15461 Mdot
.54045 .50086 Mdot
.52713 .12576 Mdot
.31826 .24374 Mdot
.29079 .26495 Mdot
.23882 .26883 Mdot
.38402 .02424 Mdot
.61872 .49631 Mdot
.43809 .03267 Mdot
.36367 .00727 Mdot
.31054 .2528 Mdot
.31831 .24768 Mdot
.38475 .02823 Mdot
.64876 .49226 Mdot
.82329 .36216 Mdot
.47257 .12164 Mdot
.55832 .07178 Mdot
.81752 .36115 Mdot
.54787 .5295 Mdot
.59539 .56 Mdot
.71345 .35851 Mdot
.61802 .57724 Mdot
.46068 .08595 Mdot
.50364 .1173 Mdot
.59069 .08407 Mdot
.48317 .12647 Mdot
.45366 .12158 Mdot
.37902 .01686 Mdot
.46924 .08323 Mdot
.49802 .0995 Mdot
.37681 .12692 Mdot
.44143 .12202 Mdot
.89057 .16243 Mdot
.32924 .1993 Mdot
.42414 .12328 Mdot
.52068 .05837 Mdot
.51203 .11082 Mdot
.67196 .42162 Mdot
.44974 .03204 Mdot
.37151 .13185 Mdot
.80597 .12879 Mdot
.53158 .06292 Mdot
.46228 .0806 Mdot
.68349 .38248 Mdot
.32645 .23193 Mdot
.48549 .10753 Mdot
.39727 .04364 Mdot
.3862 .02752 Mdot
.67108 .44187 Mdot
.25395 .26822 Mdot
.1916 .26154 Mdot
.60546 .08921 Mdot
.64417 .4972 Mdot
.67156 .46637 Mdot
.98234 .40962 Mdot
.40333 .03499 Mdot
.53725 .06347 Mdot
.57184 .54297 Mdot
.54811 .51156 Mdot
.52776 .51727 Mdot
.44044 .07013 Mdot
.42178 .04942 Mdot
.29814 .26105 Mdot
.44237 .03795 Mdot
.08866 .23351 Mdot
.42801 .04537 Mdot
.6226 .58271 Mdot
.37652 .01695 Mdot
.54179 .51503 Mdot
.55138 .07065 Mdot
.58946 .51124 Mdot
.42301 .04886 Mdot
.68391 .38809 Mdot
.35119 .00749 Mdot
.47503 .09528 Mdot
.55487 .50199 Mdot
.13481 .24743 Mdot
.32942 .19446 Mdot
.04299 .43173 Mdot
.43225 .05513 Mdot
.53125 .5032 Mdot
.50371 .05527 Mdot
.54794 .50269 Mdot
.56564 .54445 Mdot
.5778 .5477 Mdot
.56678 .54628 Mdot
.63347 .49372 Mdot
.42186 .06179 Mdot
.43724 .03048 Mdot
.95595 .18765 Mdot
.30734 .25229 Mdot
.33339 .17006 Mdot
.33402 .20618 Mdot
.45296 .08023 Mdot
.66775 .47198 Mdot
.42595 .03763 Mdot
.54085 .52043 Mdot
.50148 .10299 Mdot
.42429 .06184 Mdot
.41341 .03679 Mdot
.45414 .03357 Mdot
.43356 .12569 Mdot
.62355 .05269 Mdot
.48435 .0475 Mdot
.55671 .53318 Mdot
.55306 .51543 Mdot
.48169 .04359 Mdot
.9369 .18025 Mdot
.40226 .04547 Mdot
.42477 .03446 Mdot
.65177 .60403 Mdot
.64886 .6025 Mdot
.54871 .51777 Mdot
.32928 .19701 Mdot
.42772 .11923 Mdot
.4745 .09216 Mdot
.50598 .10896 Mdot
.44275 .06484 Mdot
.4262 .11892 Mdot
.33835 .17925 Mdot
.51491 .05865 Mdot
.33953 .15265 Mdot
.46077 .0402 Mdot
.45715 .06905 Mdot
.46341 .08645 Mdot
.58934 .50965 Mdot
.57943 .55595 Mdot
.79993 .35781 Mdot
.32297 .23264 Mdot
.4889 .09374 Mdot
.40888 .05016 Mdot
.3342 .54887 Mdot
.61693 .57596 Mdot
.47907 .08738 Mdot
.63759 .49444 Mdot
.56733 .51306 Mdot
.36704 .56206 Mdot
.74942 .14628 Mdot
.66606 .45948 Mdot
.49371 .10441 Mdot
.4668 .04303 Mdot
.56064 .51059 Mdot
.54989 .06824 Mdot
.44544 .03547 Mdot
.40237 .01806 Mdot
.03974 .43109 Mdot
.43726 .03639 Mdot
.52741 .50989 Mdot
.65875 .0677 Mdot
.53805 .50467 Mdot
.57425 .54599 Mdot
.47118 .12599 Mdot
.67644 .41779 Mdot
.10324 .45414 Mdot
.72963 .09748 Mdot
.44887 .12079 Mdot
.98463 .41049 Mdot
.8844 .15952 Mdot
.48682 .12467 Mdot
.59335 .50099 Mdot
.56005 .02631 Mdot
.65869 .48713 Mdot
.66526 .46776 Mdot
.32722 .21464 Mdot
.72811 .13745 Mdot
.57931 .55393 Mdot
.46139 .11802 Mdot
.43264 .12525 Mdot
.10075 .23735 Mdot
.56208 .53507 Mdot
.47365 .09787 Mdot
.44073 .06829 Mdot
.29934 .25836 Mdot
.48563 .09904 Mdot
.55387 .02348 Mdot
.52917 .51499 Mdot
.96901 .19237 Mdot
.62232 .58493 Mdot
.50854 .11204 Mdot
.35481 .13562 Mdot
.53544 .50304 Mdot
.50729 .12299 Mdot
.82831 .36256 Mdot
.40797 .04921 Mdot
.60518 .09108 Mdot
.67246 .45796 Mdot
.33833 .15859 Mdot
.53648 .06274 Mdot
.67488 .4258 Mdot
.45609 .03605 Mdot
.46895 .08092 Mdot
.70213 .36327 Mdot
.32718 .22777 Mdot
.42351 .0452 Mdot
.53995 .06374 Mdot
.42744 .02914 Mdot
.60597 .50564 Mdot
.41691 .03779 Mdot
.35619 .13881 Mdot
.4843 .10258 Mdot
.54824 .5008 Mdot
.40639 .02448 Mdot
.41302 .12038 Mdot
.31622 .24265 Mdot
.67288 .44615 Mdot
.3801 .0288 Mdot
.36195 .5606 Mdot
.55481 .52789 Mdot
.53593 .52018 Mdot
.65034 .06424 Mdot
.49951 .10262 Mdot
.44171 .12239 Mdot
.11908 .24311 Mdot
.42152 .03503 Mdot
.45861 .07806 Mdot
.67836 .4164 Mdot
.52236 .12911 Mdot
.80506 .35881 Mdot
.14544 .25093 Mdot
.98439 .19829 Mdot
.66865 .46719 Mdot
.37038 .01032 Mdot
.51903 .11413 Mdot
.32125 .24292 Mdot
.54493 .50412 Mdot
.44002 .05938 Mdot
.40312 .125 Mdot
.71104 .08899 Mdot
.6247 .09648 Mdot
.6628 .47424 Mdot
.41908 .04513 Mdot
.47107 .04032 Mdot
.26704 .26642 Mdot
.4076 .01838 Mdot
.64477 .60003 Mdot
.50131 .12519 Mdot
.47794 .0457 Mdot
.5533 .07044 Mdot
.67065 .4376 Mdot
.33322 .19592 Mdot
.91431 .38689 Mdot
.54812 .50223 Mdot
.4988 .10549 Mdot
.89258 .38048 Mdot
.55284 .51116 Mdot
.67333 .41844 Mdot
.54775 .52213 Mdot
.41153 .04553 Mdot
.71038 .36038 Mdot
.46548 .04092 Mdot
.41917 .02509 Mdot
.78791 .35487 Mdot
.30556 .25458 Mdot
.88003 .37767 Mdot
.42812 .02741 Mdot
.38774 .02014 Mdot
.54606 .07024 Mdot
.32821 .21204 Mdot
.42428 .05592 Mdot
.41286 .03219 Mdot
.50669 .12769 Mdot
.38511 .03755 Mdot
.43537 .11975 Mdot
.51584 .13011 Mdot
.58541 .55994 Mdot
.30056 .2629 Mdot
.66066 .47587 Mdot
.30923 .25432 Mdot
.00043 .20351 Mdot
.3639 .01572 Mdot
.34297 .14626 Mdot
.5761 .50465 Mdot
.55002 .53208 Mdot
.66933 .45366 Mdot
.01343 .42023 Mdot
.42316 .05564 Mdot
.64706 .48279 Mdot
.30772 .25535 Mdot
.57329 .50662 Mdot
.60769 .50905 Mdot
.46326 .11747 Mdot
.6196 .50421 Mdot
.67806 .43627 Mdot
.38802 .01704 Mdot
.6138 .09212 Mdot
.34776 .14057 Mdot
.47977 .1262 Mdot
.42478 .02752 Mdot
.67779 .416 Mdot
.87492 .37472 Mdot
.59908 .56666 Mdot
.88164 .37667 Mdot
.67062 .43788 Mdot
.74798 .35237 Mdot
.56959 .50197 Mdot
.4269 .12582 Mdot
.6714 .44629 Mdot
.46919 .04395 Mdot
.4177 .0455 Mdot
.37272 .01401 Mdot
.00593 .20487 Mdot
.14489 .24926 Mdot
.44227 .12549 Mdot
.60567 .57384 Mdot
.64678 .49272 Mdot
.4041 .03547 Mdot
.42153 .02619 Mdot
.89047 .16232 Mdot
.37307 .12652 Mdot
.51573 .12644 Mdot
.39764 .01906 Mdot
.50137 .12196 Mdot
.35111 .55552 Mdot
.53684 .51655 Mdot
.4412 .03087 Mdot
.60281 .56611 Mdot
.44046 .03558 Mdot
.84662 .36823 Mdot
.37033 .01738 Mdot
.70773 .13098 Mdot
.60129 .49955 Mdot
.75421 .35194 Mdot
.20353 .2635 Mdot
.4063 .03447 Mdot
.6353 .58941 Mdot
.48198 .12191 Mdot
.58671 .50711 Mdot
.33187 .17377 Mdot
.00765 .20649 Mdot
.92135 .38903 Mdot
.19517 .2617 Mdot
.01724 .20927 Mdot
.54921 .50808 Mdot
.60444 .57088 Mdot
.41269 .03341 Mdot
.74332 .35269 Mdot
.42413 .05336 Mdot
.40247 .1195 Mdot
.44421 .06059 Mdot
.63202 .59107 Mdot
.66428 .46233 Mdot
.44351 .06462 Mdot
.46318 .03817 Mdot
.65545 .48064 Mdot
.46404 .08738 Mdot
.53573 .50722 Mdot
.57861 .54972 Mdot
.5145 .05772 Mdot
.79812 .12554 Mdot
.68434 .38937 Mdot
.43738 .05755 Mdot
.65645 .48564 Mdot
.02964 .21412 Mdot
.8762 .37491 Mdot
.93644 .39353 Mdot
.6777 .41464 Mdot
.4363 .05586 Mdot
.57672 .54831 Mdot
.50245 .12156 Mdot
.64982 .48826 Mdot
.78798 .12131 Mdot
.55746 .51844 Mdot
.43931 .05895 Mdot
.41453 .05704 Mdot
.66261 .466 Mdot
.45139 .12689 Mdot
.40005 .04656 Mdot
.62434 .49745 Mdot
.55453 .50295 Mdot
.906 .38522 Mdot
.5127 .11818 Mdot
.59866 .56296 Mdot
.08157 .23193 Mdot
.5578 .52982 Mdot
.34393 .14648 Mdot
.61091 .50336 Mdot
.24083 .26938 Mdot
.44567 .06787 Mdot
.37714 .132 Mdot
.16985 .25574 Mdot
.68151 .39643 Mdot
.67337 .43116 Mdot
.32621 .21161 Mdot
.02572 .21315 Mdot
.64654 .48386 Mdot
.66492 .46655 Mdot
.42435 .03637 Mdot
.65668 .48627 Mdot
.41375 .1262 Mdot
.93729 .39398 Mdot
.65345 .60712 Mdot
.66011 .11178 Mdot
.40924 .0476 Mdot
.4999 .10804 Mdot
.58942 .50301 Mdot
.07266 .22842 Mdot
.37702 .02493 Mdot
.53857 .52497 Mdot
.54909 .50603 Mdot
.58757 .55584 Mdot
.45861 .08013 Mdot
.37617 .12555 Mdot
.47272 .09105 Mdot
.49253 .11692 Mdot
.70631 .13015 Mdot
.56135 .51242 Mdot
.42096 .04971 Mdot
.41629 .11949 Mdot
.38308 .02595 Mdot
.52721 .1233 Mdot
.41609 .11836 Mdot
.36061 .13719 Mdot
.52037 .05737 Mdot
.38407 .02052 Mdot
.59694 .50234 Mdot
.52746 .51174 Mdot
.67221 .43869 Mdot
.55427 .50737 Mdot
.49867 .12674 Mdot
.20153 .26234 Mdot
.49442 .11083 Mdot
.38732 .01314 Mdot
.62137 .57901 Mdot
.37915 .12948 Mdot
.55488 .51197 Mdot
.39699 .12193 Mdot
.38529 .03091 Mdot
.00514 .41729 Mdot
.49396 .0951 Mdot
.29268 .53132 Mdot
.61492 .57511 Mdot
.39252 .03539 Mdot
.30925 .25793 Mdot
.41524 .057 Mdot
.43331 .59042 Mdot
.31549 .54054 Mdot
.53543 .50193 Mdot
.47783 .10022 Mdot
.32466 .23614 Mdot
.643 .48581 Mdot
.44555 .03559 Mdot
.58835 .55641 Mdot
.39714 .03416 Mdot
.52446 .51633 Mdot
.33713 .17108 Mdot
.32646 .23608 Mdot
.70369 .36543 Mdot
.49135 .04703 Mdot
.60279 .0895 Mdot
.6116 .50242 Mdot
.17753 .25712 Mdot
.38999 .02617 Mdot
.49226 .10744 Mdot
.4591 .0848 Mdot
.57144 .0776 Mdot
.33514 .16448 Mdot
.56754 .02886 Mdot
.60775 .49924 Mdot
.67119 .44525 Mdot
.18712 .48792 Mdot
.41285 .58161 Mdot
.53961 .52923 Mdot
.39 .03152 Mdot
.30377 .53581 Mdot
.5678 .5478 Mdot
.35411 .13931 Mdot
.57486 .50325 Mdot
.37291 .01163 Mdot
.48162 .10915 Mdot
.43205 .11876 Mdot
.41076 .12404 Mdot
.56664 .02879 Mdot
.53459 .52224 Mdot
.64495 .49154 Mdot
.90257 .16708 Mdot
.44918 .07969 Mdot
.67754 .41568 Mdot
.01232 .42061 Mdot
.43221 .02498 Mdot
.82314 .36209 Mdot
.6243 .49791 Mdot
.47532 .12062 Mdot
.42321 .05024 Mdot
.63811 .05906 Mdot
.46088 .1238 Mdot
.5408 .52785 Mdot
.03161 .42788 Mdot
.64287 .48697 Mdot
.62397 .58272 Mdot
.57354 .54519 Mdot
.57855 .51031 Mdot
.42519 .11837 Mdot
.39056 .03152 Mdot
.56881 .51256 Mdot
.62847 .50082 Mdot
.46569 .11873 Mdot
.31635 .243 Mdot
.50296 .10106 Mdot
.68306 .3836 Mdot
.40082 .5769 Mdot
.62262 .49634 Mdot
.65549 .48153 Mdot
.65032 .48544 Mdot
.34052 .15698 Mdot
.39452 .12823 Mdot
.38289 .12732 Mdot
.66788 .45464 Mdot
.39362 .0333 Mdot
.48448 .11224 Mdot
.6754 .42099 Mdot
.35064 .14759 Mdot
.56431 .53605 Mdot
.64033 .49425 Mdot
.46698 .09062 Mdot
.36305 .01396 Mdot
.9896 .41264 Mdot
.31041 .25086 Mdot
.4877 .10781 Mdot
.50513 .00312 Mdot
.54533 .06729 Mdot
.48524 .1288 Mdot
.48351 .12022 Mdot
.62567 .58397 Mdot
.46606 .08004 Mdot
.41759 .02569 Mdot
.41578 .02491 Mdot
.40083 .01818 Mdot
.48097 .08838 Mdot
.91877 .38799 Mdot
.44174 .03209 Mdot
.53109 .50768 Mdot
.67761 .11818 Mdot
.49449 .1115 Mdot
.91149 .38639 Mdot
.43189 .11902 Mdot
.459 .07178 Mdot
.39505 .03015 Mdot
.45972 .08172 Mdot
.39562 .04241 Mdot
.57587 .50638 Mdot
.48977 .12965 Mdot
.4496 .59752 Mdot
.38644 .57069 Mdot
.2684 .26999 Mdot
.44078 .12188 Mdot
.60141 .56458 Mdot
.3725 .01444 Mdot
.7313 .09777 Mdot
.64562 .49375 Mdot
.37526 .12534 Mdot
.70327 .36349 Mdot
.38697 .12671 Mdot
.40146 .02995 Mdot
.90911 .38582 Mdot
.51177 .12997 Mdot
.57707 .07854 Mdot
.40799 .02105 Mdot
.39186 .01496 Mdot
.36811 .00733 Mdot
.51465 .11264 Mdot
.38516 .0191 Mdot
.55473 .07082 Mdot
.4714 .08169 Mdot
.95764 .40071 Mdot
.40916 .05089 Mdot
.58015 .50482 Mdot
.71088 .35758 Mdot
.68471 .38665 Mdot
.36232 .13803 Mdot
.66252 .47053 Mdot
.33184 .20219 Mdot
.48313 .09587 Mdot
.33018 .19122 Mdot
.407 .03154 Mdot
.38878 .01471 Mdot
.56412 .02773 Mdot
.56946 .54733 Mdot
.52697 .51063 Mdot
.43585 .03616 Mdot
.44796 .03093 Mdot
.65053 .48163 Mdot
.47457 .11782 Mdot
.39705 .02139 Mdot
.55211 .52278 Mdot
.67573 .41172 Mdot
.64953 .06407 Mdot
.33915 .17732 Mdot
.37495 .01446 Mdot
.2387 .50922 Mdot
.48777 .11026 Mdot
.51841 .12916 Mdot
.40461 .03171 Mdot
.70471 .36393 Mdot
.54844 .51691 Mdot
.68507 .37848 Mdot
.62572 .50488 Mdot
.62251 .50496 Mdot
.48356 .10844 Mdot
.42161 .04112 Mdot
.46372 .04029 Mdot
.96611 .40353 Mdot
.58016 .50719 Mdot
.36344 .01509 Mdot
.31734 .25025 Mdot
.46279 .0828 Mdot
.67194 .43869 Mdot
.77263 .35305 Mdot
.66492 .46557 Mdot
.70706 .35894 Mdot
.27308 .26676 Mdot
.48927 .12018 Mdot
.50286 .11237 Mdot
.58028 .50254 Mdot
.52146 .11856 Mdot
.6019 .49905 Mdot
.52254 .51451 Mdot
.49681 .12606 Mdot
.50762 .05357 Mdot
.61384 .50196 Mdot
.48894 .12099 Mdot
.41936 .05577 Mdot
.54047 .52885 Mdot
.70531 .365 Mdot
.36635 .13326 Mdot
.53185 .0625 Mdot
.53464 .06229 Mdot
.5038 .10788 Mdot
.40533 .03709 Mdot
.63044 .58988 Mdot
.56394 .07627 Mdot
.4122 .02318 Mdot
.66839 .46386 Mdot
.56791 .54502 Mdot
.55579 .53033 Mdot
.3741 .0125 Mdot
.52432 .11984 Mdot
.55962 .53288 Mdot
.35266 .13974 Mdot
.3473 .15404 Mdot
.40848 .02753 Mdot
.28739 .26661 Mdot
.58409 .08132 Mdot
.05314 .22158 Mdot
.47901 .10013 Mdot
.67403 .4082 Mdot
.42164 .051 Mdot
.35597 .14248 Mdot
.67787 .41298 Mdot
.15711 .47552 Mdot
.47354 .12156 Mdot
.60315 .56618 Mdot
.41557 .02651 Mdot
.49356 .10303 Mdot
.59068 .08564 Mdot
.55699 .5035 Mdot
.64846 .49221 Mdot
.42025 .05795 Mdot
.71056 .35704 Mdot
.58283 .03549 Mdot
.62188 .50004 Mdot
.36913 .0093 Mdot
.29287 .26149 Mdot
.65861 .11068 Mdot
.47362 .08811 Mdot
.67365 .42774 Mdot
.40068 .02626 Mdot
.59972 .56808 Mdot
.42047 .04276 Mdot
.58645 .0375 Mdot
.69589 .08331 Mdot
.39173 .02079 Mdot
.53397 .51898 Mdot
.37252 .01969 Mdot
.33006 .18555 Mdot
.4063 .01919 Mdot
.42807 .0266 Mdot
.37703 .12423 Mdot
.67269 .46065 Mdot
.49236 .09395 Mdot
.70257 .35986 Mdot
.63998 .488 Mdot
.5466 .52811 Mdot
.33164 .20043 Mdot
.35679 .0131 Mdot
.34418 .14859 Mdot
.66262 .46344 Mdot
.46394 .07611 Mdot
.28741 .26511 Mdot
.63205 .09964 Mdot
.50416 .00235 Mdot
.33823 .17527 Mdot
.45806 .03601 Mdot
.61116 .50576 Mdot
.40732 .04789 Mdot
.38528 .12378 Mdot
.38961 .03748 Mdot
.64191 .49895 Mdot
.20322 .26228 Mdot
.79819 .35659 Mdot
.56669 .50894 Mdot
.86756 .1529 Mdot
.47675 .11481 Mdot
.55822 .53291 Mdot
.38676 .02788 Mdot
.57324 .07707 Mdot
.64373 .59652 Mdot
.22221 .50211 Mdot
.70461 .36555 Mdot
.86081 .3715 Mdot
.47773 .08579 Mdot
.38328 .01662 Mdot
.31736 .24219 Mdot
.23557 .50714 Mdot
.46164 .08514 Mdot
.30836 .25552 Mdot
.5987 .0874 Mdot
.44676 .12554 Mdot
.4983 .04976 Mdot
.53702 .51302 Mdot
.40303 .02821 Mdot
.47069 .0438 Mdot
.68979 .37892 Mdot
.4067 .02077 Mdot
.49934 .10604 Mdot
.19222 .26085 Mdot
.38045 .02139 Mdot
.5749 .51233 Mdot
.46733 .03903 Mdot
.09331 .23414 Mdot
.74642 .14475 Mdot
.32555 .2322 Mdot
.56962 .50367 Mdot
.49511 .0989 Mdot
.56986 .54244 Mdot
.4946 .11089 Mdot
.33605 .18666 Mdot
.62762 .05487 Mdot
.35002 .14433 Mdot
.53669 .50194 Mdot
.49293 .09586 Mdot
.43984 .11792 Mdot
.47772 .0845 Mdot
.67737 .40375 Mdot
.28076 .26713 Mdot
.47455 .08757 Mdot
.70732 .35849 Mdot
.3863 .01227 Mdot
.40349 .01632 Mdot
.47964 .09525 Mdot
.44523 .12555 Mdot
.22507 .26599 Mdot
.62903 .10078 Mdot
.45478 .07923 Mdot
.56908 .50108 Mdot
.49276 .12927 Mdot
.38362 .01951 Mdot
.41676 .05374 Mdot
.26106 .26762 Mdot
.45227 .08216 Mdot
.52474 .12706 Mdot
.60264 .50529 Mdot
.62971 .58836 Mdot
.46881 .12142 Mdot
.52806 .51702 Mdot
.41287 .05573 Mdot
.38721 .03859 Mdot
.7298 .35261 Mdot
.55122 .5218 Mdot
.5078 .10771 Mdot
.33607 .16876 Mdot
.41658 .03282 Mdot
.58451 .55282 Mdot
.39836 .1211 Mdot
.40417 .01726 Mdot
.69581 .12452 Mdot
.43728 .06817 Mdot
.67017 .46604 Mdot
.37362 .02448 Mdot
.41493 .04372 Mdot
.41376 .02482 Mdot
.68026 .40819 Mdot
.67702 .39928 Mdot
.68505 .37549 Mdot
.00364 .20505 Mdot
.42866 .03374 Mdot
.05258 .43519 Mdot
.48426 .04957 Mdot
.32597 .21893 Mdot
.40892 .11987 Mdot
.42935 .04674 Mdot
.4084 .02073 Mdot
.41012 .04722 Mdot
.40246 .03597 Mdot
.64024 .05947 Mdot
.92483 .17546 Mdot
.54776 .50739 Mdot
.50529 .1088 Mdot
.49707 .05323 Mdot
.44195 .03355 Mdot
.89445 .38147 Mdot
.66297 .47394 Mdot
.51382 .11483 Mdot
.59163 .50053 Mdot
.41781 .05298 Mdot
.34387 .15326 Mdot
.67324 .42202 Mdot
.68265 .39944 Mdot
.70029 .36711 Mdot
.29703 .26013 Mdot
.33918 .1723 Mdot
.49097 .10089 Mdot
.54019 .52857 Mdot
.51051 .13096 Mdot
.3568 .13609 Mdot
.82247 .36304 Mdot
.47002 .04438 Mdot
.49277 .10654 Mdot
.36097 .13818 Mdot
.40914 .1222 Mdot
.8323 .13949 Mdot
.60307 .56896 Mdot
.40627 .05066 Mdot
.25222 .26903 Mdot
.4383 .03853 Mdot
.49744 .05002 Mdot
.65519 .48604 Mdot
.41692 .04138 Mdot
.26935 .26913 Mdot
.5854 .5532 Mdot
.38671 .03783 Mdot
.83125 .36317 Mdot
.37413 .12587 Mdot
.33392 .19924 Mdot
.48402 .11034 Mdot
.37028 .00738 Mdot
.63202 .59027 Mdot
.54411 .51353 Mdot
.38072 .01595 Mdot
.24376 .26875 Mdot
.45399 .12368 Mdot
.74239 .35207 Mdot
.50166 .11086 Mdot
.36634 .01521 Mdot
.59219 .55879 Mdot
.34572 .1484 Mdot
.65581 .47899 Mdot
.32105 .23495 Mdot
.56867 .5031 Mdot
.35272 .14486 Mdot
.15336 .2528 Mdot
.61757 .58139 Mdot
.46164 .08388 Mdot
.41708 .04296 Mdot
.6431 .4955 Mdot
.39762 .03281 Mdot
.54376 .52303 Mdot
.59015 .50134 Mdot
.446 .07654 Mdot
.42979 .03718 Mdot
.48573 .09109 Mdot
.63725 .49196 Mdot
.25822 .2702 Mdot
.53789 .50574 Mdot
.48237 .12641 Mdot
.32123 .23878 Mdot
.41421 .12594 Mdot
.42516 .04606 Mdot
.35458 .55708 Mdot
.3373 .1759 Mdot
.34475 .1507 Mdot
.41803 .04424 Mdot
.45348 .03467 Mdot
.32009 .24163 Mdot
.50875 .11667 Mdot
.65514 .4792 Mdot
.66134 .4831 Mdot
.44413 .03583 Mdot
.43091 .0488 Mdot
.67888 .42186 Mdot
.75728 .35284 Mdot
.48062 .11858 Mdot
.47939 .10545 Mdot
.4396 .02763 Mdot
.38344 .01945 Mdot
.52375 .12315 Mdot
.22406 .50323 Mdot
.77862 .35508 Mdot
.73968 .35487 Mdot
.4124 .12519 Mdot
.52569 .12609 Mdot
.31045 .2567 Mdot
.65645 .48138 Mdot
.48449 .09238 Mdot
.15652 .25288 Mdot
.47611 .12134 Mdot
.22663 .26547 Mdot
.54037 .51133 Mdot
.66382 .46549 Mdot
.48157 .04608 Mdot
.53571 .51602 Mdot
.37085 .13519 Mdot
.44653 .1215 Mdot
.6248 .58554 Mdot
.35088 .14946 Mdot
.71646 .09148 Mdot
.43085 .02489 Mdot
.48166 .10979 Mdot
.93812 .18026 Mdot
.4882 .09715 Mdot
.5444 .53141 Mdot
.45033 .03763 Mdot
.56407 .5131 Mdot
.35374 .14598 Mdot
.89097 .16217 Mdot
.27685 .26848 Mdot
.56854 .54057 Mdot
.41968 .02359 Mdot
.63346 .59033 Mdot
.57865 .50534 Mdot
.50675 .10826 Mdot
.49158 .12866 Mdot
.34309 .15816 Mdot
.41556 .11823 Mdot
.39726 .12741 Mdot
.63026 .49373 Mdot
.5754 .54512 Mdot
.38557 .01447 Mdot
.34885 .00913 Mdot
.57632 .51237 Mdot
.68153 .11978 Mdot
.38272 .02315 Mdot
.67486 .40684 Mdot
.69343 .08212 Mdot
.39738 .01863 Mdot
.49327 .10244 Mdot
.33666 .17174 Mdot
.2832 .52713 Mdot
.19781 .49169 Mdot
.90699 .38408 Mdot
.52592 .12956 Mdot
.24899 .51277 Mdot
.22835 .26574 Mdot
.51484 .11687 Mdot
.87657 .37668 Mdot
.56383 .50279 Mdot
.70756 .36062 Mdot
.4957 .12619 Mdot
.51404 .05926 Mdot
.5445 .50516 Mdot
.30974 .25785 Mdot
.48629 .10454 Mdot
.55802 .07455 Mdot
.61015 .49792 Mdot
.97599 .19512 Mdot
.48939 .10548 Mdot
.67606 .44629 Mdot
.80948 .12941 Mdot
.38768 .02992 Mdot
.41184 .02107 Mdot
.56744 .54195 Mdot
.48368 .10365 Mdot
.45995 .08065 Mdot
.60627 .50881 Mdot
.3943 .01775 Mdot
.41943 .03675 Mdot
.50587 .11998 Mdot
.53994 .06343 Mdot
.40891 .12374 Mdot
.34315 .15441 Mdot
.47705 .11967 Mdot
.30558 .25361 Mdot
.46544 .07784 Mdot
.4906 .05026 Mdot
.3868 .0168 Mdot
.49948 .05377 Mdot
.76131 .15072 Mdot
.60453 .57229 Mdot
.37007 .56351 Mdot
.54131 .5155 Mdot
.50856 .05566 Mdot
.48252 .08726 Mdot
.65837 .48147 Mdot
.59274 .51016 Mdot
.51216 .1279 Mdot
.52314 .51493 Mdot
.48307 .12262 Mdot
.70499 .35894 Mdot
.49404 .12204 Mdot
.61417 .49693 Mdot
.01836 .21055 Mdot
.67573 .42614 Mdot
.88709 .37824 Mdot
.5034 .1091 Mdot
.67764 .40789 Mdot
.50261 .10583 Mdot
.42158 .04884 Mdot
.33106 .21223 Mdot
.55216 .53288 Mdot
.55534 .52599 Mdot
.43495 .12532 Mdot
.44777 .06921 Mdot
.79637 .35821 Mdot
.37011 .56312 Mdot
.41101 .02981 Mdot
.38262 .0239 Mdot
.31835 .24056 Mdot
.73744 .35402 Mdot
.39137 .02773 Mdot
.54752 .07043 Mdot
.48993 .10984 Mdot
.40619 .04629 Mdot
.66935 .45277 Mdot
.62793 .50073 Mdot
.54291 .519 Mdot
.4968 .10253 Mdot
.4818 .611 Mdot
.44801 .075 Mdot
.41443 .04835 Mdot
.43974 .12323 Mdot
.73107 .13964 Mdot
.43666 .06111 Mdot
.78472 .35621 Mdot
.37536 .01833 Mdot
.41967 .02257 Mdot
.40165 .03321 Mdot
.62292 .09838 Mdot
.70077 .36821 Mdot
.34215 .15154 Mdot
.16897 .25635 Mdot
.42705 .03118 Mdot
.44419 .0751 Mdot
.47851 .04509 Mdot
.5469 .50951 Mdot
.33305 .16824 Mdot
.54048 .50297 Mdot
.4769 .08954 Mdot
.3111 .25271 Mdot
.39793 .02716 Mdot
.92003 .38893 Mdot
.63992 .49178 Mdot
.63277 .10055 Mdot
.31989 .24311 Mdot
.65093 .49001 Mdot
.5134 .11321 Mdot
.62206 .57961 Mdot
.61637 .09413 Mdot
.46448 .08859 Mdot
.64146 .48944 Mdot
.75389 .10728 Mdot
.34256 .15797 Mdot
.63648 .59243 Mdot
.60592 .50069 Mdot
.56234 .54071 Mdot
.40702 .02721 Mdot
.47252 .03994 Mdot
.02391 .42511 Mdot
.3736 .01217 Mdot
.57499 .50082 Mdot
.53548 .52321 Mdot
.56533 .51413 Mdot
.39252 .03027 Mdot
.32049 .23602 Mdot
.42224 .05584 Mdot
.2423 .26937 Mdot
.46173 .1187 Mdot
.27738 .26605 Mdot
.42004 .05095 Mdot
.67548 .4163 Mdot
.42085 .05668 Mdot
.42136 .02134 Mdot
.41345 .11951 Mdot
.49757 .0479 Mdot
.41991 .02741 Mdot
.03464 .21535 Mdot
.58122 .55357 Mdot
.54889 .50745 Mdot
.68202 .3826 Mdot
.38329 .12341 Mdot
.50904 .11897 Mdot
.25026 .26929 Mdot
.41406 .05177 Mdot
.10807 .4564 Mdot
.53198 .51922 Mdot
.33402 .20052 Mdot
.87753 .37611 Mdot
.4445 .03133 Mdot
.61857 .49813 Mdot
.46617 .08996 Mdot
.38977 .03937 Mdot
.74951 .35463 Mdot
.69454 .36927 Mdot
.44183 .07158 Mdot
.7621 .11019 Mdot
.36977 .13423 Mdot
.61467 .49688 Mdot
.65362 .49123 Mdot
.50423 .05006 Mdot
.54594 .50796 Mdot
.47208 .09142 Mdot
.71002 .35794 Mdot
.39416 .04034 Mdot
.56007 .50413 Mdot
.51384 .12077 Mdot
.69296 .36667 Mdot
.56149 .50732 Mdot
.37307 .01052 Mdot
.39246 .03186 Mdot
.37343 .01752 Mdot
.51619 .0593 Mdot
.44413 .03757 Mdot
.5619 .51041 Mdot
.31867 .24558 Mdot
.64841 .48794 Mdot
.62693 .49706 Mdot
.48945 .09518 Mdot
.40323 .0446 Mdot
.27216 .26686 Mdot
.41701 .05823 Mdot
.42993 .05282 Mdot
.59266 .08438 Mdot
.55274 .07155 Mdot
.78215 .35604 Mdot
.44018 .07039 Mdot
.45396 .08042 Mdot
.51163 .11286 Mdot
.51556 .11515 Mdot
.35474 .01557 Mdot
.42611 .05583 Mdot
.38639 .12791 Mdot
.39618 .02016 Mdot
.47246 .04512 Mdot
.53624 .06428 Mdot
.37446 .02978 Mdot
.42242 .03801 Mdot
.6687 .46901 Mdot
.53285 .06302 Mdot
.11665 .2412 Mdot
.32329 .24192 Mdot
.29089 .2615 Mdot
.43274 .12133 Mdot
.54575 .52759 Mdot
.42074 .03646 Mdot
.70522 .36085 Mdot
.44959 .07803 Mdot
.27034 .52176 Mdot
.55625 .53759 Mdot
.69877 .36598 Mdot
.63321 .49612 Mdot
.44624 .07012 Mdot
.39813 .02217 Mdot
.58765 .50465 Mdot
.59199 .501 Mdot
.60424 .57032 Mdot
.32919 .20244 Mdot
.40945 .03282 Mdot
.48458 .11428 Mdot
.16106 .47732 Mdot
.45362 .06853 Mdot
.66577 .47629 Mdot
.20018 .26239 Mdot
.11366 .45855 Mdot
.49734 .09892 Mdot
.01378 .42152 Mdot
.92071 .17408 Mdot
.67246 .4571 Mdot
.40638 .04274 Mdot
.67523 .40079 Mdot
.57185 .54532 Mdot
.55287 .52452 Mdot
.09944 .23679 Mdot
.54309 .06643 Mdot
.35441 .01133 Mdot
.35569 .13756 Mdot
.75163 .35186 Mdot
.04171 .43111 Mdot
.55317 .5296 Mdot
.67814 .41053 Mdot
.06391 .22618 Mdot
.40195 .02522 Mdot
.67917 .40309 Mdot
.4764 .1018 Mdot
.44882 .07809 Mdot
.37939 .02699 Mdot
.43461 .06985 Mdot
.25804 .27 Mdot
.44352 .12537 Mdot
.45849 .03488 Mdot
.8143 .13165 Mdot
.42486 .03379 Mdot
.55205 .50637 Mdot
.36823 .01352 Mdot
.57092 .07696 Mdot
.53587 .52026 Mdot
.61046 .50436 Mdot
.9198 .17402 Mdot
.78943 .35647 Mdot
.36056 .01897 Mdot
.43012 .03233 Mdot
.50119 .04925 Mdot
.36569 .56164 Mdot
.72706 .3554 Mdot
.5224 .50542 Mdot
.72989 .35382 Mdot
.66942 .44944 Mdot
.52844 .50884 Mdot
.6635 .47392 Mdot
.3663 .01653 Mdot
.68589 .12232 Mdot
.36142 .00836 Mdot
.54763 .53196 Mdot
.54457 .0655 Mdot
.40994 .03415 Mdot
.44648 .03882 Mdot
.47545 .12636 Mdot
.30375 .25842 Mdot
.66488 .46859 Mdot
.66322 .46903 Mdot
.60689 .50764 Mdot
.67117 .43423 Mdot
.67803 .42898 Mdot
.34447 .16122 Mdot
.5558 .52248 Mdot
.1829 .48601 Mdot
.79948 .12626 Mdot
.48818 .12211 Mdot
.4874 .10596 Mdot
.80531 .35968 Mdot
.46998 .12621 Mdot
.44853 .03224 Mdot
.46431 .12697 Mdot
.43885 .12141 Mdot
.33519 .19772 Mdot
.65775 .47863 Mdot
.7003 .36277 Mdot
.42853 .06526 Mdot
.55144 .53209 Mdot
.68309 .39033 Mdot
.67081 .43423 Mdot
.56474 .51394 Mdot
.38799 .03215 Mdot
.56758 .54426 Mdot
.48057 .61023 Mdot
.47882 .12818 Mdot
.56696 .54001 Mdot
.67373 .43516 Mdot
.47795 .11967 Mdot
.62986 .05531 Mdot
.48601 .09044 Mdot
.67945 .40636 Mdot
.05454 .4364 Mdot
.76169 .35457 Mdot
.95343 .18621 Mdot
.58704 .50701 Mdot
.64617 .60243 Mdot
.48843 .09482 Mdot
.57559 .54489 Mdot
.92646 .39059 Mdot
.68652 .377 Mdot
.69538 .12462 Mdot
.4684 .08639 Mdot
.45788 .08351 Mdot
.3498 .14653 Mdot
.39783 .12171 Mdot
.59472 .56462 Mdot
.4023 .1243 Mdot
.62117 .58214 Mdot
.57121 .07804 Mdot
.54742 .51867 Mdot
.37657 .1293 Mdot
.48599 .10372 Mdot
.46834 .12564 Mdot
.56866 .51324 Mdot
.43554 .06209 Mdot
.3178 .24157 Mdot
.53864 .52115 Mdot
.17016 .48063 Mdot
.5119 .11611 Mdot
.6757 .39792 Mdot
.41648 .03961 Mdot
.98746 .41144 Mdot
.56122 .50356 Mdot
.36227 .13144 Mdot
.4793 .0918 Mdot
.4242 .12111 Mdot
.36215 .02163 Mdot
.60412 .57043 Mdot
.43212 .03099 Mdot
.33148 .17615 Mdot
.52262 .50403 Mdot
.52134 .50643 Mdot
.2764 .26587 Mdot
.42683 .02772 Mdot
.28587 .26745 Mdot
.6745 .4249 Mdot
.48525 .12205 Mdot
.39153 .12077 Mdot
.49642 .11037 Mdot
.47682 .08412 Mdot
.43341 .03074 Mdot
.69572 .12462 Mdot
.50803 .11261 Mdot
.42703 .03317 Mdot
.5435 .51348 Mdot
.37412 .02336 Mdot
.40567 .0401 Mdot
.47776 .08586 Mdot
.54129 .5271 Mdot
.60639 .09025 Mdot
.37873 .13062 Mdot
.31461 .25298 Mdot
.33347 .17075 Mdot
.66159 .46508 Mdot
.45692 .03372 Mdot
.33767 .15898 Mdot
.653 .10985 Mdot
.4224 .03846 Mdot
.54218 .51019 Mdot
.60068 .56892 Mdot
.38003 .01012 Mdot
.53396 .51379 Mdot
.36692 .13171 Mdot
.41022 .04712 Mdot
.38164 .01286 Mdot
.10416 .23807 Mdot
.65977 .11077 Mdot
.3981 .04258 Mdot
.64559 .49548 Mdot
.53351 .51029 Mdot
.43264 .02635 Mdot
.59144 .56143 Mdot
.3686 .00896 Mdot
.65182 .10839 Mdot
.34831 .1511 Mdot
.57466 .50589 Mdot
.32993 .20814 Mdot
.45951 .11841 Mdot
.40861 .12388 Mdot
.53406 .06481 Mdot
.34871 .15029 Mdot
.4485 .07011 Mdot
.22133 .26548 Mdot
.49006 .12196 Mdot
.95809 .18749 Mdot
.46777 .08434 Mdot
.55853 .53703 Mdot
.25498 .26699 Mdot
.49676 .0988 Mdot
.57785 .08137 Mdot
.57185 .54783 Mdot
.3525 .00559 Mdot
.50386 .11758 Mdot
.72795 .3544 Mdot
.52801 .51284 Mdot
.38339 .1228 Mdot
.39188 .12099 Mdot
.48496 .04446 Mdot
.51316 .1154 Mdot
.06383 .22551 Mdot
.70915 .12975 Mdot
.44003 .12327 Mdot
.4852 .04546 Mdot
.40574 .12327 Mdot
.6195 .49707 Mdot
.53561 .50166 Mdot
.68096 .41049 Mdot
.47578 .08285 Mdot
.43803 .1258 Mdot
.4885 .12133 Mdot
.40126 .04556 Mdot
.25307 .51511 Mdot
.38417 .03049 Mdot
.49097 .11231 Mdot
.50844 .05323 Mdot
.67509 .43887 Mdot
.49907 .10931 Mdot
.50498 .05227 Mdot
.41998 .12227 Mdot
.9215 .17438 Mdot
.57666 .50705 Mdot
.49792 .11423 Mdot
.6713 .44638 Mdot
.27899 .26706 Mdot
.74532 .35152 Mdot
.49329 .10833 Mdot
.31536 .24787 Mdot
.4361 .12352 Mdot
.51656 .05994 Mdot
.4714 .07918 Mdot
.67385 .43549 Mdot
.64436 .48805 Mdot
.67955 .41653 Mdot
.49721 .09849 Mdot
.39794 .02133 Mdot
.55049 .50593 Mdot
.28962 .26395 Mdot
.97799 .40755 Mdot
.59451 .51079 Mdot
.3926 .01595 Mdot
.12421 .46336 Mdot
.8548 .36971 Mdot
.45076 .03215 Mdot
.59672 .56572 Mdot
.39725 .02339 Mdot
.19642 .26128 Mdot
.3526 .0115 Mdot
.28797 .26678 Mdot
.40333 .12438 Mdot
.55801 .07338 Mdot
.42731 .12372 Mdot
.43606 .02825 Mdot
.49633 .61715 Mdot
.33175 .17795 Mdot
.68197 .38397 Mdot
.52624 .12235 Mdot
.40986 .12412 Mdot
.55899 .51411 Mdot
.43783 .12339 Mdot
.42039 .04346 Mdot
.62928 .50413 Mdot
.5525 .07243 Mdot
.32431 .22849 Mdot
.39663 .01963 Mdot
.67548 .42993 Mdot
.67773 .40116 Mdot
.37954 .02106 Mdot
.42837 .05981 Mdot
.23658 .26828 Mdot
.41068 .04128 Mdot
.43286 .06776 Mdot
.59194 .50896 Mdot
.45023 .07921 Mdot
.9187 .389 Mdot
.79611 .12471 Mdot
.76326 .35289 Mdot
.57201 .54886 Mdot
.6519 .49341 Mdot
.84324 .36762 Mdot
.77525 .35462 Mdot
.41632 .05696 Mdot
.52516 .12282 Mdot
.62897 .50433 Mdot
.71023 .08869 Mdot
.8976 .38263 Mdot
.64466 .48825 Mdot
.37812 .03083 Mdot
.6607 .11222 Mdot
.50175 .05434 Mdot
.60565 .09153 Mdot
.3302 .18785 Mdot
.42696 .12082 Mdot
.46592 .11718 Mdot
.54525 .52459 Mdot
.44648 .11773 Mdot
.38617 .12384 Mdot
.10917 .23914 Mdot
.33544 .19606 Mdot
.32805 .19858 Mdot
.78594 .35448 Mdot
.46461 .08947 Mdot
.29486 .26036 Mdot
.26227 .51908 Mdot
.59006 .08406 Mdot
.50892 .1308 Mdot
.38121 .02314 Mdot
.4551 .04061 Mdot
.57281 .50163 Mdot
.15507 .47537 Mdot
.371 .0244 Mdot
.46567 .07838 Mdot
.62819 .05431 Mdot
.4343 .03128 Mdot
.70913 .1312 Mdot
.48941 .09621 Mdot
.37174 .00784 Mdot
.67384 .44953 Mdot
.67319 .45512 Mdot
.33444 .1944 Mdot
.46495 .03964 Mdot
.72829 .35675 Mdot
.48793 .0449 Mdot
.19754 .26142 Mdot
.33059 .20311 Mdot
.50051 .10965 Mdot
.40421 .12306 Mdot
.57019 .51232 Mdot
.33858 .15942 Mdot
.41445 .05626 Mdot
.17249 .25675 Mdot
.04813 .21984 Mdot
.5151 .1268 Mdot
.67856 .39419 Mdot
.34014 .15521 Mdot
.45093 .08068 Mdot
.62536 .50272 Mdot
.6304 .49789 Mdot
.33105 .19276 Mdot
.66691 .47048 Mdot
.35247 .01206 Mdot
.03949 .43059 Mdot
.43882 .12281 Mdot
.39599 .03662 Mdot
.55703 .51701 Mdot
.92717 .17588 Mdot
.29408 .26289 Mdot
.4027 .11994 Mdot
.16458 .2553 Mdot
.35054 .14537 Mdot
.39061 .03298 Mdot
.28402 .26752 Mdot
.38149 .02579 Mdot
.60316 .56875 Mdot
.89534 .16434 Mdot
.94002 .39578 Mdot
.59816 .49948 Mdot
.40908 .04057 Mdot
.39957 .02253 Mdot
.54956 .51082 Mdot
.48755 .12843 Mdot
.46904 .07801 Mdot
.50038 .11131 Mdot
.57514 .50131 Mdot
.45459 .08194 Mdot
.98045 .40963 Mdot
.3124 .24974 Mdot
.35517 .00871 Mdot
.569 .50345 Mdot
.66337 .47138 Mdot
.15722 .25349 Mdot
.68344 .39609 Mdot
.53723 .06585 Mdot
.52307 .11777 Mdot
.61029 .50134 Mdot
.64183 .06083 Mdot
.03492 .42841 Mdot
.65807 .48823 Mdot
.64111 .10514 Mdot
.65066 .49256 Mdot
.44839 .06825 Mdot
.38291 .02281 Mdot
.3278 .23285 Mdot
.45501 .07619 Mdot
.48018 .60974 Mdot
.64699 .48947 Mdot
.05412 .43612 Mdot
.48219 .04399 Mdot
.38739 .0191 Mdot
.43749 .03077 Mdot
.47369 .03936 Mdot
.42022 .02957 Mdot
.83756 .14146 Mdot
.38435 .01334 Mdot
.64796 .10594 Mdot
.94283 .39678 Mdot
.43823 .12404 Mdot
.59257 .55962 Mdot
.65954 .06836 Mdot
.61761 .50377 Mdot
.62664 .05408 Mdot
.5311 .50408 Mdot
.673 .41499 Mdot
.75001 .1054 Mdot
.57491 .5497 Mdot
.19707 .49143 Mdot
.54046 .51469 Mdot
.59222 .5017 Mdot
.51322 .11584 Mdot
.90407 .38456 Mdot
.21904 .26632 Mdot
.56251 .54306 Mdot
.37892 .0098 Mdot
.39402 .04315 Mdot
.36647 .12934 Mdot
.37335 .13128 Mdot
.52109 .11705 Mdot
.55631 .5281 Mdot
.29968 .26053 Mdot
.42539 .05786 Mdot
.47453 .04378 Mdot
.44738 .12275 Mdot
.55177 .02195 Mdot
.19017 .26033 Mdot
.48371 .1274 Mdot
.35163 .14056 Mdot
.4412 .03122 Mdot
.57272 .50859 Mdot
.03697 .21658 Mdot
.62105 .58352 Mdot
.36685 .02101 Mdot
.07354 .44337 Mdot
.55624 .53456 Mdot
.48438 .11591 Mdot
.37121 .12901 Mdot
.22121 .50201 Mdot
.54748 .51673 Mdot
.47767 .09225 Mdot
.76573 .35502 Mdot
.48374 .09041 Mdot
.41876 .05432 Mdot
.51547 .12604 Mdot
.3824 .03157 Mdot
.57981 .50162 Mdot
.45838 .03994 Mdot
.96372 .18948 Mdot
.67326 .43935 Mdot
.63303 .49361 Mdot
.78327 .35642 Mdot
.51813 .1235 Mdot
.60955 .50791 Mdot
.7127 .13253 Mdot
.67902 .40293 Mdot
.81937 .36087 Mdot
.93946 .39498 Mdot
.5597 .54293 Mdot
.42612 .12261 Mdot
.32945 .18907 Mdot
.62171 .49543 Mdot
.25586 .26956 Mdot
.55165 .53561 Mdot
.47883 .10432 Mdot
.55813 .53877 Mdot
.43247 .06833 Mdot
.43502 .03049 Mdot
.42616 .12508 Mdot
.30872 .25274 Mdot
.05597 .22326 Mdot
.58163 .0801 Mdot
.41924 .04551 Mdot
.4752 .08704 Mdot
.34007 .17277 Mdot
.39247 .12481 Mdot
.49617 .09686 Mdot
.75437 .10711 Mdot
.42318 .03548 Mdot
.50057 .1258 Mdot
.56176 .50112 Mdot
.56287 .53893 Mdot
.37105 .01119 Mdot
.58174 .50806 Mdot
.67353 .43787 Mdot
.72876 .35223 Mdot
.40366 .0219 Mdot
.40361 .02121 Mdot
.96277 .40308 Mdot
.63623 .05782 Mdot
.51005 .12458 Mdot
.41932 .02554 Mdot
.18437 .4869 Mdot
.42389 .06039 Mdot
.95207 .39916 Mdot
.43353 .06129 Mdot
.67567 .44615 Mdot
.89643 .3816 Mdot
.65295 .48263 Mdot
.45253 .12707 Mdot
.58821 .08322 Mdot
.62922 .09837 Mdot
.67644 .39772 Mdot
.55992 .54044 Mdot
.5471 .52377 Mdot
.55782 .50074 Mdot
.46399 .11853 Mdot
.38888 .12542 Mdot
.3457 .14574 Mdot
.51968 .50862 Mdot
.29969 .26277 Mdot
.47887 .10422 Mdot
.71336 .35586 Mdot
.42775 .06191 Mdot
.64785 .60432 Mdot
.44286 .11799 Mdot
.47436 .04038 Mdot
.76643 .35214 Mdot
.67351 .43469 Mdot
.41202 .02298 Mdot
.46464 .12006 Mdot
.49085 .10111 Mdot
.72321 .35456 Mdot
.40024 .02057 Mdot
.3674 .0124 Mdot
.57031 .54661 Mdot
.36798 .01723 Mdot
.73694 .35221 Mdot
.54911 .06807 Mdot
.36186 .01228 Mdot
.4922 .11656 Mdot
.55467 .51311 Mdot
.64549 .60094 Mdot
.70061 .36169 Mdot
.43694 .06019 Mdot
.38468 .12756 Mdot
.42715 .05778 Mdot
.86393 .15154 Mdot
.39784 .04201 Mdot
.61341 .57548 Mdot
.41935 .0249 Mdot
.60199 .57122 Mdot
.5654 .50384 Mdot
.57404 .5472 Mdot
.53408 .50725 Mdot
.46425 .12011 Mdot
.33527 .1778 Mdot
.6499 .48845 Mdot
.46847 .11784 Mdot
.47952 .09963 Mdot
.53795 .06582 Mdot
.43639 .03802 Mdot
.39231 .01356 Mdot
.45304 .06649 Mdot
.48072 .1077 Mdot
.49324 .12561 Mdot
.4989 .1021 Mdot
.38544 .01678 Mdot
.5364 .5212 Mdot
.41452 .03619 Mdot
.90954 .38506 Mdot
.54118 .06468 Mdot
.33419 .17477 Mdot
.76694 .35407 Mdot
.24613 .26685 Mdot
.4937 .09973 Mdot
.48145 .10866 Mdot
.61993 .58192 Mdot
.53372 .50786 Mdot
.66437 .47413 Mdot
.64255 .59952 Mdot
.38145 .1302 Mdot
.46881 .07948 Mdot
.81777 .13287 Mdot
.54792 .51166 Mdot
.67093 .4536 Mdot
.37542 .1289 Mdot
.50614 .10623 Mdot
.42881 .05863 Mdot
.49256 .12776 Mdot
.34812 .14298 Mdot
.67345 .41463 Mdot
.32745 .21223 Mdot
.36799 .0136 Mdot
.38477 .01508 Mdot
.12217 .46151 Mdot
.48665 .04836 Mdot
.67693 .41232 Mdot
.67963 .39257 Mdot
.47303 .08532 Mdot
.52019 .11986 Mdot
.68208 .40038 Mdot
.52595 .05891 Mdot
.42442 .03194 Mdot
.9533 .18607 Mdot
.40006 .02275 Mdot
.63298 .05628 Mdot
.92786 .17656 Mdot
.45186 .11992 Mdot
.72916 .35655 Mdot
.32534 .23708 Mdot
.27242 .26703 Mdot
.47317 .09794 Mdot
.95551 .40038 Mdot
.38839 .03007 Mdot
.4885 .12557 Mdot
.6907 .36823 Mdot
.46034 .11797 Mdot
.67457 .11787 Mdot
.17025 .48115 Mdot
.97601 .40787 Mdot
.6515 .48699 Mdot
.59365 .08637 Mdot
.49012 .11724 Mdot
.65825 .48535 Mdot
.29372 .26478 Mdot
.67638 .41161 Mdot
.4556 .08111 Mdot
.38326 .02181 Mdot
.59946 .56718 Mdot
.42804 .02549 Mdot
.4175 .04824 Mdot
.43899 .06134 Mdot
.2749 .26554 Mdot
.44585 .0369 Mdot
.50803 .05512 Mdot
.40291 .11904 Mdot
.52767 .12409 Mdot
.29475 .26311 Mdot
.41295 .03831 Mdot
.32522 .22106 Mdot
.48377 .09353 Mdot
.50418 .10819 Mdot
.37995 .03395 Mdot
.69832 .12703 Mdot
.33869 .17861 Mdot
.54506 .53138 Mdot
.04068 .2172 Mdot
.21763 .49985 Mdot
.36608 .00802 Mdot
.55609 .5306 Mdot
.66953 .45427 Mdot
.28 .26609 Mdot
.50774 .10916 Mdot
.43905 .03223 Mdot
.44184 .06281 Mdot
.53033 .06165 Mdot
.00425 .20524 Mdot
.39858 .03189 Mdot
.40086 .02417 Mdot
.04305 .43169 Mdot
.38256 .02354 Mdot
.25042 .26995 Mdot
.32284 .22571 Mdot
.39964 .02455 Mdot
.63546 .58915 Mdot
.70753 .12972 Mdot
.94097 .39562 Mdot
.6087 .5722 Mdot
.5558 .52265 Mdot
.73991 .3536 Mdot
.52881 .51706 Mdot
.36538 .02013 Mdot
.7 .08502 Mdot
.37317 .12639 Mdot
.42166 .04871 Mdot
.39605 .03007 Mdot
.46697 .08416 Mdot
.41126 .02641 Mdot
.67197 .42101 Mdot
.41229 .04775 Mdot
.96445 .40325 Mdot
.51263 .12845 Mdot
.54212 .50357 Mdot
.51205 .11541 Mdot
.39534 .01882 Mdot
.49129 .04608 Mdot
.67917 .40881 Mdot
.86255 .37288 Mdot
.07738 .22947 Mdot
.78346 .35485 Mdot
.56043 .54011 Mdot
.51198 .11035 Mdot
.42584 .03681 Mdot
.63524 .59333 Mdot
.46357 .12597 Mdot
.0461 .21925 Mdot
.41288 .12108 Mdot
.42482 .1245 Mdot
.30031 .26068 Mdot
.84906 .14607 Mdot
.38749 .01417 Mdot
.43824 .02832 Mdot
.41688 .05725 Mdot
.14089 .24898 Mdot
.5393 .52609 Mdot
.38513 .56996 Mdot
.48773 .12186 Mdot
.37427 .02402 Mdot
.63825 .59488 Mdot
.01003 .20689 Mdot
.49399 .12316 Mdot
.60165 .50565 Mdot
.4361 .11905 Mdot
.53086 .51663 Mdot
.45983 .08692 Mdot
.40468 .03813 Mdot
.42691 .04798 Mdot
.77912 .35352 Mdot
.55714 .53175 Mdot
.51606 .1268 Mdot
.46584 .03626 Mdot
.53672 .5118 Mdot
.35679 .14442 Mdot
.55354 .51856 Mdot
.41638 .04004 Mdot
.39512 .02081 Mdot
.53114 .06272 Mdot
.67225 .46252 Mdot
.035 .42921 Mdot
.43017 .05149 Mdot
.58476 .50383 Mdot
.56119 .54371 Mdot
.84168 .36747 Mdot
.55526 .52188 Mdot
.51233 .05812 Mdot
.34955 .0096 Mdot
.58105 .55585 Mdot
.56158 .5076 Mdot
.59241 .50301 Mdot
.55576 .5279 Mdot
.45616 .03349 Mdot
.13021 .24627 Mdot
.47024 .09378 Mdot
.68365 .38858 Mdot
.34897 .14136 Mdot
.13968 .46943 Mdot
.44405 .07279 Mdot
.2751 .52434 Mdot
.45735 .11886 Mdot
.54022 .513 Mdot
.45149 .12524 Mdot
.64068 .49742 Mdot
.3241 .22905 Mdot
.48404 .11422 Mdot
.49054 .11132 Mdot
.34573 .14902 Mdot
.57652 .55443 Mdot
.84308 .3669 Mdot
.15429 .25288 Mdot
.55075 .51037 Mdot
.49133 .09833 Mdot
.35555 .00663 Mdot
.68511 .38981 Mdot
.37193 .0179 Mdot
.50562 .11281 Mdot
.52955 .51419 Mdot
.3829 .01594 Mdot
.4802 .08864 Mdot
.42742 .05998 Mdot
.67823 .39675 Mdot
.32831 .22036 Mdot
.76347 .35417 Mdot
.48507 .04859 Mdot
.70447 .36317 Mdot
.42803 .04456 Mdot
.77089 .35353 Mdot
.57713 .54837 Mdot
.52796 .50996 Mdot
.57667 .55444 Mdot
.35904 .13587 Mdot
.90637 .1685 Mdot
.54023 .50263 Mdot
.38434 .03487 Mdot
.60934 .57024 Mdot
.57304 .54868 Mdot
.40353 .0302 Mdot
.21038 .49704 Mdot
.92873 .17666 Mdot
.33334 .20299 Mdot
.59697 .50037 Mdot
.23863 .50916 Mdot
.41518 .04322 Mdot
.36705 .02199 Mdot
.37216 .1312 Mdot
.64145 .49942 Mdot
.20861 .26351 Mdot
.59047 .08385 Mdot
.44812 .06981 Mdot
.40114 .12365 Mdot
.64845 .48547 Mdot
.66347 .47573 Mdot
.36262 .0065 Mdot
.59659 .08761 Mdot
.67572 .41636 Mdot
.61783 .09408 Mdot
.42404 .03222 Mdot
.58672 .08276 Mdot
.7848 .35561 Mdot
.3496 .00934 Mdot
.48863 .09143 Mdot
.30649 .25651 Mdot
.58396 .03621 Mdot
.74697 .10461 Mdot
.08123 .44617 Mdot
.35989 .14156 Mdot
.61824 .58038 Mdot
.02079 .42309 Mdot
.66779 .45614 Mdot
.31162 .25138 Mdot
.62259 .09532 Mdot
.32208 .23574 Mdot
.34074 .16573 Mdot
.61367 .50643 Mdot
.58246 .55705 Mdot
.4828 .11197 Mdot
.40311 .03729 Mdot
.67652 .39755 Mdot
.4633 .08176 Mdot
.69109 .12362 Mdot
.23519 .50713 Mdot
.3324 .19351 Mdot
.19146 .26083 Mdot
.35855 .00696 Mdot
.55474 .52245 Mdot
.37022 .01226 Mdot
.44965 .03363 Mdot
.53196 .50739 Mdot
.56978 .55028 Mdot
.45342 .0812 Mdot
.25254 .26863 Mdot
.39598 .04152 Mdot
.41102 .0182 Mdot
.25994 .26915 Mdot
.51448 .11317 Mdot
.12337 .244 Mdot
.32563 .21949 Mdot
.03666 .21598 Mdot
.49764 .10542 Mdot
.59034 .50036 Mdot
.38099 .12774 Mdot
.50413 .13062 Mdot
.60228 .5711 Mdot
.49398 .09857 Mdot
.6099 .50498 Mdot
.53702 .50245 Mdot
.5197 .12674 Mdot
.39309 .02315 Mdot
.56925 .07528 Mdot
.83676 .36493 Mdot
.65825 .47274 Mdot
.56965 .54745 Mdot
.39487 .02883 Mdot
.3952 .12183 Mdot
.45752 .07708 Mdot
.58837 .55491 Mdot
.48819 .0933 Mdot
.43445 .06421 Mdot
.6723 .46451 Mdot
.61594 .09435 Mdot
.54306 .52597 Mdot
.461 .12414 Mdot
.46139 .08595 Mdot
.26671 .26793 Mdot
.53118 .06044 Mdot
.41417 .05375 Mdot
.57866 .50093 Mdot
.43891 .03329 Mdot
.46985 .12045 Mdot
.56388 .54008 Mdot
.3629 .13199 Mdot
.57363 .50665 Mdot
.51789 .13106 Mdot
.49888 .09904 Mdot
.42456 .04803 Mdot
.56308 .50752 Mdot
.49094 .11597 Mdot
.67155 .44138 Mdot
.09936 .45272 Mdot
.33247 .19626 Mdot
.44771 .03845 Mdot
.92401 .3897 Mdot
.66883 .46399 Mdot
.98293 .4102 Mdot
.44187 .06449 Mdot
.42718 .05212 Mdot
.56744 .51357 Mdot
.34443 .14764 Mdot
.07168 .44261 Mdot
.13293 .24735 Mdot
.38585 .01904 Mdot
.38965 .03362 Mdot
.56008 .50798 Mdot
.11331 .45812 Mdot
.64583 .10602 Mdot
.58731 .50445 Mdot
.58997 .50192 Mdot
.3646 .13553 Mdot
.64787 .48753 Mdot
.39161 .01866 Mdot
.57858 .0801 Mdot
.49048 .12444 Mdot
.57511 .54777 Mdot
.48002 .09937 Mdot
.61813 .09521 Mdot
.63914 .48895 Mdot
.75555 .14835 Mdot
.64195 .49443 Mdot
.40805 .03207 Mdot
.42532 .04291 Mdot
.33469 .17318 Mdot
.40153 .0381 Mdot
.50396 .12216 Mdot
.02187 .42452 Mdot
.32987 .19331 Mdot
.35873 .14036 Mdot
.46947 .12156 Mdot
.63736 .49717 Mdot
.4847 .12176 Mdot
.3507 .00901 Mdot
.44007 .03148 Mdot
.63105 .49264 Mdot
.72756 .35353 Mdot
.39383 .1251 Mdot
.41087 .03803 Mdot
.36274 .56057 Mdot
.63871 .49507 Mdot
.54767 .06914 Mdot
.3185 .24062 Mdot
.48326 .10455 Mdot
.57908 .08115 Mdot
.47885 .10141 Mdot
.3924 .01259 Mdot
.0995 .45261 Mdot
.43216 .0499 Mdot
.42295 .02368 Mdot
.36782 .0162 Mdot
.47283 .08236 Mdot
.40798 .03857 Mdot
.46808 .11697 Mdot
.65269 .48395 Mdot
.69413 .12425 Mdot
.33678 .54962 Mdot
.71931 .35781 Mdot
.70324 .36115 Mdot
.41222 .0372 Mdot
.49495 .11582 Mdot
.43158 .06288 Mdot
.48156 .10571 Mdot
.59907 .50401 Mdot
.58554 .55413 Mdot
.16518 .255 Mdot
.51668 .05991 Mdot
.32978 .21418 Mdot
.29483 .26224 Mdot
.02474 .42533 Mdot
.55478 .53769 Mdot
.78406 .119 Mdot
.37792 .13138 Mdot
.41475 .04434 Mdot
.45396 .07032 Mdot
.33211 .1791 Mdot
.48433 .12244 Mdot
.66582 .47224 Mdot
.38834 .02923 Mdot
.4709 .11845 Mdot
.35116 .15074 Mdot
.14924 .25071 Mdot
.24831 .51318 Mdot
.38167 .01293 Mdot
.55192 .07228 Mdot
.67873 .40675 Mdot
.52829 .5119 Mdot
.50088 .12051 Mdot
.5107 .12751 Mdot
.42439 .12433 Mdot
.4891 .10337 Mdot
.40112 .03213 Mdot
.77995 .3545 Mdot
.68158 .38657 Mdot
.54733 .51194 Mdot
.6671 .44963 Mdot
.70364 .36282 Mdot
.55088 .50626 Mdot
.5411 .52145 Mdot
.52303 .12724 Mdot
.46635 .12428 Mdot
.62735 .58522 Mdot
.39503 .04034 Mdot
.68276 .38778 Mdot
.51244 .12886 Mdot
.36416 .01208 Mdot
.78911 .12138 Mdot
.33397 .17124 Mdot
.67809 .4196 Mdot
.35425 .14501 Mdot
.5502 .52836 Mdot
.63115 .10098 Mdot
.50037 .12896 Mdot
.49121 .04902 Mdot
.48888 .0974 Mdot
.39097 .12274 Mdot
.66834 .46858 Mdot
.38849 .12128 Mdot
.47601 .09142 Mdot
.65524 .48827 Mdot
.47815 .12571 Mdot
.38486 .12169 Mdot
.08672 .23242 Mdot
.47975 .10247 Mdot
.42077 .02205 Mdot
.37479 .01567 Mdot
.96286 .19009 Mdot
.61152 .49788 Mdot
.53375 .52517 Mdot
.33504 .16237 Mdot
.3366 .17311 Mdot
.29979 .25842 Mdot
.65732 .11076 Mdot
.40196 .04585 Mdot
.34067 .16353 Mdot
.60471 .57152 Mdot
.1682 .25536 Mdot
.67856 .41515 Mdot
.60357 .50377 Mdot
.46373 .03944 Mdot
.47581 .04058 Mdot
.75799 .35358 Mdot
.52281 .1293 Mdot
.46044 .08003 Mdot
.30239 .2558 Mdot
.37969 .0268 Mdot
.53728 .51193 Mdot
.45241 .07921 Mdot
.37413 .12517 Mdot
.48315 .12274 Mdot
.35315 .14234 Mdot
.40747 .03508 Mdot
.00437 .20432 Mdot
.7572 .10804 Mdot
.64127 .59672 Mdot
.39983 .03376 Mdot
.01549 .42096 Mdot
.37266 .01505 Mdot
.75791 .10896 Mdot
.56244 .54378 Mdot
.4702 .08463 Mdot
.41504 .12408 Mdot
.52848 .51954 Mdot
.45413 .04097 Mdot
.35623 .13299 Mdot
.50293 .00212 Mdot
.45169 .06627 Mdot
.18226 .25862 Mdot
.72582 .35676 Mdot
.2106 .26324 Mdot
.40375 .04617 Mdot
.41397 .12594 Mdot
.652 .48775 Mdot
.3666 .01305 Mdot
.51652 .05524 Mdot
.54543 .50483 Mdot
.18378 .48662 Mdot
.38645 .01428 Mdot
.4508 .07069 Mdot
.18587 .48685 Mdot
.48081 .12686 Mdot
.69875 .12724 Mdot
.48503 .09657 Mdot
.66734 .07072 Mdot
.52098 .12723 Mdot
.51813 .1187 Mdot
.33422 .17329 Mdot
.96578 .19092 Mdot
.73462 .35446 Mdot
.4663 .60395 Mdot
.18733 .25911 Mdot
.36658 .00973 Mdot
.60758 .56955 Mdot
.61157 .57344 Mdot
.20817 .2647 Mdot
.31147 .24947 Mdot
.50661 .05596 Mdot
.41324 .01985 Mdot
.80342 .35876 Mdot
.5041 .10521 Mdot
.62087 .50556 Mdot
.63546 .49682 Mdot
.49751 .12914 Mdot
.60102 .50259 Mdot
.33675 .17197 Mdot
.53046 .51791 Mdot
.66603 .47279 Mdot
.4505 .06494 Mdot
.1739 .25776 Mdot
.49479 .1027 Mdot
.59826 .56576 Mdot
.59047 .50852 Mdot
.61352 .57423 Mdot
.3704 .02284 Mdot
.34079 .157 Mdot
.41705 .04274 Mdot
.60899 .50703 Mdot
.47964 .12556 Mdot
.37404 .02777 Mdot
.5128 .05511 Mdot
.36286 .13215 Mdot
.58819 .50066 Mdot
.12451 .24355 Mdot
.60212 .50173 Mdot
.48423 .12798 Mdot
.65615 .47601 Mdot
.43331 .02619 Mdot
.42245 .12113 Mdot
.45383 .03464 Mdot
.56495 .51164 Mdot
.58162 .55026 Mdot
.57933 .55581 Mdot
.1807 .48495 Mdot
.56795 .07793 Mdot
.37752 .03079 Mdot
.50533 .11041 Mdot
.20967 .49677 Mdot
.87794 .37621 Mdot
.38393 .12937 Mdot
.48213 .11707 Mdot
.31505 .24594 Mdot
.49916 .11293 Mdot
.48347 .12745 Mdot
.35814 .13581 Mdot
.55851 .50997 Mdot
.4758 .0922 Mdot
.62793 .49848 Mdot
.62106 .5031 Mdot
.46337 .08577 Mdot
.45013 .07684 Mdot
.80258 .35809 Mdot
.61129 .57563 Mdot
.44603 .07532 Mdot
.30738 .25733 Mdot
.68148 .38819 Mdot
.39239 .03538 Mdot
.75144 .35386 Mdot
.67964 .41888 Mdot
.60103 .56618 Mdot
.63065 .58603 Mdot
.55313 .50083 Mdot
.54694 .02084 Mdot
.49149 .04692 Mdot
.69669 .371 Mdot
.55774 .50668 Mdot
.47102 .09266 Mdot
.43386 .06903 Mdot
.62111 .09617 Mdot
.43693 .12032 Mdot
.49746 .05231 Mdot
.31808 .23785 Mdot
.4053 .02604 Mdot
.32333 .24272 Mdot
.51155 .12267 Mdot
.2248 .50306 Mdot
.34477 .15684 Mdot
.49537 .61698 Mdot
.49339 .10128 Mdot
.34489 .15879 Mdot
.41831 .04446 Mdot
.40623 .03879 Mdot
.58964 .08524 Mdot
.65391 .48574 Mdot
.57938 .55248 Mdot
.41408 .02584 Mdot
.34646 .15085 Mdot
.00646 .20533 Mdot
.60112 .5078 Mdot
.61627 .49911 Mdot
.9746 .40664 Mdot
.38502 .02714 Mdot
.48818 .10036 Mdot
.61878 .50417 Mdot
.39385 .02823 Mdot
.36755 .02018 Mdot
.47468 .09315 Mdot
.54628 .51529 Mdot
.92748 .39157 Mdot
.39784 .12229 Mdot
.90721 .3855 Mdot
.66711 .45006 Mdot
.40532 .02675 Mdot
.42164 .12329 Mdot
.54701 .53094 Mdot
.38659 .12877 Mdot
.36475 .56148 Mdot
.45252 .12436 Mdot
.37381 .12818 Mdot
.33999 .55055 Mdot
.312 .5394 Mdot
.50295 .05341 Mdot
.63544 .49933 Mdot
.46403 .12615 Mdot
.62165 .49624 Mdot
.36242 .00811 Mdot
.73764 .35509 Mdot
.3339 .17637 Mdot
.38609 .03267 Mdot
.55515 .52463 Mdot
.05638 .22354 Mdot
.4391 .12283 Mdot
.37854 .00966 Mdot
.43312 .0567 Mdot
.39116 .018 Mdot
.97964 .40943 Mdot
.41847 .12066 Mdot
.79428 .35762 Mdot
.13038 .24569 Mdot
.49065 .10231 Mdot
.32932 .19363 Mdot
.43741 .05892 Mdot
.65977 .47199 Mdot
.5388 .52344 Mdot
.29131 .26633 Mdot
.26295 .26841 Mdot
.20906 .26422 Mdot
.67723 .41152 Mdot
.43736 .06832 Mdot
.55855 .51536 Mdot
.31951 .24712 Mdot
.69728 .36516 Mdot
.41125 .03138 Mdot
.50118 .11045 Mdot
.33372 .18728 Mdot
.32709 .21661 Mdot
.63633 .49636 Mdot
.63576 .49907 Mdot
.48054 .1148 Mdot
.38888 .03534 Mdot
.61827 .09484 Mdot
.38851 .02356 Mdot
.47612 .08307 Mdot
.21697 .26458 Mdot
.41706 .05608 Mdot
.43606 .03142 Mdot
.032 .21481 Mdot
.7599 .3528 Mdot
.52036 .50986 Mdot
.6828 .38969 Mdot
.49883 .13047 Mdot
.10087 .45355 Mdot
.21484 .26419 Mdot
.52236 .12531 Mdot
.36659 .0163 Mdot
.55305 .51805 Mdot
.60901 .57526 Mdot
.5407 .53038 Mdot
.47385 .08991 Mdot
.41066 .02504 Mdot
.33075 .20002 Mdot
.44948 .06344 Mdot
.5676 .54109 Mdot
.71584 .35797 Mdot
.32163 .23517 Mdot
.41841 .04494 Mdot
.32937 .19158 Mdot
.43222 .11831 Mdot
.84537 .14376 Mdot
.00611 .20498 Mdot
.3968 .02788 Mdot
.49815 .1093 Mdot
.65863 .47326 Mdot
.55286 .52969 Mdot
.09263 .45079 Mdot
.45361 .03843 Mdot
.43662 .06457 Mdot
.59396 .56505 Mdot
.55051 .50628 Mdot
.40788 .12688 Mdot
.4741 .1217 Mdot
.61846 .09631 Mdot
.44773 .03553 Mdot
.66092 .47549 Mdot
.41645 .12296 Mdot
.54494 .53321 Mdot
.44334 .59482 Mdot
.68683 .37492 Mdot
.3325 .18654 Mdot
.58087 .50145 Mdot
.66524 .45645 Mdot
.41027 .05231 Mdot
.42246 .05004 Mdot
.3658 .00925 Mdot
.61699 .0959 Mdot
.40779 .03518 Mdot
.86606 .3727 Mdot
.51425 .1202 Mdot
.54865 .51237 Mdot
.6733 .44017 Mdot
.32788 .20739 Mdot
.41589 .02054 Mdot
.53179 .50479 Mdot
.54035 .52465 Mdot
.33081 .20166 Mdot
.54625 .53376 Mdot
.49524 .1236 Mdot
.41528 .58245 Mdot
.58533 .50119 Mdot
.40162 .02534 Mdot
.6584 .48047 Mdot
.32974 .191 Mdot
.47557 .12264 Mdot
.50066 .10416 Mdot
.28629 .52829 Mdot
.33605 .17287 Mdot
.58899 .08399 Mdot
.96384 .40326 Mdot
.68066 .38871 Mdot
.36354 .01811 Mdot
.60686 .5715 Mdot
.55594 .50853 Mdot
.42347 .02715 Mdot
.33761 .1649 Mdot
.59878 .5009 Mdot
.48571 .04593 Mdot
.54519 .06944 Mdot
.98857 .41148 Mdot
.37153 .02528 Mdot
.59323 .50752 Mdot
.50204 .1034 Mdot
.62656 .49983 Mdot
.46658 .12501 Mdot
.63473 .59205 Mdot
.38871 .12126 Mdot
.44304 .12398 Mdot
.35963 .14053 Mdot
.32699 .20548 Mdot
.49491 .09669 Mdot
.73426 .35504 Mdot
.44045 .06123 Mdot
.56767 .54728 Mdot
.67024 .46936 Mdot
.46944 .03852 Mdot
.33357 .17681 Mdot
.40736 .0202 Mdot
.37943 .0275 Mdot
.33484 .19011 Mdot
.25127 .26824 Mdot
.42513 .03106 Mdot
.39669 .02103 Mdot
.47271 .08079 Mdot
.68284 .39249 Mdot
.46974 .12692 Mdot
.65112 .49063 Mdot
.32815 .21214 Mdot
.43229 .12207 Mdot
.49119 .09472 Mdot
.48655 .11812 Mdot
.52407 .51124 Mdot
.02585 .42574 Mdot
.25509 .51544 Mdot
.91317 .38639 Mdot
.41355 .04986 Mdot
.65345 .48527 Mdot
.94177 .39601 Mdot
.60535 .50657 Mdot
.45023 .07674 Mdot
.30805 .25362 Mdot
.58613 .50393 Mdot
.46068 .08695 Mdot
.3976 .01438 Mdot
.34158 .15306 Mdot
.47149 .07952 Mdot
.00365 .41797 Mdot
.39526 .02765 Mdot
.59531 .55962 Mdot
.60227 .04331 Mdot
.5087 .05363 Mdot
.41467 .04118 Mdot
.8891 .16142 Mdot
.34409 .15069 Mdot
.42075 .12054 Mdot
.26404 .26688 Mdot
.63466 .59362 Mdot
.35916 .01356 Mdot
.42196 .06191 Mdot
.59985 .50459 Mdot
.41119 .0241 Mdot
.50546 .11507 Mdot
.66589 .11391 Mdot
.55576 .07146 Mdot
.36616 .13309 Mdot
.30096 .53451 Mdot
.37131 .02068 Mdot
.39664 .03969 Mdot
.39963 .04337 Mdot
.37962 .03017 Mdot
.37099 .00892 Mdot
.41312 .04434 Mdot
.59891 .50578 Mdot
.5791 .55514 Mdot
.67691 .42674 Mdot
.5671 .50413 Mdot
.44722 .11976 Mdot
.50198 .05439 Mdot
.46486 .04358 Mdot
.53371 .06157 Mdot
.53343 .06305 Mdot
.54094 .51608 Mdot
.44776 .03194 Mdot
.27309 .26894 Mdot
.50281 .05422 Mdot
.80996 .36019 Mdot
.41297 .11951 Mdot
.5617 .53751 Mdot
.74058 .14235 Mdot
.67381 .43618 Mdot
.57836 .03414 Mdot
.54962 .02187 Mdot
.67342 .42324 Mdot
.58778 .50447 Mdot
.28366 .26695 Mdot
.40289 .02547 Mdot
.52084 .12292 Mdot
.50032 .1008 Mdot
.4829 .04539 Mdot
.36976 .13087 Mdot
.52046 .05876 Mdot
.2485 .26992 Mdot
.44957 .06755 Mdot
.6343 .59109 Mdot
.42493 .58675 Mdot
.44322 .03302 Mdot
.64804 .10612 Mdot
.63456 .59283 Mdot
.43035 .12613 Mdot
.6014 .04307 Mdot
.32787 .21296 Mdot
.51428 .05547 Mdot
.50637 .11795 Mdot
.48807 .09574 Mdot
.6035 .08862 Mdot
.50707 .122 Mdot
.39107 .1224 Mdot
.43079 .03559 Mdot
.49633 .12006 Mdot
.42167 .04345 Mdot
.65567 .4807 Mdot
.73914 .35415 Mdot
.46721 .11856 Mdot
.5978 .49973 Mdot
.55062 .51209 Mdot
.49342 .1212 Mdot
.6592 .48406 Mdot
.58451 .50996 Mdot
.35733 .13952 Mdot
.13318 .2474 Mdot
.41109 .05123 Mdot
.32825 .19705 Mdot
.4987 .10094 Mdot
.00481 .41742 Mdot
.4913 .04835 Mdot
.55986 .54018 Mdot
.44098 .07245 Mdot
.40313 .12595 Mdot
.49114 .10674 Mdot
.69862 .36195 Mdot
.71865 .35749 Mdot
.56788 .54743 Mdot
.89409 .16348 Mdot
.92431 .17471 Mdot
.40218 .0276 Mdot
.66319 .47866 Mdot
.64893 .10791 Mdot
.55656 .52907 Mdot
.63392 .50005 Mdot
.5176 .12229 Mdot
.67919 .07611 Mdot
.67339 .45248 Mdot
.67575 .44049 Mdot
.55166 .51691 Mdot
.46161 .08335 Mdot
.41109 .12327 Mdot
.53702 .06342 Mdot
.33602 .18302 Mdot
.56782 .51088 Mdot
.79704 .35654 Mdot
.70195 .12771 Mdot
.38981 .03152 Mdot
.43734 .12169 Mdot
.46372 .07947 Mdot
.33169 .20438 Mdot
.43568 .05289 Mdot
.49563 .11619 Mdot
.54034 .51202 Mdot
.41952 .04871 Mdot
.44222 .06473 Mdot
.42394 .0437 Mdot
.78173 .35503 Mdot
.44298 .11753 Mdot
.46791 .6045 Mdot
.59791 .50514 Mdot
.40189 .0405 Mdot
.42335 .03951 Mdot
.57901 .50519 Mdot
.55816 .52917 Mdot
.63674 .59465 Mdot
.14099 .24972 Mdot
.86289 .37182 Mdot
.32805 .20092 Mdot
.61571 .50633 Mdot
.40313 .04892 Mdot
.51832 .11866 Mdot
.43311 .06156 Mdot
.43705 .06571 Mdot
.54688 .52054 Mdot
.46831 .07772 Mdot
.62499 .50411 Mdot
.51234 .10981 Mdot
.45424 .03998 Mdot
.6703 .45607 Mdot
.70292 .36562 Mdot
.66555 .47122 Mdot
.74986 .10577 Mdot
.49017 .09483 Mdot
.3383 .16072 Mdot
.38457 .02451 Mdot
.45582 .12555 Mdot
.6735 .43793 Mdot
.41983 .12541 Mdot
.47668 .08942 Mdot
.42608 .04333 Mdot
.12693 .46337 Mdot
.92979 .17684 Mdot
.68248 .38607 Mdot
.58359 .50349 Mdot
.4724 .08633 Mdot
.35023 .13778 Mdot
.4209 .05892 Mdot
.5307 .51173 Mdot
.5125 .11941 Mdot
.48752 .10209 Mdot
.37037 .02548 Mdot
.57605 .54814 Mdot
.04723 .43271 Mdot
.32976 .19893 Mdot
.66132 .47817 Mdot
.32884 .22856 Mdot
.51491 .00638 Mdot
.42102 .04005 Mdot
.44054 .05871 Mdot
.47904 .12599 Mdot
.59549 .56312 Mdot
.39703 .03953 Mdot
.54553 .53102 Mdot
.48581 .04945 Mdot
.42802 .11868 Mdot
.77508 .35484 Mdot
.34107 .15765 Mdot
.52558 .06052 Mdot
.58257 .55216 Mdot
.80669 .35986 Mdot
.71348 .0904 Mdot
.44114 .1193 Mdot
.67786 .39667 Mdot
.49534 .05135 Mdot
.52384 .50953 Mdot
.62565 .50402 Mdot
.52586 .12079 Mdot
.43848 .06937 Mdot
.57133 .54207 Mdot
.39983 .01967 Mdot
.35832 .00731 Mdot
.45368 .07297 Mdot
.51155 .11937 Mdot
.5714 .54358 Mdot
.6749 .42098 Mdot
.66955 .46099 Mdot
.56026 .53879 Mdot
.65773 .48359 Mdot
.34442 .14897 Mdot
.12681 .46382 Mdot
.51602 .12571 Mdot
.83357 .3637 Mdot
.50002 .12582 Mdot
.44922 .07376 Mdot
.35502 .01589 Mdot
.42818 .03615 Mdot
.45742 .07582 Mdot
.33294 .18097 Mdot
.42406 .12057 Mdot
.23072 .26742 Mdot
.66294 .48286 Mdot
.61748 .57916 Mdot
.24316 .26729 Mdot
.34011 .15247 Mdot
.46707 .03853 Mdot
.46112 .03905 Mdot
.49928 .049 Mdot
.6709 .4626 Mdot
.09591 .23644 Mdot
.47535 .12339 Mdot
.47362 .08593 Mdot
.83012 .36465 Mdot
.51079 .11587 Mdot
.66977 .46351 Mdot
.54191 .51298 Mdot
.45679 .12397 Mdot
.69685 .37093 Mdot
.42236 .04438 Mdot
.56953 .50412 Mdot
.28467 .2637 Mdot
.38093 .01542 Mdot
.50775 .05264 Mdot
.81566 .36124 Mdot
.41046 .0345 Mdot
.34817 .13999 Mdot
.32366 .22433 Mdot
.43931 .12308 Mdot
.56238 .53708 Mdot
.27543 .26817 Mdot
.6653 .07039 Mdot
.59179 .50333 Mdot
.39781 .03521 Mdot
.5605 .50065 Mdot
.52487 .06174 Mdot
.59759 .56331 Mdot
.57936 .55492 Mdot
.01067 .41953 Mdot
.93329 .17809 Mdot
.43816 .03233 Mdot
.34449 .15384 Mdot
.01299 .42002 Mdot
.5774 .55537 Mdot
.85066 .36912 Mdot
.08364 .44706 Mdot
.55255 .06837 Mdot
.36561 .1343 Mdot
.38869 .01372 Mdot
.90465 .16763 Mdot
.29673 .25901 Mdot
.38814 .01964 Mdot
.4807 .09674 Mdot
.34144 .16605 Mdot
.66144 .47192 Mdot
.56505 .02839 Mdot
.59068 .08313 Mdot
.38766 .01502 Mdot
.35171 .00556 Mdot
.35269 .14531 Mdot
.56715 .51168 Mdot
.59301 .56177 Mdot
.37486 .13111 Mdot
.68542 .38633 Mdot
.45855 .0804 Mdot
.46974 .04409 Mdot
.41017 .58002 Mdot
.02633 .21207 Mdot
.31373 .24847 Mdot
.51316 .1193 Mdot
.27318 .26672 Mdot
.70515 .36494 Mdot
.327 .22438 Mdot
.6053 .50586 Mdot
.65709 .10913 Mdot
.65481 .11022 Mdot
.67087 .44989 Mdot
.5818 .55755 Mdot
.43614 .06494 Mdot
.31122 .24788 Mdot
.56267 .50121 Mdot
.40982 .0179 Mdot
.41717 .03139 Mdot
.3848 .02782 Mdot
.67397 .42129 Mdot
.40722 .03794 Mdot
.83298 .36451 Mdot
.44502 .03437 Mdot
.62137 .58345 Mdot
.4158 .04531 Mdot
.23568 .50779 Mdot
.64814 .491 Mdot
.55011 .52215 Mdot
.5422 .50735 Mdot
.33542 .5493 Mdot
.27664 .26913 Mdot
.46404 .03668 Mdot
.33878 .15916 Mdot
.35562 .13365 Mdot
.44823 .07 Mdot
.4805 .08535 Mdot
.71024 .13073 Mdot
.67181 .44074 Mdot
.40729 .04818 Mdot
.87879 .3769 Mdot
.42484 .04528 Mdot
.73714 .14157 Mdot
.34245 .16548 Mdot
.58701 .55409 Mdot
.40745 .0264 Mdot
.1227 .46213 Mdot
.58138 .55683 Mdot
.41877 .05255 Mdot
.54399 .52971 Mdot
.83095 .13807 Mdot
.17539 .25828 Mdot
.6581 .47693 Mdot
.44466 .05988 Mdot
.67548 .41561 Mdot
.5422 .50141 Mdot
.9354 .17994 Mdot
.10037 .2369 Mdot
.42201 .02483 Mdot
.70277 .36165 Mdot
.55414 .53875 Mdot
.53025 .5058 Mdot
.43567 .05322 Mdot
.37193 .02103 Mdot
.24094 .26838 Mdot
.64744 .48582 Mdot
.54575 .52919 Mdot
.63154 .58694 Mdot
.39167 .0358 Mdot
.51305 .11272 Mdot
.58492 .0824 Mdot
.67668 .41373 Mdot
.41152 .02912 Mdot
.57415 .54732 Mdot
.66908 .46652 Mdot
.53815 .52621 Mdot
.48592 .10863 Mdot
.56329 .07514 Mdot
.45075 .06654 Mdot
.43767 .03137 Mdot
.39584 .02934 Mdot
.79455 .12412 Mdot
.50012 .05203 Mdot
.58438 .55467 Mdot
.60663 .57372 Mdot
.75548 .14829 Mdot
.37603 .01225 Mdot
.5092 .05606 Mdot
.52916 .50672 Mdot
.74917 .14663 Mdot
.33453 .1716 Mdot
.54332 .52437 Mdot
.40663 .03505 Mdot
.39412 .03103 Mdot
.6072 .09209 Mdot
.47652 .09662 Mdot
.46602 .04283 Mdot
.46872 .08992 Mdot
.41035 .02475 Mdot
.38675 .01572 Mdot
.50177 .11577 Mdot
.40705 .01864 Mdot
.56404 .54389 Mdot
.42202 .06159 Mdot
.19082 .48933 Mdot
.54684 .52109 Mdot
.33273 .19196 Mdot
.67497 .41609 Mdot
.46318 .07912 Mdot
.20471 .26243 Mdot
.45167 .08131 Mdot
.50336 .1068 Mdot
.65252 .48677 Mdot
.48772 .1209 Mdot
.54995 .52777 Mdot
.42844 .06151 Mdot
.43096 .03741 Mdot
.41108 .03568 Mdot
.66874 .45825 Mdot
.24099 .26787 Mdot
.51896 .12142 Mdot
.37966 .01562 Mdot
.41154 .0376 Mdot
.08861 .44913 Mdot
.32724 .21138 Mdot
.46027 .12113 Mdot
.43916 .12434 Mdot
.44433 .07682 Mdot
.41761 .03006 Mdot
.55082 .53334 Mdot
.33778 .16213 Mdot
.44696 .06575 Mdot
.48682 .04403 Mdot
.43534 .06398 Mdot
.98275 .41022 Mdot
.40132 .12586 Mdot
.46272 .07973 Mdot
.38934 .02741 Mdot
.75419 .35414 Mdot
.46134 .03522 Mdot
.74647 .35147 Mdot
.38023 .0288 Mdot
.48603 .0475 Mdot
.64809 .48819 Mdot
.3797 .02752 Mdot
.94678 .3969 Mdot
.50189 .12237 Mdot
.38322 .01088 Mdot
.66956 .11566 Mdot
.67701 .42843 Mdot
.47901 .11647 Mdot
.55343 .50474 Mdot
.32726 .23446 Mdot
.62282 .49513 Mdot
.86533 .15189 Mdot
.57182 .50793 Mdot
.47764 .08407 Mdot
.49929 .10707 Mdot
.43951 .02785 Mdot
.48712 .12051 Mdot
.54899 .52505 Mdot
.3528 .14254 Mdot
.77294 .35383 Mdot
.67416 .41759 Mdot
.45278 .03168 Mdot
.63847 .59208 Mdot
.31374 .24712 Mdot
.44998 .03367 Mdot
.37118 .01246 Mdot
.5421 .50112 Mdot
.647 .10601 Mdot
.51176 .11516 Mdot
.37792 .01631 Mdot
.57048 .54814 Mdot
.49449 .09573 Mdot
.46546 .04318 Mdot
.46894 .12384 Mdot
.40864 .03087 Mdot
.58389 .55447 Mdot
.40293 .04707 Mdot
.58475 .5595 Mdot
.33481 .1659 Mdot
.5301 .51479 Mdot
.45259 .03162 Mdot
.33945 .55105 Mdot
.37057 .019 Mdot
.42532 .04619 Mdot
.53566 .51525 Mdot
.53982 .51903 Mdot
.75541 .10784 Mdot
.62799 .58753 Mdot
.33181 .19349 Mdot
.3651 .02333 Mdot
.37297 .01692 Mdot
.43415 .03381 Mdot
.60777 .0918 Mdot
.52212 .11707 Mdot
.56086 .53167 Mdot
.42174 .06084 Mdot
.37583 .02209 Mdot
.40615 .03515 Mdot
.47458 .12616 Mdot
.44433 .06664 Mdot
.60814 .57053 Mdot
.40666 .0396 Mdot
.68766 .38534 Mdot
.62851 .09825 Mdot
.53076 .50369 Mdot
.37871 .13067 Mdot
.66062 .47557 Mdot
.51342 .11617 Mdot
.67322 .41976 Mdot
.44546 .077 Mdot
.39231 .03248 Mdot
.54728 .50804 Mdot
.46026 .08517 Mdot
.32304 .24071 Mdot
.44556 .11952 Mdot
.68082 .38307 Mdot
.02465 .42439 Mdot
.36717 .01071 Mdot
.68121 .39528 Mdot
.44286 .59428 Mdot
.39346 .01977 Mdot
.35196 .14208 Mdot
.62681 .58733 Mdot
.68061 .38353 Mdot
.7048 .08718 Mdot
.62301 .58114 Mdot
.50971 .11337 Mdot
.39123 .12216 Mdot
.64794 .49027 Mdot
.42498 .04217 Mdot
.71449 .13314 Mdot
.84035 .36624 Mdot
.54516 .52055 Mdot
.47809 .10297 Mdot
.58877 .55528 Mdot
.38669 .13008 Mdot
.42579 .05488 Mdot
.30847 .25713 Mdot
.67794 .42792 Mdot
.4198 .0503 Mdot
.38136 .0116 Mdot
.55419 .5121 Mdot
.60616 .56878 Mdot
.48642 .10794 Mdot
.63146 .09988 Mdot
.35766 .01129 Mdot
.39833 .01667 Mdot
.32216 .2308 Mdot
.76716 .35451 Mdot
.58545 .50369 Mdot
.66328 .48098 Mdot
.37127 .13313 Mdot
.60328 .50527 Mdot
.72423 .35349 Mdot
.54629 .52726 Mdot
.43703 .05369 Mdot
.57997 .50603 Mdot
.42578 .04774 Mdot
.52666 .50872 Mdot
.64483 .49412 Mdot
.40696 .01783 Mdot
.39073 .016 Mdot
.38874 .01777 Mdot
.34941 .14711 Mdot
.4202 .03087 Mdot
.5418 .51425 Mdot
.48876 .10099 Mdot
.30326 .25826 Mdot
.51391 .11082 Mdot
.40177 .03556 Mdot
.3062 .25868 Mdot
.44234 .06118 Mdot
.68299 .07763 Mdot
.45134 .0739 Mdot
.49268 .61493 Mdot
.35711 .55847 Mdot
.49144 .11282 Mdot
.56379 .50558 Mdot
.56618 .51266 Mdot
.4234 .03791 Mdot
.45244 .12597 Mdot
.38365 .01463 Mdot
.58668 .5602 Mdot
.69013 .37415 Mdot
.43639 .06083 Mdot
.12855 .24458 Mdot
.67819 .41053 Mdot
.64034 .48928 Mdot
.32886 .2127 Mdot
.66336 .47759 Mdot
.34682 .15106 Mdot
.36293 .13803 Mdot
.65121 .10671 Mdot
.33753 .16705 Mdot
.49291 .04887 Mdot
.5334 .0151 Mdot
.52533 .51549 Mdot
.42324 .03984 Mdot
.43571 .02662 Mdot
.33403 .19571 Mdot
.52455 .13 Mdot
.55071 .50083 Mdot
.59736 .56246 Mdot
.40782 .04958 Mdot
.5558 .52917 Mdot
.04407 .21912 Mdot
.67633 .44018 Mdot
.63763 .49783 Mdot
.6001 .08788 Mdot
.34518 .15654 Mdot
.40937 .019 Mdot
.6501 .60576 Mdot
.30058 .25924 Mdot
.47119 .11626 Mdot
.98407 .4097 Mdot
.56186 .07408 Mdot
.1977 .26203 Mdot
.31055 .24942 Mdot
.03397 .42848 Mdot
.13131 .24589 Mdot
.3002 .26221 Mdot
.55294 .52742 Mdot
.69111 .08104 Mdot
.56512 .53797 Mdot
.37652 .03076 Mdot
.70342 .36267 Mdot
.031 .42665 Mdot
.23788 .26834 Mdot
.55406 .5274 Mdot
.39832 .02661 Mdot
.43707 .03737 Mdot
.73016 .35313 Mdot
.69465 .36589 Mdot
.77372 .11552 Mdot
.58769 .08207 Mdot
.66138 .46976 Mdot
.56018 .51051 Mdot
.55474 .51776 Mdot
.5097 .1189 Mdot
.34684 .14119 Mdot
.31693 .24038 Mdot
.38627 .02796 Mdot
.42136 .06049 Mdot
.84297 .14292 Mdot
.50165 .13024 Mdot
.5768 .50475 Mdot
.20862 .26343 Mdot
.38474 .03392 Mdot
.31415 .25066 Mdot
.3868 .02089 Mdot
.54442 .06974 Mdot
.6499 .48663 Mdot
.41238 .58185 Mdot
.67266 .4172 Mdot
.33494 .19457 Mdot
.60148 .08961 Mdot
.63901 .10418 Mdot
.4537 .07506 Mdot
.32487 .23507 Mdot
.38856 .03321 Mdot
.35526 .00778 Mdot
.6823 .11934 Mdot
.52969 .5184 Mdot
.42699 .05863 Mdot
.36132 .01399 Mdot
.45122 .59771 Mdot
.34188 .15243 Mdot
.33854 .16415 Mdot
.49382 .11921 Mdot
.49393 .05246 Mdot
.79146 .35677 Mdot
.51432 .05545 Mdot
.74441 .35302 Mdot
.61904 .09507 Mdot
.54029 .51102 Mdot
.58879 .50387 Mdot
.53843 .50588 Mdot
.47898 .10421 Mdot
.45636 .06892 Mdot
.77375 .35431 Mdot
.51103 .054 Mdot
.36623 .13342 Mdot
.39003 .12071 Mdot
.50891 .10715 Mdot
.92412 .17511 Mdot
.34074 .151 Mdot
.58574 .50078 Mdot
.33707 .1759 Mdot
.65421 .48912 Mdot
.48487 .09339 Mdot
.47856 .12796 Mdot
.67749 .39487 Mdot
.32333 .22961 Mdot
.40511 .02335 Mdot
.39325 .03906 Mdot
.09783 .45272 Mdot
.37189 .13246 Mdot
.48246 .09374 Mdot
.67258 .45099 Mdot
.19983 .49341 Mdot
.63727 .49872 Mdot
.34361 .14786 Mdot
.46738 .07715 Mdot
.52765 .50314 Mdot
.5809 .50864 Mdot
.65283 .06504 Mdot
.66346 .47157 Mdot
.63932 .49782 Mdot
.40901 .03238 Mdot
.26188 .51816 Mdot
.32322 .22711 Mdot
.57713 .50444 Mdot
.23532 .267 Mdot
.33853 .15751 Mdot
.37877 .02097 Mdot
.67476 .40894 Mdot
.40357 .02752 Mdot
.56281 .07293 Mdot
.33411 .16997 Mdot
.56741 .07692 Mdot
.39046 .03132 Mdot
.33951 .16582 Mdot
.65074 .48412 Mdot
.65882 .47458 Mdot
.4814 .11023 Mdot
.43769 .11825 Mdot
.46816 .04004 Mdot
.32693 .23375 Mdot
.67952 .42142 Mdot
.80171 .35746 Mdot
.50483 .12838 Mdot
.32453 .22831 Mdot
.49156 .10503 Mdot
.56152 .51148 Mdot
.97538 .4067 Mdot
.42001 .05371 Mdot
.39527 .12028 Mdot
.54916 .5293 Mdot
.42831 .05962 Mdot
.45212 .07486 Mdot
.50043 .11432 Mdot
.69749 .36438 Mdot
.63023 .49898 Mdot
.53028 .06369 Mdot
.66644 .07052 Mdot
.45069 .07787 Mdot
.6463 .5978 Mdot
.56166 .51449 Mdot
.66517 .45941 Mdot
.40712 .01977 Mdot
.50983 .12607 Mdot
.10441 .45566 Mdot
.37357 .01928 Mdot
.46227 .03992 Mdot
.40869 .03851 Mdot
.70367 .12751 Mdot
.72281 .35516 Mdot
.68046 .39941 Mdot
.67188 .43693 Mdot
.80165 .35909 Mdot
.35945 .0084 Mdot
.67627 .41414 Mdot
.95624 .1872 Mdot
.54755 .524 Mdot
.20325 .26227 Mdot
.70597 .36273 Mdot
.41607 .05052 Mdot
.89381 .38142 Mdot
.51812 .13118 Mdot
.64 .59339 Mdot
.67653 .42919 Mdot
.40997 .04941 Mdot
.67108 .45452 Mdot
.51907 .11998 Mdot
.4627 .08719 Mdot
.31943 .2404 Mdot
.54709 .50087 Mdot
.91683 .38807 Mdot
.35179 .14393 Mdot
.59918 .50757 Mdot
.56021 .53272 Mdot
.54959 .51515 Mdot
.50077 .05319 Mdot
.63116 .49527 Mdot
.44387 .12044 Mdot
.49172 .10203 Mdot
.41762 .05714 Mdot
.52713 .51137 Mdot
.32709 .21018 Mdot
.41562 .02398 Mdot
.5497 .51135 Mdot
.44293 .03451 Mdot
.66732 .47585 Mdot
.47522 .09669 Mdot
.54389 .50257 Mdot
.518 .12645 Mdot
.49741 .09957 Mdot
.38007 .02584 Mdot
.40736 .03536 Mdot
.46601 .11928 Mdot
.65555 .48397 Mdot
.39886 .02806 Mdot
.60338 .57147 Mdot
.67719 .11764 Mdot
.64622 .60048 Mdot
.68371 .38963 Mdot
.4908 .05118 Mdot
.43416 .05403 Mdot
.52451 .50923 Mdot
.39649 .0299 Mdot
.16319 .25436 Mdot
.54002 .51304 Mdot
.36966 .56368 Mdot
.93901 .18116 Mdot
.68007 .40425 Mdot
.32505 .2386 Mdot
.66565 .47181 Mdot
.53403 .51947 Mdot
.27391 .26847 Mdot
.25097 .2679 Mdot
.66421 .473 Mdot
.43986 .06163 Mdot
.48728 .10607 Mdot
.36777 .13006 Mdot
.2983 .26061 Mdot
.69345 .37051 Mdot
.05679 .43706 Mdot
.46619 .03851 Mdot
.68876 .3834 Mdot
.41903 .05394 Mdot
.47368 .09279 Mdot
.62258 .49518 Mdot
.50377 .12579 Mdot
.44672 .12093 Mdot
.38754 .02723 Mdot
.63846 .59662 Mdot
.6693 .4406 Mdot
.40787 .04365 Mdot
.5486 .52843 Mdot
.54708 .06981 Mdot
.40557 .01818 Mdot
.54595 .51837 Mdot
.5268 .50557 Mdot
.42905 .05883 Mdot
.49976 .12036 Mdot
.54685 .53192 Mdot
.54122 .06859 Mdot
.58744 .55945 Mdot
.4618 .12745 Mdot
.2866 .52881 Mdot
.90287 .16703 Mdot
.37047 .13331 Mdot
.01268 .42017 Mdot
.88035 .37641 Mdot
.52498 .5082 Mdot
.47877 .08812 Mdot
.49551 .12646 Mdot
.38315 .1274 Mdot
.40938 .03931 Mdot
.11681 .2419 Mdot
.49343 .61594 Mdot
.66034 .48179 Mdot
.36192 .01651 Mdot
.37879 .12321 Mdot
.52447 .12371 Mdot
.49427 .61636 Mdot
.17458 .25788 Mdot
.35219 .13657 Mdot
.47446 .09647 Mdot
.5593 .50709 Mdot
.56802 .54138 Mdot
.43606 .11792 Mdot
.41197 .04004 Mdot
.35082 .14067 Mdot
.39698 .02887 Mdot
.36947 .01774 Mdot
.92576 .39099 Mdot
.49549 .1223 Mdot
.64533 .10579 Mdot
.43451 .02593 Mdot
.67434 .44678 Mdot
.57193 .07902 Mdot
.53496 .51656 Mdot
.69065 .37856 Mdot
.14951 .25124 Mdot
.50129 .12535 Mdot
.47105 .07903 Mdot
.49891 .1166 Mdot
.68901 .3732 Mdot
.62776 .5037 Mdot
.60161 .04342 Mdot
.54725 .52138 Mdot
.71236 .35948 Mdot
.67148 .45385 Mdot
.5386 .51689 Mdot
.55983 .51253 Mdot
.41686 .04139 Mdot
.3157 .54035 Mdot
.66763 .47188 Mdot
.40916 .02802 Mdot
.3994 .03532 Mdot
.41082 .03226 Mdot
.73516 .352 Mdot
.49181 .11609 Mdot
.58628 .5046 Mdot
.4019 .12467 Mdot
.62303 .58426 Mdot
.47829 .12864 Mdot
.70568 .35972 Mdot
.69526 .12432 Mdot
.66088 .47435 Mdot
.53129 .50587 Mdot
.42211 .12531 Mdot
.13112 .24594 Mdot
.57803 .50989 Mdot
.4879 .11097 Mdot
.37492 .01974 Mdot
.6741 .43452 Mdot
.41018 .05005 Mdot
.40258 .03738 Mdot
.1519 .47322 Mdot
.40566 .02905 Mdot
.6865 .38096 Mdot
.48414 .12436 Mdot
.41056 .0286 Mdot
.5368 .52457 Mdot
.4436 .03835 Mdot
.40903 .12666 Mdot
.42452 .02805 Mdot
.61312 .50171 Mdot
.58302 .55271 Mdot
.35745 .14311 Mdot
.36189 .13373 Mdot
.38098 .12456 Mdot
.96356 .19037 Mdot
.55331 .51757 Mdot
.07669 .22899 Mdot
.41171 .02378 Mdot
.4737 .09617 Mdot
.33446 .18358 Mdot
.41937 .02355 Mdot
.61312 .49786 Mdot
.38384 .03519 Mdot
.37675 .02745 Mdot
.03423 .21574 Mdot
.09849 .23727 Mdot
.61162 .50763 Mdot
.63612 .49284 Mdot
.50223 .12922 Mdot
.28718 .26622 Mdot
.41574 .043 Mdot
.36941 .02266 Mdot
.43426 .06588 Mdot
.33645 .15886 Mdot
.3733 .02534 Mdot
.41804 .03436 Mdot
.40276 .12297 Mdot
.44752 .12588 Mdot
.3929 .12483 Mdot
.67472 .43516 Mdot
.55188 .51769 Mdot
.50154 .05355 Mdot
.23794 .26898 Mdot
.52645 .06024 Mdot
.4272 .12351 Mdot
.25375 .51523 Mdot
.49409 .12319 Mdot
.5178 .11898 Mdot
.63069 .59024 Mdot
.67614 .44583 Mdot
.36838 .13179 Mdot
.37539 .01722 Mdot
.48291 .12808 Mdot
.54856 .52518 Mdot
.80366 .35954 Mdot
.66623 .47297 Mdot
.48006 .12059 Mdot
.43379 .06809 Mdot
.58882 .5091 Mdot
.65869 .47549 Mdot
.63627 .10084 Mdot
.55773 .50579 Mdot
.07606 .22906 Mdot
.55309 .50122 Mdot
.4335 .02579 Mdot
.67082 .45563 Mdot
.39699 .03537 Mdot
.61393 .50553 Mdot
.53706 .52295 Mdot
.75154 .35357 Mdot
.54282 .52172 Mdot
.4201 .02187 Mdot
.57694 .50803 Mdot
.46702 .09334 Mdot
.46684 .12219 Mdot
.51166 .10835 Mdot
.43901 .05589 Mdot
.8997 .38238 Mdot
.38928 .02398 Mdot
.78905 .35626 Mdot
.49479 .11236 Mdot
.60985 .50709 Mdot
.47014 .07964 Mdot
.54412 .51947 Mdot
.3188 .24035 Mdot
.67684 .4108 Mdot
.60278 .08987 Mdot
.46483 .08215 Mdot
.72025 .09363 Mdot
.67545 .40436 Mdot
.03636 .21603 Mdot
.54976 .51291 Mdot
.48055 .11641 Mdot
.55521 .51608 Mdot
.5503 .53367 Mdot
.36848 .01064 Mdot
.48129 .0867 Mdot
.42838 .05291 Mdot
.429 .1182 Mdot
.38113 .01007 Mdot
.05925 .43736 Mdot
.364 .12938 Mdot
.63513 .10031 Mdot
.44927 .12278 Mdot
.88077 .3773 Mdot
.51667 .12597 Mdot
.58072 .50529 Mdot
.49753 .12442 Mdot
.44261 .12275 Mdot
.5504 .0699 Mdot
.38953 .02003 Mdot
.43869 .03024 Mdot
.91604 .1718 Mdot
.68146 .39059 Mdot
.3241 .23415 Mdot
.42678 .03868 Mdot
.7358 .35514 Mdot
.53275 .51909 Mdot
.57973 .54969 Mdot
.4779 .12535 Mdot
.46363 .12711 Mdot
.44756 .06551 Mdot
.45109 .12213 Mdot
.47496 .09429 Mdot
.53744 .52549 Mdot
.43473 .12447 Mdot
.45296 .07356 Mdot
.42733 .03176 Mdot
.46278 .12491 Mdot
.49829 .1053 Mdot
.27848 .26576 Mdot
.6763 .44785 Mdot
.5794 .55123 Mdot
.14061 .4689 Mdot
.446 .12598 Mdot
.42408 .04452 Mdot
.77215 .11492 Mdot
.52796 .50706 Mdot
.35493 .13662 Mdot
.50618 .00297 Mdot
.54695 .51643 Mdot
.41029 .0324 Mdot
.34254 .15233 Mdot
.44582 .06477 Mdot
.54376 .01855 Mdot
.69201 .37339 Mdot
.62489 .5847 Mdot
.50665 .12671 Mdot
.46606 .08649 Mdot
.75918 .10938 Mdot
.53896 .52735 Mdot
.36587 .00984 Mdot
.5502 .51032 Mdot
.63715 .49417 Mdot
.32259 .23087 Mdot
.46661 .12501 Mdot
.613 .57518 Mdot
.60151 .49878 Mdot
.35392 .00587 Mdot
.46505 .08618 Mdot
.96701 .40481 Mdot
.32168 .24182 Mdot
.59182 .5072 Mdot
.28972 .26443 Mdot
.36524 .00673 Mdot
.53188 .50295 Mdot
.47406 .12853 Mdot
.49013 .10262 Mdot
.33506 .18901 Mdot
.47247 .60675 Mdot
.32734 .22767 Mdot
.36302 .13017 Mdot
.7218 .35777 Mdot
.65657 .47958 Mdot
.57683 .55136 Mdot
.46965 .0438 Mdot
.60625 .57312 Mdot
.51751 .118 Mdot
.3571 .1334 Mdot
.38018 .01971 Mdot
.61737 .49912 Mdot
.52288 .13018 Mdot
.40216 .02576 Mdot
.53384 .06474 Mdot
.47437 .08553 Mdot
.4957 .12282 Mdot
.44651 .12254 Mdot
.39796 .02518 Mdot
.32938 .2099 Mdot
.06262 .4394 Mdot
.38154 .02651 Mdot
.28227 .52675 Mdot
.33591 .1596 Mdot
.384 .0176 Mdot
.39747 .03809 Mdot
.55438 .52873 Mdot
.66795 .46719 Mdot
.74318 .3514 Mdot
.34252 .14972 Mdot
.46758 .12316 Mdot
.63179 .50023 Mdot
.94966 .18504 Mdot
.66712 .46231 Mdot
.38468 .01252 Mdot
.46408 .12232 Mdot
.64769 .49455 Mdot
.47626 .10164 Mdot
.58231 .5528 Mdot
.46197 .12141 Mdot
.43344 .12042 Mdot
.62406 .58339 Mdot
.5799 .5108 Mdot
.39701 .01667 Mdot
.45765 .11911 Mdot
.42462 .03811 Mdot
.4158 .03622 Mdot
.55188 .51058 Mdot
.434 .05227 Mdot
.80281 .35843 Mdot
.50982 .11915 Mdot
.45064 .11996 Mdot
.40297 .01619 Mdot
.33753 .15703 Mdot
.44987 .03209 Mdot
.45489 .07251 Mdot
.66976 .45157 Mdot
.60711 .08989 Mdot
.40696 .12307 Mdot
.3779 .02825 Mdot
.42334 .02599 Mdot
.51191 .12101 Mdot
.10625 .23959 Mdot
.4118 .02087 Mdot
.08559 .44796 Mdot
.70735 .35959 Mdot
.67141 .43246 Mdot
.48847 .09658 Mdot
.60732 .50635 Mdot
.42684 .04771 Mdot
.32515 .22464 Mdot
.40758 .02869 Mdot
.48906 .09575 Mdot
.52403 .51424 Mdot
.22508 .26718 Mdot
.73527 .35401 Mdot
.61604 .57793 Mdot
.37062 .01263 Mdot
.43442 .11769 Mdot
.92177 .38962 Mdot
.42442 .11994 Mdot
.50435 .10767 Mdot
.67915 .42321 Mdot
.45994 .08775 Mdot
.08339 .23138 Mdot
.44546 .06128 Mdot
.55741 .50728 Mdot
.05232 .43497 Mdot
.55638 .53564 Mdot
.96799 .40415 Mdot
.89991 .38233 Mdot
.58056 .5052 Mdot
.47885 .1162 Mdot
.50504 .12725 Mdot
.35456 .13541 Mdot
.4174 .04486 Mdot
.68193 .39984 Mdot
.62269 .50311 Mdot
.5875 .55531 Mdot
.47403 .09006 Mdot
.36102 .01796 Mdot
.67117 .44533 Mdot
.51731 .11982 Mdot
.67651 .44204 Mdot
.43281 .03121 Mdot
.32956 .19504 Mdot
.67484 .43465 Mdot
.3838 .0228 Mdot
.57676 .50956 Mdot
.40392 .03448 Mdot
.58702 .55621 Mdot
.59874 .56547 Mdot
.55501 .53608 Mdot
.44428 .03679 Mdot
.35936 .13637 Mdot
.42773 .04608 Mdot
.43067 .05447 Mdot
.63907 .49789 Mdot
.90151 .16602 Mdot
.65407 .48187 Mdot
.06955 .22722 Mdot
.38817 .12735 Mdot
.6915 .36842 Mdot
.20814 .26395 Mdot
.84679 .14523 Mdot
.4955 .1025 Mdot
.44161 .06872 Mdot
.55892 .0711 Mdot
.55632 .51132 Mdot
.5676 .07668 Mdot
.45242 .12247 Mdot
.50393 .11651 Mdot
.54288 .53169 Mdot
.67875 .4137 Mdot
.46513 .04296 Mdot
.47414 .09286 Mdot
.6852 .07819 Mdot
.59529 .50652 Mdot
.41333 .04334 Mdot
.58427 .5598 Mdot
.38775 .12141 Mdot
.55721 .5024 Mdot
.55527 .5103 Mdot
.51216 .12225 Mdot
.44516 .0318 Mdot
.37631 .13226 Mdot
.63142 .49888 Mdot
.47503 .08781 Mdot
.50196 .10896 Mdot
.49843 .09864 Mdot
.63095 .10087 Mdot
.46224 .12726 Mdot
.16416 .47907 Mdot
.77924 .35558 Mdot
.53492 .50957 Mdot
.36343 .12999 Mdot
.77473 .35498 Mdot
.56069 .50325 Mdot
.58953 .56167 Mdot
.45382 .12403 Mdot
.31978 .24221 Mdot
.55822 .07117 Mdot
.45648 .12394 Mdot
.47246 .12636 Mdot
.70837 .0885 Mdot
.22617 .26783 Mdot
.57884 .50485 Mdot
.43828 .05818 Mdot
.52369 .05893 Mdot
.33465 .18472 Mdot
.40221 .02359 Mdot
.38763 .03956 Mdot
.68809 .37173 Mdot
.38435 .0137 Mdot
.38679 .02338 Mdot
.31517 .24931 Mdot
.49362 .12756 Mdot
.61726 .50239 Mdot
.89019 .37947 Mdot
.4065 .1251 Mdot
.32951 .21794 Mdot
.63715 .59254 Mdot
.32404 .22332 Mdot
.5645 .54502 Mdot
.5283 .52043 Mdot
.68171 .39815 Mdot
.41895 .58421 Mdot
.48467 .10337 Mdot
.44731 .03613 Mdot
.50959 .12071 Mdot
.29945 .26028 Mdot
.6762 .44095 Mdot
.57377 .51134 Mdot
.62562 .50174 Mdot
.35343 .1444 Mdot
.54047 .06382 Mdot
.93389 .39367 Mdot
.45888 .03979 Mdot
.36818 .02034 Mdot
.55509 .51112 Mdot
.541 .51968 Mdot
.03168 .42687 Mdot
.44382 .06033 Mdot
.67113 .43524 Mdot
.34399 .14678 Mdot
.65883 .47736 Mdot
.56847 .50552 Mdot
.03474 .42903 Mdot
.49254 .04863 Mdot
.44386 .12662 Mdot
.4902 .04525 Mdot
.93749 .39434 Mdot
.38104 .03259 Mdot
.38053 .01825 Mdot
.6011 .50039 Mdot
.32954 .19958 Mdot
.35898 .13145 Mdot
.0861 .23313 Mdot
.37274 .13092 Mdot
.62052 .58377 Mdot
.48272 .08816 Mdot
.35076 .13716 Mdot
.45736 .12193 Mdot
.09404 .4512 Mdot
.49146 .1091 Mdot
.2012 .49329 Mdot
.2437 .51051 Mdot
.63026 .10132 Mdot
.4656 .09098 Mdot
.32256 .2305 Mdot
.75905 .35293 Mdot
.81525 .13182 Mdot
.45356 .07416 Mdot
.43185 .06599 Mdot
.571 .54861 Mdot
.3815 .12747 Mdot
.33916 .17395 Mdot
.54226 .52425 Mdot
.58309 .08177 Mdot
.63079 .49545 Mdot
.64585 .4936 Mdot
.45722 .11934 Mdot
.41691 .05394 Mdot
.23921 .5096 Mdot
.62462 .50225 Mdot
.33325 .20335 Mdot
.5681 .53861 Mdot
.38154 .02852 Mdot
.50337 .10746 Mdot
.46568 .04385 Mdot
.42028 .04135 Mdot
.44386 .12374 Mdot
.32954 .194 Mdot
.38774 .02251 Mdot
.43085 .03384 Mdot
.50434 .11798 Mdot
.4183 .11891 Mdot
.79292 .35709 Mdot
.49227 .10212 Mdot
.43099 .58915 Mdot
.60241 .50778 Mdot
.48729 .1225 Mdot
.33511 .19669 Mdot
.63843 .49782 Mdot
.42416 .03195 Mdot
.64394 .48877 Mdot
.60301 .50954 Mdot
.48926 .09444 Mdot
.27752 .26858 Mdot
.6771 .39638 Mdot
.49352 .11939 Mdot
.60579 .08952 Mdot
.49919 .1228 Mdot
.75542 .35243 Mdot
.70156 .3642 Mdot
.68023 .39703 Mdot
.42166 .12434 Mdot
.38815 .01227 Mdot
.43004 .12464 Mdot
.4939 .6159 Mdot
.68892 .38217 Mdot
.61053 .57113 Mdot
.3426 .15753 Mdot
.5489 .52087 Mdot
.41438 .05557 Mdot
.49136 .11566 Mdot
.49396 .12435 Mdot
.35465 .14243 Mdot
.65468 .48793 Mdot
.31655 .24553 Mdot
.438 .05451 Mdot
.67732 .4368 Mdot
.70598 .08686 Mdot
.57007 .50791 Mdot
.57242 .54431 Mdot
.63133 .59117 Mdot
.55976 .50516 Mdot
.25983 .2695 Mdot
.51494 .11487 Mdot
.38721 .03711 Mdot
.04717 .43266 Mdot
.32838 .22495 Mdot
.45557 .0843 Mdot
.6837 .0783 Mdot
.32552 .23817 Mdot
.53678 .50556 Mdot
.82668 .36315 Mdot
.54047 .52568 Mdot
.54337 .52933 Mdot
.42051 .05388 Mdot
.35557 .13755 Mdot
.37459 .01941 Mdot
.54448 .52623 Mdot
.35072 .14535 Mdot
.66064 .47235 Mdot
.70372 .36458 Mdot
.38376 .01364 Mdot
.56525 .53691 Mdot
.46469 .07731 Mdot
.37739 .01927 Mdot
.4104 .12407 Mdot
.67648 .44372 Mdot
.38267 .01339 Mdot
.6784 .40751 Mdot
.44473 .07718 Mdot
.46723 .11705 Mdot
.51393 .1236 Mdot
.32616 .21957 Mdot
.48 .12233 Mdot
.4629 .12501 Mdot
.5216 .05664 Mdot
.47594 .12138 Mdot
.50405 .12995 Mdot
.34961 .14367 Mdot
.44884 .1235 Mdot
.00986 .20726 Mdot
.45363 .07359 Mdot
.51356 .11538 Mdot
.67721 .43441 Mdot
.55009 .52508 Mdot
.33815 .16562 Mdot
.51202 .12876 Mdot
.51998 .12911 Mdot
.402 .02191 Mdot
.65028 .60644 Mdot
.66753 .45269 Mdot
.31064 .25249 Mdot
.60806 .56902 Mdot
.42798 .03325 Mdot
.31219 .2527 Mdot
.43882 .05603 Mdot
.67666 .3966 Mdot
.57252 .50602 Mdot
.3907 .03689 Mdot
.50538 .1139 Mdot
.59349 .08425 Mdot
.50635 .12031 Mdot
.49352 .10223 Mdot
.53794 .52584 Mdot
.43499 .11953 Mdot
.94176 .39558 Mdot
.6814 .39335 Mdot
.47135 .09031 Mdot
.3928 .02098 Mdot
.49441 .09753 Mdot
.6293 .58435 Mdot
.38134 .01182 Mdot
.56048 .53327 Mdot
.11133 .24079 Mdot
.66069 .46646 Mdot
.67183 .45334 Mdot
.41945 .04425 Mdot
.40805 .04695 Mdot
.9342 .17863 Mdot
.62387 .5855 Mdot
.50608 .10922 Mdot
.78918 .12127 Mdot
.47312 .12315 Mdot
.51661 .12952 Mdot
.49672 .09829 Mdot
.52937 .51545 Mdot
.14175 .47017 Mdot
.48936 .04547 Mdot
.12033 .24234 Mdot
.5295 .51238 Mdot
.61908 .5052 Mdot
.57132 .54849 Mdot
.29175 .53045 Mdot
.44418 .05969 Mdot
.43535 .03175 Mdot
.56583 .5466 Mdot
.20081 .49376 Mdot
.69417 .12457 Mdot
.60988 .50788 Mdot
.42189 .02158 Mdot
.49478 .12875 Mdot
.42373 .06093 Mdot
.47451 .12863 Mdot
.44663 .03914 Mdot
.56398 .515 Mdot
.68173 .40519 Mdot
.5316 .52017 Mdot
.71413 .13193 Mdot
.373 .01568 Mdot
.63536 .5021 Mdot
.37928 .01848 Mdot
.55121 .51937 Mdot
.92756 .17648 Mdot
.64756 .48909 Mdot
.46023 .03629 Mdot
.32641 .22696 Mdot
.55207 .06968 Mdot
.39972 .57611 Mdot
.40281 .03547 Mdot
.95219 .18596 Mdot
.38125 .02724 Mdot
.60913 .04682 Mdot
.72458 .13639 Mdot
.58313 .50019 Mdot
.43929 .12149 Mdot
.55039 .50994 Mdot
.44091 .06039 Mdot
.43445 .05192 Mdot
.48178 .11618 Mdot
.71827 .35615 Mdot
.44954 .03188 Mdot
.60072 .08789 Mdot
.56845 .54667 Mdot
.35916 .13241 Mdot
.5412 .52544 Mdot
.66395 .462 Mdot
.51493 .12819 Mdot
.68082 .39546 Mdot
.42897 .06667 Mdot
.50365 .12453 Mdot
.67999 .41207 Mdot
.63693 .49122 Mdot
.58591 .5043 Mdot
.79552 .35685 Mdot
.5743 .54945 Mdot
.49437 .11309 Mdot
.74503 .14512 Mdot
.70625 .35901 Mdot
.12612 .46317 Mdot
.61127 .50336 Mdot
.3282 .20447 Mdot
.50931 .10592 Mdot
.5897 .03823 Mdot
.35929 .55932 Mdot
.42395 .58662 Mdot
.40112 .0178 Mdot
.66633 .46863 Mdot
.54781 .50213 Mdot
.68198 .39178 Mdot
.58828 .085 Mdot
.40092 .03946 Mdot
.47564 .09302 Mdot
.61057 .50025 Mdot
.57161 .50445 Mdot
.4759 .09997 Mdot
.4376 .02965 Mdot
.30778 .25313 Mdot
.36075 .00839 Mdot
.64834 .06329 Mdot
.47337 .11695 Mdot
.59313 .5654 Mdot
.40319 .04773 Mdot
.03141 .42748 Mdot
.66867 .46848 Mdot
.56289 .54111 Mdot
.42121 .02312 Mdot
.65978 .47249 Mdot
.60681 .50779 Mdot
.48055 .1131 Mdot
.58008 .509 Mdot
.96553 .19063 Mdot
.78219 .11891 Mdot
.71024 .35857 Mdot
.33355 .18729 Mdot
.56339 .51508 Mdot
.12579 .24505 Mdot
.44182 .03059 Mdot
.16217 .47766 Mdot
.45695 .12112 Mdot
.09465 .45122 Mdot
.37797 .0249 Mdot
.24837 .51307 Mdot
.43581 .1255 Mdot
.35878 .01746 Mdot
.57724 .50602 Mdot
.33273 .1906 Mdot
.64372 .494 Mdot
.66671 .47162 Mdot
.53494 .50404 Mdot
.44065 .06735 Mdot
.5116 .11115 Mdot
.67618 .39593 Mdot
.45986 .07855 Mdot
.54106 .52402 Mdot
.76377 .3538 Mdot
.53123 .51029 Mdot
.55879 .54066 Mdot
.44374 .06426 Mdot
.45741 .03382 Mdot
.51687 .11184 Mdot
.44584 .07269 Mdot
.39822 .03354 Mdot
.64055 .49312 Mdot
.09629 .23591 Mdot
.51499 .13051 Mdot
.66205 .46951 Mdot
.61988 .49843 Mdot
.5792 .55621 Mdot
.55644 .5388 Mdot
.82581 .1362 Mdot
.64786 .49168 Mdot
.37227 .01651 Mdot
.04457 .43212 Mdot
.64304 .49515 Mdot
.71918 .35839 Mdot
.48983 .11319 Mdot
.42338 .04162 Mdot
.43685 .12577 Mdot
.3365 .17591 Mdot
.25808 .2699 Mdot
.03182 .42752 Mdot
.43093 .02892 Mdot
.71231 .36015 Mdot
.39424 .01438 Mdot
.38664 .02864 Mdot
.40596 .02338 Mdot
.49613 .10559 Mdot
.54187 .50886 Mdot
.51221 .05348 Mdot
.48581 .09824 Mdot
.5246 .12187 Mdot
.89231 .16289 Mdot
.63125 .49678 Mdot
.52034 .13001 Mdot
.58401 .08043 Mdot
.4314 .12347 Mdot
.53401 .50914 Mdot
.39082 .12119 Mdot
.44192 .12472 Mdot
.46912 .12559 Mdot
.2277 .26594 Mdot
.40559 .04741 Mdot
.38174 .01091 Mdot
.35311 .1439 Mdot
.42688 .03202 Mdot
.58128 .07987 Mdot
.46502 .0894 Mdot
.07075 .44161 Mdot
.45996 .07367 Mdot
.51254 .05868 Mdot
.54683 .53355 Mdot
.65459 .48019 Mdot
.45199 .06745 Mdot
.81924 .36058 Mdot
.48426 .09395 Mdot
.41623 .02116 Mdot
.53085 .06324 Mdot
.58773 .08198 Mdot
.58818 .50795 Mdot
.45088 .12395 Mdot
.40482 .12618 Mdot
.41229 .04328 Mdot
.69518 .08309 Mdot
.2829 .26537 Mdot
.43588 .05499 Mdot
.58515 .5559 Mdot
.39893 .01459 Mdot
.66172 .48208 Mdot
.55205 .50798 Mdot
.56118 .54162 Mdot
.57086 .51076 Mdot
.46916 .12419 Mdot
.48186 .08808 Mdot
.51748 .05956 Mdot
.63907 .48895 Mdot
.52831 .01255 Mdot
.42965 .11924 Mdot
.67089 .44405 Mdot
.43439 .05472 Mdot
.61945 .49982 Mdot
.3566 .13773 Mdot
.56106 .5405 Mdot
.39683 .12551 Mdot
.45661 .12476 Mdot
.53158 .06314 Mdot
.4258 .05064 Mdot
.51475 .12327 Mdot
.68616 .37586 Mdot
.43899 .03006 Mdot
.64182 .4979 Mdot
.7833 .35578 Mdot
.38991 .02003 Mdot
.49298 .11217 Mdot
.45694 .08158 Mdot
.67595 .42473 Mdot
.68948 .37561 Mdot
.13686 .24823 Mdot
.51773 .12384 Mdot
.48411 .11066 Mdot
.67218 .45025 Mdot
.39137 .02232 Mdot
.64975 .49024 Mdot
.49763 .09995 Mdot
.63473 .4926 Mdot
.42474 .02673 Mdot
.52465 .12949 Mdot
.42671 .04331 Mdot
.66613 .46501 Mdot
.67565 .40515 Mdot
.45958 .07647 Mdot
.32873 .19926 Mdot
.41753 .58317 Mdot
.42202 .05139 Mdot
.80206 .35791 Mdot
.6696 .46587 Mdot
.59832 .56616 Mdot
.60125 .50067 Mdot
.3322 .17904 Mdot
.34093 .15308 Mdot
.08844 .23377 Mdot
.52779 .50279 Mdot
.39352 .121 Mdot
.43314 .05303 Mdot
.53113 .5223 Mdot
.37346 .01346 Mdot
.41984 .02734 Mdot
.39955 .03627 Mdot
.40962 .04519 Mdot
.33367 .1766 Mdot
.57697 .50341 Mdot
.35568 .01202 Mdot
.40363 .02217 Mdot
.46558 .11782 Mdot
.64702 .48863 Mdot
.60637 .57157 Mdot
.57568 .54742 Mdot
.67724 .43313 Mdot
.68547 .38602 Mdot
.78063 .35453 Mdot
.30444 .53585 Mdot
.47105 .09594 Mdot
.21007 .49771 Mdot
.55979 .07478 Mdot
.94773 .39782 Mdot
.67656 .44062 Mdot
.58204 .55825 Mdot
.57867 .50935 Mdot
.5644 .50901 Mdot
.63205 .10074 Mdot
.57934 .08088 Mdot
.47831 .12423 Mdot
.34847 .14765 Mdot
.40567 .04194 Mdot
.82246 .36238 Mdot
.45948 .03584 Mdot
.35898 .01309 Mdot
.40956 .02647 Mdot
.43674 .06995 Mdot
.44741 .03859 Mdot
.43521 .06247 Mdot
.44644 .07744 Mdot
.42092 .02784 Mdot
.67858 .40304 Mdot
.67048 .43651 Mdot
.10853 .45615 Mdot
.54498 .51836 Mdot
.36212 .13487 Mdot
.53819 .51242 Mdot
.4189 .04252 Mdot
.66794 .4553 Mdot
.67488 .11734 Mdot
.5137 .12604 Mdot
.66994 .46716 Mdot
.46949 .11822 Mdot
.37871 .02425 Mdot
.66382 .45981 Mdot
.24263 .51027 Mdot
.74576 .35289 Mdot
.5235 .06026 Mdot
.52695 .51541 Mdot
.8552 .37093 Mdot
.55578 .07222 Mdot
.52982 .50293 Mdot
.66025 .46888 Mdot
.54515 .52969 Mdot
.44879 .06323 Mdot
.46145 .60253 Mdot
.95234 .18641 Mdot
.40739 .02418 Mdot
.45481 .03345 Mdot
.63054 .09924 Mdot
.41728 .05263 Mdot
.4407 .03548 Mdot
.42484 .02606 Mdot
.51741 .12495 Mdot
.42419 .1219 Mdot
.3181 .24569 Mdot
.435 .02748 Mdot
.67552 .43668 Mdot
.48259 .09513 Mdot
.66264 .46512 Mdot
.45126 .11752 Mdot
.83737 .36521 Mdot
.49448 .04833 Mdot
.43856 .1222 Mdot
.63881 .59448 Mdot
.5535 .51867 Mdot
.34071 .16244 Mdot
.32998 .18903 Mdot
.1858 .25901 Mdot
.85148 .1466 Mdot
.41298 .02698 Mdot
.55661 .53652 Mdot
.59195 .50682 Mdot
.43718 .03755 Mdot
.54123 .53036 Mdot
.59187 .50466 Mdot
.68589 .38865 Mdot
.67141 .46118 Mdot
.49154 .11892 Mdot
.4902 .12659 Mdot
.52911 .51698 Mdot
.534 .51548 Mdot
.09589 .45174 Mdot
.63955 .59753 Mdot
.0552 .43664 Mdot
.62813 .49325 Mdot
.61407 .50509 Mdot
.62725 .49917 Mdot
.63167 .10024 Mdot
.5623 .51334 Mdot
.70658 .36121 Mdot
.51242 .00533 Mdot
.53947 .51568 Mdot
.24637 .2692 Mdot
.45246 .04009 Mdot
.80364 .12777 Mdot
.14336 .24883 Mdot
.61654 .09327 Mdot
.95842 .18794 Mdot
.42329 .05986 Mdot
.33807 .16678 Mdot
.40302 .04133 Mdot
.40022 .57674 Mdot
.70195 .36248 Mdot
.58195 .50656 Mdot
.50131 .04985 Mdot
.00056 .20373 Mdot
.44653 .0652 Mdot
.38837 .02171 Mdot
.40385 .11932 Mdot
.88523 .37765 Mdot
.52257 .06068 Mdot
.47563 .04167 Mdot
.55627 .53324 Mdot
.4383 .0627 Mdot
.47896 .11588 Mdot
.325 .21856 Mdot
.41375 .04808 Mdot
.65726 .47929 Mdot
.61396 .50404 Mdot
.3436 .16247 Mdot
.32981 .21592 Mdot
.63257 .10033 Mdot
.51534 .11666 Mdot
.62297 .58098 Mdot
.33222 .18661 Mdot
.18762 .4882 Mdot
.43842 .06818 Mdot
.44234 .06637 Mdot
.56553 .51372 Mdot
.9244 .17481 Mdot
.375 .02821 Mdot
.5503 .53365 Mdot
.3287 .21583 Mdot
.55706 .50568 Mdot
.48958 .04765 Mdot
.54223 .52858 Mdot
.0442 .43194 Mdot
.39232 .02471 Mdot
.3244 .22136 Mdot
.67999 .4168 Mdot
.34309 .14984 Mdot
.4795 .08706 Mdot
.42894 .11889 Mdot
.3966 .12527 Mdot
.67548 .43286 Mdot
.6975 .3647 Mdot
.22492 .2676 Mdot
.52692 .50619 Mdot
.47181 .04051 Mdot
.00957 .20689 Mdot
.33027 .5469 Mdot
.77165 .35428 Mdot
.45629 .08001 Mdot
.46253 .07665 Mdot
.57345 .55002 Mdot
.53778 .52552 Mdot
.41564 .02374 Mdot
.46846 .04314 Mdot
.50351 .12374 Mdot
.50594 .10836 Mdot
.42656 .04348 Mdot
.55477 .50265 Mdot
.87076 .37408 Mdot
.48403 .04386 Mdot
.32585 .21754 Mdot
.89635 .16473 Mdot
.50736 .13077 Mdot
.66113 .47884 Mdot
.42836 .1217 Mdot
.27658 .26851 Mdot
.68088 .11885 Mdot
.48205 .11442 Mdot
.17596 .25835 Mdot
.52218 .12742 Mdot
.44833 .03079 Mdot
.35425 .13861 Mdot
.45113 .59762 Mdot
.6855 .38213 Mdot
.38697 .01472 Mdot
.66311 .48034 Mdot
.33261 .2114 Mdot
.48239 .11456 Mdot
.67424 .40756 Mdot
.34704 .00705 Mdot
.59767 .56555 Mdot
.63551 .05741 Mdot
.60324 .50639 Mdot
.55529 .0712 Mdot
.49918 .1119 Mdot
.46422 .12014 Mdot
.48011 .11578 Mdot
.37417 .12779 Mdot
.71761 .35494 Mdot
.40374 .04543 Mdot
.65073 .60333 Mdot
.40329 .04527 Mdot
.67953 .11925 Mdot
.67683 .39796 Mdot
.39731 .04268 Mdot
.05253 .22151 Mdot
.68301 .39265 Mdot
.47699 .09768 Mdot
.34262 .15924 Mdot
.72268 .35709 Mdot
.5454 .51688 Mdot
.72564 .09552 Mdot
.55149 .52915 Mdot
.32874 .20808 Mdot
.5635 .50741 Mdot
.52685 .51281 Mdot
.66211 .47069 Mdot
.41004 .03569 Mdot
.55061 .51182 Mdot
.51599 .05504 Mdot
.45898 .07231 Mdot
.41712 .03021 Mdot
.36251 .13307 Mdot
.18127 .48521 Mdot
.51743 .12954 Mdot
.61107 .09326 Mdot
.39167 .57256 Mdot
.41504 .0417 Mdot
.5707 .54989 Mdot
.35056 .01168 Mdot
.55381 .52923 Mdot
.59834 .56208 Mdot
.3052 .25819 Mdot
.68554 .3838 Mdot
.39082 .03617 Mdot
.40091 .03949 Mdot
.81947 .36125 Mdot
.42537 .0262 Mdot
.72414 .13654 Mdot
.68571 .38582 Mdot
.52353 .06124 Mdot
.71425 .35937 Mdot
.40776 .04603 Mdot
.59685 .5028 Mdot
.32578 .23375 Mdot
.58907 .08282 Mdot
.38715 .1256 Mdot
.54213 .50566 Mdot
.52628 .50784 Mdot
.13756 .46834 Mdot
.56266 .50262 Mdot
.67384 .45876 Mdot
.03206 .42738 Mdot
.37977 .03014 Mdot
.49354 .09542 Mdot
.42672 .05015 Mdot
.53028 .50626 Mdot
.46987 .11824 Mdot
.47877 .08916 Mdot
.51787 .12675 Mdot
.33037 .20903 Mdot
.57229 .50137 Mdot
.64149 .4911 Mdot
.52664 .51313 Mdot
.43065 .06678 Mdot
.18067 .25958 Mdot
.59306 .50084 Mdot
.34038 .15241 Mdot
.66814 .47442 Mdot
.39647 .04489 Mdot
.48014 .6099 Mdot
.6949 .36627 Mdot
.59043 .08378 Mdot
.58609 .55917 Mdot
.47077 .08861 Mdot
.69073 .12426 Mdot
.37565 .02068 Mdot
.3343 .16438 Mdot
.36982 .12778 Mdot
.59373 .50985 Mdot
.32562 .22083 Mdot
.6761 .44144 Mdot
.67982 .41361 Mdot
.40127 .0322 Mdot
.52713 .51238 Mdot
.48168 .09396 Mdot
.36587 .13575 Mdot
.40921 .04338 Mdot
.41089 .12232 Mdot
.58611 .50556 Mdot
.3741 .01177 Mdot
.60244 .50523 Mdot
.70114 .36089 Mdot
.6396 .10239 Mdot
.60976 .49907 Mdot
.53391 .50435 Mdot
.60616 .57401 Mdot
.42966 .12328 Mdot
.4469 .12011 Mdot
.48455 .11011 Mdot
.62411 .50291 Mdot
.50749 .1201 Mdot
.58223 .5058 Mdot
.51924 .12952 Mdot
.44718 .07159 Mdot
.18699 .25922 Mdot
.1392 .24796 Mdot
.3076 .25938 Mdot
.87934 .3762 Mdot
.42328 .05676 Mdot
.46507 .11734 Mdot
.60714 .56966 Mdot
.44302 .12007 Mdot
.33129 .21142 Mdot
.45159 .12486 Mdot
.56047 .07349 Mdot
.4566 .08045 Mdot
.27242 .26838 Mdot
.57706 .50039 Mdot
.57557 .50852 Mdot
.53365 .06323 Mdot
.67283 .43075 Mdot
.67751 .42002 Mdot
.14274 .25021 Mdot
.37703 .12813 Mdot
.38171 .02938 Mdot
.56206 .51304 Mdot
.43866 .02823 Mdot
.67805 .40302 Mdot
.51706 .11794 Mdot
.44468 .02979 Mdot
.88446 .15934 Mdot
.5698 .51011 Mdot
.73497 .35506 Mdot
.64212 .10583 Mdot
.60611 .09094 Mdot
.2155 .49941 Mdot
.54896 .5182 Mdot
.80892 .12989 Mdot
.58769 .55977 Mdot
.58812 .55728 Mdot
.32836 .21225 Mdot
.63413 .50068 Mdot
.6244 .58238 Mdot
.6431 .59604 Mdot
.38868 .03246 Mdot
.54294 .52877 Mdot
.42249 .02443 Mdot
.40139 .02816 Mdot
.57806 .08079 Mdot
.49005 .12893 Mdot
.41857 .02956 Mdot
.32628 .22839 Mdot
.67815 .40028 Mdot
.26367 .26918 Mdot
.60916 .49948 Mdot
.75942 .10947 Mdot
.35947 .14075 Mdot
.65058 .4854 Mdot
.31754 .2438 Mdot
.34641 .15347 Mdot
.48943 .12357 Mdot
.65394 .10889 Mdot
.42699 .03076 Mdot
.31091 .25101 Mdot
.33256 .18398 Mdot
.60214 .50459 Mdot
.60542 .49954 Mdot
.48149 .11033 Mdot
.38654 .03222 Mdot
.45855 .12425 Mdot
.33526 .19495 Mdot
.67014 .4672 Mdot
.43647 .06434 Mdot
.5512 .53792 Mdot
.54317 .06613 Mdot
.47359 .08501 Mdot
.68285 .07751 Mdot
.17407 .25641 Mdot
.53324 .51839 Mdot
.48671 .11157 Mdot
.097 .23671 Mdot
.65449 .48356 Mdot
.71255 .1327 Mdot
.57623 .50805 Mdot
.64304 .49247 Mdot
.49427 .04824 Mdot
.08025 .44617 Mdot
.01385 .20886 Mdot
.38884 .02727 Mdot
.41397 .03104 Mdot
.48795 .11887 Mdot
.55216 .52066 Mdot
.29785 .53316 Mdot
.43326 .06713 Mdot
.21589 .26482 Mdot
.44124 .06645 Mdot
.64506 .06211 Mdot
.46719 .04309 Mdot
.64917 .49489 Mdot
.52701 .12484 Mdot
.66812 .46174 Mdot
.48468 .10409 Mdot
.32565 .22191 Mdot
.44391 .06784 Mdot
.68416 .39286 Mdot
.38304 .0167 Mdot
.48056 .09247 Mdot
.70244 .36617 Mdot
.32599 .23314 Mdot
.35206 .14963 Mdot
.20951 .26488 Mdot
.4293 .06656 Mdot
.53667 .51953 Mdot
.66441 .47748 Mdot
.32036 .23359 Mdot
.05154 .43463 Mdot
.20801 .49596 Mdot
.50264 .12989 Mdot
.40631 .04016 Mdot
.62875 .49296 Mdot
.32898 .22531 Mdot
.36018 .01888 Mdot
.64249 .59878 Mdot
.60716 .57457 Mdot
.53646 .06433 Mdot
.36588 .00783 Mdot
.82908 .13797 Mdot
.49067 .09401 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo000Voooooo7o00002Oooool002Ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Pooooo`Oo00001_ooool00ol0003o
ooooooooo`0Hooooo`;o00004oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0DOooool;o`00023ooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`1Booooo`go00007_ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo05?ooooo4?l0000Mooooo`03o`000?oooooooooo06[ooooo00?o0000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0EOoooolAo`0001_ooooo00?o00000000
0?ooool0JOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Gooooo`Co
000000<00000o`000?l000002ol0000Jooooo`80000000?o0000ooooooooool0IOooool00ol0003o
ooooooooo`07ooooo`009_ooool2o`0005Sooooo5Ol0000Looooo`03o`000?oooooooooo067ooooo
0_l00009ooooo`009_ooool00ol0003oooooooooo`1Iooooo`co000000?oooooo`000?l000001_l0
000Kooooo`03o`000000003o0000067ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0F_ooool:o`0000;ooooo00@00000ooooool0000000001_l0001mooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo05cooooo2Ol00008ooooo`?o000000D00000
o`000?l0003o00000000000Hooooo`?o0000GOooool00ol0003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`1Nooooo`So00002oooool6o`0001[ooooo00<00000ooooooooool0FOooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Pooooo`Oo00003?ooool7o`00
01Wooooo0_l0001Hooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo063o
oooo00<00000o`000?l000001Ol0000>ooooo`0300000?l0003o000000?o00006?ooool3o`0005Ko
oooo00?o0000ooooooooool01oooool002Kooooo0_l0001Sooooo`So00003oooool6o`0000030000
0?oooooooooo01Gooooo0ol0001Booooo`;o00002Oooool002Kooooo00?o0000ooooooooool0I?oo
ool7o`00017ooooo1Ol0000Hooooo`0300000?l0003ooooo057ooooo00?o0000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0IOooool7o`0001?ooooo1Ol0000Gooooo`03o`000?oooooo
000004oooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Ioooool5o`00
01Gooooo00H00000o`000?l0003o0000ooooool0000Gooooo`0300000?oooooooooo04cooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0J?ooool7o`0001Gooooo00@00000
o`000?l0000000000_l0000Fooooo`?o0000B_ooool00ol0003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`1Yooooo`Go000000<00000o`000?l000005oooool5o`0001Kooooo0_l00018
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo06_ooooo1ol0000Hoooo
o`Co00005oooool3o`0004Gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0KOooool6o`0001[ooooo0ol000000`00003oooooooooo`0Dooooo`;o000000<00000oooooooo
ool0@Oooool00ol0003oooooooooo`07ooooo`009_ooool2o`0006kooooo2?l0000Kooooo`Co0000
5_ooool2o`00043ooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`1_ooooo`;o000000?o
ooooo`000?l000000_l0000Mooooo`0400000?l0003o0000o`0001Gooooo0P00000oooooo`03o`00
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo06oooooo2?l000000`00003ooooooooo
o`0Jooooo`Co00006?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo073ooooo2Ol0000Nooooo`Go00005Oooool3o`0003Wooooo00?o0000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0L?ooool:o`00023ooooo0ol0000Foooo
o`;o0000>?ooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Cooooo00Co0000oooooooo
oooooooo1Ol00004ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooool000000_ooool00`00
003o0000o`000003o`000003ooooool0003o000000;o000000@00000o`000?l0003o00008_ooool3
o`0001Kooooo0_l0000eooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Iooooo`Ko000000<0
0000o`000?l000006_l0000Sooooo`?o00005oooool00ol000000000o`00000aooooo`03o`000?oo
oooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?oo
ool2o`0005Sooooo9_l0000Uooooo`?o00005oooool00ol000000000ooooo`0/ooooo`?o00002Ooo
ool001;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05Cooooo1ol000000oooool00000ooooo`02o`00000500000?ooooooooooooooool00000
0oooool01_l000000000o`000?oooooo0000ooooo`ko000000<00000ooooooooool09_ooool3o`00
01Gooooo0ol0000]ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05;ooooo2?l0000K
ooooo`?o000000@00000o`000?oooooo0000:oooool3o`0001Oooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`1Aooooo`Go000000<00000ooooooooool0
D_ooool00ol000000000ooooo`0Eooooo`?o00009oooool00ol0003oooooooooo`07ooooo`004ooo
ool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo053ooooo1?l0001Iooooo`0300000?l0
003o000001Gooooo00<00000o`000?ooool09Oooool00ol0003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`1?ooooo`0300000?l0003o000000;o0000G?ooool2o`0001Gooooo0ol0000S
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04oooooo1?l0001Ooooo
o`03o`000?ooool0000001Gooooo00<00000ooooooooool08?ooool00ol0003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`1>ooooo`0400000?l0003o0000o`0006Cooooo00<00000oooo
ooooool04oooool2o`0001oooooo00?o0000ooooooooool01oooool002Kooooo0_l0001?ooooo`?o
0000Voooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo04gooooo1?l00020ooooo`03o`00
0000003o000001Wooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0COoo
ool3o`0008Cooooo0ol0000Fooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo04gooooo00?o000000000?ooool0Q_ooool2o`0001Gooooo00?o0000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool0COooool3o`0008Wooooo1?l0000@ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo04gooooo0_l0002=ooooo`?o00003_ooool00ol0003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1=ooooo`;o0000Soooool00`00003o0000
ooooo`0<ooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000COooool2o`00000300000?oo
oooooooo093ooooo0ol00008ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0C?ooool2
o`0009Kooooo0_l000000`00003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo04cooooo0ol0002Hooooo`0300000?oooooooooo00?ooooo00?o0000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0C?ooool2o`0009_ooooo0P000002ooooo`03
o`000?oooooooooo00Oooooo000Vooooo`;o0000COooool2o`0009kooooo00<00000o`000?ooool0
2?ooool002Kooooo1?l0001;ooooo`03o`000000003ooooo09kooooo00?o0000ooooooooool01ooo
ool002Kooooo00Oo0000oooooooooooooooo00000?oooooo000004Oooooo00<00000o`000?l00000
Woooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`04ooooo`0400000?l0
003o0000o`0004?ooooo0_l0002Pooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o00002Ooo
ool3o`00043ooooo0_l0002Oooooo`;o00002Oooool002Kooooo00?o0000ooooooooool02_ooool3
o`0003kooooo0_l0002Pooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
00cooooo00?o0000ooooool000000_l0000jooooo`;o0000X?ooool00ol0003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`0Aooooo`;o000000<00000ooooooooool0=?ooool3o`000:3o
oooo00?o0000ooooooooool01oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0ol00004ooooo`03o`000?oooooooooo01Cooooo0ol0000booooo`Co0000X?ooool00ol0003ooooo
ooooo`07ooooo`004_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool5o`0002kooooo0ol0002Qooooo`03o`000?oooooooooo00Oooooo
000Booooo`04o`000?ooooooooooo`0000Oooooo1Ol00004ooooo`03o`000?oooooooooo01[ooooo
00@00000o`000?l0003o0000:oooool3o`000:7ooooo00?o0000ooooooooool01oooool001;ooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00005ooooo`;o00007_ooool3o`00
000300000?l0003ooooo02Cooooo00@00000o`000?l0003o0000X?ooool3o`0000Wooooo000Boooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0P
ooooo`0300000?l0003o000000?o00008?ooool01000003o0000o`000?l0002Sooooo`03o`000?oo
oooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Wooooo0_l00005ooooo`03o`000?oo
oooooooo02Gooooo0ol000000`00003o0000o`00000Iooooo`Co000000<00000ooooooooool0X_oo
ool00ol0003oooooooooo`07ooooo`004oooool2o`0000_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooo000000Co000000?oooooo`000?ooool04Oooool3
o`000003ooooool0003ooooo0:Cooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0;_ooool00`00003o0000ooooo`05o`000008ooooool0003o0000ooooool0003oooooo`00
00000007o`000:Sooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0<o`000:_ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool2o`000>gooooo0_l00009oooo
o`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOoo
ool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool000Oo
oooo0ol0000Looooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool000Sooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo01_ooooo0_l0003]ooooo`;o00002Oooool000Sooooo0_l0000L
ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool000Oooooo0_l000000ooo
oooo0000o`00000Jooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07
ooooo`009_ooool2o`000>gooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03
o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0ZOooool00ol0003oooooo`00000?o`0003;ooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Y_ooool00`00003o0000o`000006
o`0000Kooooo00?o0000ooooool000001Ol000000`00003o0000ooooo`0]ooooo`03o`000?oooooo
oooo00Oooooo000Cooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0
003oooooooooo`2Uooooo`Go00005?ooool7o`00000300000?oooooooooo02Gooooo00?o0000oooo
ooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0Xoooool4o`0001gooooo1?l000000`00003oooooooooo`0R
ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0:?ooooo0_l000000`00003ooooooooo
o`0Oooooo`Co000000?ooooo00000?ooool07oooool00ol0003oooooooooo`07ooooo`004_ooool0
1?l0003oooooooooool00007ooooo`Co00001Oooool2o`000:?ooooo0_l000000`00003ooooooooo
o`0Uooooo`?o000000<00000ooooooooool06Oooool3o`0000Wooooo000Booooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Qooooo`0300000?l0
003o000002cooooo1?l0000Iooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Pooooo`?o0000<?oo
ool00`00003o0000o`000002000001Gooooo00?o0000ooooooooool01oooool001?ooooo0_l0000:
ooooo`;o00001Oooool00ol0003oooooooooo`2Pooooo`0300000?l0003o000003?ooooo1?l00000
0`00003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
0:3ooooo0ol0000gooooo`?o00004?ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`2Oooooo`?o0000>_ooool01000003o0000o`000?l0000=ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo09oooooo0ol0000mooooo`Co000000<00000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`009_ooool2o`000:3ooooo0_l00013ooooo`;o0000
1_ooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo09oooooo0ol00015ooooo`;o00001?oo
ool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2Oooooo`?o0000A_ooool3
o`00000300000?oooooo000000Wooooo000Vooooo`03o`000000003ooooo09oooooo0_l0001<oooo
o`0300000?oooooooooo00Oooooo000Vooooo`;o000000?oooooo`000?l00000W?ooool3o`0004co
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool00_ooool2o`0009[ooooo
00<00000o`000?l00000C?ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`?o000000<00000ooooooooool0U_ooool2o`0004cooooo00?o0000ooooooooool01ooo
ool002Kooooo0_l00007ooooo`?o0000UOooool3o`0004_ooooo0_l00009ooooo`009_ooool00ol0
003oooooooooo`09ooooo`?o0000T_ooool3o`0004cooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooo`00002?ooooo`;o0000COooool00ol0003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0>ooooo`?o0000SOooool2o`0004gooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool04Oooool2o`0008[ooooo0ol0
001=ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo01?ooooo0ol00000
0`00003oooooooooo`24ooooo`?o0000COooool00ol0003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`0Fooooo`?o0000Q?ooool3o`0004gooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool06Oooool00`00003o0000o`000020ooooo`?o000000<00000oooooooo
ool0Boooool00ol0003oooooooooo`07ooooo`009_ooool2o`0001cooooo00?o0000ooooooooool0
O_ooool3o`0004gooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`0Nooooo`;o0000O?oo
ool3o`0004kooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool08Oooool2
o`00000300000?oooooooooo07Gooooo0ol0001?ooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Loooool01000003o0000o`000?l0001?
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0Koooool2000000?o0000D?ooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0:?ooool3o`0006co
oooo00<00000o`000?l000000_l0001Aooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
02[ooooo0ol0001Yooooo`Ko0000DOooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool2o`0002kooooo00?o0000
ooooool00000H_ooool9o`00053ooooo0ol00009ooooo`004_ooool01?l0003oooooooooool00008
ooooo`?o00001Oooool00ol0003oooooooooo`0_ooooo`?o0000D_ooool01?l0003ooooooooooooo
ool@o`00000300000?oooooooooo05;ooooo00?o0000ooooooooool01oooool001;ooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
<_ooool2o`0004Kooooo00?o0000ooooool000006_l0001Fooooo`03o`000?oooooooooo00Oooooo
000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo03Gooooo0_l00013ooooo`_o000000<00000o`000?l000002ol000000`00003o
ooooooooo`1Gooooo`03o`000?oooooooooo00Oooooo000Cooooo`;o00002Oooool3o`0000Gooooo
00?o0000ooooooooool0=_ooool4o`00043ooooo4Ol000001@00003o0000ooooool00000000005go
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0>Oooool2o`0003oooooo
00<00000o`000?l000002_l0001Vooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0?Oooool7o`00000300000?oooooooooo06Oooooo00?o
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0?_ooool2o`0003gooooo1_l0001Z
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000@_ooool2o`0003_ooooo1_l0001Xoooo
o`;o00002Oooool002Kooooo00?o0000ooooooooool0@oooool00ol0003oooooo`00000iooooo`?o
000000<00000o`000?l00000J?ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`15ooooo`;o0000>_ooool5o`0006Oooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0B?ooool2o`0003Sooooo1Ol0001Vooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo04[ooooo00<00000ooooooooool0=_ooool5o`0006Gooooo00?o0000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0C?ooool01?l000000000o`000?l0000e
ooooo`Go0000Hoooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo03Gooooo1?l0001Rooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o
0000D_ooool200000003o`000?oooooooooo03;ooooo0ol000000`00003oooooooooo`1Nooooo`;o
00002Oooool002Kooooo00?o0000ooooooooool0Doooool3o`00000300000?oooooooooo033ooooo
1Ol0001Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool0<_ooool3o`00000300000?oooooooooo05cooooo00?o0000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0FOooool00ol000000000ooooo`0aooooo`Co0000G?ooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo
033ooooo0ol000000`00003oooooooooo`1Iooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool0<?ooool2o`00000300000?oooooooooo05So
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Goooool3o`0002oooooo
0ol0001Iooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo06;ooooo0_l0
000^ooooo`0400000?l0003o0000o`0005Oooooo00?o0000ooooooooool01oooool002Kooooo0_l0
001Uooooo`03o`000000003ooooo02gooooo0ol0001Eooooo`;o00002Oooool002Kooooo00?o0000
ooooooooool0Ioooool00ol0003oooooooooo`0[ooooo`?o0000EOooool00ol0003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo02[ooooo0ol0001Doooo
o`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo06cooooo0_l0000Zooooo`;o
000000<00000ooooooooool0D?ooool00ol0003oooooooooo`07ooooo`007_ooool3o`0000Gooooo
00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Xooooo`03o`000000003ooooo057ooooo
00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool04?ooool00ol000000000oooo
o`0Jooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`07ooooo`007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo0ol0000;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo00CooooolOl00009oooo
o`007oooool00ol0003oooooooooo`3nooooo`007_ooool2o`000?oooooo0Oooool001oooooo00?o
0000ooooooooool0o_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.158908, -0.161707, \
0.00416367, 0.00673696}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.35241 .57493 Mdot
.5736 .55243 Mdot
.53726 .52629 Mdot
.5401 .0345 Mdot
.64463 .09698 Mdot
.6786 .09171 Mdot
.63261 .09655 Mdot
.3821 .58912 Mdot
.36234 .58794 Mdot
.32491 .56799 Mdot
.40154 .02452 Mdot
.53065 .52209 Mdot
.43771 .06728 Mdot
.60371 .60663 Mdot
.48352 .61108 Mdot
.30496 .25636 Mdot
.38517 .59062 Mdot
.63457 .10133 Mdot
.49346 .57272 Mdot
.57151 .07422 Mdot
.62997 .60491 Mdot
.27207 .5429 Mdot
.32695 .56886 Mdot
.35085 .58181 Mdot
.63697 .60328 Mdot
.42315 .61282 Mdot
.55626 .05466 Mdot
.39861 .02892 Mdot
.6141 .06366 Mdot
.04027 .23507 Mdot
.91194 .18631 Mdot
.9305 .39178 Mdot
.59061 .07054 Mdot
.63346 .49055 Mdot
.73433 .11392 Mdot
.7053 .1205 Mdot
.61027 .08156 Mdot
.30859 .56646 Mdot
.45016 .55683 Mdot
.33193 .18031 Mdot
.57342 .5524 Mdot
.46761 .08599 Mdot
.40348 .54088 Mdot
.53294 .52494 Mdot
.405 .02527 Mdot
.27066 .54775 Mdot
.04658 .21903 Mdot
.52478 .5024 Mdot
.40361 .59815 Mdot
.91028 .16942 Mdot
.68595 .1177 Mdot
.22235 .52788 Mdot
.39287 .02289 Mdot
.40058 .03457 Mdot
.61763 .4955 Mdot
.37889 .52744 Mdot
.39773 .59276 Mdot
.45926 .12195 Mdot
.35999 .13382 Mdot
.53277 .59992 Mdot
.57248 .06187 Mdot
.35782 .58457 Mdot
.71945 .06247 Mdot
.27448 .54934 Mdot
.57247 .07669 Mdot
.49903 .11898 Mdot
.44676 .55263 Mdot
.63628 .6045 Mdot
.7336 .35236 Mdot
.52241 .02705 Mdot
.28575 .5558 Mdot
.43575 .61781 Mdot
.61403 .58157 Mdot
.21364 .52383 Mdot
.52668 .58193 Mdot
.62229 .61051 Mdot
.61968 .08081 Mdot
.59196 .08227 Mdot
.49875 .12024 Mdot
.40347 .02407 Mdot
.55829 .54211 Mdot
.45278 .0078 Mdot
.66687 .45465 Mdot
.55005 .59164 Mdot
.69813 .05356 Mdot
.55599 .59197 Mdot
.40308 .59421 Mdot
.52073 .58207 Mdot
.23185 .26638 Mdot
.3076 .25381 Mdot
.00831 .22306 Mdot
.41997 .61488 Mdot
.68931 .09579 Mdot
.43681 .54922 Mdot
.38036 .02024 Mdot
.47264 .56222 Mdot
.66016 .09895 Mdot
.50373 .57492 Mdot
.68125 .11692 Mdot
.57508 .59853 Mdot
.37881 .52942 Mdot
.65026 .10247 Mdot
.50064 .57134 Mdot
.36642 .59112 Mdot
.66008 .46832 Mdot
.41463 .60829 Mdot
.65392 .09926 Mdot
.3947 .03303 Mdot
.44044 .55181 Mdot
.40086 .02573 Mdot
.76037 .14624 Mdot
.40186 .03149 Mdot
.3905 .12422 Mdot
.46382 .01236 Mdot
.50074 .57294 Mdot
.32086 .56414 Mdot
.5801 .06762 Mdot
.60792 .57626 Mdot
.557 .59199 Mdot
.61846 .09292 Mdot
.21897 .52227 Mdot
.63455 .5994 Mdot
.33162 .18283 Mdot
.31682 .56343 Mdot
.46817 .56145 Mdot
.59212 .56525 Mdot
.55401 .59305 Mdot
.59288 .56976 Mdot
.65438 .47819 Mdot
.51474 .57671 Mdot
.51089 .58968 Mdot
.40397 .12021 Mdot
.53074 .52063 Mdot
.91871 .38782 Mdot
.5337 .04399 Mdot
.72713 .13196 Mdot
.48306 .09966 Mdot
.50062 .05154 Mdot
.45709 .07981 Mdot
.60716 .60539 Mdot
.57746 .49986 Mdot
.19997 .51577 Mdot
.45362 .55422 Mdot
.67782 .38975 Mdot
.52904 .59781 Mdot
.51999 .58125 Mdot
.47418 .12186 Mdot
.71161 .35574 Mdot
.24539 .536 Mdot
.27658 .54376 Mdot
.60808 .58151 Mdot
.38778 .5899 Mdot
.97596 .21081 Mdot
.29058 .55207 Mdot
.32989 .57217 Mdot
.3149 .24537 Mdot
.6881 .11614 Mdot
.34752 .14458 Mdot
.80341 .3578 Mdot
.35188 .57375 Mdot
.69471 .08227 Mdot
.18519 .51155 Mdot
.59137 .00606 Mdot
.45032 .55464 Mdot
.46546 .56551 Mdot
.33016 .20115 Mdot
.43732 .54767 Mdot
.27365 .54498 Mdot
.72282 .13106 Mdot
.70919 .12951 Mdot
.4602 .12227 Mdot
.40832 .02324 Mdot
.24713 .53218 Mdot
.39248 .02078 Mdot
.05984 .2423 Mdot
.46116 .03917 Mdot
.21078 .52163 Mdot
.56308 .61319 Mdot
.58076 .0781 Mdot
.51834 .50841 Mdot
.45067 .55797 Mdot
.33034 .57083 Mdot
.37079 .58858 Mdot
.49642 .56968 Mdot
.4945 .02701 Mdot
.43478 .61678 Mdot
.34287 .5768 Mdot
.80543 .12801 Mdot
.29767 .55876 Mdot
.6083 .57627 Mdot
.41064 .54254 Mdot
.24502 .53771 Mdot
.53078 .58398 Mdot
.51883 .57891 Mdot
.44345 .06692 Mdot
.22395 .52673 Mdot
.66879 .1107 Mdot
.61325 .58344 Mdot
.49702 .01528 Mdot
.59743 .00855 Mdot
.54071 .60322 Mdot
.35052 .57391 Mdot
.05784 .24156 Mdot
.70865 .05673 Mdot
.2655 .54759 Mdot
.59276 .05551 Mdot
.49414 .11108 Mdot
.42424 .60279 Mdot
.80141 .14237 Mdot
.60088 .08485 Mdot
.23627 .52972 Mdot
.48384 .02181 Mdot
.4191 .61374 Mdot
.56269 .0594 Mdot
.26893 .54746 Mdot
.39008 .59166 Mdot
.19719 .51558 Mdot
.29611 .56108 Mdot
.55846 .07259 Mdot
.51504 .02278 Mdot
.49083 .11491 Mdot
.62164 .58858 Mdot
.60067 .07366 Mdot
.75379 .14518 Mdot
.2821 .55088 Mdot
.34682 .57845 Mdot
.19811 .51556 Mdot
.08425 .25097 Mdot
.8348 .11255 Mdot
.58357 .60081 Mdot
.49069 .1163 Mdot
.42089 .54919 Mdot
.17257 .50766 Mdot
.57701 .04839 Mdot
.57938 .49977 Mdot
.41695 .04892 Mdot
.73191 .13755 Mdot
.45911 .03469 Mdot
.65845 .10915 Mdot
.65065 .10236 Mdot
.63645 .10084 Mdot
.66305 .10907 Mdot
.63363 .07177 Mdot
.35032 .13997 Mdot
.59112 .05384 Mdot
.5771 .07827 Mdot
.51805 .05532 Mdot
.62238 .58664 Mdot
.41637 .54363 Mdot
.42468 .02861 Mdot
.72652 .13204 Mdot
.39153 .59916 Mdot
.77358 .08589 Mdot
.5231 .5946 Mdot
.45886 .56474 Mdot
.44704 .07361 Mdot
.64486 .61028 Mdot
.49664 .58135 Mdot
.42308 .05373 Mdot
.57624 .04843 Mdot
.54298 .53486 Mdot
.59275 .08522 Mdot
.43942 .00201 Mdot
.63534 .09188 Mdot
.61428 .07977 Mdot
.41676 .60833 Mdot
.38929 .02986 Mdot
.61871 .61007 Mdot
.49699 .11513 Mdot
.62087 .0191 Mdot
.47265 .56507 Mdot
.59563 .60301 Mdot
.52261 .04071 Mdot
.48644 .02271 Mdot
.4555 .55911 Mdot
.37519 .58318 Mdot
.45073 .03591 Mdot
.56847 .50047 Mdot
.36107 .57872 Mdot
.52214 .51504 Mdot
.62582 .49305 Mdot
.48569 .56647 Mdot
.84593 .36696 Mdot
.48786 .57006 Mdot
.39115 .03182 Mdot
.40345 .02927 Mdot
.47361 .04205 Mdot
.47718 .12177 Mdot
.56935 .59655 Mdot
.53896 .50309 Mdot
.40402 .53668 Mdot
.23107 .52821 Mdot
.64625 .07825 Mdot
.44356 .61347 Mdot
.48532 .10036 Mdot
.66901 .10956 Mdot
.20958 .52427 Mdot
.54614 .53767 Mdot
.36974 .12855 Mdot
.61096 .06313 Mdot
.33849 .15989 Mdot
.34514 .57664 Mdot
.53991 .58545 Mdot
.30289 .5611 Mdot
.88574 .37784 Mdot
.4565 .56272 Mdot
.38585 .59897 Mdot
.58229 .49935 Mdot
.27966 .5534 Mdot
.64614 .61272 Mdot
.39981 .02685 Mdot
.39658 .53603 Mdot
.66776 .03991 Mdot
.37109 .1281 Mdot
.57871 .04957 Mdot
.47175 .01516 Mdot
.46148 .08328 Mdot
.48048 .04332 Mdot
.39542 .59435 Mdot
.40748 .53813 Mdot
.50232 .01805 Mdot
.41393 .54548 Mdot
.53559 .06428 Mdot
.18106 .51248 Mdot
.50203 .11818 Mdot
.53985 .0647 Mdot
.19813 .49179 Mdot
.51941 .02479 Mdot
.93819 .1968 Mdot
.53408 .52911 Mdot
.63547 .49174 Mdot
.54848 .60687 Mdot
.59268 .56978 Mdot
.10399 .25769 Mdot
.2441 .53711 Mdot
.1398 .26924 Mdot
.39172 .02671 Mdot
.3305 .18929 Mdot
.55717 .60849 Mdot
.65027 .10582 Mdot
.50724 .57581 Mdot
.62117 .60546 Mdot
.59373 .05575 Mdot
.45459 .56399 Mdot
.62894 .09742 Mdot
.43523 .54961 Mdot
.66864 .10899 Mdot
.53077 .58272 Mdot
.52977 .52213 Mdot
.64923 .10315 Mdot
.4093 .53942 Mdot
.57172 .59632 Mdot
.47771 .56542 Mdot
.23909 .53462 Mdot
.58691 .50104 Mdot
.6318 .09299 Mdot
.54993 .06743 Mdot
.68128 .11053 Mdot
.24553 .53942 Mdot
.22912 .2658 Mdot
.613 .08091 Mdot
.51045 .02204 Mdot
.46283 .12014 Mdot
.6593 .10673 Mdot
.49823 .11172 Mdot
.62334 .06902 Mdot
.58192 .50072 Mdot
.60376 .60756 Mdot
.61337 .09083 Mdot
.83606 .36439 Mdot
.65839 .10291 Mdot
.22907 .53088 Mdot
.16444 .27689 Mdot
.45313 .56276 Mdot
.44413 .0334 Mdot
.58568 .49875 Mdot
.73519 .06837 Mdot
.3818 .02177 Mdot
.33235 .57391 Mdot
.39212 .03407 Mdot
.42226 .54975 Mdot
.56284 .50154 Mdot
.50529 .05354 Mdot
.67363 .41363 Mdot
.60477 .49694 Mdot
.46174 .5576 Mdot
.23345 .52767 Mdot
.54029 .04922 Mdot
.20494 .52234 Mdot
.43323 .55569 Mdot
.60455 .60448 Mdot
.6711 .10433 Mdot
.65103 .03188 Mdot
.53094 .52785 Mdot
.54783 .06704 Mdot
.44643 .55796 Mdot
.46537 .55999 Mdot
.26934 .54855 Mdot
.39581 .53678 Mdot
.67447 .04347 Mdot
.40596 .53706 Mdot
.28544 .55702 Mdot
.45358 .55976 Mdot
.60697 .58077 Mdot
.68768 .04825 Mdot
.19348 .51754 Mdot
.43838 .03187 Mdot
.33469 .5679 Mdot
.51537 .51079 Mdot
.69293 .04993 Mdot
.43874 .55728 Mdot
.21487 .52296 Mdot
.25377 .5431 Mdot
.73626 .06861 Mdot
.27269 .54537 Mdot
.55348 .06782 Mdot
.37711 .595 Mdot
.62647 .09399 Mdot
.28631 .52818 Mdot
.28383 .55018 Mdot
.71856 .06173 Mdot
.39405 .60262 Mdot
.05853 .24238 Mdot
.02426 .22998 Mdot
.15042 .27263 Mdot
.5293 .02913 Mdot
.43568 .54986 Mdot
.61656 .58411 Mdot
.62207 .59452 Mdot
.44066 .0671 Mdot
.64711 .07751 Mdot
.43663 .61723 Mdot
.32234 .56253 Mdot
.38639 .5894 Mdot
.56221 .61066 Mdot
.78673 .1358 Mdot
.48936 .57717 Mdot
.76654 .08268 Mdot
.26137 .54507 Mdot
.26161 .5422 Mdot
.49259 .11489 Mdot
.4089 .04083 Mdot
.63089 .09802 Mdot
.41972 .60403 Mdot
.42053 .02319 Mdot
.21647 .52506 Mdot
.66539 .10403 Mdot
.45296 .61438 Mdot
.4591 .00982 Mdot
.3007 .55371 Mdot
.31599 .56508 Mdot
.62637 .58839 Mdot
.61072 .58035 Mdot
.55301 .06724 Mdot
.38589 .0296 Mdot
.17999 .51077 Mdot
.20467 .52243 Mdot
.59131 .60345 Mdot
.56797 .5005 Mdot
.49158 .57987 Mdot
.65895 .1001 Mdot
.52645 .51546 Mdot
.42974 .00115 Mdot
.79257 .09378 Mdot
.70089 .12171 Mdot
.48278 .09387 Mdot
.59945 .00928 Mdot
.46153 .07921 Mdot
.49387 .58089 Mdot
.58404 .59649 Mdot
.42333 .60484 Mdot
.53209 .50181 Mdot
.42163 .54902 Mdot
.58114 .59926 Mdot
.62016 .60359 Mdot
.47843 .56614 Mdot
.60567 .0758 Mdot
.35124 .5814 Mdot
.51902 .05607 Mdot
.5019 .11651 Mdot
.72445 .12886 Mdot
.50805 .57604 Mdot
.61308 .06484 Mdot
.87936 .17408 Mdot
.54634 .04906 Mdot
.59092 .0711 Mdot
.25629 .26767 Mdot
.56717 .05869 Mdot
.35576 .5803 Mdot
.27105 .55052 Mdot
.48181 .56678 Mdot
.44721 .07237 Mdot
.67329 .11497 Mdot
.42812 .0573 Mdot
.33314 .57218 Mdot
.73544 .13593 Mdot
.60362 .57266 Mdot
.26991 .54706 Mdot
.53796 .04723 Mdot
.57092 .55222 Mdot
.54058 .60116 Mdot
.66423 .46099 Mdot
.04191 .23624 Mdot
.52947 .04387 Mdot
.6183 .49505 Mdot
.26514 .51943 Mdot
.7046 .12346 Mdot
.36835 .58341 Mdot
.47225 .04119 Mdot
.29576 .55219 Mdot
.52354 .04157 Mdot
.35062 .58011 Mdot
.32283 .56726 Mdot
.75775 .35139 Mdot
.48807 .01238 Mdot
.40247 .60284 Mdot
.45078 .07377 Mdot
.51634 .5021 Mdot
.50897 .03586 Mdot
.52583 .05905 Mdot
.56198 .50035 Mdot
.39675 .59865 Mdot
.49437 .11085 Mdot
.21437 .52268 Mdot
.3744 .59207 Mdot
.24852 .26715 Mdot
.76165 .12565 Mdot
.40503 .60693 Mdot
.04218 .21762 Mdot
.67294 .40987 Mdot
.41492 .02286 Mdot
.37501 .58412 Mdot
.16355 .2542 Mdot
.57126 .5528 Mdot
.3176 .56797 Mdot
.57622 .55752 Mdot
.59963 .60575 Mdot
.46979 .01767 Mdot
.47976 .57659 Mdot
.18841 .28391 Mdot
.36933 .58795 Mdot
.74884 .14067 Mdot
.48731 .56888 Mdot
.64487 .10165 Mdot
.42841 .60694 Mdot
.39689 .03308 Mdot
.39948 .59269 Mdot
.42575 .54473 Mdot
.43377 .60733 Mdot
.46031 .03908 Mdot
.36913 .5901 Mdot
.52331 .49912 Mdot
.49349 .57184 Mdot
.31298 .56762 Mdot
.18442 .51227 Mdot
.64436 .48709 Mdot
.41274 .5403 Mdot
.6441 .09507 Mdot
.58727 .5007 Mdot
.34521 .14542 Mdot
.61853 .58978 Mdot
.55051 .60731 Mdot
.65897 .10935 Mdot
.5764 .07607 Mdot
.75465 .14652 Mdot
.66871 .08759 Mdot
.74944 .14359 Mdot
.41255 .60657 Mdot
.91887 .17279 Mdot
.53199 .02948 Mdot
.63245 .59403 Mdot
.44185 .12056 Mdot
.3242 .56579 Mdot
.51774 .50128 Mdot
.4042 .53578 Mdot
.48461 .04354 Mdot
.63624 .09401 Mdot
.38756 .5998 Mdot
.53831 .58373 Mdot
.41682 .54259 Mdot
.42269 .60294 Mdot
.52012 .51034 Mdot
.33495 .56998 Mdot
.53703 .04706 Mdot
.16634 .50521 Mdot
.5195 .49962 Mdot
.60465 .08562 Mdot
.41411 .60175 Mdot
.16501 .27732 Mdot
.66184 .08407 Mdot
.34602 .57856 Mdot
.45622 .01076 Mdot
.43713 .00404 Mdot
.69714 .12393 Mdot
.56043 .6107 Mdot
.37324 .59261 Mdot
.56426 .61255 Mdot
.72271 .35329 Mdot
.51808 .51477 Mdot
.67427 .11314 Mdot
.64154 .48664 Mdot
.37875 .5935 Mdot
.71865 .12734 Mdot
.21467 .52074 Mdot
.3433 .5778 Mdot
.48021 .1217 Mdot
.66718 .10719 Mdot
.42095 .02378 Mdot
.42851 .61372 Mdot
.7288 .35296 Mdot
.72367 .09435 Mdot
.6149 .09164 Mdot
.22424 .52371 Mdot
.57977 .05008 Mdot
.33127 .18745 Mdot
.35043 .57381 Mdot
.47341 .01631 Mdot
.70161 .35978 Mdot
.51968 .02445 Mdot
.63115 .0721 Mdot
.68968 .37057 Mdot
.48305 .09977 Mdot
.19466 .51828 Mdot
.80675 .1439 Mdot
.97222 .20967 Mdot
.76738 .08329 Mdot
.3869 .0233 Mdot
.52719 .58136 Mdot
.30662 .55655 Mdot
.64167 .09343 Mdot
.10088 .25672 Mdot
.29415 .55268 Mdot
.63467 .09818 Mdot
.51585 .50389 Mdot
.667 .10802 Mdot
.33753 .16238 Mdot
.49307 .027 Mdot
.83343 .36394 Mdot
.3962 .53774 Mdot
.41698 .54767 Mdot
.64202 .48727 Mdot
.41088 .02517 Mdot
.11053 .23979 Mdot
.38263 .02213 Mdot
.70227 .12219 Mdot
.93336 .17838 Mdot
.21421 .52236 Mdot
.21756 .52646 Mdot
.5378 .50222 Mdot
.70893 .12673 Mdot
.47309 .56812 Mdot
.41728 .12063 Mdot
.63771 .09693 Mdot
.90296 .18258 Mdot
.27753 .26557 Mdot
.30454 .25598 Mdot
.40622 .59758 Mdot
.59619 .60465 Mdot
.30728 .55766 Mdot
.63395 .60954 Mdot
.49064 .02455 Mdot
.44975 .1198 Mdot
.39081 .01735 Mdot
.5477 .58917 Mdot
.08864 .25305 Mdot
.55853 .54267 Mdot
.39988 .02475 Mdot
.48489 .0241 Mdot
.4245 .61234 Mdot
.56234 .05771 Mdot
.39281 .6015 Mdot
.7342 .13443 Mdot
.55797 .592 Mdot
.46457 .56386 Mdot
.41685 .05008 Mdot
.18149 .28271 Mdot
.63588 .10037 Mdot
.54661 .05244 Mdot
.63802 .59838 Mdot
.50457 .57633 Mdot
.5844 .49864 Mdot
.51494 .50977 Mdot
.63806 .09047 Mdot
.40018 .60338 Mdot
.32769 .20613 Mdot
.37131 .58691 Mdot
.4839 .57564 Mdot
.44615 .61426 Mdot
.70992 .12978 Mdot
.01278 .22513 Mdot
.54804 .54051 Mdot
.2352 .53544 Mdot
.19696 .28684 Mdot
.68213 .11056 Mdot
.52262 .51967 Mdot
.308 .56616 Mdot
.44129 .00533 Mdot
.3926 .53416 Mdot
.32089 .56645 Mdot
.96033 .40149 Mdot
.48999 .61402 Mdot
.4736 .12129 Mdot
.67503 .08975 Mdot
.40229 .04066 Mdot
.87645 .17223 Mdot
.56676 .04439 Mdot
.69899 .12302 Mdot
.48266 .57445 Mdot
.39395 .60208 Mdot
.26769 .54586 Mdot
.4683 .56691 Mdot
.67988 .38426 Mdot
.36037 .58084 Mdot
.90411 .1831 Mdot
.41229 .6113 Mdot
.33302 .1767 Mdot
.2198 .5253 Mdot
.6231 .09615 Mdot
.05346 .22165 Mdot
.31017 .25015 Mdot
.41833 .05212 Mdot
.58522 .06646 Mdot
.53672 .06423 Mdot
.58587 .56285 Mdot
.39518 .5945 Mdot
.798 .35679 Mdot
.78059 .13366 Mdot
.28374 .55355 Mdot
.60318 .05916 Mdot
.4766 .6083 Mdot
.46049 .01056 Mdot
.26627 .54424 Mdot
.47159 .56215 Mdot
.52464 .51758 Mdot
.56729 .05904 Mdot
.17859 .50805 Mdot
.68665 .09421 Mdot
.5949 .07301 Mdot
.58229 .60066 Mdot
.97786 .21238 Mdot
.51277 .59044 Mdot
.39168 .02038 Mdot
.34656 .14478 Mdot
.35304 .5791 Mdot
.39876 .12329 Mdot
.40711 .12037 Mdot
.55794 .0702 Mdot
.327 .20986 Mdot
.52955 .04232 Mdot
.33472 .57009 Mdot
.59693 .07151 Mdot
.69191 .09686 Mdot
.46749 .03971 Mdot
.64706 .48327 Mdot
.58542 .00433 Mdot
.72629 .13343 Mdot
.48765 .02536 Mdot
.45387 .56137 Mdot
.54463 .50259 Mdot
.42175 .02605 Mdot
.42674 .12021 Mdot
.33087 .57053 Mdot
.28848 .55138 Mdot
.85512 .16415 Mdot
.50573 .11688 Mdot
.43407 .02898 Mdot
.65912 .47155 Mdot
.92958 .19299 Mdot
.49029 .10353 Mdot
.21927 .52574 Mdot
.65564 .47497 Mdot
.50291 .11646 Mdot
.37171 .59321 Mdot
.39899 .04058 Mdot
.74936 .11977 Mdot
.64354 .09733 Mdot
.5306 .04264 Mdot
.56904 .551 Mdot
.47911 .04466 Mdot
.69912 .3633 Mdot
.36139 .57725 Mdot
.99166 .41259 Mdot
.42534 .61264 Mdot
.02286 .22916 Mdot
.36983 .58287 Mdot
.34556 .14859 Mdot
.49042 .02736 Mdot
.73839 .13854 Mdot
.47869 .56481 Mdot
.57068 .55558 Mdot
.50624 .03224 Mdot
.4367 .5568 Mdot
.65212 .10132 Mdot
.26162 .54221 Mdot
.5625 .61214 Mdot
.40932 .59719 Mdot
.52345 .51815 Mdot
.68668 .11271 Mdot
.37685 .1262 Mdot
.64122 .6131 Mdot
.43479 .12197 Mdot
.37423 .58954 Mdot
.52984 .06037 Mdot
.71927 .13224 Mdot
.29195 .55826 Mdot
.6759 .11155 Mdot
.59087 .05561 Mdot
.33684 .57183 Mdot
.3924 .0227 Mdot
.48404 .5783 Mdot
.67858 .0454 Mdot
.61459 .01718 Mdot
.5876 .07107 Mdot
.67357 .40952 Mdot
.55753 .54331 Mdot
.28973 .55197 Mdot
.67006 .43645 Mdot
.40642 .54082 Mdot
.45378 .03485 Mdot
.27022 .26681 Mdot
.63089 .61349 Mdot
.62597 .59436 Mdot
.13895 .26961 Mdot
.39774 .53636 Mdot
.53888 .52849 Mdot
.49346 .01518 Mdot
.20403 .51852 Mdot
.26765 .54086 Mdot
.66636 .10279 Mdot
.55518 .05626 Mdot
.58359 .00292 Mdot
.491 .12161 Mdot
.66398 .03749 Mdot
.40361 .53937 Mdot
.47396 .57197 Mdot
.17143 .50764 Mdot
.37527 .5834 Mdot
.38718 .53213 Mdot
.26525 .53938 Mdot
.67066 .43841 Mdot
.16153 .25358 Mdot
.40708 .04161 Mdot
.58484 .56451 Mdot
.78462 .09005 Mdot
.33681 .16628 Mdot
.70579 .10272 Mdot
.6238 .59149 Mdot
.70654 .1029 Mdot
.45047 .1224 Mdot
.45455 .00888 Mdot
.73944 .10088 Mdot
.56049 .07317 Mdot
.1919 .51534 Mdot
.76835 .08237 Mdot
.48608 .02144 Mdot
.18034 .50941 Mdot
.62349 .60081 Mdot
.46344 .56795 Mdot
.50768 .57618 Mdot
.63304 .60143 Mdot
.33055 .56935 Mdot
.70839 .12865 Mdot
.67636 .39397 Mdot
.6393 .61322 Mdot
.76328 .14983 Mdot
.49319 .57199 Mdot
.41877 .61431 Mdot
.4613 .56096 Mdot
.73744 .13459 Mdot
.27214 .54241 Mdot
.32897 .19964 Mdot
.36309 .58193 Mdot
.56823 .06011 Mdot
.37994 .52797 Mdot
.60057 .57412 Mdot
.41098 .54477 Mdot
.39457 .60193 Mdot
.4257 .54766 Mdot
.25197 .53581 Mdot
.53582 .5861 Mdot
.39072 .57191 Mdot
.43461 .55241 Mdot
.22954 .53122 Mdot
.00757 .20569 Mdot
.5287 .52129 Mdot
.49565 .57102 Mdot
.24641 .53337 Mdot
.32033 .56106 Mdot
.52819 .50474 Mdot
.85995 .16632 Mdot
.54606 .53594 Mdot
.50931 .03521 Mdot
.35521 .58635 Mdot
.41134 .60718 Mdot
.105 .25818 Mdot
.54074 .53432 Mdot
.61111 .08112 Mdot
.5279 .521 Mdot
.52033 .02595 Mdot
.61681 .60444 Mdot
.40666 .60406 Mdot
.09284 .4501 Mdot
.30822 .25246 Mdot
.38162 .02398 Mdot
.39608 .03667 Mdot
.22759 .52676 Mdot
.52835 .05958 Mdot
.41869 .05434 Mdot
.3541 .58571 Mdot
.42256 .58535 Mdot
.65372 .03337 Mdot
.48885 .58018 Mdot
.68712 .37276 Mdot
.35934 .58231 Mdot
.23076 .53358 Mdot
.61468 .60871 Mdot
.50286 .11861 Mdot
.54199 .58629 Mdot
.42666 .61562 Mdot
.41308 .02365 Mdot
.23356 .53066 Mdot
.64689 .48535 Mdot
.40471 .60822 Mdot
.55992 .594 Mdot
.4528 .03542 Mdot
.48733 .09753 Mdot
.66739 .11228 Mdot
.5153 .57578 Mdot
.54584 .50178 Mdot
.54353 .58786 Mdot
.33365 .17279 Mdot
.44805 .07336 Mdot
.36884 .12771 Mdot
.61386 .49628 Mdot
.38291 .59164 Mdot
.60978 .49755 Mdot
.48339 .56562 Mdot
.51595 .02267 Mdot
.66026 .10036 Mdot
.60372 .0767 Mdot
.44483 .03427 Mdot
.66399 .10224 Mdot
.59432 .05536 Mdot
.44249 .55706 Mdot
.48949 .12146 Mdot
.64324 .09939 Mdot
.39604 .60155 Mdot
.49618 .10823 Mdot
.4202 .05445 Mdot
.73815 .35125 Mdot
.42172 .60221 Mdot
.3498 .57995 Mdot
.47305 .04169 Mdot
.62851 .0239 Mdot
.3692 .12772 Mdot
.48588 .57556 Mdot
.45448 .55697 Mdot
.55396 .50051 Mdot
.42385 .05302 Mdot
.78802 .13688 Mdot
.32156 .56408 Mdot
.40935 .04212 Mdot
.27859 .55348 Mdot
.49803 .04811 Mdot
.14273 .24875 Mdot
.49021 .11707 Mdot
.26446 .54416 Mdot
.41865 .02532 Mdot
.39003 .59245 Mdot
.16952 .25577 Mdot
.61116 .58495 Mdot
.51626 .51612 Mdot
.39542 .03454 Mdot
.20691 .51748 Mdot
.56093 .07117 Mdot
.62217 .59959 Mdot
.70452 .35989 Mdot
.52121 .0268 Mdot
.91641 .17174 Mdot
.59896 .5723 Mdot
.67373 .10835 Mdot
.57767 .04833 Mdot
.55913 .50014 Mdot
.63959 .10147 Mdot
.61668 .08486 Mdot
.44692 .03235 Mdot
.6226 .58733 Mdot
.62063 .6048 Mdot
.02048 .22855 Mdot
.45425 .12067 Mdot
.39473 .02449 Mdot
.71394 .35624 Mdot
.46927 .0179 Mdot
.62756 .60339 Mdot
.55 .06878 Mdot
.44801 .00549 Mdot
.39555 .60078 Mdot
.43687 .55415 Mdot
.67929 .10794 Mdot
.40614 .6084 Mdot
.38694 .59447 Mdot
.49997 .12076 Mdot
.51459 .57652 Mdot
.55279 .53844 Mdot
.54966 .49939 Mdot
.38781 .5893 Mdot
.28466 .54932 Mdot
.57082 .50166 Mdot
.57874 .55668 Mdot
.43705 .55309 Mdot
.66405 .10105 Mdot
.62989 .60295 Mdot
.04163 .23632 Mdot
.34063 .5703 Mdot
.45398 .00897 Mdot
.34253 .57755 Mdot
.64083 .48693 Mdot
.02944 .23192 Mdot
.64399 .10447 Mdot
.59708 .08354 Mdot
.61907 .60093 Mdot
.71204 .1251 Mdot
.63338 .09226 Mdot
.61663 .49562 Mdot
.34095 .58007 Mdot
.47649 .04315 Mdot
.56103 .59254 Mdot
.63912 .09816 Mdot
.50289 .0326 Mdot
.42075 .61479 Mdot
.52092 .5179 Mdot
.55941 .61197 Mdot
.25812 .53662 Mdot
.41098 .04703 Mdot
.44551 .55139 Mdot
.44369 .56009 Mdot
.59729 .57413 Mdot
.68665 .11566 Mdot
.63058 .59733 Mdot
.23024 .52752 Mdot
.7427 .10213 Mdot
.5425 .60375 Mdot
.67086 .04213 Mdot
.19259 .51405 Mdot
.62748 .61039 Mdot
.40771 .02569 Mdot
.36214 .57869 Mdot
.71286 .35628 Mdot
.43842 .03074 Mdot
.50662 .05171 Mdot
.58732 .59715 Mdot
.38391 .59214 Mdot
.56948 .04565 Mdot
.71092 .12308 Mdot
.32184 .56478 Mdot
.70468 .12148 Mdot
.375 .58874 Mdot
.52316 .50658 Mdot
.35501 .58489 Mdot
.26385 .54654 Mdot
.76926 .11321 Mdot
.11132 .2401 Mdot
.93837 .19655 Mdot
.64382 .09192 Mdot
.71263 .05962 Mdot
.18492 .51001 Mdot
.5984 .5725 Mdot
.10684 .23855 Mdot
.51743 .05621 Mdot
.57505 .55531 Mdot
.6281 .08969 Mdot
.61935 .49551 Mdot
.43289 .12003 Mdot
.45623 .56204 Mdot
.39978 .0225 Mdot
.39404 .02726 Mdot
.465 .12124 Mdot
.44667 .0713 Mdot
.39891 .54012 Mdot
.57384 .55251 Mdot
.70823 .12446 Mdot
.23832 .53198 Mdot
.2592 .54064 Mdot
.66385 .10106 Mdot
.51739 .50068 Mdot
.42556 .05763 Mdot
.38183 .58706 Mdot
.49541 .57267 Mdot
.67309 .41185 Mdot
.39337 .03424 Mdot
.44312 .55096 Mdot
.32929 .1975 Mdot
.73059 .13533 Mdot
.69542 .11536 Mdot
.66579 .10677 Mdot
.25708 .3008 Mdot
.61873 .59111 Mdot
.39534 .02981 Mdot
.48789 .10177 Mdot
.43572 .03188 Mdot
.59472 .00853 Mdot
.37622 .58493 Mdot
.93395 .19549 Mdot
.28967 .52955 Mdot
.58029 .56102 Mdot
.29139 .55517 Mdot
.52317 .03776 Mdot
.28426 .55155 Mdot
.2112 .26406 Mdot
.49189 .10171 Mdot
.33127 .57387 Mdot
.15341 .27421 Mdot
.66042 .10362 Mdot
.48628 .57818 Mdot
.31219 .56638 Mdot
.36021 .58252 Mdot
.33555 .16364 Mdot
.23557 .53077 Mdot
.24342 .53843 Mdot
.61882 .6097 Mdot
.50535 .051 Mdot
.38286 .5898 Mdot
.46958 .00473 Mdot
.56859 .04629 Mdot
.4829 .56634 Mdot
.46149 .01199 Mdot
.6243 .60038 Mdot
.99704 .21896 Mdot
.60009 .07702 Mdot
.4477 .55909 Mdot
.91869 .1895 Mdot
.77531 .13053 Mdot
.60782 .49859 Mdot
.67341 .41727 Mdot
.41643 .02829 Mdot
.48559 .0463 Mdot
.54537 .53581 Mdot
.60695 .07979 Mdot
.27609 .54422 Mdot
.41829 .61279 Mdot
.41999 .54421 Mdot
.35852 .58204 Mdot
.58423 .56287 Mdot
.65912 .10393 Mdot
.46571 .5648 Mdot
.49643 .11001 Mdot
.62243 .08348 Mdot
.89957 .18109 Mdot
.58737 .49893 Mdot
.57841 .55755 Mdot
.43323 .0307 Mdot
.47765 .60866 Mdot
.54909 .50033 Mdot
.60947 .07867 Mdot
.79074 .0925 Mdot
.23608 .52865 Mdot
.43615 .60741 Mdot
.67043 .11416 Mdot
.40203 .12242 Mdot
.34274 .14817 Mdot
.55541 .03919 Mdot
.61156 .49695 Mdot
.66073 .11045 Mdot
.23556 .53547 Mdot
.53519 .58295 Mdot
.53975 .53129 Mdot
.40432 .53737 Mdot
.62884 .59998 Mdot
.52056 .50834 Mdot
.40016 .60361 Mdot
.47265 .01997 Mdot
.63181 .59844 Mdot
.26693 .54232 Mdot
.31785 .57019 Mdot
.39437 .12319 Mdot
.20478 .52201 Mdot
.4563 .55676 Mdot
.54324 .04896 Mdot
.20502 .51845 Mdot
.40413 .57749 Mdot
.43319 .00056 Mdot
.46342 .01294 Mdot
.28123 .54691 Mdot
.31144 .24869 Mdot
.62164 .6119 Mdot
.46974 .01386 Mdot
.64492 .10217 Mdot
.39021 .59638 Mdot
.75219 .1451 Mdot
.37009 .58082 Mdot
.70074 .12504 Mdot
.49453 .11568 Mdot
.45618 .01173 Mdot
.29781 .55575 Mdot
.69103 .09643 Mdot
.66139 .46595 Mdot
.61565 .06519 Mdot
.5783 .06468 Mdot
.63251 .59969 Mdot
.49592 .58082 Mdot
.48962 .02469 Mdot
.69465 .05175 Mdot
.52535 .5152 Mdot
.7515 .14179 Mdot
.33125 .19106 Mdot
.63521 .09161 Mdot
.57553 .07881 Mdot
.42751 .05632 Mdot
.44333 .07106 Mdot
.66599 .10584 Mdot
.33386 .17498 Mdot
.46499 .01298 Mdot
.4037 .0191 Mdot
.71419 .12593 Mdot
.3473 .14252 Mdot
.55351 .59166 Mdot
.51204 .5757 Mdot
.71099 .3566 Mdot
.5012 .03047 Mdot
.67885 .09099 Mdot
.42839 .5471 Mdot
.62874 .60478 Mdot
.33406 .57027 Mdot
.65616 .10799 Mdot
.61482 .60839 Mdot
.15882 .27568 Mdot
.72707 .134 Mdot
.25582 .54318 Mdot
.72031 .35373 Mdot
.69306 .12221 Mdot
.4489 .00549 Mdot
.4881 .02213 Mdot
.39083 .02485 Mdot
.35654 .13652 Mdot
.33954 .57501 Mdot
.56566 .06138 Mdot
.43348 .61571 Mdot
.39926 .60561 Mdot
.55545 .60882 Mdot
.12006 .26318 Mdot
.40362 .01909 Mdot
.69367 .36552 Mdot
.79298 .09282 Mdot
.46619 .01607 Mdot
.4665 .03981 Mdot
.50053 .11637 Mdot
.44084 .61229 Mdot
.71841 .12969 Mdot
.56725 .54819 Mdot
.40758 .60701 Mdot
.46707 .5637 Mdot
.30806 .56175 Mdot
.40031 .12239 Mdot
.78316 .35415 Mdot
.70158 .08513 Mdot
.42483 .05829 Mdot
.66667 .08644 Mdot
.59176 .6013 Mdot
.61261 .57931 Mdot
.70167 .11802 Mdot
.53599 .58703 Mdot
.31563 .56737 Mdot
.2093 .5192 Mdot
.50019 .57489 Mdot
.69047 .12034 Mdot
.69054 .11847 Mdot
.37852 .52729 Mdot
.56462 .61304 Mdot
.51715 .50132 Mdot
.65625 .08181 Mdot
.62325 .60556 Mdot
.47008 .12286 Mdot
.63151 .59909 Mdot
.38884 .02513 Mdot
.5956 .60049 Mdot
.4486 .03399 Mdot
.56537 .05784 Mdot
.31414 .56817 Mdot
.47022 .08665 Mdot
.52028 .02629 Mdot
.47129 .5703 Mdot
.2713 .5497 Mdot
.46936 .01816 Mdot
.39515 .03427 Mdot
.71789 .12826 Mdot
.24684 .29861 Mdot
.66849 .44404 Mdot
.49674 .11372 Mdot
.44267 .0037 Mdot
.42376 .02494 Mdot
.39149 .12447 Mdot
.33001 .57473 Mdot
.60746 .57795 Mdot
.18958 .51559 Mdot
.04315 .21804 Mdot
.44872 .07176 Mdot
.38615 .58998 Mdot
.4225 .05344 Mdot
.35113 .14035 Mdot
.24607 .53287 Mdot
.35979 .58358 Mdot
.61761 .58947 Mdot
.4089 .02613 Mdot
.68136 .11884 Mdot
.51563 .57641 Mdot
.73835 .13979 Mdot
.50348 .01893 Mdot
.57902 .00176 Mdot
.64777 .61257 Mdot
.68946 .11563 Mdot
.70882 .12511 Mdot
.64587 .10131 Mdot
.65498 .08125 Mdot
.54453 .53792 Mdot
.69156 .12284 Mdot
.25133 .54152 Mdot
.60146 .49916 Mdot
.67153 .42402 Mdot
.41231 .02648 Mdot
.59944 .60049 Mdot
.45308 .07395 Mdot
.66419 .10254 Mdot
.53771 .04751 Mdot
.35149 .57386 Mdot
.2934 .5529 Mdot
.42119 .0258 Mdot
.35575 .13716 Mdot
.62266 .09409 Mdot
.54837 .53493 Mdot
.41408 .53916 Mdot
.59163 .08198 Mdot
.10728 .25878 Mdot
.55736 .54495 Mdot
.52034 .51803 Mdot
.35023 .13954 Mdot
.44354 .06777 Mdot
.62842 .08696 Mdot
.26239 .54484 Mdot
.35355 .13999 Mdot
.23705 .508 Mdot
.60974 .49885 Mdot
.19652 .28678 Mdot
.59953 .08718 Mdot
.17787 .50889 Mdot
.61019 .60433 Mdot
.49177 .02439 Mdot
.67181 .10951 Mdot
.41969 .54186 Mdot
.48143 .56905 Mdot
.50132 .1118 Mdot
.35726 .58091 Mdot
.57955 .55727 Mdot
.74591 .13823 Mdot
.56178 .50165 Mdot
.72475 .06382 Mdot
.53231 .50233 Mdot
.47529 .00763 Mdot
.69572 .1156 Mdot
.48999 .56953 Mdot
.37054 .12944 Mdot
.61879 .6098 Mdot
.19099 .28498 Mdot
.43131 .05807 Mdot
.45728 .0127 Mdot
.7916 .1386 Mdot
.54296 .06464 Mdot
.37248 .58418 Mdot
.43156 .12074 Mdot
.52264 .5829 Mdot
.35487 .57653 Mdot
.23043 .52955 Mdot
.73919 .14055 Mdot
.28369 .55213 Mdot
.75893 .14465 Mdot
.46242 .08189 Mdot
.3743 .5901 Mdot
.70159 .12103 Mdot
.44754 .55703 Mdot
.45817 .00021 Mdot
.38184 .01753 Mdot
.60404 .06068 Mdot
.34371 .58001 Mdot
.45843 .61729 Mdot
.578 .50012 Mdot
.5933 .00843 Mdot
.33409 .5747 Mdot
.68536 .11304 Mdot
.52169 .58087 Mdot
.83103 .11073 Mdot
.80088 .09628 Mdot
.40526 .53833 Mdot
.54584 .53826 Mdot
.61082 .49696 Mdot
.73935 .13943 Mdot
.40952 .04284 Mdot
.60663 .6033 Mdot
.61671 .04961 Mdot
.45781 .03759 Mdot
.52026 .05603 Mdot
.51324 .51179 Mdot
.47574 .04066 Mdot
.40893 .04042 Mdot
.68663 .12097 Mdot
.5036 .57638 Mdot
.54048 .58623 Mdot
.84766 .36709 Mdot
.36766 .58741 Mdot
.59308 .50024 Mdot
.53542 .49877 Mdot
.49083 .01425 Mdot
.40184 .59687 Mdot
.41896 .04997 Mdot
.611 .60781 Mdot
.54664 .59008 Mdot
.57833 .06294 Mdot
.81972 .10557 Mdot
.44344 .12023 Mdot
.7049 .11929 Mdot
.35157 .58251 Mdot
.5753 .55775 Mdot
.89426 .38028 Mdot
.4232 .0563 Mdot
.70083 .12287 Mdot
.4894 .5686 Mdot
.68088 .11782 Mdot
.52937 .58297 Mdot
.91574 .18799 Mdot
.47747 .56566 Mdot
.4987 .11245 Mdot
.5904 .08347 Mdot
.42053 .02344 Mdot
.62265 .60628 Mdot
.67832 .39165 Mdot
.52765 .05848 Mdot
.51639 .05467 Mdot
.60123 .0875 Mdot
.44369 .55312 Mdot
.57439 .49883 Mdot
.61361 .58192 Mdot
.66866 .4436 Mdot
.6379 .09585 Mdot
.39155 .5915 Mdot
.58458 .55968 Mdot
.49608 .04829 Mdot
.35175 .5836 Mdot
.21182 .52272 Mdot
.41947 .54836 Mdot
.35167 .14037 Mdot
.47561 .56694 Mdot
.5365 .03139 Mdot
.4356 .00321 Mdot
.38378 .02082 Mdot
.69828 .05355 Mdot
.36557 .58914 Mdot
.18009 .5104 Mdot
.39512 .5376 Mdot
.59906 .57074 Mdot
.46877 .60505 Mdot
.51988 .59153 Mdot
.25447 .54156 Mdot
.07341 .24698 Mdot
.64066 .07519 Mdot
.63542 .59865 Mdot
.67203 .42433 Mdot
.48784 .56938 Mdot
.40794 .12018 Mdot
.47681 .56493 Mdot
.62138 .59673 Mdot
.90056 .18181 Mdot
.60133 .01152 Mdot
.21086 .52175 Mdot
.66803 .45195 Mdot
.29777 .55242 Mdot
.62282 .60272 Mdot
.31321 .56181 Mdot
.72796 .11111 Mdot
.57833 .07629 Mdot
.4956 .10833 Mdot
.6785 .11539 Mdot
.45148 .55651 Mdot
.5291 .04195 Mdot
.66272 .03684 Mdot
.4803 .02143 Mdot
.31213 .56513 Mdot
.59333 .07394 Mdot
.49361 .10893 Mdot
.37009 .58042 Mdot
.60542 .08919 Mdot
.59876 .57304 Mdot
.6261 .02239 Mdot
.44049 .0014 Mdot
.68787 .09432 Mdot
.22494 .52449 Mdot
.22213 .52347 Mdot
.66668 .45586 Mdot
.56057 .545 Mdot
.39804 .02799 Mdot
.67588 .10958 Mdot
.3501 .14111 Mdot
.62917 .59256 Mdot
.45622 .56609 Mdot
.4622 .56151 Mdot
.36237 .13122 Mdot
.72894 .06685 Mdot
.75935 .14528 Mdot
.62604 .61076 Mdot
.6035 .60106 Mdot
.26211 .5468 Mdot
.25275 .54027 Mdot
.51898 .50619 Mdot
.49667 .05057 Mdot
.64454 .60745 Mdot
.96612 .19072 Mdot
.68723 .04795 Mdot
.32373 .56763 Mdot
.20513 .51798 Mdot
.65449 .47768 Mdot
.25301 .53824 Mdot
.64941 .07874 Mdot
.2855 .54754 Mdot
.51723 .59163 Mdot
.37415 .59088 Mdot
.68864 .11874 Mdot
.55221 .0513 Mdot
.2497 .26762 Mdot
.71696 .13008 Mdot
.62729 .0847 Mdot
.65088 .10505 Mdot
.55304 .54341 Mdot
.49571 .01656 Mdot
.33867 .15805 Mdot
.30647 .55992 Mdot
.57803 .56058 Mdot
.64556 .61077 Mdot
.39567 .60129 Mdot
.67443 .40151 Mdot
.57751 .56043 Mdot
.25771 .54014 Mdot
.58435 .06923 Mdot
.3799 .52739 Mdot
.53635 .49854 Mdot
.27916 .52506 Mdot
.71929 .10738 Mdot
.65521 .10017 Mdot
.70936 .12469 Mdot
.68331 .11716 Mdot
.99916 .22058 Mdot
.50838 .5747 Mdot
.76825 .1498 Mdot
.4842 .12391 Mdot
.34655 .57664 Mdot
.6475 .61088 Mdot
.32515 .22608 Mdot
.65997 .09909 Mdot
.59852 .57413 Mdot
.33034 .56637 Mdot
.49417 .02672 Mdot
.46656 .55844 Mdot
.309 .55995 Mdot
.5344 .58492 Mdot
.94184 .39548 Mdot
.31804 .56403 Mdot
.72548 .12925 Mdot
.35954 .58433 Mdot
.43628 .54766 Mdot
.59202 .56583 Mdot
.0461 .23779 Mdot
.62434 .60313 Mdot
.57324 .59503 Mdot
.78098 .08812 Mdot
.49151 .10287 Mdot
.32898 .56488 Mdot
.54562 .53288 Mdot
.6272 .59091 Mdot
.4919 .11602 Mdot
.53569 .49856 Mdot
.55712 .58859 Mdot
.6162 .60415 Mdot
.50997 .505 Mdot
.1743 .50889 Mdot
.57153 .55238 Mdot
.11516 .26162 Mdot
.63401 .09331 Mdot
.55901 .60954 Mdot
.40433 .01963 Mdot
.49192 .01361 Mdot
.60858 .57595 Mdot
.39546 .02943 Mdot
.54073 .03471 Mdot
.58861 .59972 Mdot
.40561 .03854 Mdot
.60549 .60345 Mdot
.40564 .53695 Mdot
.5531 .54151 Mdot
.69579 .36346 Mdot
.14837 .25054 Mdot
.59864 .07665 Mdot
.60872 .49714 Mdot
.54759 .06537 Mdot
.46015 .00027 Mdot
.24337 .53825 Mdot
.66272 .10721 Mdot
.49253 .11799 Mdot
.63263 .10014 Mdot
.60208 .60114 Mdot
.61809 .6058 Mdot
.47254 .01959 Mdot
.37006 .58067 Mdot
.79087 .09262 Mdot
.38215 .02317 Mdot
.60943 .60127 Mdot
.53773 .04655 Mdot
.43207 .03093 Mdot
.72841 .06519 Mdot
.50032 .0168 Mdot
.38912 .02606 Mdot
.69879 .12263 Mdot
.57209 .59293 Mdot
.36028 .58688 Mdot
.73686 .0998 Mdot
.49963 .03039 Mdot
.50448 .03185 Mdot
.21678 .26443 Mdot
.60232 .60743 Mdot
.62054 .01861 Mdot
.93074 .19325 Mdot
.63009 .61069 Mdot
.37521 .1264 Mdot
.41424 .12024 Mdot
.41516 .54279 Mdot
.37258 .58912 Mdot
.34871 .57483 Mdot
.40426 .595 Mdot
.55202 .60763 Mdot
.4054 .12065 Mdot
.58174 .00254 Mdot
.58977 .08379 Mdot
.44724 .5576 Mdot
.55287 .54354 Mdot
.39278 .01923 Mdot
.66972 .08763 Mdot
.56816 .07601 Mdot
.65139 .48165 Mdot
.48465 .04372 Mdot
.60711 .57834 Mdot
.6829 .10952 Mdot
.61936 .08451 Mdot
.47893 .04378 Mdot
.58688 .56439 Mdot
.67983 .38423 Mdot
.24565 .53527 Mdot
.68781 .09565 Mdot
.6869 .09381 Mdot
.5681 .55384 Mdot
.30511 .55826 Mdot
.36232 .58268 Mdot
.42153 .05587 Mdot
.5372 .50315 Mdot
.69942 .10041 Mdot
.62542 .09498 Mdot
.58332 .08027 Mdot
.42286 .54315 Mdot
.58241 .07828 Mdot
.6568 .47175 Mdot
.56731 .05952 Mdot
.75601 .07754 Mdot
.84817 .16129 Mdot
.5701 .55412 Mdot
.79069 .12194 Mdot
.41508 .54215 Mdot
.51942 .0581 Mdot
.91436 .17082 Mdot
.23375 .53138 Mdot
.26889 .26742 Mdot
.41521 .54101 Mdot
.46072 .00069 Mdot
.49583 .04943 Mdot
.28301 .54917 Mdot
.61342 .07906 Mdot
.44574 .07182 Mdot
.60444 .60061 Mdot
.40309 .02964 Mdot
.30998 .56624 Mdot
.94909 .20153 Mdot
.11767 .2624 Mdot
.43296 .06398 Mdot
.32399 .56773 Mdot
.60281 .07582 Mdot
.42344 .54268 Mdot
.76379 .12695 Mdot
.54408 .06503 Mdot
.12144 .46137 Mdot
.586 .56488 Mdot
.63245 .07162 Mdot
.66932 .43487 Mdot
.49752 .57292 Mdot
.29568 .2599 Mdot
.39596 .03247 Mdot
.54589 .05049 Mdot
.58914 .07146 Mdot
.47137 .12124 Mdot
.20772 .52131 Mdot
.4396 .00501 Mdot
.7112 .12663 Mdot
.75417 .14517 Mdot
.3903 .5969 Mdot
.61113 .60826 Mdot
.40487 .02066 Mdot
.73258 .13479 Mdot
.59185 .60197 Mdot
.28056 .55299 Mdot
.04001 .43012 Mdot
.40574 .03814 Mdot
.73818 .10025 Mdot
.74639 .14108 Mdot
.36873 .5827 Mdot
.58988 .60361 Mdot
.61014 .57751 Mdot
.19198 .51589 Mdot
.52242 .05874 Mdot
.78134 .35391 Mdot
.54805 .54019 Mdot
.34812 .14181 Mdot
.50417 .58451 Mdot
.44892 .56179 Mdot
.41444 .02309 Mdot
.48714 .04556 Mdot
.31121 .56461 Mdot
.46132 .03739 Mdot
.55856 .05518 Mdot
.52468 .0585 Mdot
.57604 .50175 Mdot
.40352 .57748 Mdot
.47965 .00946 Mdot
.36594 .58522 Mdot
.47062 .01764 Mdot
.72661 .13382 Mdot
.42126 .55013 Mdot
.76332 .07984 Mdot
.32492 .22505 Mdot
.41939 .02727 Mdot
.37255 .58707 Mdot
.25477 .54045 Mdot
.73351 .13223 Mdot
.66309 .10923 Mdot
.64788 .10043 Mdot
.3774 .58415 Mdot
.94322 .19845 Mdot
.50308 .1187 Mdot
.3346 .56994 Mdot
.10472 .23795 Mdot
.66542 .45376 Mdot
.75982 .12489 Mdot
.66539 .10709 Mdot
.52829 .59614 Mdot
.40924 .5397 Mdot
.51208 .50168 Mdot
.70037 .36069 Mdot
.42915 .05888 Mdot
.45069 .1206 Mdot
.61893 .60917 Mdot
.53893 .0465 Mdot
.63358 .09158 Mdot
.53747 .53042 Mdot
.27464 .54944 Mdot
.42324 .05684 Mdot
.59224 .05604 Mdot
.40786 .02765 Mdot
.40066 .0313 Mdot
.96989 .20889 Mdot
.23909 .53082 Mdot
.45374 .07618 Mdot
.29213 .55329 Mdot
.4597 .00129 Mdot
.46139 .56619 Mdot
.39346 .03213 Mdot
.37435 .52555 Mdot
.20382 .51775 Mdot
.6641 .4567 Mdot
.38981 .0308 Mdot
.71395 .05965 Mdot
.64747 .10383 Mdot
.64025 .60166 Mdot
.52721 .51741 Mdot
.62359 .59355 Mdot
.61046 .58392 Mdot
.63056 .49353 Mdot
.32306 .56475 Mdot
.05918 .24213 Mdot
.26116 .54145 Mdot
.71323 .13047 Mdot
.62576 .6017 Mdot
.39628 .02494 Mdot
.46351 .01226 Mdot
.50189 .11963 Mdot
.75152 .14418 Mdot
.44403 .55494 Mdot
.53005 .52201 Mdot
.43221 .60704 Mdot
.53354 .52955 Mdot
.78308 .13431 Mdot
.49452 .04899 Mdot
.4504 .03609 Mdot
.63336 .60334 Mdot
.23832 .53061 Mdot
.67728 .11636 Mdot
.58324 .08039 Mdot
.50925 .57816 Mdot
.84601 .36664 Mdot
.48261 .02413 Mdot
.51216 .05398 Mdot
.69147 .12292 Mdot
.59333 .07086 Mdot
.23504 .52844 Mdot
.60101 .49917 Mdot
.34408 .57477 Mdot
.51718 .50217 Mdot
.38747 .53128 Mdot
.3402 .57267 Mdot
.45325 .55478 Mdot
.43627 .59125 Mdot
.51566 .50183 Mdot
.65801 .10135 Mdot
.2361 .53336 Mdot
.4955 .57359 Mdot
.1607 .27663 Mdot
.62385 .08709 Mdot
.39654 .53614 Mdot
.41207 .0269 Mdot
.18322 .51224 Mdot
.42217 .02409 Mdot
.36023 .57997 Mdot
.65969 .46811 Mdot
.48889 .12164 Mdot
.39265 .59737 Mdot
.44709 .07253 Mdot
.46601 .0374 Mdot
.47313 .04047 Mdot
.03116 .23247 Mdot
.66938 .43582 Mdot
.77093 .11366 Mdot
.69406 .36472 Mdot
.8068 .14478 Mdot
.65732 .10595 Mdot
.39537 .02612 Mdot
.65106 .48055 Mdot
.33422 .5696 Mdot
.55435 .05461 Mdot
.58622 .60019 Mdot
.53416 .60083 Mdot
.52028 .50472 Mdot
.36814 .58513 Mdot
.36593 .58862 Mdot
.08024 .44547 Mdot
.42687 .60431 Mdot
.67861 .11657 Mdot
.59457 .08585 Mdot
.43092 .12195 Mdot
.54943 .06654 Mdot
.64306 .10321 Mdot
.47661 .04269 Mdot
.4861 .12195 Mdot
.35139 .14228 Mdot
.43471 5e-05 Mdot
.39551 .03403 Mdot
.45809 .0377 Mdot
.64716 .0936 Mdot
.25515 .54284 Mdot
.60072 .01202 Mdot
.38558 .0202 Mdot
.50557 .05335 Mdot
.4619 .56448 Mdot
.21225 .52172 Mdot
.44963 .00495 Mdot
.6249 .09475 Mdot
.22691 .52668 Mdot
.59085 .56464 Mdot
.45455 .0767 Mdot
.71069 .12195 Mdot
.4176 .02413 Mdot
.51581 .05733 Mdot
.17737 .50808 Mdot
.18616 .51236 Mdot
.44109 .61 Mdot
.56039 .59459 Mdot
.67134 .42984 Mdot
.33347 .17671 Mdot
.63943 .48728 Mdot
.63254 .49232 Mdot
.6819 .09255 Mdot
.41279 .60772 Mdot
.61025 .49737 Mdot
.20281 .49396 Mdot
.53126 .50012 Mdot
.15088 .47303 Mdot
.46085 .07927 Mdot
.31503 .54024 Mdot
.55073 .60691 Mdot
.23918 .53541 Mdot
.48954 .04476 Mdot
.68956 .11583 Mdot
.46216 .01421 Mdot
.7646 .12632 Mdot
.53916 .06514 Mdot
.36478 .58538 Mdot
.48967 .56853 Mdot
.63354 .48981 Mdot
.33046 .57199 Mdot
.41365 .54287 Mdot
.67293 .10884 Mdot
.44108 .54933 Mdot
.32709 .56325 Mdot
.71998 .13096 Mdot
.38131 .53028 Mdot
.49998 .02765 Mdot
.63407 .09105 Mdot
.24303 .53828 Mdot
.70679 .12098 Mdot
.77098 .15162 Mdot
.42951 .0002 Mdot
.33474 .17171 Mdot
.61857 .58378 Mdot
.49471 .57092 Mdot
.49567 .57081 Mdot
.76409 .14762 Mdot
.29409 .55124 Mdot
.08224 .25086 Mdot
.39248 .5328 Mdot
.1401 .26943 Mdot
.56169 .07154 Mdot
.72182 .13433 Mdot
.51099 .03648 Mdot
.4339 .55428 Mdot
.66765 .10964 Mdot
.47784 .5702 Mdot
.74227 .14039 Mdot
.56612 .07495 Mdot
.5752 .07682 Mdot
.71191 .12347 Mdot
.68021 .38395 Mdot
.60747 .07566 Mdot
.49447 .01584 Mdot
.55457 .53933 Mdot
.01895 .22742 Mdot
.88535 .17536 Mdot
.57196 .50058 Mdot
.24454 .2984 Mdot
.34698 .57768 Mdot
.36128 .13196 Mdot
.42806 .54812 Mdot
.26061 .53911 Mdot
.65339 .10319 Mdot
.65182 .47896 Mdot
.20163 .51761 Mdot
.63339 .60295 Mdot
.34175 .56909 Mdot
.59165 .50039 Mdot
.36148 .58461 Mdot
.66961 .4437 Mdot
.2549 .30042 Mdot
.37298 .59157 Mdot
.33686 .56911 Mdot
.38446 .59875 Mdot
.47087 .56197 Mdot
.58536 .08176 Mdot
.42787 .54563 Mdot
.61234 .58407 Mdot
.63541 .49156 Mdot
.44846 .55922 Mdot
.95974 .18806 Mdot
.37207 .58361 Mdot
.28624 .2633 Mdot
.64335 .02966 Mdot
.70505 .12379 Mdot
.89557 .1639 Mdot
.83686 .14037 Mdot
.64814 .09753 Mdot
.2965 .2609 Mdot
.55767 .49896 Mdot
.61924 .58333 Mdot
.68688 .07903 Mdot
.59634 .07098 Mdot
.75211 .14501 Mdot
.63477 .61086 Mdot
.39798 .03175 Mdot
.3627 .13137 Mdot
.52081 .50677 Mdot
.20681 .51758 Mdot
.44754 .07211 Mdot
.6602 .10277 Mdot
.4779 .57387 Mdot
.5766 .07742 Mdot
.34115 .57494 Mdot
.60142 .05814 Mdot
.7033 .3607 Mdot
.62719 .06991 Mdot
.5509 .05404 Mdot
.34158 .15296 Mdot
.50164 .05047 Mdot
.52198 .00942 Mdot
.62026 .58401 Mdot
.39839 .5963 Mdot
.50723 .58575 Mdot
.50271 .57391 Mdot
.46578 .60377 Mdot
.60657 .01429 Mdot
.62197 .61131 Mdot
.55743 .58999 Mdot
.70078 .36186 Mdot
.41486 .60065 Mdot
.68141 .11332 Mdot
.32892 .20269 Mdot
.51231 .05417 Mdot
.58365 .06743 Mdot
.72606 .13 Mdot
.61785 .08082 Mdot
.51216 .57401 Mdot
.60809 .09049 Mdot
.43898 .54859 Mdot
.51748 .51164 Mdot
.30056 .5529 Mdot
.39684 .02802 Mdot
.48329 .12381 Mdot
.66524 .03809 Mdot
.45795 .01091 Mdot
.39977 .12315 Mdot
.62779 .59158 Mdot
.56367 .07149 Mdot
.45793 .6179 Mdot
.50111 .57193 Mdot
.71778 .12799 Mdot
.91883 .18935 Mdot
.54163 .06427 Mdot
.64489 .0613 Mdot
.51498 .51031 Mdot
.42933 .02977 Mdot
.69769 .1171 Mdot
.55067 .53728 Mdot
.65399 .47455 Mdot
.42734 .02902 Mdot
.42403 .02571 Mdot
.56137 .54746 Mdot
.79218 .13759 Mdot
.01551 .20848 Mdot
.66838 .44457 Mdot
.244 .5334 Mdot
.78436 .09036 Mdot
.44125 .06729 Mdot
.20238 .2621 Mdot
.79171 .12233 Mdot
.77415 .08464 Mdot
.78614 .13604 Mdot
.43108 .03067 Mdot
.63764 .10061 Mdot
.50292 .0013 Mdot
.23988 .50916 Mdot
.63517 .61232 Mdot
.8427 .36619 Mdot
.53796 .58721 Mdot
.43031 .00112 Mdot
.69604 .12267 Mdot
.39613 .03489 Mdot
.45223 .03408 Mdot
.67724 .10952 Mdot
.5395 .58537 Mdot
.74545 .07403 Mdot
.65249 .10008 Mdot
.46294 .0157 Mdot
.67335 .11291 Mdot
.38861 .02524 Mdot
.70788 .12617 Mdot
.67365 .10987 Mdot
.60429 .60769 Mdot
.54003 .50258 Mdot
.46783 .08542 Mdot
.42684 .05822 Mdot
.57564 .59449 Mdot
.36172 .13241 Mdot
.72337 .12841 Mdot
.50767 .05247 Mdot
.33346 .56684 Mdot
.64827 .61132 Mdot
.46098 .12287 Mdot
.34446 .14914 Mdot
.39166 .12438 Mdot
.52456 .51665 Mdot
.27434 .54925 Mdot
.67944 .11222 Mdot
.40245 .04142 Mdot
.85975 .1498 Mdot
.40458 .59451 Mdot
.66511 .10338 Mdot
.64635 .61082 Mdot
.71279 .1283 Mdot
.62861 .09352 Mdot
.1145 .45875 Mdot
.75509 .35119 Mdot
.71714 .06111 Mdot
.67947 .10956 Mdot
.50067 .1205 Mdot
.48742 .57822 Mdot
.62885 .59155 Mdot
.63436 .59467 Mdot
.33985 .15444 Mdot
.82566 .10807 Mdot
.43943 .61006 Mdot
.40414 .53571 Mdot
.58075 .06452 Mdot
.6046 .06132 Mdot
.71318 .12854 Mdot
.43351 .54857 Mdot
.6585 .47274 Mdot
.63016 .59118 Mdot
.57943 .55634 Mdot
.16293 .50398 Mdot
.63067 .08699 Mdot
.24679 .29879 Mdot
.64045 .09731 Mdot
.4098 .60026 Mdot
.43824 .55603 Mdot
.17231 .27993 Mdot
.61493 .09293 Mdot
.30691 .56073 Mdot
.33567 .17095 Mdot
.43958 .00235 Mdot
.63374 .4925 Mdot
.4445 .0046 Mdot
.44762 .0734 Mdot
.39721 .60171 Mdot
.51166 .03653 Mdot
.84248 .15801 Mdot
.39132 .59766 Mdot
.48437 .56889 Mdot
.40534 .54206 Mdot
.46815 .55891 Mdot
.25925 .54424 Mdot
.42544 .02667 Mdot
.67162 .10956 Mdot
.51038 .02156 Mdot
.49475 .58324 Mdot
.50598 .58788 Mdot
.49918 .10814 Mdot
.4544 .55655 Mdot
.41205 .02134 Mdot
.56289 .59443 Mdot
.73534 .13938 Mdot
.32832 .56692 Mdot
.69762 .11754 Mdot
.61022 .60345 Mdot
.2765 .54506 Mdot
.33311 .1769 Mdot
.46474 .01488 Mdot
.58048 .56059 Mdot
.34629 .14552 Mdot
.52524 .51562 Mdot
.44785 .00731 Mdot
.63739 .02717 Mdot
.52149 .5169 Mdot
.54359 .53477 Mdot
.48672 .0227 Mdot
.77425 .08472 Mdot
.51819 .03861 Mdot
.70575 .12119 Mdot
.23452 .29598 Mdot
.52508 .50087 Mdot
.58018 .07922 Mdot
.55718 .59106 Mdot
.52141 .04098 Mdot
.47791 .57409 Mdot
.59376 .08482 Mdot
.56097 .04283 Mdot
.78479 .13554 Mdot
.32494 .56569 Mdot
.49192 .57022 Mdot
.71859 .35512 Mdot
.5355 .58489 Mdot
.37011 .58178 Mdot
.45444 .11985 Mdot
.63667 .09723 Mdot
.42717 .60693 Mdot
.56449 .05733 Mdot
.52824 .58071 Mdot
.55408 .0399 Mdot
.66803 .4462 Mdot
.7697 .08297 Mdot
.70001 .36237 Mdot
.43982 .00451 Mdot
.4347 .55553 Mdot
.54474 .03525 Mdot
.4202 .0555 Mdot
.63648 .60593 Mdot
.36044 .5886 Mdot
.75314 .14474 Mdot
.50905 .03226 Mdot
.39327 .59456 Mdot
.51588 .50613 Mdot
.40855 .60569 Mdot
.46554 .56446 Mdot
.35109 .57442 Mdot
.29732 .55341 Mdot
.13766 .26884 Mdot
.52115 .51704 Mdot
.4054 .6071 Mdot
.02951 .21329 Mdot
.53644 .52954 Mdot
.34232 .57864 Mdot
.51266 .05453 Mdot
.62783 .05409 Mdot
.44118 .61072 Mdot
.41816 .12037 Mdot
.83061 .10951 Mdot
.70056 .11791 Mdot
.74625 .07323 Mdot
.51643 .51056 Mdot
.68708 .37461 Mdot
.34978 .58384 Mdot
.3297 .56469 Mdot
.49491 .57195 Mdot
.40519 .02745 Mdot
.71643 .1304 Mdot
.49458 .11138 Mdot
.44774 .56056 Mdot
.44481 .11996 Mdot
.39412 .02209 Mdot
.06593 .43969 Mdot
.29212 .26294 Mdot
.52256 .5782 Mdot
.42129 .05147 Mdot
.54103 .01763 Mdot
.60169 .57634 Mdot
.78146 .13392 Mdot
.40751 .60697 Mdot
.32603 .22092 Mdot
.506 .05125 Mdot
.25493 .54036 Mdot
.63271 .6111 Mdot
.70654 .35808 Mdot
.53936 .03349 Mdot
.46776 .57046 Mdot
.66205 .1116 Mdot
.27408 .54868 Mdot
.63176 .59486 Mdot
.52053 .0248 Mdot
.66787 .44516 Mdot
.46731 .11963 Mdot
.6306 .09418 Mdot
.44679 .00568 Mdot
.56816 .07364 Mdot
.51464 .51125 Mdot
.33184 .57414 Mdot
.37876 .52859 Mdot
.69908 .36235 Mdot
.37497 .12749 Mdot
.53021 .52208 Mdot
.6304 .4909 Mdot
.31573 .56611 Mdot
.40653 .6088 Mdot
.5003 .58285 Mdot
.47727 .56424 Mdot
.66965 .43713 Mdot
.46564 .0161 Mdot
.68649 .11151 Mdot
.40527 .04479 Mdot
.6293 .6027 Mdot
.63074 .59844 Mdot
.44711 .55675 Mdot
.3582 .58619 Mdot
.41999 .12204 Mdot
.2372 .52978 Mdot
.57012 .55311 Mdot
.46754 .00443 Mdot
.28579 .55642 Mdot
.83021 .15305 Mdot
.57863 .55976 Mdot
.36319 .1322 Mdot
.63661 .6135 Mdot
.41143 .54511 Mdot
.36548 .57879 Mdot
.47434 .12272 Mdot
.65 .09751 Mdot
.33912 .1572 Mdot
.55997 .07326 Mdot
.71071 .12516 Mdot
.75316 .14341 Mdot
.50297 .0292 Mdot
.53301 .52613 Mdot
.61366 .60456 Mdot
.61837 .58525 Mdot
.61237 .01602 Mdot
.45561 .55529 Mdot
.59237 .07101 Mdot
.71634 .13166 Mdot
.47209 .56013 Mdot
.63779 .61202 Mdot
.6937 .11815 Mdot
.33801 .15659 Mdot
.4997 .5825 Mdot
.52734 .50089 Mdot
.49609 .02931 Mdot
.64243 .60671 Mdot
.56579 .07175 Mdot
.40176 .59435 Mdot
.51741 .5906 Mdot
.49164 .1025 Mdot
.43093 .61733 Mdot
.38358 .12583 Mdot
.67209 .04253 Mdot
.41826 .60305 Mdot
.45711 .5632 Mdot
.49838 .11445 Mdot
.62771 .59968 Mdot
.3107 .25115 Mdot
.41436 .0504 Mdot
.67029 .42986 Mdot
.6724 .11462 Mdot
.58377 .00285 Mdot
.50028 .0313 Mdot
.49017 .02562 Mdot
.63526 .09754 Mdot
.56357 .04248 Mdot
.64263 .09271 Mdot
.33082 .18383 Mdot
.69489 .36498 Mdot
.5171 .57747 Mdot
.49498 .02922 Mdot
.58205 .06742 Mdot
.54408 .5353 Mdot
.36587 .58437 Mdot
.33951 .15504 Mdot
.41211 .59776 Mdot
.61904 .08552 Mdot
.51926 .58188 Mdot
.44769 .55415 Mdot
.59698 .08656 Mdot
.63542 .09432 Mdot
.5277 .50094 Mdot
.10014 .25653 Mdot
.48292 .09951 Mdot
.63809 .09171 Mdot
.31951 .57003 Mdot
.44962 .55317 Mdot
.63883 .0749 Mdot
.68601 .37332 Mdot
.83247 .15501 Mdot
.32615 .54485 Mdot
.51061 .50735 Mdot
.61921 .09435 Mdot
.50755 .57601 Mdot
.73153 .13324 Mdot
.41406 .02447 Mdot
.23298 .53143 Mdot
.65479 .10487 Mdot
.5112 .05246 Mdot
.29076 .55649 Mdot
.98943 .19931 Mdot
.41371 .59854 Mdot
.20823 .51964 Mdot
.45295 .03424 Mdot
.46574 .12182 Mdot
.51761 .0571 Mdot
.5093 .02123 Mdot
.2065 .51828 Mdot
.41879 .60086 Mdot
.36424 .13309 Mdot
.57838 .55864 Mdot
.45506 .0765 Mdot
.57398 .61583 Mdot
.20892 .26311 Mdot
.59977 .01021 Mdot
.67707 .09054 Mdot
.60573 .07582 Mdot
.51429 .50072 Mdot
.54657 .03702 Mdot
.4324 .03073 Mdot
.2568 .54079 Mdot
.53423 .52487 Mdot
.55183 .05067 Mdot
.66502 .10605 Mdot
.6029 .08739 Mdot
.42572 .54421 Mdot
.49364 .11441 Mdot
.54134 .49999 Mdot
.28096 .54696 Mdot
.23256 .52906 Mdot
.45795 .55861 Mdot
.44242 .06852 Mdot
.45683 .55518 Mdot
.35269 .55595 Mdot
.45855 .03517 Mdot
.57195 .07544 Mdot
.48585 .56962 Mdot
.6442 .48407 Mdot
.39936 .02321 Mdot
.60172 .60578 Mdot
.39717 .03862 Mdot
.54032 .58565 Mdot
.40645 .02382 Mdot
.41077 .02071 Mdot
.56585 .55024 Mdot
.65689 .47275 Mdot
.49942 .04917 Mdot
.61188 .0887 Mdot
.64497 .10355 Mdot
.44097 .12191 Mdot
.63477 .59472 Mdot
.4211 .54216 Mdot
.62824 .09853 Mdot
.47534 .56496 Mdot
.25655 .53626 Mdot
.48337 .12211 Mdot
.36219 .58396 Mdot
.62553 .02177 Mdot
.46786 .56231 Mdot
.56934 .55428 Mdot
.225 .26528 Mdot
.70728 .05641 Mdot
.63351 .48954 Mdot
.55634 .05645 Mdot
.19683 .51568 Mdot
.53015 .04291 Mdot
.13729 .26855 Mdot
.37912 .1271 Mdot
.47102 .55973 Mdot
.56894 .50122 Mdot
.59589 .60184 Mdot
.38546 .58818 Mdot
.66936 .10664 Mdot
.26579 .5455 Mdot
.63014 .60154 Mdot
.61827 .01854 Mdot
.61945 .60318 Mdot
.35202 .14041 Mdot
.57285 .55581 Mdot
.52981 .58376 Mdot
.70373 .05487 Mdot
.84965 .16212 Mdot
.50321 .01872 Mdot
.30396 .55449 Mdot
.46188 .5586 Mdot
.53899 .52784 Mdot
.28797 .55788 Mdot
.52589 .58279 Mdot
.57272 .06034 Mdot
.55639 .06872 Mdot
.69955 .36222 Mdot
.60508 .08786 Mdot
.58376 .5628 Mdot
.41756 .61204 Mdot
.49239 .10498 Mdot
.57854 .06717 Mdot
.61249 .60268 Mdot
.4891 .04474 Mdot
.51149 .50273 Mdot
.54991 .0672 Mdot
.53895 .04838 Mdot
.2036 .51928 Mdot
.39751 .03346 Mdot
.34548 .14851 Mdot
.43914 .54982 Mdot
.40372 .02229 Mdot
.34257 .57642 Mdot
.52417 .04095 Mdot
.46576 .08393 Mdot
.5554 .60859 Mdot
.4686 .56866 Mdot
.59251 .49827 Mdot
.62453 .59444 Mdot
.66255 .11155 Mdot
.31676 .56273 Mdot
.44838 .56264 Mdot
.63243 .0981 Mdot
.70331 .12108 Mdot
.44913 .61395 Mdot
.25505 .54252 Mdot
.66356 .45819 Mdot
.57722 .0495 Mdot
.33493 .1702 Mdot
.41519 .04715 Mdot
.45955 .56607 Mdot
.07405 .24781 Mdot
.6825 .38115 Mdot
.40469 .59781 Mdot
.63405 .09787 Mdot
.42068 .5475 Mdot
.30886 .56249 Mdot
.42958 .54525 Mdot
.0962 .45148 Mdot
.70861 .35701 Mdot
.18012 .282 Mdot
.63825 .0261 Mdot
.38753 .58927 Mdot
.43968 .55448 Mdot
.46053 .1197 Mdot
.00866 .41864 Mdot
.67426 .08944 Mdot
.47462 .56215 Mdot
.51462 .59143 Mdot
.19189 .51389 Mdot
.32671 .5699 Mdot
.71894 .12591 Mdot
.33151 .56854 Mdot
.48004 .04351 Mdot
.21798 .52797 Mdot
.68369 .37628 Mdot
.57105 .556 Mdot
.46274 .55945 Mdot
.35618 .13535 Mdot
.21275 .52351 Mdot
.54983 .54143 Mdot
.19351 .51739 Mdot
.60463 .08781 Mdot
.5839 .49891 Mdot
.33495 .5694 Mdot
.34141 .571 Mdot
.40085 .59441 Mdot
.38627 .1243 Mdot
.42348 .02726 Mdot
.51807 .57645 Mdot
.64379 .02876 Mdot
.50108 .11025 Mdot
.61885 .09267 Mdot
.43185 .05907 Mdot
.58684 .60264 Mdot
.90234 .18219 Mdot
.47651 .56264 Mdot
.51589 .59229 Mdot
.73906 .10071 Mdot
.45315 .00887 Mdot
.83351 .1556 Mdot
.48975 .12054 Mdot
.30392 .55759 Mdot
.4805 .56597 Mdot
.44787 .55306 Mdot
.37334 .59092 Mdot
.44704 .55347 Mdot
.42131 .60446 Mdot
.20728 .52187 Mdot
.57918 .06355 Mdot
.69374 .12171 Mdot
.22767 .52962 Mdot
.37099 .59046 Mdot
.43253 .0306 Mdot
.13216 .2676 Mdot
.51585 .51259 Mdot
.34839 .57968 Mdot
.72043 .13065 Mdot
.4237 .02555 Mdot
.38471 .58827 Mdot
.49194 .04605 Mdot
.67407 .41512 Mdot
.44963 .55725 Mdot
.02692 .42532 Mdot
.50336 .11219 Mdot
.63305 .07236 Mdot
.45902 .03872 Mdot
.48766 .04602 Mdot
.65492 .10579 Mdot
.06706 .245 Mdot
.74528 .07389 Mdot
.51042 .58945 Mdot
.40098 .02829 Mdot
.24104 .53436 Mdot
.5242 .5006 Mdot
.73504 .13732 Mdot
.68164 .04497 Mdot
.38306 .59265 Mdot
.54615 .06613 Mdot
.45112 .55543 Mdot
.20674 .52304 Mdot
.63065 .60813 Mdot
.35497 .58663 Mdot
.50544 .5864 Mdot
.19004 .25972 Mdot
.41279 .54654 Mdot
.59025 .5643 Mdot
.5377 .06277 Mdot
.48213 .56618 Mdot
.25888 .53766 Mdot
.40534 .12043 Mdot
.57325 .04795 Mdot
.48169 .09928 Mdot
.63409 .09837 Mdot
.51281 .05283 Mdot
.63098 .08597 Mdot
.67735 .39705 Mdot
.40284 .0288 Mdot
.69416 .0521 Mdot
.32907 .57095 Mdot
.48309 .00917 Mdot
.35607 .58555 Mdot
.33793 .15978 Mdot
.44316 .61032 Mdot
.27136 .54835 Mdot
.58061 .56199 Mdot
.41777 .54354 Mdot
.59562 .07426 Mdot
.31888 .56109 Mdot
.59307 .49863 Mdot
.2736 .54824 Mdot
.70823 .12499 Mdot
.85002 .162 Mdot
.42907 .61801 Mdot
.49828 .11669 Mdot
.41645 .6014 Mdot
.38612 .02843 Mdot
.39962 .0243 Mdot
.46337 .03936 Mdot
.55845 .0557 Mdot
.4079 .04496 Mdot
.52176 .51868 Mdot
.37339 .58822 Mdot
.41046 .60678 Mdot
.56447 .06086 Mdot
.34049 .57034 Mdot
.9006 .16569 Mdot
.55548 .59256 Mdot
.46202 .01352 Mdot
.42365 .05738 Mdot
.6747 .4065 Mdot
.42156 .60284 Mdot
.53926 .04852 Mdot
.38854 .02241 Mdot
.512 .58968 Mdot
.32255 .56362 Mdot
.62791 .60207 Mdot
.17127 .50814 Mdot
.65882 .08288 Mdot
.20561 .52038 Mdot
.42577 .54619 Mdot
.60738 .58182 Mdot
.47759 .0081 Mdot
.49675 .11446 Mdot
.45042 .55851 Mdot
.24283 .5389 Mdot
.24391 .53134 Mdot
.4651 .56755 Mdot
.40115 .59726 Mdot
.44565 .55835 Mdot
.42889 .61769 Mdot
.40761 .5418 Mdot
.43215 .61566 Mdot
.49745 .03001 Mdot
.48523 .02498 Mdot
.33233 .18615 Mdot
.37112 .59068 Mdot
.48628 .0976 Mdot
.49198 .02713 Mdot
.51481 .50802 Mdot
.56318 .61216 Mdot
.92228 .38924 Mdot
.43579 .54728 Mdot
.52414 .58193 Mdot
.38437 .02578 Mdot
.52195 .50265 Mdot
.61908 .08605 Mdot
.76537 .12665 Mdot
.53491 .59888 Mdot
.64818 .09421 Mdot
.54526 .58562 Mdot
.52315 .50184 Mdot
.59424 .5005 Mdot
.44616 .55752 Mdot
.87564 .17182 Mdot
.48089 .56999 Mdot
.19239 .26051 Mdot
.63521 .09175 Mdot
.63696 .10074 Mdot
.34666 .57979 Mdot
.43277 .11956 Mdot
.60684 .57627 Mdot
.33134 .19467 Mdot
.25612 .54252 Mdot
.68019 .04567 Mdot
.36616 .58171 Mdot
.42005 .54686 Mdot
.63151 .07242 Mdot
.32003 .56516 Mdot
.51802 .57989 Mdot
.39476 .53332 Mdot
.62373 .60151 Mdot
.38601 .5926 Mdot
.44909 .55449 Mdot
.5229 .49898 Mdot
.55205 .58777 Mdot
.49381 .10301 Mdot
.46833 .1213 Mdot
.56644 .54975 Mdot
.68943 .11631 Mdot
.49985 .05162 Mdot
.7187 .12747 Mdot
.6056 .4991 Mdot
.64016 .48804 Mdot
.73629 .13865 Mdot
.42574 .55158 Mdot
.64054 .60931 Mdot
.04097 .23614 Mdot
.38894 .5911 Mdot
.49888 .11253 Mdot
.41359 .04998 Mdot
.60257 .07749 Mdot
.42052 .54705 Mdot
.54063 .58547 Mdot
.35975 .5775 Mdot
.78374 .1349 Mdot
.47903 .1228 Mdot
.35811 .5838 Mdot
.24083 .26759 Mdot
.41658 .60125 Mdot
.95786 .18737 Mdot
.63849 .48747 Mdot
.98447 .21486 Mdot
.38502 .02905 Mdot
.31227 .56408 Mdot
.42715 .05732 Mdot
.35057 .58467 Mdot
.73726 .13672 Mdot
.49084 .1057 Mdot
.47668 .0217 Mdot
.62808 .59778 Mdot
.7304 .06583 Mdot
.52022 .04021 Mdot
.39027 .03261 Mdot
.24387 .537 Mdot
.18499 .51216 Mdot
.55789 .59238 Mdot
.39255 .0242 Mdot
.53899 .53045 Mdot
.83215 .15433 Mdot
.64571 .09631 Mdot
.59765 .60443 Mdot
.67457 .11657 Mdot
.43957 .55475 Mdot
.47419 .01697 Mdot
.48096 .12078 Mdot
.33064 .57308 Mdot
.48611 .11951 Mdot
.40428 .60348 Mdot
.47578 .56979 Mdot
.23546 .2665 Mdot
.64582 .60958 Mdot
.40067 .59646 Mdot
.19055 .51215 Mdot
.36086 .13491 Mdot
.55606 .04001 Mdot
.4011 .01984 Mdot
.16275 .25379 Mdot
.33881 .57035 Mdot
.25644 .5436 Mdot
.57447 .55408 Mdot
.27317 .54463 Mdot
.515 .03616 Mdot
.297 .55737 Mdot
.65472 .08067 Mdot
.31543 .56729 Mdot
.51073 .03377 Mdot
.62526 .06885 Mdot
.46032 .56474 Mdot
.49584 .11186 Mdot
.6688 .44859 Mdot
.38472 .02069 Mdot
.73422 .06892 Mdot
.37661 .59194 Mdot
.26701 .52018 Mdot
.22225 .52841 Mdot
.4086 .04111 Mdot
.6264 .61052 Mdot
.66302 .10654 Mdot
.39083 .53588 Mdot
.57239 .06091 Mdot
.42722 .6147 Mdot
.43112 .03052 Mdot
.44651 .55461 Mdot
.50303 .11476 Mdot
.49108 .10196 Mdot
.71006 .05718 Mdot
.40139 .03777 Mdot
.65349 .10617 Mdot
.49679 .10669 Mdot
.2264 .52965 Mdot
.5516 .53868 Mdot
.53889 .53113 Mdot
.19747 .49154 Mdot
.31619 .56195 Mdot
.31235 .24911 Mdot
.50553 .05326 Mdot
.02158 .22818 Mdot
.4941 .1072 Mdot
.45826 .12041 Mdot
.45521 .0121 Mdot
.44295 .5524 Mdot
.93775 .19654 Mdot
.68221 .09221 Mdot
.67988 .11321 Mdot
.39358 .02846 Mdot
.42113 .60293 Mdot
.62965 .02447 Mdot
.41048 .04259 Mdot
.44753 .56119 Mdot
.27886 .54558 Mdot
.47514 .01639 Mdot
.47566 .57309 Mdot
.3939 .02989 Mdot
.53961 .58558 Mdot
.76138 .14652 Mdot
.15097 .25073 Mdot
.59416 .00757 Mdot
.67845 .11541 Mdot
.23289 .5286 Mdot
.55137 .53966 Mdot
.53797 .0485 Mdot
.62511 .59815 Mdot
.39268 .5358 Mdot
.64342 .48712 Mdot
.54531 .04958 Mdot
.53248 .5986 Mdot
.63703 .60211 Mdot
.38624 .02836 Mdot
.42564 .54972 Mdot
.81727 .14787 Mdot
.41864 .54923 Mdot
.64418 .09757 Mdot
.40999 .04197 Mdot
.59747 .08714 Mdot
.52972 .50304 Mdot
.41475 .54016 Mdot
.45087 .12021 Mdot
.57303 .55309 Mdot
.46129 .60179 Mdot
.68348 .11845 Mdot
.50832 .57377 Mdot
.62386 .08285 Mdot
.69103 .04963 Mdot
.53282 .03103 Mdot
.65091 .10441 Mdot
.41312 .04491 Mdot
.48378 .09763 Mdot
.59534 .56817 Mdot
.23812 .53 Mdot
.56468 .59655 Mdot
.68905 .11344 Mdot
.31746 .24141 Mdot
.20451 .26265 Mdot
.25627 .54116 Mdot
.51724 .50163 Mdot
.50228 .58382 Mdot
.37571 .58888 Mdot
.64594 .09422 Mdot
.62935 .59751 Mdot
.67464 .11628 Mdot
.58369 .59667 Mdot
.70694 .12872 Mdot
.67674 .11045 Mdot
.46455 .56544 Mdot
.34377 .15147 Mdot
.40686 .53876 Mdot
.63574 .07291 Mdot
.63891 .60385 Mdot
.64773 .4836 Mdot
.25347 .26711 Mdot
.70246 .05411 Mdot
.75652 .0777 Mdot
.65551 .10269 Mdot
.44695 .07289 Mdot
.53156 .58484 Mdot
.47378 .0419 Mdot
.38908 .59167 Mdot
.60472 .49801 Mdot
.43061 .00045 Mdot
.58676 .5628 Mdot
.53095 .06127 Mdot
.54453 .0488 Mdot
.47462 .09236 Mdot
.69947 .12039 Mdot
.55336 .0556 Mdot
.49586 .58255 Mdot
.54991 .05299 Mdot
.72457 .13298 Mdot
.66015 .03567 Mdot
.59617 .60072 Mdot
.3923 .533 Mdot
.45122 .55843 Mdot
.64659 .09478 Mdot
.40121 .0315 Mdot
.42481 .54869 Mdot
.48505 .02359 Mdot
.55018 .54037 Mdot
.46921 .0384 Mdot
.38044 .12403 Mdot
.44694 .55852 Mdot
.61403 .09233 Mdot
.3862 .59934 Mdot
.71343 .35582 Mdot
.32517 .56964 Mdot
.38231 .59298 Mdot
.47045 .1225 Mdot
.60645 .08907 Mdot
.55489 .06907 Mdot
.60895 .60309 Mdot
.19563 .51466 Mdot
.66264 .10606 Mdot
.55553 .03989 Mdot
.63225 .60802 Mdot
.45503 .56193 Mdot
.46237 .0152 Mdot
.33487 .17381 Mdot
.42074 .54905 Mdot
.21747 .52629 Mdot
.71585 .12989 Mdot
.32804 .21475 Mdot
.54674 .49998 Mdot
.10319 .23755 Mdot
.38624 .01932 Mdot
.57452 .07868 Mdot
.48577 .0987 Mdot
.3631 .56028 Mdot
.68361 .1178 Mdot
.4554 .55883 Mdot
.34361 .14873 Mdot
.46943 .56129 Mdot
.49057 .01322 Mdot
.29445 .55303 Mdot
.39533 .03486 Mdot
.75387 .14435 Mdot
.20601 .52106 Mdot
.63854 .59968 Mdot
.39799 .02341 Mdot
.52543 .04157 Mdot
.2989 .56261 Mdot
.45325 .00765 Mdot
.39646 .03106 Mdot
.41936 .05309 Mdot
.58928 .06748 Mdot
.45802 .00949 Mdot
.45496 .56038 Mdot
.61582 .01854 Mdot
.43088 .54894 Mdot
.79623 .0943 Mdot
.56372 .05648 Mdot
.77888 .35391 Mdot
.35404 .58071 Mdot
.55449 .05181 Mdot
.5359 .5825 Mdot
.4603 .56002 Mdot
.59489 .08332 Mdot
.42088 .05196 Mdot
.7135 .12601 Mdot
.77513 .11559 Mdot
.35166 .13875 Mdot
.66005 .469 Mdot
.24868 .53786 Mdot
.50908 .57783 Mdot
.56961 .59517 Mdot
.41444 .02697 Mdot
.25053 .53661 Mdot
.51863 .50122 Mdot
.4479 .55236 Mdot
.38852 .58877 Mdot
.71323 .12825 Mdot
.60875 .07683 Mdot
.42883 .55052 Mdot
.56117 .54832 Mdot
.37959 .52739 Mdot
.51488 .50751 Mdot
.43867 .55337 Mdot
.32168 .56308 Mdot
.38053 .5297 Mdot
.46499 .08498 Mdot
.1401 .26944 Mdot
.68639 .11191 Mdot
.68255 .37944 Mdot
.23464 .29622 Mdot
.32839 .21352 Mdot
.53265 .04299 Mdot
.59165 .60388 Mdot
.64825 .48177 Mdot
.32392 .56263 Mdot
.55858 .07225 Mdot
.55197 .05362 Mdot
.44497 .6115 Mdot
.4289 .61675 Mdot
.39444 .12331 Mdot
.5114 .50831 Mdot
.50081 .11975 Mdot
.53468 .60018 Mdot
.41462 .60216 Mdot
.57442 .61709 Mdot
.34617 .14643 Mdot
.62691 .58945 Mdot
.72987 .11248 Mdot
.16019 .25329 Mdot
.2257 .52547 Mdot
.39173 .03411 Mdot
.68854 .11958 Mdot
.66959 .07192 Mdot
.60694 .49891 Mdot
.63587 .59835 Mdot
.63022 .09907 Mdot
.44636 .55827 Mdot
.48707 .57902 Mdot
.58186 .05016 Mdot
.61578 .60574 Mdot
.44767 .07454 Mdot
.52088 .5776 Mdot
.52437 .58342 Mdot
.624 .0845 Mdot
.45624 .00014 Mdot
.42113 .02806 Mdot
.42672 .02553 Mdot
.22326 .53053 Mdot
.70967 .12825 Mdot
.48802 .01251 Mdot
.42525 .0588 Mdot
.62242 .09434 Mdot
.17757 .50872 Mdot
.54912 .49936 Mdot
.20885 .51885 Mdot
.45465 .00926 Mdot
.49444 .56927 Mdot
.12108 .46127 Mdot
.46756 .08763 Mdot
.34054 .15638 Mdot
.52544 .02634 Mdot
.76838 .15081 Mdot
.04484 .21858 Mdot
.34715 .57286 Mdot
.68935 .07996 Mdot
.4606 .08163 Mdot
.6844 .37532 Mdot
.35434 .57718 Mdot
.67516 .40649 Mdot
.76145 .1456 Mdot
.51853 .03747 Mdot
.40808 .5389 Mdot
.58896 .08076 Mdot
.66404 .10846 Mdot
.07235 .4424 Mdot
.32712 .56686 Mdot
.2685 .54415 Mdot
.56823 .55234 Mdot
.10353 .23751 Mdot
.39755 .02396 Mdot
.63104 .60928 Mdot
.67385 .08866 Mdot
.67417 .40259 Mdot
.38608 .59815 Mdot
.42757 .60669 Mdot
.57105 .61643 Mdot
.2985 .25857 Mdot
.53005 .50075 Mdot
.66213 .10148 Mdot
.81077 .10085 Mdot
.5437 .58559 Mdot
.40247 .02268 Mdot
.47618 .56529 Mdot
.73496 .13389 Mdot
.70909 .12422 Mdot
.37181 .59174 Mdot
.40549 .59653 Mdot
.67348 .11165 Mdot
.20145 .26215 Mdot
.45085 .07225 Mdot
.36131 .58138 Mdot
.48374 .12283 Mdot
.4493 .03419 Mdot
.31612 .56864 Mdot
.58094 .08108 Mdot
.53928 .53207 Mdot
.32776 .5727 Mdot
.7695 .15106 Mdot
.78426 .1346 Mdot
.32799 .56647 Mdot
.40059 .04062 Mdot
.42843 .0295 Mdot
.29684 .55972 Mdot
.69905 .05402 Mdot
.30875 .25304 Mdot
.66308 .46479 Mdot
.61502 .06468 Mdot
.30737 .55616 Mdot
.47027 .57071 Mdot
.44013 .12062 Mdot
.59926 .60374 Mdot
.62492 .08407 Mdot
.43943 .03042 Mdot
.64185 .48871 Mdot
.62902 .09471 Mdot
.63024 .5916 Mdot
.36665 .56173 Mdot
.34546 .582 Mdot
.43548 .0303 Mdot
.67137 .0881 Mdot
.04956 .4336 Mdot
.35366 .13746 Mdot
.66835 .44845 Mdot
.27481 .54637 Mdot
.66624 .10677 Mdot
.62193 .08411 Mdot
.20327 .51682 Mdot
.6945 .12203 Mdot
.70373 .11947 Mdot
.52816 .04254 Mdot
.58423 .00373 Mdot
.34499 .57315 Mdot
.40694 .60388 Mdot
.67022 .43488 Mdot
.67238 .41718 Mdot
.73774 .14002 Mdot
.43529 .02726 Mdot
.30867 .56454 Mdot
.37352 .58986 Mdot
.66574 .45849 Mdot
.53327 .52312 Mdot
.46866 .08723 Mdot
.50647 .57627 Mdot
.48996 .02452 Mdot
.46199 .08024 Mdot
.51364 .50926 Mdot
.57424 .61592 Mdot
.28833 .55552 Mdot
.67134 .42917 Mdot
.83081 .11066 Mdot
.6819 .11034 Mdot
.54769 .05234 Mdot
.51167 .05511 Mdot
.71679 .09156 Mdot
.61817 .0951 Mdot
.39832 .0391 Mdot
.69056 .04956 Mdot
.48491 .6119 Mdot
.46937 .56466 Mdot
.41094 .12108 Mdot
.6576 .10457 Mdot
.35213 .13958 Mdot
.43874 .55236 Mdot
.56992 .07453 Mdot
.66951 .1044 Mdot
.94264 .39563 Mdot
.56305 .54661 Mdot
.48994 .0263 Mdot
.53293 .58367 Mdot
.40146 .03956 Mdot
.64435 .60967 Mdot
.63481 .59567 Mdot
.42863 .12115 Mdot
.65937 .10191 Mdot
.61114 .60312 Mdot
.7216 .06321 Mdot
.68589 .11413 Mdot
.48089 .02057 Mdot
.46688 .04 Mdot
.25049 .5354 Mdot
.53185 .5281 Mdot
.4196 .02868 Mdot
.62763 .60307 Mdot
.5611 .59004 Mdot
.3944 .59161 Mdot
.71459 .12606 Mdot
.61591 .092 Mdot
.54996 .06817 Mdot
.14172 .27034 Mdot
.73731 .1159 Mdot
.32355 .22709 Mdot
.42636 .60392 Mdot
.57996 .00259 Mdot
.54364 .06588 Mdot
.53512 .03182 Mdot
.55257 .54099 Mdot
.2005 .5168 Mdot
.49802 .02736 Mdot
.43263 .1215 Mdot
.48935 .57962 Mdot
.42136 .05141 Mdot
.63132 .60385 Mdot
.52618 .02741 Mdot
.32394 .23063 Mdot
.29196 .55501 Mdot
.58119 .0666 Mdot
.86782 .16855 Mdot
.62798 .09841 Mdot
.55263 .6062 Mdot
.51194 .03722 Mdot
.51375 .0347 Mdot
.34556 .5775 Mdot
.18657 .25951 Mdot
.48144 .09696 Mdot
.52209 .50042 Mdot
.63282 .60213 Mdot
.68827 .12054 Mdot
.18093 .2578 Mdot
.61614 .07944 Mdot
.74662 .07297 Mdot
.48257 .0439 Mdot
.39953 .53614 Mdot
.53741 .03206 Mdot
.47009 .12146 Mdot
.54515 .04865 Mdot
.19941 .51937 Mdot
.58233 .50012 Mdot
.39604 .60125 Mdot
.34547 .57522 Mdot
.56224 .54732 Mdot
.52239 .51122 Mdot
.5642 .59214 Mdot
.59048 .08287 Mdot
.75911 .07917 Mdot
.45226 .00697 Mdot
.72624 .13272 Mdot
.81598 .10317 Mdot
.68459 .11256 Mdot
.466 .01436 Mdot
.02339 .22944 Mdot
.91494 .18735 Mdot
.67811 .11108 Mdot
.52166 .02679 Mdot
.75491 .35125 Mdot
.62525 .60662 Mdot
.50898 .50639 Mdot
.59902 .08653 Mdot
.32423 .57153 Mdot
.45104 .03431 Mdot
.53731 .52793 Mdot
.65852 .08345 Mdot
.46001 .60134 Mdot
.32956 .5751 Mdot
.57566 .07739 Mdot
.5954 .00857 Mdot
.42427 .54677 Mdot
.56804 .04542 Mdot
.60781 .07844 Mdot
.61374 .58548 Mdot
.31796 .57081 Mdot
.31836 .56537 Mdot
.65582 .10188 Mdot
.82902 .15294 Mdot
.43036 .12024 Mdot
.47578 .56506 Mdot
.82931 .15354 Mdot
.64628 .0298 Mdot
.3906 .5997 Mdot
.61227 .60645 Mdot
.74203 .07185 Mdot
.26792 .54636 Mdot
.46938 .57181 Mdot
.52162 .58093 Mdot
.41718 .02747 Mdot
.54418 .53212 Mdot
.44105 .60978 Mdot
.5912 .0062 Mdot
.46908 .56306 Mdot
.61479 .61028 Mdot
.62417 .59928 Mdot
.2507 .53785 Mdot
.4263 .54355 Mdot
.81848 .10515 Mdot
.57698 .555 Mdot
.24046 .53088 Mdot
.54034 .06283 Mdot
.3184 .56894 Mdot
.41748 .61103 Mdot
.62878 .09113 Mdot
.4107 .60545 Mdot
.63809 .09686 Mdot
.4783 .12323 Mdot
.43884 .60978 Mdot
.61018 .60811 Mdot
.37379 .58378 Mdot
.09944 .25637 Mdot
.23576 .5305 Mdot
.01524 .42114 Mdot
.611 .57741 Mdot
.48696 .10238 Mdot
.49502 .12338 Mdot
.25622 .54217 Mdot
.70448 .1194 Mdot
.39201 .02272 Mdot
.65877 .10661 Mdot
.41461 .04817 Mdot
.30298 .55732 Mdot
.55766 .07152 Mdot
.22207 .52647 Mdot
.12326 .46216 Mdot
.35152 .58376 Mdot
.41233 .60868 Mdot
.48213 .09763 Mdot
.2674 .54705 Mdot
.32355 .56256 Mdot
.44709 .12203 Mdot
.55971 .59014 Mdot
.26711 .54749 Mdot
.49512 .10764 Mdot
.00877 .2061 Mdot
.46206 .083 Mdot
.58323 .60003 Mdot
.39686 .59568 Mdot
.51916 .5182 Mdot
.5696 .55159 Mdot
.69408 .1232 Mdot
.5926 .59962 Mdot
.64526 .48636 Mdot
.169 .50554 Mdot
.84053 .14205 Mdot
.49868 .04982 Mdot
.19314 .51524 Mdot
.73083 .06645 Mdot
.26709 .54437 Mdot
.58139 .56183 Mdot
.46428 .12108 Mdot
.51115 .57663 Mdot
.54392 .03451 Mdot
.26287 .54447 Mdot
.32598 .56973 Mdot
.26736 .54716 Mdot
.62027 .09577 Mdot
.30427 .25655 Mdot
.62601 .09744 Mdot
.61198 .49738 Mdot
.65331 .10547 Mdot
.27982 .54506 Mdot
.65076 .48225 Mdot
.49743 .01607 Mdot
.62577 .60576 Mdot
.66113 .03605 Mdot
.42627 .0286 Mdot
.47414 .57386 Mdot
.48493 .57031 Mdot
.30979 .56548 Mdot
.75848 .14412 Mdot
.73213 .13684 Mdot
.3989 .59361 Mdot
.49456 .04814 Mdot
.46241 .01237 Mdot
.40652 .60554 Mdot
.34316 .14896 Mdot
.66332 .10474 Mdot
.55678 .60805 Mdot
.43391 .06415 Mdot
.96839 .20803 Mdot
.36405 .58287 Mdot
.47153 .04186 Mdot
.39183 .53534 Mdot
.40181 .04178 Mdot
.70059 .11905 Mdot
.3 .55444 Mdot
.08858 .2531 Mdot
.77555 .35303 Mdot
.55776 .54339 Mdot
.47996 .09379 Mdot
.70199 .12283 Mdot
.48162 .04546 Mdot
.43651 .60852 Mdot
.17767 .50926 Mdot
.51189 .03517 Mdot
.40135 .02958 Mdot
.64127 .60947 Mdot
.42854 .05927 Mdot
.57843 .50114 Mdot
.57414 .61747 Mdot
.79972 .09622 Mdot
.65236 .09773 Mdot
.37511 .12732 Mdot
.51998 .51201 Mdot
.78348 .35389 Mdot
.52039 .51424 Mdot
.38593 .59735 Mdot
.37075 .58263 Mdot
.58431 .06603 Mdot
.51233 .50536 Mdot
.52178 .0595 Mdot
.43118 .54536 Mdot
.40049 .03131 Mdot
.65866 .10825 Mdot
.71872 .06108 Mdot
.47422 .08873 Mdot
.45725 .07981 Mdot
.42445 .55022 Mdot
.32496 .56647 Mdot
.61832 .49615 Mdot
.52889 .50462 Mdot
.25347 .53604 Mdot
.41503 .60225 Mdot
.67414 .11259 Mdot
.62112 .59412 Mdot
.60226 .60644 Mdot
.33626 .16789 Mdot
.45367 .03313 Mdot
.32508 .5703 Mdot
.74945 .14324 Mdot
.09492 .25439 Mdot
.59464 .60022 Mdot
.67175 .08886 Mdot
.45231 .12236 Mdot
.60662 .57467 Mdot
.65708 .09984 Mdot
.39547 .5938 Mdot
.71481 .12581 Mdot
.67437 .4017 Mdot
.54889 .03677 Mdot
.64714 .09573 Mdot
.44645 .06951 Mdot
.51159 .03428 Mdot
.56339 .59334 Mdot
.44829 .614 Mdot
.32698 .56616 Mdot
.34034 .57381 Mdot
.42141 .54992 Mdot
.17576 .28058 Mdot
.43904 .03032 Mdot
.75943 .14719 Mdot
.57753 .06292 Mdot
.26983 .54693 Mdot
.99015 .1996 Mdot
.60203 .57263 Mdot
.43637 .55354 Mdot
.56796 .59196 Mdot
.88477 .37767 Mdot
.40943 .04683 Mdot
.56738 .59532 Mdot
.41671 .02399 Mdot
.44573 .07185 Mdot
.48253 .57561 Mdot
.31314 .55913 Mdot
.37199 .52627 Mdot
.65825 .10075 Mdot
.59306 .00747 Mdot
.48778 .10519 Mdot
.58943 .07108 Mdot
.56273 .54899 Mdot
.68477 .37858 Mdot
.59848 .57124 Mdot
.70025 .11933 Mdot
.67635 .11332 Mdot
.43989 .0682 Mdot
.3739 .58568 Mdot
.55394 .54357 Mdot
.46487 .56802 Mdot
.32373 .23147 Mdot
.49296 .10834 Mdot
.59904 .08698 Mdot
.38737 .5346 Mdot
.24334 .26754 Mdot
.41833 .60003 Mdot
.58109 .0779 Mdot
.62134 .59485 Mdot
.55386 .53928 Mdot
.3917 .03311 Mdot
.34355 .57325 Mdot
.67072 .1146 Mdot
.71427 .13087 Mdot
.58164 .04997 Mdot
.82265 .10598 Mdot
.33 .57272 Mdot
.66877 .10726 Mdot
.58896 .07134 Mdot
.77909 .08685 Mdot
.66775 .44373 Mdot
.24829 .53898 Mdot
.69067 .09652 Mdot
.44492 .55482 Mdot
.59423 .5721 Mdot
.73395 .13637 Mdot
.1131 .2404 Mdot
.6764 .11568 Mdot
.55113 .05052 Mdot
.25669 .54235 Mdot
.47438 .00691 Mdot
.36754 .59172 Mdot
.50198 .11489 Mdot
.06398 .24366 Mdot
.7582 .14659 Mdot
.23599 .53225 Mdot
.53633 .52656 Mdot
.96166 .40211 Mdot
.43138 .61801 Mdot
.49313 .0155 Mdot
.54016 .58564 Mdot
.50661 .01964 Mdot
.16624 .25483 Mdot
.4854 .57563 Mdot
.13329 .26778 Mdot
.50092 .57459 Mdot
.5767 .49898 Mdot
.48966 .56836 Mdot
.58831 .59839 Mdot
.52254 .0267 Mdot
.62646 .09757 Mdot
.6246 .61075 Mdot
.53549 .49975 Mdot
.38559 .53096 Mdot
.49216 .57852 Mdot
.61869 .60706 Mdot
.49679 .57252 Mdot
.63762 .60008 Mdot
.63587 .08997 Mdot
.30593 .55516 Mdot
.59971 .04234 Mdot
.53637 .58471 Mdot
.41169 .59854 Mdot
.49385 .57206 Mdot
.39519 .03529 Mdot
.32349 .56423 Mdot
.65045 .1062 Mdot
.472 .03912 Mdot
.6756 .39593 Mdot
.41953 .05372 Mdot
.31969 .56916 Mdot
.67506 .10584 Mdot
.5146 .50014 Mdot
.33426 .17119 Mdot
.39993 .03824 Mdot
.4432 .12143 Mdot
.18429 .51184 Mdot
.35765 .13377 Mdot
.35164 .13979 Mdot
.45661 .01293 Mdot
.3667 .57953 Mdot
.91607 .17174 Mdot
.50338 .58725 Mdot
.33505 .57217 Mdot
.60306 .08518 Mdot
.51615 .50318 Mdot
.57348 .55443 Mdot
.6369 .07337 Mdot
.57049 .55306 Mdot
.4845 .1218 Mdot
.52737 .04402 Mdot
.61635 .09279 Mdot
.3495 .57416 Mdot
.00692 .41812 Mdot
.47787 .01958 Mdot
.3195 .23647 Mdot
.59734 .0566 Mdot
.54846 .53665 Mdot
.48203 .01083 Mdot
.41468 .53989 Mdot
.39056 .02672 Mdot
.28754 .55316 Mdot
.63561 .0909 Mdot
.21732 .26507 Mdot
.4964 .01588 Mdot
.19516 .51392 Mdot
.44869 .56174 Mdot
.46782 .60442 Mdot
.6334 .6089 Mdot
.56136 .54764 Mdot
.48795 .12224 Mdot
.62754 .02224 Mdot
.27336 .55052 Mdot
.59914 .49972 Mdot
.53202 .52359 Mdot
.94108 .19738 Mdot
.61476 .60119 Mdot
.52724 .59477 Mdot
.56431 .50145 Mdot
.41393 .0244 Mdot
.68854 .04891 Mdot
.465 .55802 Mdot
.67672 .10935 Mdot
.58712 .50096 Mdot
.45623 .01144 Mdot
.1826 .51141 Mdot
.68145 .11677 Mdot
.31402 .55829 Mdot
.51886 .51335 Mdot
.93721 .19602 Mdot
.49423 .57198 Mdot
.20792 .26307 Mdot
.55485 .60729 Mdot
.39431 .53414 Mdot
.61986 .59342 Mdot
.30709 .55537 Mdot
.73908 .13861 Mdot
.73015 .06616 Mdot
.21492 .52174 Mdot
.58202 .60096 Mdot
.44397 .00381 Mdot
.68539 .04794 Mdot
.38848 .03204 Mdot
.56057 .05524 Mdot
.70122 .1235 Mdot
.44045 .06624 Mdot
.52224 .51759 Mdot
.32982 .19485 Mdot
.38563 .59608 Mdot
.65025 .4788 Mdot
.40037 .60407 Mdot
.61398 .496 Mdot
.54585 .58897 Mdot
.62356 .60107 Mdot
.39784 .03261 Mdot
.67702 .11282 Mdot
.39629 .60381 Mdot
.53828 .50141 Mdot
.72421 .13365 Mdot
.401 .60501 Mdot
.86368 .16781 Mdot
.566 .49961 Mdot
.44268 .55477 Mdot
.17301 .50848 Mdot
.4821 .57014 Mdot
.40025 .60125 Mdot
.48976 .11734 Mdot
.68133 .09153 Mdot
.37337 .58637 Mdot
.41755 .60284 Mdot
.39862 .53745 Mdot
.56235 .04205 Mdot
.57314 .5564 Mdot
.47169 .03998 Mdot
.57654 .5009 Mdot
.50553 .05134 Mdot
.97654 .40738 Mdot
.28959 .54929 Mdot
.42129 .61135 Mdot
.91549 .18764 Mdot
.09516 .25486 Mdot
.61677 .49744 Mdot
.32174 .5654 Mdot
.5906 .59964 Mdot
.48771 .10114 Mdot
.4508 .00536 Mdot
.62079 .49624 Mdot
.47778 .57033 Mdot
.13514 .26785 Mdot
.54435 .60376 Mdot
.59799 .59974 Mdot
.47401 .56391 Mdot
.52516 .52278 Mdot
.54478 .03526 Mdot
.51157 .05412 Mdot
.68182 .11359 Mdot
.58032 .55696 Mdot
.55834 .60979 Mdot
.26856 .54869 Mdot
.4618 .5628 Mdot
.22986 .53006 Mdot
.27492 .54305 Mdot
.3846 .0219 Mdot
.57036 .04623 Mdot
.38893 .53078 Mdot
.18349 .51213 Mdot
.6121 .07924 Mdot
.05796 .43694 Mdot
.66528 .11159 Mdot
.62973 .60419 Mdot
.66779 .10545 Mdot
.5301 .52249 Mdot
.57444 .06451 Mdot
.62571 .60636 Mdot
.65548 .47742 Mdot
.28472 .26459 Mdot
.07244 .24692 Mdot
.32638 .21943 Mdot
.60545 .57828 Mdot
.63701 .61207 Mdot
.37715 .59274 Mdot
.26828 .54455 Mdot
.65371 .03387 Mdot
.54947 .05059 Mdot
.48365 .56419 Mdot
.27862 .26542 Mdot
.62988 .02424 Mdot
.53019 .58347 Mdot
.42859 .55255 Mdot
.62027 .0918 Mdot
.73882 .11659 Mdot
.50546 .05117 Mdot
.44398 .55929 Mdot
.35148 .57643 Mdot
.73255 .0683 Mdot
.55779 .61125 Mdot
.62314 .08829 Mdot
.43114 .61643 Mdot
.37767 .59017 Mdot
.43265 .06423 Mdot
.72189 .13314 Mdot
.9665 .20811 Mdot
.38705 .59577 Mdot
.65584 .47567 Mdot
.66203 .11021 Mdot
.69626 .12468 Mdot
.39595 .0235 Mdot
.50386 .11406 Mdot
.48598 .02338 Mdot
.50033 .04926 Mdot
.47391 .57 Mdot
.7352 .06854 Mdot
.66026 .1107 Mdot
.41684 .5465 Mdot
.60637 .08009 Mdot
.32137 .56275 Mdot
.63217 .60319 Mdot
.48424 .1221 Mdot
.35844 .58103 Mdot
.50756 .5763 Mdot
.69936 .0526 Mdot
.42652 .1206 Mdot
.86435 .16699 Mdot
.79587 .35604 Mdot
.6858 .12036 Mdot
.44163 .5494 Mdot
.37309 .58951 Mdot
.21795 .26478 Mdot
.49711 .11585 Mdot
.145 .27128 Mdot
.39468 .60128 Mdot
.23683 .53434 Mdot
.63339 .09133 Mdot
.43208 .03004 Mdot
.38919 .59913 Mdot
.46917 .56946 Mdot
.61762 .49648 Mdot
.33284 .57522 Mdot
.73855 .1362 Mdot
.4353 .03135 Mdot
.44516 .55839 Mdot
.67886 .11796 Mdot
.49725 .12246 Mdot
.73102 .13489 Mdot
.72473 .13103 Mdot
.57694 .55484 Mdot
.38719 .59983 Mdot
.47897 .57332 Mdot
.60944 .09026 Mdot
.45041 .55299 Mdot
.96635 .20709 Mdot
.41515 .61135 Mdot
.23696 .53091 Mdot
.54978 .50006 Mdot
.5324 .06155 Mdot
.34755 .57882 Mdot
.98422 .21416 Mdot
.61807 .08106 Mdot
.60431 .60499 Mdot
.38557 .02264 Mdot
.48921 .10699 Mdot
.58918 .56787 Mdot
.39816 .02059 Mdot
.74711 .14146 Mdot
.39506 .59819 Mdot
.63048 .60404 Mdot
.44109 .55341 Mdot
.46667 .03976 Mdot
.61617 .60824 Mdot
.79851 .14102 Mdot
.17861 .50957 Mdot
.68922 .37103 Mdot
.51073 .5094 Mdot
.44191 .61018 Mdot
.37966 .5867 Mdot
.48586 .09806 Mdot
.60684 .57596 Mdot
.44275 .55144 Mdot
.59604 .00866 Mdot
.5447 .04885 Mdot
.48944 .01195 Mdot
.37262 .58441 Mdot
.42488 .60311 Mdot
.33018 .18964 Mdot
.47312 .04096 Mdot
.61787 .09386 Mdot
.33936 .57526 Mdot
.53643 .52592 Mdot
.60026 .07237 Mdot
.65422 .08054 Mdot
.61162 .09151 Mdot
.39144 .12444 Mdot
.42901 .0614 Mdot
.34528 .14552 Mdot
.69412 .11653 Mdot
.83715 .11315 Mdot
.65464 .03434 Mdot
.44541 .12049 Mdot
.6395 .48809 Mdot
.64676 .48306 Mdot
.46172 .01267 Mdot
.49942 .11011 Mdot
.59498 .50053 Mdot
.6261 .61063 Mdot
.67839 .10827 Mdot
.7171 .12922 Mdot
.18976 .5126 Mdot
.70901 .12675 Mdot
.0886 .25298 Mdot
.43657 .55616 Mdot
.6503 .10526 Mdot
.39497 .59319 Mdot
.90252 .18314 Mdot
.52432 .49891 Mdot
.49238 .04592 Mdot
.56221 .54878 Mdot
.52293 .59457 Mdot
.42357 .61323 Mdot
.56087 .61205 Mdot
.58221 .00346 Mdot
.3936 .53396 Mdot
.12928 .26616 Mdot
.72679 .13203 Mdot
.40808 .54367 Mdot
.37107 .58944 Mdot
.63837 .09564 Mdot
.46528 .56381 Mdot
.42695 .02913 Mdot
.30498 .55509 Mdot
.65013 .10085 Mdot
.30318 .5631 Mdot
.38619 .03017 Mdot
.43706 .02817 Mdot
.48449 .04346 Mdot
.48568 .57722 Mdot
.26162 .5178 Mdot
.32601 .22187 Mdot
.40428 .59807 Mdot
.50618 .11859 Mdot
.60259 .60132 Mdot
.28646 .26406 Mdot
.37393 .12592 Mdot
.47202 .08966 Mdot
.28881 .5585 Mdot
.30454 .56342 Mdot
.30527 .53619 Mdot
.42781 .60666 Mdot
.38547 .59011 Mdot
.90468 .38335 Mdot
.58167 .60115 Mdot
.47507 .5736 Mdot
.33589 .57274 Mdot
.33994 .57658 Mdot
.52585 .5185 Mdot
.59887 .6011 Mdot
.92896 .39127 Mdot
.46553 .04055 Mdot
.54134 .58826 Mdot
.38463 .01782 Mdot
.34443 .15078 Mdot
.64974 .48259 Mdot
.40976 .53789 Mdot
.51736 .57901 Mdot
.49459 .11704 Mdot
.62057 .60024 Mdot
.66924 .44307 Mdot
.59906 .60504 Mdot
.51469 .58002 Mdot
.44208 .00242 Mdot
.17897 .51132 Mdot
.48993 .57162 Mdot
.53943 .06245 Mdot
.60583 .06161 Mdot
.64471 .48302 Mdot
.65374 .10012 Mdot
.74451 .11821 Mdot
.64193 .48591 Mdot
.44075 .02952 Mdot
.54453 .50037 Mdot
.54859 .0667 Mdot
.68106 .11033 Mdot
.6077 .08832 Mdot
.60908 .07665 Mdot
.20205 .51731 Mdot
.54916 .03817 Mdot
.42459 .1198 Mdot
.48864 .56948 Mdot
.51649 .05595 Mdot
.63529 .09113 Mdot
.24157 .53219 Mdot
.40735 .02658 Mdot
.53469 .58175 Mdot
.49903 .03061 Mdot
.56876 .05893 Mdot
.50281 .57251 Mdot
.58358 .06647 Mdot
.77729 .11637 Mdot
.49108 .56871 Mdot
.29284 .26233 Mdot
.58029 .06354 Mdot
.59271 .08361 Mdot
.57316 .06194 Mdot
.63556 .607 Mdot
.32969 .19895 Mdot
.90254 .38276 Mdot
.32339 .56741 Mdot
.82421 .3621 Mdot
.62461 .02185 Mdot
.28794 .55249 Mdot
.66062 .08347 Mdot
.65586 .10858 Mdot
.33667 .1663 Mdot
.22666 .52682 Mdot
.50856 .05212 Mdot
.3326 .5719 Mdot
.61048 .49809 Mdot
.67052 .43225 Mdot
.76653 .15112 Mdot
.4472 .5533 Mdot
.40609 .03857 Mdot
.41633 .12165 Mdot
.13501 .2465 Mdot
.52272 .04198 Mdot
.44226 .55214 Mdot
.63198 .07177 Mdot
.35623 .13515 Mdot
.51445 .59213 Mdot
.56273 .54784 Mdot
.31502 .56346 Mdot
.37129 .5912 Mdot
.55548 .06934 Mdot
.34098 .15452 Mdot
.5394 .50059 Mdot
.27189 .54324 Mdot
.4976 .11269 Mdot
.5922 .05621 Mdot
.73308 .13642 Mdot
.78088 .11796 Mdot
.46752 .08467 Mdot
.6388 .02696 Mdot
.38503 .02931 Mdot
.13431 .46649 Mdot
.47477 .56931 Mdot
.24759 .53934 Mdot
.65351 .10163 Mdot
.97688 .21136 Mdot
.67553 .40372 Mdot
.52615 .50399 Mdot
.39552 .59532 Mdot
.12235 .26448 Mdot
.60233 .57584 Mdot
.47167 .00529 Mdot
.62267 .0941 Mdot
.58831 .06725 Mdot
.68894 .11409 Mdot
.40025 .6028 Mdot
.2796 .54655 Mdot
.37643 .58711 Mdot
.62363 .08374 Mdot
.45849 .11997 Mdot
.73211 .11325 Mdot
.38833 .01813 Mdot
.6913 .11921 Mdot
.45982 .01244 Mdot
.18093 .50867 Mdot
.55707 .59126 Mdot
.69964 .08432 Mdot
.42631 .02922 Mdot
.80425 .35734 Mdot
.37519 .5884 Mdot
.29894 .5609 Mdot
.55415 .54001 Mdot
.40681 .59629 Mdot
.65564 .10839 Mdot
.55592 .58877 Mdot
.48969 .02609 Mdot
.44718 .55108 Mdot
.61587 .08006 Mdot
.34656 .5722 Mdot
.65188 .48112 Mdot
.45535 .12117 Mdot
.7755 .15381 Mdot
.38463 .02574 Mdot
.5755 .55826 Mdot
.55294 .05269 Mdot
.30689 .56332 Mdot
.33319 .17681 Mdot
.74614 .07352 Mdot
.4718 .56274 Mdot
.06235 .22442 Mdot
.96586 .40371 Mdot
.63099 .60387 Mdot
.34589 .58 Mdot
.51568 .03719 Mdot
.46995 .5609 Mdot
.6823 .37955 Mdot
.53899 .06472 Mdot
.68357 .11049 Mdot
.5192 .59341 Mdot
.6949 .12291 Mdot
.8372 .15599 Mdot
.41787 .54468 Mdot
.3253 .56781 Mdot
.00929 .22433 Mdot
.22224 .52322 Mdot
.59683 .60279 Mdot
.53207 .03098 Mdot
.54366 .04999 Mdot
.62407 .59549 Mdot
.56853 .59468 Mdot
.40435 .54275 Mdot
.63155 .08686 Mdot
.53898 .58428 Mdot
.46591 .08459 Mdot
.46262 .08179 Mdot
.62256 .09512 Mdot
.41184 .12065 Mdot
.51459 .057 Mdot
.69163 .11695 Mdot
.56159 .05633 Mdot
.54775 .49951 Mdot
.35576 .13531 Mdot
.40732 .53981 Mdot
.23232 .53006 Mdot
.16293 .27708 Mdot
.40996 .0264 Mdot
.47709 .09332 Mdot
.27773 .55165 Mdot
.79924 .09666 Mdot
.28232 .26463 Mdot
.32691 .21685 Mdot
.31569 .565 Mdot
.68412 .04632 Mdot
.52468 .51979 Mdot
.41598 .61312 Mdot
.51134 .50732 Mdot
.25275 .54274 Mdot
.24201 .53165 Mdot
.46918 .08587 Mdot
.69685 .05324 Mdot
.44083 .12123 Mdot
.58473 .06644 Mdot
.81956 .10473 Mdot
.35205 .58518 Mdot
.99765 .21916 Mdot
.71799 .12965 Mdot
.64126 .60807 Mdot
.62591 .59343 Mdot
.52661 .51959 Mdot
.60161 .60083 Mdot
.6169 .08518 Mdot
.38235 .52957 Mdot
.63561 .05746 Mdot
.4109 .02309 Mdot
.68387 .37707 Mdot
.67439 .11078 Mdot
.3371 .16263 Mdot
.55311 .59109 Mdot
.87803 .37571 Mdot
.29116 .55776 Mdot
.71967 .06279 Mdot
.48007 .09729 Mdot
.48616 .5651 Mdot
.61152 .58499 Mdot
.44826 .61365 Mdot
.31421 .56289 Mdot
.49416 .10877 Mdot
.44612 .55915 Mdot
.64354 .61125 Mdot
.48829 .57621 Mdot
.51336 .03741 Mdot
.46573 .55999 Mdot
.6397 .09813 Mdot
.40175 .02064 Mdot
.67485 .3995 Mdot
.53861 .5837 Mdot
.44469 .03184 Mdot
.47383 .09002 Mdot
.70878 .05843 Mdot
.51466 .51295 Mdot
.81857 .10382 Mdot
.08841 .44846 Mdot
.70461 .36027 Mdot
.3795 .52927 Mdot
.62176 .09622 Mdot
.62021 .08185 Mdot
.5123 .57946 Mdot
.33 .1984 Mdot
.44054 .12075 Mdot
.25895 .54529 Mdot
.75547 .35165 Mdot
.73565 .13372 Mdot
.61079 .49696 Mdot
.5846 .59884 Mdot
.43008 .54752 Mdot
.3294 .56431 Mdot
.63874 .0922 Mdot
.24036 .26715 Mdot
.56941 .06031 Mdot
.54628 .59066 Mdot
.44532 .55077 Mdot
.64377 .61038 Mdot
.43784 .60907 Mdot
.73281 .13226 Mdot
.40441 .0431 Mdot
.21032 .49691 Mdot
.41057 .02706 Mdot
.51101 .50685 Mdot
.54129 .04821 Mdot
.52699 .59455 Mdot
.57976 .60057 Mdot
.50056 .58207 Mdot
.38113 .58808 Mdot
.77395 .13068 Mdot
.27581 .55137 Mdot
.48518 .0965 Mdot
.49651 .12332 Mdot
.67537 .04227 Mdot
.28147 .55493 Mdot
.49323 .04684 Mdot
.63296 .59808 Mdot
.68053 .11021 Mdot
.63737 .60139 Mdot
.45727 .0085 Mdot
.44647 .06915 Mdot
.65516 .10341 Mdot
.47621 .04276 Mdot
.60867 .49717 Mdot
.56993 .55177 Mdot
.46457 .08122 Mdot
.67065 .43525 Mdot
.38302 .59493 Mdot
.54795 .53467 Mdot
.65753 .03604 Mdot
.24028 .53045 Mdot
.90472 .38332 Mdot
.52481 .05866 Mdot
.4089 .6 Mdot
.58428 .60096 Mdot
.36421 .13204 Mdot
.31126 .5674 Mdot
.47599 .56847 Mdot
.63215 .09869 Mdot
.52325 .57778 Mdot
.44685 .07112 Mdot
.69187 .3692 Mdot
.4727 .12071 Mdot
.34436 .57427 Mdot
.88214 .17466 Mdot
.53378 .58567 Mdot
.45593 .0124 Mdot
.55094 .06691 Mdot
.16743 .27823 Mdot
.68758 .11628 Mdot
.40567 .57821 Mdot
.68699 .37288 Mdot
.93281 .19473 Mdot
.50342 .57318 Mdot
.49967 .11781 Mdot
.46559 .12216 Mdot
.60378 .08888 Mdot
.49894 .12187 Mdot
.54907 .05065 Mdot
.51228 .03418 Mdot
.40573 .60482 Mdot
.71592 .05955 Mdot
.51588 .51173 Mdot
.46222 .0107 Mdot
.28269 .26481 Mdot
.43597 .06387 Mdot
.10524 .25813 Mdot
.641 .61173 Mdot
.61038 .04677 Mdot
.60782 .08673 Mdot
.31894 .56864 Mdot
.54481 .60427 Mdot
.57551 .59775 Mdot
.64594 .60657 Mdot
.39907 .60425 Mdot
.6358 .10178 Mdot
.40317 .03614 Mdot
.42042 .60126 Mdot
.56623 .07554 Mdot
.38448 .58776 Mdot
.02568 .22984 Mdot
.5945 .6026 Mdot
.48431 .56638 Mdot
.54109 .60236 Mdot
.50073 .57431 Mdot
.36812 .57973 Mdot
.60555 .57761 Mdot
.39395 .02153 Mdot
.29404 .55299 Mdot
.64115 .09069 Mdot
.49656 .1199 Mdot
.6651 .10546 Mdot
.41113 .02574 Mdot
.72873 .13505 Mdot
.5559 .54408 Mdot
.47229 .08982 Mdot
.51827 .50942 Mdot
.76934 .14937 Mdot
.21627 .52129 Mdot
.59816 .05703 Mdot
.60957 .60667 Mdot
.44876 .1215 Mdot
.58705 .07989 Mdot
.6775 .11163 Mdot
.62978 .60351 Mdot
.57323 .59677 Mdot
.21208 .52576 Mdot
.47851 .04201 Mdot
.60935 .079 Mdot
.46365 .56815 Mdot
.6546 .10195 Mdot
.63599 .60918 Mdot
.68492 .1181 Mdot
.63331 .09504 Mdot
.26513 .54106 Mdot
.5019 .5743 Mdot
.41708 .02258 Mdot
.20311 .52151 Mdot
.56355 .07109 Mdot
.35608 .13757 Mdot
.50983 .5865 Mdot
.60963 .57953 Mdot
.5356 .52898 Mdot
.63029 .61199 Mdot
.39984 .60072 Mdot
.36048 .13472 Mdot
.36864 .58988 Mdot
.49663 .56934 Mdot
.43518 .55118 Mdot
.59631 .59967 Mdot
.9138 .17075 Mdot
.25991 .5376 Mdot
.46765 .08425 Mdot
.33657 .57246 Mdot
.42208 .54795 Mdot
.39412 .59838 Mdot
.42309 .12035 Mdot
.58616 .56608 Mdot
.37794 .59137 Mdot
.60928 .57672 Mdot
.52526 .05876 Mdot
.43943 .61079 Mdot
.68669 .37571 Mdot
.27078 .54509 Mdot
.47001 .01787 Mdot
.59079 .60234 Mdot
.3971 .59991 Mdot
.399 .02779 Mdot
.62208 .58929 Mdot
.53595 .58589 Mdot
.55811 .0715 Mdot
.99619 .21892 Mdot
.21135 .5214 Mdot
.53675 .60191 Mdot
.61231 .08122 Mdot
.59703 .49935 Mdot
.21666 .52752 Mdot
.5287 .50367 Mdot
.54988 .58701 Mdot
.63594 .09564 Mdot
.46102 .56201 Mdot
.67293 .11049 Mdot
.75636 .14288 Mdot
.48837 .02489 Mdot
.72421 .12971 Mdot
.57782 .07788 Mdot
.27432 .54671 Mdot
.368 .13078 Mdot
.29039 .55056 Mdot
.57183 .61745 Mdot
.59367 .0834 Mdot
.40269 .03199 Mdot
.72978 .13397 Mdot
.48925 .0241 Mdot
.49085 .57069 Mdot
.2144 .52208 Mdot
.71375 .1313 Mdot
.47605 .1232 Mdot
.6859 .1175 Mdot
.82203 .10675 Mdot
.42022 .60419 Mdot
.05016 .23954 Mdot
.54246 .58729 Mdot
.20375 .26217 Mdot
.76497 .14754 Mdot
.30891 .56508 Mdot
.32313 .22873 Mdot
.30444 .56479 Mdot
.3063 .55534 Mdot
.44308 .0703 Mdot
.50371 .11332 Mdot
.49157 .10779 Mdot
.56039 .05441 Mdot
.53069 .05997 Mdot
.49164 .11923 Mdot
.44389 .55959 Mdot
.3189 .56037 Mdot
.33908 .16044 Mdot
.33328 .17165 Mdot
.41125 .04405 Mdot
.71326 .13004 Mdot
.31987 .56273 Mdot
.56998 .50142 Mdot
.5329 .50018 Mdot
.60895 .07672 Mdot
.56707 .07293 Mdot
.47296 .56315 Mdot
.73182 .13161 Mdot
.43415 .55564 Mdot
.41764 .54097 Mdot
.37971 .02166 Mdot
.33476 .57654 Mdot
.47425 .57283 Mdot
.81318 .14625 Mdot
.28953 .55036 Mdot
.651 .1045 Mdot
.66849 .44741 Mdot
.19123 .51278 Mdot
.41928 .54859 Mdot
.16516 .47856 Mdot
.83603 .11275 Mdot
.38241 .5302 Mdot
.40739 .03855 Mdot
.49485 .10485 Mdot
.66897 .44614 Mdot
.54741 .49895 Mdot
.56314 .49955 Mdot
.34132 .57421 Mdot
.47365 .56429 Mdot
.32556 .5697 Mdot
.32387 .56295 Mdot
.63605 .48971 Mdot
.30092 .55407 Mdot
.42101 .5469 Mdot
.46388 .03799 Mdot
.39533 .60155 Mdot
.61452 .04869 Mdot
.67504 .40265 Mdot
.36956 .58103 Mdot
.71995 .12937 Mdot
.69135 .09694 Mdot
.84408 .1599 Mdot
.29495 .5519 Mdot
.41302 .02461 Mdot
.16543 .50548 Mdot
.63046 .49127 Mdot
.4995 .1169 Mdot
.63275 .08821 Mdot
.61625 .58207 Mdot
.61997 .59032 Mdot
.52735 .5807 Mdot
.52762 .04145 Mdot
.70623 .3584 Mdot
.33957 .57053 Mdot
.56901 .49888 Mdot
.6218 .59485 Mdot
.59648 .49783 Mdot
.03758 .23451 Mdot
.61616 .01646 Mdot
.62216 .59265 Mdot
.37673 .58468 Mdot
.57929 .60104 Mdot
.66125 .1075 Mdot
.51641 .50336 Mdot
.38245 .12582 Mdot
.43874 .03175 Mdot
.72674 .11122 Mdot
.61926 .60819 Mdot
.46163 .03868 Mdot
.52034 .5077 Mdot
.35193 .13909 Mdot
.34694 .5723 Mdot
.73471 .13549 Mdot
.35778 .57663 Mdot
.28655 .54915 Mdot
.38876 .0309 Mdot
.70458 .12624 Mdot
.43702 .55081 Mdot
.42793 .61405 Mdot
.99605 .21861 Mdot
.37976 .52954 Mdot
.62553 .08899 Mdot
.33389 .57204 Mdot
.30063 .55526 Mdot
.45641 .56639 Mdot
.20714 .5236 Mdot
.53828 .50081 Mdot
.49834 .10777 Mdot
.36618 .58493 Mdot
.62868 .59643 Mdot
.78741 .09153 Mdot
.55444 .50091 Mdot
.77139 .13021 Mdot
.39757 .03409 Mdot
.55299 .60814 Mdot
.4112 .04949 Mdot
.21864 .52625 Mdot
.39499 .01768 Mdot
.63796 .09058 Mdot
.62501 .59994 Mdot
.80242 .14217 Mdot
.52941 .58364 Mdot
.58853 .05362 Mdot
.50803 .03525 Mdot
.5369 .5863 Mdot
.76182 .35202 Mdot
.54192 .03343 Mdot
.51559 .0368 Mdot
.54956 .60614 Mdot
.4729 .57099 Mdot
.48082 .09445 Mdot
.54054 .04868 Mdot
.69812 .12525 Mdot
.56089 .05645 Mdot
.3918 .03355 Mdot
.2753 .54581 Mdot
.39186 .0303 Mdot
.74756 .13887 Mdot
.74417 .13808 Mdot
.29831 .55873 Mdot
.39442 .03067 Mdot
.63473 .09616 Mdot
.6365 .61292 Mdot
.93762 .19605 Mdot
.48827 .11696 Mdot
.62551 .59949 Mdot
.07103 .24602 Mdot
.43065 .05922 Mdot
.4917 .11988 Mdot
.58732 .05306 Mdot
.37725 .58431 Mdot
.53342 .59965 Mdot
.55942 .07302 Mdot
.53421 .52984 Mdot
.5669 .55301 Mdot
.74073 .35151 Mdot
.60775 .08049 Mdot
.60585 .01312 Mdot
.48054 .02244 Mdot
.70315 .12177 Mdot
.36626 .13149 Mdot
.35008 .57792 Mdot
.92447 .38962 Mdot
.67543 .10781 Mdot
.28637 .54761 Mdot
.51607 .5071 Mdot
.44308 .03086 Mdot
.2549 .54357 Mdot
.40649 .60807 Mdot
.60664 .06162 Mdot
.62508 .61257 Mdot
.53296 .58233 Mdot
.64197 .10007 Mdot
.45842 .07945 Mdot
.33218 .18775 Mdot
.59805 .05805 Mdot
.69482 .36544 Mdot
.40779 .02243 Mdot
.65351 .10031 Mdot
.62526 .09494 Mdot
.29817 .56221 Mdot
.31276 .56581 Mdot
.36116 .5892 Mdot
.3967 .038 Mdot
.53239 .50331 Mdot
.58481 .60036 Mdot
.38518 .59984 Mdot
.37913 .56714 Mdot
.45978 .0368 Mdot
.59021 .0701 Mdot
.37106 .59279 Mdot
.6929 .05074 Mdot
.20264 .52005 Mdot
.63381 .49169 Mdot
.71054 .05873 Mdot
.6586 .10038 Mdot
.24548 .53848 Mdot
.75298 .14209 Mdot
.76551 .08122 Mdot
.49888 .56978 Mdot
.41138 .0256 Mdot
.68249 .11799 Mdot
.70796 .12507 Mdot
.3929 .03083 Mdot
.66774 .10608 Mdot
.69319 .36736 Mdot
.53268 .06103 Mdot
.38884 .01862 Mdot
.64258 .09942 Mdot
.55862 .61055 Mdot
.37045 .58592 Mdot
.48096 .02299 Mdot
.54372 .58532 Mdot
.54883 .53815 Mdot
.68299 .11098 Mdot
.62865 .09445 Mdot
.22674 .52651 Mdot
.37775 .12566 Mdot
.50589 .11932 Mdot
.35701 .58679 Mdot
.65936 .09909 Mdot
.46518 .0039 Mdot
.94132 .19845 Mdot
.91349 .18684 Mdot
.61498 .07976 Mdot
.66518 .10621 Mdot
.82405 .10664 Mdot
.20685 .51815 Mdot
.5818 .60031 Mdot
.74509 .14247 Mdot
.34522 .57479 Mdot
.53405 .04397 Mdot
.56633 .50183 Mdot
.6604 .08359 Mdot
.43579 .12194 Mdot
.1645 .27754 Mdot
.59558 .08346 Mdot
.5701 .50103 Mdot
.48913 .04495 Mdot
.52799 .52261 Mdot
.45517 .0347 Mdot
.35151 .58161 Mdot
.277 .54784 Mdot
.64335 .60362 Mdot
.61825 .08198 Mdot
.39253 .53424 Mdot
.33435 .17345 Mdot
.51178 .57475 Mdot
.63922 .09215 Mdot
.55833 .04009 Mdot
.65428 .03319 Mdot
.59986 .08402 Mdot
.5531 .49888 Mdot
.36567 .57883 Mdot
.64435 .10336 Mdot
.29194 .55119 Mdot
.05787 .24208 Mdot
.64914 .09794 Mdot
.39495 .03516 Mdot
.72679 .09548 Mdot
.65391 .08111 Mdot
.39394 .02913 Mdot
.25769 .54023 Mdot
.37804 .59369 Mdot
.35948 .1336 Mdot
.59402 .07333 Mdot
.6542 .08123 Mdot
.47132 .00522 Mdot
.04764 .23796 Mdot
.4691 .56114 Mdot
.42049 .12092 Mdot
.6745 .11215 Mdot
.70392 .12675 Mdot
.53865 .5295 Mdot
.67589 .11308 Mdot
.94068 .39484 Mdot
.91784 .38784 Mdot
.38287 .5921 Mdot
.56209 .54921 Mdot
.39577 .6032 Mdot
.67192 .42109 Mdot
.45095 .00631 Mdot
.87342 .17066 Mdot
.57606 .04763 Mdot
.63052 .0997 Mdot
.39812 .59459 Mdot
.30994 .56238 Mdot
.31054 .25129 Mdot
.70673 .12702 Mdot
.54707 .04967 Mdot
.6174 .58568 Mdot
.26668 .54445 Mdot
.34902 .58327 Mdot
.63056 .59565 Mdot
.26603 .54256 Mdot
.37988 .53015 Mdot
.40219 .12174 Mdot
.78 .3536 Mdot
.49636 .0264 Mdot
.44855 .55659 Mdot
.60069 .01094 Mdot
.40027 .02751 Mdot
.42775 .6057 Mdot
.44265 .03123 Mdot
.60892 .06123 Mdot
.48461 .09659 Mdot
.53263 .59995 Mdot
.56774 .54997 Mdot
.48899 .02456 Mdot
.37946 .59483 Mdot
.51233 .57788 Mdot
.37748 .58996 Mdot
.52683 .02692 Mdot
.51567 .57559 Mdot
.61145 .57925 Mdot
.42858 .61517 Mdot
.40435 .54034 Mdot
.46164 .12293 Mdot
.7646 .08111 Mdot
.449 .56178 Mdot
.71939 .35434 Mdot
.42123 .12132 Mdot
.02795 .4258 Mdot
.45121 .00678 Mdot
.6262 .59449 Mdot
.49913 .11076 Mdot
.50692 .57555 Mdot
.38526 .59138 Mdot
.2981 .55276 Mdot
.51484 .51463 Mdot
.22198 .52672 Mdot
.27162 .52219 Mdot
.72694 .13184 Mdot
.25816 .54488 Mdot
.46709 .12279 Mdot
.59294 .60013 Mdot
.43537 .55289 Mdot
.30913 .55921 Mdot
.48647 .57169 Mdot
.59197 .60212 Mdot
.49607 .58193 Mdot
.4032 .60458 Mdot
.43095 .55405 Mdot
.46789 .04069 Mdot
.46514 .03841 Mdot
.71313 .12977 Mdot
.54963 .53815 Mdot
.54896 .50008 Mdot
.47449 .57356 Mdot
.57212 .07721 Mdot
.42184 .54638 Mdot
.52494 .52256 Mdot
.64772 .61027 Mdot
.71028 .12534 Mdot
.82602 .15204 Mdot
.58705 .56263 Mdot
.65407 .47617 Mdot
.40755 .04683 Mdot
.64129 .60552 Mdot
.7012 .36131 Mdot
.53095 .5964 Mdot
.47609 .00774 Mdot
.26281 .54585 Mdot
.39507 .02845 Mdot
.38902 .60033 Mdot
.4309 .00126 Mdot
.26963 .54252 Mdot
.68121 .11415 Mdot
.4641 .11974 Mdot
.57277 .61646 Mdot
.90241 .16629 Mdot
.32531 .56929 Mdot
.43475 .06213 Mdot
.9587 .20463 Mdot
.45585 .03557 Mdot
.31799 .23985 Mdot
.64106 .09484 Mdot
.38989 .01771 Mdot
.46748 .00413 Mdot
.85235 .16224 Mdot
.71303 .35641 Mdot
.28076 .5468 Mdot
.28167 .55065 Mdot
.62172 .58649 Mdot
.43417 .06081 Mdot
.67289 .42576 Mdot
.28391 .55366 Mdot
.36553 .58655 Mdot
.5563 .60994 Mdot
.51914 .58014 Mdot
.59281 .56893 Mdot
.57964 .55648 Mdot
.50591 .58519 Mdot
.63414 .60131 Mdot
.38894 .53483 Mdot
.52142 .58122 Mdot
.44946 .0088 Mdot
.58323 .05173 Mdot
.04665 .23753 Mdot
.52277 .59586 Mdot
.44464 .61233 Mdot
.5232 .59453 Mdot
.45409 .03449 Mdot
.28828 .54843 Mdot
.73738 .13619 Mdot
.35852 .57953 Mdot
.47117 .12249 Mdot
.58137 .07764 Mdot
.55657 .07036 Mdot
.30084 .56198 Mdot
.71927 .12881 Mdot
.66686 .10807 Mdot
.40761 .59917 Mdot
.48516 .02115 Mdot
.61446 .60704 Mdot
.62857 .08675 Mdot
.70327 .11931 Mdot
.66361 .08498 Mdot
.38873 .53195 Mdot
.57231 .55311 Mdot
.6817 .11055 Mdot
.66687 .45156 Mdot
.81907 .10528 Mdot
.46267 .03661 Mdot
.52833 .57973 Mdot
.74884 .07365 Mdot
.4714 .56248 Mdot
.32263 .23285 Mdot
.65311 .10708 Mdot
.56107 .07352 Mdot
.04612 .43241 Mdot
.58913 .5987 Mdot
.35714 .5809 Mdot
.77843 .13242 Mdot
.37192 .58878 Mdot
.64205 .48696 Mdot
.41073 .04398 Mdot
.60205 .57578 Mdot
.6025 .57618 Mdot
.5644 .04306 Mdot
.3621 .5862 Mdot
.50917 .05403 Mdot
.53777 .49892 Mdot
.59552 .57019 Mdot
.64774 .10288 Mdot
.04384 .21837 Mdot
.36957 .58054 Mdot
.76777 .08275 Mdot
.6655 .11178 Mdot
.34439 .5751 Mdot
.61856 .58774 Mdot
.48263 .02345 Mdot
.63108 .0991 Mdot
.59563 .49943 Mdot
.55934 .59244 Mdot
.76307 .08088 Mdot
.34714 .14401 Mdot
.58711 .06894 Mdot
.71255 .13086 Mdot
.67646 .11256 Mdot
.21964 .52439 Mdot
.38342 .58663 Mdot
.40398 .60293 Mdot
.41486 .54458 Mdot
.41827 .54786 Mdot
.46877 .00442 Mdot
.48775 .57697 Mdot
.3171 .56306 Mdot
.39049 .03186 Mdot
.52097 .59387 Mdot
.47607 .57363 Mdot
.4415 .03354 Mdot
.45937 .56772 Mdot
.48625 .10027 Mdot
.31853 .23857 Mdot
.57302 .55666 Mdot
.47785 .0906 Mdot
.47518 .09187 Mdot
.52245 .50127 Mdot
.44016 .00225 Mdot
.64851 .09924 Mdot
.64229 .10216 Mdot
.49185 .02442 Mdot
.63327 .60644 Mdot
.59191 .08475 Mdot
.61027 .08817 Mdot
.89091 .17772 Mdot
.41187 .04344 Mdot
.58656 .06683 Mdot
.31921 .56198 Mdot
.54267 .50019 Mdot
.52586 .50439 Mdot
.3865 .02575 Mdot
.45695 .03545 Mdot
.28605 .54834 Mdot
.43055 .05826 Mdot
.46282 .08206 Mdot
.46341 .01234 Mdot
.58952 .0837 Mdot
.31498 .24693 Mdot
.94903 .20157 Mdot
.42389 .58587 Mdot
.57055 .07579 Mdot
.62071 .58853 Mdot
.26091 .53761 Mdot
.42132 .02395 Mdot
.60982 .60827 Mdot
.61461 .60417 Mdot
.47677 .04166 Mdot
.61676 .09284 Mdot
.46917 .56192 Mdot
.6834 .37969 Mdot
.53038 .52451 Mdot
.25439 .53979 Mdot
.37604 .58811 Mdot
.4834 .02037 Mdot
.40058 .60308 Mdot
.03187 .23194 Mdot
.48354 .02107 Mdot
.44444 .0051 Mdot
.47208 .57033 Mdot
.50262 .58695 Mdot
.16749 .27858 Mdot
.24831 .53794 Mdot
.65119 .09761 Mdot
.56594 .59677 Mdot
.52786 .02762 Mdot
.56598 .55258 Mdot
.18941 .48855 Mdot
.64273 .48516 Mdot
.44532 .07261 Mdot
.57155 .06075 Mdot
.53182 .06174 Mdot
.49131 .04784 Mdot
.71776 .12957 Mdot
.59965 .0856 Mdot
.21935 .5279 Mdot
.62381 .09481 Mdot
.55143 .0376 Mdot
.63001 .6024 Mdot
.41571 .60951 Mdot
.35311 .58534 Mdot
.55338 .59079 Mdot
.61706 .60622 Mdot
.49209 .11234 Mdot
.40028 .60203 Mdot
.42251 .6021 Mdot
.47251 .57052 Mdot
.58738 .00448 Mdot
.66878 .43931 Mdot
.59846 .60476 Mdot
.54123 .53108 Mdot
.525 .52337 Mdot
.37414 .56498 Mdot
.55363 .54207 Mdot
.47794 .57512 Mdot
.65084 .0983 Mdot
.32935 .19917 Mdot
.36909 .58445 Mdot
.43111 .05838 Mdot
.56685 .05929 Mdot
.85547 .16364 Mdot
.67006 .10457 Mdot
.55192 .03953 Mdot
.52803 .5027 Mdot
.35162 .13941 Mdot
.23033 .52713 Mdot
.58972 .56793 Mdot
.80509 .12786 Mdot
.70844 .10365 Mdot
.29293 .26091 Mdot
.76289 .14837 Mdot
.28259 .55144 Mdot
.46294 .08439 Mdot
.52679 .50327 Mdot
.53152 .04535 Mdot
.16873 .50631 Mdot
.4376 .12161 Mdot
.49172 .57177 Mdot
.48829 .5765 Mdot
.40095 .59571 Mdot
.63295 .59468 Mdot
.12222 .46173 Mdot
.57428 .06074 Mdot
.32291 .22946 Mdot
.50844 .5775 Mdot
.54876 .53792 Mdot
.52082 .50465 Mdot
.54557 .53587 Mdot
.78369 .13479 Mdot
.54115 .50174 Mdot
.2624 .5459 Mdot
.48733 .04753 Mdot
.47229 .0183 Mdot
.43058 .55382 Mdot
.50104 .57205 Mdot
.37087 .58815 Mdot
.58965 .60118 Mdot
.34402 .14778 Mdot
.0262 .2306 Mdot
.56816 .50135 Mdot
.8122 .10128 Mdot
.83656 .11308 Mdot
.56857 .54935 Mdot
.47674 .09508 Mdot
.15433 .25184 Mdot
.49442 .04988 Mdot
.39831 .53598 Mdot
.62864 .0946 Mdot
.46346 .56475 Mdot
.76495 .35251 Mdot
.62017 .60856 Mdot
.6483 .61181 Mdot
.51538 .5778 Mdot
.64428 .61369 Mdot
.51244 .58788 Mdot
.63911 .10277 Mdot
.38298 .01743 Mdot
.63493 .61372 Mdot
.54635 .0678 Mdot
.41441 .12196 Mdot
.06057 .43773 Mdot
.73044 .06696 Mdot
.64616 .48413 Mdot
.82246 .1056 Mdot
.46113 .56854 Mdot
.19202 .51512 Mdot
.48537 .56668 Mdot
.36067 .13243 Mdot
.43984 .06728 Mdot
.19397 .26057 Mdot
.47149 .56947 Mdot
.42312 .54609 Mdot
.53114 .06062 Mdot
.53992 .60223 Mdot
.32056 .23797 Mdot
.62877 .02345 Mdot
.62334 .58775 Mdot
.59254 .00844 Mdot
.34374 .5701 Mdot
.56131 .05574 Mdot
.67471 .39974 Mdot
.6322 .60672 Mdot
.35403 .13782 Mdot
.68102 .04587 Mdot
.50121 .03208 Mdot
.11912 .26266 Mdot
.49453 .11 Mdot
.62821 .07015 Mdot
.95462 .18632 Mdot
.3272 .56782 Mdot
.53494 .49913 Mdot
.52787 .5179 Mdot
.2238 .52935 Mdot
.33673 .56785 Mdot
.48994 .04754 Mdot
.24673 .53765 Mdot
.57243 .06159 Mdot
.26591 .54165 Mdot
.41644 .54188 Mdot
.86302 .16635 Mdot
.35221 .57583 Mdot
.92158 .38902 Mdot
.49892 .1144 Mdot
.71209 .05981 Mdot
.40769 .04477 Mdot
.57228 .59609 Mdot
.46506 .56412 Mdot
.62305 .60408 Mdot
.58562 .56557 Mdot
.48774 .09878 Mdot
.52377 .51443 Mdot
.51249 .50237 Mdot
.55829 .54669 Mdot
.40357 .54095 Mdot
.46066 .00049 Mdot
.61854 .01904 Mdot
.62112 .49449 Mdot
.50453 .0182 Mdot
.63465 .05714 Mdot
.67751 .11323 Mdot
.53473 .03036 Mdot
.59244 .49957 Mdot
.32621 .56613 Mdot
.25616 .53745 Mdot
.45343 .07576 Mdot
.60727 .07907 Mdot
.70081 .11786 Mdot
.4573 .03438 Mdot
.60279 .57414 Mdot
.48858 .02468 Mdot
.42591 .61752 Mdot
.68431 .047 Mdot
.28884 .55047 Mdot
.3358 .57389 Mdot
.59221 .60348 Mdot
.31447 .56764 Mdot
.44347 .03111 Mdot
.66559 .03963 Mdot
.58003 .00095 Mdot
.53205 .06317 Mdot
.47289 .0063 Mdot
.60055 .07466 Mdot
.938 .19637 Mdot
.60744 .08837 Mdot
.50283 .58567 Mdot
.41833 .60125 Mdot
.56016 .61007 Mdot
.56516 .61304 Mdot
.68022 .38336 Mdot
.22219 .52357 Mdot
.48034 .09362 Mdot
.41773 .05277 Mdot
.66325 .10058 Mdot
.53509 .03171 Mdot
.38303 .02319 Mdot
.63345 .60216 Mdot
.74893 .1438 Mdot
.40618 .12239 Mdot
.46932 .08741 Mdot
.51799 .50585 Mdot
.58973 .00595 Mdot
.59513 .57069 Mdot
.65974 .10123 Mdot
.62984 .09497 Mdot
.47649 .56513 Mdot
.25382 .541 Mdot
.4666 .0854 Mdot
.47446 .01694 Mdot
.56666 .04379 Mdot
.48846 .0985 Mdot
.24652 .26707 Mdot
.46451 .56769 Mdot
.41529 .02732 Mdot
.57983 .06762 Mdot
.5047 .03257 Mdot
.64212 .60125 Mdot
.49198 .02504 Mdot
.5538 .54071 Mdot
.45958 .55728 Mdot
.75383 .14339 Mdot
.52728 .50342 Mdot
.66778 .45323 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002=ooooo`;o00001Oooool2o`0001_ooooo00?o0000
ooooooooool0K?ooool002KooooolOl00009ooooo`009_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool01oooool00`00003o0000o`000002o`0000;o
oooo1?l0000Iooooo`;o000000<00000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo06[ooooo0ol000000`00003ooooo
ooooo`04o`0000Kooooo00?o0000ooooooooool04?ooool2o`0005kooooo00?o0000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0FOooool01?l0003ooooo00000?l0000?ooooo`Co0000
0oooool3o`0000Wooooo00?o0000ooooooooool03Oooool3o`0005_ooooo00?o0000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0F?ooool7o`000003ooooool0003ooooo00cooooo1Ol0
0003ooooo`?o00006?ooool3o`0005Wooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0FOooool;o`0000cooooo1?l00004ooooo`80000000?o0000ooooooooool05_ooool2
o`0005Sooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0FOooool?o`00
00_ooooo1?l00003ooooo`?o000000<00000ooooooooool05_ooool3o`0005Cooooo00?o0000oooo
ooooool01oooool002Kooooo0_l0001Kooooo`Go00001_ooool6o`0000[ooooo1?l00004ooooo`?o
00006Oooool00`00003o0000ooooo`1@ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0
G?ooool3o`0000[ooooo1_l00008ooooo`Co000000@00000oooooooooooooooo0ol0000Iooooo`?o
0000Coooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Looooo`Go0000
2_ooool6o`0000Sooooo1?l00005ooooo`?o00002?ooool00ol0003oooooooooo`0=ooooo`?o0000
COooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Nooooo`?o00003_oo
ool5o`0000Sooooo0ol00005ooooo`?o00002Oooool00ol0003oooooooooo`0<ooooo`0300000?l0
003o000004_ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0H?ooool3
o`0000oooooo1?l000000`00003oooooooooo`05ooooo`Go00001?ooool3o`0000Oooooo00?o0000
ooooooooool03Oooool3o`0004Wooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0HOooool2o`00000300000?oooooooooo00oooooo1Ol00006ooooo`0500000?l0003o0000
00000?l000001?ooool2o`00000300000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool3
o`0004Kooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0H_ooool4o`00
01?ooooo1?l00005ooooo`Go00001?ooool3o`00000300000?oooooooooo00Cooooo0_l0000@oooo
o`;o0000A?ooool00ol0003oooooooooo`07ooooo`009_ooool2o`0006Gooooo0_l0000Dooooo`03
o`000?oooooo000000?o00001?ooool00`00003o0000o`000002o`0000Gooooo0_l000000`00003o
ooooooooo`05ooooo`03o`000?oooooooooo00gooooo0ol00011ooooo`;o00002Oooool002Kooooo
00?o0000ooooooooool0IOooool3o`0001Kooooo1?l000000`00003oooooooooo`02ooooo`Go0000
1?ooool00`00003o0000ooooo`0Hooooo`0300000?l0003o000003oooooo00?o0000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0Ioooool2o`00000300000?oooooooooo01Cooooo1_l0
0003ooooo`Co00001_ooool3o`0001Oooooo0_l0000nooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo06Sooooo0ol0000Hooooo`Co00001?ooool5o`0000Gooooo0ol00006
ooooo`03o`000?oooooooooo00kooooo0ol0000kooooo`03o`000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo06[ooooo0ol0000Hooooo`Ko00000_ooool5o`0000Kooooo00<00000o`00
0?ooool01oooool2o`0000oooooo0_l0000hooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo06cooooo0_l0000Kooooo`Go000000?oooooo`000?l000000ol00006ooooo`?o
00001oooool00`00003oooooooooo`0=ooooo`?o0000=_ooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`1/ooooo`?o00007?ooool;o`0000Kooooo00?o000000000?l00000
1_ooool00ol0003oooooooooo`0?ooooo`?o0000<oooool00ol0003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`1^ooooo`?o00007Oooool:o`00000300000?oooooooooo00?ooooo1?l0
0007ooooo`03o`000?oooooooooo00gooooo0ol0000aooooo`03o`000?oooooooooo00Oooooo000V
ooooo`;o0000L?ooool4o`0001kooooo2Ol00008ooooo`;o00001oooool00`00003o0000ooooo`0=
ooooo`0300000?l0003o000002kooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`1`oooo
o`?o00008?ooool:o`0000Kooooo00?o0000ooooool000002?ooool00ol000000000ooooo`0?oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0L_ooool3o`00023ooooo00<00000o`000?l000001ol00007ooooo`0300000?l0003ooooo00Ko
oooo00<00000ooooooooool03_ooool3o`0002[ooooo00?o0000ooooooooool01oooool002Kooooo
00?o0000ooooooooool0L_ooool4o`0002?ooooo2?l00009ooooo`03o`000?oooooooooo01Gooooo
0_l0000Yooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo07?ooooo1?l0
000Tooooo`0300000?l0003o000000Go00002Oooool2o`0000Sooooo00<00000ooooooooool02ooo
ool3o`0002Kooooo00?o0000ooooooooool01oooool001?ooooo0_l00004ooooo`04o`000?oooooo
ooooooooo`Go00001?ooool00ol0003oooooooooo`1booooo`Go00009oooool8o`0000Oooooo00<0
0000o`000?ooool01_ooool3o`0003Cooooo00?o0000ooooooooool01oooool001;ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05kooooo
4ol000000ooooooo0000o`000004o`0002Sooooo2?l00008ooooo`03o`000000003ooooo00Kooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Cooooo0_l0001Hooooo`Oo000000<00000o`000?ooool0
0_l000000ooooooo000000000003o`00000300000?l00000000000Oo000000?oooooo`000?l00000
;Oooool8o`0000Sooooo00?o000000000?ooool01Oooool00ol0003oooooooooo`0]ooooo`?o0000
2Oooool001;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05Kooooo00<00000o`000?l00000COooool6o`0000Sooooo0_l00008ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0Doooool3o`0005;o
oooo1ol00007ooooo`Co0000<oooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Boooo
o`?o0000EOooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Oooooo0ol0000aoooo
o`03o`000?oooooooooo00Oooooo000Cooooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool0D?ooool00`00003o0000o`00001Kooooo`Go00002?ooool01000003oooooo`000?l00007oooo
o`;o00009Oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo05kooooo1?l0000:ooooo`;o0000;?ooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`1?ooooo`;o0000H_ooool4o`0000[ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo04oooooo0_l0001Tooooo`?o00002oooool3o`0002Oooooo00?o0000ooooooooool01ooo
ool002Kooooo0_l0001?ooooo`;o0000MOooool3o`0002Cooooo0_l00009ooooo`009_ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo07Oooooo0ol0000Rooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0NOooool01?l0003o
ooooo`000?l00006ooooo`?o00005_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`1=ooooo`;o0000OOooool2o`000003ooooool0003ooooo00Oooooo0_l0000Cooooo`03
o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
Ooooool01?l000000000o`000?l00007ooooo`0300000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`23ooooo`03o`00
0?oooooooooo00Oooooo00<00000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`1<ooooo`03o`000000003ooooo08Kooooo0_l0000Fooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`;o0000C_ooool00ol0003oooooooooo`28ooooo`;o00002?ooool2
o`0000Sooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`1<ooooo`03o`000000003ooooo
08_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo04cooooo0_l0002>ooooo`0300000?l0003o000000ko
oooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`2?ooooo`0300000?l0003o000000[ooooo00?o0000ooooool000002Oooool002Kooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool01oooool002Kooooo00Go0000ooooool0003oooooo`00001:ooooo`0300000?oo
oooooooo09Kooooo0_l00006ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0AOooool00`00003oooooooooo`2Gooooo`80000000?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1;oooo
o`;o0000W?ooool01Ol0003ooooooooooooooooo000000Wooooo000Vooooo`;o00002?ooool01000
003o0000ooooo`000010ooooo`03o`000?oooooooooo09kooooo0_l00009ooooo`009_ooool01?l0
003oooooo`000000000;ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Woooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`02ooooo`;o0000Aoooool00ol0
003oooooooooo`2Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00?o
oooo0ol00014ooooo`;o0000XOooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Cooooo
00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool01_ooool3o`0000gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Oooooo
000Booooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooo000000_ooooo00<00000o`000?ooool0;oooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo
1Ol00004ooooo`03o`000?oooooooooo00cooooo0ol0000>ooooo`03o`000?oooooooooo02Wooooo
00<00000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Gooooo0_l0000?ooooo`;o00003oooool00`00003o
ooooo`00000Uooooo`0300000?l0003o00000:7ooooo0ol00009ooooo`004_ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool04Oooool2o`000003
ooooool0003ooooo00cooooo1?l0000Qooooo`;o0000Y?ooool00ol0003oooooooooo`07ooooo`00
4_ooool01?l0003oooooooooool00009ooooo`;o00001Oooool00ol0003oooooooooo`0Eooooo`;o
000000<00000ooooooooool03?ooool00`00003oooooo`00000Looooo`;o0000Y_ooool00ol0003o
ooooooooo`07ooooo`004oooool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Iooooo`;o00003oooool6o`0001;ooooo0ol0002Xooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool000004oooool01000003o0000oooo
ool00002000000?o000000<00000o`000?ooool00_ooool00ol0003oooooo`000002o`000:[ooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool07Oooool4o`0001Kooooo00Go
0000ooooool0003ooooo0000002aooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo027ooooo0`000039ooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o00009Oooool3
o`000<Gooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`0Wooooo`;o00000P000032oooo
o`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo02_ooooo0P000030ooooo`03
o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2eooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo03Sooooo00Co0000ooooool000000000/Ooo
ool00ol0003oooooooooo`07ooooo`001oooool3o`0001cooooo00?o0000ooooooooool0kOooool0
0ol0003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
0>gooooo00?o0000ooooooooool01oooool000Sooooo00?o0000ooooooooool06oooool2o`000>go
oooo0_l00009ooooo`002?ooool2o`0001cooooo00?o0000ooooooooool0kOooool00ol0003ooooo
ooooo`07ooooo`001oooool2o`000003ooooool0003o000001[ooooo00?o0000ooooooooool0kOoo
ool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`3]ooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000kOooool2o`0000Wooooo000V
ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2Zooooo`03
o`000000000000000080000000Go0000oooooooooooo000000000002o`000004ooooool0003o0000
o`0003?ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Yoooool2o`00
0003ooooool0003ooooo013ooooo00?o000000000?l00000;_ooool00ol0003oooooooooo`07oooo
o`004oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000oooooooo
ool0YOooool2o`0001cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`07ooooo`00
4_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`2Sooooo`;o000000<00000ooooooooool07Oooool2000000?o00008oooool00ol0
003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool4o`0000Gooooo0_l0002R
ooooo`;o0000;Oooool00ol0003oooooooooo`0Hooooo`?o00002Oooool001;ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0:7ooooo00?o0000
ooooooooool0;Oooool00ol000000000ooooo`0Iooooo`03o`000?oooooooooo00Oooooo000Boooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2P
ooooo`;o0000<_ooool00ol0003oooooo`00000Fooooo`03o`000?oooooooooo00Oooooo000Coooo
o`;o00002_ooool2o`0000Gooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0foooo
o`03o`000000003ooooo017ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0X?ooool00ol0003oooooooooo`0gooooo`?o00004?ooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2Oooooo`;o0000C?oo
ool00ol0003oooooooooo`07ooooo`009_ooool2o`000:3ooooo00?o0000ooooooooool0@_ooool2
o`0000Kooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`2Oooooo`0300000?oooooooooo04Wooooo00<00000ooooool000002Oooool002Kooooo
00?o0000ooooooooool0W_ooool2o`0004gooooo00?o0000ooooooooool01oooool002Kooooo00Go
0000ooooool0003oooooo`00002Looooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Hooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2Gooooo`;o0000COooool00ol0003oooooooooo`07ooooo`009_ooool2o`00
00Sooooo0ol0002Dooooo`03o`000?oooooooooo04_ooooo0_l00009ooooo`009_ooool00ol0003o
ooooooooo`0;ooooo`;o0000TOooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0S_ooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00kooooo00?o
0000ooooool00000S?ooool2o`0004kooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool04_ooool00ol000000000ooooo`28ooooo`;o0000C_ooool00ol0003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08Kooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo087ooooo0_l0001?ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo01[ooooo0_l00021ooooo`0300000?oooooooooo04gooooo00?o0000ooooooooool0
1oooool002Kooooo0_l0000Nooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool0COoo
ool2o`0000Wooooo000Vooooo`03o`000?oooooooooo09_ooooo0_l0001@ooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0M_ooool2o`00
057ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1aooooo`;o0000D_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooo
ooooo`2Hooooo`?o0000D_ooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Cooooo00?o
0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0U_ooool3o`0005Cooooo00?o
0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0:_ooool01?l0003oooooo`000000001Vooooo`Co
0000EOooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001?ooool2o`0002oooooo00?o0000ooooooooool0Goooool3o`00
000300000?l0003o000005Gooooo0ol00009ooooo`004_ooool01?l0003oooooooooool00008oooo
o`?o00001Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04Oooooo0ol000000ooo
oooo0000o`00000;o`00000300000?l0003o000000Go0000Foooool00ol0003oooooooooo`07oooo
o`004_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo057ooooo2?l000001@00003oooooo`000?oo
ool0000000Co000000<00000o`000?ooool0HOooool00ol0003oooooooooo`07ooooo`004_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`0Uooooo`Co00003Oooool00`00003oooooooooo`0nooooo`Co000000<00000ooooooooool0
Koooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Wooooo0ol00005ooooo`03o`000?oo
oooooooo02Sooooo1?l0000;ooooo`03o`000?oooooooooo03kooooo0ol0001booooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo02_ooooo1?l0001:ooooo`?o0000LOooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0[ooooo`03o`000000003o0000
00Co00002_ooool2o`0003cooooo0ol0001`ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo02kooooo1_l0000:ooooo`03o`000?oooooo000001Kooooo00?o0000oooooooo
ool08Oooool3o`0006oooooo00?o0000ooooooooool01oooool002Kooooo0_l0000aooooo`Oo0000
2oooool2000001;ooooo00Co0000ooooool0003o00008_ooool00`00003o0000o`00001]ooooo`;o
00002Oooool002Kooooo00?o0000ooooooooool0<oooool6o`0001oooooo1Ol0000Pooooo`Co0000
K?ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0eooooo`0300000?l0
003o000000Go00002Oooool00ol0003oooooooooo`0Aooooo`Ko00007oooool00`00003o0000o`00
001[ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo03Oooooo1ol0000;
ooooo`03o`000?oooooooooo017ooooo00@00000o`000?l0000000000_l0000Mooooo`?o000000<0
0000ooooooooool0Ioooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0j
ooooo`Oo00002_ooool00ol0003oooooooooo`0@ooooo`So00007?ooool3o`0006Sooooo00?o0000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0??ooool8o`0001cooooo2?l0000Koooo
o`Co0000I_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0oooooo`So
00007?ooool8o`0001[ooooo0ol0001Uooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000
@_ooool8o`0000Wooooo00?o0000ooooooooool04?ooool2o`00000300000?l0003o000000Co0000
6?ooool3o`0006?ooooo0_l00009ooooo`009_ooool00ol0003oooooooooo`14ooooo`So00002?oo
ool2o`0001;ooooo0ol000000`00003o0000o`000002o`0001Sooooo0ol0001Rooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Kooooo2?l00009ooooo`;o00004Oooool0
0`00003o0000o`000006o`0001Kooooo00<00000o`000?l00000HOooool00ol0003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`18ooooo`Wo00006_ooool;o`0001Cooooo1?l0001Ooooo
o`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04_ooooo1ol000000`00003o
ooooooooo`06ooooo`0300000?oooooooooo013ooooo3?l0000Booooo`Co0000GOooool00ol0003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo000000Co0000
00<00000o`000?ooool01oooool00ol0003oooooooooo`0?ooooo`8000000_l00002ooooo`Oo0000
4?ooool4o`0005cooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Cooo
ool00`00003o0000o`000006o`0001[ooooo0P000003o`0000;ooooo1_l0000@ooooo`Co0000F_oo
ool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Aooooo`Wo00002?ooool0
0`00003o0000ooooo`0Aooooo`?o00000oooool00`00003o0000o`000004o`0000gooooo1?l0001I
ooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000EOooool9o`0000Wooooo00?o0000oooo
ooooool03oooool3o`0000Cooooo0_l000000`00003o0000o`000002o`0000_ooooo00@00000o`00
0000003o0000Eoooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo05Kooooo00?o00000000
0?l000001ol0000Iooooo`Co00001Oooool6o`0000[ooooo1?l0001Gooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo05Wooooo2Ol0000Jooooo`0300000?l0003ooooo00Ko
oooo00?o000000000?l000001_l00004ooooo`Go0000E_ooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`1Kooooo`0300000?l0003o000000;o000000<00000o`000?l00000
0_l00006ooooo`?o00003oooool4o`0000Oooooo4?l0001Eooooo`03o`000?oooooooooo00Oooooo
000Nooooo`?o00001Oooool00ol0003oooooooooo`1Mooooo`Co000000<00000ooooo`0000000ol0
0007ooooo`03o`00000000000000013ooooo0ol00009ooooo`co0000E?ooool00ol0003ooooooooo
o`07ooooo`007oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;Oooool01?l0003oooooooooo`000002o`00000300000?oooooooooo00?o00002?oo
ool00ol0003oooooooooo`0?ooooo`?o00001oooool01?l0003oooooooooooooool9o`0002?ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`007oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01_l0003ooooooooo
oooooooo0000000000?o000000D00000ooooo`00003o000000000008ooooo`0300000?oooooo0000
00_ooooo00Go0000ooooooooool00000ooooo`02o`0000Gooooo00?o0000ooooooooool01Oooool2
o`00000300000?l0003o000000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool001oooooo00?o0000oooo
ooooool01?oooomYo`00000300000?l0003o000008Go00002Oooool001oooooo00?o0000oooooooo
ool0o_ooool001kooooo0_l0003oooooo`7ooooo000Oooooo`03o`000?oooooooooo0?kooooo003o
ooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.158908, -0.161707, \
0.00416367, 0.00673696}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.27295 .53168 Mdot
.39538 .55966 Mdot
.32854 .20317 Mdot
.62181 .59872 Mdot
.28585 .54996 Mdot
.52485 .59746 Mdot
.32953 .5518 Mdot
.59177 .02329 Mdot
.03729 .23091 Mdot
.25192 .29754 Mdot
.28641 .5515 Mdot
.63131 .03769 Mdot
.4774 .61421 Mdot
.77176 .09215 Mdot
.43193 .11952 Mdot
.25495 .52532 Mdot
.22415 .27696 Mdot
.14439 .26907 Mdot
.08528 .21614 Mdot
.19571 .28437 Mdot
.51744 .05595 Mdot
.52688 .61468 Mdot
.01593 .43319 Mdot
.05269 .44442 Mdot
.53887 .00613 Mdot
.37117 .59183 Mdot
.29424 .55837 Mdot
.0026 .21968 Mdot
.06661 .24226 Mdot
.43512 .5764 Mdot
.53548 .03083 Mdot
.23742 .29406 Mdot
.36991 .52719 Mdot
.31777 .23974 Mdot
.92987 .39126 Mdot
.77072 .12409 Mdot
.74728 .08127 Mdot
.15218 .46068 Mdot
.17674 .49077 Mdot
.15661 .27456 Mdot
.3367 .53695 Mdot
.52487 .52345 Mdot
.32967 .19333 Mdot
.91682 .39968 Mdot
.93052 .16517 Mdot
.60836 .58287 Mdot
.43076 .59752 Mdot
.38859 .57937 Mdot
.39128 .03087 Mdot
.61283 .06367 Mdot
.89269 .17355 Mdot
.37814 .5534 Mdot
.31202 .56596 Mdot
.09995 .25429 Mdot
.42522 .55245 Mdot
.92791 .18229 Mdot
.66216 .05135 Mdot
.47892 .02058 Mdot
.58291 .05145 Mdot
.00921 .42797 Mdot
.66925 .06104 Mdot
.67818 .1154 Mdot
.656 .10627 Mdot
.76405 .08685 Mdot
.89867 .39607 Mdot
.71217 .09902 Mdot
.92268 .18606 Mdot
.54965 .0265 Mdot
.13524 .2641 Mdot
.56011 .58905 Mdot
.43052 .55464 Mdot
.98318 .21338 Mdot
.37193 .55019 Mdot
.41753 .54049 Mdot
.36718 .58021 Mdot
.24896 .51842 Mdot
.33306 .55385 Mdot
.86063 .1499 Mdot
.35845 .5469 Mdot
.03444 .2331 Mdot
.30566 .55787 Mdot
.57271 .01537 Mdot
.42416 .05663 Mdot
.39393 .01913 Mdot
.37705 .55142 Mdot
.40057 .54149 Mdot
.56531 .03634 Mdot
.66025 .04913 Mdot
.25747 .52637 Mdot
.0275 .19821 Mdot
.96522 .41429 Mdot
.26767 .54422 Mdot
.69413 .12101 Mdot
.28537 .55148 Mdot
.18996 .23741 Mdot
.11676 .46578 Mdot
.42777 .59322 Mdot
.08547 .45584 Mdot
.47509 .56157 Mdot
.30217 .55764 Mdot
.43099 .02807 Mdot
.43915 .02983 Mdot
.65695 .10148 Mdot
.05368 .44661 Mdot
.48763 .59765 Mdot
.47489 .09232 Mdot
.17993 .47064 Mdot
.47364 .56018 Mdot
.66885 .43852 Mdot
.03635 .23286 Mdot
.79103 .09786 Mdot
.71831 .06328 Mdot
.29566 .5378 Mdot
.90167 .17839 Mdot
.55826 .54735 Mdot
.3651 .1885 Mdot
.61688 .58798 Mdot
.27762 .54984 Mdot
.36407 .54843 Mdot
.09898 .43933 Mdot
.82281 .14982 Mdot
.11878 .26152 Mdot
.31595 .56205 Mdot
.34022 .57131 Mdot
.59948 .07515 Mdot
.72341 .10373 Mdot
.37329 .52637 Mdot
.0833 .45549 Mdot
.39303 .55957 Mdot
.70426 .06726 Mdot
.20724 .23855 Mdot
.3045 .54106 Mdot
.69475 .11866 Mdot
.35732 .58435 Mdot
.40709 .15128 Mdot
.45064 .14721 Mdot
.57659 .06367 Mdot
.47726 .57681 Mdot
.17882 .47206 Mdot
.80529 .14283 Mdot
.16077 .4632 Mdot
.47538 .00695 Mdot
.18058 .47237 Mdot
.63839 .09995 Mdot
.22274 .51153 Mdot
.28668 .51565 Mdot
.92509 .40223 Mdot
.34333 .5384 Mdot
.35092 .58209 Mdot
.57258 .04028 Mdot
.51071 .57353 Mdot
.61967 .0406 Mdot
.21877 .48822 Mdot
.93572 .19433 Mdot
.78341 .37749 Mdot
.57908 .59524 Mdot
.59757 .01116 Mdot
.08899 .43483 Mdot
.34474 .5142 Mdot
.29421 .51775 Mdot
.1296 .4711 Mdot
.43668 .55887 Mdot
.38343 .57714 Mdot
.10662 .44069 Mdot
.74539 .11862 Mdot
.21867 .28882 Mdot
.79567 .13923 Mdot
.76748 .08691 Mdot
.70792 .06751 Mdot
.78214 .10747 Mdot
.36634 .18448 Mdot
.10264 .24455 Mdot
.83781 .12908 Mdot
.13626 .26688 Mdot
.28807 .5288 Mdot
.38514 .56947 Mdot
.5921 .04433 Mdot
.97369 .41628 Mdot
.69386 .05404 Mdot
.31112 .565 Mdot
.18694 .23765 Mdot
.31188 .24813 Mdot
.76039 .09871 Mdot
.33165 .57351 Mdot
.56209 .01092 Mdot
.20733 .50602 Mdot
.04103 .23275 Mdot
.29047 .55213 Mdot
.92791 .40224 Mdot
.15711 .48384 Mdot
.46737 .01572 Mdot
.71763 .0725 Mdot
.65067 .10435 Mdot
.96804 .20447 Mdot
.60615 .60034 Mdot
.60114 .60045 Mdot
.59608 .59927 Mdot
.53873 .0634 Mdot
.30102 .55504 Mdot
.00734 .4305 Mdot
.09529 .45991 Mdot
.10698 .44145 Mdot
.78342 .09431 Mdot
.34278 .5397 Mdot
.64516 .06703 Mdot
.42418 .55277 Mdot
.67654 .10971 Mdot
.32312 .53047 Mdot
.57166 .02027 Mdot
.2723 .5436 Mdot
.19444 .2842 Mdot
.51647 .0127 Mdot
.95104 .19115 Mdot
.17753 .27751 Mdot
.05329 .23906 Mdot
.64803 .09749 Mdot
.93189 .40374 Mdot
.51222 .50468 Mdot
.31537 .56201 Mdot
.1325 .45157 Mdot
.30307 .25611 Mdot
.63884 .09955 Mdot
.48063 .61566 Mdot
.81942 .14467 Mdot
.86615 .38875 Mdot
.59584 .02406 Mdot
.61812 .49485 Mdot
.67788 .09006 Mdot
.31672 .24143 Mdot
.33061 .18624 Mdot
.78348 .10781 Mdot
.24341 .49597 Mdot
.21232 .50721 Mdot
.18121 .49272 Mdot
.65204 .05338 Mdot
.28802 .28268 Mdot
.25616 .50349 Mdot
.59377 .04936 Mdot
.14306 .47723 Mdot
.63495 .04678 Mdot
.67585 .39688 Mdot
.28133 .53471 Mdot
.73702 .07177 Mdot
.32537 .57042 Mdot
.56793 .55449 Mdot
.08032 .45483 Mdot
.67889 .11155 Mdot
.88398 .16512 Mdot
.54395 .60648 Mdot
.29955 .52119 Mdot
.28944 .55059 Mdot
.03714 .43644 Mdot
.61945 .60109 Mdot
.5323 .5808 Mdot
.65663 .03607 Mdot
.85353 .15284 Mdot
.38644 .57838 Mdot
.69143 .0704 Mdot
.70225 .06642 Mdot
.76458 .08626 Mdot
.98798 .42307 Mdot
.36671 .52485 Mdot
.17594 .46841 Mdot
.76274 .08696 Mdot
.4374 .59677 Mdot
.44609 .584 Mdot
.97068 .4149 Mdot
.59571 .01014 Mdot
.64193 .03045 Mdot
.31644 .52735 Mdot
.15199 .2318 Mdot
.2203 .51054 Mdot
.3741 .52744 Mdot
.22709 .29282 Mdot
.14635 .25795 Mdot
.38499 .52921 Mdot
.16435 .23407 Mdot
.10094 .43897 Mdot
.78587 .09677 Mdot
.73222 .08671 Mdot
.41612 .14883 Mdot
.34463 .25607 Mdot
.34208 .25977 Mdot
.40754 .56436 Mdot
.96889 .20635 Mdot
.06535 .24081 Mdot
.17751 .49359 Mdot
.30359 .55772 Mdot
.66082 .07805 Mdot
.36656 .52325 Mdot
.17841 .27831 Mdot
.31388 .52517 Mdot
.99238 .21281 Mdot
.59848 .01189 Mdot
.23576 .51554 Mdot
.96625 .17801 Mdot
.36103 .20278 Mdot
.67194 .1123 Mdot
.47323 .59213 Mdot
.3578 .21214 Mdot
.47364 .5603 Mdot
.00676 .21984 Mdot
.0996 .46252 Mdot
.2491 .29601 Mdot
.60493 .01391 Mdot
.37875 .53094 Mdot
.01916 .22739 Mdot
.69223 .06279 Mdot
.03889 .22999 Mdot
.3249 .55055 Mdot
.4309 .02721 Mdot
.93003 .18971 Mdot
.4072 .54346 Mdot
.75508 .08794 Mdot
.50923 .50533 Mdot
.25049 .2965 Mdot
.6419 .03072 Mdot
.62661 .02418 Mdot
.03796 .43992 Mdot
.79099 .09446 Mdot
.60913 .01618 Mdot
.46341 .01338 Mdot
.83821 .15227 Mdot
.01825 .22293 Mdot
.61168 .06265 Mdot
.1134 .25725 Mdot
.06921 .22666 Mdot
.63651 .04101 Mdot
.74108 .10648 Mdot
.01639 .43309 Mdot
.14107 .45665 Mdot
.67841 .08517 Mdot
.15476 .48056 Mdot
.08177 .23066 Mdot
.26834 .5062 Mdot
.42884 .6047 Mdot
.77392 .1248 Mdot
.48889 .60271 Mdot
.3925 .60009 Mdot
.19674 .27111 Mdot
.25691 .51587 Mdot
.21457 .48531 Mdot
.55613 .00764 Mdot
.35227 .57596 Mdot
.62214 .4941 Mdot
.54006 .00653 Mdot
.37629 .55353 Mdot
.52186 .52115 Mdot
.37547 .59231 Mdot
.69233 .12045 Mdot
.79098 .37641 Mdot
.43318 .54549 Mdot
.22163 .29017 Mdot
.52376 .49986 Mdot
.56236 .49922 Mdot
.96226 .19534 Mdot
.54253 .00298 Mdot
.03896 .44026 Mdot
.78979 .0932 Mdot
.58711 .56722 Mdot
.71087 .10355 Mdot
.54921 .01036 Mdot
.20864 .50332 Mdot
.83728 .15536 Mdot
.13089 .45215 Mdot
.49295 .11082 Mdot
.93832 .40468 Mdot
.85484 .16296 Mdot
.13314 .47324 Mdot
.73047 .10255 Mdot
.10808 .46527 Mdot
.61832 .08283 Mdot
.3479 .54102 Mdot
.57448 .59332 Mdot
.33347 .17284 Mdot
.77695 .13096 Mdot
.71146 .07045 Mdot
.53774 .53213 Mdot
.51457 .60841 Mdot
.08129 .24861 Mdot
.59412 .08344 Mdot
.96138 .41311 Mdot
.16802 .48934 Mdot
.33722 .5751 Mdot
.11104 .46578 Mdot
.38457 .55756 Mdot
.59933 .5988 Mdot
.52147 .49939 Mdot
.36343 .52116 Mdot
.55464 .00757 Mdot
.88226 .14647 Mdot
.40937 .04759 Mdot
.07597 .24343 Mdot
.63137 .06511 Mdot
.03797 .44055 Mdot
.78696 .35453 Mdot
.24438 .49764 Mdot
.68397 .11767 Mdot
.07531 .24485 Mdot
.4582 .60547 Mdot
.31755 .56573 Mdot
.15856 .262 Mdot
.48542 .12 Mdot
.39867 .02153 Mdot
.02558 .43403 Mdot
.58353 .05097 Mdot
.95889 .40989 Mdot
.55624 .49928 Mdot
.15635 .26119 Mdot
.32538 .27359 Mdot
.75014 .08446 Mdot
.11341 .22311 Mdot
.97071 .41632 Mdot
.21577 .48489 Mdot
.85032 .16172 Mdot
.86242 .38552 Mdot
.88219 .17351 Mdot
.37185 .54896 Mdot
.12263 .47067 Mdot
.06058 .20839 Mdot
.28068 .28356 Mdot
.38001 .55585 Mdot
.07892 .24579 Mdot
.91694 .15943 Mdot
.24303 .28043 Mdot
.48072 .00163 Mdot
.57464 .04805 Mdot
.24694 .28054 Mdot
.07691 .4531 Mdot
.75756 .11806 Mdot
.73404 .07994 Mdot
.11816 .26054 Mdot
.28402 .51626 Mdot
.84258 .15304 Mdot
.30481 .55708 Mdot
.05984 .24151 Mdot
.9655 .20271 Mdot
.29918 .54283 Mdot
.36779 .52371 Mdot
.08678 .45541 Mdot
.12348 .26377 Mdot
.60656 .60205 Mdot
.0219 .22839 Mdot
.43048 .60606 Mdot
.39125 .03011 Mdot
.5421 .02293 Mdot
.26347 .5283 Mdot
.31633 .56454 Mdot
.80631 .10278 Mdot
.14418 .26906 Mdot
.94008 .40867 Mdot
.30099 .54042 Mdot
.56601 .55282 Mdot
.82357 .14517 Mdot
.87043 .38606 Mdot
.45184 .58668 Mdot
.09959 .25481 Mdot
.79146 .09417 Mdot
.3381 .55951 Mdot
.16599 .48664 Mdot
.99271 .2137 Mdot
.22074 .48852 Mdot
.2508 .52311 Mdot
.51963 .51866 Mdot
.35673 .51765 Mdot
.28273 .53583 Mdot
.46333 .00183 Mdot
.73916 .11525 Mdot
.96638 .41619 Mdot
.25797 .54103 Mdot
.15731 .23263 Mdot
.87691 .39062 Mdot
.49456 .11064 Mdot
.19141 .49603 Mdot
.28147 .55128 Mdot
.39484 .03595 Mdot
.15666 .462 Mdot
.12468 .47192 Mdot
.94261 .19397 Mdot
.33244 .53503 Mdot
.15281 .48409 Mdot
.49756 .0487 Mdot
.65969 .07783 Mdot
.49258 .02707 Mdot
.66802 .11023 Mdot
.37958 .57634 Mdot
.40135 .15271 Mdot
.75157 .08371 Mdot
.0183 .43115 Mdot
.45939 .61783 Mdot
.38842 .56025 Mdot
.18172 .28126 Mdot
.43114 .02823 Mdot
.31059 .52691 Mdot
.02751 .23042 Mdot
.88282 .16927 Mdot
.78965 .12644 Mdot
.92893 .40288 Mdot
.31567 .52824 Mdot
.29151 .55631 Mdot
.70601 .35813 Mdot
.3842 .16011 Mdot
.78981 .09931 Mdot
.63794 .48714 Mdot
.36456 .5666 Mdot
.64339 .10237 Mdot
.67169 .10675 Mdot
.10982 .46442 Mdot
.62065 .59535 Mdot
.83892 .3795 Mdot
.49106 .11931 Mdot
.35882 .57845 Mdot
.80558 .10567 Mdot
.42732 .54313 Mdot
.81867 .37835 Mdot
.84732 .38529 Mdot
.21177 .48439 Mdot
.26347 .54301 Mdot
.13968 .47843 Mdot
.02706 .43631 Mdot
.61821 .59825 Mdot
.09527 .46206 Mdot
.20267 .48149 Mdot
.32849 .20084 Mdot
.45011 .58628 Mdot
.08475 .21578 Mdot
.31379 .52864 Mdot
.72051 .08235 Mdot
.33927 .53729 Mdot
.23615 .29483 Mdot
.69936 .06468 Mdot
.77913 .12751 Mdot
.32158 .55263 Mdot
.92523 .40349 Mdot
.14499 .47927 Mdot
.37727 .5247 Mdot
.15088 .27057 Mdot
.44185 .00378 Mdot
.64857 .09707 Mdot
.66761 .44592 Mdot
.30357 .55987 Mdot
.13551 .47424 Mdot
.76566 .0902 Mdot
.48193 .59977 Mdot
.62144 .5975 Mdot
.07494 .42905 Mdot
.12108 .26036 Mdot
.87956 .16965 Mdot
.7393 .08199 Mdot
.60329 .57919 Mdot
.59972 .05794 Mdot
.27963 .51178 Mdot
.8069 .10475 Mdot
.46136 .12063 Mdot
.81568 .37736 Mdot
.75286 .07938 Mdot
.0031 .21687 Mdot
.79608 .11285 Mdot
.84311 .37981 Mdot
.70736 .06764 Mdot
.84271 .38017 Mdot
.35215 .24284 Mdot
.55587 .05453 Mdot
.23801 .51764 Mdot
.48457 .04485 Mdot
.30323 .55905 Mdot
.43387 .02873 Mdot
.54699 .00429 Mdot
.31936 .54823 Mdot
.47667 .59773 Mdot
.03429 .43742 Mdot
.59393 .04991 Mdot
.97045 .41687 Mdot
.80808 .37886 Mdot
.57025 .06107 Mdot
.75337 .07873 Mdot
.79427 .10053 Mdot
.06722 .44878 Mdot
.56828 .03451 Mdot
.5645 .043 Mdot
.81436 .10837 Mdot
.47186 .09119 Mdot
.76509 .08593 Mdot
.19561 .49848 Mdot
.55615 .0401 Mdot
.21062 .50397 Mdot
.07638 .21375 Mdot
.29432 .55752 Mdot
.89499 .39174 Mdot
.05303 .44532 Mdot
.33854 .53593 Mdot
.15917 .46261 Mdot
.26241 .50537 Mdot
.62469 .06798 Mdot
.34023 .56009 Mdot
.82359 .37797 Mdot
.5585 .54716 Mdot
.47061 .5905 Mdot
.54917 .60815 Mdot
.25099 .52182 Mdot
.75681 .0822 Mdot
.88113 .38929 Mdot
.6992 .05502 Mdot
.0015 .21878 Mdot
.65778 .05636 Mdot
.81101 .10337 Mdot
.39601 .03525 Mdot
.79616 .10057 Mdot
.10299 .22033 Mdot
.8724 .38591 Mdot
.04146 .43984 Mdot
.4976 .58565 Mdot
.45844 .01152 Mdot
.39847 .59393 Mdot
.49315 .1077 Mdot
.28121 .53473 Mdot
.50188 .58684 Mdot
.91311 .18152 Mdot
.29989 .28237 Mdot
.34127 .15111 Mdot
.22925 .51081 Mdot
.23132 .29446 Mdot
.77732 .08798 Mdot
.73574 .07082 Mdot
.94631 .1989 Mdot
.03976 .43934 Mdot
.53899 .49872 Mdot
.81389 .10436 Mdot
.69428 .05297 Mdot
.25923 .29917 Mdot
.44925 .12034 Mdot
.40781 .56524 Mdot
.55944 .49862 Mdot
.18016 .27903 Mdot
.36068 .52391 Mdot
.35089 .5154 Mdot
.05535 .44532 Mdot
.93212 .19331 Mdot
.51743 .49973 Mdot
.33514 .56796 Mdot
.53012 .59949 Mdot
.39851 .56417 Mdot
.34887 .25081 Mdot
.37544 .55346 Mdot
.34377 .57272 Mdot
.71373 .10584 Mdot
.49608 .60225 Mdot
.65221 .04801 Mdot
.50158 .603 Mdot
.39547 .03529 Mdot
.97592 .20039 Mdot
.34728 .56306 Mdot
.73744 .11459 Mdot
.16311 .48558 Mdot
.50005 .0098 Mdot
.05363 .23764 Mdot
.53671 .53268 Mdot
.75734 .08169 Mdot
.6735 .40682 Mdot
.74982 .07809 Mdot
.26905 .50949 Mdot
.56747 .03378 Mdot
.71329 .06166 Mdot
.18699 .47454 Mdot
.26929 .54528 Mdot
.44034 .11981 Mdot
.95644 .20022 Mdot
.97118 .20782 Mdot
.58674 .06801 Mdot
.39306 .59165 Mdot
.82191 .13976 Mdot
.72056 .07361 Mdot
.00281 .42797 Mdot
.48329 .61103 Mdot
.97555 .206 Mdot
.51858 .61082 Mdot
.40257 .56523 Mdot
.02591 .22804 Mdot
.47466 .57522 Mdot
.77873 .37656 Mdot
.10194 .4605 Mdot
.43242 .00066 Mdot
.37282 .17116 Mdot
.6874 .11782 Mdot
.56854 .01305 Mdot
.73088 .06846 Mdot
.00545 .22159 Mdot
.09986 .21974 Mdot
.07119 .24196 Mdot
.6316 .03773 Mdot
.39809 .53291 Mdot
.70072 .12318 Mdot
.32162 .56809 Mdot
.03204 .43669 Mdot
.34027 .51213 Mdot
.57612 .00267 Mdot
.4216 .55112 Mdot
.53891 .00061 Mdot
.28392 .54795 Mdot
.08397 .43293 Mdot
.82762 .12534 Mdot
.04361 .44326 Mdot
.14078 .47683 Mdot
.6256 .08709 Mdot
.73533 .07744 Mdot
.10029 .46341 Mdot
.95262 .4127 Mdot
.49379 .11511 Mdot
.06734 .24162 Mdot
.07982 .43098 Mdot
.81049 .11839 Mdot
.22268 .23939 Mdot
.78731 .3765 Mdot
.53337 .60051 Mdot
.57425 .01493 Mdot
.19752 .28366 Mdot
.82661 .3805 Mdot
.34044 .56013 Mdot
.16965 .2347 Mdot
.41684 .61056 Mdot
.44689 .07244 Mdot
.43038 .55447 Mdot
.36608 .52572 Mdot
.496 .58406 Mdot
.38243 .53381 Mdot
.68175 .05963 Mdot
.97313 .18044 Mdot
.97841 .40765 Mdot
.38865 .53472 Mdot
.3376 .55821 Mdot
.77995 .08984 Mdot
.39188 .02149 Mdot
.81441 .14286 Mdot
.50056 .57059 Mdot
.49513 .01485 Mdot
.1866 .23725 Mdot
.45777 .58552 Mdot
.79434 .3744 Mdot
.41644 .5716 Mdot
.1358 .26375 Mdot
.16161 .4837 Mdot
.97541 .41946 Mdot
.10341 .46245 Mdot
.27451 .54776 Mdot
.32195 .27558 Mdot
.7339 .35158 Mdot
.61673 .49466 Mdot
.61807 .60061 Mdot
.5983 .49796 Mdot
.34902 .51709 Mdot
.50721 .60524 Mdot
.33086 .55631 Mdot
.49432 .11497 Mdot
.84052 .38375 Mdot
.94173 .1934 Mdot
.68742 .11786 Mdot
.14449 .47921 Mdot
.05825 .20786 Mdot
.61331 .58551 Mdot
.25895 .52541 Mdot
.85467 .38464 Mdot
.58318 .0353 Mdot
.32347 .56317 Mdot
.35788 .58566 Mdot
.39159 .53156 Mdot
.37319 .58283 Mdot
.6454 .09641 Mdot
.6664 .04092 Mdot
.94654 .4099 Mdot
.44806 .58132 Mdot
.10279 .25581 Mdot
.29056 .55477 Mdot
.01407 .22284 Mdot
.40994 .53834 Mdot
.50146 .58635 Mdot
.10033 .25322 Mdot
.83983 .3826 Mdot
.88022 .14593 Mdot
.65652 .0378 Mdot
.97699 .41647 Mdot
.94891 .20059 Mdot
.92802 .1913 Mdot
.8739 .38912 Mdot
.65284 .03524 Mdot
.27616 .51269 Mdot
.32056 .52943 Mdot
.1125 .22297 Mdot
.50991 .5727 Mdot
.89825 .15313 Mdot
.65324 .09814 Mdot
.33229 .55349 Mdot
.6532 .10533 Mdot
.47847 .59353 Mdot
.72101 .10335 Mdot
.56234 .05725 Mdot
.13785 .26817 Mdot
.42437 .54313 Mdot
.32749 .2071 Mdot
.77765 .08969 Mdot
.76921 .08437 Mdot
.28959 .51613 Mdot
.93821 .1949 Mdot
.15514 .25181 Mdot
.62078 .60105 Mdot
.2417 .49732 Mdot
.48015 .02164 Mdot
.40041 .58501 Mdot
.6475 .05151 Mdot
.07268 .24654 Mdot
.29759 .5589 Mdot
.61079 .0175 Mdot
.53856 .06309 Mdot
.37056 .52513 Mdot
.92957 .18906 Mdot
.02156 .43535 Mdot
.31453 .56503 Mdot
.01739 .43126 Mdot
.0119 .42817 Mdot
.00195 .19009 Mdot
.22774 .51423 Mdot
.27688 .54928 Mdot
.35181 .13885 Mdot
.18683 .47281 Mdot
.89482 .39476 Mdot
.80081 .11451 Mdot
.3806 .52892 Mdot
.152 .46013 Mdot
.99701 .2168 Mdot
.47276 .12059 Mdot
.99123 .42124 Mdot
.40761 .53646 Mdot
.70803 .07664 Mdot
.96742 .20505 Mdot
.2954 .54062 Mdot
.23127 .29174 Mdot
.95763 .41225 Mdot
.3218 .56351 Mdot
.99348 .21357 Mdot
.55501 .58771 Mdot
.05516 .44326 Mdot
.35179 .23845 Mdot
.79171 .10111 Mdot
.09271 .25169 Mdot
.54645 .00894 Mdot
.84962 .38311 Mdot
.45885 .08068 Mdot
.52551 .52404 Mdot
.66456 .10834 Mdot
.64784 .06779 Mdot
.05637 .44382 Mdot
.2913 .55598 Mdot
.78419 .37773 Mdot
.96092 .20498 Mdot
.82141 .38055 Mdot
.86939 .38863 Mdot
.3808 .57305 Mdot
.42782 .14732 Mdot
.09343 .2496 Mdot
.15691 .27222 Mdot
.39131 .55875 Mdot
.11952 .46869 Mdot
.20497 .48257 Mdot
.78393 .09591 Mdot
.15607 .4623 Mdot
.48024 .00027 Mdot
.09602 .43686 Mdot
.0802 .45513 Mdot
.55985 .58943 Mdot
.04162 .44018 Mdot
.2483 .52166 Mdot
.28596 .51682 Mdot
.14373 .47904 Mdot
.65839 .46854 Mdot
.05659 .24047 Mdot
.47601 .56172 Mdot
.48885 .1188 Mdot
.07844 .24443 Mdot
.4126 .56641 Mdot
.1723 .49178 Mdot
.15947 .26193 Mdot
.28103 .5138 Mdot
.14117 .45579 Mdot
.87061 .38599 Mdot
.50948 .05272 Mdot
.43549 .06569 Mdot
.02629 .21887 Mdot
.57158 .00025 Mdot
.66644 .10978 Mdot
.74813 .11458 Mdot
.44789 .58063 Mdot
.88127 .39161 Mdot
.61432 .58859 Mdot
.15688 .48226 Mdot
.33891 .15705 Mdot
.87682 .38827 Mdot
.99373 .42403 Mdot
.5918 .57044 Mdot
.14183 .25688 Mdot
.74128 .07236 Mdot
.41163 .04855 Mdot
.3526 .13799 Mdot
.21973 .48712 Mdot
.55224 .06797 Mdot
.99757 .21639 Mdot
.94958 .19657 Mdot
.3903 .01897 Mdot
.76871 .12358 Mdot
.42232 .59419 Mdot
.3176 .56607 Mdot
.32642 .55078 Mdot
.53149 .06112 Mdot
.74834 .35109 Mdot
.90765 .39479 Mdot
.49608 .11161 Mdot
.59245 .498 Mdot
.1533 .27307 Mdot
.97921 .41989 Mdot
.39148 .56055 Mdot
.9367 .16695 Mdot
.59744 .02406 Mdot
.02779 .22944 Mdot
.42438 .02525 Mdot
.61465 .58801 Mdot
.8104 .10342 Mdot
.35559 .52138 Mdot
.93095 .18334 Mdot
.91965 .40262 Mdot
.75683 .08384 Mdot
.47344 .59234 Mdot
.44834 .55126 Mdot
.54788 .00963 Mdot
.88997 .14923 Mdot
.34255 .51337 Mdot
.50069 .04937 Mdot
.32953 .53295 Mdot
.55331 .02263 Mdot
.89472 .17478 Mdot
.55009 .03727 Mdot
.17566 .49261 Mdot
.78565 .09435 Mdot
.27158 .53074 Mdot
.97604 .4201 Mdot
.05796 .24032 Mdot
.42397 .59126 Mdot
.7538 .08496 Mdot
.30761 .25251 Mdot
.66482 .04028 Mdot
.79671 .37603 Mdot
.39265 .03475 Mdot
.66866 .10603 Mdot
.11689 .46929 Mdot
.15201 .45916 Mdot
.65249 .04769 Mdot
.75435 .08444 Mdot
.41526 .05117 Mdot
.40475 .04333 Mdot
.13066 .45199 Mdot
.19584 .23865 Mdot
.46178 .6069 Mdot
.74932 .08538 Mdot
.61568 .09148 Mdot
.66723 .08564 Mdot
.14195 .47846 Mdot
.613 .58815 Mdot
.29407 .5396 Mdot
.42808 .55346 Mdot
.58829 .00713 Mdot
.55344 .03221 Mdot
.47252 .59555 Mdot
.86014 .1611 Mdot
.8227 .10823 Mdot
.06629 .24108 Mdot
.15002 .271 Mdot
.04372 .20328 Mdot
.01445 .21459 Mdot
.30419 .56218 Mdot
.56016 .54792 Mdot
.3575 .13416 Mdot
.07955 .2142 Mdot
.26108 .53978 Mdot
.33672 .26508 Mdot
.92971 .18264 Mdot
.17407 .2657 Mdot
.66464 .05118 Mdot
.65858 .03845 Mdot
.81462 .1315 Mdot
.39511 .0359 Mdot
.5615 .03526 Mdot
.75463 .0792 Mdot
.76699 .08685 Mdot
.38085 .55337 Mdot
.4502 .61364 Mdot
.72587 .06653 Mdot
.65998 .07736 Mdot
.23454 .26648 Mdot
.47928 .09653 Mdot
.16378 .26295 Mdot
.63662 .04043 Mdot
.67228 .10888 Mdot
.9576 .2039 Mdot
.3218 .23228 Mdot
.67734 .04591 Mdot
.18404 .47267 Mdot
.43629 .60827 Mdot
.15949 .2616 Mdot
.20543 .27353 Mdot
.15611 .48421 Mdot
.66837 .11121 Mdot
.92155 .18689 Mdot
.29463 .51731 Mdot
.5294 .49917 Mdot
.8725 .16585 Mdot
.40736 .15024 Mdot
.16774 .27789 Mdot
.96799 .41388 Mdot
.23616 .51349 Mdot
.30546 .28127 Mdot
.35701 .54498 Mdot
.13599 .45412 Mdot
.27123 .54781 Mdot
.35274 .51644 Mdot
.30626 .56026 Mdot
.25058 .50061 Mdot
.88447 .17105 Mdot
.35604 .54355 Mdot
.743 .07495 Mdot
.07622 .42889 Mdot
.68847 .1183 Mdot
.4867 .5811 Mdot
.33228 .57268 Mdot
.24592 .50021 Mdot
.15647 .48249 Mdot
.43143 .59473 Mdot
.40706 .60619 Mdot
.9029 .17842 Mdot
.07823 .24489 Mdot
.8789 .16803 Mdot
.60919 .60073 Mdot
.6781 .11031 Mdot
.01347 .21394 Mdot
.33339 .53577 Mdot
.16758 .2753 Mdot
.0196 .43098 Mdot
.55843 .03019 Mdot
.44538 .58089 Mdot
.895 .17948 Mdot
.54952 .58602 Mdot
.05007 .44545 Mdot
.41612 .59161 Mdot
.09803 .25529 Mdot
.48422 .04454 Mdot
.66748 .10716 Mdot
.74381 .07564 Mdot
.33837 .55527 Mdot
.49504 .02763 Mdot
.70866 .06963 Mdot
.36039 .58556 Mdot
.72424 .1038 Mdot
.37725 .55457 Mdot
.08039 .45428 Mdot
.60384 .02662 Mdot
.24902 .26735 Mdot
.80534 .3752 Mdot
.20675 .50433 Mdot
.16124 .48543 Mdot
.72582 .10552 Mdot
.76173 .08754 Mdot
.00433 .218 Mdot
.86368 .38618 Mdot
.26719 .50746 Mdot
.49961 .00526 Mdot
.43411 .06366 Mdot
.16663 .27674 Mdot
.75138 .08573 Mdot
.90922 .18479 Mdot
.39694 .59336 Mdot
.18101 .49143 Mdot
.88299 .16979 Mdot
.78066 .13271 Mdot
.82065 .3768 Mdot
.85707 .16313 Mdot
.58486 .0412 Mdot
.89747 .39558 Mdot
.10427 .25325 Mdot
.51425 .50118 Mdot
.33054 .18616 Mdot
.52736 .01731 Mdot
.86466 .13976 Mdot
.86221 .38551 Mdot
.4667 .03842 Mdot
.39978 .02196 Mdot
.4781 .09542 Mdot
.13934 .26493 Mdot
.00999 .22362 Mdot
.55824 .03377 Mdot
.30564 .28012 Mdot
.46039 .56933 Mdot
.34128 .57057 Mdot
.28855 .55542 Mdot
.38676 .01933 Mdot
.17421 .49107 Mdot
.4357 .57661 Mdot
.31379 .56163 Mdot
.95208 .20098 Mdot
.22538 .27749 Mdot
.55694 .00863 Mdot
.13395 .45195 Mdot
.55705 .61095 Mdot
.44529 .6048 Mdot
.78778 .13575 Mdot
.69302 .3661 Mdot
.50132 .60818 Mdot
.97765 .20682 Mdot
.22045 .27589 Mdot
.27208 .51102 Mdot
.50716 .57206 Mdot
.77068 .08933 Mdot
.4605 .55616 Mdot
.98635 .18502 Mdot
.81517 .10754 Mdot
.07133 .42708 Mdot
.47061 .01723 Mdot
.82543 .37732 Mdot
.61861 .59472 Mdot
.53159 .52881 Mdot
.46634 .03819 Mdot
.36857 .54782 Mdot
.8123 .11956 Mdot
.39892 .15338 Mdot
.878 .3897 Mdot
.25701 .28205 Mdot
.07152 .45234 Mdot
.54637 .02851 Mdot
.55436 .00672 Mdot
.73965 .11077 Mdot
.46515 .6132 Mdot
.60489 .01479 Mdot
.56978 .07465 Mdot
.02015 .19607 Mdot
.59175 .59795 Mdot
.56617 .0177 Mdot
.51569 .49946 Mdot
.64654 .04436 Mdot
.86634 .1633 Mdot
.7849 .13465 Mdot
.48823 .11892 Mdot
.32852 .27313 Mdot
.37527 .58377 Mdot
.14551 .26961 Mdot
.53043 .59932 Mdot
.30924 .55821 Mdot
.97115 .41715 Mdot
.32926 .19477 Mdot
.57452 .55837 Mdot
.57984 .4993 Mdot
.26739 .52902 Mdot
.06409 .2415 Mdot
.57357 .001 Mdot
.09094 .45998 Mdot
.22942 .51175 Mdot
.4403 .54901 Mdot
.59741 .07421 Mdot
.10546 .25636 Mdot
.06922 .45083 Mdot
.18297 .47181 Mdot
.52112 .49921 Mdot
.01227 .42798 Mdot
.72818 .10607 Mdot
.30123 .51991 Mdot
.58014 .56263 Mdot
.3078 .56169 Mdot
.99263 .21578 Mdot
.98423 .4098 Mdot
.51514 .57568 Mdot
.04133 .23492 Mdot
.68534 .37398 Mdot
.64224 .48487 Mdot
.74183 .08289 Mdot
.9395 .19699 Mdot
.60568 .60064 Mdot
.55067 .58679 Mdot
.84935 .38304 Mdot
.7144 .09577 Mdot
.11018 .44296 Mdot
.76739 .12206 Mdot
.10257 .22049 Mdot
.8563 .13656 Mdot
.71549 .10021 Mdot
.32209 .55136 Mdot
.8871 .17111 Mdot
.19854 .48005 Mdot
.42083 .55093 Mdot
.02055 .43107 Mdot
.34653 .51593 Mdot
.36456 .54756 Mdot
.23942 .49747 Mdot
.33732 .57014 Mdot
.5445 .60557 Mdot
.41165 .04815 Mdot
.21216 .28687 Mdot
.21837 .50936 Mdot
.84055 .384 Mdot
.7654 .12662 Mdot
.88912 .17258 Mdot
.17752 .49179 Mdot
.35357 .51884 Mdot
.73469 .11366 Mdot
.17454 .46898 Mdot
.74973 .08383 Mdot
.57419 .0364 Mdot
.47789 .61411 Mdot
.58672 .06868 Mdot
.48197 .60023 Mdot
.28659 .55096 Mdot
.99621 .21837 Mdot
.68445 .08844 Mdot
.23059 .51123 Mdot
.58299 .05114 Mdot
.78193 .09358 Mdot
.59905 .57564 Mdot
.2164 .23943 Mdot
.53628 .04568 Mdot
.15182 .45977 Mdot
.83812 .38013 Mdot
.12259 .22539 Mdot
.37526 .59258 Mdot
.42423 .61449 Mdot
.13865 .26538 Mdot
.92359 .18565 Mdot
.89669 .15237 Mdot
.76178 .10994 Mdot
.13267 .47496 Mdot
.66009 .46623 Mdot
.68547 .11332 Mdot
.22305 .48804 Mdot
.69095 .11779 Mdot
.26061 .50619 Mdot
.38626 .15873 Mdot
.77175 .12434 Mdot
.45043 .55161 Mdot
.43334 .57547 Mdot
.66491 .05093 Mdot
.65541 .07129 Mdot
.32336 .56323 Mdot
.46501 .03765 Mdot
.7654 .085 Mdot
.52248 .6116 Mdot
.29065 .53589 Mdot
.42662 .55247 Mdot
.93058 .18322 Mdot
.4232 .02539 Mdot
.29923 .55646 Mdot
.49258 .04749 Mdot
.80598 .10386 Mdot
.2318 .29195 Mdot
.29481 .55314 Mdot
.2834 .51386 Mdot
.5601 .00897 Mdot
.01649 .43253 Mdot
.40419 .04324 Mdot
.99348 .21387 Mdot
.01214 .2241 Mdot
.47617 .09258 Mdot
.74623 .07513 Mdot
.80966 .37917 Mdot
.2065 .23901 Mdot
.61361 .5884 Mdot
.29668 .55751 Mdot
.60448 .04429 Mdot
.7898 .09761 Mdot
.60818 .08816 Mdot
.96535 .20379 Mdot
.08711 .45521 Mdot
.80373 .10183 Mdot
.14536 .26836 Mdot
.54734 .00547 Mdot
.00171 .2169 Mdot
.39385 .15497 Mdot
.75727 .08097 Mdot
.67507 .11081 Mdot
.313 .27962 Mdot
.49499 .111 Mdot
.46786 .03916 Mdot
.06677 .2441 Mdot
.42467 .11962 Mdot
.4388 .61016 Mdot
.07193 .44996 Mdot
.3396 .5121 Mdot
.17601 .47068 Mdot
.56983 .55559 Mdot
.03333 .22125 Mdot
.32168 .27606 Mdot
.53624 .00059 Mdot
.37693 .59468 Mdot
.20101 .50033 Mdot
.50055 .6076 Mdot
.5545 .54423 Mdot
.11826 .26031 Mdot
.61486 .59942 Mdot
.7717 .08759 Mdot
.49512 .11733 Mdot
.20848 .50605 Mdot
.37709 .53151 Mdot
.92602 .40083 Mdot
.35289 .51824 Mdot
.51338 .59247 Mdot
.71964 .1076 Mdot
.06063 .42365 Mdot
.40008 .1213 Mdot
.03172 .23148 Mdot
.41263 .58652 Mdot
.59588 .01114 Mdot
.06959 .24143 Mdot
.23091 .29317 Mdot
.36805 .52425 Mdot
.08604 .2499 Mdot
.85106 .38275 Mdot
.31647 .56509 Mdot
.59914 .08607 Mdot
.41574 .54041 Mdot
.85821 .3825 Mdot
.50153 .01695 Mdot
.37704 .55222 Mdot
.59586 .02366 Mdot
.9537 .20246 Mdot
.87903 .1689 Mdot
.53648 .61739 Mdot
.81226 .1037 Mdot
.6914 .11964 Mdot
.17334 .48964 Mdot
.68663 .06131 Mdot
.38842 .01849 Mdot
.30245 .52156 Mdot
.1577 .26124 Mdot
.49349 .15159 Mdot
.89067 .17315 Mdot
.41028 .04802 Mdot
.82671 .37825 Mdot
.07873 .43028 Mdot
.91004 .39866 Mdot
.95523 .41257 Mdot
.26026 .50348 Mdot
.05865 .44778 Mdot
.69894 .09897 Mdot
.11462 .46726 Mdot
.76398 .12095 Mdot
.11778 .46798 Mdot
.22131 .23867 Mdot
.50807 .57277 Mdot
.62308 .03594 Mdot
.33533 .53671 Mdot
.7791 .09424 Mdot
.27425 .50892 Mdot
.09447 .21872 Mdot
.39952 .6032 Mdot
.29944 .55768 Mdot
.17471 .49076 Mdot
.91517 .18389 Mdot
.81189 .3792 Mdot
.96232 .20295 Mdot
.95478 .19894 Mdot
.04604 .23458 Mdot
.42284 .59398 Mdot
.04247 .23578 Mdot
.4072 .60697 Mdot
.29654 .55594 Mdot
.56791 .0135 Mdot
.68685 .06176 Mdot
.60791 .07776 Mdot
.55529 .4994 Mdot
.35432 .5833 Mdot
.62079 .06699 Mdot
.88081 .16958 Mdot
.11612 .46929 Mdot
.28011 .51349 Mdot
.57239 .55635 Mdot
.7614 .11951 Mdot
.12973 .25361 Mdot
.66303 .10739 Mdot
.13504 .25524 Mdot
.19059 .47474 Mdot
.51833 .03873 Mdot
.1885 .49769 Mdot
.29455 .51989 Mdot
.08275 .21522 Mdot
.48024 .04327 Mdot
.22161 .2763 Mdot
.00383 .19062 Mdot
.65026 .10503 Mdot
.39478 .55883 Mdot
.07806 .45264 Mdot
.51323 .50059 Mdot
.05375 .23927 Mdot
.34523 .56255 Mdot
.59965 .05237 Mdot
.04948 .44338 Mdot
.40763 .58475 Mdot
.35182 .57546 Mdot
.25005 .52309 Mdot
.56302 .07228 Mdot
.67044 .11101 Mdot
.44726 .58096 Mdot
.53523 .02416 Mdot
.89571 .17595 Mdot
.75367 .09608 Mdot
.8711 .38996 Mdot
.35989 .54397 Mdot
.34014 .53639 Mdot
.4665 .08707 Mdot
.35595 .56632 Mdot
.21877 .50871 Mdot
.69368 .11736 Mdot
.7804 .09065 Mdot
.69029 .0619 Mdot
.64396 .48342 Mdot
.6886 .0796 Mdot
.35722 .584 Mdot
.47032 .03921 Mdot
.79446 .09529 Mdot
.56233 .07234 Mdot
.12952 .26205 Mdot
.45206 .61468 Mdot
.35058 .24554 Mdot
.68435 .04912 Mdot
.94996 .19735 Mdot
.8152 .10498 Mdot
.70789 .06804 Mdot
.85004 .15659 Mdot
.86082 .38631 Mdot
.35314 .54169 Mdot
.13053 .47531 Mdot
.89414 .39295 Mdot
.71715 .06335 Mdot
.49938 .60205 Mdot
.64107 .48589 Mdot
.33635 .53674 Mdot
.3784 .58472 Mdot
.22151 .27635 Mdot
.35915 .58489 Mdot
.62782 .03646 Mdot
.36128 .57887 Mdot
.79168 .10033 Mdot
.11119 .25786 Mdot
.76417 .08887 Mdot
.54494 .03573 Mdot
.84633 .38072 Mdot
.30473 .52397 Mdot
.62577 .05837 Mdot
.41755 .11974 Mdot
.39578 .15431 Mdot
.47706 .59788 Mdot
.22968 .51366 Mdot
.14245 .26801 Mdot
.65459 .07434 Mdot
.78992 .37653 Mdot
.40257 .04138 Mdot
.63038 .0894 Mdot
.33025 .18858 Mdot
.40395 .59563 Mdot
.60135 .05881 Mdot
.59362 .029 Mdot
.14951 .27181 Mdot
.81013 .37765 Mdot
.65325 .07522 Mdot
.89961 .38178 Mdot
.0513 .41958 Mdot
.75618 .35136 Mdot
.90095 .39535 Mdot
.17704 .49325 Mdot
.61182 .58665 Mdot
.56613 .0281 Mdot
.94585 .40613 Mdot
.77956 .09206 Mdot
.65651 .10696 Mdot
.75528 .08111 Mdot
.12713 .26437 Mdot
.81436 .13658 Mdot
.32686 .21302 Mdot
.26873 .54704 Mdot
.39789 .03877 Mdot
.02598 .43324 Mdot
.05523 .20743 Mdot
.1777 .27753 Mdot
.77679 .0946 Mdot
.61812 .60103 Mdot
.9137 .18553 Mdot
.01989 .1958 Mdot
.37757 .55198 Mdot
.34931 .54121 Mdot
.3385 .55575 Mdot
.65932 .10159 Mdot
.04166 .43061 Mdot
.63962 .09962 Mdot
.36227 .52254 Mdot
.8657 .38397 Mdot
.65394 .03518 Mdot
.4688 .61357 Mdot
.39513 .60125 Mdot
.12828 .26271 Mdot
.76775 .08578 Mdot
.03644 .22921 Mdot
.68492 .11413 Mdot
.124 .44853 Mdot
.00383 .19105 Mdot
.25608 .53917 Mdot
.94734 .40895 Mdot
.60056 .05152 Mdot
.58115 .04359 Mdot
.79124 .37744 Mdot
.346 .14515 Mdot
.55813 .49908 Mdot
.53552 .00441 Mdot
.07543 .45344 Mdot
.81253 .14086 Mdot
.63836 .0739 Mdot
.18878 .28295 Mdot
.86323 .38372 Mdot
.98312 .21045 Mdot
.60896 .60094 Mdot
.31368 .52723 Mdot
.60711 .58187 Mdot
.05271 .44384 Mdot
.48551 .59778 Mdot
.94535 .1954 Mdot
.72193 .07314 Mdot
.28974 .51627 Mdot
.27766 .53334 Mdot
.20959 .2883 Mdot
.56135 .0354 Mdot
.95338 .41056 Mdot
.34752 .51731 Mdot
.46562 .60924 Mdot
.36967 .54999 Mdot
.16404 .23359 Mdot
.4355 .14694 Mdot
.4843 .12052 Mdot
.14496 .47984 Mdot
.41738 .56831 Mdot
.76205 .09045 Mdot
.04627 .2338 Mdot
.514 .57454 Mdot
.26174 .28261 Mdot
.89467 .3918 Mdot
.70234 .05573 Mdot
.38553 .57508 Mdot
.73985 .08165 Mdot
.78222 .12366 Mdot
.76167 .11557 Mdot
.61754 .58868 Mdot
.18911 .28221 Mdot
.54135 .58439 Mdot
.84471 .3832 Mdot
.93541 .40404 Mdot
.77897 .1059 Mdot
.8247 .38039 Mdot
.8808 .38778 Mdot
.46862 .59379 Mdot
.96106 .41135 Mdot
.77895 .08913 Mdot
.28651 .51482 Mdot
.35344 .23516 Mdot
.19465 .28492 Mdot
.26134 .52419 Mdot
.15858 .27257 Mdot
.86458 .38471 Mdot
.26892 .54476 Mdot
.82643 .37674 Mdot
.55859 .0569 Mdot
.20656 .27325 Mdot
.5588 .03428 Mdot
.91069 .17551 Mdot
.45409 .60704 Mdot
.00021 .42824 Mdot
.61922 .04024 Mdot
.41433 .5713 Mdot
.30089 .55988 Mdot
.42317 .54285 Mdot
.8151 .37815 Mdot
.64661 .03244 Mdot
.55242 .61011 Mdot
.03277 .42735 Mdot
.10873 .25563 Mdot
.34012 .5131 Mdot
.29276 .28184 Mdot
.25064 .26707 Mdot
.04227 .43873 Mdot
.49529 .0274 Mdot
.41969 .55128 Mdot
.19412 .47844 Mdot
.55913 .04143 Mdot
.23188 .51136 Mdot
.69189 .06293 Mdot
.39583 .58313 Mdot
.54397 .01864 Mdot
.57909 .56131 Mdot
.65485 .10031 Mdot
.92228 .40172 Mdot
.96451 .202 Mdot
.47066 .01701 Mdot
.51416 .57503 Mdot
.39356 .53153 Mdot
.41539 .58812 Mdot
.71007 .06826 Mdot
.86664 .16743 Mdot
.99044 .21607 Mdot
.14451 .45705 Mdot
.17809 .46921 Mdot
.32717 .55364 Mdot
.69059 .11735 Mdot
.1051 .22149 Mdot
.81478 .37944 Mdot
.02524 .43613 Mdot
.95628 .19915 Mdot
.47034 .59481 Mdot
.79537 .35585 Mdot
.57622 .59346 Mdot
.98179 .2112 Mdot
.24639 .5116 Mdot
.26009 .29886 Mdot
.68279 .08632 Mdot
.32289 .53197 Mdot
.1938 .28212 Mdot
.16478 .46549 Mdot
.38933 .58034 Mdot
.37158 .58279 Mdot
.71187 .10413 Mdot
.32043 .53151 Mdot
.19059 .47434 Mdot
.34778 .51777 Mdot
.84165 .37938 Mdot
.98641 .42358 Mdot
.62046 .59716 Mdot
.01852 .43105 Mdot
.98186 .42073 Mdot
.08466 .24827 Mdot
.81908 .10746 Mdot
.50638 .5889 Mdot
.42814 .61603 Mdot
.32797 .53311 Mdot
.7597 .08141 Mdot
.09368 .25047 Mdot
.65877 .04923 Mdot
.29631 .54137 Mdot
.4272 .59704 Mdot
.36097 .20273 Mdot
.36425 .54882 Mdot
.51388 .59251 Mdot
.22754 .27754 Mdot
.60487 .02864 Mdot
.42916 .1194 Mdot
.1449 .23022 Mdot
.5572 .58852 Mdot
.42136 .05519 Mdot
.72889 .08592 Mdot
.24752 .52049 Mdot
.40448 .02248 Mdot
.94394 .19702 Mdot
.7662 .08538 Mdot
.28817 .55419 Mdot
.66593 .45199 Mdot
.29998 .55896 Mdot
.95204 .41002 Mdot
.65579 .10627 Mdot
.48808 .11809 Mdot
.80494 .10517 Mdot
.45515 .5672 Mdot
.3812 .58713 Mdot
.81912 .12239 Mdot
.29857 .54164 Mdot
.23488 .51308 Mdot
.39647 .56002 Mdot
.43429 .02778 Mdot
.31796 .54986 Mdot
.50436 .01108 Mdot
.76263 .08861 Mdot
.78465 .0949 Mdot
.56001 .00973 Mdot
.92958 .40423 Mdot
.23799 .51743 Mdot
.82 .14466 Mdot
.43323 .57569 Mdot
.30536 .54179 Mdot
.81054 .37763 Mdot
.79335 .12284 Mdot
.71985 .06485 Mdot
.29167 .55728 Mdot
.79836 .10298 Mdot
.61886 .09301 Mdot
.8704 .38593 Mdot
.36881 .59073 Mdot
.40537 .54322 Mdot
.92404 .18076 Mdot
.66547 .05967 Mdot
.831 .3786 Mdot
.43439 .54706 Mdot
.15558 .27116 Mdot
.24127 .5155 Mdot
.14082 .25625 Mdot
.15921 .48312 Mdot
.66181 .10659 Mdot
.87171 .38698 Mdot
.37812 .5534 Mdot
.45063 .60614 Mdot
.52358 .57831 Mdot
.05951 .24135 Mdot
.36789 .52327 Mdot
.68255 .11291 Mdot
.35261 .5643 Mdot
.47759 .09571 Mdot
.01268 .22366 Mdot
.04654 .2346 Mdot
.47076 .59521 Mdot
.74837 .11001 Mdot
.27483 .51117 Mdot
.32382 .53254 Mdot
.20602 .50137 Mdot
.00623 .22236 Mdot
.31186 .56619 Mdot
.72997 .08629 Mdot
.79829 .37612 Mdot
.59292 .07225 Mdot
.43762 .06576 Mdot
.9089 .1747 Mdot
.64622 .0322 Mdot
.78786 .0994 Mdot
.43589 .58045 Mdot
.80712 .13369 Mdot
.47082 .57337 Mdot
.469 .00427 Mdot
.12743 .26372 Mdot
.38834 .02704 Mdot
.06552 .24277 Mdot
.02587 .43514 Mdot
.71812 .35395 Mdot
.252 .28138 Mdot
.42835 .55373 Mdot
.17441 .26621 Mdot
.30332 .52218 Mdot
.87902 .38988 Mdot
.60901 .0563 Mdot
.58943 .08189 Mdot
.76516 .08397 Mdot
.72203 .07483 Mdot
.59927 .0749 Mdot
.74992 .07888 Mdot
.53293 .60058 Mdot
.93542 .17891 Mdot
.48724 .15054 Mdot
.45142 .61441 Mdot
.893 .39119 Mdot
.2349 .51387 Mdot
.26011 .50554 Mdot
.36887 .52296 Mdot
.01448 .2145 Mdot
.441 .5597 Mdot
.3614 .13189 Mdot
.06128 .4456 Mdot
.37473 .52818 Mdot
.43586 .06567 Mdot
.39965 .53434 Mdot
.30575 .28128 Mdot
.51955 .59527 Mdot
.39576 .5335 Mdot
.20025 .48091 Mdot
.9028 .3948 Mdot
.76818 .08625 Mdot
.50041 .00905 Mdot
.18249 .26809 Mdot
.67217 .0829 Mdot
.61297 .06296 Mdot
.67526 .11449 Mdot
.45652 .03491 Mdot
.59794 .59846 Mdot
.62557 .60154 Mdot
.57259 .01417 Mdot
.51161 .60872 Mdot
.69352 .11881 Mdot
.1827 .49531 Mdot
.17579 .49029 Mdot
.36768 .56766 Mdot
.20251 .27242 Mdot
.7223 .06536 Mdot
.78227 .12839 Mdot
.90751 .18076 Mdot
.40377 .54266 Mdot
.31108 .56555 Mdot
.39656 .57954 Mdot
.26943 .54391 Mdot
.21743 .28894 Mdot
.24103 .51573 Mdot
.92946 .18288 Mdot
.82783 .38118 Mdot
.95714 .41345 Mdot
.41526 .59123 Mdot
.76634 .08484 Mdot
.08858 .45532 Mdot
.39384 .56013 Mdot
.53372 .58085 Mdot
.74143 .09072 Mdot
.86305 .15682 Mdot
.36827 .59017 Mdot
.82437 .37718 Mdot
.85842 .16017 Mdot
.13695 .22887 Mdot
.08825 .45924 Mdot
.55982 .54811 Mdot
.00304 .21687 Mdot
.49138 .58325 Mdot
.64165 .06885 Mdot
.36867 .17697 Mdot
.1155 .26084 Mdot
.6057 .60168 Mdot
.92075 .16097 Mdot
.36561 .52311 Mdot
.47449 .04125 Mdot
.78033 .09134 Mdot
.28957 .55181 Mdot
.35792 .21785 Mdot
.9413 .18718 Mdot
.22732 .2922 Mdot
.31715 .24166 Mdot
.39154 .03399 Mdot
.98312 .21156 Mdot
.6367 .02892 Mdot
.12054 .47014 Mdot
.2942 .51817 Mdot
.31611 .56338 Mdot
.14129 .47987 Mdot
.90431 .39527 Mdot
.79747 .37627 Mdot
.2807 .28262 Mdot
.32602 .21625 Mdot
.21595 .50755 Mdot
.85891 .38574 Mdot
.35244 .23975 Mdot
.64633 .09695 Mdot
.08603 .43347 Mdot
.34188 .57832 Mdot
.47749 .00024 Mdot
.05322 .23882 Mdot
.0569 .22941 Mdot
.9813 .21213 Mdot
.44703 .14708 Mdot
.16597 .25454 Mdot
.61087 .02943 Mdot
.45382 .07714 Mdot
.41803 .53977 Mdot
.02263 .43411 Mdot
.59513 .49868 Mdot
.59004 .02118 Mdot
.41053 .60797 Mdot
.7881 .13093 Mdot
.67286 .41007 Mdot
.97016 .17862 Mdot
.39943 .12099 Mdot
.31828 .55086 Mdot
.19995 .48038 Mdot
.44096 .0037 Mdot
.00817 .22089 Mdot
.34639 .5717 Mdot
.60375 .08666 Mdot
.31738 .56544 Mdot
.15492 .46126 Mdot
.9933 .21424 Mdot
.87809 .17163 Mdot
.15612 .48291 Mdot
.71263 .35563 Mdot
.40148 .58164 Mdot
.57232 .01487 Mdot
.19501 .28519 Mdot
.34099 .15186 Mdot
.6951 .08774 Mdot
.9207 .40191 Mdot
.77944 .13281 Mdot
.74929 .11937 Mdot
.19514 .50021 Mdot
.4742 .14888 Mdot
.32198 .53072 Mdot
.00929 .22143 Mdot
.83665 .12926 Mdot
.13832 .26734 Mdot
.26069 .5422 Mdot
.09021 .43453 Mdot
.54014 .02656 Mdot
.67271 .11313 Mdot
.44495 .55015 Mdot
.67975 .08535 Mdot
.18191 .27829 Mdot
.5495 .02995 Mdot
.64331 .09493 Mdot
.6795 .08095 Mdot
.53143 .49854 Mdot
.75989 .08545 Mdot
.69336 .09209 Mdot
.96394 .17727 Mdot
.40977 .56619 Mdot
.97311 .20663 Mdot
.83342 .15037 Mdot
.25857 .50408 Mdot
.48505 .59646 Mdot
.45107 .00807 Mdot
.18937 .49594 Mdot
.38018 .12423 Mdot
.88376 .37707 Mdot
.62286 .5938 Mdot
.34078 .57079 Mdot
.75659 .07889 Mdot
.66053 .08368 Mdot
.41704 .02439 Mdot
.51041 .01343 Mdot
.77007 .09005 Mdot
.67065 .11123 Mdot
.94607 .40728 Mdot
.27551 .53315 Mdot
.54101 .49878 Mdot
.34231 .57145 Mdot
.63861 .0414 Mdot
.77829 .37767 Mdot
.23032 .49194 Mdot
.66736 .10861 Mdot
.03373 .43767 Mdot
.89408 .39282 Mdot
.49745 .02905 Mdot
.35885 .5231 Mdot
.40368 .58586 Mdot
.11744 .25859 Mdot
.3576 .51957 Mdot
.38471 .53059 Mdot
.47275 .57348 Mdot
.38287 .52993 Mdot
.56835 .01815 Mdot
.02236 .22404 Mdot
.66075 .46552 Mdot
.735 .10912 Mdot
.39238 .58185 Mdot
.43998 .54814 Mdot
.32814 .53184 Mdot
.21066 .50617 Mdot
.61816 .06013 Mdot
.1887 .28182 Mdot
.84726 .15944 Mdot
.31337 .56475 Mdot
.78836 .13108 Mdot
.05414 .22885 Mdot
.34239 .57781 Mdot
.30041 .52033 Mdot
.10014 .25448 Mdot
.79479 .13453 Mdot
.22257 .2902 Mdot
.35171 .54398 Mdot
.07979 .4545 Mdot
.62338 .06807 Mdot
.30572 .52358 Mdot
.16335 .23438 Mdot
.31829 .56398 Mdot
.09397 .43626 Mdot
.80429 .37574 Mdot
.41583 .56838 Mdot
.47759 .09411 Mdot
.56223 .59008 Mdot
.36898 .56864 Mdot
.49228 .10641 Mdot
.08826 .21681 Mdot
.67333 .08338 Mdot
.7455 .10826 Mdot
.00444 .21899 Mdot
.13935 .26755 Mdot
.38316 .02005 Mdot
.03118 .23072 Mdot
.49483 .04767 Mdot
.66695 .44817 Mdot
.41732 .54821 Mdot
.10615 .25768 Mdot
.35319 .23942 Mdot
.2999 .55531 Mdot
.74877 .08483 Mdot
.46489 .11987 Mdot
.44256 .12003 Mdot
.98206 .41784 Mdot
.92608 .40205 Mdot
.44724 .58048 Mdot
.34453 .51584 Mdot
.31384 .54508 Mdot
.40484 .56281 Mdot
.44168 .00371 Mdot
.36692 .5212 Mdot
.88316 .39132 Mdot
.47796 .57686 Mdot
.52558 .57824 Mdot
.29248 .28251 Mdot
.46179 .00132 Mdot
.40277 .56613 Mdot
.55258 .60929 Mdot
.0429 .2342 Mdot
.51154 .60724 Mdot
.51157 .51166 Mdot
.89746 .39519 Mdot
.17022 .23554 Mdot
.77864 .37834 Mdot
.07666 .4538 Mdot
.92783 .18781 Mdot
.65718 .0719 Mdot
.47473 .56136 Mdot
.32409 .55298 Mdot
.18212 .23656 Mdot
.83695 .12888 Mdot
.36656 .56763 Mdot
.2598 .54074 Mdot
.27047 .52731 Mdot
.55668 .0558 Mdot
.32765 .55086 Mdot
.96511 .41472 Mdot
.48486 .12058 Mdot
.21717 .27531 Mdot
.00041 .18979 Mdot
.29321 .51642 Mdot
.82745 .1116 Mdot
.4894 .56643 Mdot
.48278 .59514 Mdot
.14589 .26876 Mdot
.20394 .26231 Mdot
.43491 .57965 Mdot
.83885 .15708 Mdot
.55612 .02387 Mdot
.25639 .50459 Mdot
.75325 .08444 Mdot
.69167 .05121 Mdot
.16959 .23474 Mdot
.82235 .1112 Mdot
.15386 .48422 Mdot
.32024 .54847 Mdot
.43168 .55523 Mdot
.28194 .26449 Mdot
.21426 .48552 Mdot
.2658 .52532 Mdot
.94769 .40766 Mdot
.20529 .50437 Mdot
.30914 .55796 Mdot
.01233 .22088 Mdot
.48712 .02482 Mdot
.15103 .2706 Mdot
.11523 .46667 Mdot
.13201 .47235 Mdot
.63455 .09157 Mdot
.49294 .11196 Mdot
.28874 .55316 Mdot
.00269 .22091 Mdot
.25335 .53937 Mdot
.74335 .11303 Mdot
.45494 .58491 Mdot
.59671 .02482 Mdot
.28823 .55351 Mdot
.3739 .126 Mdot
.109 .46586 Mdot
.09062 .25144 Mdot
.80643 .10282 Mdot
.12273 .44807 Mdot
.45247 .61449 Mdot
.1368 .2658 Mdot
.18694 .2375 Mdot
.91566 .39999 Mdot
.89828 .392 Mdot
.11091 .46634 Mdot
.59646 .05684 Mdot
.40497 .53622 Mdot
.95833 .20245 Mdot
.3056 .55676 Mdot
.60247 .05882 Mdot
.4878 .56505 Mdot
.80948 .37653 Mdot
.05509 .44594 Mdot
.82946 .38102 Mdot
.8325 .3807 Mdot
.35752 .21576 Mdot
.7163 .0717 Mdot
.92578 .38991 Mdot
.2621 .28176 Mdot
.90524 .18237 Mdot
.19912 .26142 Mdot
.78752 .09883 Mdot
.12626 .22633 Mdot
.69574 .06421 Mdot
.36291 .52211 Mdot
.78478 .09546 Mdot
.48416 .56399 Mdot
.43187 .54556 Mdot
.43443 .55629 Mdot
.00615 .42888 Mdot
.13143 .45175 Mdot
.2941 .51968 Mdot
.18439 .49354 Mdot
.06876 .23332 Mdot
.14325 .47918 Mdot
.48123 .002 Mdot
.31844 .23861 Mdot
.13051 .26339 Mdot
.7709 .08548 Mdot
.34139 .57679 Mdot
.4339 .14736 Mdot
.73447 .1139 Mdot
.11173 .46499 Mdot
.3214 .2321 Mdot
.69733 .06549 Mdot
.34804 .58102 Mdot
.69317 .05367 Mdot
.12657 .26242 Mdot
.33012 .27233 Mdot
.61991 .035 Mdot
.96822 .20532 Mdot
.32189 .55134 Mdot
.72415 .10503 Mdot
.25909 .50469 Mdot
.09896 .45902 Mdot
.56599 .04362 Mdot
.25555 .52112 Mdot
.80355 .10064 Mdot
.79946 .14047 Mdot
.46448 .03728 Mdot
.60221 .05281 Mdot
.54326 .06467 Mdot
.04141 .43796 Mdot
.96711 .41615 Mdot
.17842 .4701 Mdot
.26181 .52457 Mdot
.46013 .55631 Mdot
.7238 .07513 Mdot
.78145 .0926 Mdot
.40167 .15172 Mdot
.35056 .56322 Mdot
.50644 .01939 Mdot
.0957 .45822 Mdot
.88391 .14702 Mdot
.8039 .3779 Mdot
.54955 .54032 Mdot
.20966 .50327 Mdot
.60379 .57998 Mdot
.67301 .08227 Mdot
.40507 .53552 Mdot
.42392 .11982 Mdot
.59838 .57475 Mdot
.28687 .53768 Mdot
.57157 .03584 Mdot
.26302 .28283 Mdot
.01783 .43279 Mdot
.24942 .28112 Mdot
.10844 .25801 Mdot
.90391 .15519 Mdot
.54241 .00244 Mdot
.40768 .12017 Mdot
.37618 .5755 Mdot
.51826 .61089 Mdot
.44629 .61266 Mdot
.51898 .59534 Mdot
.24931 .52181 Mdot
.4308 .02701 Mdot
.83459 .38151 Mdot
.73409 .11356 Mdot
.40818 .5792 Mdot
.62058 .08442 Mdot
.13824 .455 Mdot
.09017 .21723 Mdot
.75819 .08393 Mdot
.23354 .51215 Mdot
.96446 .41476 Mdot
.54383 .03445 Mdot
.78502 .09783 Mdot
.68276 .06685 Mdot
.78918 .0951 Mdot
.79638 .1396 Mdot
.28718 .28329 Mdot
.2206 .50671 Mdot
.21823 .50905 Mdot
.82108 .37688 Mdot
.53037 .06049 Mdot
.35006 .54201 Mdot
.41994 .6132 Mdot
.49371 .11155 Mdot
.6703 .11145 Mdot
.48386 .57957 Mdot
.32908 .20011 Mdot
.97196 .41642 Mdot
.3691 .58252 Mdot
.46595 .61328 Mdot
.02492 .228 Mdot
.25298 .28185 Mdot
.55688 .54613 Mdot
.21672 .50947 Mdot
.63158 .06554 Mdot
.35272 .58239 Mdot
.40325 .04132 Mdot
.27268 .50911 Mdot
.79327 .10147 Mdot
.42473 .02654 Mdot
.26014 .52574 Mdot
.69348 .09718 Mdot
.26843 .28225 Mdot
.60835 .055 Mdot
.61161 .06244 Mdot
.9351 .40438 Mdot
.29219 .28281 Mdot
.39442 .60116 Mdot
.64491 .09649 Mdot
.54963 .60886 Mdot
.48792 .04489 Mdot
.95133 .17219 Mdot
.97653 .41989 Mdot
.50805 .01989 Mdot
.95496 .40925 Mdot
.83912 .14689 Mdot
.73711 .07909 Mdot
.90156 .15395 Mdot
.52958 .52694 Mdot
.13672 .26655 Mdot
.36785 .5715 Mdot
.60308 .014 Mdot
.67414 .05518 Mdot
.2256 .48857 Mdot
.44907 .56429 Mdot
.55959 .03455 Mdot
.29947 .55834 Mdot
.40474 .58343 Mdot
.7111 .06956 Mdot
.06109 .44821 Mdot
.30766 .28099 Mdot
.41198 .57042 Mdot
.29647 .51871 Mdot
.48872 .00066 Mdot
.90488 .39808 Mdot
.15244 .27023 Mdot
.39718 .03864 Mdot
.92227 .40326 Mdot
.41487 .5712 Mdot
.50595 .61009 Mdot
.34007 .26429 Mdot
.30658 .25354 Mdot
.77756 .37721 Mdot
.79484 .09749 Mdot
.02385 .43228 Mdot
.45501 .03511 Mdot
.10218 .46025 Mdot
.03451 .23093 Mdot
.40292 .02066 Mdot
.60688 .05536 Mdot
.60459 .01521 Mdot
.07874 .45385 Mdot
.46424 .1199 Mdot
.58281 .59517 Mdot
.23295 .29209 Mdot
.60981 .0167 Mdot
.11258 .25871 Mdot
.5619 .03137 Mdot
.28671 .5489 Mdot
.76675 .08991 Mdot
.4744 .57467 Mdot
.67916 .38539 Mdot
.10342 .46176 Mdot
.99165 .21306 Mdot
.67827 .3885 Mdot
.68976 .05148 Mdot
.01205 .42945 Mdot
.61044 .03122 Mdot
.16983 .46776 Mdot
.45332 .58758 Mdot
.38907 .03117 Mdot
.28493 .28348 Mdot
.42651 .54339 Mdot
.39464 .60138 Mdot
.62504 .06871 Mdot
.84498 .15538 Mdot
.13301 .45321 Mdot
.95772 .20387 Mdot
.12905 .24481 Mdot
.05877 .24149 Mdot
.43909 .57709 Mdot
.47391 .04054 Mdot
.43561 .59662 Mdot
.89016 .17706 Mdot
.63828 .0922 Mdot
.64181 .03004 Mdot
.34118 .26046 Mdot
.47368 .04085 Mdot
.02825 .43491 Mdot
.56881 .03929 Mdot
.51186 .50165 Mdot
.53553 .60251 Mdot
.33391 .53694 Mdot
.15734 .26151 Mdot
.43056 .54462 Mdot
.5731 .00068 Mdot
.05202 .22794 Mdot
.59943 .02608 Mdot
.9114 .40051 Mdot
.30989 .54434 Mdot
.17034 .46752 Mdot
.3626 .19743 Mdot
.44395 .60014 Mdot
.18871 .28165 Mdot
.80963 .13976 Mdot
.09143 .45865 Mdot
.35754 .5199 Mdot
.57623 .07678 Mdot
.68743 .11768 Mdot
.45455 .03469 Mdot
.29563 .55433 Mdot
.92046 .18488 Mdot
.44939 .5515 Mdot
.05388 .4451 Mdot
.44006 .60978 Mdot
.61478 .60331 Mdot
.77163 .1192 Mdot
.69764 .36213 Mdot
.58271 .05044 Mdot
.36037 .20106 Mdot
.4691 .57261 Mdot
.27507 .54932 Mdot
.31238 .54522 Mdot
.26178 .52361 Mdot
.68465 .11671 Mdot
.39621 .53326 Mdot
.11681 .47007 Mdot
.4652 .58935 Mdot
.31338 .54509 Mdot
.16551 .27574 Mdot
.72739 .06774 Mdot
.90861 .17997 Mdot
.41913 .14814 Mdot
.36384 .54875 Mdot
.32045 .23588 Mdot
.91821 .16038 Mdot
.99665 .42598 Mdot
.87305 .3888 Mdot
.78397 .37511 Mdot
.92558 .40137 Mdot
.24801 .49883 Mdot
.18159 .25806 Mdot
.19376 .50069 Mdot
.2866 .54893 Mdot
.99864 .42752 Mdot
.08989 .25164 Mdot
.36202 .57795 Mdot
.29716 .55873 Mdot
.19242 .49618 Mdot
.31021 .55765 Mdot
.00122 .425 Mdot
.95513 .41123 Mdot
.0159 .22431 Mdot
.05376 .23956 Mdot
.22904 .51459 Mdot
.2129 .50397 Mdot
.81309 .37944 Mdot
.64131 .04174 Mdot
.58628 .08131 Mdot
.03909 .43945 Mdot
.42576 .05878 Mdot
.56443 .01181 Mdot
.04045 .23123 Mdot
.68753 .05994 Mdot
.02467 .43225 Mdot
.47218 .61552 Mdot
.42842 .57705 Mdot
.94519 .18891 Mdot
.20596 .48293 Mdot
.21782 .29037 Mdot
.0435 .44279 Mdot
.87846 .16908 Mdot
.6594 .03915 Mdot
.03553 .22989 Mdot
.74504 .11338 Mdot
.55125 .49877 Mdot
.73916 .10618 Mdot
.43813 .60049 Mdot
.31347 .54849 Mdot
.05841 .23038 Mdot
.5067 .01914 Mdot
.69506 .06277 Mdot
.99456 .21555 Mdot
.23233 .29192 Mdot
.36478 .52579 Mdot
.94538 .40715 Mdot
.79697 .1345 Mdot
.33601 .16242 Mdot
.63029 .06055 Mdot
.13593 .47719 Mdot
.39004 .56083 Mdot
.21997 .50657 Mdot
.22262 .29164 Mdot
.0838 .24856 Mdot
.04388 .4404 Mdot
.22502 .48904 Mdot
.64853 .10401 Mdot
.45611 .07856 Mdot
.22061 .50784 Mdot
.01302 .42867 Mdot
.86674 .38908 Mdot
.85283 .13535 Mdot
.45338 .60391 Mdot
.72617 .07629 Mdot
.50573 .05208 Mdot
.45193 .07637 Mdot
.65915 .10691 Mdot
.3205 .52766 Mdot
.52492 .61351 Mdot
.8266 .37762 Mdot
.40158 .02139 Mdot
.55848 .00937 Mdot
.54215 .04854 Mdot
.54498 .00831 Mdot
.90214 .1773 Mdot
.17007 .26462 Mdot
.43919 .03036 Mdot
.61822 .0833 Mdot
.9796 .41844 Mdot
.67502 .05547 Mdot
.50853 .0194 Mdot
.36838 .54758 Mdot
.3651 .52105 Mdot
.45542 .58433 Mdot
.50264 .00634 Mdot
.41164 .54571 Mdot
.47652 .12085 Mdot
.20769 .48147 Mdot
.41928 .14816 Mdot
.12452 .47146 Mdot
.28236 .51233 Mdot
.38599 .59776 Mdot
.59129 .08227 Mdot
.78711 .09641 Mdot
.4664 .55866 Mdot
.16571 .23448 Mdot
.77867 .09334 Mdot
.9225 .40313 Mdot
.47753 .61373 Mdot
.20128 .50136 Mdot
.9674 .19701 Mdot
.80148 .37645 Mdot
.55612 .03332 Mdot
.29363 .55383 Mdot
.35067 .54029 Mdot
.66042 .04946 Mdot
.69167 .07051 Mdot
.17611 .46848 Mdot
.6089 .05141 Mdot
.55337 .05316 Mdot
.80846 .37794 Mdot
.17711 .49182 Mdot
.72756 .08471 Mdot
.10474 .464 Mdot
.3308 .53198 Mdot
.36604 .54674 Mdot
.66508 .05315 Mdot
.46768 .14851 Mdot
.30655 .28089 Mdot
.1443 .47808 Mdot
.14218 .22998 Mdot
.31422 .56354 Mdot
.74324 .07324 Mdot
.59047 .05346 Mdot
.2664 .50737 Mdot
.84263 .37967 Mdot
.99781 .42616 Mdot
.98696 .21355 Mdot
.00425 .42827 Mdot
.97022 .20589 Mdot
.31156 .54427 Mdot
.07373 .21246 Mdot
.92653 .40117 Mdot
.77462 .13009 Mdot
.03961 .44063 Mdot
.81648 .37708 Mdot
.66714 .08532 Mdot
.45737 .14763 Mdot
.18396 .49246 Mdot
.68075 .38274 Mdot
.77416 .10428 Mdot
.74447 .11829 Mdot
.78833 .09714 Mdot
.47078 .0171 Mdot
.7115 .06872 Mdot
.10083 .46398 Mdot
.42662 .60454 Mdot
.11648 .47039 Mdot
.92812 .4029 Mdot
.94264 .40943 Mdot
.36463 .1889 Mdot
.69909 .09888 Mdot
.5446 .02436 Mdot
.49138 .59938 Mdot
.87396 .17042 Mdot
.17773 .49201 Mdot
.47281 .57467 Mdot
.2219 .50784 Mdot
.10087 .46122 Mdot
.09724 .2428 Mdot
.85541 .38267 Mdot
.27212 .50921 Mdot
.90782 .15593 Mdot
.44186 .11979 Mdot
.7961 .0999 Mdot
.34201 .15091 Mdot
.50143 .03103 Mdot
.89096 .17268 Mdot
.03071 .42659 Mdot
.94943 .19728 Mdot
.06626 .22558 Mdot
.07446 .45316 Mdot
.21721 .29052 Mdot
.52298 .02546 Mdot
.29317 .55648 Mdot
.62367 .59747 Mdot
.70003 .12265 Mdot
.37075 .17446 Mdot
.97346 .41662 Mdot
.31384 .56363 Mdot
.15152 .27184 Mdot
.82777 .14725 Mdot
.26994 .50773 Mdot
.97669 .42014 Mdot
.16419 .27496 Mdot
.07275 .42858 Mdot
.78166 .10725 Mdot
.88195 .38814 Mdot
.83866 .15249 Mdot
.317 .54623 Mdot
.92796 .18189 Mdot
.03678 .23314 Mdot
.6583 .03865 Mdot
.33566 .26683 Mdot
.41526 .54826 Mdot
.40266 .56311 Mdot
.33361 .55624 Mdot
.13008 .47162 Mdot
.20976 .28713 Mdot
.85059 .38295 Mdot
.9576 .41195 Mdot
.34948 .24751 Mdot
.22648 .27774 Mdot
.41348 .53851 Mdot
.16771 .27759 Mdot
.4567 .07937 Mdot
.77822 .09265 Mdot
.4575 .0359 Mdot
.75036 .1203 Mdot
.45881 .12008 Mdot
.32521 .53227 Mdot
.16894 .27441 Mdot
.0659 .42499 Mdot
.26394 .54465 Mdot
.36629 .52644 Mdot
.69845 .36199 Mdot
.90444 .3976 Mdot
.84548 .38415 Mdot
.56185 .035 Mdot
.35749 .57645 Mdot
.49211 .60379 Mdot
.50568 .57245 Mdot
.428 .14741 Mdot
.38966 .60018 Mdot
.20541 .50182 Mdot
.79239 .37842 Mdot
.67926 .11081 Mdot
.07165 .24447 Mdot
.28152 .54975 Mdot
.90123 .17815 Mdot
.15405 .48077 Mdot
.38118 .52997 Mdot
.22532 .51323 Mdot
.4445 .14684 Mdot
.0032 .42891 Mdot
.35188 .58194 Mdot
.28212 .51495 Mdot
.31042 .56053 Mdot
.43155 .59826 Mdot
.28368 .53627 Mdot
.42069 .58453 Mdot
.02901 .43338 Mdot
.61404 .60115 Mdot
.93196 .40469 Mdot
.60136 .08603 Mdot
.92143 .4008 Mdot
.26571 .54195 Mdot
.48914 .02506 Mdot
.20237 .28724 Mdot
.39227 .55921 Mdot
.37422 .57418 Mdot
.76994 .08827 Mdot
.27882 .54805 Mdot
.40456 .04224 Mdot
.12564 .45016 Mdot
.67546 .11005 Mdot
.22825 .51315 Mdot
.44252 .60214 Mdot
.33584 .53518 Mdot
.40542 .56346 Mdot
.17309 .27699 Mdot
.75805 .08759 Mdot
.06737 .45154 Mdot
.87014 .38785 Mdot
.49583 .113 Mdot
.7515 .12086 Mdot
.80025 .10268 Mdot
.83594 .12909 Mdot
.65552 .08168 Mdot
.18089 .48482 Mdot
.54344 .58419 Mdot
.78941 .35492 Mdot
.09803 .46157 Mdot
.34056 .53998 Mdot
.98825 .42003 Mdot
.5783 .49932 Mdot
.18689 .28102 Mdot
.07574 .24557 Mdot
.13716 .26845 Mdot
.27139 .54483 Mdot
.82485 .11171 Mdot
.54169 .00726 Mdot
.40831 .58832 Mdot
.02437 .43481 Mdot
.36362 .18848 Mdot
.12613 .26308 Mdot
.31704 .5296 Mdot
.50068 .05 Mdot
.4957 .01491 Mdot
.05725 .23822 Mdot
.31156 .5257 Mdot
.69207 .07077 Mdot
.42049 .57287 Mdot
.44841 .58229 Mdot
.5797 .01698 Mdot
.64153 .042 Mdot
.69156 .05262 Mdot
.96724 .20327 Mdot
.58805 .56654 Mdot
.40552 .04269 Mdot
.08112 .24737 Mdot
.13987 .26827 Mdot
.00309 .21704 Mdot
.47794 .0202 Mdot
.29793 .56005 Mdot
.32363 .56933 Mdot
.62737 .08635 Mdot
.7818 .09606 Mdot
.34467 .53937 Mdot
.24516 .29599 Mdot
.38735 .57603 Mdot
.32847 .20456 Mdot
.41535 .56769 Mdot
.0674 .24316 Mdot
.07228 .24617 Mdot
.39461 .53257 Mdot
.65253 .06965 Mdot
.79042 .12737 Mdot
.18561 .28105 Mdot
.97754 .21083 Mdot
.15056 .26848 Mdot
.21552 .48556 Mdot
.04853 .23625 Mdot
.91778 .39871 Mdot
.22044 .29113 Mdot
.12003 .44645 Mdot
.79821 .37499 Mdot
.20446 .50026 Mdot
.29098 .51792 Mdot
.72743 .07596 Mdot
.88258 .17457 Mdot
.66652 .10857 Mdot
.34998 .24563 Mdot
.42407 .61422 Mdot
.36994 .52649 Mdot
.42936 .61732 Mdot
.1391 .47752 Mdot
.63778 .02959 Mdot
.23807 .51748 Mdot
.39771 .0208 Mdot
.47793 .00686 Mdot
.12217 .44768 Mdot
.21116 .48306 Mdot
.25218 .53839 Mdot
.72001 .06467 Mdot
.61872 .03326 Mdot
.39972 .56253 Mdot
.4283 .60467 Mdot
.53721 .61761 Mdot
.58595 .01948 Mdot
.47327 .00553 Mdot
.92577 .40021 Mdot
.88461 .39034 Mdot
.93886 .19318 Mdot
.90511 .1825 Mdot
.54738 .00994 Mdot
.30198 .55895 Mdot
.10598 .24585 Mdot
.65325 .08069 Mdot
.53655 .58225 Mdot
.50766 .58922 Mdot
.7155 .09584 Mdot
.67129 .08756 Mdot
.03155 .19986 Mdot
.2262 .5104 Mdot
.55614 .07012 Mdot
.47179 .59207 Mdot
.37711 .52734 Mdot
.51704 .03831 Mdot
.37874 .5519 Mdot
.19176 .47739 Mdot
.8206 .12222 Mdot
.07227 .21208 Mdot
.64573 .04528 Mdot
.32361 .56488 Mdot
.34515 .25446 Mdot
.11013 .46575 Mdot
.35803 .5667 Mdot
.4861 .01016 Mdot
.63278 .48956 Mdot
.69367 .05202 Mdot
.51285 .50441 Mdot
.35506 .2297 Mdot
.78963 .09618 Mdot
.57083 .03526 Mdot
.79562 .09831 Mdot
.75636 .12332 Mdot
.5005 .57039 Mdot
.9434 .19691 Mdot
.16631 .27342 Mdot
.82114 .1073 Mdot
.82697 .11082 Mdot
.80188 .37896 Mdot
.40579 .58808 Mdot
.08153 .21501 Mdot
.10419 .25454 Mdot
.40313 .5627 Mdot
.08232 .25013 Mdot
.69008 .08993 Mdot
.44032 .57761 Mdot
.48872 .00037 Mdot
.00412 .21995 Mdot
.0823 .45336 Mdot
.67212 .08762 Mdot
.22895 .51039 Mdot
.5135 .01552 Mdot
.88758 .39111 Mdot
.80027 .10107 Mdot
.24309 .51713 Mdot
.37871 .57565 Mdot
.69813 .07272 Mdot
.67325 .10852 Mdot
.80483 .10476 Mdot
.79098 .13249 Mdot
.34299 .53738 Mdot
.81298 .11956 Mdot
.62094 .49429 Mdot
.26412 .50444 Mdot
.69373 .36508 Mdot
.25482 .50252 Mdot
.07448 .24495 Mdot
.58703 .06841 Mdot
.31545 .54866 Mdot
.8231 .37769 Mdot
.65327 .10029 Mdot
.60724 .58065 Mdot
.6903 .11597 Mdot
.78849 .09777 Mdot
.91569 .15946 Mdot
.01965 .43042 Mdot
.37264 .5729 Mdot
.29351 .28311 Mdot
.45768 .60515 Mdot
.32226 .22983 Mdot
.6298 .49129 Mdot
.24293 .29558 Mdot
.22362 .51192 Mdot
.64313 .0425 Mdot
.6602 .10821 Mdot
.37465 .5511 Mdot
.53008 .52725 Mdot
.12649 .45039 Mdot
.73415 .10835 Mdot
.69132 .05281 Mdot
.92282 .18953 Mdot
.34411 .25927 Mdot
.49081 .11891 Mdot
.72555 .0681 Mdot
.31366 .56648 Mdot
.82539 .11152 Mdot
.80186 .10205 Mdot
.99976 .42348 Mdot
.37255 .57387 Mdot
.57696 .04228 Mdot
.54986 .00547 Mdot
.61886 .49431 Mdot
.44651 .03167 Mdot
.37187 .59214 Mdot
.7099 .06969 Mdot
.20375 .47983 Mdot
.36448 .5794 Mdot
.12946 .4511 Mdot
.46734 .01531 Mdot
.55456 .58823 Mdot
.11976 .26159 Mdot
.68248 .11403 Mdot
.58463 .56589 Mdot
.97284 .1798 Mdot
.34237 .25901 Mdot
.55325 .49853 Mdot
.31645 .55042 Mdot
.71305 .35554 Mdot
.51987 .50047 Mdot
.50526 .60558 Mdot
.45272 .60775 Mdot
.22621 .27773 Mdot
.58297 .00478 Mdot
.4582 .12031 Mdot
.09303 .46032 Mdot
.35074 .51612 Mdot
.1738 .48899 Mdot
.8909 .39447 Mdot
.98172 .20224 Mdot
.87679 .17146 Mdot
.08003 .45455 Mdot
.01543 .22547 Mdot
.55654 .02915 Mdot
.27413 .53214 Mdot
.65152 .07886 Mdot
.64608 .033 Mdot
.10296 .46083 Mdot
.45067 .14752 Mdot
.80116 .1025 Mdot
.69935 .06625 Mdot
.25671 .50458 Mdot
.56322 .07229 Mdot
.33861 .15623 Mdot
.59879 .05204 Mdot
.72026 .10823 Mdot
.20432 .48166 Mdot
.00738 .4274 Mdot
.60676 .05517 Mdot
.96256 .41529 Mdot
.18761 .49789 Mdot
.44508 .60398 Mdot
.38704 .57967 Mdot
.48942 .01206 Mdot
.68523 .11755 Mdot
.35062 .54431 Mdot
.15074 .27215 Mdot
.06611 .2432 Mdot
.49083 .11798 Mdot
.23558 .51346 Mdot
.42652 .60407 Mdot
.56835 .034 Mdot
.89833 .1774 Mdot
.06514 .42474 Mdot
.35754 .54584 Mdot
.89895 .17635 Mdot
.3688 .57113 Mdot
.29925 .55516 Mdot
.5088 .6116 Mdot
.01447 .43278 Mdot
.23727 .5169 Mdot
.61556 .03823 Mdot
.24952 .50011 Mdot
.8073 .10585 Mdot
.39755 .53294 Mdot
.78046 .12313 Mdot
.39218 .57247 Mdot
.13656 .45311 Mdot
.59171 .04769 Mdot
.61364 .05742 Mdot
.00026 .22024 Mdot
.95842 .41262 Mdot
.82016 .14516 Mdot
.91219 .18284 Mdot
.50831 .01265 Mdot
.0263 .22825 Mdot
.57563 .59337 Mdot
.89501 .39426 Mdot
.17804 .47072 Mdot
.76029 .12408 Mdot
.41073 .60887 Mdot
.65552 .07069 Mdot
.45453 .58762 Mdot
.2517 .50264 Mdot
.72371 .06608 Mdot
.33231 .56844 Mdot
.23376 .29372 Mdot
.2841 .53609 Mdot
.80379 .1037 Mdot
.94275 .40834 Mdot
.23587 .51291 Mdot
.1269 .44992 Mdot
.60741 .49639 Mdot
.67335 .04384 Mdot
.67404 .11257 Mdot
.31667 .27703 Mdot
.96167 .40197 Mdot
.12529 .2609 Mdot
.80812 .14351 Mdot
.01968 .43489 Mdot
.36898 .58116 Mdot
.34936 .54112 Mdot
.87772 .16732 Mdot
.92804 .4013 Mdot
.67751 .04523 Mdot
.15249 .48272 Mdot
.10433 .25488 Mdot
.89487 .17825 Mdot
.55272 .06837 Mdot
.20467 .48213 Mdot
.70996 .09855 Mdot
.57233 .01428 Mdot
.39781 .56438 Mdot
.79828 .09997 Mdot
.63325 .0906 Mdot
.6802 .05711 Mdot
.23897 .26663 Mdot
.3547 .57559 Mdot
.11345 .46583 Mdot
.93808 .40721 Mdot
.44946 .55148 Mdot
.32144 .54911 Mdot
.65133 .07315 Mdot
.74635 .11904 Mdot
.72751 .1113 Mdot
.71716 .06416 Mdot
.60953 .05147 Mdot
.8281 .11264 Mdot
.63669 .09181 Mdot
.29224 .55497 Mdot
.42917 .59717 Mdot
.74911 .11971 Mdot
.5608 .58935 Mdot
.86068 .38537 Mdot
.60231 .05293 Mdot
.44219 .03086 Mdot
.45126 .5527 Mdot
.33058 .53494 Mdot
.69674 .06331 Mdot
.63243 .0452 Mdot
.08405 .45461 Mdot
.22231 .29027 Mdot
.75761 .09746 Mdot
.20994 .50272 Mdot
.13593 .47519 Mdot
.04828 .20497 Mdot
.44511 .59987 Mdot
.04439 .2328 Mdot
.08986 .45782 Mdot
.46042 .01316 Mdot
.34156 .57758 Mdot
.09423 .25353 Mdot
.33652 .57702 Mdot
.37811 .55336 Mdot
.22848 .29219 Mdot
.47654 .59769 Mdot
.08125 .23814 Mdot
.09718 .21962 Mdot
.90986 .39751 Mdot
.40524 .0438 Mdot
.61164 .03094 Mdot
.98913 .4235 Mdot
.17067 .48955 Mdot
.56338 .55019 Mdot
.76048 .08944 Mdot
.23052 .26612 Mdot
.18906 .28021 Mdot
.80174 .09984 Mdot
.74994 .11963 Mdot
.49521 .60147 Mdot
.01735 .43016 Mdot
.89429 .17841 Mdot
.28766 .53511 Mdot
.92713 .18195 Mdot
.09842 .21984 Mdot
.46939 .01701 Mdot
.83355 .37796 Mdot
.53965 .60444 Mdot
.36352 .13047 Mdot
.73957 .08045 Mdot
.96723 .2044 Mdot
.80706 .10446 Mdot
.20918 .50262 Mdot
.60846 .07861 Mdot
.78168 .09636 Mdot
.08062 .24602 Mdot
.33766 .53609 Mdot
.34414 .54094 Mdot
.27514 .5116 Mdot
.94688 .19638 Mdot
.40514 .59532 Mdot
.18871 .28284 Mdot
.3595 .21015 Mdot
.39381 .53071 Mdot
.93116 .1647 Mdot
.45401 .6037 Mdot
.36969 .56849 Mdot
.68432 .11775 Mdot
.73035 .10779 Mdot
.4818 .57824 Mdot
.2423 .51913 Mdot
.66842 .10684 Mdot
.2438 .49792 Mdot
.74143 .10673 Mdot
.78296 .09574 Mdot
.49586 .01499 Mdot
.12211 .44817 Mdot
.66148 .10703 Mdot
.42423 .5427 Mdot
.30736 .52233 Mdot
.57872 .06515 Mdot
.54128 .00659 Mdot
.13799 .47559 Mdot
.61982 .09267 Mdot
.10665 .25658 Mdot
.07219 .24585 Mdot
.90698 .18435 Mdot
.82347 .10895 Mdot
.68843 .37057 Mdot
.20183 .2869 Mdot
.15215 .23147 Mdot
.51349 .51134 Mdot
.08373 .25015 Mdot
.57208 .01404 Mdot
.29081 .53611 Mdot
.35406 .56262 Mdot
.31328 .52532 Mdot
.36815 .54814 Mdot
.84303 .15389 Mdot
.2511 .50099 Mdot
.48474 .02292 Mdot
.103 .25644 Mdot
.40486 .02146 Mdot
.39056 .02211 Mdot
.02519 .21857 Mdot
.35561 .54369 Mdot
.12651 .22691 Mdot
.32539 .22038 Mdot
.46537 .60869 Mdot
.14821 .45794 Mdot
.1294 .45011 Mdot
.72384 .0755 Mdot
.10828 .46648 Mdot
.46102 .03606 Mdot
.36489 .58775 Mdot
.44483 .57977 Mdot
.43695 .06681 Mdot
.77383 .09338 Mdot
.21401 .29033 Mdot
.08678 .23998 Mdot
.32608 .56436 Mdot
.78933 .13137 Mdot
.36373 .52015 Mdot
.09346 .24958 Mdot
.16771 .27481 Mdot
.49251 .60052 Mdot
.55741 .58925 Mdot
.91367 .39851 Mdot
.34486 .56112 Mdot
.16574 .48769 Mdot
.49418 .56831 Mdot
.26555 .2828 Mdot
.15378 .27216 Mdot
.29036 .51542 Mdot
.78563 .09571 Mdot
.90993 .18457 Mdot
.99908 .21551 Mdot
.07185 .24549 Mdot
.33917 .5707 Mdot
.96288 .20385 Mdot
.58799 .04292 Mdot
.89076 .14998 Mdot
.5287 .04345 Mdot
.28832 .51472 Mdot
.5449 .024 Mdot
.78816 .37713 Mdot
.95047 .19835 Mdot
.3981 .03712 Mdot
.18662 .47361 Mdot
.00594 .21901 Mdot
.61854 .05973 Mdot
.87134 .38592 Mdot
.34667 .55866 Mdot
.9837 .42226 Mdot
.64054 .48609 Mdot
.2244 .51116 Mdot
.33628 .57459 Mdot
.1672 .48833 Mdot
.83359 .14935 Mdot
.53607 .60315 Mdot
.51783 .03787 Mdot
.60096 .052 Mdot
.97949 .21063 Mdot
.76823 .12314 Mdot
.00157 .42693 Mdot
.99401 .42571 Mdot
.60982 .58479 Mdot
.27629 .50977 Mdot
.00495 .19108 Mdot
.47051 .0171 Mdot
.44832 .11985 Mdot
.21716 .48648 Mdot
.30722 .27969 Mdot
.30576 .56103 Mdot
.43914 .54824 Mdot
.96719 .20383 Mdot
.6625 .46017 Mdot
.13291 .47633 Mdot
.78979 .10032 Mdot
.37422 .57324 Mdot
.35541 .22248 Mdot
.55247 .00664 Mdot
.51845 .02419 Mdot
.15465 .23242 Mdot
.22193 .29045 Mdot
.54277 .03406 Mdot
.76826 .08737 Mdot
.35626 .22602 Mdot
.40869 .58906 Mdot
.45439 .58456 Mdot
.72232 .10404 Mdot
.3384 .57623 Mdot
.17528 .49247 Mdot
.76844 .08811 Mdot
.69199 .36714 Mdot
.36138 .54471 Mdot
.70519 .10127 Mdot
.54852 .02958 Mdot
.32117 .5678 Mdot
.09322 .45835 Mdot
.18773 .28132 Mdot
.83879 .15594 Mdot
.95975 .41325 Mdot
.67991 .04735 Mdot
.8299 .11283 Mdot
.79982 .37522 Mdot
.65928 .0777 Mdot
.8973 .17921 Mdot
.42468 .55171 Mdot
.68533 .06752 Mdot
.96543 .20531 Mdot
.43519 .5467 Mdot
.23322 .49234 Mdot
.67434 .0889 Mdot
.70207 .12298 Mdot
.72936 .07552 Mdot
.41367 .04909 Mdot
.70315 .12375 Mdot
.85502 .16352 Mdot
.85465 .15806 Mdot
.70098 .12135 Mdot
.73105 .11249 Mdot
.97258 .20508 Mdot
.40987 .0233 Mdot
.6684 .11088 Mdot
.66246 .07833 Mdot
.464 .58834 Mdot
.40882 .12034 Mdot
.10475 .46236 Mdot
.27084 .5093 Mdot
.66792 .1117 Mdot
.302 .55976 Mdot
.78576 .37801 Mdot
.89412 .39537 Mdot
.43496 .54607 Mdot
.27497 .54502 Mdot
.03293 .22105 Mdot
.54207 .02304 Mdot
.41316 .59112 Mdot
.57164 .07491 Mdot
.81423 .11994 Mdot
.34572 .5796 Mdot
.84009 .15281 Mdot
.78603 .3777 Mdot
.71544 .10092 Mdot
.82212 .10916 Mdot
.36073 .52353 Mdot
.35664 .57713 Mdot
.43254 .02795 Mdot
.65333 .10449 Mdot
.64181 .07537 Mdot
.69439 .06449 Mdot
.60265 .08624 Mdot
.26128 .54112 Mdot
.14272 .47673 Mdot
.27951 .54663 Mdot
.36142 .54843 Mdot
.50909 .03445 Mdot
.00855 .22106 Mdot
.26207 .50537 Mdot
.72138 .35333 Mdot
.28928 .55487 Mdot
.96353 .20307 Mdot
.34506 .57973 Mdot
.06024 .42352 Mdot
.85785 .38506 Mdot
.54479 .49866 Mdot
.62866 .03683 Mdot
.65295 .10626 Mdot
.13552 .47469 Mdot
.16807 .27445 Mdot
.08329 .24881 Mdot
.60431 .02718 Mdot
.43791 .55776 Mdot
.33821 .15651 Mdot
.1089 .25745 Mdot
.37825 .55164 Mdot
.97889 .20932 Mdot
.70738 .09271 Mdot
.21978 .29174 Mdot
.16928 .27527 Mdot
.99188 .21492 Mdot
.58454 .02057 Mdot
.61827 .0338 Mdot
.01368 .43044 Mdot
.32784 .27245 Mdot
.60057 .60021 Mdot
.37116 .52815 Mdot
.02489 .21799 Mdot
.40264 .60561 Mdot
.80284 .09957 Mdot
.6007 .03226 Mdot
.3889 .01879 Mdot
.59004 .00857 Mdot
.46279 .03672 Mdot
.67516 .04512 Mdot
.41321 .5904 Mdot
.54021 .49906 Mdot
.88248 .17466 Mdot
.96097 .41043 Mdot
.40668 .02137 Mdot
.60498 .59969 Mdot
.66815 .4426 Mdot
.65638 .10734 Mdot
.94999 .41063 Mdot
.39822 .56321 Mdot
.60874 .01681 Mdot
.80186 .13731 Mdot
.14964 .26996 Mdot
.40718 .60703 Mdot
.78794 .09405 Mdot
.40669 .02109 Mdot
.0042 .21858 Mdot
.94467 .17011 Mdot
.6928 .11997 Mdot
.93166 .1902 Mdot
.28104 .55091 Mdot
.30153 .54362 Mdot
.26903 .50681 Mdot
.91958 .39785 Mdot
.1887 .28238 Mdot
.95123 .20146 Mdot
.34209 .51306 Mdot
.53452 .00379 Mdot
.32516 .55299 Mdot
.99599 .42218 Mdot
.63395 .03872 Mdot
.14857 .45766 Mdot
.00827 .42892 Mdot
.30354 .56072 Mdot
.44404 .6114 Mdot
.64384 .10165 Mdot
.37545 .55362 Mdot
.79845 .13008 Mdot
.14728 .2692 Mdot
.80613 .37913 Mdot
.28988 .28253 Mdot
.40812 .56767 Mdot
.88109 .16899 Mdot
.99146 .42387 Mdot
.14913 .48288 Mdot
.61076 .09029 Mdot
.61682 .49533 Mdot
.95021 .40858 Mdot
.36629 .54681 Mdot
.37785 .57635 Mdot
.1335 .26455 Mdot
.36166 .20062 Mdot
.27916 .53392 Mdot
.86653 .38678 Mdot
.12351 .22614 Mdot
.81435 .10797 Mdot
.6065 .57973 Mdot
.94002 .19566 Mdot
.83057 .38083 Mdot
.96779 .41328 Mdot
.42519 .60329 Mdot
.46525 .59242 Mdot
.42254 .57413 Mdot
.50073 .60332 Mdot
.39597 .02087 Mdot
.56195 .00987 Mdot
.6347 .48938 Mdot
.24536 .49711 Mdot
.72203 .07461 Mdot
.33019 .18861 Mdot
.78509 .0964 Mdot
.19691 .2851 Mdot
.28318 .55172 Mdot
.67588 .11199 Mdot
.186 .28296 Mdot
.674 .11363 Mdot
.26071 .50597 Mdot
.47804 .59416 Mdot
.95452 .41023 Mdot
.85902 .38385 Mdot
.11994 .4693 Mdot
.27957 .52523 Mdot
.39601 .60247 Mdot
.85241 .38226 Mdot
.53017 .61642 Mdot
.45505 .55316 Mdot
.23558 .29288 Mdot
.7558 .09664 Mdot
.6416 .09323 Mdot
.9363 .18504 Mdot
.45681 .01146 Mdot
.8239 .12386 Mdot
.9348 .4062 Mdot
.36502 .5892 Mdot
.69882 .11987 Mdot
.48731 .00332 Mdot
.7363 .07775 Mdot
.62477 .5982 Mdot
.75117 .11648 Mdot
.76427 .08999 Mdot
.22899 .5044 Mdot
.23769 .49675 Mdot
.20129 .50346 Mdot
.80911 .10413 Mdot
.36831 .17791 Mdot
.79642 .13942 Mdot
.30544 .54458 Mdot
.7841 .12442 Mdot
.6462 .10357 Mdot
.17967 .49328 Mdot
.19534 .28495 Mdot
.5317 .04456 Mdot
.30825 .52356 Mdot
.38475 .5278 Mdot
.67618 .04573 Mdot
.6966 .05434 Mdot
.39702 .53287 Mdot
.18902 .49673 Mdot
.13572 .26489 Mdot
.70908 .09848 Mdot
.8437 .36619 Mdot
.3621 .54861 Mdot
.37359 .57064 Mdot
.6328 .09737 Mdot
.11588 .25965 Mdot
.46562 .5583 Mdot
.45055 .56507 Mdot
.05788 .4441 Mdot
.30877 .52396 Mdot
.41107 .54634 Mdot
.1243 .26422 Mdot
.55236 .068 Mdot
.1077 .44175 Mdot
.33609 .56982 Mdot
.81223 .35892 Mdot
.75757 .11361 Mdot
.12023 .46829 Mdot
.1367 .4763 Mdot
.533 .04444 Mdot
.33431 .55758 Mdot
.71614 .0637 Mdot
.19195 .28401 Mdot
.04262 .44258 Mdot
.3794 .55576 Mdot
.30073 .55407 Mdot
.07065 .24248 Mdot
.62191 .59365 Mdot
.09933 .46057 Mdot
.59388 .59769 Mdot
.81798 .10598 Mdot
.93153 .16473 Mdot
.59854 .57462 Mdot
.01744 .22538 Mdot
.09868 .46054 Mdot
.57467 .04174 Mdot
.00947 .22037 Mdot
.62379 .60274 Mdot
.55691 .00899 Mdot
.8031 .37715 Mdot
.44194 .03134 Mdot
.3824 .02212 Mdot
.05791 .4227 Mdot
.8585 .16475 Mdot
.92229 .39915 Mdot
.91589 .39964 Mdot
.79099 .09862 Mdot
.86265 .13874 Mdot
.47285 .09156 Mdot
.92761 .40336 Mdot
.44539 .07179 Mdot
.87288 .38914 Mdot
.30835 .52349 Mdot
.34896 .51736 Mdot
.95972 .41059 Mdot
.92859 .40262 Mdot
.78281 .37724 Mdot
.77898 .37625 Mdot
.96765 .41577 Mdot
.24953 .2805 Mdot
.3522 .51894 Mdot
.15459 .46133 Mdot
.29603 .28212 Mdot
.4502 .07421 Mdot
.16338 .48807 Mdot
.12514 .25186 Mdot
.29879 .28219 Mdot
.65025 .05306 Mdot
.25998 .28209 Mdot
.77377 .104 Mdot
.29098 .51851 Mdot
.25972 .5039 Mdot
.98109 .21038 Mdot
.83148 .37865 Mdot
.09025 .45991 Mdot
.05949 .24034 Mdot
.72743 .07752 Mdot
.11151 .46745 Mdot
.54935 .01077 Mdot
.05869 .23963 Mdot
.49354 .59999 Mdot
.27554 .5499 Mdot
.57022 .61662 Mdot
.46483 .0022 Mdot
.66452 .10349 Mdot
.29616 .55316 Mdot
.59296 .0552 Mdot
.01987 .43499 Mdot
.47673 .0071 Mdot
.38468 .55516 Mdot
.48871 .10442 Mdot
.2204 .50088 Mdot
.11187 .44338 Mdot
.43299 .59938 Mdot
.69587 .07213 Mdot
.62212 .59632 Mdot
.87561 .16753 Mdot
.01375 .22232 Mdot
.40162 .54157 Mdot
.21228 .50771 Mdot
.77163 .12865 Mdot
.3336 .55667 Mdot
.54741 .53947 Mdot
.45331 .56562 Mdot
.23158 .49252 Mdot
.43927 .06781 Mdot
.05742 .20752 Mdot
.72847 .06738 Mdot
.39278 .02213 Mdot
.59834 .08524 Mdot
.6324 .04556 Mdot
.46043 2e-05 Mdot
.39767 .5324 Mdot
.27946 .53102 Mdot
.27701 .51099 Mdot
.31914 .56119 Mdot
.78076 .37639 Mdot
.37225 .52585 Mdot
.35612 .22062 Mdot
.8255 .11003 Mdot
.17359 .4909 Mdot
.10181 .25521 Mdot
.14199 .26747 Mdot
.10783 .22211 Mdot
.76764 .08586 Mdot
.49387 .6005 Mdot
.46994 .57243 Mdot
.53879 .04742 Mdot
.57876 .00265 Mdot
.51118 .50467 Mdot
.59169 .569 Mdot
.38791 .53016 Mdot
.48594 .10269 Mdot
.28222 .54811 Mdot
.04697 .44061 Mdot
.66914 .10827 Mdot
.34214 .57032 Mdot
.68706 .11767 Mdot
.47286 .04014 Mdot
.84287 .38259 Mdot
.60921 .58292 Mdot
.14834 .2696 Mdot
.4872 .59786 Mdot
.34653 .57956 Mdot
.07053 .24486 Mdot
.95086 .40943 Mdot
.14472 .47792 Mdot
.54123 .60486 Mdot
.78033 .09568 Mdot
.61421 .05362 Mdot
.06655 .24275 Mdot
.3738 .5699 Mdot
.68631 .11778 Mdot
.58967 .06944 Mdot
.54914 .00462 Mdot
.80752 .37901 Mdot
.91967 .18448 Mdot
.43442 .5758 Mdot
.22564 .27757 Mdot
.14496 .48125 Mdot
.00556 .21917 Mdot
.10218 .46033 Mdot
.79546 .10233 Mdot
.43753 .1468 Mdot
.86269 .16574 Mdot
.24915 .53754 Mdot
.35533 .51695 Mdot
.17229 .48963 Mdot
.43113 .59835 Mdot
.41631 .60032 Mdot
.916 .39759 Mdot
.05195 .23636 Mdot
.10856 .44216 Mdot
.18147 .49266 Mdot
.18277 .47327 Mdot
.78654 .13461 Mdot
.56596 .49869 Mdot
.08522 .21647 Mdot
.81956 .10672 Mdot
.42226 .55241 Mdot
.5165 .51521 Mdot
.96372 .41278 Mdot
.56159 .58955 Mdot
.17681 .47076 Mdot
.12206 .44861 Mdot
.98982 .19912 Mdot
.6302 .03894 Mdot
.042 .23316 Mdot
.17721 .27723 Mdot
.65483 .08054 Mdot
.16669 .27723 Mdot
.58019 .01737 Mdot
.27348 .50848 Mdot
.69116 .11799 Mdot
.23647 .27957 Mdot
.60339 .01402 Mdot
.37171 .57237 Mdot
.268 .53051 Mdot
.41249 .61027 Mdot
.62617 .02312 Mdot
.00246 .19023 Mdot
.35417 .57593 Mdot
.32385 .57087 Mdot
.72746 .06785 Mdot
.7262 .06828 Mdot
.47152 .61151 Mdot
.4721 .0912 Mdot
.36255 .57872 Mdot
.04082 .44181 Mdot
.98291 .21035 Mdot
.46254 .58704 Mdot
.67094 .0874 Mdot
.18928 .47638 Mdot
.76174 .08958 Mdot
.90571 .17881 Mdot
.90895 .39846 Mdot
.53624 .49909 Mdot
.47776 .59766 Mdot
.99544 .42479 Mdot
.276 .52375 Mdot
.85524 .38234 Mdot
.12217 .46961 Mdot
.91307 .18531 Mdot
.42825 .57322 Mdot
.08282 .2458 Mdot
.38204 .55483 Mdot
.81396 .37823 Mdot
.53654 .61791 Mdot
.10322 .25443 Mdot
.42149 .55036 Mdot
.27481 .28334 Mdot
.31247 .5478 Mdot
.4898 .00093 Mdot
.36522 .18621 Mdot
.79394 .0974 Mdot
.01958 .43387 Mdot
.12246 .26044 Mdot
.00848 .42869 Mdot
.99582 .21483 Mdot
.29603 .55288 Mdot
.77643 .09573 Mdot
.38744 .02853 Mdot
.27286 .51145 Mdot
.09142 .45956 Mdot
.66363 .04016 Mdot
.07204 .45021 Mdot
.76523 .09119 Mdot
.98154 .41703 Mdot
.32282 .22833 Mdot
.42581 .55284 Mdot
.06042 .44648 Mdot
.99004 .21573 Mdot
.07909 .45393 Mdot
.22359 .49074 Mdot
.2001 .28492 Mdot
.40785 .04573 Mdot
.39135 .53775 Mdot
.06168 .23875 Mdot
.64172 .03058 Mdot
.00486 .22123 Mdot
.41172 .59024 Mdot
.50591 .03232 Mdot
.53937 .00594 Mdot
.27464 .53293 Mdot
.63338 .48999 Mdot
.5369 .03149 Mdot
.18224 .49286 Mdot
.46921 .55934 Mdot
.68283 .11615 Mdot
.46592 .01565 Mdot
.14915 .45954 Mdot
.15581 .26054 Mdot
.4617 .01249 Mdot
.10753 .25449 Mdot
.6145 .58792 Mdot
.03295 .43792 Mdot
.41835 .56981 Mdot
.19501 .47694 Mdot
.40417 .04209 Mdot
.37641 .57112 Mdot
.85237 .38504 Mdot
.52139 .49947 Mdot
.95776 .20244 Mdot
.66029 .10166 Mdot
.35121 .51896 Mdot
.70394 .09155 Mdot
.3525 .54276 Mdot
.87432 .14338 Mdot
.47301 .14883 Mdot
.35853 .21628 Mdot
.75325 .12118 Mdot
.04796 .44044 Mdot
.50453 .00765 Mdot
.73882 .10991 Mdot
.65657 .04961 Mdot
.20486 .48021 Mdot
.59075 .04752 Mdot
.66307 .45916 Mdot
.28203 .55298 Mdot
.31138 .56301 Mdot
.2551 .53811 Mdot
.23614 .29443 Mdot
.39305 .15571 Mdot
.71688 .10654 Mdot
.54855 .53966 Mdot
.48019 .61467 Mdot
.2483 .50113 Mdot
.58242 .04456 Mdot
.66287 .10439 Mdot
.71073 .06127 Mdot
.87505 .38997 Mdot
.83422 .37997 Mdot
.47177 .59072 Mdot
.17904 .2574 Mdot
.758 .08217 Mdot
.98337 .20339 Mdot
.44606 .58462 Mdot
.92638 .40268 Mdot
.82816 .37981 Mdot
.92081 .16137 Mdot
.39934 .5943 Mdot
.39233 .57848 Mdot
.92324 .1905 Mdot
.115 .466 Mdot
.37692 .52589 Mdot
.37078 .12736 Mdot
.92086 .39819 Mdot
.81918 .14843 Mdot
.06003 .44932 Mdot
.42336 .59139 Mdot
.35367 .23229 Mdot
.16832 .48891 Mdot
.1871 .28012 Mdot
.35389 .23264 Mdot
.08243 .21514 Mdot
.50587 .61029 Mdot
.03811 .43971 Mdot
.23677 .51635 Mdot
.3674 .57149 Mdot
.30452 .52376 Mdot
.85289 .38436 Mdot
.5975 .59957 Mdot
.06049 .44506 Mdot
.1727 .27599 Mdot
.43375 .06362 Mdot
.46122 .61007 Mdot
.61496 .58826 Mdot
.12769 .26509 Mdot
.18609 .27994 Mdot
.18438 .26877 Mdot
.05651 .44675 Mdot
.21535 .50851 Mdot
.88185 .39155 Mdot
.06641 .24444 Mdot
.3331 .26891 Mdot
.90754 .39935 Mdot
.31957 .56928 Mdot
.59818 .02444 Mdot
.62338 .59685 Mdot
.53321 .02376 Mdot
.1749 .49121 Mdot
.84978 .38127 Mdot
.86264 .3847 Mdot
.3792 .52785 Mdot
.15953 .23334 Mdot
.16504 .48652 Mdot
.49895 .60708 Mdot
.465 .60892 Mdot
.484 .10088 Mdot
.03325 .23248 Mdot
.76116 .08277 Mdot
.47716 .61747 Mdot
.65758 .08204 Mdot
.69336 .09174 Mdot
.47741 .00681 Mdot
.67056 .08737 Mdot
.31049 .56548 Mdot
.95745 .41039 Mdot
.16839 .27741 Mdot
.36553 .54755 Mdot
.31604 .52799 Mdot
.13018 .26246 Mdot
.43007 .59804 Mdot
.91935 .40203 Mdot
.55783 .58907 Mdot
.61758 .01935 Mdot
.09993 .25499 Mdot
.36145 .57836 Mdot
.90004 .15301 Mdot
.17209 .49 Mdot
.29099 .55436 Mdot
.43927 .60936 Mdot
.88285 .17485 Mdot
.60813 .03498 Mdot
.82286 .14515 Mdot
.16575 .46578 Mdot
.36638 .5266 Mdot
.84822 .1332 Mdot
.05097 .44444 Mdot
.09705 .25521 Mdot
.85284 .1584 Mdot
.93743 .19309 Mdot
.60227 .60048 Mdot
.54652 .60657 Mdot
.02259 .43213 Mdot
.15269 .46018 Mdot
.61622 .60287 Mdot
.72081 .07499 Mdot
.28658 .53425 Mdot
.12018 .24999 Mdot
.93815 .16767 Mdot
.84464 .15913 Mdot
.57965 .07879 Mdot
.10721 .46557 Mdot
.85959 .13769 Mdot
.10545 .25396 Mdot
.55192 .609 Mdot
.688 .11691 Mdot
.37733 .16656 Mdot
.65939 .10787 Mdot
.35802 .54735 Mdot
.66968 .08753 Mdot
.11556 .22449 Mdot
.85132 .38359 Mdot
.98157 .21071 Mdot
.8048 .10206 Mdot
.10991 .4662 Mdot
.17464 .2764 Mdot
.09301 .24928 Mdot
.1803 .47188 Mdot
.49159 .02692 Mdot
.18915 .49741 Mdot
.97094 .20932 Mdot
.33909 .55013 Mdot
.31301 .56286 Mdot
.36942 .12805 Mdot
.62251 .06085 Mdot
.6133 .58567 Mdot
.89117 .39451 Mdot
.1938 .49873 Mdot
.48621 .58086 Mdot
.89802 .18043 Mdot
.96749 .20518 Mdot
.89291 .16854 Mdot
.75788 .08498 Mdot
.65657 .10562 Mdot
.82197 .38006 Mdot
.80164 .10088 Mdot
.63326 .02731 Mdot
.35055 .24528 Mdot
.4824 .56305 Mdot
.23387 .26644 Mdot
.82141 .11024 Mdot
.06095 .2396 Mdot
.40563 .04307 Mdot
.91707 .39903 Mdot
.35472 .22687 Mdot
.37158 .52824 Mdot
.32332 .53061 Mdot
.79494 .09677 Mdot
.59659 .0505 Mdot
.5682 .55326 Mdot
.3545 .51808 Mdot
.37919 .16393 Mdot
.65702 .03734 Mdot
.58877 .59736 Mdot
.5057 .00749 Mdot
.158 .27496 Mdot
.33596 .26592 Mdot
.78931 .09845 Mdot
.83594 .38277 Mdot
.53748 .00133 Mdot
.57856 .00276 Mdot
.91062 .18227 Mdot
.87838 .39012 Mdot
.63388 .06667 Mdot
.67966 .08505 Mdot
.39637 .59273 Mdot
.09032 .25125 Mdot
.35785 .54552 Mdot
.72621 .10507 Mdot
.16071 .48741 Mdot
.26956 .5304 Mdot
.06425 .45043 Mdot
.22169 .28968 Mdot
.93481 .1664 Mdot
.92478 .18677 Mdot
.39256 .03121 Mdot
.33405 .53489 Mdot
.33957 .55995 Mdot
.52228 .49899 Mdot
.01283 .43109 Mdot
.2239 .51163 Mdot
.94115 .40461 Mdot
.77949 .37666 Mdot
.66349 .05871 Mdot
.01411 .4204 Mdot
.19483 .23854 Mdot
.99359 .42404 Mdot
.97877 .21004 Mdot
.17505 .48994 Mdot
.34378 .25749 Mdot
.33162 .18144 Mdot
.16857 .4663 Mdot
.5334 .02274 Mdot
.51569 .51341 Mdot
.59026 .04707 Mdot
.80491 .10391 Mdot
.57522 .00112 Mdot
.66649 .05307 Mdot
.44422 .54946 Mdot
.49542 .11386 Mdot
.83513 .15479 Mdot
.35051 .58132 Mdot
.6322 .49047 Mdot
.44824 .56321 Mdot
.49078 .0051 Mdot
.3504 .5428 Mdot
.53832 .00125 Mdot
.35114 .24442 Mdot
.36374 .19295 Mdot
.44906 .60611 Mdot
.12664 .26463 Mdot
.56108 .05721 Mdot
.94394 .40604 Mdot
.3762 .55211 Mdot
.11439 .25704 Mdot
.45794 .61001 Mdot
.89914 .39657 Mdot
.01625 .43251 Mdot
.95989 .41349 Mdot
.08965 .456 Mdot
.00503 .42546 Mdot
.28843 .51742 Mdot
.694 .11939 Mdot
.68104 .08579 Mdot
.55532 .06894 Mdot
.49627 .02895 Mdot
.89957 .39295 Mdot
.96289 .20429 Mdot
.02733 .1983 Mdot
.6108 .05199 Mdot
.46705 .55855 Mdot
.15829 .23336 Mdot
.57941 .00368 Mdot
.17558 .26602 Mdot
.37916 .57241 Mdot
.42314 .02613 Mdot
.15116 .25076 Mdot
.09448 .46004 Mdot
.50915 .50214 Mdot
.33629 .26559 Mdot
.31457 .56176 Mdot
.08815 .21675 Mdot
.06052 .42346 Mdot
.78224 .37535 Mdot
.05466 .22875 Mdot
.52032 .61607 Mdot
.17751 .23599 Mdot
.29633 .54164 Mdot
.00852 .21916 Mdot
.32969 .5336 Mdot
.79029 .09511 Mdot
.7998 .10374 Mdot
.07578 .45241 Mdot
.38091 .55469 Mdot
.12856 .2652 Mdot
.35924 .54646 Mdot
.43283 .00113 Mdot
.87716 .38699 Mdot
.90437 .17804 Mdot
.53147 .58095 Mdot
.82902 .378 Mdot
.13424 .45317 Mdot
.99269 .42346 Mdot
.31912 .53062 Mdot
.52761 .61506 Mdot
.23906 .49549 Mdot
.49104 .11627 Mdot
.73695 .08053 Mdot
.99437 .42625 Mdot
.32859 .53187 Mdot
.75647 .08466 Mdot
.63722 .06317 Mdot
.68913 .11535 Mdot
.27483 .53282 Mdot
.29897 .55999 Mdot
.61526 .06397 Mdot
.27727 .54876 Mdot
.15402 .27289 Mdot
.8661 .14013 Mdot
.04009 .23508 Mdot
.2101 .4842 Mdot
.5789 .56124 Mdot
.34317 .56142 Mdot
.33128 .57277 Mdot
.43227 .02772 Mdot
.06995 .24446 Mdot
.9745 .41917 Mdot
.82912 .37721 Mdot
.38995 .0217 Mdot
.65267 .1053 Mdot
.41316 .53843 Mdot
.88297 .1642 Mdot
.07543 .42976 Mdot
.30281 .55519 Mdot
.44607 .00579 Mdot
.64371 .04325 Mdot
.956 .40894 Mdot
.02106 .22329 Mdot
.63361 .04623 Mdot
.19279 .28234 Mdot
.39801 .58422 Mdot
.18203 .47281 Mdot
.57112 .59194 Mdot
.76022 .08149 Mdot
.23662 .26668 Mdot
.50464 .01843 Mdot
.21152 .50743 Mdot
.60873 .01684 Mdot
.05416 .22879 Mdot
.78414 .13014 Mdot
.03186 .43695 Mdot
.66898 .05324 Mdot
.09468 .21804 Mdot
.95996 .17562 Mdot
.29603 .55854 Mdot
.9323 .4024 Mdot
.36087 .52328 Mdot
.51662 .03673 Mdot
.4825 .1192 Mdot
.38347 .16052 Mdot
.64298 .07556 Mdot
.37268 .5256 Mdot
.98829 .42012 Mdot
.99321 .1866 Mdot
.89202 .39433 Mdot
.83008 .37923 Mdot
.70595 .1246 Mdot
.4624 .58819 Mdot
.27369 .28235 Mdot
.23496 .51567 Mdot
.28824 .55236 Mdot
.17576 .49093 Mdot
.93134 .40469 Mdot
.39725 .0381 Mdot
.36265 .19345 Mdot
.96759 .20793 Mdot
.36362 .54683 Mdot
.89902 .18083 Mdot
.04916 .44346 Mdot
.14651 .27097 Mdot
.96015 .20284 Mdot
.22816 .27821 Mdot
.47722 .57648 Mdot
.43781 .54845 Mdot
.58698 .59603 Mdot
.47719 .61722 Mdot
.49012 .11732 Mdot
.58328 .59672 Mdot
.40018 .02063 Mdot
.86691 .16754 Mdot
.44617 .60394 Mdot
.31995 .52826 Mdot
.18214 .26791 Mdot
.49061 .56648 Mdot
.94616 .199 Mdot
.54302 .00268 Mdot
.44278 .57912 Mdot
.54963 .03737 Mdot
.04648 .23582 Mdot
.47425 .121 Mdot
.57794 .49932 Mdot
.09245 .25017 Mdot
.6747 .08289 Mdot
.41095 .04868 Mdot
.979 .21076 Mdot
.5716 .6178 Mdot
.69307 .06346 Mdot
.02799 .19872 Mdot
.84124 .38019 Mdot
.43971 .60972 Mdot
.13911 .45345 Mdot
.50094 .57016 Mdot
.85572 .38171 Mdot
.31648 .54904 Mdot
.53164 .52883 Mdot
.62996 .02484 Mdot
.77277 .12918 Mdot
.81887 .37837 Mdot
.59443 .05564 Mdot
.06344 .45048 Mdot
.35068 .57359 Mdot
.76587 .35204 Mdot
.34624 .51619 Mdot
.15678 .23273 Mdot
.38539 .59674 Mdot
.36564 .52086 Mdot
.16311 .2625 Mdot
.7437 .08152 Mdot
.57225 .59302 Mdot
.74785 .0821 Mdot
.93812 .19497 Mdot
.48985 .56563 Mdot
.78178 .09012 Mdot
.20386 .48138 Mdot
.09593 .46082 Mdot
.50448 .60953 Mdot
.69749 .12152 Mdot
.91091 .18461 Mdot
.36753 .52157 Mdot
.57007 .0459 Mdot
.42036 .57045 Mdot
.77327 .08722 Mdot
.30881 .2516 Mdot
.13643 .47684 Mdot
.54626 .58561 Mdot
.56254 .04212 Mdot
.78381 .1189 Mdot
.16181 .27204 Mdot
.23278 .49423 Mdot
.85338 .15281 Mdot
.97269 .20748 Mdot
.53075 .60066 Mdot
.0409 .23225 Mdot
.68795 .06084 Mdot
.46478 .03796 Mdot
.41092 .59874 Mdot
.41195 .54582 Mdot
.96388 .4134 Mdot
.39604 .58259 Mdot
.5613 .59002 Mdot
.7343 .11402 Mdot
.30494 .56079 Mdot
.07877 .45465 Mdot
.37792 .55266 Mdot
.71574 .08014 Mdot
.88154 .39197 Mdot
.65003 .07294 Mdot
.3858 .02065 Mdot
.07296 .24638 Mdot
.78359 .12892 Mdot
.0776 .23665 Mdot
.35848 .52266 Mdot
.34458 .5156 Mdot
.94409 .40559 Mdot
.11352 .25915 Mdot
.56808 .03426 Mdot
.40349 .60609 Mdot
.80673 .13358 Mdot
.07651 .4512 Mdot
.58342 .07936 Mdot
.7024 .12304 Mdot
.94197 .40598 Mdot
.51074 .51078 Mdot
.67717 .11129 Mdot
.81757 .1056 Mdot
.1007 .25197 Mdot
.65056 .10459 Mdot
.026 .22807 Mdot
.91004 .39841 Mdot
.09907 .46258 Mdot
.3554 .22527 Mdot
.77044 .08794 Mdot
.56248 .03521 Mdot
.37472 .59235 Mdot
.37729 .52862 Mdot
.90089 .39311 Mdot
.77439 .08703 Mdot
.73284 .35164 Mdot
.06889 .24304 Mdot
.91219 .18531 Mdot
.14017 .25666 Mdot
.52095 .01407 Mdot
.02262 .43575 Mdot
.01288 .22398 Mdot
.54231 .00181 Mdot
.50409 .58814 Mdot
.43617 .58033 Mdot
.7671 .08685 Mdot
.28521 .53314 Mdot
.27231 .283 Mdot
.69434 .06263 Mdot
.41967 .55004 Mdot
.87415 .15519 Mdot
.5572 .00774 Mdot
.63156 .0899 Mdot
.82646 .14671 Mdot
.60473 .08819 Mdot
.61896 .59518 Mdot
.42238 .55131 Mdot
.53784 .60248 Mdot
.5364 .61745 Mdot
.10357 .43966 Mdot
.7933 .37834 Mdot
.82493 .12399 Mdot
.19137 .28379 Mdot
.89565 .17549 Mdot
.18107 .26724 Mdot
.38007 .55368 Mdot
.59742 .05046 Mdot
.07271 .24337 Mdot
.54463 .53855 Mdot
.60051 .05833 Mdot
.58626 .59746 Mdot
.57895 .59487 Mdot
.57146 .55545 Mdot
.63345 .0386 Mdot
.63922 .07378 Mdot
.18836 .28174 Mdot
.8331 .14996 Mdot
.45154 .1197 Mdot
.35892 .54518 Mdot
.94332 .40631 Mdot
.1775 .27864 Mdot
.70428 .12421 Mdot
.55354 .05344 Mdot
.72052 .08184 Mdot
.45393 .55414 Mdot
.85641 .15954 Mdot
.97929 .21243 Mdot
.79802 .10159 Mdot
.27652 .53338 Mdot
.08601 .24771 Mdot
.16463 .48739 Mdot
.89041 .17393 Mdot
.54524 .00898 Mdot
.11225 .45756 Mdot
.87831 .16851 Mdot
.3399 .57696 Mdot
.3534 .57515 Mdot
.9422 .19419 Mdot
.25392 .50161 Mdot
.16761 .27645 Mdot
.75142 .08241 Mdot
.45763 .14794 Mdot
.51007 .0203 Mdot
.45269 .55358 Mdot
.41102 .04889 Mdot
.1175 .46918 Mdot
.03123 .43558 Mdot
.40672 .56347 Mdot
.7237 .07405 Mdot
.17969 .27996 Mdot
.66922 .04192 Mdot
.77817 .37751 Mdot
.22684 .51004 Mdot
.17383 .23594 Mdot
.79507 .09968 Mdot
.09436 .46179 Mdot
.09781 .25224 Mdot
.2464 .49804 Mdot
.8019 .13193 Mdot
.93026 .40416 Mdot
.12718 .26412 Mdot
.52937 .52616 Mdot
.31984 .56344 Mdot
.54263 .53598 Mdot
.30984 .56537 Mdot
.37845 .52685 Mdot
.64498 .10235 Mdot
.42991 .11982 Mdot
.69834 .08919 Mdot
.24922 .49826 Mdot
.79415 .37794 Mdot
.63393 .08988 Mdot
.30207 .25657 Mdot
.38017 .52945 Mdot
.01979 .21636 Mdot
.89299 .3947 Mdot
.75925 .35156 Mdot
.0678 .24148 Mdot
.9939 .42551 Mdot
.28108 .5113 Mdot
.73486 .08794 Mdot
.69158 .06353 Mdot
.57591 .02177 Mdot
.42957 .60542 Mdot
.1845 .49537 Mdot
.3903 .01969 Mdot
.94118 .1944 Mdot
.54444 .05034 Mdot
.65518 .10604 Mdot
.43916 .59759 Mdot
.26989 .54354 Mdot
.08816 .24864 Mdot
.18604 .27973 Mdot
.13004 .26294 Mdot
.2908 .55437 Mdot
.9324 .16512 Mdot
.14544 .4781 Mdot
.98864 .21102 Mdot
.3626 .54776 Mdot
.40284 .56383 Mdot
.337 .57672 Mdot
.58836 .02714 Mdot
.81079 .37921 Mdot
.39017 .59945 Mdot
.60608 .60002 Mdot
.2659 .28306 Mdot
.34823 .55942 Mdot
.99127 .42179 Mdot
.76507 .08325 Mdot
.50432 .57146 Mdot
.58776 .02713 Mdot
.59264 .49871 Mdot
.17968 .27831 Mdot
.79538 .10027 Mdot
.01394 .22115 Mdot
.58472 .05103 Mdot
.65861 .03782 Mdot
.26048 .52759 Mdot
.61192 .09084 Mdot
.60278 .03287 Mdot
.12668 .4501 Mdot
.08781 .45621 Mdot
.1181 .2246 Mdot
.22506 .29034 Mdot
.42626 .02597 Mdot
.583 .56425 Mdot
.03565 .43682 Mdot
.06421 .24211 Mdot
.27995 .55178 Mdot
.23387 .51634 Mdot
.76741 .08767 Mdot
.2168 .50626 Mdot
.73047 .08667 Mdot
.78492 .37601 Mdot
.81699 .10623 Mdot
.02138 .42306 Mdot
.13963 .26676 Mdot
.78482 .09811 Mdot
.54813 .02599 Mdot
.41366 .02315 Mdot
.38787 .53474 Mdot
.3172 .56079 Mdot
.22496 .5089 Mdot
.94901 .4103 Mdot
.0602 .44791 Mdot
.96729 .41654 Mdot
.53734 .02487 Mdot
.41237 .5377 Mdot
.03167 .19985 Mdot
.46471 .57107 Mdot
.72047 .07276 Mdot
.08084 .23771 Mdot
.31143 .52683 Mdot
.60482 .60077 Mdot
.38314 .52923 Mdot
.29295 .26097 Mdot
.65259 .47621 Mdot
.75728 .11774 Mdot
.28538 .53691 Mdot
.46607 .5582 Mdot
.03129 .22839 Mdot
.98931 .42031 Mdot
.51634 .49955 Mdot
.339 .26242 Mdot
.42751 .02688 Mdot
.99594 .21728 Mdot
.38987 .53125 Mdot
.05593 .42117 Mdot
.04124 .44103 Mdot
.26148 .54038 Mdot
.82635 .11232 Mdot
.17256 .25595 Mdot
.36797 .12877 Mdot
.18978 .28369 Mdot
.94585 .40615 Mdot
.39705 .01927 Mdot
.18994 .28283 Mdot
.01259 .21416 Mdot
.43763 .0019 Mdot
.9548 .19802 Mdot
.50766 .01945 Mdot
.34784 .2498 Mdot
.26752 .54442 Mdot
.38062 .58598 Mdot
.37313 .52734 Mdot
.32589 .53255 Mdot
.69335 .05331 Mdot
.27832 .54815 Mdot
.37919 .576 Mdot
.67318 .08289 Mdot
.4417 .06884 Mdot
.55587 .00813 Mdot
.65921 .07711 Mdot
.55038 .60824 Mdot
.18438 .47426 Mdot
.72093 .10808 Mdot
.99237 .42089 Mdot
.19617 .28358 Mdot
.51905 .02386 Mdot
.80217 .1152 Mdot
.27952 .53085 Mdot
.4281 .02717 Mdot
.96389 .20183 Mdot
.2559 .50125 Mdot
.86478 .38615 Mdot
.52244 .61688 Mdot
.01867 .22426 Mdot
.61584 .5909 Mdot
.16366 .48526 Mdot
.90272 .39663 Mdot
.734 .07934 Mdot
.72285 .1046 Mdot
.17646 .4704 Mdot
.38508 .02605 Mdot
.29575 .55375 Mdot
.25242 .49953 Mdot
.34385 .5709 Mdot
.49333 .58327 Mdot
.35644 .22408 Mdot
.02456 .43508 Mdot
.40493 .56745 Mdot
.82785 .37991 Mdot
.71375 .07932 Mdot
.50683 .61066 Mdot
.91783 .40231 Mdot
.47146 .61453 Mdot
.39787 .03782 Mdot
.52826 .04206 Mdot
.42751 .59673 Mdot
.13996 .45524 Mdot
.9039 .39573 Mdot
.53012 .06038 Mdot
.94091 .19355 Mdot
.67903 .11423 Mdot
.33049 .56555 Mdot
.38109 .52665 Mdot
.95123 .20003 Mdot
.94398 .1948 Mdot
.62811 .49191 Mdot
.52433 .49923 Mdot
.45018 .00855 Mdot
.20156 .47927 Mdot
.18613 .49623 Mdot
.96922 .41544 Mdot
.0004 .18913 Mdot
.5591 .61311 Mdot
.38812 .52907 Mdot
.42146 .57149 Mdot
.35259 .57439 Mdot
.39114 .53063 Mdot
.52061 .51919 Mdot
.42157 .14837 Mdot
.62319 .06173 Mdot
.01254 .4297 Mdot
.37201 .55142 Mdot
.78772 .37644 Mdot
.35391 .56153 Mdot
.43079 .59716 Mdot
.47063 .00404 Mdot
.26759 .54238 Mdot
.21909 .23944 Mdot
.33408 .17003 Mdot
.88195 .16996 Mdot
.54297 .06505 Mdot
.40313 .15129 Mdot
.63145 .09011 Mdot
.78943 .37482 Mdot
.68148 .08581 Mdot
.41025 .5684 Mdot
.44503 .14703 Mdot
.76507 .11128 Mdot
.69971 .12166 Mdot
.67282 .41166 Mdot
.11502 .22375 Mdot
.29885 .55351 Mdot
.09611 .25211 Mdot
.61891 .06555 Mdot
.33684 .53778 Mdot
.31667 .56024 Mdot
.6362 .09125 Mdot
.09554 .25309 Mdot
.36964 .59053 Mdot
.47312 .09045 Mdot
.78563 .09792 Mdot
.97021 .41386 Mdot
.31939 .52844 Mdot
.65155 .0351 Mdot
.58187 .56379 Mdot
.31511 .55969 Mdot
.39087 .02125 Mdot
.77716 .37787 Mdot
.87849 .39085 Mdot
.3782 .12525 Mdot
.6348 .09023 Mdot
.44901 .58233 Mdot
.46274 .03765 Mdot
.15545 .46164 Mdot
.67288 .05479 Mdot
.29082 .28315 Mdot
.5442 .02848 Mdot
.62439 .60037 Mdot
.65842 .10735 Mdot
.62443 .59945 Mdot
.36725 .59003 Mdot
.91723 .40157 Mdot
.67182 .05484 Mdot
.95561 .41187 Mdot
.05542 .44376 Mdot
.89375 .17812 Mdot
.71816 .10683 Mdot
.24469 .52071 Mdot
.38885 .58093 Mdot
.79683 .13949 Mdot
.45317 .03408 Mdot
.44455 .07081 Mdot
.94379 .40909 Mdot
.59568 .07275 Mdot
.22859 .51341 Mdot
.25107 .53692 Mdot
.17376 .49263 Mdot
.3613 .19718 Mdot
.62439 .5978 Mdot
.75356 .08589 Mdot
.68629 .11416 Mdot
.51708 .0383 Mdot
.83548 .37868 Mdot
.77471 .08946 Mdot
.5613 .61271 Mdot
.26906 .52727 Mdot
.50966 .50775 Mdot
.68445 .04847 Mdot
.66992 .10838 Mdot
.59019 .5986 Mdot
.35661 .52003 Mdot
.87267 .14263 Mdot
.61317 .05305 Mdot
.32783 .20588 Mdot
.97643 .41555 Mdot
.58638 .59768 Mdot
.89913 .39517 Mdot
.34422 .51402 Mdot
.6791 .38515 Mdot
.74797 .08315 Mdot
.35766 .21618 Mdot
.51851 .61523 Mdot
.1229 .26197 Mdot
.17983 .23687 Mdot
.12301 .47078 Mdot
.08838 .2484 Mdot
.34644 .56246 Mdot
.29984 .55811 Mdot
.96435 .41622 Mdot
.29709 .51966 Mdot
.82441 .1513 Mdot
.09395 .46141 Mdot
.476 .11981 Mdot
.23616 .51397 Mdot
.12259 .46874 Mdot
.08856 .45701 Mdot
.67868 .04596 Mdot
.43691 .58097 Mdot
.66508 .4539 Mdot
.04621 .23402 Mdot
.59217 .08254 Mdot
.86326 .16165 Mdot
.65588 .05539 Mdot
.99777 .4257 Mdot
.41388 .61064 Mdot
.36878 .55054 Mdot
.54905 .03011 Mdot
.28006 .26509 Mdot
.19989 .28509 Mdot
.79997 .09907 Mdot
.46494 .58832 Mdot
.38453 .02217 Mdot
.73671 .11439 Mdot
.93999 .40587 Mdot
.88688 .17104 Mdot
.18267 .23736 Mdot
.36389 .54767 Mdot
.91012 .15696 Mdot
.71584 .06332 Mdot
.29908 .54279 Mdot
.4549 .60816 Mdot
.03453 .22886 Mdot
.66572 .10741 Mdot
.33946 .53611 Mdot
.34233 .26078 Mdot
.55098 .06811 Mdot
.69036 .11995 Mdot
.49083 .11936 Mdot
.76048 .08337 Mdot
.36342 .52334 Mdot
.7828 .37818 Mdot
.49257 .11363 Mdot
.44515 .56189 Mdot
.8674 .3866 Mdot
.98369 .21015 Mdot
.25782 .52312 Mdot
.0109 .43022 Mdot
.39495 .5314 Mdot
.31995 .5684 Mdot
.38421 .55814 Mdot
.42398 .57116 Mdot
.42471 .59184 Mdot
.51557 .60911 Mdot
.36026 .13282 Mdot
.34455 .25614 Mdot
.49117 .10751 Mdot
.71782 .06385 Mdot
.94294 .19433 Mdot
.76806 .12807 Mdot
.53443 .60209 Mdot
.14694 .23037 Mdot
.66363 .45947 Mdot
.69639 .08836 Mdot
.54904 .58547 Mdot
.15278 .27161 Mdot
.23228 .49373 Mdot
.60803 .05487 Mdot
.15726 .48387 Mdot
.85147 .14623 Mdot
.73957 .10581 Mdot
.40536 .58338 Mdot
.03289 .23111 Mdot
.88171 .38894 Mdot
.41223 .04904 Mdot
.24774 .49914 Mdot
.01322 .1934 Mdot
.17761 .28056 Mdot
.06961 .45288 Mdot
.29135 .54007 Mdot
.07862 .4307 Mdot
.29869 .55727 Mdot
.70819 .05917 Mdot
.58385 .0793 Mdot
.45388 .01003 Mdot
.91425 .18231 Mdot
.7619 .08155 Mdot
.55965 .05702 Mdot
.33017 .5327 Mdot
.68881 .069 Mdot
.74906 .077 Mdot
.22644 .48907 Mdot
.77143 .10259 Mdot
.17881 .49399 Mdot
.53418 .02007 Mdot
.74007 .08008 Mdot
.44437 .55015 Mdot
.14825 .26998 Mdot
.7679 .08451 Mdot
.49091 .60367 Mdot
.00152 .18979 Mdot
.78233 .09794 Mdot
.09264 .45762 Mdot
.34111 .55693 Mdot
.23474 .51675 Mdot
.77001 .10204 Mdot
.91626 .15915 Mdot
.89144 .17428 Mdot
.04138 .44007 Mdot
.74012 .08112 Mdot
.53572 .02375 Mdot
.60425 .0337 Mdot
.18944 .28134 Mdot
.80051 .11454 Mdot
.99036 .21431 Mdot
.65071 .03452 Mdot
.34328 .25866 Mdot
.05332 .42019 Mdot
.02934 .43394 Mdot
.88274 .17469 Mdot
.70316 .05659 Mdot
.45479 .56665 Mdot
.1912 .28359 Mdot
.4635 .12105 Mdot
.47833 .14969 Mdot
.46063 .56854 Mdot
.53962 .49937 Mdot
.82615 .3778 Mdot
.59848 .02458 Mdot
.03077 .229 Mdot
.42251 .05591 Mdot
.77613 .09031 Mdot
.62422 .59683 Mdot
.8434 .38416 Mdot
.51821 .02352 Mdot
.6472 .07714 Mdot
.83442 .15418 Mdot
.66977 .10745 Mdot
.49264 .11126 Mdot
.5988 .08484 Mdot
.09775 .43855 Mdot
.82217 .14026 Mdot
.95133 .4103 Mdot
.91859 .18848 Mdot
.16938 .27594 Mdot
.12987 .2642 Mdot
.34594 .55843 Mdot
.98939 .41995 Mdot
.75602 .08029 Mdot
.52876 .52718 Mdot
.78563 .13049 Mdot
.35586 .22549 Mdot
.49851 .02986 Mdot
.52586 .59713 Mdot
.08217 .45575 Mdot
.30046 .55502 Mdot
.49751 .6069 Mdot
.35897 .21098 Mdot
.78218 .09222 Mdot
.50438 .0069 Mdot
.78267 .37793 Mdot
.28354 .55158 Mdot
.56809 .59223 Mdot
.13349 .26627 Mdot
.88508 .17092 Mdot
.29823 .55795 Mdot
.35168 .24112 Mdot
.83608 .38112 Mdot
.2023 .50031 Mdot
.00341 .42439 Mdot
.31904 .56169 Mdot
.44834 .58245 Mdot
.37583 .5838 Mdot
.60248 .07616 Mdot
.33326 .17298 Mdot
.09904 .24358 Mdot
.3932 .59027 Mdot
.64855 .47988 Mdot
.98091 .2099 Mdot
.21717 .28905 Mdot
.92425 .39947 Mdot
.62885 .07004 Mdot
.57274 .0012 Mdot
.0121 .22444 Mdot
.04843 .44204 Mdot
.83617 .12855 Mdot
.52474 .52373 Mdot
.47637 .59347 Mdot
.00154 .21797 Mdot
.1218 .26058 Mdot
.77803 .37829 Mdot
.58985 .02227 Mdot
.3158 .52775 Mdot
.67158 .10959 Mdot
.8285 .14773 Mdot
.76584 .11667 Mdot
.28416 .28317 Mdot
.80631 .37614 Mdot
.32952 .5666 Mdot
.99322 .42198 Mdot
.3631 .56938 Mdot
.04808 .41854 Mdot
.30587 .54551 Mdot
.16973 .4673 Mdot
.13408 .47507 Mdot
.29403 .55818 Mdot
.96806 .17815 Mdot
.14985 .27016 Mdot
.23848 .49466 Mdot
.09281 .25193 Mdot
.63842 .06785 Mdot
.24975 .51938 Mdot
.82826 .37995 Mdot
.18001 .27831 Mdot
.63672 .02798 Mdot
.60316 .08696 Mdot
.85801 .16476 Mdot
.96873 .41655 Mdot
.6056 .07709 Mdot
.53894 .58335 Mdot
.75744 .08203 Mdot
.36623 .58028 Mdot
.13108 .26452 Mdot
.08755 .458 Mdot
.03341 .22974 Mdot
.37677 .52831 Mdot
.54997 .03729 Mdot
.71159 .09935 Mdot
.4276 .57344 Mdot
.36872 .18019 Mdot
.25294 .53765 Mdot
.95857 .20309 Mdot
.67885 .11556 Mdot
.78583 .09277 Mdot
.96062 .20135 Mdot
.35408 .51655 Mdot
.78375 .37533 Mdot
.42009 .56933 Mdot
.52649 .04175 Mdot
.06449 .24375 Mdot
.37887 .59397 Mdot
.07429 .24291 Mdot
.06012 .44649 Mdot
.68983 .08546 Mdot
.41527 .60061 Mdot
.85296 .16162 Mdot
.54913 .03013 Mdot
.55625 .00733 Mdot
.74586 .11364 Mdot
.71796 .07341 Mdot
.15036 .25064 Mdot
.90632 .17876 Mdot
.23752 .51825 Mdot
.21392 .2387 Mdot
.35457 .54569 Mdot
.16627 .46589 Mdot
.06519 .24135 Mdot
.71631 .35428 Mdot
.35602 .22123 Mdot
.28521 .51642 Mdot
.74414 .07534 Mdot
.49418 .60499 Mdot
.61132 .05206 Mdot
.65423 .09992 Mdot
.29956 .51986 Mdot
.59165 .08245 Mdot
.10507 .22101 Mdot
.75529 .08291 Mdot
.61496 .09189 Mdot
.22596 .27739 Mdot
.65161 .03563 Mdot
.01655 .43185 Mdot
.63297 .03965 Mdot
.04548 .23431 Mdot
.49788 .60682 Mdot
.54185 .53507 Mdot
.32875 .27155 Mdot
.27007 .53058 Mdot
.44844 .60134 Mdot
.38653 .0253 Mdot
.06761 .24111 Mdot
.62526 .06885 Mdot
.51073 .57358 Mdot
.96583 .20587 Mdot
.41971 .54177 Mdot
.44595 .58165 Mdot
.44713 .58153 Mdot
.73375 .10402 Mdot
.72447 .06526 Mdot
.5559 .01311 Mdot
.27887 .51126 Mdot
.42519 .59506 Mdot
.00597 .22232 Mdot
.1632 .46565 Mdot
.39501 .55887 Mdot
.08746 .25185 Mdot
.68669 .06815 Mdot
.66812 .44091 Mdot
.07946 .23692 Mdot
.68746 .09386 Mdot
.43781 .59707 Mdot
.93175 .18935 Mdot
.82729 .14787 Mdot
.3753 .16843 Mdot
.6456 .03232 Mdot
.2555 .52173 Mdot
.06291 .20922 Mdot
.62185 .09453 Mdot
.41337 .14955 Mdot
.93297 .18416 Mdot
.95676 .40913 Mdot
.64505 .03144 Mdot
.48824 .59854 Mdot
.40131 .04163 Mdot
.61416 .60148 Mdot
.61442 .08178 Mdot
.09108 .21799 Mdot
.58558 .04583 Mdot
.50399 .60527 Mdot
.46026 .03626 Mdot
.80099 .10355 Mdot
.1461 .27018 Mdot
.28818 .51527 Mdot
.3173 .56268 Mdot
.48079 .59574 Mdot
.98956 .20536 Mdot
.9436 .19477 Mdot
.37082 .12753 Mdot
.95771 .20318 Mdot
.27026 .543 Mdot
.09549 .25361 Mdot
.57785 .00259 Mdot
.79546 .13917 Mdot
.35661 .56586 Mdot
.61627 .59079 Mdot
.11606 .44471 Mdot
.5115 .50209 Mdot
.36815 .52643 Mdot
.27574 .54493 Mdot
.35823 .21526 Mdot
.3561 .21942 Mdot
.10234 .23708 Mdot
.59385 .57197 Mdot
.84013 .13023 Mdot
.06854 .44842 Mdot
.74606 .35106 Mdot
.6375 .09956 Mdot
.13869 .45391 Mdot
.95585 .17435 Mdot
.08977 .24069 Mdot
.93555 .19561 Mdot
.37564 .16783 Mdot
.08815 .23259 Mdot
.73234 .11234 Mdot
.81544 .10825 Mdot
.53671 .02455 Mdot
.46399 .5877 Mdot
.60648 .01535 Mdot
.1564 .48256 Mdot
.7447 .09214 Mdot
.42058 .59303 Mdot
.56762 .01265 Mdot
.60582 .57931 Mdot
.78087 .0911 Mdot
.06657 .44947 Mdot
.35151 .58251 Mdot
.30872 .546 Mdot
.33624 .55486 Mdot
.47078 .01699 Mdot
.27856 .54755 Mdot
.27245 .5313 Mdot
.46219 .12006 Mdot
.67795 .05794 Mdot
.00854 .2059 Mdot
.24075 .28019 Mdot
.5433 .00811 Mdot
.52234 .61724 Mdot
.10409 .2541 Mdot
.49051 .11779 Mdot
.39667 .58005 Mdot
.32741 .27218 Mdot
.5358 .60241 Mdot
.50824 .05299 Mdot
.4121 .59042 Mdot
.26939 .50667 Mdot
.31276 .56541 Mdot
.56892 .5916 Mdot
.60744 .49663 Mdot
.32897 .53111 Mdot
.01366 .43044 Mdot
.20247 .5001 Mdot
.36027 .20231 Mdot
.3332 .27055 Mdot
.00479 .21827 Mdot
.94659 .19471 Mdot
.89472 .39515 Mdot
.58366 .08017 Mdot
.6926 .11965 Mdot
.92515 .1808 Mdot
.24014 .51467 Mdot
.84493 .15441 Mdot
.38598 .52966 Mdot
.99164 .20648 Mdot
.88327 .15884 Mdot
.4341 .1475 Mdot
.59631 .05643 Mdot
.34442 .57313 Mdot
.02388 .22765 Mdot
.03037 .19943 Mdot
.59268 .59832 Mdot
.27772 .51111 Mdot
.75946 .08509 Mdot
.52374 .02681 Mdot
.23201 .4936 Mdot
.53411 .02317 Mdot
.89254 .39286 Mdot
.20878 .50468 Mdot
.47805 .04264 Mdot
.39185 .02216 Mdot
.10309 .25344 Mdot
.609 .58212 Mdot
.72465 .0672 Mdot
.17617 .4703 Mdot
.7943 .37541 Mdot
.99098 .21308 Mdot
.9428 .18787 Mdot
.29923 .52155 Mdot
.91604 .15898 Mdot
.38764 .02756 Mdot
.80791 .13949 Mdot
.47709 .59374 Mdot
.70302 .06733 Mdot
.96692 .19706 Mdot
.98547 .42173 Mdot
.36873 .57166 Mdot
.01185 .43133 Mdot
.10794 .22197 Mdot
.45382 .6036 Mdot
.15173 .25944 Mdot
.79914 .37727 Mdot
.5604 .05755 Mdot
.51078 .57373 Mdot
.55642 .05515 Mdot
.38385 .53032 Mdot
.15732 .27174 Mdot
.51209 .51069 Mdot
.01735 .43385 Mdot
.39098 .01883 Mdot
.27847 .2836 Mdot
.96141 .20521 Mdot
.87893 .39042 Mdot
.0089 .22295 Mdot
.75164 .07945 Mdot
.6362 .09978 Mdot
.11692 .46671 Mdot
.57543 .59454 Mdot
.33186 .1817 Mdot
.88513 .39147 Mdot
.62512 .08549 Mdot
.34939 .51596 Mdot
.23758 .29473 Mdot
.96627 .4143 Mdot
.05119 .2353 Mdot
.07942 .43039 Mdot
.62093 .59909 Mdot
.90009 .39641 Mdot
.7804 .13305 Mdot
.08563 .24861 Mdot
.51477 .51307 Mdot
.79924 .13665 Mdot
.32233 .27603 Mdot
.40866 .59778 Mdot
.31757 .56359 Mdot
.60439 .05949 Mdot
.65873 .07696 Mdot
.5944 .5727 Mdot
.40383 .59616 Mdot
.20541 .28537 Mdot
.85887 .38592 Mdot
.93112 .40236 Mdot
.14309 .26821 Mdot
.30667 .5248 Mdot
.23325 .51535 Mdot
.11119 .25643 Mdot
.49538 .11553 Mdot
.30116 .5397 Mdot
.43141 .60623 Mdot
.28809 .55466 Mdot
.48196 .59525 Mdot
.49279 .00192 Mdot
.69192 .06151 Mdot
.46086 .56811 Mdot
.88394 .17045 Mdot
.34811 .54232 Mdot
.36599 .18407 Mdot
.37375 .58402 Mdot
.33635 .56801 Mdot
.5564 .06955 Mdot
.56163 .01108 Mdot
.91663 .4019 Mdot
.9228 .40093 Mdot
.34936 .5599 Mdot
.27783 .54752 Mdot
.97605 .41767 Mdot
.11081 .2476 Mdot
.99241 .21499 Mdot
.37335 .17313 Mdot
.58576 .00658 Mdot
.97691 .19447 Mdot
.98425 .2036 Mdot
.33288 .1763 Mdot
.33565 .26706 Mdot
.47627 .0937 Mdot
.06961 .21126 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.482681,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002>ooooo`0300000?oooooooooo00Cooooo00Ko0000
ooooooooooooooooo`000?ooool2o`0000[ooooo00<00000ooooooooool01Oooool00`00003o0000
ooooo`1^ooooo`009_oooomco`00000300000?l0003o000000go000000<00000o`000?l00000Jol0
0009ooooo`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool02?ooool2o`0000Gooooo0_l00004ooooo`;o00001oooool00`00003o0000o`000003
o`00000300000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`0^ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0J_ooool3o`00
00Gooooo0_l000000oooool00000o`000002o`00000300000?oooooooooo00Cooooo1_l000000`00
003oooooooooo`03ooooo`800000Goooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`1]ooooo`;o00001Oooool02Ol000000000oooooooooooo0000ooooool0003ooooo0000
0009ooooo`?o00001Oooool2o`00000300000?oooooooooo05[ooooo00?o0000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0FOooool7o`00013ooooo00?o0000ooooooooool00oooool2
o`0000Gooooo00Co0000oooooooooooo00001?ooool01?l000000000o`000?ooool3o`0000Gooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`1Iooooo`?o000000?ooooo00000?l000000ol000000ooooooo0000ooooo`0<ooooo`;o00001_oo
ool3o`000003ooooool0003o000000?o000000<00000o`000?ooool01_ooool3o`0000Gooooo0_l0
001Hooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05Wooooo0_l00000
0`00003oooooooooo`05ooooo`?o000000<00000ooooooooool02_ooool3o`0000Gooooo00Co0000
oooooooooooooooo0ol000001?oooooo0000ooooool00004ooooo`03o`000?oooooo000000;o0000
00?oooooo`000?ooool00oooool3o`0005Gooooo00?o0000ooooooooool01oooool002Kooooo0_l0
001Kooooo`;o00002_ooool3o`000003ooooool0003ooooo00Wooooo0_l00007ooooo`;o00000_oo
ool01000003o0000o`000?l00007ooooo`;o000000Coooooo`000?l0003o00001?ooool2o`0005?o
oooo0_l00009ooooo`009_ooool00ol0003oooooooooo`1Kooooo`0300000?l0003o000000cooooo
1?l00009ooooo`03o`000?oooooo000000Kooooo0_l000002?oooooo0000o`000000003o00000000
0?ooool000001Oooool01ol0003oooooo`000?l000000000o`00000000000oooool3o`00057ooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0G?ooool3o`0000kooooo00@0
0000o`000?l0003o00002?ooool01?l0003oooooo`000?l00006ooooo`;o000000Goooooo`000?l0
003o000000000008ooooo`03o`000?oooooo000000?o00000oooool2o`00000300000?l0003ooooo
04gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0G_ooool2o`00013o
oooo00?o000000000?l000002Oooool2o`00000300000?oooooooooo00Cooooo0_l00002ooooo`;o
000000@00000ooooooooool000001_ooool01?l0003oooooooooool00006ooooo`;o0000C?ooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Oooooo`0300000?l0003ooooo
017ooooo00<00000o`000?l000002?ooool3o`0000Kooooo00@00000ooooool0003ooooo0_l0000=
ooooo`0400000?l0003o0000000000;ooooo0_l0001;ooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo067ooooo00<00000ooooooooool04_ooool2o`0000[ooooo0_l00005
ooooo`04o`000?oooooo0000ooooo`Co00001oooool01@00003o000000000?ooool0000000?o0000
0oooool2o`00000300000?oooooooooo04Gooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0H_ooool2o`0001Gooooo00<00000ooooooooool01oooool2o`0000Kooooo1_l0
0002ooooo`03o`000?oooooooooo00Gooooo0_l00002ooooo`;o00001Oooool2o`0004Gooooo00?o
0000ooooooooool01oooool002Kooooo0_l0001mooooo`03o`0000000000000000Oooooo00<00000
ooooooooool01Oooool00ol0003oooooo`000004o`000003ooooool0003ooooo00Gooooo00Go0000
00000?oooooooooo00000003o`0000?ooooo0_l00012ooooo`;o00002Oooool002Kooooo00?o0000
ooooooooool0IOooool2o`0001Sooooo00?o0000ooooooooool01Oooool00`00003o0000ooooo`06
ooooo`0300000?l0003o000000;ooooo00Co0000ooooooooool000002?ooool6o`00000300000?oo
oooo000000?o0000@?ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1V
ooooo`?o00006?ooool3o`0000Kooooo0_l00007ooooo`;o000000Koooooo`000?l0003ooooo0000
0?l00007ooooo`;o00000oooool3o`000003ooooool0003o000000800000?_ooool00ol0003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`1Xooooo`0300000?l0003ooooo01Wooooo00?o
0000ooooool000001?ooool3o`0000Sooooo0_l000001?oooooo0000o`000?l00008ooooo`;o0000
0oooool4o`0000;ooooo0_l0000looooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo06[ooooo0_l0000Kooooo`?o00001?ooool2o`0000Sooooo0_l000000ooooooo0000o`00
0005ooooo`03o`000?oooooooooo00;ooooo00@00000o`000?l0003ooooo1Ol000001?oooooo0000
o`000?l0000iooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo06_ooooo
00<00000ooooooooool06oooool3o`00000300000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool3o`000004ooooool0003o0000o`0000Wooooo00Co0000oooooooooooooooo2?l0000goooo
o`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo06gooooo00?o0000oooooooo
ool07Oooool2o`00000300000?oooooooooo00?o00002?ooool2o`000004ooooool0003o0000oooo
o`;o00001oooool2o`0000?ooooo0ol000001@00003o0000o`000?l00000000003Cooooo00?o0000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0K_ooool2o`00023ooooo0_l00002oooo
o`?o00002?ooool01?l000000000ooooooooool4o`0000Sooooo0_l00003ooooo`Ko0000<oooool0
0ol0003oooooooooo`07ooooo`009_ooool2o`00073ooooo0_l0000Qooooo`03o`000?oooooooooo
00;ooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002?ooool2o`00
00?ooooo1_l0000_ooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0LOooool00ol0003o
ooooooooo`0Qooooo`Co000000<00000o`000?ooool02?ooool2o`000004ooooool0003o0000o`00
00Wooooo00?o000000000?ooool00oooool6o`0002kooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0L_ooool00ol0003oooooooooo`0Sooooo`Ko00002?ooool01?l0003o
ooooo`000?ooool2o`00000300000?l0003ooooo00Oooooo0_l00003ooooo`0300000?l0003o0000
00;o000000<00000o`000?ooool0:_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`1cooooo`03o`000?oooooooooo02Cooooo1_l00008ooooo`0400000?l0003o00000000
00Go00001oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l0000Yooooo`03o`000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo07?ooooo0_l0000Xooooo`Go000000<00000oooo
ooooool01oooool3o`00000300000?l0003o000000;ooooo00<00000o`000?ooool01Oooool00`00
003oooooooooo`03ooooo`?o0000:?ooool00ol0003oooooooooo`07ooooo`004oooool2o`0000Co
oooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo07?ooooo0_l0000Zoooo
o`Ko00002?ooool2o`00000400000?l0003o0000ooooo`?o00001oooool2o`0002kooooo00?o0000
ooooooooool01oooool001;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo05gooooo00Ko0000ooooool0003oooooo`000?ooool2o`000006
00000?oooooo0000ooooool0003ooooo0ol000000ooooooo0000ooooo`03o`0002gooooo1Ol0000:
ooooo`Co000000<00000ooooool000000_ooool00ol0003oooooooooo`04ooooo`;o0000:oooool0
0ol0003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00Cooooo0_l0001Iooooo`03o`000?oooooooooo04[ooooo0ol0000;ooooo`?o00000P000002
o`0000;ooooo00?o0000ooooooooool00oooool2o`00000300000?oooooooooo02Cooooo0ol00009
ooooo`004_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0EOooool3o`0005gooooo0ol000001P00003o0000ooooool0003oooooo`0000Sooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`004_ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`1Cooooo`03
00000?l0003ooooo06;ooooo1?l00002ooooo`;o000000?ooooo00000?ooool01?ooool00ol0003o
ooooo`00000Sooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo05;ooooo00<00000oooo
ooooool0I?ooool00`00003o0000ooooo`03o`0000;ooooo00?o0000ooooooooool01_ooool2o`00
027ooooo00?o0000ooooooooool01oooool001?ooooo0_l00009ooooo`?o00001Oooool00ol0003o
ooooooooo`1Aooooo`0300000?oooooooooo06Sooooo0_l000001Ooooooo0000o`000?oooooo0000
00Wooooo0_l0000Oooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool0Joooool01000003o0000ooooo`000002o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0000000000000000Kooooo`03o`000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool03Oooool01@00003o000000000?l0003ooooo
00?o000000Soooooo`000?l0003oooooo`000?oooooo0000ooooo`;o000000?oooooo`000?ooool0
C_ooool01_l000000000o`000?l0003oooooo`0000Cooooo00<00000ooooooooool00_ooool00ol0
003oooooo`00000Iooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool02_ooool3o`00000300000?oooooooooo01;ooooo00<00000oooooooo
ool0C?ooool00ol0003oooooo`000003o`000003ooooool0003ooooo00Sooooo00<00000o`000?l0
00005_ooool00ol0003oooooooooo`07ooooo`009_ooool2o`0004oooooo00?o0000ooooooooool0
2Oooool00`00003o0000ooooo`1Yooooo`03o`000?oooooo000000;o000000Ooooooo`000?oooooo
ooooo`000?oooooo000000Cooooo1?l0000Booooo`;o00002Oooool002Kooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06cooooo00?o000000000?l0
00000_l000000`00003oooooooooo`09ooooo`;o00004_ooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo06oooooo1?l000001?oooooo0000
o`000?l0000:ooooo`0300000?l00000000000kooooo00?o0000ooooooooool01oooool002Kooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Gooooo
1Ol0000:ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool01oooool002Kooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`06ooooo`;o0000NOooool01?l0003oooooo`00
0?l00002ooooo`;o00002?ooool01?l0003oooooo`000?l00008ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01Oooool2o`0007cooooo
1Ol00006ooooo`03o`000?oooooooooo00?ooooo1?l00005ooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool01Oooool2o`0007kooooo1Ol0
00001?oooooo0000o`000?l00009ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool002Kooooo0_l0001=ooooo`0300000?oooooooooo00Kooooo00?o0000ooooooooool0Oooo
ool2o`000005ooooool0003o0000o`000?ooool00_l0000:ooooo`0400000?oooooo0000o`0000Wo
oooo000Vooooo`;o0000COooool00ol0003oooooooooo`05ooooo`;o0000Q?ooool2o`0000060000
0?l0003oooooooooool0000000002oooool00ol0003oooooooooo`07ooooo`009_ooool01_l0003o
ooooooooool0003oooooo`0004Wooooo00<00000ooooooooool01Oooool00ol0003oooooooooo`26
ooooo`0500000?l0003o0000o`00000000000_ooool01@00003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool01?ooool2o`0004Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`28ooooo`0300000?l0003o000000;o000000Co
ooooo`000?ooool000000oooool00ol0003oooooo`000009ooooo`009_ooool00ol0003ooooooooo
o`07ooooo`0300000?oooooo000004;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2:ooooo`03o`000000003o000000;o00000oooool01Ol0003ooooooooooooooooo000000Wooooo
000Vooooo`03o`000?oooooo000000[ooooo0ol0000oooooo`03o`000?oooooooooo09Gooooo1?l0
00001P00003oooooooooool0003oooooo`0000Wooooo000Vooooo`03o`000?oooooooooo00kooooo
0_l0000kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
o`000003o`000003ooooool0003ooooo00Sooooo000Vooooo`0600000?l0003oooooo`000?oooooo
00003?ooool2000000?o0000=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Co
oooo1?l00009ooooo`009_ooool4o`0000;ooooo00?o0000ooooool000003Oooool4o`0003Cooooo
00?o0000ooooooooool01?ooool2o`0009Sooooo00<00000o`000?ooool02?ooool002Kooooo1_l0
000:ooooo`03o`000?oooooooooo00Oooooo00Co000000000?l000000000=oooool2o`0009Wooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool00_ooool00`00003o0000o`00
0002o`0000;ooooo0ol00002ooooo`0300000?oooooooooo00[ooooo00?o0000ooooooooool00_l0
000Zooooo`;o00001_ooool2o`0009Wooooo00?o0000ooooooooool01oooool002Kooooo00?o0000
ooooooooool01?ooool5o`0000;ooooo00?o0000ooooool000000oooool00`00003o0000ooooo`0<
ooooo`03o`000000003o000000;o00009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooooooool01oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo
00?ooooo0ol00004ooooo`03o`000?oooooooooo00Oooooo0ol000000`00003o0000ooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool7o`00000300000?oooooooooo
01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo
00Oooooo000Booooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`Go00000oooool2o`0001Sooooo00Oo0000ooooooooool00000o`000000
003o000001Kooooo00?o0000ooooooooool01Oooool2o`0009[ooooo00?o0000ooooooooool01ooo
ool001;ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo00?o0000ooooooooool03?oo
ool6o`0000;ooooo0ol00005ooooo`03o`000?oooooooooo03;ooooo00?o000000000?ooool0VOoo
ool00ol0003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000Gooooo0_l0000Aooooo`Co00001?ooool00ol0003oooooo`000006ooooo`03o`00
0?oooooooooo02Cooooo00<00000ooooooooool01_ooool00ol0003oooooooooo`2Gooooo`?o0000
2Oooool001;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo01;ooooo1_l00003ooooo`03o`000000003ooooo00Cooooo00@00000oooooooooooo
00008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo09[ooooo00?o0000oooooooo
ool01oooool001;ooooo00Co0000oooooooooooo00002Oooool2o`0000Gooooo00?o0000oooooooo
ool05?ooool6o`0000?ooooo00@00000ooooool0000000001Oooool01?l0003oooooo`000?l0000L
ooooo`03o`000?oooooooooo00Kooooo0_l0002Looooo`03o`000?oooooooooo00Oooooo000Coooo
o`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo1?l00004oooo
o`Co00002?ooool2o`0001Cooooo00?o0000ooooooooool02?ooool3o`0009cooooo00?o0000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool06oooool5o`0000Kooooo0ol0000;ooooo`?o
00000_ooool00ol0003oooooooooo`04ooooo`;o00003?ooool2o`0009gooooo00?o0000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool07_ooool5o`0000Kooooo00Co0000ooooooooool0
00007oooool2o`0009oooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
8Oooool6o`0000Oooooo0_l000000ooooooo0000ooooo`0Gooooo`80000000?o0000ooooooooool0
W_ooool00ol0003oooooooooo`07ooooo`009_ooool2o`0002Kooooo1_l00007ooooo`?o000000?o
ooooo`000?ooool03oooool01?l000000000o`000?l0002Qooooo`;o00002Oooool002Kooooo00?o
0000ooooooooool0:?ooool00ol000000000o`000002o`0000[ooooo00?o000000000?l000003_l0
002Uooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo02cooooo1?l00000
0`00003oooooooooo`2jooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
033ooooo1_l0002gooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo03Co
oooo00<00000o`000?l000000_l000000`00003oooooooooo`2aooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo03Wooooo00<00000ooooool00000/Oooool00ol0003ooooo
ooooo`07ooooo`001oooool3o`0001cooooo00?o0000ooooooooool0kOooool00ol0003ooooooooo
o`07ooooo`002?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0>gooooo00?o0000
ooooooooool01oooool000Sooooo00?o0000ooooooooool06oooool2o`000>gooooo0_l00009oooo
o`002?ooool2o`0001cooooo00?o0000ooooooooool0kOooool00ol0003oooooooooo`07ooooo`00
1oooool2o`000003ooooool0003o000001[ooooo00?o0000ooooooooool0kOooool00ol0003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03o`000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0kOooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03
o`000?oooooooooo00Oooooo000Vooooo`;o0000kOooool2o`0000Wooooo000Vooooo`03o`000?oo
oooooooo0>gooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool0
0ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2Yooooo`;o00000_ooool02Ol0
003oooooooooool000000000ooooool0003oooooo`000004ooooo`0300000?l0003ooooo033ooooo
00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Yoooool00`00003o0000oooo
o`0Booooo`05o`000?ooooooooooooooool00000;?ooool00ol0003oooooooooo`07ooooo`004ooo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000ooooooooool0YOoo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo0:?ooooo
0_l0000Sooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool001;ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool0X_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`00
0?ooooooooooo`0000Oooooo1?l00005ooooo`;o0000Xoooool00`00003oooooooooo`0Dooooo`03
o`000?oooooo000000?o0000;?ooool3o`0000Wooooo000Booooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2hoooooa3o00002Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo01oo
oooo3?l00007ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool001?ooooo
0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooool000001?l000000`00003o0000o`00000Kooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0:_ooool9o`0000Gooooo00?o
000000000?ooool03oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3C
ooooo`Co000000<00000ooooooooool04oooool00ol0003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`2Oooooo`0300000?oooooooooo03Cooooo1_l0000Aooooo`03o`000?oooooooooo
00Oooooo000Vooooo`;o0000f_ooool7o`0000Cooooo00?o0000ooooooooool01Oooool2o`0000Wo
oooo000Vooooo`03o`000?oooooooooo09oooooo00<00000ooooooooool0>oooool5o`000003oooo
ool0003ooooo00?ooooo00<00000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo03gooooo1_l00004ooooo`0500000?oo
ooooooooooooool000002Oooool002Kooooo00?o0000ooooooooool0hoooool5o`00000300000?l0
003ooooo00;ooooo00?o0000ooooooooool01oooool002Kooooo00Co0000oooooooooooo00002?oo
ool2o`000=cooooo1Ol000000ooooooo0000ooooo`08ooooo`009_ooool2o`0000?ooooo00?o0000
ooooooooool01_ooool3o`000=_ooooo1Ol00009ooooo`009_ooool4o`0000?ooooo0_l00008oooo
o`;o0000g?ooool2o`0000Wooooo000Vooooo`;o000000<00000o`000?l000000ol00002ooooo`03
o`000?oooooooooo00Kooooo00?o000000000?l00000fOooool2o`0000Wooooo000Vooooo`03o`00
0?oooooooooo00;ooooo1_l0000:ooooo`0300000?l0003o00000=Sooooo00?o0000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool01_ooool4o`0000[ooooo00Co000000000?l0003o0000
QOooool00ol000000000ooooo`1=ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooool000000ol0000:ooooo`0400000?l0003o0000o`0008;ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`0:ooooo`0300000?l0003o000000;o00002oooool3o`00083ooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0=ooooo`Go00002_ooool3
o`0007kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`0@ooooo`0300000?l0003o000000?o00000_ooool00ol0003oooooooooo`03oooo
o`Co0000boooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Booooo`Go
00002_ooool2o`0000800000Moooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Oo
oooo000Vooooo`;o00005_ooool5o`0000[ooooo0ol0001eooooo`03o`000?oooooooooo04gooooo
0_l00009ooooo`009_ooool00ol0003oooooooooo`0Hooooo`Co000000<00000ooooooooool01ooo
ool3o`0007;ooooo00<00000ooooooooool0Coooool00ol0003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`0Kooooo`0400000?l0003o0000o`0000Wooooo1?l00031ooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo01gooooo1?l00009ooooo`Go0000Joooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
01oooooo1Ol000000`00003oooooooooo`06ooooo`Co0000Ioooool2o`0005?ooooo00?o0000oooo
ooooool01oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo02;ooooo00Co0000ooooool0003o00000_ooool00ol0003oooooooooo`04oooo
o`?o00000P00001Rooooo`0300000?l0003ooooo05Cooooo00?o0000ooooooooool01oooool001;o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool09Oooool4o`0000Wooooo00@00000o`000?l0003o0000G_ooool2o`0005Oooooo00?o
0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Cooooo0_l0000Xooooo`Go00002Oooool2o`00000300000?oooooooooo05Gooooo
00Co0000ooooool0003o0000F?ooool3o`0000Wooooo000Booooo`04o`000?ooooooooooo`0000So
oooo0ol00005ooooo`03o`000?oooooooooo02[ooooo00Go0000ooooool000000000o`000007oooo
o`03o`000000003o000000;o0000?Oooool4o`00000300000?l0003o000000Go000000D00000o`00
0?ooooooooooo`000002ooooo`;o000000<00000ooooool00000GOooool00ol0003oooooooooo`07
ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`0/ooooo`Go000000Coooooo`000?oooooo00001?ooool4o`0003[ooooo
0_l0001dooooo`03o`000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02oooooo00<00000o`000?l0
00000_l00007ooooo`Go0000=oooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Oo
oooo000Cooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0<Oooool00ol000000000
o`000003o`000003ooooool0003ooooo00Cooooo1?l0000=ooooo`03o`000?oooooooooo02Kooooo
0_l0001cooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo03?ooooo1Ol0
0003ooooo`0300000?oooooooooo00;ooooo00D00000o`000?l0003o00000000000:ooooo`040000
0?l0003o0000o`0002Kooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`0fooooo`Go00001oooool4o`0000_ooooo1Ol0000Tooooo`03o`00
0?oooooooooo073ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0>Ooo
ool5o`000003ooooool0003o000000Cooooo1?l0000:ooooo`Co000000?ooooo00000?ooool08Ooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00Oooooo000Vooooo`;o0000??ooool2
o`00000300000?l0003ooooo00;ooooo00<00000ooooooooool00oooool3o`0000[ooooo1_l0000Q
ooooo`;o0000K_ooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo03gooooo1Ol00008oooo
o`?o00002oooool00`00003o0000o`000002o`00000300000?oooooooooo01kooooo00<00000oooo
ooooool0K?ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0iooooo`;o
00001_ooool3o`00000300000?oooooooooo00Gooooo1?l0000:ooooo`;o000000Goooooo`000?l0
00000000o`00000Nooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0>_ooool4o`0000Gooooo1?l00008ooooo`Co00002_ooool00ol0003o
oooo00000003o`0001gooooo0_l0001[ooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo03cooooo1?l00005ooooo`Go00001oooool4o`0000Wooooo00?o000000000?l00000
0_ooool3o`0001cooooo00<00000o`000?ooool0J?ooool00ol0003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`0nooooo`Go00001Oooool3o`00000400000?ooooooooooo`0000Cooooo
1?l0000:ooooo`;o00000_ooool4o`0001[ooooo0_l0001Xooooo`03o`000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo043ooooo1_l00003ooooo`Co000000<00000ooooooooool01_oo
ool3o`0000Wooooo0ol00004ooooo`;o00006_ooool00ol0003oooooooooo`1Uooooo`03o`000?oo
oooooooo00Oooooo000Vooooo`;o0000@oooool6o`0000Cooooo00<00000o`000?l000000_l00007
ooooo`;o000000?ooooo00000?l000002?ooool2o`0000Cooooo00?o000000000?l000006?ooool0
0ol000000000ooooo`1Sooooo`;o00002Oooool002Kooooo00?o0000ooooooooool0AOooool2o`00
000400000?l0003o0000o`0000?ooooo00<00000o`000?l000000_l00007ooooo`0300000?l0003o
000000;o00002?ooool2o`0000Gooooo0_l000000ooooooo0000ooooo`0Eooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Aoooool6o`00
00Cooooo0ol000000oooool00000ooooo`06ooooo`?o000000<00000ooooooooool01_ooool2o`00
00Kooooo0ol0000Eooooo`;o0000H_ooool00ol0003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`1:ooooo`;o000000?oooooo`000?l000000_l00003ooooo`Co000000?ooooo00000?oo
ool00oooool6o`0000Sooooo0_l00006ooooo`?o00005?ooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04gooooo0_l000001?oooooo0000
o`000?l00002ooooo`Co000000?oooooo`000?l000001Oooool01@00003o0000ooooool000000000
00Sooooo0_l00006ooooo`03o`000000003o000001?ooooo0_l0001Oooooo`03o`000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo04kooooo0ol000000ooooooo0000o`000002o`0000;o
oooo00?o000000000?l000000_l00002ooooo`03o`000?oooooooooo00;ooooo1Ol00007ooooo`;o
00001oooool00`00003oooooo`00000Aooooo`0300000?l0003o000005gooooo00?o0000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0DOooool2o`0000;ooooo0ol00002ooooo`Go0000
1oooool01?l0003oooooo`000?l00008ooooo`;o00002Oooool2o`0000oooooo0_l0001Mooooo`03
o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05?ooooo00Co000000000?l0003o
oooo0ol00003ooooo`?o000000<00000ooooool000001Oooool01Ol000000000o`000000003o0000
00Oooooo0`000008ooooo`?o000000<00000ooooooooool02_ooool3o`0005_ooooo00?o0000oooo
ooooool01oooool002Kooooo0_l0001Fooooo`;o00001?ooool01?l0003oooooooooooooool3o`00
0003ooooool0003ooooo00Oooooo0ol000000`00003oooooooooo`04ooooo`;o00002_ooool5o`00
00Wooooo00<00000o`000?ooool0FOooool2o`0000Wooooo000Vooooo`03o`000?oooooooooo05Oo
oooo0_l00003ooooo`?o00000oooool2o`00008000001oooool5o`0000Kooooo00?o0000ooooool0
00002oooool5o`0000Oooooo0_l0001Iooooo`03o`000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo05[ooooo0_l00003ooooo`?o00000_ooool3o`000003ooooool0003ooooo00Gooooo
1_l00006ooooo`03o`000000003o000000_ooooo1ol000001?ooool00000o`000?l0001Iooooo`03
o`000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05cooooo00?o000000000?ooool0
0_ooool01?l0003oooooo`000?l00002ooooo`Co00001oooool01000003o0000o`000?l00006oooo
o`Co00003_ooool4o`00000300000?l0003ooooo05Sooooo00?o0000ooooooooool01oooool001ko
oooo0ol00005ooooo`03o`000?oooooooooo05kooooo0ol00003ooooo`;o000000<00000ooooo`00
00000ol000000`00003o0000ooooo`05ooooo`?o000000<00000o`00000000001Oooool3o`0006_o
oooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo02gooooo00Go0000oooooooooooo000000000004ooooo`?o
00000_ooool4o`0000;ooooo00<00000ooooooooool00_ooool2o`000003ooooool00000000000Oo
oooo00?o000000000?l000002?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool3o`0000Cooooo
0_l00002ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`02ooooo`?o0000
1?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oo
oooooooo00CoooooK_l000000`00003o0000o`000020o`0000Wooooo000Oooooo`03o`000?oooooo
oooo0?kooooo000Nooooo`;o0000ooooool1ooooo`007oooool00ol0003oooooooooo`3nooooo`00
oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.158908, -0.161707, \
0.00416367, 0.00673696}}]
}, Closed]],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
To run the animation, select the plots and choose Animate Selected \
Graphics from the Cell menu.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Single Trajectory", "Section"],

Cell[TextData[{
  "Plotting a single trajectory is very simple.  The procedure is identical \
to that used to create the surface of section, but with only a single initial \
point used.  In the example below we use the initial point {0.5,0.0001} and \
plot the results of iterating the map 10000 times.  The value of K used is \
actually larger than the critical value for the breakup of the Golden Torus \
(",
  Cell[BoxData[
      \(TraditionalForm\`\(K\^*\)\)]],
  "= 0.9716354).  However, the diffusion of trajectories in r is still slowed \
by cantori (broken KAM tori), which results in the appearance of boundaries \
to the motion.  If a larger number of points were used we would see that some \
trajectories do diffuse through these boundaries (for example, try using ",
  StyleBox["n=100000", "Input"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(K = 1.13; \[Theta]0 = 0.5; r0 = 0.0001; n = 10000;\), "\n", 
    \(\(f[{\[Theta]_, r_}] := 
        N[{Mod[\[Theta] + r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1], 
            Mod[r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1]}];\)\), "\n", 
    \(\(MapData\  = \ NestList[f, {\[Theta]0, r0}, n];\)\), "\n", 
    \(ListPlot[MapData, PlotStyle \[Rule] PointSize[0.002], 
      PlotRange \[Rule] {{0, 1}, {0, 1}}, Frame \[Rule] True, 
      RotateLabel \[Rule] False, 
      FrameLabel \[Rule] {"\<\[Theta]\>", "\<r\>", "\<\>", "\<\>"}]\)}], \
"Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.5 6e-05 Mdot
.5001 6e-05 Mdot
.50031 .00013 Mdot
.50088 .00035 Mdot
.50244 .00096 Mdot
.50676 .00267 Mdot
.51871 .00739 Mdot
.55176 .02043 Mdot
.64228 .05594 Mdot
.87299 .14259 Mdot
.23247 .22217 Mdot
.41319 .11169 Mdot
.50061 .05403 Mdot
.58873 .05446 Mdot
.772 .11327 Mdot
.1334 .22336 Mdot
.3611 .14072 Mdot
.45102 .05557 Mdot
.48646 .0219 Mdot
.50661 .01245 Mdot
.53422 .01707 Mdot
.60021 .04078 Mdot
.77211 .10624 Mdot
.12211 .21632 Mdot
.34728 .13916 Mdot
.42516 .04813 Mdot
.42155 .6158 Mdot
.33284 .56321 Mdot
.08811 .46678 Mdot
.74882 .40834 Mdot
.58937 .51949 Mdot
.52569 .57868 Mdot
.4909 .59654 Mdot
.44584 .59018 Mdot
.34075 .55309 Mdot
.08427 .45952 Mdot
.73695 .40338 Mdot
.56888 .51416 Mdot
.47622 .56077 Mdot
.35679 .54422 Mdot
.0965 .45717 Mdot
.73373 .39383 Mdot
.54986 .5044 Mdot
.42142 .53865 Mdot
.20774 .48597 Mdot
.82052 .37872 Mdot
.59578 .47914 Mdot
.47285 .54206 Mdot
.31938 .52319 Mdot
.00289 .42243 Mdot
.68313 .42041 Mdot
.52758 .5219 Mdot
.40304 .54106 Mdot
.1756 .47746 Mdot
.7876 .37824 Mdot
.57445 .4863 Mdot
.44241 .53642 Mdot
.24669 .49707 Mdot
.87116 .38595 Mdot
.62584 .46641 Mdot
.50835 .54542 Mdot
.40028 .55125 Mdot
.18677 .48608 Mdot
.80742 .38358 Mdot
.59634 .48758 Mdot
.48759 .55082 Mdot
.36482 .54216 Mdot
.10702 .4587 Mdot
.73719 .38947 Mdot
.54663 .50026 Mdot
.40802 .53236 Mdot
.17115 .47164 Mdot
.77607 .37386 Mdot
.55842 .48352 Mdot
.4053 .52341 Mdot
.15139 .46111 Mdot
.75106 .37062 Mdot
.53057 .48176 Mdot
.34442 .50298 Mdot
.00915 .41083 Mdot
.66355 .40444 Mdot
.4719 .49959 Mdot
.24868 .48007 Mdot
.84561 .36893 Mdot
.5909 .46062 Mdot
.43342 .5207 Mdot
.20287 .47555 Mdot
.80031 .36924 Mdot
.56868 .47488 Mdot
.41227 .52137 Mdot
.16168 .46316 Mdot
.75823 .36869 Mdot
.53438 .47969 Mdot
.34908 .50351 Mdot
.01768 .41322 Mdot
.66634 .40089 Mdot
.47057 .49704 Mdot
.24172 .4766 Mdot
.83327 .3656 Mdot
.58061 .46188 Mdot
.41519 .5158 Mdot
.15842 .45934 Mdot
.75076 .36609 Mdot
.52294 .47724 Mdot
.32096 .4932 Mdot
.95671 .39292 Mdot
.64078 .42278 Mdot
.46398 .50877 Mdot
.24683 .48382 Mdot
.84986 .3727 Mdot
.59849 .46268 Mdot
.45143 .52715 Mdot
.25035 .49376 Mdot
.86942 .38261 Mdot
.62004 .46391 Mdot
.49381 .54002 Mdot
.36058 .53569 Mdot
.08919 .45031 Mdot
.72221 .39123 Mdot
.53234 .50069 Mdot
.37877 .52312 Mdot
.10108 .44641 Mdot
.7167 .38047 Mdot
.50823 .48919 Mdot
.30906 .49494 Mdot
.94228 .39135 Mdot
.63931 .43079 Mdot
.4744 .51612 Mdot
.2807 .49832 Mdot
.91049 .38923 Mdot
.63618 .4485 Mdot
.49764 .53241 Mdot
.35645 .53077 Mdot
.07415 .44357 Mdot
.71107 .39363 Mdot
.52247 .50147 Mdot
.35917 .51711 Mdot
.05671 .4311 Mdot
.69151 .39233 Mdot
.49415 .49606 Mdot
.29019 .49198 Mdot
.91208 .38435 Mdot
.62835 .44268 Mdot
.47443 .52291 Mdot
.29173 .50512 Mdot
.93534 .39777 Mdot
.65002 .4417 Mdot
.51021 .53163 Mdot
.38193 .53875 Mdot
.13215 .46366 Mdot
.74961 .38161 Mdot
.54692 .49276 Mdot
.39647 .52506 Mdot
.13713 .45775 Mdot
.7413 .3734 Mdot
.52504 .48438 Mdot
.33697 .5018 Mdot
.99525 .40684 Mdot
.65889 .41015 Mdot
.47371 .50358 Mdot
.25896 .48531 Mdot
.86464 .37433 Mdot
.6055 .45787 Mdot
.45703 .52627 Mdot
.26058 .49662 Mdot
.88469 .38572 Mdot
.62799 .45939 Mdot
.50084 .53945 Mdot
.37463 .54003 Mdot
.12095 .46125 Mdot
.74338 .38468 Mdot
.5455 .49574 Mdot
.39834 .52708 Mdot
.14395 .46082 Mdot
.74819 .37344 Mdot
.53226 .48458 Mdot
.35254 .50696 Mdot
.02902 .41809 Mdot
.67289 .39793 Mdot
.47591 .49629 Mdot
.25181 .47953 Mdot
.84788 .36839 Mdot
.59084 .45918 Mdot
.43096 .51923 Mdot
.1955 .47251 Mdot
.79064 .36781 Mdot
.55979 .47536 Mdot
.39492 .51614 Mdot
.11975 .44797 Mdot
.72167 .37201 Mdot
.5006 .4814 Mdot
.28021 .48182 Mdot
.8832 .37267 Mdot
.60665 .44711 Mdot
.44178 .51614 Mdot
.21258 .47638 Mdot
.80849 .36829 Mdot
.57223 .47202 Mdot
.41482 .52075 Mdot
.16569 .46406 Mdot
.76137 .36815 Mdot
.53643 .47901 Mdot
.35229 .50423 Mdot
.02419 .41526 Mdot
.66886 .39843 Mdot
.47051 .49545 Mdot
.23902 .47497 Mdot
.82811 .36408 Mdot
.57582 .46211 Mdot
.40601 .51308 Mdot
.13605 .45119 Mdot
.73041 .36733 Mdot
.50325 .47764 Mdot
.27976 .47991 Mdot
.87955 .3707 Mdot
.60283 .44701 Mdot
.43439 .51393 Mdot
.19389 .4694 Mdot
.78461 .36508 Mdot
.55094 .47362 Mdot
.37385 .50859 Mdot
.06867 .42942 Mdot
.68828 .38294 Mdot
.47438 .48584 Mdot
.23166 .46802 Mdot
.81029 .35761 Mdot
.55601 .46088 Mdot
.36372 .49919 Mdot
.03558 .41523 Mdot
.66757 .39059 Mdot
.45581 .48716 Mdot
.19476 .4567 Mdot
.76459 .35217 Mdot
.51351 .46286 Mdot
.27767 .47228 Mdot
.8647 .36281 Mdot
.58686 .44632 Mdot
.40237 .50401 Mdot
.11434 .44002 Mdot
.70794 .36686 Mdot
.47514 .47416 Mdot
.21436 .45687 Mdot
.77823 .34849 Mdot
.51912 .4579 Mdot
.28157 .47122 Mdot
.8677 .36225 Mdot
.58669 .44436 Mdot
.39888 .50196 Mdot
.10434 .436 Mdot
.70016 .36824 Mdot
.46708 .47398 Mdot
.19706 .45115 Mdot
.75706 .3461 Mdot
.49672 .45714 Mdot
.23268 .45485 Mdot
.78985 .34435 Mdot
.52126 .45204 Mdot
.27663 .46684 Mdot
.85467 .35725 Mdot
.57504 .44521 Mdot
.3771 .4957 Mdot
.05368 .41815 Mdot
.67074 .38137 Mdot
.44581 .47902 Mdot
.16082 .4419 Mdot
.72349 .34775 Mdot
.46351 .45736 Mdot
.16266 .4321 Mdot
.70838 .33727 Mdot
.42782 .44464 Mdot
.06846 .39594 Mdot
.6341 .34959 Mdot
.33399 .43255 Mdot
.87849 .33652 Mdot
.54734 .41337 Mdot
.2689 .44595 Mdot
.81189 .33558 Mdot
.52129 .43844 Mdot
.25468 .45326 Mdot
.80831 .34216 Mdot
.52984 .44593 Mdot
.2849 .46665 Mdot
.86442 .35816 Mdot
.57928 .44181 Mdot
.38006 .49491 Mdot
.05777 .41885 Mdot
.67163 .37938 Mdot
.44396 .47733 Mdot
.15428 .439 Mdot
.7163 .34735 Mdot
.45416 .45602 Mdot
.14093 .42445 Mdot
.68846 .33839 Mdot
.40256 .44134 Mdot
.01331 .37746 Mdot
.60903 .36818 Mdot
.31855 .43851 Mdot
.86465 .33751 Mdot
.54591 .42105 Mdot
.27834 .45267 Mdot
.83377 .34327 Mdot
.5447 .43938 Mdot
.30548 .47019 Mdot
.89724 .36573 Mdot
.59721 .43261 Mdot
.40033 .49636 Mdot
.09805 .43121 Mdot
.69185 .36699 Mdot
.45361 .4708 Mdot
.1637 .43886 Mdot
.71975 .34365 Mdot
.45239 .4528 Mdot
.13204 .42005 Mdot
.67902 .33805 Mdot
.38825 .43833 Mdot
.98133 .36654 Mdot
.59546 .37955 Mdot
.3111 .44229 Mdot
.85999 .33923 Mdot
.54746 .42488 Mdot
.28777 .45753 Mdot
.85327 .3495 Mdot
.56207 .43806 Mdot
.33923 .48032 Mdot
.96409 .38618 Mdot
.62918 .41105 Mdot
.42474 .49168 Mdot
.13839 .44106 Mdot
.71463 .35614 Mdot
.4663 .46455 Mdot
.18017 .44119 Mdot
.73122 .34057 Mdot
.46088 .45095 Mdot
.14677 .4239 Mdot
.68934 .33533 Mdot
.39884 .4385 Mdot
.00158 .37251 Mdot
.60254 .37141 Mdot
.3115 .43817 Mdot
.85388 .33521 Mdot
.53914 .42351 Mdot
.26818 .45057 Mdot
.81855 .34015 Mdot
.53234 .44115 Mdot
.28243 .46358 Mdot
.85638 .35473 Mdot
.57148 .44196 Mdot
.36467 .49022 Mdot
.02271 .40669 Mdot
.65517 .39088 Mdot
.43649 .48288 Mdot
.14794 .4397 Mdot
.71527 .35063 Mdot
.45818 .45914 Mdot
.15437 .43027 Mdot
.70221 .33859 Mdot
.42186 .44477 Mdot
.05672 .39236 Mdot
.62883 .35359 Mdot
.33114 .43405 Mdot
.87646 .33703 Mdot
.54779 .4149 Mdot
.2723 .44777 Mdot
.81873 .33771 Mdot
.5285 .43866 Mdot
.2703 .45846 Mdot
.83371 .34821 Mdot
.55266 .44434 Mdot
.33004 .48044 Mdot
.94983 .38306 Mdot
.62538 .41751 Mdot
.42841 .4963 Mdot
.15324 .44797 Mdot
.73046 .35674 Mdot
.48616 .46705 Mdot
.22624 .45739 Mdot
.78847 .34748 Mdot
.52532 .4554 Mdot
.29067 .47301 Mdot
.882 .36547 Mdot
.59479 .44053 Mdot
.40848 .50289 Mdot
.12435 .44243 Mdot
.71357 .36416 Mdot
.47795 .47241 Mdot
.21749 .45706 Mdot
.78093 .34822 Mdot
.52082 .45728 Mdot
.28417 .47178 Mdot
.87181 .36318 Mdot
.58914 .44333 Mdot
.40202 .50239 Mdot
.11104 .4382 Mdot
.70452 .36679 Mdot
.47055 .47343 Mdot
.2035 .45299 Mdot
.76422 .34655 Mdot
.50407 .45725 Mdot
.24852 .4601 Mdot
.81314 .34895 Mdot
.54363 .45147 Mdot
.32281 .48156 Mdot
.94063 .38184 Mdot
.624 .42234 Mdot
.43373 .50044 Mdot
.17072 .45549 Mdot
.74972 .35784 Mdot
.50857 .46899 Mdot
.2771 .47498 Mdot
.86838 .36543 Mdot
.59201 .44723 Mdot
.41391 .50797 Mdot
.14321 .45073 Mdot
.73166 .36368 Mdot
.49875 .47409 Mdot
.26443 .47322 Mdot
.851 .36252 Mdot
.5824 .45203 Mdot
.40282 .50704 Mdot
.12011 .44331 Mdot
.7142 .36717 Mdot
.48361 .47552 Mdot
.23452 .46409 Mdot
.80644 .35346 Mdot
.54701 .4577 Mdot
.33994 .49006 Mdot
.98098 .39619 Mdot
.64346 .40944 Mdot
.44698 .4966 Mdot
.19169 .46025 Mdot
.76849 .35648 Mdot
.52392 .46688 Mdot
.30628 .48353 Mdot
.91992 .37925 Mdot
.62028 .43285 Mdot
.44399 .50908 Mdot
.2057 .47076 Mdot
.79449 .36389 Mdot
.55614 .47073 Mdot
.37993 .50913 Mdot
.08054 .433 Mdot
.69398 .37913 Mdot
.47623 .48346 Mdot
.23173 .46692 Mdot
.80857 .3565 Mdot
.55321 .46021 Mdot
.35686 .49669 Mdot
.01971 .40966 Mdot
.66034 .39593 Mdot
.45303 .48991 Mdot
.19341 .45758 Mdot
.76519 .35338 Mdot
.516 .46403 Mdot
.28486 .47518 Mdot
.87818 .36669 Mdot
.5961 .4437 Mdot
.41613 .50681 Mdot
.14571 .4509 Mdot
.73269 .36278 Mdot
.49846 .47327 Mdot
.26249 .4722 Mdot
.84723 .36139 Mdot
.57928 .45243 Mdot
.39727 .50554 Mdot
.10707 .43868 Mdot
.7048 .36942 Mdot
.47517 .47612 Mdot
.2176 .45885 Mdot
.7839 .34999 Mdot
.52598 .45863 Mdot
.29728 .47669 Mdot
.89661 .37041 Mdot
.60473 .43764 Mdot
.42283 .50562 Mdot
.15711 .45381 Mdot
.74132 .36106 Mdot
.5051 .47204 Mdot
.27464 .4756 Mdot
.86649 .36578 Mdot
.59212 .44847 Mdot
.41614 .50927 Mdot
.14972 .45338 Mdot
.73799 .36357 Mdot
.50559 .4744 Mdot
.27951 .47831 Mdot
.87667 .36906 Mdot
.59966 .44683 Mdot
.42804 .51197 Mdot
.17784 .46341 Mdot
.76597 .36348 Mdot
.53304 .47408 Mdot
.33719 .49699 Mdot
.9878 .4021 Mdot
.65219 .41061 Mdot
.46351 .50142 Mdot
.23396 .47616 Mdot
.82547 .36558 Mdot
.57699 .46446 Mdot
.41215 .51616 Mdot
.153 .45787 Mdot
.74638 .36673 Mdot
.51957 .47786 Mdot
.31482 .49149 Mdot
.94493 .38943 Mdot
.63604 .42713 Mdot
.46282 .51098 Mdot
.24797 .48525 Mdot
.85328 .37411 Mdot
.60189 .46266 Mdot
.45792 .52906 Mdot
.26695 .50001 Mdot
.89715 .38949 Mdot
.63565 .45642 Mdot
.50954 .54009 Mdot
.39421 .54676 Mdot
.16795 .4782 Mdot
.78522 .38149 Mdot
.57795 .48993 Mdot
.45528 .54222 Mdot
.28274 .5114 Mdot
.93414 .40259 Mdot
.65786 .44728 Mdot
.53212 .54032 Mdot
.44242 .5626 Mdot
.28907 .52326 Mdot
.96127 .41544 Mdot
.6768 .44222 Mdot
.55349 .54182 Mdot
.48949 .57848 Mdot
.41363 .57115 Mdot
.2449 .51375 Mdot
.89641 .40266 Mdot
.65689 .47 Mdot
.5673 .56267 Mdot
.55151 .60828 Mdot
.59292 .02559 Mdot
.73346 .08686 Mdot
.05288 .19741 Mdot
.31364 .16116 Mdot
.40873 .05877 Mdot
.40626 .6165 Mdot
.30388 .55476 Mdot
.03186 .44992 Mdot
.72408 .42782 Mdot
.59376 .5375 Mdot
.56338 .59926 Mdot
.60274 .02433 Mdot
.7503 .0912 Mdot
.0777 .20235 Mdot
.32075 .15021 Mdot
.40143 .04986 Mdot
.37771 .60337 Mdot
.229 .52613 Mdot
.90202 .41594 Mdot
.67889 .48013 Mdot
.61795 .58037 Mdot
.67842 .03737 Mdot
.90085 .13747 Mdot
.22821 .20232 Mdot
.37741 .09221 Mdot
.40139 .01482 Mdot
.32092 .56831 Mdot
.07818 .46801 Mdot
.7506 .41558 Mdot
.60287 .52673 Mdot
.56345 .59367 Mdot
.59385 .01879 Mdot
.72425 .08059 Mdot
.03214 .19029 Mdot
.30397 .16799 Mdot
.40618 .06317 Mdot
.40841 .00138 Mdot
.31277 .55892 Mdot
.0511 .45631 Mdot
.73267 .42123 Mdot
.59302 .53173 Mdot
.55259 .59305 Mdot
.57053 .01108 Mdot
.66558 .05874 Mdot
.91576 .15462 Mdot
.25675 .21074 Mdot
.41806 .09969 Mdot
.4908 .04496 Mdot
.55316 .03854 Mdot
.67449 .07498 Mdot
.95579 .17386 Mdot
.28641 .20433 Mdot
.44187 .09608 Mdot
.5331 .05638 Mdot
.66145 .07933 Mdot
.94253 .17372 Mdot
.28715 .21298 Mdot
.45679 .10485 Mdot
.57822 .07504 Mdot
.78451 .12749 Mdot
.16643 .23604 Mdot
.39274 .13987 Mdot
.50681 .0705 Mdot
.62858 .07526 Mdot
.88034 .1556 Mdot
.25494 .23151 Mdot
.44977 .12041 Mdot
.58879 .08592 Mdot
.82301 .14476 Mdot
.21848 .24442 Mdot
.43762 .13544 Mdot
.58807 .09298 Mdot
.83305 .1514 Mdot
.23393 .24776 Mdot
.45588 .13718 Mdot
.62862 .10676 Mdot
.9314 .18712 Mdot
.30931 .23356 Mdot
.51973 .13004 Mdot
.75238 .14379 Mdot
.16486 .25492 Mdot
.42261 .1593 Mdot
.59633 .10736 Mdot
.87238 .17061 Mdot
.27768 .25048 Mdot
.50584 .14101 Mdot
.74059 .14509 Mdot
.15488 .25604 Mdot
.42049 .16416 Mdot
.59996 .11092 Mdot
.8851 .17622 Mdot
.28909 .24968 Mdot
.51863 .14186 Mdot
.76917 .15484 Mdot
.19825 .26519 Mdot
.45691 .15986 Mdot
.66748 .13014 Mdot
.03425 .22668 Mdot
.36262 .20294 Mdot
.55432 .11848 Mdot
.80621 .15568 Mdot
.22684 .25997 Mdot
.46954 .14999 Mdot
.67801 .12885 Mdot
.04825 .22882 Mdot
.3648 .19564 Mdot
.54629 .11217 Mdot
.77934 .14404 Mdot
.1892 .2533 Mdot
.43217 .15017 Mdot
.6008 .10422 Mdot
.87588 .17 Mdot
.27742 .24817 Mdot
.50178 .13866 Mdot
.72814 .1399 Mdot
.13265 .25 Mdot
.40403 .16772 Mdot
.57342 .10469 Mdot
.82286 .15416 Mdot
.23363 .25387 Mdot
.4655 .14331 Mdot
.6587 .1194 Mdot
.00295 .21276 Mdot
.34387 .2107 Mdot
.53532 .11833 Mdot
.76637 .14279 Mdot
.17631 .25336 Mdot
.42534 .15391 Mdot
.59307 .10366 Mdot
.86007 .16501 Mdot
.26559 .25063 Mdot
.49213 .14001 Mdot
.70979 .13452 Mdot
.10158 .24214 Mdot
.38622 .17592 Mdot
.55297 .10306 Mdot
.77847 .13937 Mdot
.18095 .24875 Mdot
.42025 .14789 Mdot
.57314 .0945 Mdot
.80582 .1438 Mdot
.20739 .24818 Mdot
.43552 .14099 Mdot
.59277 .09718 Mdot
.849 .15836 Mdot
.2514 .24869 Mdot
.47395 .13755 Mdot
.66721 .11944 Mdot
.01652 .21589 Mdot
.3472 .20437 Mdot
.53054 .11331 Mdot
.74817 .13451 Mdot
.14564 .24565 Mdot
.40056 .15755 Mdot
.55028 .09253 Mdot
.75588 .12707 Mdot
.14121 .23814 Mdot
.38709 .15197 Mdot
.51583 .07956 Mdot
.66242 .0906 Mdot
.9623 .18534 Mdot
.30439 .21142 Mdot
.47703 .1067 Mdot
.6238 .09071 Mdot
.89678 .16871 Mdot
.27839 .23585 Mdot
.48301 .12646 Mdot
.66847 .11462 Mdot
.01069 .2115 Mdot
.34084 .20404 Mdot
.51965 .11051 Mdot
.72061 .1242 Mdot
.09835 .23346 Mdot
.3719 .16906 Mdot
.51582 .08895 Mdot
.67759 .09998 Mdot
.00091 .19982 Mdot
.3232 .19919 Mdot
.48434 .09959 Mdot
.62781 .08867 Mdot
.90067 .16864 Mdot
.27863 .23359 Mdot
.47965 .12423 Mdot
.65773 .11006 Mdot
.98626 .20305 Mdot
.3303 .21263 Mdot
.51691 .11533 Mdot
.72258 .12711 Mdot
.10544 .23662 Mdot
.37768 .16825 Mdot
.5249 .09099 Mdot
.70015 .10831 Mdot
.0465 .21405 Mdot
.34104 .18204 Mdot
.48438 .08859 Mdot
.61009 .0777 Mdot
.85053 .1486 Mdot
.23611 .2383 Mdot
.44253 .12757 Mdot
.5854 .0883 Mdot
.82022 .14513 Mdot
.21766 .24563 Mdot
.43896 .13677 Mdot
.59295 .09517 Mdot
.84611 .15646 Mdot
.24731 .24795 Mdot
.46869 .13682 Mdot
.65491 .11509 Mdot
.98981 .20698 Mdot
.33622 .21409 Mdot
.52854 .11886 Mdot
.75294 .13869 Mdot
.15715 .24982 Mdot
.41126 .15705 Mdot
.57022 .09824 Mdot
.80598 .14571 Mdot
.21057 .25005 Mdot
.44081 .14229 Mdot
.60569 .1019 Mdot
.88142 .17041 Mdot
.27909 .24577 Mdot
.4999 .13647 Mdot
.72061 .1364 Mdot
.1181 .24566 Mdot
.39405 .17055 Mdot
.55893 .1019 Mdot
.7889 .14213 Mdot
.19337 .24997 Mdot
.42925 .14579 Mdot
.58781 .09799 Mdot
.84062 .15625 Mdot
.24491 .24986 Mdot
.46944 .13877 Mdot
.65965 .11756 Mdot
.00151 .21128 Mdot
.34166 .21022 Mdot
.53097 .117 Mdot
.75506 .13849 Mdot
.1589 .24959 Mdot
.41156 .15616 Mdot
.56935 .09752 Mdot
.80306 .14444 Mdot
.20671 .24947 Mdot
.43712 .1424 Mdot
.59832 .09963 Mdot
.8637 .16401 Mdot
.26494 .24798 Mdot
.48714 .13732 Mdot
.69481 .12835 Mdot
.07162 .23288 Mdot
.37021 .18454 Mdot
.53785 .10361 Mdot
.74785 .12979 Mdot
.13769 .24093 Mdot
.39063 .15633 Mdot
.52949 .08582 Mdot
.70147 .10629 Mdot
.045 .21231 Mdot
.33836 .1813 Mdot
.47888 .08685 Mdot
.5956 .07214 Mdot
.81397 .13496 Mdot
.19785 .23725 Mdot
.41145 .13202 Mdot
.53009 .07332 Mdot
.68252 .09421 Mdot
.99886 .19551 Mdot
.3165 .19631 Mdot
.46975 .09472 Mdot
.58903 .07372 Mdot
.80375 .13271 Mdot
.18816 .23758 Mdot
.40613 .13471 Mdot
.52406 .07289 Mdot
.66909 .08963 Mdot
.97121 .18672 Mdot
.30569 .20672 Mdot
.47122 .1023 Mdot
.60441 .08231 Mdot
.84729 .15011 Mdot
.23745 .24113 Mdot
.44833 .13033 Mdot
.60183 .09487 Mdot
.86271 .16123 Mdot
.26019 .24566 Mdot
.47819 .13473 Mdot
.67163 .11955 Mdot
.02355 .2175 Mdot
.34895 .20111 Mdot
.52817 .11076 Mdot
.73905 .13033 Mdot
.12935 .24122 Mdot
.38905 .16051 Mdot
.53329 .08915 Mdot
.71488 .11223 Mdot
.07194 .22068 Mdot
.35046 .17213 Mdot
.48377 .0824 Mdot
.59879 .07108 Mdot
.8184 .13573 Mdot
.20151 .23677 Mdot
.41305 .13074 Mdot
.53115 .07299 Mdot
.68423 .09461 Mdot
.00202 .1964 Mdot
.31752 .19499 Mdot
.46913 .0937 Mdot
.58607 .07227 Mdot
.7956 .1295 Mdot
.17765 .23612 Mdot
.39811 .13625 Mdot
.51115 .06986 Mdot
.63677 .07764 Mdot
.89861 .16183 Mdot
.26743 .22794 Mdot
.45748 .11746 Mdot
.60004 .08811 Mdot
.84836 .15347 Mdot
.24326 .24406 Mdot
.45847 .13301 Mdot
.62729 .10433 Mdot
.92508 .18405 Mdot
.30444 .23446 Mdot
.51438 .12975 Mdot
.74055 .13978 Mdot
.14625 .25073 Mdot
.40898 .16238 Mdot
.57437 .10222 Mdot
.82077 .15229 Mdot
.22953 .25263 Mdot
.45993 .14239 Mdot
.64553 .11471 Mdot
.97361 .20276 Mdot
.33137 .22111 Mdot
.53228 .12417 Mdot
.76942 .14656 Mdot
.18507 .25689 Mdot
.43563 .15486 Mdot
.61543 .11112 Mdot
.91453 .18485 Mdot
.30563 .24172 Mdot
.52776 .13729 Mdot
.78111 .15658 Mdot
.21088 .26561 Mdot
.46621 .1578 Mdot
.68364 .13438 Mdot
.06552 .23601 Mdot
.37543 .19154 Mdot
.55851 .11315 Mdot
.80624 .1531 Mdot
.2227 .25739 Mdot
.46195 .14787 Mdot
.65862 .12155 Mdot
.00629 .21487 Mdot
.34686 .21048 Mdot
.53987 .11929 Mdot
.77745 .14684 Mdot
.19222 .25634 Mdot
.43886 .15243 Mdot
.6181 .11078 Mdot
.91887 .18589 Mdot
.3074 .24013 Mdot
.52766 .13613 Mdot
.77902 .15535 Mdot
.20724 .26465 Mdot
.46206 .15749 Mdot
.67443 .13125 Mdot
.04674 .2301 Mdot
.36699 .19793 Mdot
.55384 .11548 Mdot
.80037 .15237 Mdot
.21782 .258 Mdot
.45908 .14911 Mdot
.65462 .12085 Mdot
.99866 .21263 Mdot
.34422 .21356 Mdot
.54053 .12133 Mdot
.78214 .14932 Mdot
.19994 .25822 Mdot
.44672 .15252 Mdot
.63441 .116 Mdot
.95657 .19911 Mdot
.3272 .22906 Mdot
.53872 .13073 Mdot
.79357 .15751 Mdot
.22157 .26452 Mdot
.47258 .15514 Mdot
.69276 .13608 Mdot
.08129 .24012 Mdot
.3819 .18579 Mdot
.56097 .11067 Mdot
.80726 .15222 Mdot
.22188 .25625 Mdot
.45946 .14683 Mdot
.65172 .11882 Mdot
.9906 .20944 Mdot
.3401 .216 Mdot
.53782 .12219 Mdot
.77786 .14836 Mdot
.195 .25781 Mdot
.44293 .15323 Mdot
.62774 .11422 Mdot
.94188 .19415 Mdot
.32025 .23384 Mdot
.53601 .13335 Mdot
.79212 .15828 Mdot
.22182 .26556 Mdot
.47448 .15615 Mdot
.69842 .1384 Mdot
.09284 .24377 Mdot
.38821 .18254 Mdot
.56737 .11073 Mdot
.82042 .15639 Mdot
.23599 .25684 Mdot
.47242 .14612 Mdot
.67783 .12695 Mdot
.04491 .22687 Mdot
.36191 .19592 Mdot
.54173 .11113 Mdot
.76817 .13995 Mdot
.17328 .25037 Mdot
.41904 .15189 Mdot
.57721 .09775 Mdot
.81924 .14959 Mdot
.22437 .25038 Mdot
.45198 .14067 Mdot
.62614 .10764 Mdot
.92837 .18679 Mdot
.30884 .23514 Mdot
.52162 .1315 Mdot
.75875 .14655 Mdot
.17545 .25754 Mdot
.43168 .15836 Mdot
.61306 .1121 Mdot
.91172 .18458 Mdot
.3051 .24312 Mdot
.5293 .13857 Mdot
.78644 .15892 Mdot
.21872 .26717 Mdot
.47462 .15816 Mdot
.70196 .14051 Mdot
.10102 .24663 Mdot
.39344 .18072 Mdot
.57424 .11174 Mdot
.83591 .16172 Mdot
.25186 .25707 Mdot
.48798 .14593 Mdot
.71052 .13754 Mdot
.10741 .24529 Mdot
.39193 .17584 Mdot
.5635 .10604 Mdot
.80493 .14921 Mdot
.2156 .25381 Mdot
.45061 .14524 Mdot
.63071 .11131 Mdot
.94245 .19267 Mdot
.31782 .23199 Mdot
.52942 .13078 Mdot
.77407 .15121 Mdot
.19652 .26109 Mdot
.44918 .15615 Mdot
.64538 .12126 Mdot
.98396 .20925 Mdot
.34063 .22043 Mdot
.54583 .12682 Mdot
.80212 .15839 Mdot
.22869 .26364 Mdot
.47703 .15348 Mdot
.6995 .13749 Mdot
.09284 .2431 Mdot
.38712 .18188 Mdot
.56427 .10949 Mdot
.81209 .15316 Mdot
.22624 .25596 Mdot
.46254 .14605 Mdot
.65692 .12013 Mdot
.00124 .2128 Mdot
.34416 .21194 Mdot
.53781 .11968 Mdot
.77378 .14584 Mdot
.18759 .25575 Mdot
.43521 .15304 Mdot
.61162 .10903 Mdot
.90407 .18074 Mdot
.29848 .24376 Mdot
.52131 .13772 Mdot
.76817 .15256 Mdot
.1937 .26299 Mdot
.45052 .15872 Mdot
.65231 .12472 Mdot
.00113 .21558 Mdot
.34867 .21479 Mdot
.54983 .12433 Mdot
.80639 .15856 Mdot
.23163 .26281 Mdot
.47821 .1524 Mdot
.70025 .13723 Mdot
.09343 .24299 Mdot
.38699 .18143 Mdot
.56331 .10897 Mdot
.80929 .15203 Mdot
.22279 .25555 Mdot
.45906 .14602 Mdot
.64958 .11775 Mdot
.98531 .20749 Mdot
.33762 .21774 Mdot
.53666 .12301 Mdot
.77675 .14839 Mdot
.19415 .25797 Mdot
.44267 .15359 Mdot
.6278 .11442 Mdot
.94232 .19438 Mdot
.3206 .23379 Mdot
.53644 .1334 Mdot
.7931 .15862 Mdot
.22304 .26572 Mdot
.47572 .15616 Mdot
.70107 .13927 Mdot
.09783 .24521 Mdot
.39087 .18111 Mdot
.57004 .11073 Mdot
.82583 .15809 Mdot
.24143 .25686 Mdot
.47745 .14587 Mdot
.68808 .13017 Mdot
.0651 .23301 Mdot
.3706 .18881 Mdot
.54545 .10807 Mdot
.77098 .13938 Mdot
.17479 .24957 Mdot
.41847 .1506 Mdot
.57399 .09612 Mdot
.81013 .14594 Mdot
.21343 .24926 Mdot
.44162 .14103 Mdot
.60531 .10116 Mdot
.8795 .16946 Mdot
.27721 .2458 Mdot
.49771 .13627 Mdot
.71561 .13467 Mdot
.10917 .24324 Mdot
.38882 .17283 Mdot
.55281 .10135 Mdot
.77538 .13756 Mdot
.17551 .2473 Mdot
.41514 .1481 Mdot
.56336 .0916 Mdot
.7813 .13469 Mdot
.17562 .2437 Mdot
.40938 .14447 Mdot
.54618 .08455 Mdot
.73443 .11635 Mdot
.10168 .22697 Mdot
.36168 .16069 Mdot
.48433 .0758 Mdot
.5893 .06488 Mdot
.78997 .12402 Mdot
.16484 .23168 Mdot
.385 .13607 Mdot
.48623 .06256 Mdot
.57193 .05296 Mdot
.73616 .1015 Mdot
.07957 .21223 Mdot
.33676 .15895 Mdot
.44017 .06391 Mdot
.47755 .0231 Mdot
.48964 .00747 Mdot
.49004 .00025 Mdot
.47919 .61133 Mdot
.44489 .59684 Mdot
.34955 .55911 Mdot
.10842 .46901 Mdot
.75403 .39901 Mdot
.57943 .51012 Mdot
.49091 .56332 Mdot
.39211 .55698 Mdot
.18053 .48727 Mdot
.80596 .38654 Mdot
.60024 .49089 Mdot
.50044 .55636 Mdot
.40114 .55666 Mdot
.19718 .49198 Mdot
.82318 .38689 Mdot
.61035 .4865 Mdot
.51247 .55754 Mdot
.42867 .56624 Mdot
.26692 .51807 Mdot
.92635 .40755 Mdot
.66607 .45717 Mdot
.56119 .55322 Mdot
.52376 .5949 Mdot
.51307 .61143 Mdot
.51714 .00252 Mdot
.54055 .01447 Mdot
.60929 .04248 Mdot
.79204 .11295 Mdot
.1484 .22024 Mdot
.36033 .13098 Mdot
.43393 .04549 Mdot
.43499 .00066 Mdot
.36463 .57455 Mdot
.15908 .491 Mdot
.80225 .3975 Mdot
.61565 .50271 Mdot
.54854 .57656 Mdot
.53544 .60993 Mdot
.56204 .01644 Mdot
.657 .05868 Mdot
.90195 .15139 Mdot
.25083 .21562 Mdot
.41986 .10447 Mdot
.50211 .05083 Mdot
.58673 .0523 Mdot
.76459 .10992 Mdot
.12153 .2206 Mdot
.35411 .14374 Mdot
.44396 .05553 Mdot
.4718 .0172 Mdot
.46793 .61565 Mdot
.42808 .5934 Mdot
.3097 .54487 Mdot
.02397 .44145 Mdot
.71126 .42477 Mdot
.57309 .53264 Mdot
.51465 .58191 Mdot
.47273 .59213 Mdot
.40015 .57318 Mdot
.222 .50793 Mdot
.86678 .3985 Mdot
.64513 .48104 Mdot
.56566 .56892 Mdot
.55831 .61349 Mdot
.61539 .03528 Mdot
.79173 .10898 Mdot
.14177 .21634 Mdot
.35197 .12991 Mdot
.41799 .0408 Mdot
.39539 .60407 Mdot
.26291 .53616 Mdot
.95117 .42537 Mdot
.69375 .45894 Mdot
.60506 .56322 Mdot
.62665 .01334 Mdot
.77671 .09275 Mdot
.1041 .20233 Mdot
.32206 .13471 Mdot
.3783 .03476 Mdot
.31004 .57584 Mdot
.07457 .47251 Mdot
.75789 .42231 Mdot
.62083 .53333 Mdot
.60757 .60984 Mdot
.70682 .06134 Mdot
.97934 .16842 Mdot
.27514 .18281 Mdot
.39333 .07305 Mdot
.39981 .004 Mdot
.3004 .5566 Mdot
.0301 .45098 Mdot
.72598 .43008 Mdot
.59967 .53997 Mdot
.57877 .60511 Mdot
.64328 .03987 Mdot
.84869 .12695 Mdot
.20047 .21741 Mdot
.38104 .1116 Mdot
.43936 .03604 Mdot
.43079 .61274 Mdot
.34647 .56592 Mdot
.11433 .47457 Mdot
.76383 .40141 Mdot
.5925 .51214 Mdot
.5199 .57317 Mdot
.46972 .58702 Mdot
.38554 .56601 Mdot
.18288 .49278 Mdot
.81613 .39137 Mdot
.61392 .49307 Mdot
.52974 .566 Mdot
.47896 .58665 Mdot
.40449 .572 Mdot
.22844 .50923 Mdot
.8742 .3991 Mdot
.64777 .47809 Mdot
.56533 .56709 Mdot
.55466 .61144 Mdot
.60456 .03084 Mdot
.76428 .09871 Mdot
.10312 .20942 Mdot
.33342 .14233 Mdot
.40802 .04611 Mdot
.38438 .60342 Mdot
.24128 .52959 Mdot
.9186 .41861 Mdot
.68395 .47301 Mdot
.61387 .57472 Mdot
.66177 .0296 Mdot
.86257 .1241 Mdot
.20008 .20859 Mdot
.36652 .10286 Mdot
.39919 .02019 Mdot
.32541 .57244 Mdot
.0916 .47353 Mdot
.7599 .41303 Mdot
.6077 .52397 Mdot
.56813 .59357 Mdot
.6032 .02168 Mdot
.74689 .08881 Mdot
.0704 .19994 Mdot
.31692 .15236 Mdot
.39926 .05089 Mdot
.37522 .60318 Mdot
.22419 .52469 Mdot
.89568 .415 Mdot
.67678 .48275 Mdot
.61904 .58235 Mdot
.68361 .03991 Mdot
.91261 .14153 Mdot
.23547 .19954 Mdot
.37924 .08885 Mdot
.39926 .01238 Mdot
.3129 .56466 Mdot
.06056 .46208 Mdot
.74142 .4208 Mdot
.60188 .53179 Mdot
.56974 .59818 Mdot
.61393 .02731 Mdot
.77613 .10025 Mdot
.11576 .2099 Mdot
.33581 .136 Mdot
.40154 .04062 Mdot
.36296 .59419 Mdot
.18796 .50988 Mdot
.84661 .40707 Mdot
.65298 .49836 Mdot
.60679 .58949 Mdot
.67242 .04056 Mdot
.89695 .13877 Mdot
.22996 .20581 Mdot
.38455 .09554 Mdot
.41982 .0218 Mdot
.36826 .58617 Mdot
.18427 .50432 Mdot
.83555 .40252 Mdot
.64132 .49799 Mdot
.5866 .58422 Mdot
.62498 .02372 Mdot
.79052 .10231 Mdot
.13011 .20988 Mdot
.33851 .1288 Mdot
.39417 .0344 Mdot
.33885 .58385 Mdot
.131 .48957 Mdot
.79127 .40807 Mdot
.62538 .51551 Mdot
.58696 .59429 Mdot
.64199 .03401 Mdot
.83701 .12053 Mdot
.18567 .21548 Mdot
.36897 .11329 Mdot
.42038 .03177 Mdot
.38551 .59649 Mdot
.23215 .52325 Mdot
.90007 .4128 Mdot
.67364 .47809 Mdot
.60674 .57669 Mdot
.65163 .02774 Mdot
.84309 .11833 Mdot
.1845 .211 Mdot
.36108 .10913 Mdot
.39987 .02397 Mdot
.33282 .5766 Mdot
.10973 .48016 Mdot
.77224 .40945 Mdot
.61284 .51952 Mdot
.57054 .59189 Mdot
.60536 .02152 Mdot
.75072 .08984 Mdot
.07593 .20099 Mdot
.31855 .14995 Mdot
.39776 .04895 Mdot
.36923 .6004 Mdot
.209 .51901 Mdot
.87486 .41152 Mdot
.668 .49019 Mdot
.61764 .58691 Mdot
.68844 .04375 Mdot
.92579 .14669 Mdot
.244 .19666 Mdot
.38248 .08559 Mdot
.39992 .01077 Mdot
.31156 .56343 Mdot
.05665 .46049 Mdot
.73907 .42176 Mdot
.6009 .53264 Mdot
.56928 .59849 Mdot
.61348 .02732 Mdot
.77533 .10003 Mdot
.11476 .20977 Mdot
.33545 .1364 Mdot
.40161 .04089 Mdot
.36352 .5945 Mdot
.18944 .51044 Mdot
.84837 .40724 Mdot
.65388 .49783 Mdot
.60741 .58932 Mdot
.67332 .04073 Mdot
.8986 .13923 Mdot
.23086 .20535 Mdot
.38458 .095 Mdot
.41902 .02128 Mdot
.36584 .58517 Mdot
.17838 .50218 Mdot
.82898 .40209 Mdot
.63773 .49984 Mdot
.58341 .58446 Mdot
.6191 .02205 Mdot
.77714 .09768 Mdot
.11243 .20722 Mdot
.33097 .13507 Mdot
.39245 .038 Mdot
.34144 .58651 Mdot
.13947 .49321 Mdot
.7993 .4078 Mdot
.63042 .51366 Mdot
.59297 .59489 Mdot
.6547 .03815 Mdot
.86498 .12996 Mdot
.21018 .21335 Mdot
.38114 .10566 Mdot
.42992 .03015 Mdot
.40205 .60081 Mdot
.27034 .53664 Mdot
.96026 .42639 Mdot
.69462 .45386 Mdot
.59804 .55835 Mdot
.60539 .00454 Mdot
.7233 .07287 Mdot
.01853 .18246 Mdot
.29287 .16955 Mdot
.39385 .06241 Mdot
.38358 .61168 Mdot
.25317 .53744 Mdot
.94295 .42631 Mdot
.69583 .4653 Mdot
.61823 .57008 Mdot
.66228 .02722 Mdot
.85954 .12192 Mdot
.19571 .20776 Mdot
.36239 .10302 Mdot
.39224 .01845 Mdot
.30941 .56684 Mdot
.05911 .46334 Mdot
.74355 .423 Mdot
.60768 .53406 Mdot
.58442 .60366 Mdot
.65213 .04185 Mdot
.86675 .13264 Mdot
.21496 .2152 Mdot
.38766 .10674 Mdot
.4437 .03463 Mdot
.43743 .61416 Mdot
.36227 .57158 Mdot
.1502 .48696 Mdot
.79249 .39696 Mdot
.60826 .50417 Mdot
.53714 .57408 Mdot
.5076 .59978 Mdot
.48666 .60509 Mdot
.45066 .59578 Mdot
.35978 .56187 Mdot
.13018 .47613 Mdot
.76933 .39502 Mdot
.58701 .50535 Mdot
.49819 .56314 Mdot
.40731 .56187 Mdot
.21752 .50074 Mdot
.85162 .39189 Mdot
.63013 .48115 Mdot
.53984 .56223 Mdot
.49411 .58977 Mdot
.44173 .58566 Mdot
.32495 .54586 Mdot
.04791 .44681 Mdot
.71754 .41386 Mdot
.5633 .5227 Mdot
.4787 .56575 Mdot
.37012 .55092 Mdot
.13052 .46995 Mdot
.75942 .38868 Mdot
.56785 .49964 Mdot
.45065 .5456 Mdot
.27857 .51168 Mdot
.92954 .40232 Mdot
.65755 .44994 Mdot
.53591 .54286 Mdot
.45451 .56773 Mdot
.3224 .53639 Mdot
.02875 .43654 Mdot
.70278 .41658 Mdot
.5488 .52287 Mdot
.44911 .55642 Mdot
.29289 .52148 Mdot
.96331 .41434 Mdot
.67483 .43974 Mdot
.5465 .53872 Mdot
.46996 .57073 Mdot
.35968 .54988 Mdot
.11061 .4641 Mdot
.74637 .39292 Mdot
.56192 .50404 Mdot
.44569 .5462 Mdot
.26929 .50901 Mdot
.91435 .39867 Mdot
.6516 .45564 Mdot
.53539 .54621 Mdot
.45885 .57073 Mdot
.33632 .54231 Mdot
.05975 .44711 Mdot
.71724 .40635 Mdot
.55078 .51516 Mdot
.44073 .55002 Mdot
.26524 .50958 Mdot
.91074 .39894 Mdot
.65189 .45806 Mdot
.53979 .54875 Mdot
.47218 .57625 Mdot
.37331 .55692 Mdot
.14591 .4775 Mdot
.77578 .38928 Mdot
.58314 .49898 Mdot
.48024 .55444 Mdot
.35508 .54068 Mdot
.08786 .45288 Mdot
.72632 .3946 Mdot
.54265 .50452 Mdot
.4066 .53395 Mdot
.17096 .4724 Mdot
.7772 .37468 Mdot
.56067 .48421 Mdot
.41104 .52556 Mdot
.16603 .46661 Mdot
.76564 .37058 Mdot
.54422 .48119 Mdot
.37213 .51168 Mdot
.07059 .43168 Mdot
.69188 .38398 Mdot
.48115 .4878 Mdot
.24917 .47466 Mdot
.83734 .36351 Mdot
.57895 .45834 Mdot
.40617 .51125 Mdot
.1334 .44945 Mdot
.72692 .36682 Mdot
.49841 .4768 Mdot
.26809 .47569 Mdot
.85909 .36526 Mdot
.58932 .4513 Mdot
.41525 .51046 Mdot
.14989 .45403 Mdot
.7391 .36415 Mdot
.50774 .47504 Mdot
.28512 .48045 Mdot
.88701 .37199 Mdot
.60612 .44444 Mdot
.43646 .51318 Mdot
.1969 .46998 Mdot
.78741 .36495 Mdot
.55282 .47305 Mdot
.37682 .50926 Mdot
.07512 .43157 Mdot
.69165 .38104 Mdot
.47607 .4848 Mdot
.23355 .46815 Mdot
.81215 .35759 Mdot
.55706 .46038 Mdot
.36506 .49937 Mdot
.03821 .41603 Mdot
.66859 .3896 Mdot
.45581 .48652 Mdot
.19372 .45606 Mdot
.76291 .35178 Mdot
.51136 .46257 Mdot
.27264 .4705 Mdot
.8559 .36047 Mdot
.58063 .44791 Mdot
.39263 .50184 Mdot
.0923 .43242 Mdot
.69342 .37151 Mdot
.46314 .47571 Mdot
.19157 .4502 Mdot
.75214 .34645 Mdot
.49254 .45759 Mdot
.22452 .45239 Mdot
.77895 .34266 Mdot
.51026 .45197 Mdot
.25316 .45914 Mdot
.81625 .34801 Mdot
.54383 .44967 Mdot
.3203 .47989 Mdot
.93419 .37941 Mdot
.62035 .42407 Mdot
.4299 .50033 Mdot
.16277 .45294 Mdot
.74214 .35807 Mdot
.50113 .46908 Mdot
.26141 .46988 Mdot
.8423 .35901 Mdot
.57363 .45199 Mdot
.38523 .5016 Mdot
.07809 .42821 Mdot
.68621 .37584 Mdot
.45991 .47818 Mdot
.1888 .45048 Mdot
.75098 .34744 Mdot
.49299 .45859 Mdot
.22709 .4537 Mdot
.78321 .3437 Mdot
.51527 .45244 Mdot
.26455 .46308 Mdot
.83475 .3524 Mdot
.55988 .44816 Mdot
.35111 .489 Mdot
.99757 .39954 Mdot
.64678 .40123 Mdot
.43932 .48982 Mdot
.16493 .44846 Mdot
.73579 .35281 Mdot
.48577 .46351 Mdot
.21969 .45359 Mdot
.77702 .34445 Mdot
.51161 .454 Mdot
.25931 .4621 Mdot
.82746 .35114 Mdot
.55458 .44938 Mdot
.34218 .48676 Mdot
.97925 .39374 Mdot
.63971 .40818 Mdot
.43853 .4937 Mdot
.16959 .45182 Mdot
.74328 .35456 Mdot
.49665 .46561 Mdot
.24625 .46327 Mdot
.81605 .35216 Mdot
.55043 .45387 Mdot
.34084 .4885 Mdot
.97992 .39497 Mdot
.64163 .40896 Mdot
.44307 .49532 Mdot
.18156 .45641 Mdot
.75657 .35538 Mdot
.51128 .46643 Mdot
.27872 .4743 Mdot
.86923 .36496 Mdot
.59144 .44635 Mdot
.41138 .50675 Mdot
.13628 .44801 Mdot
.72532 .36405 Mdot
.49205 .47387 Mdot
.24981 .46832 Mdot
.82772 .35717 Mdot
.56446 .45533 Mdot
.37205 .49912 Mdot
.05014 .41908 Mdot
.67251 .38464 Mdot
.45381 .48287 Mdot
.18366 .45107 Mdot
.74906 .34944 Mdot
.4943 .46058 Mdot
.23309 .4566 Mdot
.79306 .34608 Mdot
.52633 .45319 Mdot
.28922 .47149 Mdot
.87769 .3637 Mdot
.59117 .44095 Mdot
.40212 .5012 Mdot
.1093 .43706 Mdot
.70246 .36659 Mdot
.4675 .47282 Mdot
.19606 .45028 Mdot
.75501 .34545 Mdot
.49371 .45654 Mdot
.22531 .45215 Mdot
.77922 .34234 Mdot
.50996 .45162 Mdot
.25194 .45857 Mdot
.8141 .34743 Mdot
.5417 .44969 Mdot
.3159 .47848 Mdot
.92545 .37672 Mdot
.61619 .4269 Mdot
.42688 .50103 Mdot
.15782 .45174 Mdot
.73824 .35872 Mdot
.49802 .46957 Mdot
.25557 .46819 Mdot
.83338 .35711 Mdot
.56692 .45335 Mdot
.37386 .49872 Mdot
.05272 .41956 Mdot
.67309 .38341 Mdot
.45272 .48184 Mdot
.1797 .4493 Mdot
.74409 .34882 Mdot
.48821 .45989 Mdot
.21902 .45166 Mdot
.77338 .34261 Mdot
.50564 .45257 Mdot
.24429 .45651 Mdot
.8032 .34543 Mdot
.53201 .45043 Mdot
.29674 .47263 Mdot
.88932 .36624 Mdot
.59713 .43745 Mdot
.40801 .50115 Mdot
.12064 .44043 Mdot
.70963 .36401 Mdot
.47271 .47161 Mdot
.2051 .45264 Mdot
.76476 .34589 Mdot
.50349 .45656 Mdot
.24616 .459 Mdot
.80904 .34788 Mdot
.53953 .45147 Mdot
.31423 .47879 Mdot
.92352 .37657 Mdot
.61595 .42794 Mdot
.42812 .50195 Mdot
.1618 .45344 Mdot
.74255 .35892 Mdot
.50295 .46995 Mdot
.26669 .47201 Mdot
.85157 .36147 Mdot
.58089 .45075 Mdot
.39775 .50484 Mdot
.10684 .43824 Mdot
.70407 .36911 Mdot
.47371 .47566 Mdot
.21377 .45738 Mdot
.77863 .3491 Mdot
.52043 .45846 Mdot
.28525 .47269 Mdot
.87462 .36425 Mdot
.59146 .44303 Mdot
.40606 .50345 Mdot
.12057 .44159 Mdot
.7115 .36521 Mdot
.47703 .47313 Mdot
.2167 .45714 Mdot
.78045 .34841 Mdot
.52076 .45754 Mdot
.28446 .47199 Mdot
.87251 .36344 Mdot
.5897 .44325 Mdot
.40299 .50264 Mdot
.11331 .439 Mdot
.70613 .36639 Mdot
.47202 .47334 Mdot
.20645 .4539 Mdot
.76773 .34689 Mdot
.50774 .45735 Mdot
.25648 .46275 Mdot
.82553 .35169 Mdot
.55455 .45056 Mdot
.34402 .48792 Mdot
.98411 .3956 Mdot
.64213 .40668 Mdot
.44025 .49326 Mdot
.17241 .4525 Mdot
.74569 .3543 Mdot
.49874 .46541 Mdot
.25036 .46453 Mdot
.82215 .35338 Mdot
.55561 .45331 Mdot
.35064 .49136 Mdot
.0006 .4017 Mdot
.64988 .40128 Mdot
.44458 .49115 Mdot
.17792 .45323 Mdot
.74954 .35328 Mdot
.50101 .46443 Mdot
.25362 .46514 Mdot
.82643 .35402 Mdot
.55875 .45259 Mdot
.35595 .4927 Mdot
.0117 .40528 Mdot
.65424 .39711 Mdot
.44505 .48875 Mdot
.175 .45113 Mdot
.7447 .3521 Mdot
.49415 .46318 Mdot
.23698 .4591 Mdot
.80057 .34832 Mdot
.53501 .4539 Mdot
.30868 .47816 Mdot
.91459 .37448 Mdot
.61245 .4313 Mdot
.42707 .50346 Mdot
.16212 .45429 Mdot
.74406 .35966 Mdot
.50571 .47073 Mdot
.27382 .47472 Mdot
.86409 .36481 Mdot
.58994 .4486 Mdot
.41211 .50813 Mdot
.13993 .44982 Mdot
.72923 .36421 Mdot
.49684 .47441 Mdot
.26089 .47221 Mdot
.84551 .36132 Mdot
.57856 .45305 Mdot
.3968 .50571 Mdot
.10644 .43858 Mdot
.70457 .36966 Mdot
.47527 .47632 Mdot
.21812 .45911 Mdot
.78473 .35018 Mdot
.52692 .4587 Mdot
.29937 .4774 Mdot
.90057 .37156 Mdot
.60695 .43657 Mdot
.42531 .50577 Mdot
.16232 .4555 Mdot
.74609 .36079 Mdot
.50966 .47191 Mdot
.28414 .47865 Mdot
.88289 .37005 Mdot
.60236 .44465 Mdot
.42967 .51131 Mdot
.18008 .46378 Mdot
.76772 .36318 Mdot
.53409 .47364 Mdot
.33869 .49727 Mdot
.99064 .40293 Mdot
.65317 .40946 Mdot
.46327 .50067 Mdot
.23222 .47524 Mdot
.82246 .36478 Mdot
.57422 .46461 Mdot
.40684 .51459 Mdot
.14009 .45318 Mdot
.73471 .36749 Mdot
.50834 .47813 Mdot
.29139 .48395 Mdot
.90064 .37654 Mdot
.61501 .44151 Mdot
.44834 .51502 Mdot
.2243 .47957 Mdot
.82276 .36987 Mdot
.58259 .4696 Mdot
.43163 .52473 Mdot
.20575 .47844 Mdot
.80694 .37155 Mdot
.57658 .47567 Mdot
.42947 .52711 Mdot
.20523 .47945 Mdot
.80821 .37267 Mdot
.57915 .47646 Mdot
.43588 .52949 Mdot
.22209 .48591 Mdot
.83122 .37646 Mdot
.59728 .47345 Mdot
.46655 .53724 Mdot
.29829 .51405 Mdot
.95841 .40797 Mdot
.66499 .43669 Mdot
.52636 .53236 Mdot
.41739 .55069 Mdot
.21921 .49555 Mdot
.84454 .38647 Mdot
.61891 .47858 Mdot
.51548 .55411 Mdot
.42952 .56491 Mdot
.26649 .51728 Mdot
.92458 .40672 Mdot
.66474 .45744 Mdot
.55955 .55302 Mdot
.5201 .59365 Mdot
.50331 .60765 Mdot
.49024 .60996 Mdot
.46616 .60315 Mdot
.40414 .5797 Mdot
.24022 .51673 Mdot
.8968 .40579 Mdot
.66199 .47291 Mdot
.58023 .5675 Mdot
.58532 .00315 Mdot
.68229 .05993 Mdot
.94306 .16117 Mdot
.26681 .20009 Mdot
.41172 .08956 Mdot
.46191 .03102 Mdot
.46948 .00468 Mdot
.44277 .60153 Mdot
.35278 .56242 Mdot
.11917 .47365 Mdot
.76313 .39799 Mdot
.58632 .50876 Mdot
.50234 .56613 Mdot
.421 .56777 Mdot
.25402 .51483 Mdot
.90725 .40372 Mdot
.65946 .46489 Mdot
.56318 .55853 Mdot
.53643 .6015 Mdot
.55049 .00869 Mdot
.62064 .04336 Mdot
.81443 .11977 Mdot
.17353 .22194 Mdot
.37315 .12337 Mdot
.44412 .04387 Mdot
.45325 .00564 Mdot
.4103 .59149 Mdot
.27128 .53211 Mdot
.95402 .42196 Mdot
.688 .45362 Mdot
.58834 .55644 Mdot
.58346 .61502 Mdot
.66863 .05264 Mdot
.91065 .14957 Mdot
.24841 .20875 Mdot
.40634 .0976 Mdot
.46444 .03591 Mdot
.48268 .01127 Mdot
.48138 .61723 Mdot
.4591 .60426 Mdot
.39112 .57602 Mdot
.20947 .50577 Mdot
.85378 .3982 Mdot
.64104 .48655 Mdot
.5676 .57265 Mdot
.56829 .00042 Mdot
.6438 .04667 Mdot
.86057 .13397 Mdot
.2155 .21936 Mdot
.3948 .11081 Mdot
.4637 .04258 Mdot
.49192 .01745 Mdot
.51103 .01181 Mdot
.54259 .0195 Mdot
.6217 .04889 Mdot
.82531 .12584 Mdot
.18901 .22478 Mdot
.38591 .12169 Mdot
.46464 .04866 Mdot
.50374 .02417 Mdot
.54707 .02678 Mdot
.6428 .05917 Mdot
.87911 .14605 Mdot
.23926 .22259 Mdot
.41998 .11169 Mdot
.51403 .05813 Mdot
.62391 .06791 Mdot
.86009 .14597 Mdot
.23478 .23157 Mdot
.43044 .12093 Mdot
.54999 .07388 Mdot
.72509 .10822 Mdot
.07784 .21801 Mdot
.3461 .16579 Mdot
.4663 .07429 Mdot
.54872 .05094 Mdot
.68534 .08444 Mdot
.98717 .18654 Mdot
.30348 .19549 Mdot
.45 .09056 Mdot
.54095 .05621 Mdot
.67767 .08449 Mdot
.97597 .18436 Mdot
.30132 .20108 Mdot
.4561 .09566 Mdot
.56191 .06539 Mdot
.73592 .10755 Mdot
.08908 .21826 Mdot
.34675 .15925 Mdot
.45679 .06801 Mdot
.51861 .0382 Mdot
.60141 .05117 Mdot
.79119 .1173 Mdot
.15483 .22474 Mdot
.36984 .13288 Mdot
.45361 .05177 Mdot
.4857 .01983 Mdot
.50164 .00986 Mdot
.51945 .011 Mdot
.55917 .02455 Mdot
.66424 .06493 Mdot
.92366 .16033 Mdot
.26608 .21162 Mdot
.42957 .10104 Mdot
.51604 .05344 Mdot
.62059 .06462 Mdot
.84876 .14101 Mdot
.22324 .23144 Mdot
.42041 .12186 Mdot
.53134 .06856 Mdot
.67747 .09031 Mdot
.98509 .19012 Mdot
.30953 .20052 Mdot
.46656 .09705 Mdot
.58609 .07387 Mdot
.79823 .13111 Mdot
.18202 .23719 Mdot
.40212 .13603 Mdot
.51846 .0719 Mdot
.65561 .08476 Mdot
.94189 .17693 Mdot
.29239 .21662 Mdot
.46938 .10939 Mdot
.61198 .08813 Mdot
.87094 .16004 Mdot
.26027 .24062 Mdot
.47013 .1297 Mdot
.64642 .10896 Mdot
.96581 .19739 Mdot
.32353 .22109 Mdot
.52027 .12159 Mdot
.73985 .13571 Mdot
.1389 .24663 Mdot
.40018 .16148 Mdot
.55591 .09625 Mdot
.77353 .1345 Mdot
.16903 .24443 Mdot
.40746 .14736 Mdot
.54712 .08631 Mdot
.73925 .11874 Mdot
.11082 .22964 Mdot
.36704 .15835 Mdot
.48988 .07592 Mdot
.6013 .06886 Mdot
.81962 .13493 Mdot
.20085 .23561 Mdot
.41074 .12972 Mdot
.52498 .0706 Mdot
.66733 .08798 Mdot
.9658 .18446 Mdot
.30262 .20817 Mdot
.46934 .10304 Mdot
.60162 .08175 Mdot
.84108 .148 Mdot
.23174 .24144 Mdot
.44373 .13102 Mdot
.59345 .09253 Mdot
.84281 .15411 Mdot
.24229 .24689 Mdot
.46214 .13587 Mdot
.63961 .10968 Mdot
.95537 .19515 Mdot
.3209 .22591 Mdot
.52415 .12561 Mdot
.75457 .14241 Mdot
.16476 .25351 Mdot
.42029 .15793 Mdot
.58947 .10456 Mdot
.85452 .16381 Mdot
.262 .25184 Mdot
.49015 .141 Mdot
.70717 .13413 Mdot
.09757 .24128 Mdot
.38449 .17733 Mdot
.55205 .10355 Mdot
.77737 .13926 Mdot
.17989 .24877 Mdot
.41973 .14823 Mdot
.57267 .09452 Mdot
.8049 .14353 Mdot
.20638 .24813 Mdot
.43473 .14113 Mdot
.59137 .09681 Mdot
.84567 .15717 Mdot
.24829 .24884 Mdot
.47108 .13769 Mdot
.66138 .11761 Mdot
.00435 .21197 Mdot
.34241 .20893 Mdot
.53009 .11599 Mdot
.75157 .13688 Mdot
.15289 .24803 Mdot
.40682 .15693 Mdot
.56136 .09551 Mdot
.78352 .13731 Mdot
.18156 .246 Mdot
.41613 .14497 Mdot
.56024 .08907 Mdot
.77082 .13014 Mdot
.15971 .24034 Mdot
.39692 .14661 Mdot
.52563 .07955 Mdot
.68318 .09737 Mdot
.00496 .19887 Mdot
.32113 .19541 Mdot
.47513 .09517 Mdot
.60113 .07787 Mdot
.83387 .14384 Mdot
.22206 .23991 Mdot
.43317 .13047 Mdot
.57095 .08516 Mdot
.78629 .13308 Mdot
.17682 .24136 Mdot
.40618 .14175 Mdot
.53555 .07996 Mdot
.70477 .10458 Mdot
.04662 .21127 Mdot
.33654 .17918 Mdot
.47255 .08406 Mdot
.5777 .06498 Mdot
.76719 .11712 Mdot
.13549 .22762 Mdot
.36851 .14402 Mdot
.4693 .06229 Mdot
.53559 .04098 Mdot
.64178 .06563 Mdot
.88782 .15206 Mdot
.25038 .22408 Mdot
.4331 .11293 Mdot
.54242 .06757 Mdot
.69912 .09684 Mdot
.02654 .20236 Mdot
.32411 .18391 Mdot
.46099 .08459 Mdot
.55423 .05762 Mdot
.70757 .09477 Mdot
.0344 .20199 Mdot
.32266 .17815 Mdot
.4495 .07839 Mdot
.52021 .0437 Mdot
.6137 .05778 Mdot
.82503 .13061 Mdot
.19658 .22963 Mdot
.39832 .12468 Mdot
.49283 .05841 Mdot
.57924 .0534 Mdot
.75154 .10648 Mdot
.10367 .21763 Mdot
.34677 .15024 Mdot
.44225 .05901 Mdot
.47389 .01956 Mdot
.47616 .0014 Mdot
.45159 .60285 Mdot
.37316 .56956 Mdot
.1661 .49006 Mdot
.80361 .394 Mdot
.61086 .49891 Mdot
.53349 .57022 Mdot
.49368 .59343 Mdot
.44674 .58902 Mdot
.34074 .55252 Mdot
.08335 .45895 Mdot
.73601 .40337 Mdot
.56783 .51409 Mdot
.474 .56004 Mdot
.35092 .54197 Mdot
.08296 .45242 Mdot
.72544 .39707 Mdot
.54563 .5069 Mdot
.41668 .53834 Mdot
.19781 .48277 Mdot
.80869 .37754 Mdot
.58732 .48122 Mdot
.45974 .53919 Mdot
.28715 .51137 Mdot
.93958 .40323 Mdot
.65867 .44442 Mdot
.52878 .53776 Mdot
.43124 .55775 Mdot
.2584 .51121 Mdot
.90596 .40022 Mdot
.65371 .46214 Mdot
.54939 .55356 Mdot
.49997 .5875 Mdot
.45053 .58748 Mdot
.34608 .55348 Mdot
.09358 .46198 Mdot
.74132 .40033 Mdot
.56864 .51131 Mdot
.47114 .55777 Mdot
.3412 .53773 Mdot
.06014 .44433 Mdot
.71273 .40332 Mdot
.54026 .51144 Mdot
.41279 .53925 Mdot
.19163 .48135 Mdot
.80259 .37759 Mdot
.58366 .48273 Mdot
.45498 .5385 Mdot
.27609 .50748 Mdot
.91977 .39782 Mdot
.65032 .4515 Mdot
.52658 .54156 Mdot
.43273 .56003 Mdot
.2651 .51444 Mdot
.91844 .40379 Mdot
.65996 .45828 Mdot
.55331 .55212 Mdot
.50576 .58865 Mdot
.46473 .59267 Mdot
.38417 .56824 Mdot
.18397 .49431 Mdot
.81919 .39258 Mdot
.61752 .4934 Mdot
.5369 .56821 Mdot
.49762 .59375 Mdot
.45564 .59209 Mdot
.36417 .56151 Mdot
.13718 .47775 Mdot
.77367 .39337 Mdot
.58802 .5033 Mdot
.49684 .56168 Mdot
.4021 .55948 Mdot
.20358 .49534 Mdot
.83281 .38888 Mdot
.61808 .48533 Mdot
.52488 .56043 Mdot
.45968 .57774 Mdot
.3494 .54988 Mdot
.09322 .45971 Mdot
.73762 .39826 Mdot
.56133 .50908 Mdot
.45264 .55086 Mdot
.29121 .51827 Mdot
.95594 .41082 Mdot
.66982 .4412 Mdot
.5412 .53854 Mdot
.45863 .567 Mdot
.32983 .53843 Mdot
.04334 .44097 Mdot
.70848 .41108 Mdot
.54738 .51847 Mdot
.43902 .55107 Mdot
.26344 .50952 Mdot
.90865 .39876 Mdot
.65151 .45911 Mdot
.54087 .54965 Mdot
.4759 .57788 Mdot
.38381 .56112 Mdot
.17177 .48699 Mdot
.80118 .389 Mdot
.60121 .49445 Mdot
.50807 .56047 Mdot
.42404 .5661 Mdot
.25739 .51504 Mdot
.9111 .40401 Mdot
.66012 .46292 Mdot
.56106 .55681 Mdot
.52931 .59841 Mdot
.5305 .00074 Mdot
.56595 .02191 Mdot
.67381 .06666 Mdot
.9413 .16532 Mdot
.27363 .20539 Mdot
.42808 .09546 Mdot
.50402 .04693 Mdot
.58448 .04973 Mdot
.756 .106 Mdot
.10723 .21707 Mdot
.34625 .14773 Mdot
.43733 .05629 Mdot
.45941 .01364 Mdot
.43611 .60363 Mdot
.34253 .5602 Mdot
.09867 .46731 Mdot
.75031 .40274 Mdot
.5818 .51389 Mdot
.50171 .56853 Mdot
.42355 .56973 Mdot
.26228 .51836 Mdot
.92169 .40754 Mdot
.66607 .46005 Mdot
.56586 .5561 Mdot
.53797 .6008 Mdot
.55258 .00903 Mdot
.62553 .04509 Mdot
.82608 .12394 Mdot
.18631 .22264 Mdot
.38091 .12027 Mdot
.45314 .04464 Mdot
.47318 .01239 Mdot
.46306 .61178 Mdot
.41156 .58621 Mdot
.2652 .52758 Mdot
.93981 .41693 Mdot
.68083 .45797 Mdot
.58496 .55879 Mdot
.58062 .61535 Mdot
.66353 .05124 Mdot
.90038 .14638 Mdot
.24259 .2115 Mdot
.40516 .10047 Mdot
.46679 .03809 Mdot
.49116 .01506 Mdot
.50556 .0089 Mdot
.52623 .01278 Mdot
.57642 .03102 Mdot
.70968 .08236 Mdot
.01704 .18996 Mdot
.30518 .17808 Mdot
.42419 .07355 Mdot
.46072 .02258 Mdot
.45333 .61346 Mdot
.39395 .58134 Mdot
.22341 .51263 Mdot
.87553 .40303 Mdot
.65439 .48137 Mdot
.58162 .57306 Mdot
.59708 .00956 Mdot
.71557 .07323 Mdot
.0097 .18179 Mdot
.29288 .17501 Mdot
.40271 .06787 Mdot
.40931 .00408 Mdot
.31889 .56215 Mdot
.06521 .46125 Mdot
.73989 .41697 Mdot
.59405 .5279 Mdot
.5484 .58982 Mdot
.55661 .00507 Mdot
.62746 .04378 Mdot
.82741 .12358 Mdot
.18636 .22184 Mdot
.37965 .11946 Mdot
.44953 .04319 Mdot
.46333 .00853 Mdot
.43607 .60119 Mdot
.3385 .55773 Mdot
.08818 .46333 Mdot
.74324 .40485 Mdot
.57797 .5159 Mdot
.49734 .5682 Mdot
.4137 .56634 Mdot
.23726 .50898 Mdot
.88154 .39819 Mdot
.64766 .47349 Mdot
.55772 .56244 Mdot
.53157 .60187 Mdot
.54085 .00574 Mdot
.5958 .03396 Mdot
.75257 .09689 Mdot
.08917 .20803 Mdot
.3302 .14896 Mdot
.41373 .05162 Mdot
.40447 .61232 Mdot
.29364 .54954 Mdot
.00968 .44254 Mdot
.71479 .43578 Mdot
.59536 .54422 Mdot
.57735 .60691 Mdot
.64335 .04079 Mdot
.85031 .12791 Mdot
.20256 .2177 Mdot
.3829 .11145 Mdot
.44252 .03685 Mdot
.4386 .61561 Mdot
.367 .57379 Mdot
.16201 .49134 Mdot
.80397 .39675 Mdot
.61552 .50157 Mdot
.54646 .57535 Mdot
.52916 .60734 Mdot
.54462 .00956 Mdot
.60984 .04031 Mdot
.78956 .11107 Mdot
.1436 .21881 Mdot
.35651 .13158 Mdot
.42836 .04441 Mdot
.42197 .61408 Mdot
.33089 .56175 Mdot
.08271 .46465 Mdot
.74521 .40945 Mdot
.58748 .52055 Mdot
.5237 .57861 Mdot
.48659 .5951 Mdot
.43436 .58575 Mdot
.31003 .54119 Mdot
.01849 .43786 Mdot
.70611 .42497 Mdot
.56678 .53192 Mdot
.5007 .5772 Mdot
.43543 .57769 Mdot
.29917 .53382 Mdot
.99158 .42793 Mdot
.6935 .43381 Mdot
.56405 .53803 Mdot
.50505 .58157 Mdot
.45176 .5851 Mdot
.34478 .55192 Mdot
.08892 .4599 Mdot
.73773 .40098 Mdot
.56584 .5118 Mdot
.46625 .55649 Mdot
.32882 .53309 Mdot
.03314 .4353 Mdot
.70029 .41232 Mdot
.53857 .51809 Mdot
.42002 .54477 Mdot
.21486 .49123 Mdot
.83421 .38278 Mdot
.60882 .47873 Mdot
.49703 .54894 Mdot
.38188 .54687 Mdot
.14518 .47174 Mdot
.76624 .38384 Mdot
.56622 .49441 Mdot
.43889 .53934 Mdot
.2442 .4977 Mdot
.86977 .38663 Mdot
.62663 .46776 Mdot
.51194 .54716 Mdot
.41075 .55549 Mdot
.21389 .49637 Mdot
.84181 .38807 Mdot
.62046 .48124 Mdot
.52261 .55756 Mdot
.45023 .5733 Mdot
.32251 .5391 Mdot
.03328 .43929 Mdot
.70672 .41621 Mdot
.5534 .52328 Mdot
.4593 .55988 Mdot
.31971 .53176 Mdot
.01724 .4311 Mdot
.69533 .41908 Mdot
.54276 .52374 Mdot
.43794 .55325 Mdot
.26474 .51099 Mdot
.91247 .40032 Mdot
.6542 .45841 Mdot
.54416 .55003 Mdot
.48339 .58047 Mdot
.40387 .56889 Mdot
.22222 .50577 Mdot
.86345 .3963 Mdot
.64074 .48039 Mdot
.55713 .56636 Mdot
.53671 .60541 Mdot
.5574 .01279 Mdot
.64155 .05201 Mdot
.86539 .13834 Mdot
.22384 .22153 Mdot
.40487 .11188 Mdot
.48469 .04933 Mdot
.54723 .03865 Mdot
.66237 .07116 Mdot
.93077 .16588 Mdot
.27496 .21272 Mdot
.44151 .10293 Mdot
.54344 .063 Mdot
.69384 .09296 Mdot
.01302 .19726 Mdot
.3175 .18818 Mdot
.45806 .08688 Mdot
.55179 .05793 Mdot
.70301 .09346 Mdot
.0263 .1998 Mdot
.32 .18152 Mdot
.45098 .08095 Mdot
.52743 .04725 Mdot
.63473 .06631 Mdot
.87672 .14956 Mdot
.2445 .2273 Mdot
.43255 .11622 Mdot
.54663 .07051 Mdot
.71266 .10261 Mdot
.0536 .21072 Mdot
.33511 .17398 Mdot
.46189 .07835 Mdot
.54602 .05199 Mdot
.68143 .08369 Mdot
.98024 .18468 Mdot
.30133 .19844 Mdot
.45184 .09302 Mdot
.54875 .0599 Mdot
.6999 .09342 Mdot
.02206 .1991 Mdot
.31937 .18375 Mdot
.45365 .08299 Mdot
.53629 .05107 Mdot
.65957 .0762 Mdot
.93445 .16988 Mdot
.28132 .21438 Mdot
.45182 .10537 Mdot
.5687 .07224 Mdot
.76083 .11874 Mdot
.13238 .22963 Mdot
.37101 .14748 Mdot
.47931 .06694 Mdot
.56431 .05253 Mdot
.72001 .09623 Mdot
.05238 .20541 Mdot
.32662 .16949 Mdot
.44146 .07097 Mdot
.49162 .031 Mdot
.53232 .02515 Mdot
.60928 .04757 Mdot
.80026 .11803 Mdot
.16219 .22368 Mdot
.37096 .12903 Mdot
.44937 .04846 Mdot
.47154 .0137 Mdot
.46171 .61196 Mdot
.40904 .58548 Mdot
.25909 .52536 Mdot
.92958 .41439 Mdot
.67708 .46198 Mdot
.58587 .56166 Mdot
.58706 .00073 Mdot
.68179 .05855 Mdot
.94009 .15964 Mdot
.26451 .2005 Mdot
.40982 .08981 Mdot
.45861 .03015 Mdot
.46114 .00157 Mdot
.42019 .59273 Mdot
.29279 .5393 Mdot
.99201 .43214 Mdot
.70025 .43772 Mdot
.57963 .54348 Mdot
.54527 .5968 Mdot
.56138 .00996 Mdot
.64515 .05177 Mdot
.87113 .13966 Mdot
.22733 .22015 Mdot
.40551 .11012 Mdot
.48308 .04794 Mdot
.54156 .03614 Mdot
.64648 .06484 Mdot
.89452 .1533 Mdot
.25321 .22169 Mdot
.4321 .11056 Mdot
.53658 .06457 Mdot
.68202 .08989 Mdot
.99116 .19106 Mdot
.31028 .19723 Mdot
.4623 .09395 Mdot
.57212 .06787 Mdot
.76066 .11653 Mdot
.12865 .22743 Mdot
.36659 .14705 Mdot
.47081 .06441 Mdot
.54223 .04414 Mdot
.66082 .07329 Mdot
.93175 .16744 Mdot
.27746 .21366 Mdot
.446 .10416 Mdot
.55467 .06717 Mdot
.72392 .1046 Mdot
.0706 .21426 Mdot
.3401 .16656 Mdot
.4578 .07274 Mdot
.52837 .04362 Mdot
.63083 .06333 Mdot
.86504 .14475 Mdot
.23412 .2281 Mdot
.42425 .11751 Mdot
.53198 .06658 Mdot
.6756 .08876 Mdot
.97978 .18799 Mdot
.30674 .20208 Mdot
.46517 .09791 Mdot
.58456 .07378 Mdot
.79506 .1301 Mdot
.17825 .23682 Mdot
.39956 .13678 Mdot
.51476 .0712 Mdot
.64661 .08149 Mdot
.92169 .17 Mdot
.28172 .22252 Mdot
.46548 .11357 Mdot
.61053 .08965 Mdot
.87067 .16078 Mdot
.2614 .24148 Mdot
.47274 .13062 Mdot
.65342 .11167 Mdot
.98185 .20298 Mdot
.33074 .21563 Mdot
.52244 .11847 Mdot
.7394 .13409 Mdot
.13581 .24499 Mdot
.39671 .16125 Mdot
.54892 .09407 Mdot
.75555 .1277 Mdot
.14191 .23879 Mdot
.38833 .1523 Mdot
.51867 .08055 Mdot
.67007 .09357 Mdot
.9791 .19099 Mdot
.31168 .20555 Mdot
.47775 .10264 Mdot
.61877 .08715 Mdot
.88188 .16261 Mdot
.26655 .23774 Mdot
.47234 .12719 Mdot
.64703 .10796 Mdot
.96522 .19665 Mdot
.3224 .22075 Mdot
.51802 .1209 Mdot
.73397 .13346 Mdot
.12886 .24405 Mdot
.39353 .16357 Mdot
.54666 .09464 Mdot
.75175 .12676 Mdot
.13669 .2379 Mdot
.38546 .15375 Mdot
.5157 .08049 Mdot
.66364 .09144 Mdot
.96561 .18662 Mdot
.30613 .21046 Mdot
.47788 .10615 Mdot
.62471 .09075 Mdot
.89849 .1692 Mdot
.27935 .23539 Mdot
.48342 .12612 Mdot
.66878 .11456 Mdot
.01107 .21155 Mdot
.34086 .20382 Mdot
.51933 .1103 Mdot
.71959 .12377 Mdot
.09643 .2329 Mdot
.37084 .1696 Mdot
.51481 .08898 Mdot
.6755 .09931 Mdot
.99668 .1985 Mdot
.32161 .20082 Mdot
.4846 .10073 Mdot
.63022 .09 Mdot
.90712 .17113 Mdot
.28311 .23238 Mdot
.48314 .12362 Mdot
.66415 .11187 Mdot
.99947 .20724 Mdot
.33539 .20761 Mdot
.51673 .11208 Mdot
.71695 .12374 Mdot
.09314 .2325 Mdot
.36999 .1711 Mdot
.51574 .09007 Mdot
.67924 .10105 Mdot
.00509 .20139 Mdot
.3252 .19783 Mdot
.48516 .09886 Mdot
.62837 .08851 Mdot
.90142 .16875 Mdot
.27887 .23328 Mdot
.47944 .12396 Mdot
.65683 .10964 Mdot
.98413 .20228 Mdot
.32933 .21335 Mdot
.51657 .11572 Mdot
.72249 .12727 Mdot
.10558 .23676 Mdot
.37792 .16832 Mdot
.52545 .09118 Mdot
.70163 .10888 Mdot
.0494 .21494 Mdot
.34224 .18099 Mdot
.48461 .08799 Mdot
.60962 .07726 Mdot
.84894 .14791 Mdot
.23446 .23826 Mdot
.44098 .12764 Mdot
.58234 .08736 Mdot
.81265 .14234 Mdot
.20905 .24499 Mdot
.43153 .1375 Mdot
.57899 .09114 Mdot
.81209 .14406 Mdot
.21152 .24686 Mdot
.43634 .13895 Mdot
.59113 .09566 Mdot
.84335 .15588 Mdot
.24536 .24846 Mdot
.4676 .13735 Mdot
.65348 .11488 Mdot
.98714 .20621 Mdot
.33531 .21518 Mdot
.52887 .11962 Mdot
.75487 .13967 Mdot
.16062 .25077 Mdot
.41416 .15669 Mdot
.57533 .09961 Mdot
.81847 .15027 Mdot
.22507 .25129 Mdot
.45403 .1415 Mdot
.63175 .10984 Mdot
.94193 .1917 Mdot
.31628 .23136 Mdot
.52616 .12971 Mdot
.76545 .14789 Mdot
.18375 .25852 Mdot
.43756 .15686 Mdot
.6226 .11436 Mdot
.93289 .19177 Mdot
.31678 .23726 Mdot
.53643 .13575 Mdot
.79689 .16097 Mdot
.22945 .26733 Mdot
.48366 .15711 Mdot
.71943 .14572 Mdot
.13174 .25482 Mdot
.41161 .17297 Mdot
.59666 .11437 Mdot
.88434 .17779 Mdot
.29151 .25165 Mdot
.52492 .14426 Mdot
.78638 .16159 Mdot
.223 .26985 Mdot
.48236 .16029 Mdot
.72183 .148 Mdot
.13834 .25741 Mdot
.41748 .17252 Mdot
.60748 .11743 Mdot
.90992 .18692 Mdot
.3088 .24652 Mdot
.53997 .14287 Mdot
.81584 .17049 Mdot
.25638 .27227 Mdot
.51722 .16121 Mdot
.79747 .17321 Mdot
.24963 .27945 Mdot
.52195 .1683 Mdot
.81899 .18358 Mdot
.27924 .28445 Mdot
.56268 .17517 Mdot
.91512 .21782 Mdot
.35899 .27433 Mdot
.66357 .18824 Mdot
.12213 .2834 Mdot
.45583 .20624 Mdot
.74025 .17578 Mdot
.20418 .28673 Mdot
.49567 .18015 Mdot
.78226 .17713 Mdot
.24502 .286 Mdot
.52802 .1749 Mdot
.84252 .19437 Mdot
.30732 .28726 Mdot
.60382 .18325 Mdot
.00949 .25072 Mdot
.40444 .24409 Mdot
.69779 .1813 Mdot
.16138 .28652 Mdot
.4723 .19216 Mdot
.75207 .17291 Mdot
.21168 .28405 Mdot
.49662 .17611 Mdot
.77775 .17375 Mdot
.236 .28321 Mdot
.5151 .17249 Mdot
.81123 .18302 Mdot
.27407 .28605 Mdot
.55911 .17616 Mdot
.90941 .2165 Mdot
.35664 .2764 Mdot
.66291 .18929 Mdot
.12277 .28421 Mdot
.45725 .20672 Mdot
.74401 .17723 Mdot
.21048 .2883 Mdot
.50263 .18055 Mdot
.79774 .18239 Mdot
.26467 .28858 Mdot
.55252 .1779 Mdot
.89864 .21391 Mdot
.35171 .28001 Mdot
.66043 .1908 Mdot
.12125 .28481 Mdot
.45794 .20808 Mdot
.74764 .17905 Mdot
.21717 .29019 Mdot
.51067 .18139 Mdot
.81622 .18884 Mdot
.28627 .29051 Mdot
.58112 .18223 Mdot
.96372 .23646 Mdot
.38696 .26158 Mdot
.69295 .18911 Mdot
.16734 .29319 Mdot
.4856 .1967 Mdot
.78762 .18666 Mdot
.26448 .29472 Mdot
.56225 .18403 Mdot
.92856 .2264 Mdot
.37292 .27463 Mdot
.68846 .19501 Mdot
.17057 .29796 Mdot
.49477 .20037 Mdot
.81306 .19671 Mdot
.29726 .29925 Mdot
.60949 .19297 Mdot
.0359 .26354 Mdot
.42209 .23868 Mdot
.72372 .18642 Mdot
.20275 .29606 Mdot
.5098 .18977 Mdot
.82791 .19661 Mdot
.30475 .2947 Mdot
.61228 .19006 Mdot
.03642 .26213 Mdot
.41976 .23692 Mdot
.71623 .18323 Mdot
.18851 .29189 Mdot
.4942 .18893 Mdot
.79335 .18488 Mdot
.26571 .29193 Mdot
.55909 .18132 Mdot
.91774 .22165 Mdot
.36525 .27658 Mdot
.67805 .19332 Mdot
.15263 .29331 Mdot
.47998 .20232 Mdot
.78478 .18837 Mdot
.26515 .29688 Mdot
.56648 .18623 Mdot
.94077 .23132 Mdot
.38045 .27174 Mdot
.6974 .19589 Mdot
.18447 .30102 Mdot
.50671 .19916 Mdot
.83655 .20385 Mdot
.32029 .29897 Mdot
.64143 .19848 Mdot
.10218 .28476 Mdot
.45523 .2182 Mdot
.75836 .18734 Mdot
.24109 .29834 Mdot
.54425 .18737 Mdot
.89678 .21787 Mdot
.35794 .28501 Mdot
.67906 .19846 Mdot
.16244 .29875 Mdot
.49252 .204 Mdot
.81415 .19878 Mdot
.30121 .30102 Mdot
.61765 .19557 Mdot
.05526 .27046 Mdot
.43167 .23263 Mdot
.73322 .18637 Mdot
.21362 .2969 Mdot
.51885 .18864 Mdot
.84534 .20178 Mdot
.32036 .29358 Mdot
.63282 .19311 Mdot
.07854 .27547 Mdot
.43907 .22282 Mdot
.73241 .1813 Mdot
.20451 .29177 Mdot
.50406 .18513 Mdot
.80819 .18796 Mdot
.28028 .29177 Mdot
.57577 .18262 Mdot
.95368 .23356 Mdot
.3832 .26546 Mdot
.69226 .19101 Mdot
.16946 .29493 Mdot
.48936 .19771 Mdot
.79723 .19028 Mdot
.27709 .29657 Mdot
.57971 .18703 Mdot
.96868 .2404 Mdot
.39281 .26213 Mdot
.70478 .1928 Mdot
.18937 .2995 Mdot
.50702 .19631 Mdot
.83258 .20121 Mdot
.31432 .29773 Mdot
.63071 .19554 Mdot
.07874 .2769 Mdot
.44138 .22412 Mdot
.73927 .18411 Mdot
.2166 .295 Mdot
.51803 .18629 Mdot
.83978 .19886 Mdot
.31352 .29278 Mdot
.62154 .19037 Mdot
.05394 .26724 Mdot
.42655 .23029 Mdot
.71907 .18079 Mdot
.18805 .28985 Mdot
.49064 .18701 Mdot
.78265 .18047 Mdot
.25074 .28929 Mdot
.53898 .17814 Mdot
.87084 .2051 Mdot
.33314 .28572 Mdot
.63959 .1894 Mdot
.08432 .27486 Mdot
.43816 .21869 Mdot
.72387 .17658 Mdot
.18701 .28623 Mdot
.4842 .18368 Mdot
.76358 .17266 Mdot
.22214 .28341 Mdot
.50361 .17396 Mdot
.78916 .17648 Mdot
.24914 .28428 Mdot
.52927 .17313 Mdot
.8423 .19346 Mdot
.30577 .28644 Mdot
.60032 .18204 Mdot
.00087 .24755 Mdot
.40044 .24695 Mdot
.6947 .18186 Mdot
.15805 .28637 Mdot
.47075 .19326 Mdot
.75058 .17295 Mdot
.21026 .2841 Mdot
.49567 .17639 Mdot
.77619 .17337 Mdot
.23412 .28302 Mdot
.5131 .17242 Mdot
.80687 .18156 Mdot
.26913 .28569 Mdot
.55283 .17534 Mdot
.89515 .21156 Mdot
.34756 .27961 Mdot
.65288 .18869 Mdot
.10557 .27978 Mdot
.44753 .21134 Mdot
.73126 .17536 Mdot
.1936 .28574 Mdot
.48726 .18149 Mdot
.76655 .17261 Mdot
.22471 .28316 Mdot
.50529 .17341 Mdot
.79185 .1771 Mdot
.25208 .28443 Mdot
.53247 .17329 Mdot
.8493 .19581 Mdot
.31209 .28602 Mdot
.60855 .18322 Mdot
.01839 .25329 Mdot
.40749 .24048 Mdot
.69784 .17945 Mdot
.15847 .28468 Mdot
.46818 .19141 Mdot
.74218 .16934 Mdot
.19581 .28036 Mdot
.47991 .17559 Mdot
.74138 .1616 Mdot
.18243 .27258 Mdot
.4596 .1713 Mdot
.69161 .14339 Mdot
.09149 .24714 Mdot
.39359 .18671 Mdot
.58421 .11781 Mdot
.8656 .17391 Mdot
.28145 .25701 Mdot
.52095 .14802 Mdot
.78405 .16261 Mdot
.2229 .27122 Mdot
.48451 .16168 Mdot
.72864 .15088 Mdot
.15099 .26103 Mdot
.42719 .1707 Mdot
.62396 .12161 Mdot
.94706 .19969 Mdot
.32889 .23598 Mdot
.55251 .13821 Mdot
.83441 .17422 Mdot
.27144 .2701 Mdot
.53026 .15996 Mdot
.82307 .18096 Mdot
.2771 .28061 Mdot
.55388 .17106 Mdot
.89039 .20798 Mdot
.3412 .27861 Mdot
.64089 .18522 Mdot
.07979 .27126 Mdot
.43226 .21784 Mdot
.71047 .17194 Mdot
.16301 .27968 Mdot
.4619 .18473 Mdot
.71816 .15837 Mdot
.15067 .26731 Mdot
.43724 .17711 Mdot
.65472 .13441 Mdot
.02077 .22623 Mdot
.36341 .21177 Mdot
.56998 .12766 Mdot
.85309 .17497 Mdot
.27962 .26361 Mdot
.52942 .15438 Mdot
.81226 .17481 Mdot
.26136 .27756 Mdot
.53108 .16669 Mdot
.83569 .18826 Mdot
.2947 .28369 Mdot
.58091 .17689 Mdot
.95467 .231 Mdot
.37896 .26222 Mdot
.67929 .18561 Mdot
.142 .28597 Mdot
.4647 .19945 Mdot
.74786 .175 Mdot
.21084 .28614 Mdot
.49939 .17834 Mdot
.78725 .17791 Mdot
.25005 .28603 Mdot
.53301 .17488 Mdot
.853 .19777 Mdot
.31647 .28644 Mdot
.61556 .18484 Mdot
.03404 .25864 Mdot
.41435 .23505 Mdot
.70249 .17808 Mdot
.16252 .28431 Mdot
.46919 .18953 Mdot
.74127 .16815 Mdot
.19292 .27914 Mdot
.47617 .17506 Mdot
.7326 .15848 Mdot
.1678 .26897 Mdot
.44661 .17232 Mdot
.66621 .13572 Mdot
.04131 .23182 Mdot
.37025 .2033 Mdot
.56828 .12239 Mdot
.84113 .16863 Mdot
.26513 .26205 Mdot
.51011 .1514 Mdot
.76649 .15846 Mdot
.20176 .26901 Mdot
.46538 .16293 Mdot
.69019 .13894 Mdot
.08229 .24233 Mdot
.38549 .18739 Mdot
.57018 .11414 Mdot
.83162 .16158 Mdot
.24978 .25843 Mdot
.48808 .14728 Mdot
.71293 .13897 Mdot
.11277 .24712 Mdot
.39558 .17478 Mdot
.56867 .10698 Mdot
.81699 .15347 Mdot
.22945 .25492 Mdot
.46356 .14469 Mdot
.65686 .11946 Mdot
7e-05 .21212 Mdot
.3432 .21207 Mdot
.53646 .11944 Mdot
.77055 .14468 Mdot
.18299 .2549 Mdot
.43129 .15346 Mdot
.60435 .10695 Mdot
.88705 .17472 Mdot
.28693 .24714 Mdot
.5118 .13897 Mdot
.74998 .14721 Mdot
.16801 .25836 Mdot
.42953 .16163 Mdot
.61401 .11401 Mdot
.91657 .187 Mdot
.30915 .24263 Mdot
.53416 .13907 Mdot
.79749 .16274 Mdot
.23271 .26898 Mdot
.48915 .15849 Mdot
.73333 .15091 Mdot
.15637 .26145 Mdot
.4298 .16899 Mdot
.62646 .12154 Mdot
.95144 .20085 Mdot
.33045 .23424 Mdot
.5521 .13699 Mdot
.83158 .17273 Mdot
.2678 .26959 Mdot
.52528 .15914 Mdot
.81123 .17672 Mdot
.26387 .27975 Mdot
.53735 .16902 Mdot
.85264 .19486 Mdot
.31166 .28369 Mdot
.60416 .18078 Mdot
.00614 .24844 Mdot
.40118 .24415 Mdot
.6916 .17949 Mdot
.14989 .28324 Mdot
.46275 .19336 Mdot
.73391 .16759 Mdot
.184 .27817 Mdot
.46948 .17644 Mdot
.7207 .15526 Mdot
.14872 .26453 Mdot
.4321 .17514 Mdot
.64105 .12914 Mdot
.98933 .21525 Mdot
.34966 .2227 Mdot
.56426 .13263 Mdot
.84952 .1763 Mdot
.2806 .26642 Mdot
.53514 .15732 Mdot
.82908 .18166 Mdot
.28111 .27937 Mdot
.55673 .17034 Mdot
.89509 .20912 Mdot
.34361 .2772 Mdot
.64249 .18472 Mdot
.08172 .27146 Mdot
.43262 .21686 Mdot
.70962 .1712 Mdot
.1607 .27879 Mdot
.45952 .18468 Mdot
.71308 .15671 Mdot
.14167 .26488 Mdot
.43049 .1785 Mdot
.64324 .13149 Mdot
.99687 .21855 Mdot
.35403 .22074 Mdot
.56843 .1325 Mdot
.85779 .17883 Mdot
.2873 .26545 Mdot
.54189 .15734 Mdot
.84326 .18626 Mdot
.29447 .27887 Mdot
.57282 .17203 Mdot
.93061 .22113 Mdot
.36435 .26807 Mdot
.6627 .18439 Mdot
.11452 .27924 Mdot
.44781 .20599 Mdot
.72318 .17019 Mdot
.17584 .27976 Mdot
.46783 .18046 Mdot
.72372 .15815 Mdot
.15701 .26779 Mdot
.44029 .17508 Mdot
.65766 .13434 Mdot
.02544 .2273 Mdot
.3646 .20961 Mdot
.56856 .12605 Mdot
.84761 .17246 Mdot
.27373 .26336 Mdot
.522 .15344 Mdot
.79505 .16875 Mdot
.24079 .27548 Mdot
.50698 .16452 Mdot
.78106 .16939 Mdot
.23157 .27843 Mdot
.50344 .16803 Mdot
.7792 .17043 Mdot
.23179 .27971 Mdot
.50571 .16929 Mdot
.78607 .17327 Mdot
.24168 .28158 Mdot
.51769 .17058 Mdot
.81365 .18291 Mdot
.27526 .28529 Mdot
.55929 .17554 Mdot
.90878 .21599 Mdot
.35579 .27627 Mdot
.66126 .18879 Mdot
.11932 .2831 Mdot
.45484 .20736 Mdot
.74 .17624 Mdot
.20465 .28717 Mdot
.49671 .1805 Mdot
.78504 .1782 Mdot
.24888 .28667 Mdot
.53288 .17552 Mdot
.85377 .19832 Mdot
.31761 .28667 Mdot
.6176 .1854 Mdot
.0387 .26026 Mdot
.4165 .2335 Mdot
.70422 .17782 Mdot
.16439 .2844 Mdot
.47012 .18895 Mdot
.74227 .1682 Mdot
.19406 .27922 Mdot
.477 .17487 Mdot
.73403 .15886 Mdot
.17001 .26945 Mdot
.44838 .17204 Mdot
.66943 .13662 Mdot
.04778 .23383 Mdot
.37294 .20096 Mdot
.5693 .12136 Mdot
.84152 .16824 Mdot
.26466 .26151 Mdot
.50872 .15084 Mdot
.76262 .15692 Mdot
.1958 .26772 Mdot
.45946 .16295 Mdot
.67782 .13495 Mdot
.05783 .23486 Mdot
.37393 .19536 Mdot
.562 .11623 Mdot
.81836 .15844 Mdot
.23824 .2595 Mdot
.47876 .14865 Mdot
.69534 .13386 Mdot
.08127 .23852 Mdot
.3793 .1842 Mdot
.55365 .10775 Mdot
.78748 .14451 Mdot
.19619 .2526 Mdot
.43524 .14774 Mdot
.6031 .10375 Mdot
.8795 .17082 Mdot
.27942 .24716 Mdot
.50256 .13791 Mdot
.72859 .13969 Mdot
.13283 .24984 Mdot
.40381 .16747 Mdot
.57259 .10431 Mdot
.82057 .15326 Mdot
.23101 .25366 Mdot
.46288 .1433 Mdot
.65319 .11762 Mdot
.99109 .20883 Mdot
.33905 .21505 Mdot
.53459 .12085 Mdot
.76891 .14482 Mdot
.18181 .25518 Mdot
.43112 .15408 Mdot
.605 .10746 Mdot
.88911 .17559 Mdot
.28863 .24692 Mdot
.51357 .13903 Mdot
.75384 .14849 Mdot
.1739 .25961 Mdot
.43429 .16093 Mdot
.62251 .11633 Mdot
.93589 .19368 Mdot
.31977 .23725 Mdot
.54082 .13661 Mdot
.80749 .16481 Mdot
.2424 .26879 Mdot
.49767 .15776 Mdot
.7503 .15613 Mdot
.18277 .26728 Mdot
.45121 .1659 Mdot
.66537 .13236 Mdot
.03455 .22816 Mdot
.36499 .20422 Mdot
.56052 .12085 Mdot
.82281 .1621 Mdot
.24645 .26182 Mdot
.49029 .1507 Mdot
.72316 .14392 Mdot
.13332 .2535 Mdot
.40984 .1709 Mdot
.58985 .11125 Mdot
.86608 .17072 Mdot
.27641 .25359 Mdot
.50935 .14397 Mdot
.75286 .1505 Mdot
.17619 .26163 Mdot
.43866 .16222 Mdot
.63354 .12044 Mdot
.96221 .20313 Mdot
.33319 .22928 Mdot
.54833 .13297 Mdot
.81726 .1662 Mdot
.2502 .26758 Mdot
.50331 .15643 Mdot
.76015 .15874 Mdot
.19647 .26966 Mdot
.46302 .16474 Mdot
.68816 .13914 Mdot
.07974 .24201 Mdot
.38493 .18862 Mdot
.57114 .11508 Mdot
.83509 .16313 Mdot
.25379 .25877 Mdot
.49269 .14765 Mdot
.72334 .14255 Mdot
.13131 .25214 Mdot
.40718 .17049 Mdot
.58399 .10928 Mdot
.85137 .16525 Mdot
.26334 .25461 Mdot
.49608 .14385 Mdot
.72441 .14111 Mdot
.13026 .25083 Mdot
.4048 .16968 Mdot
.57808 .10709 Mdot
.8361 .15946 Mdot
.24828 .25474 Mdot
.48062 .1436 Mdot
.69113 .1301 Mdot
.06932 .23373 Mdot
.37163 .18684 Mdot
.54411 .1066 Mdot
.76579 .13701 Mdot
.16643 .24761 Mdot
.41146 .15143 Mdot
.56151 .09274 Mdot
.77935 .13463 Mdot
.17398 .2439 Mdot
.4089 .14519 Mdot
.5464 .08498 Mdot
.73561 .11693 Mdot
.10392 .22763 Mdot
.36297 .1601 Mdot
.48561 .0758 Mdot
.59202 .06576 Mdot
.79671 .12651 Mdot
.17355 .2329 Mdot
.3909 .13433 Mdot
.49441 .06397 Mdot
.59159 .06006 Mdot
.78666 .12056 Mdot
.15682 .22877 Mdot
.37709 .13613 Mdot
.47187 .05858 Mdot
.53502 .03903 Mdot
.63743 .06329 Mdot
.87655 .14778 Mdot
.24159 .22561 Mdot
.42704 .11461 Mdot
.5329 .06543 Mdot
.67568 .08824 Mdot
.97905 .18749 Mdot
.30602 .20208 Mdot
.46418 .09775 Mdot
.5822 .07294 Mdot
.78904 .12783 Mdot
.17033 .23565 Mdot
.39385 .13814 Mdot
.50611 .06938 Mdot
.62529 .07365 Mdot
.87186 .15239 Mdot
.24808 .23252 Mdot
.44448 .12138 Mdot
.5794 .08339 Mdot
.80036 .13656 Mdot
.19224 .2422 Mdot
.41599 .13828 Mdot
.54916 .0823 Mdot
.73699 .11609 Mdot
.10407 .22687 Mdot
.36175 .15926 Mdot
.48213 .0744 Mdot
.58236 .06195 Mdot
.77157 .11693 Mdot
.13897 .22707 Mdot
.36854 .14188 Mdot
.46589 .06017 Mdot
.52499 .03653 Mdot
.61222 .05391 Mdot
.816 .12595 Mdot
.18439 .22767 Mdot
.388 .12584 Mdot
.47523 .05391 Mdot
.53458 .03668 Mdot
.6327 .06064 Mdot
.864 .14295 Mdot
.23094 .22678 Mdot
.41933 .11643 Mdot
.52042 .06247 Mdot
.64451 .07669 Mdot
.91037 .16431 Mdot
.27224 .22365 Mdot
.45602 .11358 Mdot
.59074 .08326 Mdot
.82252 .14325 Mdot
.2158 .24306 Mdot
.43337 .13447 Mdot
.57783 .08928 Mdot
.80677 .14149 Mdot
.20424 .24565 Mdot
.42924 .13906 Mdot
.5769 .09126 Mdot
.8081 .14289 Mdot
.2073 .24672 Mdot
.43309 .13954 Mdot
.58547 .09418 Mdot
.82987 .15105 Mdot
.23194 .24849 Mdot
.45531 .13806 Mdot
.62886 .10726 Mdot
.93262 .18773 Mdot
.31026 .2334 Mdot
.52081 .13012 Mdot
.75479 .14461 Mdot
.16854 .25571 Mdot
.42549 .1588 Mdot
.60129 .10865 Mdot
.88396 .17471 Mdot
.28645 .24875 Mdot
.51379 .1405 Mdot
.75669 .15012 Mdot
.17928 .26117 Mdot
.43949 .16082 Mdot
.63296 .11957 Mdot
.95979 .20199 Mdot
.33158 .22978 Mdot
.54663 .13291 Mdot
.81364 .16502 Mdot
.2463 .2674 Mdot
.49916 .15628 Mdot
.75108 .15569 Mdot
.18284 .26684 Mdot
.45053 .16544 Mdot
.66321 .13144 Mdot
.02965 .22647 Mdot
.36278 .20589 Mdot
.55936 .12149 Mdot
.82148 .162 Mdot
.2456 .26212 Mdot
.48995 .15102 Mdot
.72296 .144 Mdot
.13322 .25355 Mdot
.40991 .17101 Mdot
.59016 .1114 Mdot
.86693 .17105 Mdot
.27715 .25353 Mdot
.51014 .14399 Mdot
.75457 .15107 Mdot
.17878 .26217 Mdot
.44085 .16197 Mdot
.6376 .1216 Mdot
.97118 .20617 Mdot
.33715 .22618 Mdot
.54957 .13128 Mdot
.8171 .16534 Mdot
.24873 .26676 Mdot
.50052 .15561 Mdot
.7529 .15598 Mdot
.18509 .26711 Mdot
.45219 .16508 Mdot
.66608 .13219 Mdot
.03538 .22824 Mdot
.36503 .20374 Mdot
.5598 .12037 Mdot
.82057 .16116 Mdot
.24379 .26157 Mdot
.4873 .1505 Mdot
.71648 .14164 Mdot
.12153 .25034 Mdot
.40221 .17347 Mdot
.57922 .1094 Mdot
.8421 .16247 Mdot
.25554 .25552 Mdot
.48924 .14444 Mdot
.7108 .13693 Mdot
.10677 .24473 Mdot
.39094 .17563 Mdot
.5613 .10529 Mdot
.79922 .14704 Mdot
.20845 .25292 Mdot
.44394 .14554 Mdot
.61737 .10719 Mdot
.91173 .18193 Mdot
.3008 .24046 Mdot
.51911 .13492 Mdot
.75896 .14824 Mdot
.17837 .25921 Mdot
.43585 .15913 Mdot
.62278 .11553 Mdot
.93509 .19302 Mdot
.31873 .2371 Mdot
.53904 .13616 Mdot
.80303 .16315 Mdot
.23698 .26819 Mdot
.49168 .15741 Mdot
.73697 .1516 Mdot
.16151 .26238 Mdot
.43329 .16797 Mdot
.63188 .12274 Mdot
.96303 .20466 Mdot
.33557 .23025 Mdot
.55365 .13478 Mdot
.83121 .17154 Mdot
.26571 .26853 Mdot
.52124 .15792 Mdot
.80069 .17271 Mdot
.25094 .27827 Mdot
.52136 .16712 Mdot
.81583 .18199 Mdot
.27498 .28377 Mdot
.5565 .17399 Mdot
.90053 .21262 Mdot
.34978 .27766 Mdot
.6534 .18764 Mdot
.10474 .27894 Mdot
.44608 .21096 Mdot
.72766 .17402 Mdot
.1873 .28408 Mdot
.48088 .18144 Mdot
.75291 .16812 Mdot
.20476 .27926 Mdot
.48398 .17257 Mdot
.74512 .16139 Mdot
.18602 .27249 Mdot
.46141 .1702 Mdot
.69363 .14352 Mdot
.09453 .24777 Mdot
.39478 .18557 Mdot
.58461 .11732 Mdot
.8656 .17366 Mdot
.28105 .25676 Mdot
.52006 .14772 Mdot
.78168 .16169 Mdot
.2196 .27065 Mdot
.48094 .16152 Mdot
.7208 .14824 Mdot
.13748 .25752 Mdot
.41742 .17301 Mdot
.60819 .1179 Mdot
.912 .18777 Mdot
.31026 .24614 Mdot
.54142 .14286 Mdot
.81885 .17146 Mdot
.25956 .27237 Mdot
.52075 .16142 Mdot
.80533 .17588 Mdot
.25899 .28038 Mdot
.53309 .16941 Mdot
.84433 .19235 Mdot
.30473 .28455 Mdot
.59582 .1799 Mdot
.98876 .24285 Mdot
.39439 .25069 Mdot
.68925 .18223 Mdot
.15102 .28539 Mdot
.46661 .19505 Mdot
.74475 .1719 Mdot
.20264 .28299 Mdot
.48858 .17672 Mdot
.76164 .16876 Mdot
.21406 .27961 Mdot
.49121 .17128 Mdot
.75842 .16514 Mdot
.20522 .27614 Mdot
.47925 .16936 Mdot
.7299 .15491 Mdot
.15896 .26518 Mdot
.43681 .17172 Mdot
.64511 .12874 Mdot
.99559 .21661 Mdot
.35105 .21969 Mdot
.56172 .1302 Mdot
.8404 .17223 Mdot
.27069 .26593 Mdot
.52265 .15572 Mdot
.8001 .17148 Mdot
.24857 .27717 Mdot
.5172 .16602 Mdot
.80522 .17801 Mdot
.26237 .28253 Mdot
.54022 .17172 Mdot
.86304 .19951 Mdot
.32221 .28379 Mdot
.61974 .18388 Mdot
.04017 .25984 Mdot
.41569 .23208 Mdot
.70032 .17591 Mdot
.15612 .28169 Mdot
.46246 .18933 Mdot
.72676 .16335 Mdot
.169 .27332 Mdot
.45419 .17625 Mdot
.68832 .1447 Mdot
.08896 .24761 Mdot
.39423 .18867 Mdot
.58858 .12012 Mdot
.87794 .17883 Mdot
.2921 .25596 Mdot
.53267 .14868 Mdot
.80989 .17133 Mdot
.25437 .27471 Mdot
.51908 .1636 Mdot
.80529 .17689 Mdot
.26061 .2814 Mdot
.53648 .1705 Mdot
.85321 .19575 Mdot
.31327 .28434 Mdot
.60752 .18186 Mdot
.01424 .25136 Mdot
.40489 .24143 Mdot
.69434 .17889 Mdot
.15275 .28331 Mdot
.46386 .19228 Mdot
.73448 .16725 Mdot
.18409 .27787 Mdot
.46906 .17612 Mdot
.71928 .15465 Mdot
.14601 .26373 Mdot
.42994 .17548 Mdot
.63723 .12811 Mdot
.98108 .21251 Mdot
.34626 .22569 Mdot
.56349 .13426 Mdot
.85059 .17743 Mdot
.28279 .26712 Mdot
.53895 .15832 Mdot
.83868 .18525 Mdot
.29106 .27958 Mdot
.56954 .17211 Mdot
.92412 .21914 Mdot
.36123 .27015 Mdot
.66067 .18506 Mdot
.11236 .27916 Mdot
.44737 .20705 Mdot
.72398 .17096 Mdot
.17804 .28063 Mdot
.47033 .18064 Mdot
.72928 .16004 Mdot
.16656 .27025 Mdot
.44814 .17403 Mdot
.67216 .13845 Mdot
.05495 .23657 Mdot
.37687 .19896 Mdot
.57312 .12129 Mdot
.84911 .17057 Mdot
.27119 .26086 Mdot
.51502 .15069 Mdot
.77579 .16117 Mdot
.21406 .27086 Mdot
.47704 .16253 Mdot
.71417 .14655 Mdot
.12661 .2549 Mdot
.4106 .17551 Mdot
.59879 .11631 Mdot
.89159 .18096 Mdot
.29763 .25095 Mdot
.53183 .14474 Mdot
.80175 .16682 Mdot
.2421 .27215 Mdot
.50282 .16113 Mdot
.76672 .1631 Mdot
.20948 .27364 Mdot
.47819 .16607 Mdot
.72233 .15089 Mdot
.1436 .26036 Mdot
.42374 .17314 Mdot
.62097 .12189 Mdot
.94211 .19847 Mdot
.32723 .23802 Mdot
.55327 .1397 Mdot
.83839 .17621 Mdot
.27633 .27066 Mdot
.53687 .16102 Mdot
.8387 .18654 Mdot
.29317 .28087 Mdot
.57436 .17379 Mdot
.93655 .22385 Mdot
.36856 .26699 Mdot
.66835 .18528 Mdot
.12484 .28212 Mdot
.45428 .20361 Mdot
.73278 .17212 Mdot
.19007 .28262 Mdot
.48012 .17926 Mdot
.74775 .16541 Mdot
.19521 .27655 Mdot
.47338 .17192 Mdot
.72161 .15341 Mdot
.14683 .2628 Mdot
.42868 .1742 Mdot
.63262 .12604 Mdot
.96968 .20831 Mdot
.34079 .22936 Mdot
.56053 .13581 Mdot
.84703 .17707 Mdot
.28098 .26819 Mdot
.53848 .15914 Mdot
.83903 .18575 Mdot
.29202 .27996 Mdot
.57139 .17266 Mdot
.92876 .22086 Mdot
.36397 .26897 Mdot
.6635 .18512 Mdot
.11697 .28026 Mdot
.44984 .20573 Mdot
.72697 .17127 Mdot
.18206 .28126 Mdot
.47345 .18009 Mdot
.73497 .16163 Mdot
.17554 .27229 Mdot
.45559 .17308 Mdot
.6861 .14246 Mdot
.08216 .24478 Mdot
.38945 .18991 Mdot
.58161 .11877 Mdot
.86201 .1733 Mdot
.27952 .25804 Mdot
.52027 .14879 Mdot
.78388 .16291 Mdot
.22326 .27156 Mdot
.48534 .16197 Mdot
.73087 .15175 Mdot
.15494 .26209 Mdot
.43031 .17019 Mdot
.62942 .12306 Mdot
.95918 .2038 Mdot
.33456 .232 Mdot
.55489 .13617 Mdot
.83604 .17375 Mdot
.27138 .26906 Mdot
.5285 .15891 Mdot
.81764 .1787 Mdot
.27063 .27996 Mdot
.54529 .16975 Mdot
.87043 .20095 Mdot
.32634 .28177 Mdot
.6227 .18316 Mdot
.04438 .26061 Mdot
.41656 .23002 Mdot
.69871 .17438 Mdot
.15144 .27981 Mdot
.45773 .1893 Mdot
.7168 .16012 Mdot
.15182 .26886 Mdot
.44015 .17819 Mdot
.66242 .13737 Mdot
.03798 .23211 Mdot
.37103 .20584 Mdot
.57379 .12531 Mdot
.85696 .17501 Mdot
.28087 .26199 Mdot
.52831 .15293 Mdot
.80758 .1726 Mdot
.25505 .27655 Mdot
.52276 .16546 Mdot
.81611 .1813 Mdot
.27401 .283 Mdot
.5541 .17311 Mdot
.89416 .21017 Mdot
.3452 .27876 Mdot
.64761 .1869 Mdot
.09392 .27583 Mdot
.44015 .21398 Mdot
.72034 .17317 Mdot
.17726 .28239 Mdot
.47279 .18265 Mdot
.73773 .16374 Mdot
.18198 .27456 Mdot
.46256 .17341 Mdot
.70122 .1475 Mdot
.11134 .25347 Mdot
.40566 .1819 Mdot
.59952 .11981 Mdot
.89864 .18487 Mdot
.30471 .25097 Mdot
.54146 .14632 Mdot
.82454 .17495 Mdot
.26809 .27413 Mdot
.53296 .1637 Mdot
.83481 .18655 Mdot
.29157 .28229 Mdot
.57459 .17491 Mdot
.93883 .22512 Mdot
.37051 .26679 Mdot
.67148 .18601 Mdot
.13084 .2839 Mdot
.45846 .20248 Mdot
.73966 .17379 Mdot
.20033 .28471 Mdot
.48984 .17893 Mdot
.76787 .17183 Mdot
.22462 .28228 Mdot
.5038 .17255 Mdot
.78728 .1752 Mdot
.24569 .28331 Mdot
.52433 .1722 Mdot
.83034 .18913 Mdot
.29377 .28641 Mdot
.58411 .17944 Mdot
.96514 .23549 Mdot
.38524 .25964 Mdot
.68662 .18626 Mdot
.15377 .28872 Mdot
.47296 .19727 Mdot
.76174 .17848 Mdot
.22988 .28932 Mdot
.51961 .17906 Mdot
.83144 .19272 Mdot
.30008 .28964 Mdot
.5977 .18394 Mdot
.99892 .24797 Mdot
.40136 .24872 Mdot
.69934 .18416 Mdot
.16813 .28973 Mdot
.48035 .19296 Mdot
.77041 .17927 Mdot
.23885 .28951 Mdot
.52788 .17863 Mdot
.84825 .198 Mdot
.31528 .28864 Mdot
.61737 .1867 Mdot
.04039 .26144 Mdot
.41826 .23354 Mdot
.70777 .17893 Mdot
.17083 .28619 Mdot
.47584 .18851 Mdot
.75366 .1717 Mdot
.21127 .28282 Mdot
.49434 .17495 Mdot
.77101 .17099 Mdot
.22596 .28117 Mdot
.50311 .17129 Mdot
.78378 .17346 Mdot
.24025 .28212 Mdot
.51722 .17118 Mdot
.81361 .18318 Mdot
.27568 .28557 Mdot
.56023 .17586 Mdot
.91122 .21693 Mdot
.35741 .27576 Mdot
.66319 .18898 Mdot
.12271 .284 Mdot
.45691 .20654 Mdot
.743 .17682 Mdot
.20876 .28786 Mdot
.50069 .18042 Mdot
.79338 .1809 Mdot
.25928 .28794 Mdot
.54565 .17698 Mdot
.88289 .20842 Mdot
.34084 .28303 Mdot
.64746 .1895 Mdot
.09786 .27837 Mdot
.44452 .21425 Mdot
.72975 .17628 Mdot
.19338 .28653 Mdot
.48842 .18235 Mdot
.77038 .17426 Mdot
.23072 .2845 Mdot
.51253 .17417 Mdot
.80848 .18291 Mdot
.27227 .28664 Mdot
.55797 .17657 Mdot
.90774 .21617 Mdot
.35603 .27705 Mdot
.66291 .18967 Mdot
.12339 .28459 Mdot
.45799 .20679 Mdot
.74566 .17779 Mdot
.21312 .2889 Mdot
.50554 .18072 Mdot
.80421 .18459 Mdot
.27239 .28935 Mdot
.56251 .1793 Mdot
.92145 .22184 Mdot
.3656 .2745 Mdot
.67529 .1914 Mdot
.14537 .29053 Mdot
.47309 .20254 Mdot
.77054 .18384 Mdot
.24635 .29406 Mdot
.54235 .18294 Mdot
.88566 .21217 Mdot
.34734 .28533 Mdot
.66177 .19433 Mdot
.12911 .28883 Mdot
.46604 .20823 Mdot
.76489 .1847 Mdot
.2428 .29536 Mdot
.54104 .18433 Mdot
.88515 .21267 Mdot
.34807 .2861 Mdot
.66421 .19539 Mdot
.1347 .29078 Mdot
.47051 .20754 Mdot
.77319 .18706 Mdot
.2538 .29704 Mdot
.55462 .18592 Mdot
.91597 .22332 Mdot
.36792 .27932 Mdot
.68716 .19731 Mdot
.17242 .2999 Mdot
.49878 .2017 Mdot
.82375 .20085 Mdot
.30961 .30027 Mdot
.62808 .19683 Mdot
.07617 .27693 Mdot
.44143 .22574 Mdot
.742 .18576 Mdot
.22218 .29677 Mdot
.52526 .18731 Mdot
.85675 .20488 Mdot
.32913 .29195 Mdot
.64344 .19425 Mdot
.09878 .28141 Mdot
.44952 .21677 Mdot
.74417 .18211 Mdot
.21855 .29318 Mdot
.51658 .18419 Mdot
.83332 .19575 Mdot
.30581 .29202 Mdot
.60941 .18763 Mdot
.02712 .25816 Mdot
.41434 .23931 Mdot
.70936 .18233 Mdot
.1784 .28988 Mdot
.48549 .18979 Mdot
.7762 .17967 Mdot
.24432 .28932 Mdot
.53271 .17824 Mdot
.85782 .20092 Mdot
.32305 .28753 Mdot
.62705 .18788 Mdot
.05986 .26749 Mdot
.4266 .22666 Mdot
.71333 .1772 Mdot
.17514 .28542 Mdot
.47664 .18634 Mdot
.75183 .17008 Mdot
.20685 .28122 Mdot
.4886 .17413 Mdot
.75748 .16618 Mdot
.206 .2772 Mdot
.48151 .17027 Mdot
.73617 .15739 Mdot
.17 .26812 Mdot
.44623 .17072 Mdot
.66284 .13387 Mdot
.033 .22877 Mdot
.36613 .20589 Mdot
.56522 .12304 Mdot
.83595 .16732 Mdot
.26094 .26265 Mdot
.5065 .15177 Mdot
.75942 .15631 Mdot
.19186 .26726 Mdot
.45632 .16345 Mdot
.67205 .13333 Mdot
.04648 .23141 Mdot
.36913 .19941 Mdot
.56001 .11797 Mdot
.8171 .15889 Mdot
.23829 .26031 Mdot
.48012 .14946 Mdot
.69955 .13561 Mdot
.08987 .24123 Mdot
.38394 .18175 Mdot
.55819 .10769 Mdot
.79674 .14743 Mdot
.20744 .25382 Mdot
.44468 .14662 Mdot
.62066 .10876 Mdot
.9203 .18519 Mdot
.30628 .23855 Mdot
.52355 .13428 Mdot
.76733 .15066 Mdot
.18989 .26116 Mdot
.44528 .15784 Mdot
.64004 .12037 Mdot
.97341 .20603 Mdot
.33668 .22452 Mdot
.54614 .12945 Mdot
.807 .16122 Mdot
.2363 .26532 Mdot
.48641 .15458 Mdot
.7212 .1451 Mdot
.13289 .25444 Mdot
.41126 .17205 Mdot
.59449 .11324 Mdot
.87831 .17542 Mdot
.28664 .25236 Mdot
.51986 .14414 Mdot
.77546 .15797 Mdot
.20861 .2677 Mdot
.46796 .16029 Mdot
.69136 .13807 Mdot
.08253 .24176 Mdot
.38457 .18667 Mdot
.5673 .11294 Mdot
.82384 .15855 Mdot
.24121 .25795 Mdot
.47901 .14697 Mdot
.69316 .13235 Mdot
.07582 .23649 Mdot
.376 .18552 Mdot
.54981 .10742 Mdot
.779 .14165 Mdot
.18506 .25096 Mdot
.42604 .14893 Mdot
.58641 .09912 Mdot
.8397 .15654 Mdot
.24502 .2505 Mdot
.47058 .13941 Mdot
.6631 .11898 Mdot
.0093 .21397 Mdot
.345 .20748 Mdot
.53196 .11555 Mdot
.75479 .13771 Mdot
.15738 .24881 Mdot
.40973 .15596 Mdot
.56545 .09624 Mdot
.79308 .14068 Mdot
.194 .24778 Mdot
.42609 .14344 Mdot
.57764 .09366 Mdot
.81349 .14576 Mdot
.21506 .24818 Mdot
.4411 .1397 Mdot
.60209 .0995 Mdot
.8707 .16601 Mdot
.26987 .2467 Mdot
.49059 .13641 Mdot
.70068 .12984 Mdot
.08205 .2357 Mdot
.37475 .1809 Mdot
.5401 .10219 Mdot
.75027 .1299 Mdot
.14029 .24105 Mdot
.39153 .15527 Mdot
.52946 .08525 Mdot
.7005 .10571 Mdot
.04276 .21153 Mdot
.33728 .18202 Mdot
.47832 .08717 Mdot
.59494 .07208 Mdot
.8126 .13452 Mdot
.19637 .23718 Mdot
.4104 .13228 Mdot
.52846 .07296 Mdot
.67852 .09274 Mdot
.99058 .19286 Mdot
.31328 .19944 Mdot
.47017 .09696 Mdot
.59354 .07625 Mdot
.81662 .13787 Mdot
.20402 .23943 Mdot
.41903 .13288 Mdot
.54645 .07875 Mdot
.7256 .11072 Mdot
.08249 .22057 Mdot
.35029 .1655 Mdot
.47277 .0757 Mdot
.56463 .05678 Mdot
.72755 .10068 Mdot
.06851 .21073 Mdot
.33443 .16435 Mdot
.44522 .06847 Mdot
.49533 .03097 Mdot
.54015 .0277 Mdot
.62988 .05545 Mdot
.8506 .13642 Mdot
.21643 .22609 Mdot
.40639 .1174 Mdot
.49657 .05573 Mdot
.58288 .05334 Mdot
.75866 .10864 Mdot
.11402 .21963 Mdot
.35128 .14663 Mdot
.4439 .05724 Mdot
.47442 .01887 Mdot
.47617 .00108 Mdot
.4511 .60254 Mdot
.37163 .56892 Mdot
.16233 .48868 Mdot
.79978 .39397 Mdot
.60836 .49973 Mdot
.53014 .56969 Mdot
.48576 .59061 Mdot
.42532 .58068 Mdot
.28357 .53042 Mdot
.96595 .42173 Mdot
.68651 .44534 Mdot
.57281 .54776 Mdot
.53854 .59685 Mdot
.54739 .00547 Mdot
.609 .03808 Mdot
.78439 .10839 Mdot
.13543 .21696 Mdot
.35125 .13338 Mdot
.42241 .04398 Mdot
.40932 .60995 Mdot
.29923 .54999 Mdot
.01782 .44411 Mdot
.71632 .4317 Mdot
.59065 .54037 Mdot
.56197 .60031 Mdot
.60155 .02446 Mdot
.74826 .09067 Mdot
.0748 .20181 Mdot
.3199 .15148 Mdot
.40221 .05087 Mdot
.38085 .60483 Mdot
.23707 .52918 Mdot
.91405 .41839 Mdot
.68349 .47554 Mdot
.61731 .57713 Mdot
.67201 .03381 Mdot
.88539 .13188 Mdot
.21737 .20518 Mdot
.37328 .09635 Mdot
.40064 .01691 Mdot
.32288 .56997 Mdot
.0838 .47028 Mdot
.75434 .41442 Mdot
.60466 .52553 Mdot
.56491 .59347 Mdot
.5965 .01952 Mdot
.73056 .08286 Mdot
.04313 .19318 Mdot
.30756 .16342 Mdot
.40377 .05946 Mdot
.39775 .61431 Mdot
.28398 .54772 Mdot
.99445 .43909 Mdot
.71119 .44297 Mdot
.60245 .55083 Mdot
.60165 .61754 Mdot
.70807 .06577 Mdot
.98813 .17309 Mdot
.28159 .18137 Mdot
.39873 .0724 Mdot
.40902 .00635 Mdot
.322 .56425 Mdot
.07322 .46428 Mdot
.74459 .41493 Mdot
.59571 .52602 Mdot
.54857 .5889 Mdot
.55547 .00426 Mdot
.62379 .04222 Mdot
.81831 .12022 Mdot
.17636 .22129 Mdot
.37348 .12182 Mdot
.44221 .04248 Mdot
.44708 .00301 Mdot
.39324 .58476 Mdot
.2276 .51566 Mdot
.8839 .40561 Mdot
.66006 .47969 Mdot
.58811 .57356 Mdot
.6107 .01397 Mdot
.74855 .08519 Mdot
.06623 .19634 Mdot
.31122 .15141 Mdot
.38949 .04838 Mdot
.35269 .59529 Mdot
.1722 .50648 Mdot
.83292 .40835 Mdot
.64963 .50475 Mdot
.61159 .59452 Mdot
.68957 .04819 Mdot
.93459 .15143 Mdot
.25146 .19584 Mdot
.38849 .08469 Mdot
.40957 .01303 Mdot
.33387 .57125 Mdot
.10273 .47518 Mdot
.7634 .40832 Mdot
.60327 .51907 Mdot
.55183 .58624 Mdot
.55793 .00377 Mdot
.62804 .04334 Mdot
.82774 .12342 Mdot
.18625 .22157 Mdot
.37915 .11922 Mdot
.44824 .0427 Mdot
.45987 .00719 Mdot
.42663 .59749 Mdot
.31338 .54804 Mdot
.03435 .44559 Mdot
.71681 .42178 Mdot
.57522 .53053 Mdot
.5155 .58112 Mdot
.47326 .59193 Mdot
.40094 .57334 Mdot
.22378 .50854 Mdot
.8692 .3989 Mdot
.64634 .4803 Mdot
.56652 .5687 Mdot
.55969 .61381 Mdot
.61875 .0365 Mdot
.79988 .11195 Mdot
.1521 .21768 Mdot
.35744 .12691 Mdot
.42237 .04013 Mdot
.40303 .60608 Mdot
.28076 .54247 Mdot
.982 .43339 Mdot
.70353 .44593 Mdot
.5973 .55238 Mdot
.5943 .61618 Mdot
.69174 .06022 Mdot
.9571 .164 Mdot
.27036 .1936 Mdot
.40523 .08336 Mdot
.43924 .02102 Mdot
.40625 .59764 Mdot
.27334 .53589 Mdot
.96252 .42594 Mdot
.69366 .45187 Mdot
.59349 .55613 Mdot
.593 .61773 Mdot
.69171 .06101 Mdot
.95834 .16479 Mdot
.27151 .19355 Mdot
.40647 .08341 Mdot
.44173 .02179 Mdot
.41261 .60003 Mdot
.28962 .54202 Mdot
.99234 .4343 Mdot
.70371 .43965 Mdot
.58737 .54613 Mdot
.56487 .60413 Mdot
.61366 .03015 Mdot
.78024 .10295 Mdot
.12343 .2121 Mdot
.34071 .13429 Mdot
.40658 .04071 Mdot
.37283 .59718 Mdot
.2102 .51752 Mdot
.87331 .40983 Mdot
.66494 .48925 Mdot
.61133 .5849 Mdot
.67351 .03843 Mdot
.89517 .13699 Mdot
.2269 .20502 Mdot
.38068 .09504 Mdot
.41191 .0193 Mdot
.34861 .57891 Mdot
.13888 .48842 Mdot
.79139 .40327 Mdot
.6177 .51069 Mdot
.56522 .5856 Mdot
.58438 .01185 Mdot
.6945 .06806 Mdot
.97364 .17252 Mdot
.28243 .19084 Mdot
.41509 .08199 Mdot
.4563 .02547 Mdot
.44875 .61337 Mdot
.38428 .57819 Mdot
.20027 .50431 Mdot
.84513 .39854 Mdot
.63865 .49042 Mdot
.56976 .57546 Mdot
.57719 .0046 Mdot
.66848 .05642 Mdot
.91654 .15331 Mdot
.25464 .20896 Mdot
.41298 .09786 Mdot
.4778 .04006 Mdot
.51762 .02461 Mdot
.57731 .03689 Mdot
.72097 .08879 Mdot
.04149 .19809 Mdot
.31565 .16944 Mdot
.42506 .06762 Mdot
.45289 .0172 Mdot
.42825 .60281 Mdot
.32524 .55437 Mdot
.06212 .45542 Mdot
.73057 .41312 Mdot
.57753 .52345 Mdot
.50867 .57548 Mdot
.4496 .58153 Mdot
.33452 .54691 Mdot
.06436 .45107 Mdot
.72344 .40733 Mdot
.55987 .51694 Mdot
.46237 .55777 Mdot
.32274 .53174 Mdot
.02173 .432 Mdot
.69624 .41687 Mdot
.54043 .52174 Mdot
.42981 .54967 Mdot
.24244 .50223 Mdot
.87541 .3912 Mdot
.63523 .46959 Mdot
.53013 .55307 Mdot
.45886 .57399 Mdot
.34162 .54558 Mdot
.07352 .45234 Mdot
.72527 .4028 Mdot
.55469 .51261 Mdot
.4447 .55006 Mdot
.27348 .51221 Mdot
.92437 .40227 Mdot
.65754 .45312 Mdot
.54105 .54604 Mdot
.47043 .57439 Mdot
.36659 .55386 Mdot
.12904 .47122 Mdot
.76114 .39065 Mdot
.57264 .50153 Mdot
.46339 .55052 Mdot
.31314 .52518 Mdot
.99702 .42266 Mdot
.68426 .42474 Mdot
.53623 .52654 Mdot
.42878 .55163 Mdot
.24351 .50353 Mdot
.87855 .39247 Mdot
.63789 .4693 Mdot
.53427 .55399 Mdot
.46907 .57774 Mdot
.36913 .55627 Mdot
.13743 .47483 Mdot
.76902 .39035 Mdot
.57918 .5007 Mdot
.47516 .55375 Mdot
.34317 .53646 Mdot
.0613 .44382 Mdot
.71185 .40207 Mdot
.53711 .51004 Mdot
.40394 .53573 Mdot
.16868 .47264 Mdot
.77655 .37568 Mdot
.56176 .48529 Mdot
.41503 .52735 Mdot
.17678 .47079 Mdot
.77739 .37119 Mdot
.55518 .4807 Mdot
.39409 .51847 Mdot
.12195 .44984 Mdot
.7251 .37277 Mdot
.50591 .48256 Mdot
.29338 .48669 Mdot
.90766 .37964 Mdot
.62052 .44057 Mdot
.45692 .51693 Mdot
.24524 .48721 Mdot
.8538 .37611 Mdot
.60529 .46445 Mdot
.46726 .53273 Mdot
.29249 .51002 Mdot
.94426 .40281 Mdot
.65773 .44095 Mdot
.52166 .53394 Mdot
.40999 .54902 Mdot
.20195 .48946 Mdot
.82219 .38333 Mdot
.6041 .48324 Mdot
.49542 .55087 Mdot
.38157 .54767 Mdot
.14591 .47239 Mdot
.76751 .38417 Mdot
.56788 .49465 Mdot
.44263 .54063 Mdot
.25396 .50143 Mdot
.8855 .39031 Mdot
.63555 .46355 Mdot
.52091 .54718 Mdot
.42983 .56174 Mdot
.262 .51431 Mdot
.91484 .40348 Mdot
.65938 .46015 Mdot
.5554 .55377 Mdot
.51276 .59168 Mdot
.48451 .60058 Mdot
.43879 .58978 Mdot
.32561 .54808 Mdot
.05249 .44924 Mdot
.72113 .41324 Mdot
.56666 .52257 Mdot
.48534 .56777 Mdot
.38747 .55755 Mdot
.17277 .48535 Mdot
.79899 .38702 Mdot
.5966 .49295 Mdot
.4968 .55635 Mdot
.39337 .55411 Mdot
.17826 .48509 Mdot
.80127 .38504 Mdot
.59487 .49048 Mdot
.48944 .55288 Mdot
.3721 .54551 Mdot
.12528 .46549 Mdot
.75107 .38676 Mdot
.5567 .49791 Mdot
.42506 .53667 Mdot
.21183 .48625 Mdot
.8239 .37828 Mdot
.59678 .47766 Mdot
.47239 .54116 Mdot
.31697 .52198 Mdot
.99739 .42052 Mdot
.68076 .42234 Mdot
.52722 .52314 Mdot
.40429 .54206 Mdot
.17961 .47917 Mdot
.79239 .37872 Mdot
.57867 .48595 Mdot
.45028 .53868 Mdot
.2666 .50452 Mdot
.90406 .39397 Mdot
.64349 .45699 Mdot
.52396 .54416 Mdot
.4314 .56083 Mdot
.26369 .51439 Mdot
.9168 .40365 Mdot
.65971 .45914 Mdot
.55428 .55288 Mdot
.509 .59005 Mdot
.4739 .59634 Mdot
.40943 .57819 Mdot
.24806 .5183 Mdot
.90686 .40716 Mdot
.665 .46856 Mdot
.57794 .56423 Mdot
.57547 .61651 Mdot
.65513 .04923 Mdot
.88362 .14121 Mdot
.23221 .21544 Mdot
.40207 .10498 Mdot
.46813 .04083 Mdot
.49842 .01872 Mdot
.52691 .01761 Mdot
.58567 .03631 Mdot
.73662 .09329 Mdot
.06678 .20405 Mdot
.32368 .15877 Mdot
.41965 .05932 Mdot
.42865 .00556 Mdot
.35969 .57541 Mdot
.15193 .48963 Mdot
.79741 .39892 Mdot
.6148 .50518 Mdot
.55097 .57858 Mdot
.54376 .61358 Mdot
.58537 .02572 Mdot
.7189 .08252 Mdot
.02884 .19156 Mdot
.30637 .17152 Mdot
.41523 .06727 Mdot
.43275 .01083 Mdot
.37652 .58328 Mdot
.19434 .50544 Mdot
.84321 .40102 Mdot
.64195 .49365 Mdot
.58065 .58015 Mdot
.60663 .01606 Mdot
.7443 .08508 Mdot
.06169 .19616 Mdot
.31111 .15415 Mdot
.39377 .05109 Mdot
.36511 .60032 Mdot
.20163 .517 Mdot
.86655 .41094 Mdot
.66521 .4936 Mdot
.61878 .58934 Mdot
.69446 .04677 Mdot
.93914 .15122 Mdot
.25093 .1927 Mdot
.38288 .08155 Mdot
.3941 .00694 Mdot
.2943 .55635 Mdot
.02157 .44948 Mdot
.72454 .43446 Mdot
.60506 .54419 Mdot
.59587 .61235 Mdot
.68858 .0573 Mdot
.94791 .16027 Mdot
.26505 .19601 Mdot
.40316 .08535 Mdot
.43846 .02182 Mdot
.40594 .59794 Mdot
.27322 .53601 Mdot
.96256 .42604 Mdot
.69382 .45194 Mdot
.59384 .55624 Mdot
.59385 1e-05 Mdot
.69386 .06181 Mdot
.96266 .16612 Mdot
.27326 .19196 Mdot
.40594 .082 Mdot
.4384 .02007 Mdot
.40299 .59615 Mdot
.26462 .53252 Mdot
.94716 .42183 Mdot
.68832 .45806 Mdot
.59599 .56097 Mdot
.60567 .00598 Mdot
.72616 .07447 Mdot
.0245 .18438 Mdot
.29526 .16734 Mdot
.39339 .06065 Mdot
.37987 .60968 Mdot
.24314 .53353 Mdot
.92672 .42248 Mdot
.69022 .47187 Mdot
.62102 .57527 Mdot
.67577 .03384 Mdot
.89115 .13311 Mdot
.22017 .20334 Mdot
.37249 .09414 Mdot
.39565 .01431 Mdot
.30917 .56458 Mdot
.05512 .46102 Mdot
.74003 .4233 Mdot
.60443 .53423 Mdot
.57854 .60204 Mdot
.63784 .03665 Mdot
.83415 .12133 Mdot
.18575 .2173 Mdot
.37196 .11508 Mdot
.42859 .035 Mdot
.4072 .60482 Mdot
.28679 .54362 Mdot
.99131 .43542 Mdot
.70565 .44149 Mdot
.5929 .54835 Mdot
.57926 .6096 Mdot
.65152 .04466 Mdot
.87028 .1352 Mdot
.21993 .21609 Mdot
.39293 .10692 Mdot
.45386 .03766 Mdot
.46339 .00589 Mdot
.43192 .59858 Mdot
.32583 .55247 Mdot
.05993 .4537 Mdot
.7279 .41283 Mdot
.57398 .52291 Mdot
.50068 .57273 Mdot
.42814 .57321 Mdot
.27714 .52471 Mdot
.9489 .41517 Mdot
.67742 .45025 Mdot
.5674 .55004 Mdot
.53128 .59571 Mdot
.53028 .61742 Mdot
.56328 .0204 Mdot
.66593 .06344 Mdot
.92391 .15944 Mdot
.26463 .21058 Mdot
.42627 .0999 Mdot
.50754 .05023 Mdot
.59734 .0555 Mdot
.79039 .11931 Mdot
.15753 .2269 Mdot
.37433 .13399 Mdot
.46344 .05507 Mdot
.51159 .02976 Mdot
.57283 .03785 Mdot
.71352 .08695 Mdot
.02936 .1952 Mdot
.31221 .17481 Mdot
.42877 .07204 Mdot
.46752 .02394 Mdot
.46981 .00142 Mdot
.43818 .59849 Mdot
.33844 .55639 Mdot
.08592 .46197 Mdot
.74095 .40484 Mdot
.57555 .51581 Mdot
.49233 .56661 Mdot
.40047 .56126 Mdot
.20331 .49619 Mdot
.834 .38978 Mdot
.62005 .48581 Mdot
.52927 .56193 Mdot
.47138 .58225 Mdot
.38131 .56237 Mdot
.16922 .48695 Mdot
.79996 .38982 Mdot
.60175 .49554 Mdot
.51085 .56185 Mdot
.43219 .56942 Mdot
.2792 .52348 Mdot
.94938 .4142 Mdot
.6758 .44895 Mdot
.56288 .54824 Mdot
.51918 .59103 Mdot
.4971 .60439 Mdot
.47175 .60236 Mdot
.41463 .58274 Mdot
.26562 .52594 Mdot
.93762 .41532 Mdot
.67832 .45778 Mdot
.58093 .55785 Mdot
.57111 .61196 Mdot
.639 .04196 Mdot
.84475 .12716 Mdot
.1994 .21919 Mdot
.38322 .11361 Mdot
.4466 .03917 Mdot
.45076 .00257 Mdot
.40015 .58676 Mdot
.24398 .52152 Mdot
.9081 .41044 Mdot
.67038 .47112 Mdot
.59048 .56865 Mdot
.6074 .01046 Mdot
.73668 .0799 Mdot
.04517 .19066 Mdot
.3033 .15954 Mdot
.39158 .05456 Mdot
.36661 .6026 Mdot
.20795 .51997 Mdot
.87568 .41268 Mdot
.67004 .49094 Mdot
.62201 .58835 Mdot
.69875 .04743 Mdot
.94609 .15286 Mdot
.25319 .1898 Mdot
.38048 .07867 Mdot
.38505 .00282 Mdot
.27073 .54738 Mdot
.97808 .43717 Mdot
.71013 .45243 Mdot
.6164 .56011 Mdot
.64279 .01631 Mdot
.80975 .10318 Mdot
.14402 .20659 Mdot
.33687 .11919 Mdot
.37601 .02419 Mdot
.28878 .56413 Mdot
.02703 .45626 Mdot
.73488 .43748 Mdot
.62176 .54812 Mdot
.6332 .00707 Mdot
.77818 .08961 Mdot
.1002 .19902 Mdot
.31633 .13357 Mdot
.368 .03193 Mdot
.28703 .56799 Mdot
.03106 .45984 Mdot
.74021 .43828 Mdot
.62888 .54922 Mdot
.64777 .01168 Mdot
.81067 .10068 Mdot
.14051 .20385 Mdot
.3314 .11798 Mdot
.36547 .02105 Mdot
.26499 .55593 Mdot
.98545 .44527 Mdot
.72233 .45542 Mdot
.63635 .56489 Mdot
.68628 .03086 Mdot
.90183 .13322 Mdot
.22141 .19751 Mdot
.36404 .08815 Mdot
.37105 .00433 Mdot
.24777 .54184 Mdot
.94467 .4307 Mdot
.70284 .46857 Mdot
.63301 .57488 Mdot
.69659 .0393 Mdot
.92999 .14425 Mdot
.23997 .19158 Mdot
.37046 .08065 Mdot
.37021 .61788 Mdot
.23903 .53696 Mdot
.92842 .42607 Mdot
.696 .47439 Mdot
.63317 .5792 Mdot
.70388 .0437 Mdot
.94693 .15021 Mdot
.24884 .18659 Mdot
.37092 .07545 Mdot
.36261 .6129 Mdot
.21762 .52843 Mdot
.8965 .41957 Mdot
.68426 .48686 Mdot
.63674 .58867 Mdot
.72542 .05481 Mdot
.99181 .16464 Mdot
.26745 .17035 Mdot
.36432 .05987 Mdot
.32577 .59421 Mdot
.12739 .49542 Mdot
.79994 .41566 Mdot
.64355 .52138 Mdot
.62826 .60859 Mdot
.74273 .07074 Mdot
.03685 .18178 Mdot
.2897 .15627 Mdot
.36828 .04856 Mdot
.31442 .58475 Mdot
.09526 .48258 Mdot
.77477 .41996 Mdot
.63194 .52976 Mdot
.62172 .61171 Mdot
.73601 .07064 Mdot
.02945 .18136 Mdot
.2898 .16091 Mdot
.37591 .05322 Mdot
.33557 .5931 Mdot
.14076 .49764 Mdot
.80683 .41165 Mdot
.6414 .51579 Mdot
.61556 .60206 Mdot
.70911 .05782 Mdot
.9766 .16532 Mdot
.27044 .1816 Mdot
.38592 .07137 Mdot
.38323 .61638 Mdot
.26013 .54195 Mdot
.95754 .43102 Mdot
.70237 .46033 Mdot
.61904 .56654 Mdot
.65804 .0241 Mdot
.84768 .11721 Mdot
.18435 .20807 Mdot
.35625 .10624 Mdot
.38693 .01896 Mdot
.30031 .5645 Mdot
.04277 .45886 Mdot
.73747 .42935 Mdot
.61147 .54016 Mdot
.60137 .61179 Mdot
.69823 .05986 Mdot
.9655 .16518 Mdot
.27145 .18909 Mdot
.39919 .07895 Mdot
.42049 .01316 Mdot
.35562 .57794 Mdot
.14908 .49038 Mdot
.79765 .40084 Mdot
.61807 .50705 Mdot
.56001 .58215 Mdot
.56815 .00504 Mdot
.65098 .05119 Mdot
.87996 .14151 Mdot
.23208 .21762 Mdot
.4055 .10718 Mdot
.47829 .04499 Mdot
.52663 .02987 Mdot
.60492 .04839 Mdot
.79336 .11647 Mdot
.15502 .22352 Mdot
.36792 .13158 Mdot
.44811 .04956 Mdot
.47071 .01397 Mdot
.46039 .61166 Mdot
.40578 .58428 Mdot
.25082 .52226 Mdot
.91601 .41111 Mdot
.67177 .46708 Mdot
.58607 .56507 Mdot
.59297 .00426 Mdot
.69906 .06556 Mdot
.97585 .17107 Mdot
.27983 .18787 Mdot
.40711 .07866 Mdot
.43529 .01741 Mdot
.39233 .59149 Mdot
.23678 .5219 Mdot
.902 .41113 Mdot
.6711 .47533 Mdot
.59839 .5731 Mdot
.6299 .01948 Mdot
.79245 .10046 Mdot
.12848 .20768 Mdot
.33459 .12739 Mdot
.38567 .03157 Mdot
.31838 .57645 Mdot
.08759 .4754 Mdot
.76275 .41727 Mdot
.61717 .52806 Mdot
.59236 .6027 Mdot
.66615 .0456 Mdot
.89539 .14168 Mdot
.23451 .20959 Mdot
.39464 .09897 Mdot
.44423 .03064 Mdot
.43207 .61052 Mdot
.34547 .56451 Mdot
.11041 .47276 Mdot
.76036 .40169 Mdot
.58977 .51261 Mdot
.51534 .57203 Mdot
.45821 .58273 Mdot
.3544 .55388 Mdot
.10807 .46579 Mdot
.74879 .39599 Mdot
.56935 .50714 Mdot
.46582 .55405 Mdot
.32397 .53036 Mdot
.02135 .431 Mdot
.69468 .41614 Mdot
.53709 .52064 Mdot
.42104 .54631 Mdot
.21938 .4934 Mdot
.8412 .3843 Mdot
.61413 .4777 Mdot
.50526 .55075 Mdot
.40233 .55442 Mdot
.19584 .49041 Mdot
.81981 .38564 Mdot
.6066 .48627 Mdot
.50505 .55527 Mdot
.40921 .5588 Mdot
.21625 .49878 Mdot
.84747 .39012 Mdot
.62585 .48107 Mdot
.53208 .56008 Mdot
.47432 .58233 Mdot
.38766 .56448 Mdot
.18433 .49237 Mdot
.81625 .39055 Mdot
.61266 .49221 Mdot
.52601 .56448 Mdot
.46862 .58256 Mdot
.376 .56079 Mdot
.15701 .48269 Mdot
.78801 .38998 Mdot
.59375 .49798 Mdot
.4994 .55973 Mdot
.40438 .55931 Mdot
.2077 .49648 Mdot
.83749 .38923 Mdot
.62063 .484 Mdot
.52739 .56041 Mdot
.46495 .57945 Mdot
.36323 .55517 Mdot
.12529 .47098 Mdot
.75995 .39224 Mdot
.5741 .50317 Mdot
.46899 .55307 Mdot
.32907 .53156 Mdot
.03105 .43385 Mdot
.69816 .4123 Mdot
.53567 .5176 Mdot
.41313 .5423 Mdot
.19724 .48461 Mdot
.81129 .37951 Mdot
.59202 .48252 Mdot
.47103 .54326 Mdot
.31749 .52314 Mdot
4e-05 .42184 Mdot
.68254 .42181 Mdot
.52897 .52312 Mdot
.40796 .54325 Mdot
.18865 .48249 Mdot
.8027 .3795 Mdot
.58681 .48461 Mdot
.46424 .54228 Mdot
.30159 .51751 Mdot
.96846 .41215 Mdot
.67074 .43403 Mdot
.53102 .53168 Mdot
.42613 .55321 Mdot
.24072 .50345 Mdot
.87578 .39249 Mdot
.63738 .4707 Mdot
.53565 .55516 Mdot
.47387 .57985 Mdot
.3827 .56169 Mdot
.17066 .48698 Mdot
.80066 .38936 Mdot
.60147 .49493 Mdot
.50934 .56109 Mdot
.42775 .56761 Mdot
.26728 .51886 Mdot
.92803 .40837 Mdot
.66736 .45693 Mdot
.56284 .55343 Mdot
.52748 .59619 Mdot
.52304 .61528 Mdot
.54453 .01328 Mdot
.61568 .04397 Mdot
.80633 .11783 Mdot
.16569 .22209 Mdot
.36985 .12618 Mdot
.44278 .04508 Mdot
.45245 .00598 Mdot
.40919 .5913 Mdot
.2688 .53126 Mdot
.94981 .42089 Mdot
.6866 .45536 Mdot
.58916 .55781 Mdot
.58728 .61687 Mdot
.67915 .05678 Mdot
.93334 .1571 Mdot
.26067 .2023 Mdot
.40856 .0914 Mdot
.45873 .031 Mdot
.46277 .0025 Mdot
.42512 .59477 Mdot
.30595 .54438 Mdot
.01794 .44003 Mdot
.7097 .42753 Mdot
.57556 .53514 Mdot
.52365 .58595 Mdot
.49835 .6024 Mdot
.47119 .60125 Mdot
.41165 .58123 Mdot
.25731 .52265 Mdot
.92332 .41162 Mdot
.67267 .46312 Mdot
.58104 .5614 Mdot
.57708 .61559 Mdot
.65685 .0493 Mdot
.88652 .14195 Mdot
.23384 .21465 Mdot
.40223 .10407 Mdot
.46697 .04001 Mdot
.49466 .01711 Mdot
.51632 .01338 Mdot
.55638 .02476 Mdot
.65882 .06331 Mdot
.91238 .15671 Mdot
.26003 .21486 Mdot
.42819 .10393 Mdot
.51794 .05546 Mdot
.6279 .06796 Mdot
.86734 .14798 Mdot
.23992 .23027 Mdot
.43301 .11934 Mdot
.55262 .07392 Mdot
.73061 .11 Mdot
.08711 .22033 Mdot
.35002 .16249 Mdot
.46744 .07257 Mdot
.54833 .04999 Mdot
.68301 .08323 Mdot
.98183 .18468 Mdot
.30114 .19734 Mdot
.44981 .09188 Mdot
.54269 .05741 Mdot
.68324 .08686 Mdot
.98805 .18838 Mdot
.30635 .19672 Mdot
.45595 .09246 Mdot
.55642 .06209 Mdot
.71932 .10068 Mdot
.05874 .20977 Mdot
.33328 .16967 Mdot
.45203 .07339 Mdot
.51739 .0404 Mdot
.60237 .05252 Mdot
.79522 .11919 Mdot
.1607 .22588 Mdot
.37391 .13177 Mdot
.45909 .05264 Mdot
.49853 .02438 Mdot
.53633 .02336 Mdot
.61481 .04851 Mdot
.81207 .12191 Mdot
.17567 .22472 Mdot
.37869 .12547 Mdot
.45751 .04871 Mdot
.48888 .01939 Mdot
.50771 .01163 Mdot
.53524 .01701 Mdot
.60226 .04142 Mdot
.77706 .10803 Mdot
.12911 .21758 Mdot
.35075 .13698 Mdot
.42738 .04736 Mdot
.42478 .61643 Mdot
.34031 .56583 Mdot
.10418 .4721 Mdot
.75856 .40442 Mdot
.59252 .51541 Mdot
.52523 .57645 Mdot
.48633 .59399 Mdot
.43201 .58446 Mdot
.30317 .53841 Mdot
.00443 .4334 Mdot
.70068 .43031 Mdot
.56822 .53617 Mdot
.5105 .58236 Mdot
.46465 .58969 Mdot
.37917 .56521 Mdot
.16991 .4887 Mdot
.80309 .39133 Mdot
.60621 .49635 Mdot
.52062 .56514 Mdot
.45828 .57951 Mdot
.34934 .5507 Mdot
.09447 .46051 Mdot
.739 .39834 Mdot
.56295 .50923 Mdot
.4562 .55206 Mdot
.30058 .52186 Mdot
.97413 .41627 Mdot
.67678 .43426 Mdot
.54057 .53386 Mdot
.44972 .56189 Mdot
.303 .52735 Mdot
.98631 .42231 Mdot
.68507 .43186 Mdot
.54892 .53389 Mdot
.46718 .56751 Mdot
.3486 .54475 Mdot
.08361 .45426 Mdot
.72842 .39852 Mdot
.55143 .50865 Mdot
.43156 .54395 Mdot
.2367 .49761 Mdot
.86262 .38684 Mdot
.62521 .47131 Mdot
.51514 .55001 Mdot
.42216 .56057 Mdot
.24467 .50834 Mdot
.88745 .39726 Mdot
.64707 .46947 Mdot
.55021 .55817 Mdot
.50915 .59266 Mdot
.47842 .59904 Mdot
.42338 .58402 Mdot
.28508 .53256 Mdot
.97128 .42409 Mdot
.68976 .44404 Mdot
.57535 .54733 Mdot
.54295 .59801 Mdot
.55848 .0096 Mdot
.63863 .04953 Mdot
.85636 .13457 Mdot
.21525 .2218 Mdot
.39856 .11329 Mdot
.47485 .04715 Mdot
.52285 .02966 Mdot
.59657 .04556 Mdot
.77284 .10894 Mdot
.12711 .21895 Mdot
.35253 .13932 Mdot
.43416 .05045 Mdot
.44349 .00577 Mdot
.3903 .58516 Mdot
.22274 .51448 Mdot
.87797 .40495 Mdot
.65797 .48207 Mdot
.58858 .57515 Mdot
.61419 .01583 Mdot
.75804 .08891 Mdot
.08151 .19992 Mdot
.31685 .14544 Mdot
.38797 .04396 Mdot
.3427 .59005 Mdot
.14723 .49723 Mdot
.80813 .40846 Mdot
.63701 .51228 Mdot
.60228 .59657 Mdot
.67534 .04515 Mdot
.90881 .1443 Mdot
.23978 .20455 Mdot
.39128 .09363 Mdot
.42925 .02347 Mdot
.38989 .59371 Mdot
.2358 .5228 Mdot
.90257 .41209 Mdot
.67269 .47596 Mdot
.60186 .57425 Mdot
.63842 .0226 Mdot
.81242 .10753 Mdot
.1526 .21025 Mdot
.34558 .11927 Mdot
.39018 .02757 Mdot
.32031 .57485 Mdot
.08786 .47437 Mdot
.76109 .41608 Mdot
.61373 .52696 Mdot
.58423 .5998 Mdot
.64554 .03789 Mdot
.84931 .12594 Mdot
.19904 .21615 Mdot
.37807 .11064 Mdot
.4324 .03358 Mdot
.41261 .60581 Mdot
.29897 .5478 Mdot
.01392 .44187 Mdot
.71316 .43216 Mdot
.58746 .54034 Mdot
.55568 .5984 Mdot
.58555 .01846 Mdot
.70751 .07537 Mdot
.00294 .18258 Mdot
.29505 .18053 Mdot
.41447 .07381 Mdot
.44183 .01691 Mdot
.4049 .59521 Mdot
.26679 .53268 Mdot
.94983 .42215 Mdot
.68863 .4566 Mdot
.59407 .55959 Mdot
.59973 .0035 Mdot
.71085 .06868 Mdot
.99641 .17648 Mdot
.28602 .17899 Mdot
.40038 .07068 Mdot
.40937 .00556 Mdot
.32139 .56366 Mdot
.07135 .4635 Mdot
.74336 .41533 Mdot
.59506 .52638 Mdot
.54791 .58889 Mdot
.55408 .00382 Mdot
.6202 .04086 Mdot
.8096 .11705 Mdot
.16638 .2205 Mdot
.36757 .12434 Mdot
.4358 .04217 Mdot
.43343 .61657 Mdot
.35801 .57142 Mdot
.14259 .4849 Mdot
.78675 .39811 Mdot
.60598 .50632 Mdot
.53632 .57498 Mdot
.50735 .60013 Mdot
.48668 .60526 Mdot
.45097 .59597 Mdot
.36074 .56226 Mdot
.13246 .47695 Mdot
.77119 .39476 Mdot
.58818 .50493 Mdot
.49979 .56341 Mdot
.41117 .56326 Mdot
.2273 .5044 Mdot
.86541 .39438 Mdot
.63812 .47756 Mdot
.54804 .56236 Mdot
.51141 .5954 Mdot
.48767 .60336 Mdot
.45002 .59476 Mdot
.3568 .56042 Mdot
.12274 .47337 Mdot
.76332 .3959 Mdot
.58313 .50667 Mdot
.49265 .56212 Mdot
.39387 .55699 Mdot
.18386 .48824 Mdot
.80931 .38655 Mdot
.60226 .49007 Mdot
.50298 .55667 Mdot
.40706 .55875 Mdot
.21199 .49748 Mdot
.84219 .38948 Mdot
.62289 .4825 Mdot
.52906 .56004 Mdot
.46788 .58022 Mdot
.37066 .55795 Mdot
.14284 .47723 Mdot
.77442 .39034 Mdot
.58374 .50019 Mdot
.48338 .55601 Mdot
.36429 .54443 Mdot
.10975 .46072 Mdot
.74079 .39001 Mdot
.55138 .50097 Mdot
.41903 .53624 Mdot
.19908 .4821 Mdot
.80841 .37659 Mdot
.58561 .48033 Mdot
.45495 .53728 Mdot
.27407 .50624 Mdot
.9154 .39636 Mdot
.64788 .4527 Mdot
.52445 .54175 Mdot
.42854 .55876 Mdot
.25457 .51051 Mdot
.90082 .39941 Mdot
.65204 .46427 Mdot
.55008 .55502 Mdot
.5038 .58943 Mdot
.46181 .59208 Mdot
.37707 .56566 Mdot
.16683 .4881 Mdot
.80075 .39178 Mdot
.60544 .49733 Mdot
.52076 .5657 Mdot
.45948 .58016 Mdot
.3529 .55217 Mdot
.10278 .46345 Mdot
.74442 .39656 Mdot
.5658 .50764 Mdot
.45942 .55229 Mdot
.3077 .52426 Mdot
.98781 .42034 Mdot
.68169 .42884 Mdot
.53909 .52991 Mdot
.44023 .55693 Mdot
.2754 .51616 Mdot
.93301 .40642 Mdot
.6641 .45184 Mdot
.54948 .54719 Mdot
.48987 .5812 Mdot
.41884 .57413 Mdot
.26001 .51987 Mdot
.92168 .40894 Mdot
.66833 .46145 Mdot
.57166 .55829 Mdot
.55326 .60666 Mdot
.59393 .02514 Mdot
.73469 .08699 Mdot
.05447 .19763 Mdot
.31389 .16033 Mdot
.40776 .05802 Mdot
.40314 .61518 Mdot
.29569 .55163 Mdot
.01576 .44503 Mdot
.71805 .43404 Mdot
.59657 .54296 Mdot
.57765 .60634 Mdot
.64303 .04041 Mdot
.84913 .12738 Mdot
.20131 .21766 Mdot
.38199 .11167 Mdot
.44122 .0366 Mdot
.43552 .61451 Mdot
.35892 .5707 Mdot
.14298 .48458 Mdot
.78635 .39762 Mdot
.60489 .50588 Mdot
.53355 .57395 Mdot
.49985 .59721 Mdot
.46599 .5971 Mdot
.39398 .57353 Mdot
.21085 .50485 Mdot
.85328 .39704 Mdot
.639 .4856 Mdot
.56257 .5708 Mdot
.55504 .61338 Mdot
.60847 .03302 Mdot
.77521 .10305 Mdot
.11954 .21281 Mdot
.34114 .13695 Mdot
.41158 .04353 Mdot
.38716 .60294 Mdot
.24566 .53058 Mdot
.92438 .41947 Mdot
.68537 .47032 Mdot
.61158 .57243 Mdot
.6538 .02609 Mdot
.844 .11755 Mdot
.18358 .20987 Mdot
.35875 .10826 Mdot
.39445 .02206 Mdot
.31942 .57167 Mdot
.08139 .47092 Mdot
.75535 .41653 Mdot
.60904 .52761 Mdot
.57655 .59795 Mdot
.62725 .03134 Mdot
.8069 .11103 Mdot
.15503 .21515 Mdot
.35439 .12321 Mdot
.41123 .03513 Mdot
.37288 .59433 Mdot
.20566 .51469 Mdot
.86554 .40783 Mdot
.65992 .49095 Mdot
.60609 .58477 Mdot
.66346 .03546 Mdot
.87475 .13058 Mdot
.2134 .2093 Mdot
.37695 .10108 Mdot
.41488 .02345 Mdot
.36116 .58483 Mdot
.1697 .4997 Mdot
.8208 .40241 Mdot
.63425 .50274 Mdot
.58203 .58576 Mdot
.61847 .02252 Mdot
.77674 .09782 Mdot
.11233 .20741 Mdot
.33127 .13531 Mdot
.39329 .03834 Mdot
.34357 .58731 Mdot
.14421 .49482 Mdot
.80329 .40733 Mdot
.63223 .51231 Mdot
.59397 .59439 Mdot
.65585 .03824 Mdot
.867 .1305 Mdot
.21155 .21295 Mdot
.38148 .10502 Mdot
.42953 .02969 Mdot
.40051 .6001 Mdot
.26626 .53506 Mdot
.9531 .42449 Mdot
.69217 .45677 Mdot
.59935 .56066 Mdot
.61164 .00759 Mdot
.73998 .07932 Mdot
.04782 .19025 Mdot
.30243 .15736 Mdot
.38686 .05218 Mdot
.35395 .59769 Mdot
.17821 .50942 Mdot
.84061 .40939 Mdot
.65449 .50301 Mdot
.61679 .59473 Mdot
.69954 .05114 Mdot
.95316 .15675 Mdot
.25895 .18899 Mdot
.38519 .07802 Mdot
.39264 .00461 Mdot
.28777 .55322 Mdot
.0081 .44519 Mdot
.71928 .43953 Mdot
.60696 .54862 Mdot
.60661 .61782 Mdot
.71793 .0688 Mdot
.00546 .1777 Mdot
.28682 .17389 Mdot
.39312 .0657 Mdot
.38753 .61458 Mdot
.26516 .54241 Mdot
.96376 .43176 Mdot
.70296 .45685 Mdot
.61421 .56318 Mdot
.64371 .01824 Mdot
.81443 .10551 Mdot
.15045 .20767 Mdot
.34068 .11757 Mdot
.37947 .02398 Mdot
.29472 .56565 Mdot
.03717 .45886 Mdot
.738 .43314 Mdot
.61817 .54397 Mdot
.61993 .00109 Mdot
.74475 .07714 Mdot
.04931 .18823 Mdot
.29904 .15434 Mdot
.3774 .04843 Mdot
.33051 .58906 Mdot
.12631 .49183 Mdot
.79389 .41259 Mdot
.63453 .51954 Mdot
.60971 .6027 Mdot
.69928 .05536 Mdot
.95964 .16091 Mdot
.26512 .18879 Mdot
.39156 .07815 Mdot
.40474 .00814 Mdot
.31657 .56355 Mdot
.06407 .46198 Mdot
.74111 .41843 Mdot
.59771 .52941 Mdot
.55792 .59344 Mdot
.58214 .01497 Mdot
.69512 .06983 Mdot
.97736 .17443 Mdot
.2851 .19019 Mdot
.41734 .08173 Mdot
.46032 .02656 Mdot
.45892 .61717 Mdot
.41162 .5888 Mdot
.26949 .5302 Mdot
.94887 .41988 Mdot
.68504 .45498 Mdot
.58627 .557 Mdot
.58029 .61434 Mdot
.66125 .05003 Mdot
.8948 .14434 Mdot
.23876 .21258 Mdot
.40332 .1017 Mdot
.46523 .03826 Mdot
.48817 .01418 Mdot
.49775 .00592 Mdot
.5048 .00435 Mdot
.51726 .0077 Mdot
.54918 .01973 Mdot
.63581 .05354 Mdot
.85793 .13728 Mdot
.22011 .22384 Mdot
.4056 .11464 Mdot
.49058 .05252 Mdot
.5649 .04594 Mdot
.71056 .09002 Mdot
.03056 .19777 Mdot
.31624 .17656 Mdot
.43743 .0749 Mdot
.48973 .03232 Mdot
.53044 .02516 Mdot
.60533 .04629 Mdot
.79075 .1146 Mdot
.15015 .22212 Mdot
.36396 .13214 Mdot
.44207 .04828 Mdot
.45617 .00871 Mdot
.42137 .59653 Mdot
.30129 .54382 Mdot
.01062 .43839 Mdot
.70796 .43098 Mdot
.57891 .53827 Mdot
.53541 .59115 Mdot
.53159 .61567 Mdot
.56323 .01956 Mdot
.66445 .06256 Mdot
.92016 .15804 Mdot
.26235 .21148 Mdot
.42524 .10067 Mdot
.50671 .05036 Mdot
.59578 .05504 Mdot
.78665 .11797 Mdot
.15263 .22618 Mdot
.37138 .1352 Mdot
.4601 .05483 Mdot
.50419 .02725 Mdot
.55303 .03018 Mdot
.66069 .06654 Mdot
.92062 .16064 Mdot
.26657 .21381 Mdot
.43366 .10326 Mdot
.52792 .05826 Mdot
.65358 .07766 Mdot
.92708 .16903 Mdot
.28013 .21819 Mdot
.45654 .10903 Mdot
.58444 .07905 Mdot
.80336 .1353 Mdot
.19211 .24026 Mdot
.41278 .13638 Mdot
.53974 .07847 Mdot
.71116 .10594 Mdot
.05708 .21379 Mdot
.33988 .17478 Mdot
.47076 .08089 Mdot
.56878 .06058 Mdot
.74212 .10713 Mdot
.09508 .21814 Mdot
.34688 .15562 Mdot
.45114 .06444 Mdot
.50106 .03085 Mdot
.55216 .03159 Mdot
.66116 .06736 Mdot
.92271 .16164 Mdot
.2682 .21353 Mdot
.43503 .1031 Mdot
.53045 .05898 Mdot
.66008 .08011 Mdot
.94159 .17399 Mdot
.28764 .21387 Mdot
.45885 .10581 Mdot
.58407 .07739 Mdot
.79993 .13341 Mdot
.18686 .23914 Mdot
.40791 .13662 Mdot
.53061 .07583 Mdot
.68769 .09708 Mdot
.01101 .19982 Mdot
.3219 .19214 Mdot
.47098 .09214 Mdot
.58745 .07198 Mdot
.79784 .13003 Mdot
.18001 .23619 Mdot
.39944 .13562 Mdot
.51267 .06997 Mdot
.64019 .07881 Mdot
.90641 .16454 Mdot
.2724 .22619 Mdot
.46033 .11614 Mdot
.60388 .08872 Mdot
.85667 .15623 Mdot
.2504 .24334 Mdot
.46428 .13219 Mdot
.63813 .10745 Mdot
.94921 .19225 Mdot
.31671 .22713 Mdot
.51993 .1256 Mdot
.74562 .13948 Mdot
.15108 .25059 Mdot
.41033 .16023 Mdot
.57353 .10086 Mdot
.81689 .15041 Mdot
.22445 .25188 Mdot
.45447 .14216 Mdot
.63375 .1108 Mdot
.94699 .19359 Mdot
.31903 .22993 Mdot
.52788 .12908 Mdot
.76807 .14845 Mdot
.18695 .25888 Mdot
.43991 .15634 Mdot
.62658 .11537 Mdot
.94167 .19474 Mdot
.32121 .23457 Mdot
.5386 .13436 Mdot
.7992 .16105 Mdot
.23111 .26694 Mdot
.48444 .15657 Mdot
.72022 .14572 Mdot
.1327 .25493 Mdot
.41201 .17262 Mdot
.59689 .11426 Mdot
.88461 .17782 Mdot
.29159 .25153 Mdot
.52484 .14415 Mdot
.78604 .16143 Mdot
.2225 .26974 Mdot
.48179 .16025 Mdot
.72054 .14756 Mdot
.13606 .25681 Mdot
.41589 .17294 Mdot
.60504 .1169 Mdot
.90445 .18505 Mdot
.30546 .24784 Mdot
.53744 .14337 Mdot
.81134 .16928 Mdot
.25189 .27228 Mdot
.51261 .16113 Mdot
.78756 .16993 Mdot
.23737 .278 Mdot
.5079 .1672 Mdot
.78736 .17271 Mdot
.24172 .28082 Mdot
.51649 .16982 Mdot
.80986 .18131 Mdot
.2705 .28469 Mdot
.55279 .17446 Mdot
.89365 .21066 Mdot
.34593 .27953 Mdot
.65007 .18797 Mdot
.09976 .27792 Mdot
.44395 .21273 Mdot
.72611 .17439 Mdot
.1861 .28429 Mdot
.48054 .18198 Mdot
.75306 .16842 Mdot
.20538 .27955 Mdot
.48488 .17274 Mdot
.74732 .1622 Mdot
.18959 .27333 Mdot
.4648 .17009 Mdot
.70058 .14572 Mdot
.10759 .25155 Mdot
.40208 .182 Mdot
.59277 .11785 Mdot
.88244 .17903 Mdot
.29321 .25387 Mdot
.53071 .14679 Mdot
.8027 .1681 Mdot
.24477 .27321 Mdot
.50708 .16212 Mdot
.7774 .16707 Mdot
.22491 .27657 Mdot
.4948 .1668 Mdot
.75882 .16317 Mdot
.2024 .27415 Mdot
.47413 .16793 Mdot
.71674 .14994 Mdot
.13529 .25868 Mdot
.41872 .17517 Mdot
.61424 .12084 Mdot
.92804 .19394 Mdot
.32042 .2425 Mdot
.55027 .14205 Mdot
.83597 .17658 Mdot
.27592 .2719 Mdot
.5384 .16222 Mdot
.84385 .18878 Mdot
.29878 .28116 Mdot
.58224 .17519 Mdot
.95454 .2301 Mdot
.37752 .26141 Mdot
.67536 .18407 Mdot
.13362 .28322 Mdot
.45802 .20049 Mdot
.73552 .17151 Mdot
.19212 .2822 Mdot
.48064 .17832 Mdot
.74734 .16483 Mdot
.19385 .27596 Mdot
.4716 .17166 Mdot
.71743 .15193 Mdot
.13934 .26076 Mdot
.42316 .17541 Mdot
.62349 .12381 Mdot
.94977 .20165 Mdot
.33187 .23615 Mdot
.55741 .13939 Mdot
.84642 .17862 Mdot
.28327 .26999 Mdot
.54419 .16126 Mdot
.8544 .19172 Mdot
.30714 .2798 Mdot
.59149 .17574 Mdot
.97362 .23617 Mdot
.38543 .25451 Mdot
.67866 .18123 Mdot
.13397 .2814 Mdot
.45515 .1985 Mdot
.72632 .16759 Mdot
.17534 .27751 Mdot
.46395 .17837 Mdot
.71216 .15341 Mdot
.13516 .26143 Mdot
.42314 .17798 Mdot
.6276 .12636 Mdot
.96128 .20623 Mdot
.33829 .233 Mdot
.56242 .13852 Mdot
.85529 .181 Mdot
.29007 .26871 Mdot
.55066 .16106 Mdot
.86755 .19585 Mdot
.31742 .27803 Mdot
.60334 .17671 Mdot
.99799 .24391 Mdot
.39492 .24531 Mdot
.68154 .17714 Mdot
.13162 .27817 Mdot
.44935 .19637 Mdot
.71082 .16159 Mdot
.14671 .26939 Mdot
.43932 .18084 Mdot
.665 .13948 Mdot
.04549 .23515 Mdot
.37527 .20382 Mdot
.5781 .12535 Mdot
.86568 .17773 Mdot
.28765 .2608 Mdot
.53479 .15274 Mdot
.82094 .17685 Mdot
.26936 .27714 Mdot
.53926 .16681 Mdot
.85308 .19395 Mdot
.31032 .28259 Mdot
.60049 .17933 Mdot
.9968 .24494 Mdot
.39673 .24717 Mdot
.68799 .18001 Mdot
.14561 .28282 Mdot
.4607 .19474 Mdot
.73184 .16757 Mdot
.18165 .278 Mdot
.46795 .17694 Mdot
.71828 .15471 Mdot
.14489 .26366 Mdot
.42947 .17588 Mdot
.63694 .12822 Mdot
.98074 .21249 Mdot
.34626 .2259 Mdot
.56383 .13447 Mdot
.85161 .17786 Mdot
.28381 .26712 Mdot
.54021 .15846 Mdot
.84157 .18625 Mdot
.29381 .2795 Mdot
.57299 .17254 Mdot
.93178 .22175 Mdot
.36532 .26794 Mdot
.6642 .18472 Mdot
.11741 .2801 Mdot
.44966 .20534 Mdot
.72597 .17077 Mdot
.18008 .28066 Mdot
.47143 .18006 Mdot
.73065 .16021 Mdot
.16839 .27054 Mdot
.44942 .17368 Mdot
.67425 .13895 Mdot
.05893 .23775 Mdot
.37853 .19752 Mdot
.57382 .12069 Mdot
.84957 .17042 Mdot
.2711 .26052 Mdot
.51436 .15035 Mdot
.77383 .16036 Mdot
.21113 .27027 Mdot
.47393 .16242 Mdot
.70739 .14429 Mdot
.11428 .25148 Mdot
.40286 .17835 Mdot
.58835 .11464 Mdot
.86862 .17322 Mdot
.28106 .2549 Mdot
.51706 .14586 Mdot
.77231 .15775 Mdot
.20564 .26781 Mdot
.46606 .16095 Mdot
.68843 .13743 Mdot
.07735 .24037 Mdot
.38227 .18845 Mdot
.56595 .11352 Mdot
.82204 .15827 Mdot
.23986 .25823 Mdot
.4782 .1473 Mdot
.69199 .13213 Mdot
.07382 .23598 Mdot
.37519 .18626 Mdot
.54953 .10775 Mdot
.77895 .14179 Mdot
.18525 .25111 Mdot
.42638 .14903 Mdot
.58726 .09943 Mdot
.84186 .15736 Mdot
.24718 .2505 Mdot
.47268 .13937 Mdot
.66747 .12038 Mdot
.01845 .21692 Mdot
.34863 .20406 Mdot
.53241 .11358 Mdot
.75257 .13606 Mdot
.15254 .2472 Mdot
.40535 .15624 Mdot
.5574 .09397 Mdot
.77291 .13319 Mdot
.1664 .24319 Mdot
.4043 .14703 Mdot
.54045 .08415 Mdot
.72181 .11209 Mdot
.08021 .2215 Mdot
.35176 .16783 Mdot
.47898 .07863 Mdot
.58254 .064 Mdot
.77523 .11909 Mdot
.14551 .22885 Mdot
.37333 .1408 Mdot
.47266 .06139 Mdot
.54125 .04239 Mdot
.65594 .07088 Mdot
.91997 .16318 Mdot
.27067 .21674 Mdot
.44304 .10653 Mdot
.55241 .06759 Mdot
.71993 .10354 Mdot
.0641 .21271 Mdot
.33778 .16914 Mdot
.45828 .07447 Mdot
.53217 .04567 Mdot
.64217 .06798 Mdot
.89228 .15458 Mdot
.25504 .22419 Mdot
.43804 .1131 Mdot
.55278 .07091 Mdot
.72607 .1071 Mdot
.07717 .21699 Mdot
.34445 .16519 Mdot
.46263 .07304 Mdot
.53898 .04718 Mdot
.65893 .07414 Mdot
.93008 .16758 Mdot
.27772 .21485 Mdot
.44824 .10539 Mdot
.5613 .06987 Mdot
.74191 .11163 Mdot
.10215 .22264 Mdot
.35471 .1561 Mdot
.46498 .06815 Mdot
.536 .04389 Mdot
.64734 .06882 Mdot
.9024 .15763 Mdot
.26096 .2216 Mdot
.44011 .11072 Mdot
.55315 .06987 Mdot
.72516 .1063 Mdot
.07482 .2161 Mdot
.34302 .16575 Mdot
.46122 .07305 Mdot
.53602 .04623 Mdot
.65118 .07117 Mdot
.91263 .16158 Mdot
.26792 .21958 Mdot
.4445 .10913 Mdot
.55963 .07115 Mdot
.74057 .11183 Mdot
.10105 .22279 Mdot
.35486 .15686 Mdot
.46646 .06897 Mdot
.54044 .04572 Mdot
.65964 .07367 Mdot
.93047 .16738 Mdot
.27739 .21441 Mdot
.44712 .1049 Mdot
.5582 .06865 Mdot
.73359 .1084 Mdot
.08787 .21896 Mdot
.34782 .16066 Mdot
.46085 .06985 Mdot
.53008 .04279 Mdot
.63309 .06367 Mdot
.86958 .14616 Mdot
.23749 .22738 Mdot
.42611 .11657 Mdot
.53421 .06681 Mdot
.68067 .09052 Mdot
.99018 .19129 Mdot
.31078 .19814 Mdot
.46449 .095 Mdot
.5784 .0704 Mdot
.77737 .12297 Mdot
.15353 .23248 Mdot
.38189 .14113 Mdot
.48869 .06601 Mdot
.58272 .05811 Mdot
.76607 .11332 Mdot
.12835 .2239 Mdot
.36081 .14367 Mdot
.45529 .05839 Mdot
.4999 .02757 Mdot
.5444 .0275 Mdot
.63843 .05811 Mdot
.8699 .14305 Mdot
.23255 .22413 Mdot
.41643 .11364 Mdot
.51015 .05792 Mdot
.61534 .06501 Mdot
.83975 .13869 Mdot
.21616 .23263 Mdot
.41677 .12399 Mdot
.52757 .06848 Mdot
.66936 .08763 Mdot
.96839 .18481 Mdot
.30291 .20674 Mdot
.46743 .10168 Mdot
.59541 .07909 Mdot
.82486 .14181 Mdot
.21462 .24089 Mdot
.42896 .13247 Mdot
.56568 .08449 Mdot
.77452 .12907 Mdot
.16107 .2389 Mdot
.39513 .14466 Mdot
.51908 .07661 Mdot
.66455 .0899 Mdot
.96456 .18541 Mdot
.30428 .20996 Mdot
.47453 .10522 Mdot
.61611 .0875 Mdot
.87755 .16158 Mdot
.26411 .23891 Mdot
.47154 .12819 Mdot
.64697 .10842 Mdot
.96585 .19708 Mdot
.32303 .22075 Mdot
.51897 .1211 Mdot
.73628 .13431 Mdot
.13278 .24505 Mdot
.39604 .16271 Mdot
.55001 .09516 Mdot
.75957 .12951 Mdot
.14865 .24046 Mdot
.39313 .1511 Mdot
.52573 .08195 Mdot
.68727 .09984 Mdot
.01487 .20247 Mdot
.32569 .1921 Mdot
.47662 .09328 Mdot
.60123 .07701 Mdot
.83267 .14304 Mdot
.22024 .23953 Mdot
.43109 .13032 Mdot
.56649 .08368 Mdot
.77485 .12878 Mdot
.16087 .23857 Mdot
.39452 .1444 Mdot
.51751 .07601 Mdot
.66024 .08821 Mdot
.95496 .18215 Mdot
.2999 .21319 Mdot
.47377 .10745 Mdot
.61812 .08922 Mdot
.88402 .16434 Mdot
.26969 .23835 Mdot
.47688 .12805 Mdot
.65805 .11197 Mdot
.98987 .20508 Mdot
.33313 .21215 Mdot
.52052 .11582 Mdot
.73105 .13011 Mdot
.12014 .24047 Mdot
.38601 .16431 Mdot
.5338 .09134 Mdot
.71949 .11476 Mdot
.08173 .22388 Mdot
.35562 .16927 Mdot
.48784 .08172 Mdot
.60634 .07323 Mdot
.83626 .1421 Mdot
.22025 .23732 Mdot
.42752 .1281 Mdot
.5557 .07922 Mdot
.74555 .11733 Mdot
.11518 .22844 Mdot
.36572 .15484 Mdot
.48189 .0718 Mdot
.57765 .05918 Mdot
.75771 .11128 Mdot
.1174 .2223 Mdot
.35614 .14755 Mdot
.45356 .06021 Mdot
.49926 .02824 Mdot
.54411 .02772 Mdot
.63818 .05814 Mdot
.8695 .14296 Mdot
.23231 .22423 Mdot
.41638 .11376 Mdot
.51025 .05801 Mdot
.61569 .06517 Mdot
.84065 .13903 Mdot
.21707 .23264 Mdot
.41747 .12386 Mdot
.52874 .06877 Mdot
.67232 .08873 Mdot
.97473 .1869 Mdot
.30558 .20448 Mdot
.46744 .10004 Mdot
.59277 .07746 Mdot
.81709 .13864 Mdot
.20551 .24006 Mdot
.42107 .13322 Mdot
.55104 .08033 Mdot
.73771 .11537 Mdot
.10369 .22619 Mdot
.36061 .15879 Mdot
.47941 .07342 Mdot
.57499 .05908 Mdot
.75222 .10953 Mdot
.10928 .22067 Mdot
.35233 .15021 Mdot
.45144 .06125 Mdot
.49652 .02786 Mdot
.53767 .02543 Mdot
.621 .0515 Mdot
.82826 .12809 Mdot
.19406 .22608 Mdot
.39101 .12172 Mdot
.4742 .05141 Mdot
.52836 .03347 Mdot
.61439 .05317 Mdot
.81884 .12636 Mdot
.18658 .22727 Mdot
.38856 .12483 Mdot
.47464 .05321 Mdot
.5322 .03557 Mdot
.6259 .05791 Mdot
.8475 .13695 Mdot
.21623 .22789 Mdot
.40915 .11923 Mdot
.5049 .05918 Mdot
.60619 .0626 Mdot
.81877 .13138 Mdot
.19466 .23232 Mdot
.40147 .12782 Mdot
.50393 .06332 Mdot
.61081 .06606 Mdot
.83304 .13735 Mdot
.21119 .23371 Mdot
.41481 .12584 Mdot
.5267 .06915 Mdot
.66861 .08771 Mdot
.96736 .18464 Mdot
.30273 .20727 Mdot
.46805 .10217 Mdot
.5975 .08 Mdot
.83036 .14391 Mdot
.22062 .2412 Mdot
.43409 .13193 Mdot
.5752 .08721 Mdot
.79817 .1378 Mdot
.19281 .2439 Mdot
.41908 .13985 Mdot
.55782 .08574 Mdot
.76046 .12524 Mdot
.14255 .23615 Mdot
.38425 .14938 Mdot
.50639 .07549 Mdot
.63575 .07995 Mdot
.90058 .16367 Mdot
.27058 .22868 Mdot
.46225 .11845 Mdot
.61165 .09234 Mdot
.87712 .16407 Mdot
.26805 .24161 Mdot
.4803 .13117 Mdot
.67034 .11745 Mdot
.01817 .21497 Mdot
.34551 .20231 Mdot
.52443 .11058 Mdot
.73084 .12757 Mdot
.1158 .23792 Mdot
.38115 .16399 Mdot
.52433 .08849 Mdot
.6949 .10542 Mdot
.03465 .20998 Mdot
.33555 .18597 Mdot
.48197 .09049 Mdot
.60806 .07793 Mdot
.84708 .14773 Mdot
.23352 .23883 Mdot
.44107 .12828 Mdot
.58355 .08806 Mdot
.81617 .14377 Mdot
.21331 .24545 Mdot
.43536 .13724 Mdot
.58637 .09333 Mdot
.83026 .15073 Mdot
.2316 .24804 Mdot
.4543 .13764 Mdot
.62607 .10616 Mdot
.92586 .18528 Mdot
.30643 .23521 Mdot
.51834 .13097 Mdot
.75094 .14375 Mdot
.16337 .2549 Mdot
.42195 .15981 Mdot
.59583 .10746 Mdot
.87158 .17042 Mdot
.2772 .25069 Mdot
.50559 .14115 Mdot
.7403 .14506 Mdot
.15452 .256 Mdot
.4203 .16426 Mdot
.59974 .1109 Mdot
.88465 .17608 Mdot
.28879 .24977 Mdot
.5184 .14191 Mdot
.76876 .15473 Mdot
.19771 .26511 Mdot
.45644 .1599 Mdot
.66656 .12986 Mdot
.03236 .22608 Mdot
.36185 .20363 Mdot
.55411 .11882 Mdot
.80633 .15588 Mdot
.22725 .26014 Mdot
.47017 .15013 Mdot
.67956 .12941 Mdot
.05147 .22985 Mdot
.36623 .19453 Mdot
.547 .11173 Mdot
.78013 .14408 Mdot
.18988 .25324 Mdot
.43247 .14993 Mdot
.60102 .10417 Mdot
.8762 .17007 Mdot
.27759 .24807 Mdot
.50183 .13859 Mdot
.72815 .13987 Mdot
.13262 .24997 Mdot
.40398 .16771 Mdot
.57329 .10464 Mdot
.82253 .15404 Mdot
.23326 .25385 Mdot
.46514 .14331 Mdot
.65795 .11916 Mdot
.00134 .21223 Mdot
.34322 .21129 Mdot
.53523 .11867 Mdot
.76674 .14308 Mdot
.17709 .25361 Mdot
.42614 .15392 Mdot
.5947 .10417 Mdot
.86406 .16648 Mdot
.26903 .25028 Mdot
.49543 .13993 Mdot
.71667 .13673 Mdot
.11383 .24546 Mdot
.39305 .17257 Mdot
.56031 .10337 Mdot
.79409 .14449 Mdot
.20086 .2514 Mdot
.43629 .1455 Mdot
.60164 .10219 Mdot
.87419 .16845 Mdot
.27456 .24744 Mdot
.49722 .13761 Mdot
.71673 .13567 Mdot
.11217 .2444 Mdot
.3911 .17239 Mdot
.55634 .10213 Mdot
.78393 .14066 Mdot
.18729 .24929 Mdot
.42459 .14666 Mdot
.57982 .09594 Mdot
.82151 .14938 Mdot
.2252 .24949 Mdot
.45122 .13969 Mdot
.62298 .10615 Mdot
.9203 .18375 Mdot
.30395 .23711 Mdot
.518 .13229 Mdot
.75236 .14484 Mdot
.16653 .25598 Mdot
.42504 .15976 Mdot
.60193 .10932 Mdot
.88628 .17574 Mdot
.28848 .24857 Mdot
.51606 .14065 Mdot
.76177 .15185 Mdot
.18683 .2627 Mdot
.44602 .16019 Mdot
.64538 .12321 Mdot
.98712 .2112 Mdot
.34339 .22019 Mdot
.54991 .12763 Mdot
.8119 .16192 Mdot
.2403 .26477 Mdot
.4892 .15382 Mdot
.72589 .14629 Mdot
.14037 .25616 Mdot
.41601 .17035 Mdot
.60109 .11438 Mdot
.89287 .18033 Mdot
.29677 .24962 Mdot
.52854 .14324 Mdot
.79238 .16306 Mdot
.22973 .2703 Mdot
.48869 .16005 Mdot
.73487 .15215 Mdot
.16009 .2628 Mdot
.43341 .16892 Mdot
.63365 .12376 Mdot
.96778 .2065 Mdot
.33807 .22885 Mdot
.55536 .13429 Mdot
.83395 .17218 Mdot
.26794 .26822 Mdot
.52322 .15778 Mdot
.80466 .17394 Mdot
.25544 .2786 Mdot
.52648 .16751 Mdot
.82731 .18592 Mdot
.28717 .28421 Mdot
.57208 .17608 Mdot
.93568 .22472 Mdot
.37 .26842 Mdot
.67322 .1874 Mdot
.13576 .28586 Mdot
.46283 .20214 Mdot
.74827 .17641 Mdot
.21355 .28756 Mdot
.50368 .17931 Mdot
.79797 .18188 Mdot
.26399 .28802 Mdot
.55087 .1773 Mdot
.89425 .21222 Mdot
.34853 .28076 Mdot
.65634 .19024 Mdot
.11374 .28269 Mdot
.45328 .20985 Mdot
.74078 .17769 Mdot
.20782 .28865 Mdot
.5013 .18138 Mdot
.79625 .18229 Mdot
.2635 .28878 Mdot
.55156 .17803 Mdot
.89685 .21341 Mdot
.35072 .2805 Mdot
.65956 .19088 Mdot
.11999 .28456 Mdot
.45731 .20848 Mdot
.74698 .17902 Mdot
.21645 .29015 Mdot
.51006 .18146 Mdot
.81504 .18849 Mdot
.28505 .29048 Mdot
.57956 .18202 Mdot
.96028 .23529 Mdot
.38541 .26275 Mdot
.69197 .18946 Mdot
.16655 .29331 Mdot
.48545 .19709 Mdot
.78792 .18694 Mdot
.26516 .29495 Mdot
.56337 .1843 Mdot
.93131 .2274 Mdot
.37448 .2739 Mdot
.69007 .19504 Mdot
.1729 .29841 Mdot
.49658 .20005 Mdot
.8164 .19766 Mdot
.30064 .29928 Mdot
.61406 .1937 Mdot
.04562 .26672 Mdot
.42633 .23529 Mdot
.72673 .18566 Mdot
.20506 .29562 Mdot
.51067 .18888 Mdot
.82832 .19632 Mdot
.30448 .29428 Mdot
.61123 .18958 Mdot
.03368 .26109 Mdot
.41835 .23774 Mdot
.71477 .18319 Mdot
.18664 .29163 Mdot
.49273 .18917 Mdot
.7906 .1841 Mdot
.2625 .29165 Mdot
.5551 .18084 Mdot
.90874 .21856 Mdot
.35994 .27886 Mdot
.67253 .19319 Mdot
.14407 .29143 Mdot
.47415 .204 Mdot
.77516 .18603 Mdot
.25377 .2958 Mdot
.55258 .18468 Mdot
.90974 .22073 Mdot
.36351 .28045 Mdot
.68127 .19639 Mdot
.16236 .29733 Mdot
.4902 .20261 Mdot
.80696 .19577 Mdot
.29217 .29988 Mdot
.60381 .1926 Mdot
.02461 .26007 Mdot
.41771 .24295 Mdot
.72192 .18801 Mdot
.20318 .29744 Mdot
.51232 .19106 Mdot
.83538 .19966 Mdot
.31301 .2952 Mdot
.62471 .19264 Mdot
.06336 .2711 Mdot
.43228 .22801 Mdot
.72698 .18213 Mdot
.19964 .29212 Mdot
.50138 .18649 Mdot
.80469 .18745 Mdot
.27733 .29211 Mdot
.57276 .18259 Mdot
.94759 .23166 Mdot
.38057 .2676 Mdot
.69092 .1918 Mdot
.16886 .29538 Mdot
.48983 .19837 Mdot
.79931 .19127 Mdot
.28007 .29713 Mdot
.58419 .18796 Mdot
.97907 .24405 Mdot
.39753 .25862 Mdot
.70804 .1919 Mdot
.19218 .29921 Mdot
.50821 .19532 Mdot
.83352 .20105 Mdot
.31447 .29725 Mdot
.63013 .19509 Mdot
.077 .27618 Mdot
.44021 .22448 Mdot
.73744 .1837 Mdot
.21395 .2945 Mdot
.51522 .18619 Mdot
.83364 .1968 Mdot
.30765 .29295 Mdot
.61347 .18901 Mdot
.03694 .26171 Mdot
.41903 .23615 Mdot
.71354 .18201 Mdot
.18318 .29026 Mdot
.4886 .18876 Mdot
.78116 .18081 Mdot
.25012 .28983 Mdot
.53923 .17868 Mdot
.87224 .20581 Mdot
.3346 .28575 Mdot
.64193 .18994 Mdot
.08922 .27644 Mdot
.44089 .21734 Mdot
.72728 .177 Mdot
.19169 .28702 Mdot
.48819 .18325 Mdot
.77135 .17501 Mdot
.23275 .28516 Mdot
.51535 .17466 Mdot
.81528 .18536 Mdot
.28013 .2873 Mdot
.56835 .17813 Mdot
.93146 .22441 Mdot
.36965 .27081 Mdot
.67646 .18962 Mdot
.14425 .28911 Mdot
.47046 .20161 Mdot
.76348 .1811 Mdot
.2357 .29185 Mdot
.52881 .18115 Mdot
.85428 .20115 Mdot
.32236 .28929 Mdot
.62886 .18943 Mdot
.06557 .2699 Mdot
.43027 .2254 Mdot
.71867 .17824 Mdot
.18343 .28724 Mdot
.48386 .18567 Mdot
.76608 .17442 Mdot
.22722 .285 Mdot
.51036 .17499 Mdot
.8052 .18222 Mdot
.26918 .28675 Mdot
.55461 .17641 Mdot
.90056 .2138 Mdot
.3517 .27882 Mdot
.65849 .1896 Mdot
.11619 .28288 Mdot
.45396 .20875 Mdot
.74042 .17704 Mdot
.20641 .28799 Mdot
.49925 .18099 Mdot
.79125 .18046 Mdot
.25708 .2879 Mdot
.54325 .17686 Mdot
.87769 .20669 Mdot
.33713 .28395 Mdot
.64301 .18905 Mdot
.08962 .27601 Mdot
.44022 .21668 Mdot
.72485 .17591 Mdot
.18708 .28567 Mdot
.48334 .1831 Mdot
.7608 .17148 Mdot
.21769 .28238 Mdot
.49843 .17351 Mdot
.77741 .17241 Mdot
.23356 .28192 Mdot
.51084 .17136 Mdot
.80034 .17892 Mdot
.26077 .28456 Mdot
.54177 .17366 Mdot
.86942 .2025 Mdot
.32862 .2838 Mdot
.62948 .18594 Mdot
.06103 .26671 Mdot
.4253 .22513 Mdot
.70822 .17485 Mdot
.16482 .2822 Mdot
.46672 .18659 Mdot
.7313 .16352 Mdot
.17448 .2739 Mdot
.45769 .17503 Mdot
.69364 .14583 Mdot
.09828 .25008 Mdot
.39879 .18572 Mdot
.59248 .11971 Mdot
.8849 .18072 Mdot
.29633 .25428 Mdot
.53549 .14781 Mdot
.81442 .17239 Mdot
.25867 .27456 Mdot
.52333 .16357 Mdot
.81426 .17981 Mdot
.27058 .28202 Mdot
.54855 .1718 Mdot
.88053 .20518 Mdot
.33519 .28099 Mdot
.63516 .18539 Mdot
.07014 .26884 Mdot
.42841 .22142 Mdot
.70848 .17309 Mdot
.16231 .28048 Mdot
.46291 .18578 Mdot
.72197 .16011 Mdot
.1581 .26954 Mdot
.44354 .17641 Mdot
.66651 .1378 Mdot
.04514 .23401 Mdot
.37344 .2029 Mdot
.57334 .12354 Mdot
.85321 .17297 Mdot
.27642 .26156 Mdot
.52225 .15193 Mdot
.79314 .16742 Mdot
.23732 .27451 Mdot
.50221 .16372 Mdot
.76961 .16526 Mdot
.21549 .27557 Mdot
.48574 .16702 Mdot
.73989 .15707 Mdot
.17352 .268 Mdot
.44768 .16944 Mdot
.66376 .13355 Mdot
.03394 .22878 Mdot
.36605 .20526 Mdot
.56405 .12237 Mdot
.83249 .1659 Mdot
.25715 .26246 Mdot
.50215 .15142 Mdot
.74958 .15292 Mdot
.17685 .26407 Mdot
.44294 .16445 Mdot
.64593 .12545 Mdot
.99167 .21368 Mdot
.34682 .21949 Mdot
.55438 .12828 Mdot
.8222 .16552 Mdot
.25168 .26543 Mdot
.50132 .15429 Mdot
.75245 .15521 Mdot
.18341 .26635 Mdot
.45004 .16478 Mdot
.66113 .13046 Mdot
.02474 .22473 Mdot
.36051 .20752 Mdot
.55808 .1221 Mdot
.81982 .16177 Mdot
.24438 .26239 Mdot
.48921 .15131 Mdot
.72185 .14378 Mdot
.13154 .2532 Mdot
.40894 .17144 Mdot
.58896 .11126 Mdot
.86435 .1702 Mdot
.27513 .25388 Mdot
.5083 .14411 Mdot
.75085 .1499 Mdot
.17324 .26105 Mdot
.4363 .16258 Mdot
.62928 .11927 Mdot
.95282 .19995 Mdot
.32889 .23243 Mdot
.54676 .13465 Mdot
.81671 .16684 Mdot
.25094 .26837 Mdot
.50532 .15722 Mdot
.76573 .16094 Mdot
.2051 .27155 Mdot
.47173 .16479 Mdot
.70659 .14515 Mdot
.11465 .25219 Mdot
.40407 .17887 Mdot
.59154 .11586 Mdot
.87683 .17632 Mdot
.28782 .25401 Mdot
.52403 .14598 Mdot
.78727 .1627 Mdot
.22546 .27081 Mdot
.48593 .16098 Mdot
.73052 .15117 Mdot
.15362 .26149 Mdot
.42885 .1701 Mdot
.62633 .12205 Mdot
.95204 .2013 Mdot
.33113 .23429 Mdot
.55323 .13727 Mdot
.83438 .17376 Mdot
.27068 .26965 Mdot
.52866 .15944 Mdot
.81884 .17934 Mdot
.2723 .28026 Mdot
.54768 .1702 Mdot
.87614 .203 Mdot
.33085 .28103 Mdot
.62844 .18392 Mdot
.05591 .26419 Mdot
.42149 .22594 Mdot
.70192 .17331 Mdot
.15404 .27943 Mdot
.45803 .18788 Mdot
.71515 .15891 Mdot
.14782 .2674 Mdot
.43645 .17838 Mdot
.65516 .13517 Mdot
.02273 .22717 Mdot
.3647 .21135 Mdot
.57154 .12783 Mdot
.85651 .17613 Mdot
.28254 .2633 Mdot
.53247 .15447 Mdot
.81885 .17699 Mdot
.2685 .2779 Mdot
.53952 .1675 Mdot
.85474 .19482 Mdot
.31224 .28275 Mdot
.60348 .18 Mdot
.00359 .24728 Mdot
.39964 .24477 Mdot
.68966 .17924 Mdot
.14674 .28249 Mdot
.46052 .19393 Mdot
.73015 .16664 Mdot
.17823 .27693 Mdot
.46444 .17689 Mdot
.71081 .15226 Mdot
.13159 .26006 Mdot
.42005 .17828 Mdot
.62192 .12476 Mdot
.94847 .20182 Mdot
.33224 .23718 Mdot
.55964 .14054 Mdot
.85287 .18123 Mdot
.28967 .26996 Mdot
.55218 .16224 Mdot
.8726 .19803 Mdot
.32209 .2778 Mdot
.60988 .17786 Mdot
.0122 .24865 Mdot
.40075 .24014 Mdot
.68427 .17523 Mdot
.13251 .27703 Mdot
.44773 .19481 Mdot
.70494 .15896 Mdot
.13483 .26569 Mdot
.42994 .18239 Mdot
.64843 .13503 Mdot
.01136 .2243 Mdot
.36146 .21638 Mdot
.57406 .13139 Mdot
.86735 .18127 Mdot
.29378 .26354 Mdot
.54712 .15657 Mdot
.85293 .189 Mdot
.30227 .27771 Mdot
.58137 .1725 Mdot
.94847 .22688 Mdot
.37278 .26224 Mdot
.66817 .18256 Mdot
.12016 .27934 Mdot
.4489 .20317 Mdot
.72089 .1681 Mdot
.16972 .27739 Mdot
.46111 .18009 Mdot
.70898 .15319 Mdot
.13075 .26067 Mdot
.42084 .17929 Mdot
.62513 .12626 Mdot
.9567 .20492 Mdot
.33659 .23479 Mdot
.56261 .13969 Mdot
.85757 .18229 Mdot
.29284 .26901 Mdot
.55473 .16186 Mdot
.87726 .19933 Mdot
.32514 .27681 Mdot
.61285 .17781 Mdot
.01766 .25019 Mdot
.40255 .23788 Mdot
.68409 .174 Mdot
.13026 .27575 Mdot
.44514 .1946 Mdot
.69923 .15704 Mdot
.12409 .26258 Mdot
.42251 .18443 Mdot
.6368 .13243 Mdot
.98732 .21663 Mdot
.35215 .22548 Mdot
.57294 .13645 Mdot
.87328 .18562 Mdot
.30216 .26506 Mdot
.56077 .15983 Mdot
.8864 .20125 Mdot
.32977 .27402 Mdot
.61541 .17654 Mdot
.02034 .25026 Mdot
.40234 .23609 Mdot
.6808 .17209 Mdot
.12236 .2729 Mdot
.43888 .19562 Mdot
.68802 .15398 Mdot
.10353 .2568 Mdot
.41014 .18949 Mdot
.6205 .13001 Mdot
.95439 .20636 Mdot
.33912 .23777 Mdot
.57146 .1436 Mdot
.88187 .19184 Mdot
.31384 .26697 Mdot
.58025 .16465 Mdot
.93354 .21835 Mdot
.35977 .26342 Mdot
.64726 .17768 Mdot
.0784 .26646 Mdot
.42449 .2139 Mdot
.68842 .16312 Mdot
.1189 .26605 Mdot
.42717 .19053 Mdot
.656 .14142 Mdot
.03421 .23374 Mdot
.37406 .21004 Mdot
.58598 .13098 Mdot
.89042 .18815 Mdot
.30912 .25878 Mdot
.56025 .15521 Mdot
.87785 .19629 Mdot
.32032 .27346 Mdot
.60021 .17299 Mdot
.98602 .23844 Mdot
.3876 .24819 Mdot
.67247 .17606 Mdot
.11626 .27428 Mdot
.44006 .20012 Mdot
.6977 .15923 Mdot
.12557 .26444 Mdot
.42581 .18556 Mdot
.64523 .13561 Mdot
.00692 .22353 Mdot
.36079 .2187 Mdot
.57665 .13341 Mdot
.87583 .1849 Mdot
.30151 .26309 Mdot
.55668 .15771 Mdot
.87456 .19646 Mdot
.31996 .27527 Mdot
.60261 .17469 Mdot
.99335 .24149 Mdot
.3916 .24613 Mdot
.67661 .17615 Mdot
.12268 .27569 Mdot
.44345 .19825 Mdot
.70165 .15958 Mdot
.13145 .26564 Mdot
.42904 .18392 Mdot
.64908 .13599 Mdot
.01399 .22553 Mdot
.36312 .21577 Mdot
.57594 .13153 Mdot
.87136 .18258 Mdot
.29682 .26295 Mdot
.55017 .15658 Mdot
.85927 .19103 Mdot
.30747 .277 Mdot
.58742 .17302 Mdot
.96126 .23105 Mdot
.37845 .25784 Mdot
.67125 .18096 Mdot
.12232 .27878 Mdot
.44838 .20152 Mdot
.71714 .1661 Mdot
.16192 .27489 Mdot
.4537 .18033 Mdot
.69389 .14845 Mdot
.10287 .25276 Mdot
.40353 .18582 Mdot
.60174 .1225 Mdot
.90723 .18881 Mdot
.31172 .24999 Mdot
.54972 .14709 Mdot
.84299 .18125 Mdot
.28627 .27396 Mdot
.55436 .16569 Mdot
.88269 .20292 Mdot
.33189 .27763 Mdot
.62455 .18087 Mdot
.04401 .25924 Mdot
.41437 .2289 Mdot
.69257 .17194 Mdot
.13904 .27593 Mdot
.44763 .19072 Mdot
.6981 .1548 Mdot
.11893 .26009 Mdot
.41754 .18455 Mdot
.62707 .1295 Mdot
.96542 .20911 Mdot
.34254 .23307 Mdot
.56936 .14018 Mdot
.87211 .18711 Mdot
.30431 .26712 Mdot
.56705 .16238 Mdot
.90332 .20783 Mdot
.34224 .27127 Mdot
.6307 .17827 Mdot
.05079 .25963 Mdot
.41446 .22476 Mdot
.68605 .16785 Mdot
.12317 .27015 Mdot
.43459 .19247 Mdot
.67415 .14806 Mdot
.07353 .24683 Mdot
.39274 .19728 Mdot
.59971 .12792 Mdot
.91214 .19309 Mdot
.31888 .25138 Mdot
.56236 .15048 Mdot
.87451 .19292 Mdot
.31422 .27176 Mdot
.58854 .16953 Mdot
.95781 .22823 Mdot
.37421 .25734 Mdot
.66279 .17836 Mdot
.1049 .27324 Mdot
.43687 .20517 Mdot
.69935 .16222 Mdot
.13265 .26779 Mdot
.43281 .18551 Mdot
.65929 .13997 Mdot
.0372 .23356 Mdot
.37345 .20781 Mdot
.58129 .12846 Mdot
.87706 .18279 Mdot
.29834 .26037 Mdot
.548 .1543 Mdot
.8511 .18732 Mdot
.29895 .27679 Mdot
.57541 .17086 Mdot
.93392 .22157 Mdot
.36498 .26641 Mdot
.66111 .18302 Mdot
.10976 .27728 Mdot
.44398 .20656 Mdot
.7162 .16824 Mdot
.16423 .27689 Mdot
.4579 .1815 Mdot
.70455 .15244 Mdot
.12375 .25909 Mdot
.41679 .18111 Mdot
.62003 .12561 Mdot
.94641 .20171 Mdot
.33221 .23844 Mdot
.56162 .14179 Mdot
.85894 .18375 Mdot
.29559 .26987 Mdot
.55973 .16325 Mdot
.88978 .20399 Mdot
.33467 .27495 Mdot
.62455 .17916 Mdot
.04126 .25754 Mdot
.41186 .22905 Mdot
.68788 .17059 Mdot
.13021 .27338 Mdot
.44128 .19225 Mdot
.68749 .15217 Mdot
.09986 .25486 Mdot
.40664 .1896 Mdot
.61388 .12808 Mdot
.9391 .201 Mdot
.33147 .2425 Mdot
.56704 .14559 Mdot
.87616 .19104 Mdot
.31152 .26906 Mdot
.58029 .16611 Mdot
.936 .21984 Mdot
.36209 .26334 Mdot
.65114 .17864 Mdot
.08643 .26902 Mdot
.42878 .21159 Mdot
.69333 .1635 Mdot
.12643 .26767 Mdot
.43123 .18837 Mdot
.66071 .14183 Mdot
.04247 .23594 Mdot
.3768 .20663 Mdot
.58542 .12893 Mdot
.886 .18577 Mdot
.30466 .25875 Mdot
.55398 .15409 Mdot
.86313 .19106 Mdot
.30857 .2753 Mdot
.58621 .17159 Mdot
.95657 .2289 Mdot
.3754 .25885 Mdot
.66738 .18045 Mdot
.11552 .27696 Mdot
.44428 .20319 Mdot
.71136 .16506 Mdot
.15301 .27295 Mdot
.44719 .18181 Mdot
.68277 .1456 Mdot
.0824 .24698 Mdot
.39302 .19197 Mdot
.59165 .12276 Mdot
.88822 .18329 Mdot
.30096 .25509 Mdot
.54301 .14959 Mdot
.83307 .17927 Mdot
.27903 .27562 Mdot
.54813 .16631 Mdot
.87078 .19941 Mdot
.32393 .28006 Mdot
.61629 .18069 Mdot
.02868 .25487 Mdot
.40884 .23495 Mdot
.69151 .1747 Mdot
.14203 .27843 Mdot
.45252 .19189 Mdot
.71016 .15923 Mdot
.14203 .26691 Mdot
.43388 .18037 Mdot
.65314 .13551 Mdot
.01996 .22671 Mdot
.36428 .2128 Mdot
.57317 .1291 Mdot
.86185 .17842 Mdot
.28776 .26323 Mdot
.53887 .15519 Mdot
.83347 .18207 Mdot
.28374 .27828 Mdot
.55819 .16962 Mdot
.89694 .20936 Mdot
.34418 .27641 Mdot
.64215 .18416 Mdot
.08023 .27075 Mdot
.43144 .21706 Mdot
.70756 .17065 Mdot
.15716 .27787 Mdot
.45666 .1851 Mdot
.70778 .1552 Mdot
.13247 .26247 Mdot
.42415 .18027 Mdot
.63334 .12929 Mdot
.97619 .21189 Mdot
.34584 .22846 Mdot
.56729 .13686 Mdot
.86252 .18246 Mdot
.29449 .26697 Mdot
.5536 .16014 Mdot
.87214 .19687 Mdot
.32012 .27686 Mdot
.60542 .17633 Mdot
.00132 .24468 Mdot
.39573 .24376 Mdot
.68057 .17604 Mdot
.1284 .27678 Mdot
.44638 .19652 Mdot
.70491 .15978 Mdot
.13611 .2665 Mdot
.43158 .18261 Mdot
.6521 .13629 Mdot
.0195 .22706 Mdot
.36492 .21348 Mdot
.57537 .13007 Mdot
.86786 .18076 Mdot
.29309 .26281 Mdot
.54502 .1557 Mdot
.84715 .18673 Mdot
.29665 .2778 Mdot
.57397 .17139 Mdot
.9319 .22121 Mdot
.36446 .26734 Mdot
.6617 .18371 Mdot
.11182 .27819 Mdot
.44573 .20636 Mdot
.71948 .16919 Mdot
.16978 .2783 Mdot
.4626 .18097 Mdot
.71355 .1551 Mdot
.13965 .26334 Mdot
.42743 .17786 Mdot
.63601 .12891 Mdot
.98026 .21275 Mdot
.34675 .22651 Mdot
.56562 .13527 Mdot
.85657 .17981 Mdot
.28852 .26696 Mdot
.54588 .15905 Mdot
.85436 .19065 Mdot
.30539 .27875 Mdot
.58735 .17426 Mdot
.96315 .23225 Mdot
.38021 .25776 Mdot
.67434 .18178 Mdot
.12838 .28061 Mdot
.45257 .20036 Mdot
.72396 .16773 Mdot
.1728 .27739 Mdot
.46253 .17907 Mdot
.71032 .15314 Mdot
.1324 .26086 Mdot
.42153 .17869 Mdot
.62555 .12609 Mdot
.95716 .20495 Mdot
.3366 .23451 Mdot
.56218 .13941 Mdot
.85623 .18174 Mdot
.29154 .26903 Mdot
.55309 .16165 Mdot
.87352 .19804 Mdot
.3223 .27736 Mdot
.60947 .17748 Mdot
.01082 .24805 Mdot
.39995 .2405 Mdot
.68333 .17514 Mdot
.131 .27668 Mdot
.4468 .19517 Mdot
.7036 .15871 Mdot
.13265 .26517 Mdot
.42857 .18289 Mdot
.64645 .13466 Mdot
.00745 .2231 Mdot
.36003 .21791 Mdot
.57405 .13228 Mdot
.86877 .18215 Mdot
.29554 .26376 Mdot
.54978 .15713 Mdot
.85934 .19132 Mdot
.30796 .27726 Mdot
.58852 .1734 Mdot
.96402 .23208 Mdot
.37984 .25699 Mdot
.67241 .18082 Mdot
.12387 .27902 Mdot
.44907 .20098 Mdot
.71769 .16602 Mdot
.16247 .27489 Mdot
.45392 .18013 Mdot
.69402 .14839 Mdot
.10297 .25274 Mdot
.4035 .18574 Mdot
.60156 .12241 Mdot
.90675 .18862 Mdot
.31138 .25008 Mdot
.54939 .14709 Mdot
.8423 .18103 Mdot
.28566 .27401 Mdot
.55367 .16564 Mdot
.88117 .20241 Mdot
.33082 .2779 Mdot
.62332 .18077 Mdot
.04164 .25853 Mdot
.41344 .22979 Mdot
.69218 .17227 Mdot
.13903 .27617 Mdot
.44801 .19096 Mdot
.69927 .15529 Mdot
.12133 .26084 Mdot
.41918 .18408 Mdot
.62958 .13003 Mdot
.97075 .21086 Mdot
.34479 .23117 Mdot
.56995 .13916 Mdot
.87163 .18645 Mdot
.30314 .26669 Mdot
.56475 .16168 Mdot
.89751 .20566 Mdot
.33825 .27239 Mdot
.62609 .17789 Mdot
.04196 .25702 Mdot
.41097 .22806 Mdot
.68453 .16907 Mdot
.12293 .27095 Mdot
.43583 .19338 Mdot
.67816 .14977 Mdot
.08233 .24979 Mdot
.39756 .19482 Mdot
.60486 .12812 Mdot
.92225 .19616 Mdot
.32405 .24833 Mdot
.56512 .14899 Mdot
.87775 .19321 Mdot
.31533 .27044 Mdot
.588 .16852 Mdot
.95513 .2269 Mdot
.37229 .25782 Mdot
.66014 .1779 Mdot
.09991 .2718 Mdot
.43406 .20651 Mdot
.6958 .16177 Mdot
.12707 .26654 Mdot
.42952 .18693 Mdot
.65491 .1393 Mdot
.02898 .23119 Mdot
.37049 .21106 Mdot
.58127 .13027 Mdot
.87995 .18459 Mdot
.30178 .26071 Mdot
.55321 .15539 Mdot
.86364 .19186 Mdot
.30999 .27586 Mdot
.58912 .17251 Mdot
.96377 .23155 Mdot
.37901 .25663 Mdot
.67032 .18004 Mdot
.11941 .27755 Mdot
.44587 .20177 Mdot
.71234 .16469 Mdot
.15364 .27274 Mdot
.44707 .18135 Mdot
.68177 .14506 Mdot
.08005 .24615 Mdot
.39164 .19257 Mdot
.59002 .12261 Mdot
.88478 .18217 Mdot
.29867 .25579 Mdot
.54104 .1498 Mdot
.82929 .17815 Mdot
.27552 .27579 Mdot
.54421 .16606 Mdot
.86222 .19654 Mdot
.31719 .28119 Mdot
.60811 .1798 Mdot
.012 .24962 Mdot
.40235 .24125 Mdot
.68914 .17725 Mdot
.14279 .28037 Mdot
.45588 .1935 Mdot
.71975 .16308 Mdot
.16022 .27223 Mdot
.44871 .1783 Mdot
.68025 .1431 Mdot
.07463 .24374 Mdot
.38774 .19351 Mdot
.58425 .12145 Mdot
.87158 .17758 Mdot
.28878 .25785 Mdot
.53145 .14998 Mdot
.80943 .1718 Mdot
.25486 .27529 Mdot
.52053 .16419 Mdot
.80934 .17849 Mdot
.26563 .28201 Mdot
.54295 .17139 Mdot
.86821 .20102 Mdot
.32595 .2829 Mdot
.62394 .18417 Mdot
.04824 .26223 Mdot
.41886 .22906 Mdot
.70172 .17482 Mdot
.15621 .28089 Mdot
.46119 .18849 Mdot
.72275 .16165 Mdot
.16153 .27118 Mdot
.44754 .17676 Mdot
.67534 .14079 Mdot
.06355 .23993 Mdot
.38185 .19672 Mdot
.57855 .12157 Mdot
.86047 .17423 Mdot
.28062 .25967 Mdot
.52424 .15057 Mdot
.79515 .16743 Mdot
.23871 .27414 Mdot
.50289 .16327 Mdot
.77032 .16528 Mdot
.21613 .27553 Mdot
.48616 .16689 Mdot
.74056 .15723 Mdot
.1745 .26819 Mdot
.44845 .16931 Mdot
.66516 .13393 Mdot
.03675 .22966 Mdot
.36719 .20422 Mdot
.56437 .12186 Mdot
.83231 .1656 Mdot
.25658 .26221 Mdot
.50116 .15116 Mdot
.74705 .15197 Mdot
.17276 .2631 Mdot
.43939 .16479 Mdot
.63917 .12347 Mdot
.97692 .20874 Mdot
.34066 .22481 Mdot
.55295 .13121 Mdot
.82399 .16751 Mdot
.25579 .26686 Mdot
.50785 .15579 Mdot
.76879 .16127 Mdot
.20832 .27165 Mdot
.47414 .16428 Mdot
.71086 .1463 Mdot
.12202 .25411 Mdot
.40841 .177 Mdot
.59693 .11651 Mdot
.88833 .18009 Mdot
.29581 .25184 Mdot
.53085 .14526 Mdot
.80054 .16668 Mdot
.24108 .27227 Mdot
.50206 .16129 Mdot
.76537 .16273 Mdot
.20768 .27337 Mdot
.47647 .16612 Mdot
.71877 .14975 Mdot
.13746 .25877 Mdot
.41943 .17426 Mdot
.61418 .12037 Mdot
.92718 .19344 Mdot
.31962 .24254 Mdot
.54915 .14186 Mdot
.83335 .17564 Mdot
.27329 .2719 Mdot
.5353 .16193 Mdot
.83688 .18639 Mdot
.29217 .28138 Mdot
.57389 .17411 Mdot
.93613 .22388 Mdot
.36863 .2673 Mdot
.66896 .18562 Mdot
.12632 .28267 Mdot
.45546 .20342 Mdot
.73493 .17272 Mdot
.19344 .28337 Mdot
.48334 .17917 Mdot
.75445 .16756 Mdot
.20534 .27866 Mdot
.48341 .17186 Mdot
.74278 .1603 Mdot
.18181 .27133 Mdot
.45725 .17023 Mdot
.68496 .14073 Mdot
.0777 .24273 Mdot
.38609 .19059 Mdot
.57647 .11766 Mdot
.84997 .16903 Mdot
.26899 .25897 Mdot
.50944 .14861 Mdot
.76056 .1552 Mdot
.19113 .26611 Mdot
.45402 .16247 Mdot
.66566 .1308 Mdot
.03249 .22671 Mdot
.36286 .20418 Mdot
.55673 .11982 Mdot
.81336 .15861 Mdot
.23578 .26106 Mdot
.47906 .15036 Mdot
.69875 .13578 Mdot
.08904 .24121 Mdot
.38388 .18222 Mdot
.55885 .10813 Mdot
.79881 .1483 Mdot
.21022 .25427 Mdot
.44738 .14657 Mdot
.62614 .11049 Mdot
.93299 .18964 Mdot
.31334 .23507 Mdot
.5279 .13261 Mdot
.77384 .15199 Mdot
.1976 .2619 Mdot
.45118 .15672 Mdot
.65045 .12316 Mdot
.99552 .21326 Mdot
.34565 .21639 Mdot
.54745 .12472 Mdot
.80207 .15737 Mdot
.22701 .26262 Mdot
.47396 .15263 Mdot
.69163 .13453 Mdot
.07719 .23829 Mdot
.3789 .18647 Mdot
.5566 .10982 Mdot
.79691 .14852 Mdot
.20931 .25488 Mdot
.44771 .14734 Mdot
.62809 .11148 Mdot
.93807 .19158 Mdot
.31628 .23375 Mdot
.53002 .1321 Mdot
.77749 .15294 Mdot
.20212 .26244 Mdot
.45499 .15628 Mdot
.65767 .12526 Mdot
.01077 .21823 Mdot
.35171 .21071 Mdot
.5483 .1215 Mdot
.79862 .15471 Mdot
.22047 .26071 Mdot
.46555 .15147 Mdot
.67202 .1276 Mdot
.03717 .22568 Mdot
.3607 .19995 Mdot
.54616 .11462 Mdot
.78306 .14641 Mdot
.19594 .25517 Mdot
.43924 .15037 Mdot
.61555 .10896 Mdot
.91126 .18276 Mdot
.30213 .24157 Mdot
.52272 .13633 Mdot
.76888 .15214 Mdot
.19363 .26251 Mdot
.4497 .15826 Mdot
.64986 .12371 Mdot
.99542 .21357 Mdot
.34616 .21677 Mdot
.54889 .12529 Mdot
.806 .1589 Mdot
.23194 .26324 Mdot
.47919 .15281 Mdot
.70299 .13832 Mdot
.09885 .24465 Mdot
.39005 .17997 Mdot
.56666 .10915 Mdot
.81642 .15436 Mdot
.23059 .25597 Mdot
.46625 .14564 Mdot
.66405 .12225 Mdot
.01609 .21758 Mdot
.34999 .20636 Mdot
.53837 .11643 Mdot
.76971 .14297 Mdot
.1795 .25327 Mdot
.42681 .15285 Mdot
.59431 .10352 Mdot
.86224 .16559 Mdot
.26712 .25023 Mdot
.4932 .13972 Mdot
.71158 .13497 Mdot
.1046 .2429 Mdot
.38775 .175 Mdot
.5543 .10294 Mdot
.78104 .14013 Mdot
.18422 .24917 Mdot
.42269 .14738 Mdot
.5772 .09549 Mdot
.81556 .14732 Mdot
.21872 .24917 Mdot
.4455 .14016 Mdot
.6119 .10284 Mdot
.89457 .1747 Mdot
.28785 .24306 Mdot
.50636 .13504 Mdot
.73205 .13948 Mdot
.13644 .24993 Mdot
.40486 .16589 Mdot
.57205 .10333 Mdot
.81791 .15195 Mdot
.22749 .25313 Mdot
.45902 .14309 Mdot
.64475 .11479 Mdot
.97241 .20251 Mdot
.33109 .22168 Mdot
.53277 .12465 Mdot
.77123 .14737 Mdot
.18793 .25754 Mdot
.43829 .15473 Mdot
.62066 .11271 Mdot
.92667 .18913 Mdot
.31265 .23855 Mdot
.53253 .1359 Mdot
.78893 .15846 Mdot
.21981 .2663 Mdot
.47408 .15714 Mdot
.69918 .13912 Mdot
.09504 .24465 Mdot
.38977 .18216 Mdot
.56967 .11118 Mdot
.8258 .1583 Mdot
.24177 .25708 Mdot
.47813 .14608 Mdot
.68984 .13085 Mdot
.06871 .23415 Mdot
.37233 .18764 Mdot
.54665 .10774 Mdot
.77294 .13985 Mdot
.17721 .24985 Mdot
.42012 .15013 Mdot
.5765 .09665 Mdot
.81604 .14804 Mdot
.22016 .24976 Mdot
.44759 .14056 Mdot
.61686 .10461 Mdot
.90663 .17909 Mdot
.29596 .24062 Mdot
.51289 .13407 Mdot
.74438 .14307 Mdot
.1556 .25415 Mdot
.41769 .16198 Mdot
.59086 .10703 Mdot
.86123 .16709 Mdot
.26928 .25219 Mdot
.4988 .14185 Mdot
.72696 .14101 Mdot
.13308 .251 Mdot
.40574 .16852 Mdot
.57802 .10647 Mdot
.83496 .1588 Mdot
.24673 .25449 Mdot
.47869 .14336 Mdot
.68664 .12852 Mdot
.06037 .23098 Mdot
.36751 .18982 Mdot
.54163 .10761 Mdot
.76226 .13636 Mdot
.1622 .24718 Mdot
.40898 .15252 Mdot
.55841 .09236 Mdot
.77238 .13224 Mdot
.16441 .24229 Mdot
.40199 .14683 Mdot
.53568 .08263 Mdot
.70935 .10734 Mdot
.05704 .21488 Mdot
.34164 .17589 Mdot
.4754 .08267 Mdot
.58146 .06555 Mdot
.77561 .11999 Mdot
.14728 .2297 Mdot
.37528 .14091 Mdot
.47633 .06246 Mdot
.55074 .04599 Mdot
.68153 .08083 Mdot
.97577 .18185 Mdot
.29729 .19871 Mdot
.44684 .09243 Mdot
.53742 .05598 Mdot
.6699 .08188 Mdot
.95992 .17924 Mdot
.29476 .20694 Mdot
.45681 .10016 Mdot
.57066 .07036 Mdot
.76175 .1181 Mdot
.1322 .22895 Mdot
.36986 .14688 Mdot
.4763 .06579 Mdot
.55607 .0493 Mdot
.6979 .08765 Mdot
.01001 .1929 Mdot
.31082 .18591 Mdot
.44476 .08278 Mdot
.51753 .04497 Mdot
.61007 .05719 Mdot
.8173 .12808 Mdot
.18853 .22944 Mdot
.39317 .12647 Mdot
.48596 .05734 Mdot
.56289 .04755 Mdot
.70907 .09034 Mdot
.02917 .19783 Mdot
.31649 .17758 Mdot
.43944 .07599 Mdot
.49561 .03471 Mdot
.5468 .03164 Mdot
.65013 .06386 Mdot
.89903 .15383 Mdot
.25453 .21971 Mdot
.43026 .1086 Mdot
.52967 .06144 Mdot
.66243 .08205 Mdot
.94848 .17679 Mdot
.29174 .21214 Mdot
.4613 .1048 Mdot
.58757 .07804 Mdot
.80786 .13615 Mdot
.19625 .24004 Mdot
.41495 .13516 Mdot
.54205 .07855 Mdot
.71613 .10758 Mdot
.06599 .21623 Mdot
.3434 .17145 Mdot
.47106 .0789 Mdot
.56619 .05879 Mdot
.73398 .1037 Mdot
.0807 .21429 Mdot
.34009 .16031 Mdot
.44768 .0665 Mdot
.49722 .03062 Mdot
.54362 .02867 Mdot
.63869 .05876 Mdot
.87138 .14381 Mdot
.2341 .22417 Mdot
.41787 .11358 Mdot
.51291 .05873 Mdot
.62251 .06774 Mdot
.85729 .1451 Mdot
.23257 .23194 Mdot
.42908 .12145 Mdot
.54808 .07355 Mdot
.72059 .10661 Mdot
.06988 .21587 Mdot
.34272 .16863 Mdot
.46538 .07581 Mdot
.54923 .05182 Mdot
.68782 .08565 Mdot
.9927 .18843 Mdot
.30583 .19352 Mdot
.45006 .08914 Mdot
.53879 .05484 Mdot
.67092 .08166 Mdot
.96115 .17937 Mdot
.29485 .20623 Mdot
.45579 .09947 Mdot
.5674 .06898 Mdot
.75293 .11466 Mdot
.11827 .22579 Mdot
.36193 .15059 Mdot
.46842 .06581 Mdot
.53945 .0439 Mdot
.65461 .07117 Mdot
.91827 .16295 Mdot
.27028 .21755 Mdot
.4439 .1073 Mdot
.55543 .06893 Mdot
.72833 .10686 Mdot
.07942 .21698 Mdot
.34444 .16379 Mdot
.46036 .07164 Mdot
.53195 .04424 Mdot
.63939 .0664 Mdot
.88497 .15178 Mdot
.24951 .2253 Mdot
.4342 .11415 Mdot
.54664 .06949 Mdot
.71103 .1016 Mdot
.04991 .20944 Mdot
.33331 .17515 Mdot
.46094 .07888 Mdot
.54487 .05187 Mdot
.67885 .0828 Mdot
.97499 .18303 Mdot
.29928 .20042 Mdot
.45227 .09456 Mdot
.55214 .06172 Mdot
.70988 .09749 Mdot
.04179 .20513 Mdot
.32701 .17628 Mdot
.45304 .07789 Mdot
.52676 .04556 Mdot
.63059 .06417 Mdot
.86598 .14548 Mdot
.23553 .2284 Mdot
.42599 .11771 Mdot
.53579 .06786 Mdot
.68569 .09264 Mdot
.00095 .19484 Mdot
.31514 .19418 Mdot
.46434 .09221 Mdot
.57357 .06751 Mdot
.763 .11708 Mdot
.13168 .22786 Mdot
.36796 .14603 Mdot
.47159 .06404 Mdot
.54327 .0443 Mdot
.66325 .07415 Mdot
.93701 .16919 Mdot
.28011 .21205 Mdot
.44657 .10288 Mdot
.55377 .06626 Mdot
.7206 .1031 Mdot
.06421 .21236 Mdot
.33721 .16873 Mdot
.45671 .07385 Mdot
.52789 .04399 Mdot
.63041 .06337 Mdot
.86436 .14459 Mdot
.23369 .22826 Mdot
.42412 .11769 Mdot
.53201 .06668 Mdot
.67582 .08888 Mdot
.9803 .18818 Mdot
.30698 .2019 Mdot
.46522 .0978 Mdot
.58448 .0737 Mdot
.79477 .12997 Mdot
.17784 .23675 Mdot
.39923 .13683 Mdot
.51422 .07107 Mdot
.64525 .08098 Mdot
.91856 .16891 Mdot
.27993 .22334 Mdot
.46463 .11415 Mdot
.6097 .08965 Mdot
.86913 .16034 Mdot
.26034 .24178 Mdot
.47208 .13086 Mdot
.65243 .11146 Mdot
.97988 .20237 Mdot
.33 .21639 Mdot
.52253 .11899 Mdot
.74043 .13467 Mdot
.13785 .24562 Mdot
.39826 .16094 Mdot
.55137 .09463 Mdot
.76152 .12988 Mdot
.15104 .24074 Mdot
.39438 .15039 Mdot
.52694 .08193 Mdot
.6898 .10065 Mdot
.01978 .20394 Mdot
.32747 .19016 Mdot
.47621 .09192 Mdot
.59815 .07537 Mdot
.82412 .13965 Mdot
.21078 .23897 Mdot
.42302 .13118 Mdot
.55163 .07949 Mdot
.73757 .11492 Mdot
.10281 .22573 Mdot
.35979 .15882 Mdot
.47803 .07308 Mdot
.57153 .05779 Mdot
.74317 .10608 Mdot
.09449 .21713 Mdot
.3452 .15495 Mdot
.44728 .06309 Mdot
.49089 .02695 Mdot
.52419 .02059 Mdot
.58473 .03742 Mdot
.73656 .09383 Mdot
.06759 .20459 Mdot
.32452 .15879 Mdot
.42096 .0596 Mdot
.43171 .00665 Mdot
.36765 .57844 Mdot
.17067 .4963 Mdot
.81573 .39867 Mdot
.62552 .50047 Mdot
.56289 .57933 Mdot
.56948 .00408 Mdot
.65212 .05107 Mdot
.88165 .14186 Mdot
.23292 .2171 Mdot
.40539 .10659 Mdot
.47714 .04434 Mdot
.52314 .02843 Mdot
.59519 .04453 Mdot
.76852 .10712 Mdot
.12047 .21752 Mdot
.34892 .14119 Mdot
.43117 .05083 Mdot
.43804 .00424 Mdot
.37664 .58009 Mdot
.18939 .50231 Mdot
.83518 .39912 Mdot
.63567 .49473 Mdot
.57155 .57841 Mdot
.5856 .00868 Mdot
.69177 .06562 Mdot
.96589 .16942 Mdot
.27826 .19305 Mdot
.41361 .08365 Mdot
.45605 .02623 Mdot
.44947 .61396 Mdot
.38673 .57926 Mdot
.20654 .50667 Mdot
.85316 .39964 Mdot
.64316 .48824 Mdot
.57397 .57527 Mdot
.58539 .00706 Mdot
.68874 .06387 Mdot
.95878 .16689 Mdot
.27488 .19536 Mdot
.41332 .08556 Mdot
.45859 .02798 Mdot
.4576 .61742 Mdot
.40925 .58815 Mdot
.26382 .52815 Mdot
.93923 .41742 Mdot
.68165 .45884 Mdot
.58758 .5599 Mdot
.58757 .61802 Mdot
.68159 .05811 Mdot
.93909 .15915 Mdot
.26375 .20065 Mdot
.40924 .08992 Mdot
.45764 .02991 Mdot
.45875 .00068 Mdot
.41375 .59023 Mdot
.276 .5329 Mdot
.96079 .42323 Mdot
.68944 .45033 Mdot
.58508 .55353 Mdot
.57235 .61016 Mdot
.63857 .04093 Mdot
.84234 .12594 Mdot
.19653 .2189 Mdot
.38092 .11396 Mdot
.44296 .03834 Mdot
.44191 .61739 Mdot
.37668 .57772 Mdot
.18561 .49995 Mdot
.82923 .39777 Mdot
.63086 .49543 Mdot
.56425 .57687 Mdot
.56828 .00249 Mdot
.64713 .04873 Mdot
.86954 .13746 Mdot
.22341 .2187 Mdot
.39994 .1091 Mdot
.4707 .04373 Mdot
.50854 .02339 Mdot
.55602 .02935 Mdot
.66551 .06767 Mdot
.93009 .16352 Mdot
.27115 .21079 Mdot
.43396 .10062 Mdot
.52425 .05581 Mdot
.64186 .07268 Mdot
.89936 .15914 Mdot
.26315 .22484 Mdot
.44772 .11407 Mdot
.57427 .07821 Mdot
.78174 .12822 Mdot
.16548 .23717 Mdot
.39415 .14132 Mdot
.51184 .07273 Mdot
.64289 .08099 Mdot
.91457 .16791 Mdot
.27822 .22475 Mdot
.46484 .11534 Mdot
.61205 .09098 Mdot
.87568 .16293 Mdot
.26593 .24119 Mdot
.47724 .1306 Mdot
.66292 .11476 Mdot
.00218 .20968 Mdot
.33898 .20815 Mdot
.52332 .11393 Mdot
.73392 .13016 Mdot
.12344 .24074 Mdot
.38705 .16292 Mdot
.53346 .09049 Mdot
.71741 .11369 Mdot
.07745 .22252 Mdot
.35339 .17053 Mdot
.4861 .08202 Mdot
.60313 .07233 Mdot
.8287 .13941 Mdot
.21258 .23725 Mdot
.42156 .12916 Mdot
.54544 .07657 Mdot
.71999 .10787 Mdot
.07118 .21705 Mdot
.3446 .16898 Mdot
.46902 .07689 Mdot
.55864 .05539 Mdot
.71303 .09542 Mdot
.04244 .20359 Mdot
.32446 .17429 Mdot
.44596 .07509 Mdot
.50755 .03807 Mdot
.57767 .04334 Mdot
.73211 .09545 Mdot
.06526 .2059 Mdot
.32672 .16159 Mdot
.42882 .0631 Mdot
.45315 .01503 Mdot
.42529 .60082 Mdot
.31607 .55054 Mdot
.04229 .44883 Mdot
.72128 .41964 Mdot
.57719 .52898 Mdot
.51696 .58081 Mdot
.47584 .59262 Mdot
.40754 .57582 Mdot
.24053 .51482 Mdot
.89399 .40386 Mdot
.65858 .47254 Mdot
.57416 .56586 Mdot
.57053 .61579 Mdot
.64401 .04541 Mdot
.85891 .13282 Mdot
.21316 .21894 Mdot
.39237 .11076 Mdot
.45901 .04119 Mdot
.47985 .01288 Mdot
.47799 .61688 Mdot
.45133 .60156 Mdot
.37052 .56809 Mdot
.15901 .48731 Mdot
.79625 .39384 Mdot
.6058 .50033 Mdot
.52629 .5689 Mdot
.47637 .58718 Mdot
.39983 .57073 Mdot
.21743 .5053 Mdot
.85893 .39647 Mdot
.63978 .48259 Mdot
.55903 .56813 Mdot
.54348 .60842 Mdot
.57644 .02037 Mdot
.6925 .07173 Mdot
.9768 .17571 Mdot
.28722 .19185 Mdot
.42269 .08373 Mdot
.4742 .03183 Mdot
.49668 .01389 Mdot
.5154 .01157 Mdot
.5515 .02231 Mdot
.64478 .05765 Mdot
.88002 .14538 Mdot
.23835 .22146 Mdot
.41732 .11061 Mdot
.50701 .05543 Mdot
.60463 .06033 Mdot
.81214 .12825 Mdot
.18596 .23103 Mdot
.3943 .12876 Mdot
.49178 .06025 Mdot
.57999 .05451 Mdot
.75483 .10805 Mdot
.10942 .21915 Mdot
.34989 .14861 Mdot
.44478 .05865 Mdot
.47851 .02085 Mdot
.48804 .00589 Mdot
.48406 .61558 Mdot
.46211 .60447 Mdot
.39774 .57825 Mdot
.22561 .51165 Mdot
.87574 .4018 Mdot
.65245 .48003 Mdot
.57626 .57095 Mdot
.58299 .00416 Mdot
.67931 .05953 Mdot
.93802 .15989 Mdot
.26501 .20209 Mdot
.41296 .09144 Mdot
.46738 .03363 Mdot
.4852 .01101 Mdot
.48631 .00069 Mdot
.47198 .60918 Mdot
.42615 .58971 Mdot
.29983 .53997 Mdot
.00242 .43422 Mdot
.70227 .43253 Mdot
.57394 .53872 Mdot
.52618 .58852 Mdot
.50788 .60672 Mdot
.49849 .61223 Mdot
.48738 .61117 Mdot
.46203 .60237 Mdot
.39418 .5761 Mdot
.21537 .50752 Mdot
.86095 .39899 Mdot
.64442 .48421 Mdot
.56959 .57179 Mdot
.57093 .00082 Mdot
.64978 .04873 Mdot
.87399 .13857 Mdot
.22617 .21766 Mdot
.40052 .10775 Mdot
.46963 .04272 Mdot
.50464 .02164 Mdot
.5449 .02488 Mdot
.63522 .05582 Mdot
.86061 .1393 Mdot
.22413 .22467 Mdot
.41018 .11498 Mdot
.50003 .05553 Mdot
.58991 .05555 Mdot
.77608 .11506 Mdot
.13969 .22472 Mdot
.36495 .13922 Mdot
.45526 .05582 Mdot
.49567 .02498 Mdot
.53119 .02195 Mdot
.60174 .0436 Mdot
.77959 .10991 Mdot
.13418 .21915 Mdot
.35448 .13615 Mdot
.43232 .04811 Mdot
.43597 .00225 Mdot
.36919 .57676 Mdot
.17069 .49535 Mdot
.81421 .39772 Mdot
.62314 .49995 Mdot
.55775 .57762 Mdot
.5562 .61707 Mdot
.61683 .03747 Mdot
.79794 .11193 Mdot
.1508 .21808 Mdot
.35763 .12783 Mdot
.4242 .04114 Mdot
.40831 .60821 Mdot
.29445 .54766 Mdot
.00771 .44082 Mdot
.71226 .43544 Mdot
.59163 .54348 Mdot
.56891 .60399 Mdot
.62165 .03259 Mdot
.79885 .10952 Mdot
.14749 .21547 Mdot
.35232 .12659 Mdot
.41321 .03763 Mdot
.3808 .59801 Mdot
.22596 .52233 Mdot
.89331 .41245 Mdot
.6724 .4815 Mdot
.61037 .5797 Mdot
.66329 .03271 Mdot
.87003 .12777 Mdot
.20784 .20878 Mdot
.37209 .10151 Mdot
.40685 .02149 Mdot
.34227 .57812 Mdot
.12722 .48513 Mdot
.78324 .40544 Mdot
.6152 .51418 Mdot
.56627 .58779 Mdot
.59006 .01471 Mdot
.71029 .0743 Mdot
.00479 .18201 Mdot
.29388 .17867 Mdot
.40991 .07171 Mdot
.4295 .01211 Mdot
.372 .5825 Mdot
.18496 .50244 Mdot
.83289 .40044 Mdot
.63681 .49685 Mdot
.57699 .58106 Mdot
.6008 .01472 Mdot
.73106 .0805 Mdot
.03989 .19087 Mdot
.30411 .1633 Mdot
.39879 .05851 Mdot
.38666 .61054 Mdot
.25701 .5379 Mdot
.94768 .42686 Mdot
.69642 .46274 Mdot
.6149 .56765 Mdot
.65224 .02307 Mdot
.83654 .11391 Mdot
.17475 .20903 Mdot
.35285 .11007 Mdot
.38736 .02133 Mdot
.30495 .5671 Mdot
.0533 .46251 Mdot
.74255 .42598 Mdot
.61144 .537 Mdot
.59621 .60862 Mdot
.68321 .05376 Mdot
.93444 .15527 Mdot
.25768 .19977 Mdot
.40128 .08875 Mdot
.44035 .02415 Mdot
.41358 .60149 Mdot
.29388 .54405 Mdot
.00112 .4371 Mdot
.7071 .43632 Mdot
.58643 .54346 Mdot
.55869 .60089 Mdot
.59578 .02292 Mdot
.7347 .08585 Mdot
.05262 .19649 Mdot
.31216 .1604 Mdot
.4054 .05762 Mdot
.39793 .61342 Mdot
.28286 .54692 Mdot
.99177 .43813 Mdot
.70997 .44387 Mdot
.60236 .55153 Mdot
.60262 .00016 Mdot
.71096 .06696 Mdot
.99376 .17478 Mdot
.28361 .17914 Mdot
.39761 .07046 Mdot
.40374 .00378 Mdot
.3076 .55862 Mdot
.04326 .45467 Mdot
.73064 .42482 Mdot
.59653 .53515 Mdot
.56494 .59851 Mdot
.60472 .02458 Mdot
.75448 .09256 Mdot
.08402 .20366 Mdot
.32296 .14767 Mdot
.40063 .048 Mdot
.37315 .60106 Mdot
.21705 .52155 Mdot
.88494 .41278 Mdot
.67181 .48632 Mdot
.61727 .58432 Mdot
.68356 .04097 Mdot
.91425 .14258 Mdot
.23722 .1996 Mdot
.38092 .08881 Mdot
.40228 .0132 Mdot
.32001 .56719 Mdot
.07502 .46662 Mdot
.74836 .41615 Mdot
.60154 .52729 Mdot
.56183 .59349 Mdot
.59024 .01756 Mdot
.71526 .07726 Mdot
.01585 .18578 Mdot
.29856 .17473 Mdot
.40973 .06871 Mdot
.42428 .00899 Mdot
.35647 .57612 Mdot
.14757 .48893 Mdot
.79481 .40001 Mdot
.61481 .50679 Mdot
.55358 .58019 Mdot
.55175 .6169 Mdot
.60737 .03438 Mdot
.77533 .1038 Mdot
.12086 .21355 Mdot
.34257 .13703 Mdot
.41401 .04415 Mdot
.39294 .60501 Mdot
.25981 .53576 Mdot
.94718 .42482 Mdot
.69314 .46103 Mdot
.6076 .56517 Mdot
.6346 .01668 Mdot
.7962 .09987 Mdot
.13012 .20637 Mdot
.33285 .12529 Mdot
.37955 .02886 Mdot
.30277 .57058 Mdot
.05594 .46548 Mdot
.74719 .42722 Mdot
.61826 .53835 Mdot
.611 .61355 Mdot
.71925 .0669 Mdot
.004 .17598 Mdot
.28423 .17319 Mdot
.38876 .0646 Mdot
.37756 .61112 Mdot
.24127 .5338 Mdot
.9254 .42282 Mdot
.69078 .47303 Mdot
.62369 .57657 Mdot
.68271 .03648 Mdot
.90575 .13784 Mdot
.22917 .19989 Mdot
.37429 .08969 Mdot
.39167 .01074 Mdot
.29586 .55882 Mdot
.02763 .45226 Mdot
.72833 .43306 Mdot
.60721 .54318 Mdot
.59829 .61252 Mdot
.69352 .05885 Mdot
.95737 .16307 Mdot
.26883 .19249 Mdot
.40169 .08211 Mdot
.4304 .01774 Mdot
.38293 .5887 Mdot
.21479 .51412 Mdot
.87119 .40568 Mdot
.65776 .48613 Mdot
.59482 .57913 Mdot
.63279 .02347 Mdot
.80401 .10582 Mdot
.14481 .21063 Mdot
.34364 .12288 Mdot
.39287 .03042 Mdot
.32997 .57916 Mdot
.10945 .48175 Mdot
.77478 .41119 Mdot
.61777 .521 Mdot
.58203 .59594 Mdot
.63493 .0327 Mdot
.82269 .11604 Mdot
.17186 .2158 Mdot
.36243 .11778 Mdot
.41619 .03322 Mdot
.37955 .59539 Mdot
.21943 .51908 Mdot
.88278 .40997 Mdot
.66693 .48463 Mdot
.60698 .58098 Mdot
.65901 .03216 Mdot
.86228 .12563 Mdot
.20247 .21025 Mdot
.37078 .10402 Mdot
.40858 .02337 Mdot
.34868 .58101 Mdot
.1424 .49055 Mdot
.79583 .40385 Mdot
.62171 .51042 Mdot
.5721 .58737 Mdot
.6012 .01799 Mdot
.73711 .084 Mdot
.05228 .19478 Mdot
.30943 .15893 Mdot
.39912 .05543 Mdot
.3823 .60764 Mdot
.24428 .53273 Mdot
.92653 .42165 Mdot
.68888 .47116 Mdot
.61798 .57421 Mdot
.66852 .03124 Mdot
.87585 .12814 Mdot
.20967 .20631 Mdot
.36938 .09871 Mdot
.39752 .01739 Mdot
.31769 .5687 Mdot
.07404 .46745 Mdot
.74971 .41759 Mdot
.60522 .52874 Mdot
.57116 .59698 Mdot
.61487 .02701 Mdot
.77739 .10045 Mdot
.11711 .20995 Mdot
.33611 .13535 Mdot
.40096 .04008 Mdot
.36097 .59332 Mdot
.18312 .50811 Mdot
.84106 .40663 Mdot
.65021 .50008 Mdot
.605 .59009 Mdot
.67001 .04018 Mdot
.89263 .13759 Mdot
.22758 .20701 Mdot
.38447 .09696 Mdot
.42197 .02318 Mdot
.37479 .58888 Mdot
.20028 .51018 Mdot
.85462 .40441 Mdot
.65133 .4924 Mdot
.59443 .58286 Mdot
.63807 .02697 Mdot
.81888 .11175 Mdot
.16296 .21265 Mdot
.35342 .11771 Mdot
.40069 .02922 Mdot
.34289 .58231 Mdot
.13501 .48956 Mdot
.79222 .40618 Mdot
.62298 .51344 Mdot
.5793 .59103 Mdot
.62156 .02612 Mdot
.7882 .10299 Mdot
.12954 .21096 Mdot
.34013 .13015 Mdot
.39895 .03635 Mdot
.35111 .58847 Mdot
.15851 .499 Mdot
.81497 .40572 Mdot
.6365 .50773 Mdot
.59404 .5918 Mdot
.65178 .03568 Mdot
.85619 .12633 Mdot
.20187 .21365 Mdot
.37588 .10754 Mdot
.42341 .02938 Mdot
.3877 .59596 Mdot
.23535 .52388 Mdot
.90392 .4132 Mdot
.67459 .4763 Mdot
.60528 .5752 Mdot
.64645 .02545 Mdot
.83074 .11389 Mdot
.17221 .21105 Mdot
.3549 .11291 Mdot
.39542 .02504 Mdot
.32608 .57518 Mdot
.09705 .47649 Mdot
.76503 .41283 Mdot
.61205 .52349 Mdot
.57548 .59543 Mdot
.62105 .02816 Mdot
.79058 .10478 Mdot
.13415 .21234 Mdot
.34345 .12935 Mdot
.40303 .03682 Mdot
.35968 .59124 Mdot
.17752 .50546 Mdot
.83385 .40563 Mdot
.64564 .50171 Mdot
.59997 .58981 Mdot
.65998 .03709 Mdot
.87183 .13093 Mdot
.21335 .21108 Mdot
.37978 .10286 Mdot
.42292 .02666 Mdot
.38232 .59294 Mdot
.22053 .51804 Mdot
.88198 .40879 Mdot
.66489 .48387 Mdot
.60255 .5795 Mdot
.64823 .02823 Mdot
.83823 .11742 Mdot
.18114 .21193 Mdot
.36077 .11102 Mdot
.4024 .02572 Mdot
.34051 .57979 Mdot
.12709 .48613 Mdot
.78484 .40651 Mdot
.61814 .51501 Mdot
.57302 .59015 Mdot
.60754 .02134 Mdot
.75455 .09085 Mdot
.08132 .20196 Mdot
.32015 .1476 Mdot
.39633 .04708 Mdot
.36346 .59772 Mdot
.19454 .51364 Mdot
.85659 .40917 Mdot
.65963 .49631 Mdot
.6143 .59002 Mdot
.68732 .04513 Mdot
.92641 .14777 Mdot
.24573 .19735 Mdot
.38526 .08624 Mdot
.40609 .01287 Mdot
.32685 .56906 Mdot
.08832 .47062 Mdot
.75503 .41205 Mdot
.60151 .52315 Mdot
.55506 .58933 Mdot
.5696 .00898 Mdot
.6603 .05606 Mdot
.90302 .15001 Mdot
.24868 .21363 Mdot
.41449 .10248 Mdot
.48827 .0456 Mdot
.5488 .03741 Mdot
.66361 .07096 Mdot
.93241 .16613 Mdot
.27531 .21193 Mdot
.44064 .10218 Mdot
.54045 .06168 Mdot
.68546 .08962 Mdot
.99574 .19176 Mdot
.31083 .19474 Mdot
.45905 .09161 Mdot
.56151 .06332 Mdot
.73177 .10522 Mdot
.08069 .21565 Mdot
.34229 .16168 Mdot
.45344 .06869 Mdot
.51272 .03664 Mdot
.58636 .04551 Mdot
.75287 .10291 Mdot
.0992 .21404 Mdot
.34055 .14916 Mdot
.43038 .05552 Mdot
.44404 .00844 Mdot
.39575 .58819 Mdot
.2379 .52048 Mdot
.90072 .40965 Mdot
.6686 .47457 Mdot
.5933 .5715 Mdot
.61749 .01495 Mdot
.76272 .08976 Mdot
.08722 .20055 Mdot
.31802 .14264 Mdot
.38515 .04149 Mdot
.33347 .5861 Mdot
.12613 .48989 Mdot
.79071 .41074 Mdot
.62929 .51827 Mdot
.59842 .59896 Mdot
.67182 .04536 Mdot
.90379 .14337 Mdot
.23798 .20654 Mdot
.39283 .09571 Mdot
.43554 .02639 Mdot
.40738 .60063 Mdot
.28038 .53954 Mdot
.97679 .43041 Mdot
.69934 .44656 Mdot
.5927 .55213 Mdot
.58498 .61326 Mdot
.66879 .0518 Mdot
.90954 .14879 Mdot
.2471 .20862 Mdot
.40483 .09749 Mdot
.46132 .03491 Mdot
.47454 .00817 Mdot
.4591 .60849 Mdot
.39795 .58024 Mdot
.22923 .51376 Mdot
.8822 .40355 Mdot
.65645 .47852 Mdot
.58037 .57101 Mdot
.59129 .00675 Mdot
.69981 .06707 Mdot
.97931 .17274 Mdot
.28212 .18715 Mdot
.40874 .07825 Mdot
.43779 .01795 Mdot
.39832 .59364 Mdot
.2516 .52736 Mdot
.92505 .41622 Mdot
.6801 .46664 Mdot
.59792 .56724 Mdot
.61953 .01336 Mdot
.76388 .08921 Mdot
.08739 .19994 Mdot
.31703 .14193 Mdot
.38255 .04049 Mdot
.32708 .58375 Mdot
.11245 .48538 Mdot
.78106 .41322 Mdot
.6261 .52226 Mdot
.59919 .6014 Mdot
.67725 .04824 Mdot
.91668 .14798 Mdot
.24603 .20354 Mdot
.39558 .09243 Mdot
.43542 .02462 Mdot
.40428 .59879 Mdot
.27138 .5359 Mdot
.96026 .42575 Mdot
.69358 .45321 Mdot
.59556 .55745 Mdot
.59914 .00222 Mdot
.70765 .06706 Mdot
.98968 .1743 Mdot
.28336 .1815 Mdot
.40113 .07279 Mdot
.41423 .0081 Mdot
.33503 .56909 Mdot
.10105 .47343 Mdot
.7604 .4075 Mdot
.59921 .51841 Mdot
.54302 .5833 Mdot
.53483 .61298 Mdot
.5657 .01908 Mdot
.66872 .06367 Mdot
.92865 .16064 Mdot
.26652 .20882 Mdot
.42552 .09827 Mdot
.50341 .04813 Mdot
.58513 .05051 Mdot
.75854 .10717 Mdot
.11154 .21816 Mdot
.34856 .14649 Mdot
.43914 .05598 Mdot
.4626 .0145 Mdot
.4442 .60666 Mdot
.36402 .56848 Mdot
.1482 .48465 Mdot
.78809 .39547 Mdot
.6027 .50346 Mdot
.52547 .57031 Mdot
.47691 .58802 Mdot
.40235 .57195 Mdot
.22423 .50795 Mdot
.86862 .39826 Mdot
.64518 .47994 Mdot
.56396 .56784 Mdot
.55308 .61131 Mdot
.60107 .02966 Mdot
.75575 .0956 Mdot
.09016 .20668 Mdot
.32805 .14702 Mdot
.40729 .04897 Mdot
.38759 .60586 Mdot
.25118 .53373 Mdot
.93493 .42258 Mdot
.69017 .46677 Mdot
.61271 .57016 Mdot
.65222 .02442 Mdot
.8387 .11525 Mdot
.1778 .20958 Mdot
.35525 .10967 Mdot
.39077 .02195 Mdot
.31233 .56955 Mdot
.06766 .46682 Mdot
.74882 .42098 Mdot
.60981 .53212 Mdot
.58528 .60287 Mdot
.65257 .04159 Mdot
.86704 .13255 Mdot
.21488 .21498 Mdot
.38724 .10652 Mdot
.44257 .0342 Mdot
.4344 .61299 Mdot
.35419 .56846 Mdot
.13131 .48029 Mdot
.77632 .39864 Mdot
.59872 .50827 Mdot
.52567 .57288 Mdot
.48148 .59073 Mdot
.41643 .57783 Mdot
.26121 .5221 Mdot
.92659 .41123 Mdot
.67202 .4607 Mdot
.57613 .55877 Mdot
.56302 .60993 Mdot
.61927 .03476 Mdot
.79802 .11048 Mdot
.1485 .21661 Mdot
.35448 .1273 Mdot
.418 .03926 Mdot
.39291 .60252 Mdot
.25572 .53325 Mdot
.93881 .42217 Mdot
.68935 .46386 Mdot
.60684 .56704 Mdot
.63618 .01814 Mdot
.80131 .10206 Mdot
.13702 .20748 Mdot
.33633 .12318 Mdot
.3816 .02798 Mdot
.30508 .57074 Mdot
.05939 .46619 Mdot
.74813 .42567 Mdot
.6167 .53681 Mdot
.60565 .6112 Mdot
.7054 .06165 Mdot
.97798 .16847 Mdot
.27537 .18379 Mdot
.39518 .07405 Mdot
.40493 .00602 Mdot
.31352 .56154 Mdot
.05641 .45913 Mdot
.73688 .42055 Mdot
.59658 .53133 Mdot
.55885 .59471 Mdot
.5861 .01685 Mdot
.70598 .07409 Mdot
.99887 .18102 Mdot
.29304 .1818 Mdot
.41389 .07469 Mdot
.44212 .01745 Mdot
.40637 .59594 Mdot
.27081 .53426 Mdot
.95695 .42406 Mdot
.69114 .45376 Mdot
.59302 .55739 Mdot
.59413 .00069 Mdot
.69551 .06266 Mdot
.9663 .16736 Mdot
.27489 .19072 Mdot
.40582 .08092 Mdot
.43644 .01892 Mdot
.39712 .59373 Mdot
.24948 .52679 Mdot
.92199 .41564 Mdot
.67917 .46796 Mdot
.59867 .56828 Mdot
.62266 .01483 Mdot
.77194 .09226 Mdot
.09936 .20236 Mdot
.32165 .13739 Mdot
.38202 .03731 Mdot
.32096 .58029 Mdot
.09763 .48001 Mdot
.77077 .41602 Mdot
.62222 .52623 Mdot
.59861 .60344 Mdot
.67943 .04995 Mdot
.92271 .15035 Mdot
.24993 .20224 Mdot
.39731 .09109 Mdot
.43653 .02424 Mdot
.40592 .59912 Mdot
.27509 .53718 Mdot
.96665 .4274 Mdot
.69562 .45053 Mdot
.59403 .55525 Mdot
.59262 .61716 Mdot
.69006 .06022 Mdot
.95475 .16359 Mdot
.26988 .19476 Mdot
.40657 .08448 Mdot
.44364 .02291 Mdot
.41836 .60241 Mdot
.30481 .54786 Mdot
.02199 .44324 Mdot
.71439 .42793 Mdot
.58216 .53631 Mdot
.5387 .59118 Mdot
.53855 .61794 Mdot
.58153 .02656 Mdot
.71266 .08104 Mdot
.0187 .18915 Mdot
.30366 .17612 Mdot
.41891 .07122 Mdot
.44643 .01701 Mdot
.41455 .59833 Mdot
.29069 .54148 Mdot
.99282 .43394 Mdot
.70307 .43896 Mdot
.58539 .54531 Mdot
.55965 .60212 Mdot
.59974 .02478 Mdot
.7453 .08996 Mdot
.07063 .20106 Mdot
.31874 .15334 Mdot
.40352 .0524 Mdot
.38584 .60711 Mdot
.24995 .53404 Mdot
.9342 .42289 Mdot
.69071 .46755 Mdot
.61473 .57107 Mdot
.65745 .0264 Mdot
.85046 .11928 Mdot
.18866 .20902 Mdot
.36021 .10602 Mdot
.39333 .02047 Mdot
.31474 .56946 Mdot
.07099 .46738 Mdot
.74965 .41944 Mdot
.60815 .53059 Mdot
.57969 .60044 Mdot
.63755 .03576 Mdot
.83219 .1203 Mdot
.18323 .21695 Mdot
.37002 .11544 Mdot
.42572 .03443 Mdot
.40051 .60245 Mdot
.27005 .53741 Mdot
.96117 .42714 Mdot
.69574 .45398 Mdot
.59979 .55874 Mdot
.60936 .00592 Mdot
.73302 .07642 Mdot
.03549 .18694 Mdot
.29819 .16236 Mdot
.38923 .05626 Mdot
.36497 .60304 Mdot
.20577 .51965 Mdot
.87363 .41276 Mdot
.66975 .49203 Mdot
.62333 .58935 Mdot
.70274 .04908 Mdot
.95413 .15537 Mdot
.25664 .18696 Mdot
.37945 .07591 Mdot
.37871 .61757 Mdot
.25379 .54083 Mdot
.94908 .42971 Mdot
.70093 .46467 Mdot
.62415 .57058 Mdot
.67386 .03072 Mdot
.88322 .12939 Mdot
.21302 .20383 Mdot
.3678 .09566 Mdot
.3898 .01359 Mdot
.29698 .56067 Mdot
.0321 .45433 Mdot
.73119 .43206 Mdot
.60887 .54244 Mdot
.60021 .61268 Mdot
.69744 .06009 Mdot
.9648 .16524 Mdot
.27161 .18962 Mdot
.40024 .07949 Mdot
.42337 .0143 Mdot
.36321 .58086 Mdot
.16683 .49666 Mdot
.8146 .40035 Mdot
.62761 .50246 Mdot
.56985 .58234 Mdot
.58851 .01153 Mdot
.7021 .07021 Mdot
.98746 .17636 Mdot
.28697 .18511 Mdot
.41147 .07694 Mdot
.44101 .01826 Mdot
.40542 .59603 Mdot
.26912 .5338 Mdot
.95427 .42345 Mdot
.69039 .45495 Mdot
.59389 .55839 Mdot
.59743 .00219 Mdot
.70431 .06606 Mdot
.98369 .17266 Mdot
.28146 .18404 Mdot
.40289 .07505 Mdot
.42128 .01136 Mdot
.35429 .57663 Mdot
.1447 .4885 Mdot
.79322 .4008 Mdot
.61499 .50788 Mdot
.55568 .58138 Mdot
.55802 .00144 Mdot
.62447 .04107 Mdot
.81766 .1194 Mdot
.17469 .22066 Mdot
.37164 .12172 Mdot
.43876 .04148 Mdot
.43836 .61779 Mdot
.37005 .57581 Mdot
.17068 .49481 Mdot
.81334 .39719 Mdot
.62179 .49965 Mdot
.55481 .57664 Mdot
.54856 .61417 Mdot
.59634 .02953 Mdot
.74646 .09278 Mdot
.07637 .2039 Mdot
.32326 .15259 Mdot
.40903 .053 Mdot
.39749 .61091 Mdot
.27798 .54417 Mdot
.98139 .43473 Mdot
.70578 .4477 Mdot
.60312 .55459 Mdot
.60901 .00364 Mdot
.72868 .07396 Mdot
.02657 .18411 Mdot
.29458 .16564 Mdot
.38976 .05882 Mdot
.37008 .60587 Mdot
.21936 .52489 Mdot
.89212 .41579 Mdot
.67766 .48549 Mdot
.62479 .58536 Mdot
.69891 .04581 Mdot
.9437 .15129 Mdot
.25079 .18979 Mdot
.37803 .07864 Mdot
.38055 .00156 Mdot
.2604 .54378 Mdot
.9608 .43287 Mdot
.70504 .45997 Mdot
.62201 .56672 Mdot
.66373 .02579 Mdot
.85952 .12101 Mdot
.19423 .20686 Mdot
.36002 .10246 Mdot
.38725 .01683 Mdot
.29747 .56254 Mdot
.03578 .4563 Mdot
.734 .43152 Mdot
.61116 .54211 Mdot
.60396 .61359 Mdot
.70606 .0631 Mdot
.98119 .17004 Mdot
.27753 .18315 Mdot
.3967 .07365 Mdot
.40718 .00647 Mdot
.31861 .5633 Mdot
.06666 .46232 Mdot
.74156 .41711 Mdot
.59606 .52811 Mdot
.55263 .59119 Mdot
.56759 .00925 Mdot
.65666 .05505 Mdot
.89552 .14762 Mdot
.24414 .21546 Mdot
.41304 .10439 Mdot
.4885 .04663 Mdot
.55097 .03861 Mdot
.67006 .0736 Mdot
.94678 .17102 Mdot
.28253 .2075 Mdot
.44217 .09866 Mdot
.53788 .05916 Mdot
.67601 .08537 Mdot
.97489 .18472 Mdot
.30203 .20218 Mdot
.45885 .09692 Mdot
.56967 .0685 Mdot
.75674 .11562 Mdot
.1235 .22667 Mdot
.36429 .14882 Mdot
.46964 .06511 Mdot
.5409 .04404 Mdot
.65787 .07229 Mdot
.92538 .16533 Mdot
.27416 .21556 Mdot
.44516 .10568 Mdot
.5554 .06814 Mdot
.727 .10605 Mdot
.07656 .21604 Mdot
.34291 .16461 Mdot
.4592 .07187 Mdot
.52988 .04368 Mdot
.63413 .06443 Mdot
.87262 .1474 Mdot
.24018 .22716 Mdot
.42822 .11622 Mdot
.53789 .06778 Mdot
.68996 .09399 Mdot
.00923 .19732 Mdot
.31808 .19088 Mdot
.46328 .08974 Mdot
.56736 .06433 Mdot
.74531 .10998 Mdot
.10303 .22108 Mdot
.35229 .15405 Mdot
.45758 .06507 Mdot
.5155 .0358 Mdot
.5909 .0466 Mdot
.76352 .10669 Mdot
.11534 .21744 Mdot
.34794 .14375 Mdot
.43368 .05299 Mdot
.44663 .008 Mdot
.4004 .58946 Mdot
.24882 .52435 Mdot
.9174 .41321 Mdot
.67518 .46834 Mdot
.59331 .56743 Mdot
.61093 .01089 Mdot
.74401 .08224 Mdot
.0568 .19331 Mdot
.30676 .15449 Mdot
.3882 .05033 Mdot
.35343 .59655 Mdot
.17548 .50806 Mdot
.83704 .40887 Mdot
.65222 .5038 Mdot
.61435 .59463 Mdot
.69485 .04976 Mdot
.94451 .1543 Mdot
.25561 .19227 Mdot
.38698 .08119 Mdot
.4011 .00873 Mdot
.31051 .56205 Mdot
.05293 .45884 Mdot
.73663 .42255 Mdot
.59954 .53331 Mdot
.56775 .59838 Mdot
.61021 .02625 Mdot
.76751 .09721 Mdot
.10356 .20769 Mdot
.33067 .14037 Mdot
.40055 .04319 Mdot
.36523 .59621 Mdot
.19519 .51294 Mdot
.85585 .40832 Mdot
.65803 .49577 Mdot
.61086 .58888 Mdot
.67907 .04216 Mdot
.90956 .14245 Mdot
.23683 .20227 Mdot
.38488 .0915 Mdot
.41389 .01793 Mdot
.35027 .57872 Mdot
.14133 .4889 Mdot
.79287 .40267 Mdot
.61776 .50981 Mdot
.56392 .58476 Mdot
.58037 .01017 Mdot
.68384 .06394 Mdot
.95183 .16563 Mdot
.27343 .19876 Mdot
.41712 .08881 Mdot
.47135 .03351 Mdot
.49338 .01361 Mdot
.50792 .00899 Mdot
.5314 .01451 Mdot
.59015 .0363 Mdot
.74539 .09595 Mdot
.08041 .20705 Mdot
.32838 .15325 Mdot
.41788 .05531 Mdot
.41864 .00047 Mdot
.33142 .56413 Mdot
.08737 .46721 Mdot
.74948 .40921 Mdot
.59144 .52036 Mdot
.53112 .58076 Mdot
.50575 .60235 Mdot
.48688 .60637 Mdot
.45319 .59721 Mdot
.36736 .56499 Mdot
.1484 .48271 Mdot
.78502 .39345 Mdot
.59714 .50192 Mdot
.51235 .56563 Mdot
.44149 .57424 Mdot
.306 .53429 Mdot
.00167 .42995 Mdot
.69546 .42878 Mdot
.55863 .53347 Mdot
.48658 .5735 Mdot
.39937 .56414 Mdot
.20588 .49845 Mdot
.83941 .39154 Mdot
.62515 .48561 Mdot
.53816 .56428 Mdot
.4939 .59068 Mdot
.44274 .58642 Mdot
.32826 .54728 Mdot
.05525 .4493 Mdot
.72105 .41149 Mdot
.56373 .52081 Mdot
.47652 .56413 Mdot
.36287 .54779 Mdot
.11273 .46344 Mdot
.74559 .39113 Mdot
.55824 .50224 Mdot
.43523 .54201 Mdot
.24103 .49801 Mdot
.86727 .38704 Mdot
.62671 .46936 Mdot
.51467 .54879 Mdot
.41918 .55902 Mdot
.23624 .50497 Mdot
.87412 .39424 Mdot
.63988 .47326 Mdot
.54412 .55885 Mdot
.49757 .58927 Mdot
.44828 .58757 Mdot
.34156 .55208 Mdot
.08395 .45882 Mdot
.73581 .40287 Mdot
.56681 .51358 Mdot
.4711 .55888 Mdot
.34291 .53881 Mdot
.06465 .44606 Mdot
.71533 .40214 Mdot
.54161 .51067 Mdot
.41437 .5394 Mdot
.19498 .48244 Mdot
.80638 .37787 Mdot
.58646 .48211 Mdot
.45951 .53957 Mdot
.28729 .5116 Mdot
.94014 .40348 Mdot
.65905 .44431 Mdot
.52923 .5378 Mdot
.43225 .5581 Mdot
.26099 .51219 Mdot
.91033 .40131 Mdot
.65571 .46067 Mdot
.5503 .55288 Mdot
.50077 .58743 Mdot
.45213 .58797 Mdot
.3502 .55504 Mdot
.10291 .4652 Mdot
.74726 .39823 Mdot
.57144 .50937 Mdot
.47366 .5576 Mdot
.34624 .53929 Mdot
.07087 .44785 Mdot
.71804 .39997 Mdot
.54144 .50889 Mdot
.41113 .5375 Mdot
.18553 .47861 Mdot
.79464 .37645 Mdot
.57657 .48326 Mdot
.44173 .5347 Mdot
.2425 .4949 Mdot
.86363 .38388 Mdot
.62068 .46788 Mdot
.5014 .54432 Mdot
.38371 .54529 Mdot
.14598 .47111 Mdot
.76548 .38287 Mdot
.56397 .49349 Mdot
.43281 .53697 Mdot
.22795 .49143 Mdot
.84498 .38134 Mdot
.61076 .47328 Mdot
.49185 .54454 Mdot
.36372 .53885 Mdot
.09975 .45489 Mdot
.73029 .3897 Mdot
.5393 .5 Mdot
.39228 .52717 Mdot
.13262 .45755 Mdot
.73984 .37529 Mdot
.52655 .48621 Mdot
.34312 .50467 Mdot
.00977 .41201 Mdot
.66538 .40519 Mdot
.47601 .501 Mdot
.25964 .48431 Mdot
.86376 .37336 Mdot
.6037 .45731 Mdot
.45271 .52472 Mdot
.24906 .49217 Mdot
.86557 .38102 Mdot
.61656 .46413 Mdot
.48779 .53845 Mdot
.34525 .52994 Mdot
.05411 .4381 Mdot
.703 .40104 Mdot
.52395 .50738 Mdot
.37187 .52404 Mdot
.09013 .44391 Mdot
.7119 .38428 Mdot
.5084 .49226 Mdot
.31437 .49812 Mdot
.95502 .39594 Mdot
.64582 .42694 Mdot
.47929 .51511 Mdot
.28942 .50069 Mdot
.92519 .39293 Mdot
.64242 .44327 Mdot
.49995 .52998 Mdot
.35742 .52995 Mdot
.07447 .44316 Mdot
.71041 .39303 Mdot
.52066 .50076 Mdot
.35419 .51515 Mdot
.04505 .42698 Mdot
.68568 .39593 Mdot
.49167 .49813 Mdot
.28826 .49232 Mdot
.91017 .38436 Mdot
.62829 .44382 Mdot
.47617 .52402 Mdot
.29722 .50744 Mdot
.94629 .40115 Mdot
.6549 .43795 Mdot
.5122 .52984 Mdot
.38328 .53835 Mdot
.13397 .46395 Mdot
.75053 .38105 Mdot
.54693 .4922 Mdot
.3956 .52451 Mdot
.13459 .45672 Mdot
.73897 .37353 Mdot
.52278 .48442 Mdot
.33223 .50027 Mdot
.98531 .40363 Mdot
.65497 .41387 Mdot
.47335 .50579 Mdot
.26176 .48726 Mdot
.87082 .37642 Mdot
.61034 .45705 Mdot
.4648 .52808 Mdot
.2798 .5037 Mdot
.9181 .39449 Mdot
.64492 .4492 Mdot
.51378 .53699 Mdot
.3982 .5466 Mdot
.17526 .48025 Mdot
.79195 .38113 Mdot
.58227 .48845 Mdot
.46148 .54338 Mdot
.29757 .51674 Mdot
.96179 .41051 Mdot
.66878 .43694 Mdot
.53269 .53393 Mdot
.43328 .5566 Mdot
.26067 .51135 Mdot
.90861 .40045 Mdot
.65424 .46083 Mdot
.54814 .55246 Mdot
.49561 .58557 Mdot
.43811 .5825 Mdot
.31244 .54036 Mdot
.02058 .43765 Mdot
.70553 .42332 Mdot
.56335 .53016 Mdot
.49089 .57325 Mdot
.40814 .56689 Mdot
.22726 .50624 Mdot
.86837 .39623 Mdot
.64183 .47803 Mdot
.55518 .56448 Mdot
.52963 .60225 Mdot
.53738 .00479 Mdot
.58698 .03066 Mdot
.73005 .08842 Mdot
.05156 .1987 Mdot
.31582 .16332 Mdot
.41539 .06154 Mdot
.42379 .00519 Mdot
.34933 .57201 Mdot
.12893 .48182 Mdot
.77826 .40131 Mdot
.6046 .51071 Mdot
.54082 .57862 Mdot
.52267 .60682 Mdot
.53005 .00456 Mdot
.57119 .02543 Mdot
.69013 .07351 Mdot
.97633 .17688 Mdot
.28918 .19335 Mdot
.42761 .08555 Mdot
.48703 .03672 Mdot
.5318 .02767 Mdot
.61227 .04973 Mdot
.80934 .1218 Mdot
.17391 .22531 Mdot
.37879 .12662 Mdot
.45956 .04992 Mdot
.49514 .02198 Mdot
.52521 .01859 Mdot
.58366 .03612 Mdot
.73235 .0919 Mdot
.05978 .20236 Mdot
.32124 .16159 Mdot
.42056 .06139 Mdot
.4338 .00818 Mdot
.37438 .58131 Mdot
.1873 .50241 Mdot
.83415 .39977 Mdot
.63629 .49575 Mdot
.57428 .57971 Mdot
.5932 .01169 Mdot
.71153 .07313 Mdot
.00447 .18105 Mdot
.29236 .17793 Mdot
.40674 .07069 Mdot
.42166 .00922 Mdot
.35159 .57473 Mdot
.13709 .48547 Mdot
.78614 .40113 Mdot
.61041 .50943 Mdot
.54968 .5805 Mdot
.54417 .61463 Mdot
.58793 .02705 Mdot
.72607 .08538 Mdot
.04204 .19528 Mdot
.31105 .16626 Mdot
.41328 .06318 Mdot
.4223 .00557 Mdot
.34697 .57148 Mdot
.12415 .48033 Mdot
.77484 .40215 Mdot
.6032 .51195 Mdot
.54016 .57907 Mdot
.52201 .60682 Mdot
.52867 .00411 Mdot
.56755 .02403 Mdot
.68048 .0698 Mdot
.95637 .17051 Mdot
.28095 .2006 Mdot
.42907 .09154 Mdot
.49967 .04363 Mdot
.56989 .0434 Mdot
.71656 .09065 Mdot
.03913 .19936 Mdot
.31792 .1723 Mdot
.43301 .07112 Mdot
.4746 .02571 Mdot
.48761 .00804 Mdot
.48664 .61743 Mdot
.47059 .60812 Mdot
.42151 .5877 Mdot
.28727 .53507 Mdot
.9781 .42696 Mdot
.6936 .4422 Mdot
.57777 .54644 Mdot
.54635 .59862 Mdot
.56658 .0125 Mdot
.65986 .05765 Mdot
.9049 .15145 Mdot
.25112 .21398 Mdot
.41751 .10283 Mdot
.49479 .04776 Mdot
.5662 .04413 Mdot
.71026 .08904 Mdot
.0286 .19674 Mdot
.31479 .17688 Mdot
.43584 .07481 Mdot
.48633 .0312 Mdot
.52139 .02167 Mdot
.58054 .03656 Mdot
.72686 .09043 Mdot
.05113 .20041 Mdot
.31861 .16531 Mdot
.4227 .06433 Mdot
.44285 .01245 Mdot
.39978 .59142 Mdot
.25081 .52596 Mdot
.92199 .41481 Mdot
.67784 .46714 Mdot
.59536 .56706 Mdot
.6143 .01171 Mdot
.75158 .08484 Mdot
.06869 .19599 Mdot
.31057 .14949 Mdot
.38548 .04629 Mdot
.34185 .59107 Mdot
.14751 .49793 Mdot
.80935 .40903 Mdot
.63866 .51255 Mdot
.60559 .59759 Mdot
.68326 .04801 Mdot
.9252 .14953 Mdot
.24859 .19986 Mdot
.39213 .08872 Mdot
.42291 .01902 Mdot
.36993 .58529 Mdot
.1858 .50423 Mdot
.83626 .40201 Mdot
.64079 .49723 Mdot
.58446 .58322 Mdot
.61915 .02144 Mdot
.77625 .09709 Mdot
.11076 .20674 Mdot
.32997 .13548 Mdot
.39156 .03807 Mdot
.33988 .58609 Mdot
.13628 .4922 Mdot
.79682 .40824 Mdot
.62948 .51461 Mdot
.59285 .59539 Mdot
.65528 .03858 Mdot
.86664 .13063 Mdot
.21167 .21324 Mdot
.38204 .1053 Mdot
.431 .03026 Mdot
.4044 .6016 Mdot
.27616 .53878 Mdot
.9705 .42913 Mdot
.69798 .44961 Mdot
.59579 .55487 Mdot
.59542 .6178 Mdot
.69653 .06249 Mdot
.96742 .16742 Mdot
.27488 .19002 Mdot
.40468 .08022 Mdot
.43308 .01756 Mdot
.38808 .59022 Mdot
.22679 .51835 Mdot
.88756 .40838 Mdot
.66508 .48053 Mdot
.59744 .57623 Mdot
.63316 .02208 Mdot
.8024 .1046 Mdot
.14182 .20978 Mdot
.34137 .12333 Mdot
.38991 .03 Mdot
.32372 .57713 Mdot
.09664 .47769 Mdot
.76695 .41427 Mdot
.61608 .52479 Mdot
.58505 .59886 Mdot
.64562 .03743 Mdot
.84873 .12553 Mdot
.19817 .21597 Mdot
.37722 .11066 Mdot
.43089 .03317 Mdot
.4089 .60444 Mdot
.28949 .54424 Mdot
.99575 .43649 Mdot
.70681 .43946 Mdot
.59113 .54654 Mdot
.57289 .60676 Mdot
.63417 .03787 Mdot
.82974 .12087 Mdot
.18305 .21836 Mdot
.37219 .1169 Mdot
.43194 .03693 Mdot
.41709 .60886 Mdot
.31275 .55354 Mdot
.04235 .45092 Mdot
.72466 .42169 Mdot
.58454 .53144 Mdot
.53553 .58774 Mdot
.52632 .61235 Mdot
.54673 .01261 Mdot
.61919 .04478 Mdot
.8141 .12046 Mdot
.17446 .22272 Mdot
.37486 .12385 Mdot
.44797 .04519 Mdot
.46333 .00949 Mdot
.43762 .60214 Mdot
.34322 .55969 Mdot
.09894 .46706 Mdot
.74993 .40233 Mdot
.58076 .51348 Mdot
.49897 .56749 Mdot
.41603 .56677 Mdot
.24255 .51081 Mdot
.88941 .39979 Mdot
.65143 .47095 Mdot
.55988 .56146 Mdot
.53442 .6023 Mdot
.54755 .00811 Mdot
.61361 .04083 Mdot
.79742 .1136 Mdot
.15315 .21985 Mdot
.36132 .12866 Mdot
.43187 .0436 Mdot
.42777 .6155 Mdot
.34483 .56677 Mdot
.11303 .47477 Mdot
.76398 .40231 Mdot
.59407 .51303 Mdot
.52439 .57497 Mdot
.48217 .59194 Mdot
.41984 .57951 Mdot
.27072 .52587 Mdot
.94327 .41566 Mdot
.67858 .45444 Mdot
.57592 .55459 Mdot
.55584 .60562 Mdot
.59758 .02579 Mdot
.7428 .08975 Mdot
.06769 .20079 Mdot
.31837 .15493 Mdot
.40555 .05388 Mdot
.39215 .60975 Mdot
.26599 .54007 Mdot
.9609 .42948 Mdot
.69955 .45651 Mdot
.60908 .56212 Mdot
.63244 .01444 Mdot
.78878 .09662 Mdot
.11965 .20449 Mdot
.3277 .12858 Mdot
.37691 .03041 Mdot
.30048 .5708 Mdot
.05318 .46519 Mdot
.7469 .42874 Mdot
.62043 .53987 Mdot
.61742 .61617 Mdot
.73538 .0729 Mdot
.03243 .18359 Mdot
.29309 .16109 Mdot
.38045 .05399 Mdot
.34507 .59617 Mdot
.16098 .50426 Mdot
.82446 .41005 Mdot
.64845 .50926 Mdot
.61691 .59854 Mdot
.70592 .05501 Mdot
.96791 .16192 Mdot
.26592 .18418 Mdot
.38498 .07358 Mdot
.3851 7e-05 Mdot
.26637 .54465 Mdot
.96874 .43409 Mdot
.70621 .45578 Mdot
.61676 .56275 Mdot
.64773 .01914 Mdot
.82267 .10812 Mdot
.15903 .20788 Mdot
.34414 .1144 Mdot
.37995 .02213 Mdot
.2926 .56405 Mdot
.03182 .45686 Mdot
.73532 .43479 Mdot
.6179 .54547 Mdot
.62185 .00244 Mdot
.75043 .07947 Mdot
.05885 .19062 Mdot
.30228 .15044 Mdot
.37547 .04524 Mdot
.32188 .58491 Mdot
.10647 .4849 Mdot
.77952 .41597 Mdot
.62934 .52522 Mdot
.60974 .60592 Mdot
.70457 .0586 Mdot
.97195 .16525 Mdot
.27087 .18474 Mdot
.39149 .07454 Mdot
.39876 .0045 Mdot
.2992 .5565 Mdot
.02832 .45062 Mdot
.72561 .43095 Mdot
.60063 .54079 Mdot
.58193 .60648 Mdot
.65179 .04317 Mdot
.86833 .13383 Mdot
.21725 .21565 Mdot
.39012 .10684 Mdot
.44847 .03606 Mdot
.44959 .00069 Mdot
.39468 .5841 Mdot
.22928 .51581 Mdot
.88554 .4056 Mdot
.66028 .47882 Mdot
.58704 .57277 Mdot
.60733 .01254 Mdot
.73992 .08194 Mdot
.05199 .19287 Mdot
.30635 .1572 Mdot
.39202 .05295 Mdot
.36483 .60123 Mdot
.2026 .51777 Mdot
.86845 .41151 Mdot
.66659 .49328 Mdot
.62044 .58951 Mdot
.69775 .04779 Mdot
.94531 .153 Mdot
.25346 .19045 Mdot
.3818 .07932 Mdot
.38853 .00416 Mdot
.27934 .55055 Mdot
.99336 .44129 Mdot
.71488 .44592 Mdot
.61188 .55438 Mdot
.62514 .0082 Mdot
.76569 .08686 Mdot
.08521 .19747 Mdot
.31298 .14077 Mdot
.3748 .03821 Mdot
.30928 .57754 Mdot
.07625 .47402 Mdot
.76032 .42278 Mdot
.62385 .53369 Mdot
.61363 .61172 Mdot
.72118 .06647 Mdot
.00563 .1758 Mdot
.28372 .17187 Mdot
.38599 .0632 Mdot
.37016 .60825 Mdot
.22336 .5273 Mdot
.89922 .41771 Mdot
.68151 .48348 Mdot
.62724 .58449 Mdot
.70192 .04615 Mdot
.94829 .15227 Mdot
.25208 .18775 Mdot
.37603 .07661 Mdot
.37364 .61656 Mdot
.243 .53729 Mdot
.93269 .42625 Mdot
.69619 .47187 Mdot
.62936 .57673 Mdot
.69313 .03941 Mdot
.92539 .14354 Mdot
.2389 .19376 Mdot
.37301 .08288 Mdot
.37836 .00331 Mdot
.25926 .54443 Mdot
.96062 .43346 Mdot
.70603 .46068 Mdot
.62445 .56762 Mdot
.66961 .02791 Mdot
.87216 .12518 Mdot
.20413 .20517 Mdot
.36367 .0986 Mdot
.38731 .01461 Mdot
.29399 .56036 Mdot
.02765 .45343 Mdot
.73022 .43421 Mdot
.61125 .54451 Mdot
.60801 .61603 Mdot
.71766 .06777 Mdot
.00345 .17663 Mdot
.28535 .17422 Mdot
.39181 .0658 Mdot
.38522 .61396 Mdot
.25989 .54057 Mdot
.95505 .42964 Mdot
.70034 .46061 Mdot
.61678 .56639 Mdot
.65366 .02279 Mdot
.83844 .1142 Mdot
.176 .20862 Mdot
.35281 .10927 Mdot
.386 .02052 Mdot
.30112 .56557 Mdot
.04559 .46011 Mdot
.73925 .4287 Mdot
.61233 .5396 Mdot
.60208 .61169 Mdot
.69942 .06016 Mdot
.9676 .16574 Mdot
.27214 .18822 Mdot
.39857 .07814 Mdot
.418 .01201 Mdot
.34882 .57527 Mdot
.13335 .48487 Mdot
.78422 .40226 Mdot
.61079 .51085 Mdot
.5527 .58213 Mdot
.55306 .00023 Mdot
.61229 .0366 Mdot
.78814 .10868 Mdot
.13869 .21665 Mdot
.35162 .1316 Mdot
.42013 .04234 Mdot
.40213 .60691 Mdot
.28038 .54279 Mdot
.98205 .43366 Mdot
.70396 .44616 Mdot
.59824 .5527 Mdot
.59662 .61703 Mdot
.6976 .06241 Mdot
.96877 .16759 Mdot
.275 .18926 Mdot
.4036 .07948 Mdot
.42981 .0162 Mdot
.37924 .58678 Mdot
.20494 .51031 Mdot
.85795 .40358 Mdot
.651 .49013 Mdot
.59021 .58046 Mdot
.62599 .02211 Mdot
.78972 .10119 Mdot
.12773 .2089 Mdot
.33641 .12897 Mdot
.39109 .0338 Mdot
.3321 .58157 Mdot
.11666 .48489 Mdot
.78089 .41051 Mdot
.62158 .51958 Mdot
.58669 .59647 Mdot
.64498 .03603 Mdot
.84537 .12385 Mdot
.19427 .21563 Mdot
.37424 .11122 Mdot
.42642 .03225 Mdot
.3984 .60072 Mdot
.26321 .53448 Mdot
.9488 .42372 Mdot
.69125 .45886 Mdot
.60143 .56252 Mdot
.61862 .01063 Mdot
.75779 .08601 Mdot
.07658 .19703 Mdot
.31214 .14558 Mdot
.38139 .0428 Mdot
.32867 .58545 Mdot
.11764 .48761 Mdot
.78545 .41273 Mdot
.62867 .52113 Mdot
.60195 .60152 Mdot
.68271 .04991 Mdot
.92748 .15128 Mdot
.25139 .20019 Mdot
.39547 .08904 Mdot
.42973 .02118 Mdot
.38714 .59171 Mdot
.22745 .51934 Mdot
.88971 .4093 Mdot
.66686 .48031 Mdot
.59988 .57663 Mdot
.63849 .02386 Mdot
.81457 .10883 Mdot
.15591 .21095 Mdot
.34792 .11867 Mdot
.39306 .0279 Mdot
.32626 .57675 Mdot
.09986 .47811 Mdot
.76788 .41286 Mdot
.61461 .52331 Mdot
.57995 .59661 Mdot
.63187 .03209 Mdot
.81633 .114 Mdot
.16525 .21564 Mdot
.35922 .11988 Mdot
.41405 .03389 Mdot
.37642 .59478 Mdot
.21276 .51689 Mdot
.87415 .40876 Mdot
.66339 .48778 Mdot
.6065 .58287 Mdot
.66116 .03379 Mdot
.86838 .12807 Mdot
.20794 .20986 Mdot
.3739 .10257 Mdot
.41182 .02344 Mdot
.35512 .58299 Mdot
.1564 .49522 Mdot
.80805 .40274 Mdot
.62771 .50658 Mdot
.57669 .5865 Mdot
.60902 .01998 Mdot
.75513 .0903 Mdot
.08099 .20139 Mdot
.31923 .14724 Mdot
.39438 .04644 Mdot
.35874 .59601 Mdot
.18362 .5098 Mdot
.84407 .40818 Mdot
.65386 .50048 Mdot
.61166 .59196 Mdot
.68555 .04566 Mdot
.92474 .14783 Mdot
.24584 .19845 Mdot
.38715 .08734 Mdot
.41137 .01497 Mdot
.34052 .57425 Mdot
.11815 .4806 Mdot
.77419 .40546 Mdot
.60801 .51533 Mdot
.55473 .5851 Mdot
.56208 .00454 Mdot
.6378 .0468 Mdot
.85051 .13146 Mdot
.20837 .22117 Mdot
.39251 .1138 Mdot
.46421 .04431 Mdot
.4958 .01952 Mdot
.52264 .01659 Mdot
.57497 .03234 Mdot
.70892 .08279 Mdot
.01677 .19026 Mdot
.3057 .17857 Mdot
.42568 .07416 Mdot
.46471 .02412 Mdot
.46419 .61771 Mdot
.42355 .59291 Mdot
.29979 .54155 Mdot
.00493 .4358 Mdot
.70449 .43236 Mdot
.5766 .53899 Mdot
.53197 .59045 Mdot
.52322 .61263 Mdot
.54061 .01075 Mdot
.60341 .03881 Mdot
.775 .10605 Mdot
.12422 .21583 Mdot
.3469 .13762 Mdot
.42205 .04644 Mdot
.41258 .61219 Mdot
.30924 .55416 Mdot
.03835 .45062 Mdot
.72455 .42409 Mdot
.5883 .53383 Mdot
.54678 .59238 Mdot
.55738 .00655 Mdot
.63141 .04576 Mdot
.83764 .12745 Mdot
.19712 .22217 Mdot
.3866 .1171 Mdot
.4585 .04444 Mdot
.48404 .01579 Mdot
.49158 .00466 Mdot
.48962 .61682 Mdot
.47593 .60957 Mdot
.43515 .59283 Mdot
.3231 .54878 Mdot
.04984 .44915 Mdot
.72118 .41491 Mdot
.56942 .52424 Mdot
.49365 .5712 Mdot
.4107 .56677 Mdot
.23204 .50762 Mdot
.87469 .39718 Mdot
.64475 .47592 Mdot
.55675 .56365 Mdot
.53153 .60245 Mdot
.5417 .00629 Mdot
.59846 .03508 Mdot
.75952 .09954 Mdot
.1001 .21049 Mdot
.33488 .1451 Mdot
.41479 .04939 Mdot
.40295 .61071 Mdot
.2881 .54706 Mdot
.99855 .43908 Mdot
.71063 .44009 Mdot
.59709 .54786 Mdot
.58657 .61154 Mdot
.66913 .05102 Mdot
.90881 .14813 Mdot
.24599 .20839 Mdot
.40338 .09727 Mdot
.45818 .03386 Mdot
.46625 .00499 Mdot
.43647 .59963 Mdot
.3368 .55643 Mdot
.08337 .4614 Mdot
.73998 .40581 Mdot
.57608 .51674 Mdot
.49492 .56787 Mdot
.40803 .56433 Mdot
.2229 .50362 Mdot
.86052 .39407 Mdot
.63634 .47948 Mdot
.54806 .56348 Mdot
.51328 .59654 Mdot
.49348 .6058 Mdot
.46632 .60125 Mdot
.40138 .5779 Mdot
.23199 .51335 Mdot
.88391 .40291 Mdot
.65568 .47698 Mdot
.57664 .56918 Mdot
.58088 .00262 Mdot
.67263 .05671 Mdot
.92339 .15498 Mdot
.25742 .20644 Mdot
.41179 .09541 Mdot
.47152 .03691 Mdot
.49922 .01712 Mdot
.52605 .01658 Mdot
.58219 .0347 Mdot
.72713 .08958 Mdot
.05006 .19958 Mdot
.31735 .16519 Mdot
.42066 .06385 Mdot
.43798 .01071 Mdot
.38699 .58652 Mdot
.21875 .51406 Mdot
.87413 .40504 Mdot
.65737 .48407 Mdot
.59084 .57692 Mdot
.62148 .01894 Mdot
.77644 .09577 Mdot
.10878 .20539 Mdot
.32754 .1352 Mdot
.38739 .03699 Mdot
.33033 .58277 Mdot
.11586 .48548 Mdot
.78172 .41153 Mdot
.62388 .52048 Mdot
.5923 .59852 Mdot
.65927 .04139 Mdot
.87764 .13496 Mdot
.22105 .21224 Mdot
.38759 .10293 Mdot
.43741 .03079 Mdot
.4183 .60623 Mdot
.31087 .55164 Mdot
.0366 .44852 Mdot
.72133 .42319 Mdot
.583 .53254 Mdot
.53426 .58791 Mdot
.52393 .61165 Mdot
.54053 .01026 Mdot
.60245 .03827 Mdot
.77231 .10498 Mdot
.12025 .21504 Mdot
.34487 .13882 Mdot
.42066 .04684 Mdot
.41047 .61174 Mdot
.30437 .55246 Mdot
.02881 .44773 Mdot
.72087 .42772 Mdot
.58978 .53701 Mdot
.55484 .59644 Mdot
.58066 .01596 Mdot
.69378 .06991 Mdot
.97563 .17419 Mdot
.28491 .19115 Mdot
.41866 .08266 Mdot
.46445 .0283 Mdot
.4704 .00368 Mdot
.4431 .60116 Mdot
.35287 .56227 Mdot
.11908 .47354 Mdot
.76293 .39792 Mdot
.58604 .50871 Mdot
.5017 .56591 Mdot
.41927 .56709 Mdot
.24949 .5131 Mdot
.89987 .40195 Mdot
.65607 .46736 Mdot
.5617 .55971 Mdot
.53533 .60173 Mdot
.54854 .00817 Mdot
.61576 .04154 Mdot
.80255 .11545 Mdot
.15948 .22059 Mdot
.36487 .12694 Mdot
.43526 .0435 Mdot
.4345 .61756 Mdot
.3618 .5731 Mdot
.15182 .48826 Mdot
.79515 .3976 Mdot
.61113 .50431 Mdot
.54274 .57576 Mdot
.52206 .60525 Mdot
.52623 .00258 Mdot
.55991 .02081 Mdot
.65969 .06167 Mdot
.91113 .1554 Mdot
.25786 .21429 Mdot
.42496 .10327 Mdot
.51037 .05279 Mdot
.60749 .06002 Mdot
.81704 .12951 Mdot
.19072 .23095 Mdot
.39688 .12742 Mdot
.49451 .06034 Mdot
.58593 .0565 Mdot
.76981 .11364 Mdot
.13215 .22393 Mdot
.36173 .14189 Mdot
.45399 .05702 Mdot
.49499 .02534 Mdot
.53033 .02184 Mdot
.59974 .0429 Mdot
.77463 .10808 Mdot
.12721 .21791 Mdot
.35087 .13823 Mdot
.42961 .04866 Mdot
.43137 .00109 Mdot
.35796 .57266 Mdot
.14452 .48612 Mdot
.78931 .3985 Mdot
.60848 .50628 Mdot
.54097 .57631 Mdot
.51924 .60461 Mdot
.51921 .61801 Mdot
.54083 .01336 Mdot
.60807 .04156 Mdot
.78828 .11137 Mdot
.14315 .21932 Mdot
.3572 .1323 Mdot
.4307 .04542 Mdot
.42833 .61657 Mdot
.34769 .56819 Mdot
.12002 .47733 Mdot
.76923 .40123 Mdot
.59697 .51157 Mdot
.52763 .57518 Mdot
.48935 .59438 Mdot
.43904 .58694 Mdot
.32152 .5454 Mdot
.042 .44528 Mdot
.71557 .41629 Mdot
.5648 .52485 Mdot
.48525 .56887 Mdot
.38905 .55858 Mdot
.17738 .48722 Mdot
.80427 .38744 Mdot
.60065 .49219 Mdot
.50333 .55789 Mdot
.40977 .56021 Mdot
.21964 .50052 Mdot
.85292 .39139 Mdot
.62973 .4801 Mdot
.53744 .561 Mdot
.48708 .58691 Mdot
.42212 .57789 Mdot
.27264 .52565 Mdot
.94512 .41562 Mdot
.6784 .45319 Mdot
.57362 .55328 Mdot
.54911 .60288 Mdot
.57921 .0186 Mdot
.69516 .07167 Mdot
.9804 .17628 Mdot
.28772 .18994 Mdot
.42024 .0819 Mdot
.46634 .02849 Mdot
.47469 .00516 Mdot
.45456 .60559 Mdot
.38377 .57429 Mdot
.19302 .50014 Mdot
.83382 .39604 Mdot
.6301 .49213 Mdot
.55755 .5732 Mdot
.54864 .61252 Mdot
.59383 .02793 Mdot
.73902 .08973 Mdot
.06363 .20062 Mdot
.31824 .15735 Mdot
.40927 .05626 Mdot
.40325 .61431 Mdot
.29451 .55083 Mdot
.01291 .444 Mdot
.71674 .43499 Mdot
.5965 .54372 Mdot
.57874 .60706 Mdot
.64638 .0418 Mdot
.85707 .13021 Mdot
.20842 .21715 Mdot
.38603 .10977 Mdot
.44558 .0368 Mdot
.44483 .61757 Mdot
.38297 .5798 Mdot
.20047 .50524 Mdot
.84676 .39943 Mdot
.64067 .49066 Mdot
.57364 .57661 Mdot
.58689 .00819 Mdot
.69351 .0659 Mdot
.96876 .17012 Mdot
.27909 .19179 Mdot
.41257 .08249 Mdot
.45214 .02446 Mdot
.43845 .60957 Mdot
.35692 .56765 Mdot
.13462 .48065 Mdot
.7777 .39745 Mdot
.59791 .50692 Mdot
.52192 .57107 Mdot
.47062 .58633 Mdot
.3863 .56592 Mdot
.18416 .49311 Mdot
.81735 .39133 Mdot
.61451 .49268 Mdot
.5302 .56593 Mdot
.47981 .58689 Mdot
.40668 .57283 Mdot
.23402 .51133 Mdot
.88243 .40074 Mdot
.65193 .47558 Mdot
.56821 .56629 Mdot
.55922 .61248 Mdot
.61562 .03486 Mdot
.79148 .10869 Mdot
.14111 .21608 Mdot
.35137 .12995 Mdot
.41705 .04059 Mdot
.39318 .60328 Mdot
.25747 .53416 Mdot
.94211 .42313 Mdot
.69073 .46268 Mdot
.60688 .56621 Mdot
.63492 .01733 Mdot
.79779 .10066 Mdot
.13247 .20684 Mdot
.33415 .12464 Mdot
.38054 .02867 Mdot
.30427 .57089 Mdot
.05851 .46614 Mdot
.74811 .4262 Mdot
.61755 .53734 Mdot
.60806 .61217 Mdot
.71151 .06394 Mdot
.98957 .17185 Mdot
.27941 .17913 Mdot
.39246 .06987 Mdot
.39304 .00036 Mdot
.28164 .54919 Mdot
.99394 .44023 Mdot
.71309 .44446 Mdot
.60726 .55263 Mdot
.61367 .00396 Mdot
.73788 .07677 Mdot
.04141 .18759 Mdot
.29868 .159 Mdot
.38444 .05301 Mdot
.3508 .59724 Mdot
.1722 .50765 Mdot
.83481 .40952 Mdot
.65234 .50526 Mdot
.61689 .59613 Mdot
.70198 .05259 Mdot
.95879 .15872 Mdot
.26165 .18718 Mdot
.38514 .07632 Mdot
.38982 .00289 Mdot
.27971 .54998 Mdot
.99288 .44076 Mdot
.71409 .44573 Mdot
.61059 .55407 Mdot
.62224 .0072 Mdot
.75882 .08442 Mdot
.07498 .1954 Mdot
.30951 .14495 Mdot
.37662 .04148 Mdot
.31786 .58172 Mdot
.09535 .48052 Mdot
.77143 .41784 Mdot
.62572 .52798 Mdot
.60777 .60694 Mdot
.70249 .05854 Mdot
.96911 .16478 Mdot
.27042 .18621 Mdot
.39335 .07598 Mdot
.40459 .00695 Mdot
.31436 .56227 Mdot
.05879 .46008 Mdot
.73829 .41995 Mdot
.59714 .5308 Mdot
.55908 .59451 Mdot
.58627 .0168 Mdot
.70622 .07414 Mdot
.99927 .18111 Mdot
.29314 .18162 Mdot
.41373 .07453 Mdot
.44154 .01719 Mdot
.40478 .59531 Mdot
.26671 .53271 Mdot
.9498 .42217 Mdot
.68867 .45665 Mdot
.59421 .55965 Mdot
.60009 .00363 Mdot
.71175 .06901 Mdot
.9981 .17697 Mdot
.28659 .1783 Mdot
.39997 .07007 Mdot
.40762 .00472 Mdot
.31663 .5618 Mdot
.06133 .46025 Mdot
.73843 .41847 Mdot
.5949 .52933 Mdot
.55236 .59174 Mdot
.56793 .00962 Mdot
.65796 .05564 Mdot
.89859 .14872 Mdot
.24621 .21484 Mdot
.41404 .10372 Mdot
.4894 .04657 Mdot
.55277 .03917 Mdot
.6747 .07535 Mdot
.95671 .17429 Mdot
.28704 .20415 Mdot
.44237 .096 Mdot
.534 .05663 Mdot
.66375 .08019 Mdot
.94757 .17541 Mdot
.28957 .21137 Mdot
.45726 .10364 Mdot
.57724 .07415 Mdot
.78111 .126 Mdot
.1614 .23503 Mdot
.389 .14066 Mdot
.5011 .06928 Mdot
.61444 .07005 Mdot
.84624 .14326 Mdot
.22599 .2347 Mdot
.42794 .12481 Mdot
.55122 .07619 Mdot
.73138 .11135 Mdot
.09016 .22174 Mdot
.35242 .16208 Mdot
.47081 .07317 Mdot
.55639 .05289 Mdot
.70437 .09145 Mdot
.02484 .19807 Mdot
.31736 .18079 Mdot
.44591 .07944 Mdot
.5145 .04239 Mdot
.59944 .0525 Mdot
.78959 .11752 Mdot
.15405 .22525 Mdot
.37037 .13369 Mdot
.45587 .05284 Mdot
.49213 .02241 Mdot
.51951 .01692 Mdot
.56887 .03051 Mdot
.69366 .07712 Mdot
.98713 .18138 Mdot
.29513 .19036 Mdot
.43047 .08364 Mdot
.48972 .03662 Mdot
.53736 .02944 Mdot
.62683 .0553 Mdot
.84493 .13479 Mdot
.21182 .22675 Mdot
.40401 .11878 Mdot
.4942 .05574 Mdot
.57783 .05169 Mdot
.74594 .1039 Mdot
.09383 .21501 Mdot
.34173 .15321 Mdot
.43885 .06002 Mdot
.46855 .01836 Mdot
.46294 .61457 Mdot
.41582 .58891 Mdot
.27795 .53283 Mdot
.963 .42339 Mdot
.68949 .44899 Mdot
.58297 .5522 Mdot
.56603 .60756 Mdot
.62157 .03433 Mdot
.80151 .11121 Mdot
.15196 .21659 Mdot
.35562 .12587 Mdot
.41761 .03831 Mdot
.39059 .60134 Mdot
.24945 .5308 Mdot
.92847 .41966 Mdot
.68562 .46795 Mdot
.60811 .57013 Mdot
.64358 .02192 Mdot
.82016 .10913 Mdot
.1594 .20966 Mdot
.34715 .11604 Mdot
.38753 .02496 Mdot
.31115 .57083 Mdot
.06803 .46778 Mdot
.75036 .4217 Mdot
.61253 .53285 Mdot
.59152 .60505 Mdot
.66833 .04747 Mdot
.90182 .1443 Mdot
.23935 .20861 Mdot
.39744 .0977 Mdot
.44748 .03093 Mdot
.43926 .61295 Mdot
.36404 .57155 Mdot
.15321 .48773 Mdot
.79478 .39651 Mdot
.60912 .50329 Mdot
.53734 .57367 Mdot
.50735 .5995 Mdot
.48568 .60464 Mdot
.44784 .59465 Mdot
.3521 .55887 Mdot
.11228 .46982 Mdot
.75585 .39775 Mdot
.57914 .50882 Mdot
.48821 .56184 Mdot
.38398 .55362 Mdot
.15995 .47958 Mdot
.78411 .38575 Mdot
.58399 .49436 Mdot
.47444 .55033 Mdot
.33613 .53255 Mdot
.04368 .43729 Mdot
.70248 .40717 Mdot
.53318 .5134 Mdot
.4011 .53641 Mdot
.16433 .4717 Mdot
.77314 .37627 Mdot
.5599 .48624 Mdot
.41276 .5271 Mdot
.1719 .46917 Mdot
.77241 .37114 Mdot
.551 .48119 Mdot
.38622 .5162 Mdot
.10356 .44334 Mdot
.71195 .37601 Mdot
.49508 .484 Mdot
.27266 .48057 Mdot
.87221 .37054 Mdot
.60114 .4505 Mdot
.43682 .51648 Mdot
.20296 .4735 Mdot
.79706 .36717 Mdot
.5632 .4735 Mdot
.39888 .51648 Mdot
.12785 .45052 Mdot
.72738 .37053 Mdot
.50495 .48056 Mdot
.28812 .48402 Mdot
.89658 .37605 Mdot
.61385 .4433 Mdot
.44907 .5162 Mdot
.22773 .48123 Mdot
.82829 .37117 Mdot
.58738 .46914 Mdot
.44032 .52715 Mdot
.22739 .48644 Mdot
.83643 .37641 Mdot
.59944 .47157 Mdot
.46764 .53658 Mdot
.29954 .51414 Mdot
.96022 .40833 Mdot
.66539 .43582 Mdot
.52559 .53163 Mdot
.41457 .54942 Mdot
.21159 .49259 Mdot
.83398 .38466 Mdot
.61175 .48069 Mdot
.50568 .55248 Mdot
.40601 .55644 Mdot
.20621 .49455 Mdot
.83333 .38758 Mdot
.6162 .48384 Mdot
.51901 .55797 Mdot
.44327 .57122 Mdot
.30476 .53243 Mdot
.99694 .42779 Mdot
.69258 .42993 Mdot
.55649 .53392 Mdot
.4829 .57255 Mdot
.39003 .56063 Mdot
.18254 .4898 Mdot
.81112 .38849 Mdot
.60645 .49154 Mdot
.51329 .56046 Mdot
.43514 .56973 Mdot
.2857 .52568 Mdot
.96093 .41731 Mdot
.67986 .44433 Mdot
.56146 .54486 Mdot
.51079 .58672 Mdot
.47231 .59425 Mdot
.4027 .57501 Mdot
.22986 .51121 Mdot
.87861 .40095 Mdot
.65162 .47774 Mdot
.57118 .56832 Mdot
.56854 .6164 Mdot
.64096 .04476 Mdot
.85265 .13083 Mdot
.20806 .21965 Mdot
.38983 .11234 Mdot
.45681 .0414 Mdot
.47558 .0116 Mdot
.46686 .61265 Mdot
.42097 .58967 Mdot
.28939 .53671 Mdot
.98344 .42895 Mdot
.69617 .44049 Mdot
.57856 .54535 Mdot
.54617 .59801 Mdot
.56521 .01177 Mdot
.6559 .05605 Mdot
.89591 .14833 Mdot
.24533 .21595 Mdot
.41498 .10485 Mdot
.49308 .04826 Mdot
.56334 .04343 Mdot
.70332 .08651 Mdot
.01545 .19291 Mdot
.31015 .18214 Mdot
.43771 .07883 Mdot
.49665 .03643 Mdot
.5518 .03409 Mdot
.66446 .06963 Mdot
.93162 .16511 Mdot
.27369 .21141 Mdot
.4379 .10149 Mdot
.53371 .05921 Mdot
.66732 .08258 Mdot
.95706 .17907 Mdot
.29473 .20869 Mdot
.45961 .1019 Mdot
.57935 .074 Mdot
.78509 .12715 Mdot
.16631 .23561 Mdot
.39199 .13948 Mdot
.50477 .0697 Mdot
.62294 .07303 Mdot
.86663 .15061 Mdot
.244 .23322 Mdot
.44165 .12215 Mdot
.57482 .08231 Mdot
.78947 .13266 Mdot
.17846 .24041 Mdot
.40547 .1403 Mdot
.53183 .0781 Mdot
.69392 .10018 Mdot
.02481 .2045 Mdot
.32777 .18724 Mdot
.47195 .0891 Mdot
.58458 .06961 Mdot
.78836 .12594 Mdot
.16678 .23388 Mdot
.38939 .13758 Mdot
.49683 .0664 Mdot
.6007 .06419 Mdot
.8109 .12992 Mdot
.18795 .23303 Mdot
.39865 .13022 Mdot
.5024 .06412 Mdot
.60886 .0658 Mdot
.82897 .13603 Mdot
.20723 .23378 Mdot
.4121 .12662 Mdot
.52263 .06831 Mdot
.65863 .08406 Mdot
.94566 .17739 Mdot
.2929 .21461 Mdot
.46679 .10747 Mdot
.60344 .08445 Mdot
.8489 .15171 Mdot
.24059 .24208 Mdot
.45275 .13112 Mdot
.61231 .09861 Mdot
.88849 .17069 Mdot
.28062 .24235 Mdot
.49623 .13325 Mdot
.70757 .13062 Mdot
.0924 .23784 Mdot
.37859 .17687 Mdot
.54051 .10007 Mdot
.7477 .12805 Mdot
.13472 .23919 Mdot
.38705 .15595 Mdot
.52218 .08352 Mdot
.68231 .09896 Mdot
.00626 .20021 Mdot
.32314 .19584 Mdot
.47883 .09622 Mdot
.61066 .08148 Mdot
.85771 .15268 Mdot
.24496 .23934 Mdot
.45247 .12824 Mdot
.60705 .09554 Mdot
.87368 .16479 Mdot
.26853 .24403 Mdot
.48475 .13363 Mdot
.68378 .123 Mdot
.0473 .22467 Mdot
.35816 .19212 Mdot
.52912 .10566 Mdot
.73282 .12589 Mdot
.11531 .23639 Mdot
.3786 .16273 Mdot
.51764 .08593 Mdot
.67658 .09823 Mdot
.99655 .19776 Mdot
.32043 .20016 Mdot
.48177 .09972 Mdot
.62257 .08702 Mdot
.88858 .1644 Mdot
.27046 .23601 Mdot
.47398 .12578 Mdot
.64823 .10769 Mdot
.96678 .19688 Mdot
.3226 .21991 Mdot
.51697 .12012 Mdot
.73047 .13195 Mdot
.12247 .24227 Mdot
.38933 .16493 Mdot
.54098 .09372 Mdot
.73843 .12203 Mdot
.11526 .23289 Mdot
.37293 .15925 Mdot
.50178 .07964 Mdot
.63265 .08088 Mdot
.89666 .16316 Mdot
.2694 .23037 Mdot
.46364 .12005 Mdot
.61715 .09487 Mdot
.89141 .1695 Mdot
.27907 .23959 Mdot
.48988 .13029 Mdot
.68926 .12323 Mdot
.05556 .22638 Mdot
.36034 .18836 Mdot
.52679 .10287 Mdot
.72336 .12149 Mdot
.09727 .23109 Mdot
.36798 .16731 Mdot
.50603 .08532 Mdot
.6509 .08954 Mdot
.94187 .17983 Mdot
.29707 .21953 Mdot
.48024 .1132 Mdot
.64113 .09944 Mdot
.94141 .18558 Mdot
.30641 .22558 Mdot
.50274 .12134 Mdot
.70217 .12326 Mdot
.07339 .22942 Mdot
.36458 .17997 Mdot
.52056 .0964 Mdot
.69972 .11072 Mdot
.04981 .21637 Mdot
.34454 .18215 Mdot
.49022 .09004 Mdot
.62485 .08321 Mdot
.88653 .16173 Mdot
.26584 .23443 Mdot
.4662 .12383 Mdot
.62865 .1004 Mdot
.92115 .18078 Mdot
.29915 .23362 Mdot
.50582 .12772 Mdot
.71905 .13179 Mdot
.10874 .24084 Mdot
.38489 .17067 Mdot
.54202 .09711 Mdot
.74608 .12612 Mdot
.12994 .23723 Mdot
.38274 .15624 Mdot
.5147 .08156 Mdot
.66325 .09181 Mdot
.96558 .18685 Mdot
.3065 .2107 Mdot
.4788 .10648 Mdot
.62721 .09172 Mdot
.90453 .1714 Mdot
.28339 .23414 Mdot
.48633 .12543 Mdot
.67386 .1159 Mdot
.02103 .21457 Mdot
.34451 .19992 Mdot
.51893 .1078 Mdot
.7147 .12099 Mdot
.0859 .22942 Mdot
.36468 .1723 Mdot
.50832 .08877 Mdot
.66136 .09458 Mdot
.96706 .18893 Mdot
.30972 .21178 Mdot
.48505 .10836 Mdot
.6435 .09793 Mdot
.94301 .18511 Mdot
.30556 .22406 Mdot
.4991 .11962 Mdot
.69162 .11899 Mdot
.05202 .22274 Mdot
.35468 .18705 Mdot
.51501 .09909 Mdot
.69229 .10956 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{252, 155.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003l0000Vb000`400?l00000o`00003oo?ooool0
0?cooooo003looooo`00o?ooool008Wooooo0ol0001`ooooo`00R?ooool01Ol0003ooooooooooooo
oooo000006oooooo0028ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0K?ooool0
08Sooooo1_l0001^ooooo`00ROooool01Ol0003ooooooooooooooooo000006kooooo002:ooooo`?o
0000Koooool00?cooooo003looooo`00o?ooool004Oooooo0_l00004ooooo`04o`000?oooooooooo
ooooo`Go00006_ooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0001[ooooo0_l00004
ooooo`03o`000?oooooooooo00;ooooo0ol0000Kooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`?o00008?ooool3o`0000Wooooo0016ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00006Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo01Sooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000001Wooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool02?oo
ool004Kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`0Iooooo`04o`000?oo
ooooooooo`0000Oooooo1Ol0000Iooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`00000Iooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
000Pooooo`03o`000?oooooooooo00Sooooo0016ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool06?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0001[o
oooo00Co0000oooooooooooo00001oooool4o`0001[ooooo00Co0000oooooooooooo00002?ooool3
o`00027ooooo00?o0000ooooooooool02?ooool004Kooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000001Wooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00000Jooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool06oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000008?ooool00ol0003oooooooooo`08
ooooo`00A_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000006Ooo
ool01?l0003oooooooooool00009ooooo`;o00006_ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo01[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000001oooooo0_l0000:ooooo`00Aoooool2o`0000Wooooo0ol0000Kooooo`;o00002oooool00ol0
003oooooooooo`0Iooooo`;o00002_ooool2o`0001_ooooo0_l00009ooooo`?o00008Oooool00ol0
003oooooooooo`08ooooo`00o?ooool00?cooooo003looooo`009OoooomDo`00000300000?l0003o
000000ko000000<00000o`0000000000IOl000000`00003oooooooooo`07ooooo`009Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`06o`000?ooooooooooooooool0003ooooo1ol00002ooooo`Oo000000?o
ooooo`000?l000000_l000002Ooooooo0000o`000?l0003oooooo`000?ooool00000ooooo`08o`00
0003ooooool0003ooooo00So000000?oooooo`000?ooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00`00003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`0300000?oooooooooo00Oooooo000Uooooo`03o`000?oooooooooo02Kooooo00<00000oooooooo
ool09Oooool3o`000005ooooool0003oooooo`000?ooool01?l000000ooooooo0000o`000002oooo
o`?o000000<00000ooooool000001?l00003ooooo`Oo000000?oooooo`000?l000000ol000000ooo
oooo0000o`000002o`000005ooooool0003oooooooooool000007_ooool00`00003oooooooooo`0V
ooooo`0300000?oooooooooo00Oooooo000Uooooo`03o`000?oooooooooo04gooooo0_l000000`00
003o0000o`000004o`0000;ooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`04o`00
0003ooooo`00003ooooo00Co000000Ooooooo`000?l0003oooooo`000000003o000000;ooooo0ol0
00000ooooooo0000ooooo`04o`00000400000?l0003oooooo`0004Sooooo00<00000ooooooooool0
1oooool002Gooooo00?o0000ooooooooool0B?ooool01?l0003oooooooooooooool4o`000004oooo
ool0003o0000000000Oo00000_ooool3o`000003ooooool0003o000000?o00000_ooool2o`000006
ooooool0003o0000ooooool0003ooooo0_l000000ooooooo0000o`000002o`00000500000?l00000
0000o`000?ooool01ol00017ooooo`0300000?oooooooooo00Oooooo000Uooooo`03o`000?oooooo
oooo04[ooooo0_l000001?oooooo0000o`0000000003o`00000400000?l0003o0000ooooo`;o0000
00?oooooo`000?l000000_l000001?oooooo0000ooooo`000002o`000004ooooool0003oooooo`00
00;ooooo0_l000000ooooooo0000o`000004o`0000;ooooo00?o0000ooooool000000ol000000ooo
oooo0000o`000008o`0004Cooooo00<00000ooooooooool01oooool002Gooooo00?o0000oooooooo
ool0Boooool00ol0003oooooo`000002o`0000Cooooo1_l000001?oooooo0000o`000?l00003oooo
o`Ko000000?oooooo`000?l000001?l000001?oooooo0000ooooooooool3o`000008ooooool0003o
0000o`000000003oooooo`000?ooool2o`000007ooooool0003oooooo`000000003ooooo00000002
o`0000;ooooo00?o0000ooooooooool0?Oooool00`00003oooooooooo`07ooooo`009Oooool2o`00
04[ooooo00?o0000ooooo`0000000_l000001000003oooooooooooooool2o`000004ooooool0003o
0000000000;o000000?oooooo`000?l000000_l00003ooooo`;o00000oooool01Ol0003ooooooooo
ool0003ooooo00?o00001?ooool00ol0003oooooo`000003o`000003ooooool0003o000000;o0000
00Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o0000043ooooo00?o000000000?oo
ool02?ooool002Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooo`000008o`000003oooo
ool0003ooooo00Co000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000000?o
000000?oooooo`000?ooool00ol00003ooooo`?o00000_ooool00`00003o0000o`000003o`000003
ooooool0003o000000;o000000P00000o`000?l0003oooooo`000000003o0000ooooo`;o0000?Ooo
ool00`00003oooooooooo`07ooooo`009Oooool00ol0003oooooooooo`1:ooooo`Co000000Cooooo
o`000?oooooooooo2ol000002?oooooo0000o`000?oooooo000000000?oooooo00000_ooool8o`00
00;ooooo0_l000001?oooooo0000o`000?ooool>o`00000:ooooool0003o0000o`000?oooooo0000
ooooool0003oooooo`0003_ooooo00<00000ooooooooool01oooool002Gooooo00?o0000oooooooo
ool0BOooool00ol0003oooooo`00000;o`000004ooooool0003o0000ooooo`;o00000_ooool7o`00
00?ooooo00Go0000ooooool0003o0000ooooo`02o`000003ooooool0003ooooo00;ooooo0_l00002
ooooo`?o000000Coooooo`000?oooooooooo0ol000001Ooooooo0000o`000?l0003ooooo00;o0000
00Coooooo`000?l0003o0000??ooool00`00003oooooooooo`07ooooo`009Oooool00ol0003ooooo
ooooo`1:ooooo`[o000000Koooooo`000?l0003ooooo00000?ooool3o`000003ooooool0003o0000
00;ooooo1_l000000ooooooo0000ooooo`07o`00000300000?oooooo000000Go000000?oooooo`00
0?ooool01Ol000000ooooooo0000o`000002o`0000;ooooo00Co0000oooooooooooooooo0_l00003
ooooo`03o`000?oooooooooo03Gooooo00<00000ooooooooool01oooool002Gooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`02ooooo`Go000000?oooooo`000?l000000_ooool2o`00
0004ooooool0003o0000ooooo`;o00000_ooool3o`000005ooooool0003o0000o`000?ooool01?l0
00001?oooooo0000o`000?ooool5o`000003ooooool0003ooooo00?o00000_ooool4o`0000;ooooo
3?l0000jooooo`0300000?oooooooooo00Oooooo000Uooooo`;o0000COooool2o`00000400000?oo
oooooooo000000Co000000?ooooo00000?ooool00ol000001ooooooo0000o`000?l0003ooooo0000
0?ooool00ol00002ooooo`03o`000?oooooo000000Ko000000?oooooo`000?ooool00_l000001@00
003oooooo`000?l0003ooooo00;o000000Ooooooo`000?l0003o0000ooooool0003ooooo00?o0000
0_ooool7o`0003Wooooo00?o000000000?ooool02?ooool002Gooooo00?o0000ooooooooool0C_oo
ool5o`000003ooooool0003ooooo00?ooooo1Ol000001Ooooooo0000ooooool0003ooooo00Co0000
00?oooooo`000?l000001ol000000ooooooo0000o`000002o`000004ooooool0003o0000ooooo`;o
000000?oooooo`000?l000001?l00002ooooo`?o000000?oooooo`000?ooool01ol0000hooooo`03
00000?oooooooooo00Oooooo000Uooooo`03o`000?oooooooooo04cooooo00?o0000ooooool00000
4_l00004ooooo`0300000?l0003o000000?o00000_ooool4o`000003ooooool0003ooooo00Co0000
00<00000o`000?l000000_ooool01_l000000000oooooooooooo0000ooooo`?o000000?oooooo`00
0?l000000_ooool2o`000005ooooool0003o0000o`00000000001?l0000dooooo`0300000?oooooo
oooo00Oooooo000Uooooo`03o`000?oooooooooo04Wooooo1?l000000ooooooo0000o`000003o`00
00Cooooo00Go0000ooooool0003o0000ooooo`04o`000004ooooool0003o0000ooooo`;o000000?o
ooooo`000?l000001ol00003ooooo`03o`000?oooooo000000?o000000?oooooo`000?ooool01?oo
ool2o`000004ooooool0003o0000o`0000Gooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`Go0000<_ooool00`00003oooooooooo`07ooooo`009Oooool00ol0003oooooooooo`19ooooo`;o
000000?oooooo`000?l000000_ooool6o`0000;ooooo00Ko0000ooooool0003oooooo`000?ooool2
o`00000300000?l0003ooooo00Cooooo0ol000000ooooooo0000o`000002o`0000;ooooo00Ko0000
ooooool0003o0000ooooool00002ooooo`;o00000_ooool01?l0003oooooo`000?ooool2o`000003
ooooool0003o000000Go00001?ooool01?l0003oooooo`0000000005o`000003ooooool0003ooooo
02oooooo00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooo`000004o`000003ooooool0003o000000;o000000?oooooo`000?ooool00oooool3o`000005
ooooool0003o0000ooooool000000oooool01?l0003oooooo`000?ooool2o`00000300000?oooooo
000000;ooooo00?o0000ooooool000000ol000000`00003ooooo00000006o`0000Cooooo00?o0000
ooooool000001Ol000001_oooooo0000o`000?oooooo0000ooooo`Oo000000?oooooo`000?l00000
0_ooool00ol0003oooooooooo`0Zooooo`0300000?oooooooooo00Oooooo000Uooooo`;o0000Booo
ool00ol000000000o`000003o`000003ooooool0003o000000;ooooo00Co0000oooooooooooooooo
1?l000001P00003o0000o`000?l0003oooooo`0000Cooooo00Co0000ooooool0003ooooo1_l00000
0`00003oooooo`000002o`00000500000?l0003ooooo00000?ooool01?l00006ooooo`03o`000?oo
oooo000000Co000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00?o0000
0_ooool00ol000000000ooooo`0[ooooo`03o`000000003ooooo00Sooooo000Uooooo`03o`000?oo
oooooooo04Sooooo1Ol000000ooooooo0000o`000003o`00000300000?l0003o000000;ooooo00?o
0000ooooooooool01ol00005ooooo`;o00000oooool00ol0003oooooo`000003o`00000300000?l0
003o000000;o00000P000003o`0000Gooooo00?o0000ooooooooool01?ooool3o`0000;ooooo00Oo
0000ooooool0003oooooo`000?oooooo000000;ooooo1?l000001P00003o0000o`000000003ooooo
o`0002[ooooo00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool0Aoooool00ol0
00000000o`000002o`000006ooooool0003oooooooooool0003ooooo2?l000002?oooooo0000oooo
ool000000000o`000?oooooo00001oooool01Ol0003ooooo00000?l0003ooooo00?o000000?ooooo
o`000?l000000_ooool4o`000005ooooool0003o0000ooooool000002Oooool01?l0003oooooo`00
0?l00002ooooo`;o000000Woooooo`000?l0003oooooo`000?oooooo0000ooooool000000oooool2
o`000003ooooool0003o000000?o00009_ooool00`00003oooooooooo`07ooooo`009Oooool00ol0
003oooooooooo`16ooooo`;o00000_ooool7o`000005ooooool0003oooooooooool000000_ooool8
o`000003ooooool0003ooooo00Gooooo00Co0000ooooool0003ooooo1ol000000`00003o0000o`00
0004o`000003ooooool0003o000000;o000000Coooooo`000?oooooo00002Oooool2o`000003oooo
ool0003o000000oo000000@00000o`000?l0003ooooo0ol0000Sooooo`0300000?oooooooooo00Oo
oooo000Booooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Cooooo00?o0000oooooooo
ool0A?ooool01_l0003oooooo`000?l0003ooooo000000Oo000000?ooooo00000?l000000_ooool2
o`000003ooooool0003ooooo00?o00000_ooool00ol0003oooooooooo`04ooooo`Co000000Kooooo
00000?l0003oooooo`0000000002o`00000300000?oooooooooo00?o00000_ooool6o`0000;ooooo
0ol00005ooooo`03o`000?oooooo000000;ooooo1?l000001Ooooooo0000o`000?l0003ooooo00?o
000000Goooooo`000?oooooo000000000003o`000006ooooool0003oooooo`000?oooooo00008?oo
ool00`00003oooooooooo`07ooooo`004Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0@Oooool6o`000003ooooool0003o000000;o0000
00Coooooo`000?oooooooooo0_l000000ooooooo0000o`000002o`0000Cooooo00<00000o`000?l0
00002Oooool2o`000003ooooool0003o000000;o000000Coooooo`000?l0003ooooo2Ol00002oooo
o`;o000000@00000ooooool0000000001Ol00003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00ol000000ooooooo0000o`000003o`000003ooooool0003o000000Co00000_ooool0
0ol0003oooooooooo`04o`0001gooooo00<00000ooooooooool01oooool0017ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo0ol00000
1?oooooo0000o`000?ooool5o`0000Gooooo00Oo0000ooooool0003o0000ooooool00000000000;o
oooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool2o`000005ooooool0003o0000
00000?ooool03?l000000ooooooo0000ooooo`04o`000003ooooool0003o000000?o000000L00000
ooooool0003oooooo`000?oooooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo
1?l00003ooooo`?o000000Goooooo`000?l000000000o`000002ooooo`03o`000000003ooooo01[o
oooo00<00000ooooooooool01oooool0017ooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`03ooooo`;o0000@Oooool3o`00000300000?oooooo000000Co000000?oooooo`000?oo
ool01?l000001Ooooooo0000oooooooooooo000000;ooooo00?o0000ooooool000000oooool4o`00
00?ooooo00?o0000ooooooooool00ol00002ooooo`?o00000_ooool4o`0000;ooooo0_l000000ooo
oooo0000o`000006o`00000:00000?l0003oooooooooool000000000ooooool0003ooooo000000Co
oooo00?o0000ooooool000000_ooool4o`0000;ooooo1?l000001?oooooo0000ooooooooool4o`00
0003ooooool0003o000000Oo00005oooool00ol000000000ooooo`08ooooo`004Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo00;ooooo1?l000001000003o0000o`000?l00004ooooo`04o`000?oo
oooo0000000000Co000000Ooooooo`000000003o000000000?l0003ooooo00Ko00000oooool4o`00
008000002Ol00006ooooo`03o`000?oooooo000000?o00000oooool3o`000003ooooool000000000
00Co00000_ooool02_l0003oooooo`000?l000000000ooooool0003oooooo`000?ooool2o`000003
ooooool0003o000000;o000000<00000o`000?ooool00_l00005ooooo`;o000000?oooooo`000?l0
00001?l000000ooooooo0000ooooo`0Booooo`0300000?oooooooooo00Oooooo000Aooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
03oooooo2?l00002ooooo`?o000000<00000o`000?l000001Ol00002ooooo`04o`000000003ooooo
ooooo`Go000000<00000ooooo`0000001Ol000000ooooooo0000o`00000:o`0000gooooo2?l00000
0`00003o0000o`000005o`00000300000?oooooooooo00;o000000?oooooo`000?l000000_l00000
1?oooooo0000o`000?l00002ooooo`Go000000?oooooo`000?l000002Ol00002ooooo`;o000000<0
0000o`000?ooool04Oooool00`00003oooooooooo`07ooooo`004_ooool2o`0000Wooooo0ol00005
ooooo`03o`000?oooooooooo03gooooo0_l00002ooooo`03o`000000003ooooo00Oo000000Gooooo
o`000?l0003o0000ooooo`02o`000003ooooool0003ooooo00co000000Coooooo`000?l0003ooooo
1?l000001Ooooooo0000o`000?l0003ooooo00Go00004?ooool9o`000003ooooool0003ooooo00Go
000000Kooooo00000?l0003oooooo`000?ooool5o`00000300000?l0003ooooo00?o000000?ooooo
o`000?l000001?l00002ooooo`?o000000Coooooo`000?l0003ooooo0_l000001Ooooooo0000o`00
0?oooooo000000kooooo00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool0?Ooo
ool3o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?l000001?ooool4o`0000040000
0?l0003o0000000000Co00000P000002o`00000300000?l0003ooooo00?o000000?oooooo`000?l0
00001_l000001Ooooooo0000oooooooooooo000001Gooooo00?o0000ooooool000000_l000000ooo
oooo0000o`000004o`0000;ooooo00?o0000ooooool000001?l000000`00003o0000o`000003o`00
008000000_l000001000003o0000o`000?ooool2o`000003ooooool0003o000000Co00000_ooool3
o`000003ooooool0003ooooo00;o00003Oooool00`00003oooooooooo`07ooooo`009Oooool00ol0
003oooooooooo`0kooooo`04o`000?oooooo0000000000?o000000Goooooo`000?l0003o0000oooo
o`02o`0000?ooooo0ol00002ooooo`?o000000Coooooo`000?l0003o00000P0000000oooool00000
ooooo`06o`000003ooooool0003o000000So00000oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooo000000?ooooo1?l000001?oooooo0000o`000?ooool4o`000005ooooool0003o0000o`00
000000000_ooool4000000?o000000L00000oooooooooooo000000000?l0003ooooo00?o000000?o
ooooo`000?ooool01ol000000ooooooo0000o`000002o`0000Wooooo00<00000ooooooooool01ooo
ool002Gooooo0_l0000jooooo`03o`000?oooooo000000Co00001?ooool3o`000003ooooool0003o
oooo00;ooooo0ol000000`00003o0000o`000002o`00000500000?l0003o0000o`00000000000ol0
000200000003o`000000003o000000Go00000_ooool00ol0003oooooo`000006o`0001Wooooo00?o
0000ooooool000002Ol000000ooooooo0000o`000004o`00000400000?oooooooooo000000;o0000
0_ooool2o`0000;ooooo0ol000000ooooooo0000ooooo`03ooooo`0300000?oooooo000000;o0000
00Coooooo`000000003o00000_ooool01Ol0003oooooo`000?oooooo000000Oooooo00?o00000000
0?ooool02?ooool002Gooooo00?o0000ooooooooool0>Oooool3o`000003ooooool0003o000000;o
000000?ooooo00000?l000000_l000001?oooooo0000o`000?ooool2o`000007ooooool0003o0000
o`000?oooooo0000ooooo`09o`000003ooooool0003o000000Co000000?oooooo`000?l000003?l0
000Hooooo`03o`000?oooooo000000Go000000?oooooo`000?l000000_l00002ooooo`ko000000Go
ooooo`000?l0003o000000000002ooooo`0300000?l0003o000000?o000000Coooooo`000?l0003o
oooo2ol000000ooooooo0000ooooo`04ooooo`0300000?oooooooooo00Oooooo000Uooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooool000000ol00002ooooo`Co00000oooool00ol0003ooooo
o`000003o`000005ooooool0003oooooooooool000000_ooool7o`000006ooooool0003o0000oooo
ool0003ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000?o00000oooool0
0ol0003oooooooooo`0Cooooo`;o00000oooool2o`000007ooooool0003o0000o`000?oooooo0000
ooooo`02o`000004ooooool0003oooooo`0000;ooooo1ol000000ooooooo0000o`000002ooooo`04
o`000?oooooo0000ooooo`Co00000_ooool4o`000006ooooool0003o0000ooooool0003ooooo1_l0
0002ooooo`03o`000?ooool0000000Wooooo000Uooooo`03o`000?oooooooooo03Cooooo00Ko0000
oooooooooooo0000ooooo`000002ooooo`0<o`000?oooooo0000ooooool0003oooooo`000?oooooo
000000000?l0003ooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;o0000
00Ooooooo`000?l0003o0000ooooool0003ooooo00So000000?oooooo`000?l000001?l000000ooo
oooo0000o`000004o`000003ooooool0003o000000?o00004_ooool3o`0000;ooooo3_l000000ooo
oooo0000ooooo`07o`0000;ooooo1Ol000000ooooooo0000o`000002o`00000300000?l0003o0000
00?o000000_oooooo`000?l0003o0000ooooool0003oooooo`000?oooooo0000ooooo`06o`000003
ooooo`00003ooooo00Sooooo000Uooooo`;o0000>Oooool3o`000007ooooool0003o0000o`000?oo
oooo0000ooooo`02o`0000Oooooo1?l000001?oooooo0000o`000?ooool;o`000005ooooool0003o
0000o`000?ooool01Ol000001?oooooo0000o`000?ooool6o`000003ooooool0003o000000;o0000
00?oooooo`000?l000000_l00006ooooo`03o`000?oooooooooo00;ooooo2Ol000001Ooooooo0000
o`000?l0003ooooo00?o00000_ooool9o`000005ooooool0003o0000o`000?ooool00_l000000ooo
oooo0000o`000007o`000003ooooool0003ooooo00Oooooo1?l00003ooooo`;o000000Coooooo`00
0?l0003o00002Oooool002Gooooo0ol000001_ooool00000ooooool0003oooooo`0002oooooo00?o
0000ooooool000000ol000000ooooooo0000o`000002o`0000;ooooo0ol00003ooooo`04o`000?oo
oooo0000ooooo`;o000000<00000ooooool000000_ooool5o`000003ooooool0003o000000Co0000
00?oooooo`000?l000001Ol000001ooooooo0000o`000?l0003oooooo`000?ooool02?l000000ooo
oooo0000o`000002o`000003ooooool0003o000000;o00000oooool00ol0003oooooo`000003o`00
0003ooooool0003o000000Co000000Coooooo`000?l0003o00000_ooool00ol0003oooooooooo`0@
o`000003ooooool0003o000000Wo00000_ooool2o`000003ooooool0003ooooo00;ooooo00?o0000
ooooooooool00_l00002ooooo`06o`000?ooooooooooo`000?oooooo00002Oooool002Gooooo0_l0
0002ooooo`Ko0000:Oooool00ol0003oooooo`000006o`0000Cooooo00Ko0000ooooool0003o0000
ooooool00003ooooo`03o`000?oooooooooo00Co000000Coooooo`000?l0003o00000_ooool4o`00
00Cooooo0ol000000ooooooo0000o`000002o`000007ooooool0003o0000ooooool0003oooooo`00
0002ooooo`;o000000Coooooo`000?l0003o00000_ooool01?l0003oooooooooooooool8o`000003
ooooool0003o000000;ooooo1?l000001Ooooooo0000oooooooooooo000000;ooooo00Co0000oooo
ool0003ooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000;o000000?ooooo
o`000?l000001Ol00002ooooo`Co000000?oooooo`000?ooool01Ol000001000003oooooo`000?l0
0002ooooo`0300000?l0003o000000;o000000Coooooo`000?l0000000002Oooool002Gooooo00go
0000ooooooooooooooooo`000?oooooo000000000?l0003oooooo`000?oooooo000002Cooooo00?o
0000ooooooooool00_l000000ooooooo0000o`000003o`000003ooooool0003ooooo00;ooooo0ol0
0006ooooo`05o`000?oooooo0000o`000?ooool00ol00002ooooo`04o`000?ooooooooooooooo`;o
000000?oooooo`000?l000001_l000001?oooooo0000o`000?l00002ooooo`03o`000?oooooo0000
00cooooo00?o0000ooooooooool00_ooool2o`000004ooooool0003o0000ooooo`Ko00000_ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000cooooo00Go0000oooooooooooo
0000ooooo`03o`000003ooooool0003ooooo00;o000000Coooooo`000?l0003o00000_ooool2o`00
0004ooooool0003oooooooooo`;o00000_ooool4o`000005ooooool0003oooooooooool000000_oo
ool4o`00000300000?oooooooooo00Oooooo000Uooooo`04o`000000003o0000o`0000;ooooo00Go
0000oooooooooooo0000ooooo`04o`000003ooooool0003ooooo01oooooo00Co000000000?l0003o
00000_ooool3o`0000;ooooo00?o0000ooooool000001?l00007ooooo`0500000?l0003oooooo`00
0?ooool01?l00007ooooo`?o000000?oooooo`000?l000000_l000000ooooooo0000o`000003oooo
o`03o`000?oooooooooo017ooooo1ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooo0000
00Go000000?oooooo`000?ooool04oooool2o`0000;ooooo0_l000001Ooooooo0000o`000?l0003o
oooo00Co00001_ooool01Ol0003oooooo`000?l0003ooooo00?o000000Coooooo`000?oooooo0000
1?ooool00ol0003ooooo00000009ooooo`009Oooool01@00003o0000o`000?l0003ooooo00Go0000
00?oooooo`000?ooool01_l00002ooooo`03o`000?oooooooooo01Kooooo0_l000000ooooooo0000
ooooo`06o`000004ooooool0003oooooooooo`Co000000?oooooo`000?l000000oooool01Ol00000
0000ooooool00000000000?o00002oooool8o`0000?ooooo0_l000000ooooooo0000ooooo`0Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool3o`000003ooooool0003o0000
00So000000?oooooo`000?ooool02Oooool6o`0000Gooooo00?o000000000?ooool02?ooool002Go
oooo00?o0000ooooooooool01?l00002ooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`00
0?l000000_l000002Ooooooo000000000?l0003oooooo`000?oooooo0000ooooo`02o`0000Wooooo
00?o0000ooooool000000ol000001ooooooo000000000?l0003oooooo`000?ooool00_l000001_oo
oooo0000oooooooooooo0000ooooo`Co00001Oooool3o`000003ooooool0003o000000;o00002ooo
ool6o`0000;ooooo00Go0000ooooool0003oooooo`000016ooooo`06o`000?ooooooooooooooool0
003ooooo1?l000000ooooooo0000o`00000;ooooo`So000000?ooooo00000?ooool02?ooool002Go
oooo0_l000000`00003o0000ooooo`02ooooo`03o`000?oooooo000000?o000000?oooooo`000?oo
ool00oooool00ol0003oooooo`000003o`000003ooooool0003o000000Ko00000_ooool4o`000080
00000ol00003ooooo`Go000000<00000o`000?l000000ol000000ooooooo0000o`000003o`0000Co
oooo1?l000000ooooooo0000o`000002o`0000[ooooo00Co0000oooooooooooooooo0ol000000ooo
oooo0000o`00001Cooooo`03o`000?oooooo000000;o00003?ooool3o`000005ooooo`00003o0000
ooooool000002Oooool002Gooooo0ol000000ooooooo0000o`000004ooooo`03o`000?oooooo0000
00Go00000_ooool2o`0000?ooooo0_l000001?oooooo0000o`000?ooool2o`000007ooooool0003o
ooooo`000?ooool00000ooooo`03o`00000500000?l0003o0000o`000?ooool03Ol000000ooooooo
0000ooooo`04ooooo`Co000000@00000ooooool0003o00002oooool00ol0003oooooo`000003o`00
05Wooooo00?o0000ooooool000000ol0000=ooooo`05o`000?oooooo0000o`00000000002Oooool0
02Gooooo0ol000000ooooooo000000000009ooooo`ko000000?oooooo`000?l000000ol000001?oo
oooo0000ooooool00002ooooo`Co000000?oooooo`000?l000000_l00002ooooo`03o`000?oooooo
000000;o000000Goooooo`000?ooooooooooo`000004ooooo`?o00000P000004o`0000gooooo1?l0
0002ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooool000000_l000001?oooooo0000o`00
0?l0000;ooooo`;o00002Oooool002Gooooo00Go0000ooooool0003o0000ooooo`04o`000004oooo
ool0003o0000o`0000?ooooo0_l00003ooooo`;o000000Soooooo`000?l0003oooooo`000000003o
0000ooooo`Co000000?oooooo`000?ooool01?l00002ooooo`?o000000?oooooo`000?l000001Ol0
00001?oooooo0000o`000?l00004ooooo`04o`000?ooooooooooo`0000;ooooo1?l0000<ooooo`05
o`000?oooooo0000o`000?ooool00_l0001Pooooo`;o000000Coooooo`000?l0003o00002oooool0
0`00003oooooooooo`07ooooo`009Oooool01?l0003oooooooooooooool5o`00000700000?l0003o
0000ooooool0003oooooo`000002ooooo`04o`000?oooooo0000000000?o000000?oooooo`000?l0
00000ol000000ooooooo0000o`000004ooooo`;o000000Coooooo`000?oooooooooo0ol000001?oo
oooo0000o`000?l00002ooooo`0400000?oooooo0000o`0000Sooooo0_l000000`00003o0000o`00
0002o`0000cooooo0ol000000ooooooo0000o`00001Uooooo`04o`000?oooooo0000ooooo`?o0000
1oooool00`00003oooooooooo`07ooooo`009Oooool00ol0003oooooooooo`04ooooo`Co000000?o
ooooo`000?ooool00_l000000ooooooo0000ooooo`02o`0000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06o`000005ooooool0003o0000o`000?ooool00ol000001?oooooo0000
o`000?ooool2o`0000?ooooo1?l00003ooooo`Go000000Coooooo`000?l0003o00003?ooool4o`00
0003ooooool0003o000006Sooooo00?o0000ooooool000000_l000000ooooooo0000ooooo`03oooo
o`0300000?oooooooooo00Oooooo000Booooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o
00001?ooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`So000000?oooooo`000?ooool00_l00002ooooo`[o000000Coooooo`000000003o00000oooool4
o`0000?ooooo2?l000000ooooooo0000ooooo`0:ooooo`Ko0000K_ooool2o`0000;ooooo00Co0000
ooooooooool000002Oooool0017ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`03ooooo`;o00003_ooool2o`000003ooooo`00003o000000Go000000Goooooo`000?l0003o0000
00000003ooooo`Co00000_ooool00ol0003oooooo`000003o`0000;ooooo00Ko0000ooooool0003o
ooooo`000?ooool2o`00000=ooooo`00003o0000o`000?ooool00000o`000000003o0000ooooool0
003oooooo`00000<ooooo`?o00000_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooo0000
00;o00002Oooool0017ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo1Ol0000:oooo
o`04o`000?oooooo0000ooooo`;o000000H00000ooooool0003oooooo`000?ooool3o`0000030000
0?l0003o000000;o000000?ooooo00000?l000000ol00002ooooo`Co000000?oooooo`000?ooool0
0_l000000`00003oooooooooo`05o`00000300000?l0003ooooo00;o00000_ooool00ol0003ooooo
ooooo`0:ooooo`Co0000N?ooool2o`0000Wooooo000Aooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02o`000003ooooool0003ooooo00go
oooo2?l00003ooooo`05o`000?oooooo0000o`00000000001Ol000001?oooooo000000000?ooool3
o`0000;ooooo00?o0000ooooool000000_l000000ooooooo0000o`000004o`0000?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1kooooo`0300000?oooooooooo00Oooooo000Aoooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02
ooooo`Go000000?oooooo`000?ooool02Oooool00ol0003oooooooooo`06o`000003ooooool0003o
oooo00Ko00000P000003ooooo`03o`000000003o000000Go00000_ooool2o`000003ooooool0003o
000000Go00003?ooool3o`0000;ooooo00?o0000ooooooooool0N?ooool00`00003oooooooooo`07
ooooo`004Oooool01?l0003oooooooooool00009ooooo`;o00001Oooool00ol0003oooooooooo`04
ooooo`Co000000?oooooo`000?ooool02oooool9o`0000;ooooo0_l000000ooooooo0000o`000002
o`00000400000?oooooooooo0000013o00002oooool00ol0003oooooooooo`05o`0007_ooooo00<0
0000ooooooooool01oooool001;ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01oooool7o`000003ooooool0003ooooo00Gooooo3?l000000ooooooo0000o`00000>
o`000004ooooool0003o0000ooooo`So00002?ooool3o`000003ooooool0003ooooo07gooooo00<0
0000ooooooooool01oooool002Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03
o`0000;ooooo0_l000001Ooooooo0000o`000?oooooo000000Cooooo1Ol000000ooooooo0000o`00
0002ooooo`Go00000_ooool2o`000004ooooool0003o0000ooooo`?o000000?oooooo`000?ooool0
0oooool3o`000004ooooool0003o0000o`0000?ooooo1Ol0001nooooo`0300000?oooooooooo00Oo
oooo000Uooooo`;o00003_ooool00ol0003oooooooooo`09o`000003ooooool0003ooooo00So0000
00Goooooo`000?oooooo0000ooooo`03o`000003ooooool0003o000000Wo000000?oooooo`000?l0
00001ol000000ooooooo0000o`000005o`0007oooooo00?o000000000?ooool02?ooool002Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`05o`000003ooooool0003o000000?o0000
0_oooolRo`000003ooooool0003ooooo00;o0000POooool00`00003oooooooooo`07ooooo`009Ooo
ool00ol0003oooooooooo`0Hooooo`Oo000000?oooooo`000?l000001?l000001?oooooo0000o`00
0?l00002ooooo`03o`000?oooooo000000Wo000000?oooooo`000?ooool01Ol00002ooooo`04o`00
0?oooooo0000o`0008Cooooo00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool0
6Oooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`000004ooooool0003o0000
ooooo`;o00000oooool00ol0003oooooo`000002ooooo`;o000000Coooooo`000?l0003o00000ooo
ool01_l0003oooooo`000?l0003oooooo`0008Sooooo00<00000ooooooooool01oooool002Gooooo
00?o0000ooooooooool07oooool3o`0000;ooooo0_l000000ooooooo0000ooooo`03o`0000?ooooo
00?o0000ooooool000000_ooool01?l0003oooooo`000?l00002ooooo`;o000000Coooooo`000?l0
003o0000R_ooool00`00003oooooooooo`07ooooo`001oooool3o`0001_ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooo`00000Eooooo`05o`000?oooooo0000ooooool00000S?ooool00`00
003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0<[o
oooo00<00000ooooooooool01oooool000Sooooo00?o0000ooooooooool06_ooool2o`000<[ooooo
00?o000000000?ooool02?ooool000Sooooo0_l0000Kooooo`03o`000?oooooooooo0<[ooooo00<0
0000ooooooooool01oooool000Oooooo0_l000000ooooooo0000o`00000Iooooo`03o`000?oooooo
oooo0<[ooooo00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool0b_ooool00`00
003oooooooooo`07ooooo`009Oooool00ol0003oooooooooo`3:ooooo`0300000?oooooooooo00Oo
oooo000Uooooo`03o`000?oooooooooo08Sooooo00D00000ooooo`0000000000ooooo`02000001Go
oooo0P000006ooooo`0300000?ooool0000000;ooooo00<00000ooooooooool05_ooool00`00003o
ooooooooo`07ooooo`009Oooool2o`0009;ooooo00<00000ooooo`0000002?ooool3o`0000Cooooo
00<00000ooooo`0000000_ooool00`00003oooooooooo`02ooooo`0300000?oooooooooo01Wooooo
00?o000000000?ooool02?ooool002Gooooo00?o0000ooooooooool0T?ooool00`00003ooooo0000
0004ooooo`;o000000?oooooo`000?l000000_l000000oooool00000o`000005o`0000;ooooo00<0
0000ooooooooool07oooool00`00003oooooooooo`07ooooo`009Oooool00ol0003oooooooooo`1o
ooooo`0300000?oooooooooo00kooooo00H00000ooooooooooooooooo`000?ooool2o`0000;ooooo
00?o0000ooooooooool00_l00004ooooo`0300000?l0003ooooo00?o00000oooool00`00003ooooo
ooooo`0Kooooo`0300000?oooooooooo00Oooooo000Uooooo`03o`000?oooooooooo07kooooo00<0
0000ooooooooool03oooool01@00003oooooooooo`00003ooooo00;o000000D00000o`000?oooooo
oooo00000007ooooo`0400000?l0003oooooooooo`;o00000oooool3000001_ooooo00<00000oooo
ooooool01oooool001;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03
o`000?oooooooooo09?ooooo00@00000ooooool0003o00001?ooool00ol0003oooooooooo`0<oooo
o`Co00000`00000Iooooo`0300000?oooooooooo00Oooooo000Aooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo07[ooooo00<00000
ooooooooool03_ooool00`00003oooooo`000002o`00000300000?oooooo000000?o00000P000000
0oooool0000000000003ooooo`0400000?l000000000o`0000Cooooo00Co000000000000003o0000
0oooool5o`00000400000?oooooo00000000013ooooo00D00000oooooooooooooooo00000009oooo
o`004Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol000000000ooooo`1iooooo`0300000?oooooooooo00oooooo00Co0000ooooo`00003o00000_oo
ool00`00003o0000ooooo`03ooooo`0500000?ooool00000o`000?ooool00_l00003ooooo`030000
0?oooooo000000;ooooo0_l00003ooooo`0300000?oooooooooo00;ooooo00Oo000000000?l0003o
0000ooooo`00003o000001;ooooo00?o000000000?ooool02?ooool0017ooooo00Co0000oooooooo
oooo00001oooool4o`0000Gooooo00Co0000ooooooooool00000ROooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooo`0000001?ooool2o`0000;ooooo00Co0000
ooooool0003o00001?ooool2o`0000;ooooo00Go0000ooooool0003oooooo`000004ooooo`;o0000
0_ooool00ol0003oooooo`00000>ooooo`0300000?oooooooooo00Oooooo000Aooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1gooooo`030000
0?oooooooooo00gooooo00D00000ooooooooooooooooo`000004ooooo`0300000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool20000000;o`000?oooooo0000ooooool000000000o`000?oo
oooo0000ooooool000001?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo000000;o
oooo00?o000000000?ooool02_ooool00`00003oooooooooo`07ooooo`004Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Qoooool01Ol0003o
ooooooooo`00003o000000?ooooo00?o0000ooooooooool01?ooool01000003o0000ooooooooool2
o`0000;ooooo00?o0000ooooooooool00ol000001ooooooo0000o`000?oooooo0000ooooool00000
0oooool2o`00000400000?oooooooooo000000Cooooo00?o0000ooooooooool01Oooool01000003o
ooooooooo`000006ooooo`0300000?oooooooooo00Oooooo000Booooo`;o00002_ooool2o`0000Go
oooo00?o0000ooooooooool02Oooool00`00003oooooooooo`1hooooo`0300000?oooooo000000Co
oooo00<00000ooooooooool00oooool01000003oooooo`0000000002o`0000;ooooo00Co0000oooo
ool0003o00000_ooool00ol0003oooooo`000002o`000004ooooool0003oooooooooo`Go00001?oo
ool01Ol0003oooooo`000?ooool0000000;ooooo00<00000ooooooooool00oooool2000000[ooooo
00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool02oooool00`00003ooooooooo
o`1eooooo`03o`000?ooool0000000Cooooo00?o0000ooooooooool00_ooool01ol0003ooooooooo
ool0003ooooo00000?ooool00_l00002ooooo`Wo000000?oooooo`000?ooool00_ooool01?l0003o
ooooooooooooool6o`000003ooooool0003ooooo00;ooooo00Go0000ooooool0003oooooo`000005
ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`0300000?oooooooooo00Oooooo000Uoooo
o`03o`000?oooooooooo08;ooooo00Co0000oooooooooooooooo0P000005ooooo`04o`000?oooooo
0000o`0000;ooooo3ol000000`00003oooooo`000002ooooo`Ko000000Coooooo`000?l000000000
0_l000000ooooooo0000ooooo`06o`000080000000?oooooo`000?ooool01oooool00`00003ooooo
o`000009ooooo`009Oooool2o`000004ooooool0003ooooo000007kooooo00Ko0000oooooooooooo
oooo00000?l00006ooooo`07o`000?oooooo0000o`000?oooooo0000ooooo`04o`000006ooooool0
003oooooooooool0003ooooo0ol00002ooooo`?o00000_ooool01?l0003oooooo`0000000002o`00
00;ooooo1_l000001Ooooooo0000o`000?l0003ooooo00;o000000<00000o`000?l000001oooool2
o`00008000002Oooool002Gooooo00Go0000ooooool0003ooooo0000001looooo`0700000?oooooo
0000o`000?oooooo000000000009ooooo`03o`000?oooooooooo00;o00000oooool5o`000006oooo
ool0003o0000ooooool0003ooooo0ol00002ooooo`03o`000?oooooo000000;o00000_ooool01Ol0
003oooooo`000?l00000000000?o000000Coooooo`000?l0003ooooo0ol00005ooooo`;o00001ooo
ool00`00003oooooooooo`07ooooo`009Oooool01?l0003oooooooooooooool2000000;ooooo00?o
0000ooooooooool0IOooool2000001Cooooo00?o0000ooooooooool01_ooool3o`000003ooooool0
003o000000;o000000?oooooo`000?l000001Ol000001?oooooo0000o`000?ooool2o`0000kooooo
0_l000001Ooooooo0000o`000000003o000000;ooooo2?l000000oooool0000000000002o`0000Co
oooo00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool00oooool00`00003ooooo
ooooo`02ooooo`03o`000000003ooooo00gooooo00<00000ooooooooool0D_ooool00`00003ooooo
ooooo`0=ooooo`0300000?oooooooooo00Wooooo00Co0000oooooooooooo00000oooool3o`000005
00000?l0003o0000ooooool000000_ooool3o`0001Sooooo0_l00002ooooo`05o`000000003o0000
o`000?ooool00ol000000ooooooo0000o`000004ooooo`03o`000?oooooo000000Wooooo000Uoooo
o`03o`000000003ooooo01[ooooo0P00001@ooooo`8000003_ooool00ol000000000ooooo`02oooo
o`0300000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol000000000ooooo`05o`00
000400000?l0003oooooo`00027ooooo2_l00002ooooo`04o`000?ooooooooooo`0000Wooooo000U
ooooo`;o00000_ooool2o`0000Cooooo00Oo0000ooooo`00003ooooo00000?oooooo000000?ooooo
00<00000ooooooooool02Oooool00`00003oooooooooo`1Kooooo`;o00000oooool00`00003ooooo
o`000006ooooo`03o`000?oooooo000000Oo000000Coooooo`000?l0003o0000:?ooool:o`000003
ooooool0003ooooo00Sooooo000Uooooo`;o00000oooool00ol0003oooooo`000007ooooo`05o`00
0?ooool00000ooooool000000_ooool00`00003oooooooooo`09ooooo`0300000?oooooooooo01oo
oooo0P00000eooooo`0500000?ooooooooooooooo`0000002Oooool3o`000004ooooool0003o0000
ooooo`Co000000Coooooo`000?l0003o0000;Oooool3o`000003ooooool0003o000000;o000000<0
0000ooooooooool01oooool002Gooooo0ol000002Ooooooo0000o`000000003o0000ooooool0003o
ooooo`00000:ooooo`Co00000oooool01P00003ooooo00000000003ooooo000000;ooooo00<00000
ooooooooool06?ooool00`00003ooooo0000000=ooooo`0400000?ooool00000000001Oooooo00<0
0000ooooo`0000000_ooool01000003oooooooooo`000005ooooo`07o`000000003o000000000?l0
003oooooo`000006ooooo`;o000000Coooooo`000?l0000000000oooool4o`000004ooooool0003o
ooooooooo`;o0000<?ooool00ol0003oooooo`000002o`0000Wooooo000Uooooo`03o`000?oooooo
000000?o000000Coooooo`000?oooooo00000oooool2o`00000500000?l0003oooooooooool00000
0_ooool01Ol0003oooooooooool00000000000Kooooo00<00000ooooooooool04oooool00`00003o
ooooooooo`06ooooo`0300000?oooooooooo01Cooooo0P00000Dooooo`0300000?oooooooooo00;o
oooo00<00000ooooooooool0100000001_l000000000ooooool0003oooooo`0000;ooooo00Oo0000
oooooooooooo000000000?oooooo000000?ooooo00D00000o`000?l0003o0000ooooo`04o`0003Ko
oooo00Co0000ooooooooool000002Oooool002Gooooo00?o0000ooooooooool00_ooool2o`000004
00000?l0003o0000000000?o000000?oooooo`000?ooool00_ooool00`00003ooooo00000003oooo
o`;o000000Woooooo`000?l000000000ooooo`00003oooooo`000?ooool01Ol000000`00003ooooo
ooooo`0;ooooo`8000009_ooool00`00003oooooooooo`0;ooooo`05o`000?oooooo0000o`000?oo
ool00_l00003ooooo`05o`000?oooooo000000000?l000000P000005ooooo`0500000?l0003ooooo
ooooo`0000000oooool00ol0003oooooooooo`04o`0003_ooooo00<00000ooooooooool01oooool0
02Gooooo00?o0000ooooooooool00oooool2o`000003ooooool0003ooooo00;ooooo00Co0000oooo
ool0003ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00D00000o`000?oooooo00000000
0005o`0000;ooooo00Go0000ooooool0003o0000ooooo`03o`00000500000?ooooooooooooooo`00
00001?ooool00`00003oooooooooo`0Qooooo`0300000?oooooooooo00Sooooo0ol000000`00003o
0000ooooo`02o`00000300000?l0003o000000;o000000Goooooo`000?l000000000o`00000;oooo
o`Co00000_ooool00ol0003oooooo`000002o`000005ooooool0003o0000ooooool00000>?ooool0
0`00003oooooooooo`07ooooo`009Oooool00ol0003oooooooooo`03ooooo`So00000oooool01ol0
00000000o`000?l0003ooooo00000?l000000oooool2o`000003ooooo`00003ooooo008000000ooo
ool01?l0003oooooooooo`000003ooooo`;o000000?ooooo00000?l000001?l00003ooooo`040000
0?oooooooooo000002;ooooo0P000004ooooo`Go00000_ooool2o`0000?ooooo00<00000ooooool0
00001?ooool00ol0003ooooo00000002ooooo`;o00000oooool01@00003ooooo00000?l0003ooooo
00Wo000000?oooooo`000?l00000>oooool00`00003oooooooooo`07ooooo`009Oooool2o`0000Wo
oooo1Ol000001Ooooooo0000o`000?l0003ooooo00?o000000Gooooo00000?l000000000o`000002
ooooo`0400000?ooool00000000000;ooooo00?o0000ooooooooool02?ooool00`00003ooooooooo
o`04o`0000?ooooo00<00000ooooooooool08oooool01P00003ooooooooooooooooo0000ooooo`;o
000000?oooooo`00000000002oooool00ol000000000ooooo`02ooooo`0500000?l0003ooooooooo
ool000000oooool00ol0003oooooooooo`06o`0000;ooooo0ol0000kooooo`03o`000000003ooooo
00Sooooo000Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000001?l00002ooooo`03
o`000?oooooo000000?ooooo00<00000ooooooooool01?ooool00ol0003oooooo`000003ooooo`03
00000?l0003ooooo00Gooooo00Go0000oooooooooooo0000ooooo`02o`000005ooooool000000000
ooooo`0000000oooool00`00003oooooooooo`0Rooooo`0600000?oooooo0000o`000000003o0000
0_ooool00`00003oooooooooo`09ooooo`;o00001Oooool00ol0003oooooo`000002o`000005oooo
ool0003oooooo`000?ooool01_l000000ooooooo0000ooooo`0kooooo`0300000?oooooooooo00Oo
oooo000Uooooo`03o`000?oooooooooo00gooooo0ol000000`00003oooooo`000002o`0000030000
0?l0003o000000;o000000?oooooo`000?ooool00_ooool2o`000007ooooool0003oooooooooo`00
003oooooo`000005ooooo`04o`000000003oooooo`0000;ooooo1?l000001000003o0000o`000?l0
000Oooooo`0300000?oooooooooo00?o000000D00000ooooool0003o0000ooooo`02o`0000Cooooo
00Oo0000ooooooooool00000o`000000003o0000008000001?ooool00ol0003oooooo`000002oooo
o`05o`000?ooooooooooo`000?ooool01_l000000ooooooo0000o`000002o`0003gooooo00<00000
ooooooooool01oooool002Gooooo00?o0000ooooooooool04Oooool2o`000003ooooo`00003ooooo
00Co000000Ooooooo`000?ooooooooooo`000?ooool0000000?o00000oooool02?l0003ooooo0000
0?oooooo0000ooooo`00003ooooo0`000002ooooo`09o`000?ooool0000000000?l0003ooooo0000
0?l0003ooooo00?o000000Cooooo00000?ooool000005?ooool2000000;ooooo00Co0000ooooool0
003o00000oooool00ol000000000o`000002ooooo`0400000?oooooooooo000000Oooooo0ol00000
1?ooool00000o`000?ooool3o`000003ooooool0003ooooo00Wo0000@Oooool00`00003ooooooooo
o`07ooooo`004_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooo`000002o`000005ooooool0003o0000o`000?ooool00ol0
0004ooooo`03o`000?oooooo000000;o00001Oooool01ol0003oooooooooooooool00000ooooool0
00000_ooool00ol0003ooooo00000002o`0000;ooooo00@00000ooooooooool000005oooool01000
003oooooooooool00004ooooo`07o`000?ooooooooooooooool000000000o`000002ooooo`03o`00
00000000000000;ooooo1?l00002ooooo`03o`000?oooooo000000;o000000?oooooo`000?ooool0
1?l000001?oooooo0000o`000?ooool2o`000005ooooool0003o000000000?l00000@?ooool00`00
003oooooooooo`07ooooo`004Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0Dooooo`;o000000?oooooo`00000000002ol00000
1`00003oooooooooool000000000o`000?ooool00_l00003ooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool01oooool3o`0000;ooooo00<00000ooooooooool03?ooool2o`000003
ooooo`00003o000000;ooooo00<00000ooooool000001?ooool01@00003ooooooooooooooooo0000
00Kooooo00Co0000ooooooooool000000_l000000oooool00000ooooo`02o`000003ooooool0003o
000000;ooooo0_l000000ooooooo0000o`000005o`00043ooooo00<00000ooooooooool01oooool0
017ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool05oooool00ol0003oooooo`000003o`000004ooooool0003oooooo`0000;ooooo
00Go0000ooooool000000000ooooo`03o`000004ooooool0003oooooooooo`;o000000<00000oooo
ooooool01?ooool00ol000000000ooooo`02ooooo`<000001Oooool2o`0000Cooooo00<00000oooo
ooooool01_ooool00`00003oooooooooo`02o`0000cooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooooooool2o`0000;ooooo00?o0000ooooool000001Ol000000ooooooo0000ooooo`02
o`000003ooooool0003ooooo00?o0000@_ooool00`00003oooooooooo`07ooooo`004Oooool01?l0
003oooooooooool00008ooooo`?o00001Oooool2o`0001Sooooo00?o0000ooooooooool01ol00002
ooooo`04o`000?ooooooooooooooo`Co00000oooool2o`00000400000?oooooooooo000000?ooooo
00<00000ooooooooool01?ooool01_l0003oooooooooooooool00000o`0000;ooooo00H00000oooo
ool0003oooooo`0000000003ooooo`0300000?oooooooooo00?ooooo00D00000oooooooooooo0000
00000004ooooo`8000000_ooool00ol000000000ooooo`08ooooo`0300000?oooooo000000;ooooo
00L00000oooooooooooo0000ooooool0003ooooo00;o00000_ooool00ol0003oooooo`000002o`00
0003ooooo`00003o000004Cooooo00?o000000000?ooool02?ooool0017ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool07_ooool0
1Ol0003oooooooooooooool0000000Co000000?oooooo`000?ooool00ol00002ooooo`03o`000?oo
oooo000000;ooooo00Ko0000oooooooooooo0000ooooool00007ooooo`05o`000000003oooooo`00
000000001_ooool00ol0003oooooo`000003o`0000?ooooo00?o000000000?ooool01?ooool01?l0
003ooooo00000?l00008ooooo`09o`000?ooool00000ooooool000000000o`000?oooooo000000;o
oooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0000;ooooo0_l00016oooo
o`0300000?oooooooooo00Oooooo000Aooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo027ooooo0ol000001?oooooo0000o`000?oo
ool8o`0000?ooooo1?l00002ooooo`0300000?l0003ooooo00[ooooo00H00000oooooooooooooooo
o`0000000003ooooo`06o`000000003oooooo`000000003o00000oooool01`00003ooooooooooooo
ool00000ooooool000002_ooool00ol0003oooooooooo`03o`000005ooooool0003o0000o`000?oo
ool00ol000000ooooooo0000o`000003o`000005ooooool0003oooooo`000?ooool00_l00016oooo
o`0300000?oooooooooo00Oooooo000Booooo`;o00002Oooool3o`0000Gooooo00?o0000oooooooo
ool08oooool00ol000000000o`000002o`000003ooooool0003o000000?o000000?oooooo`000?l0
00001Ol00002000000Co00003_ooool00ol0003oooooooooo`03ooooo`0300000?l0003o000000;o
oooo00?o000000000?l000001?ooool00`00003oooooooooo`0<ooooo`;o00000_ooool01ol0003o
ooooo`000?l0003oooooo`000?ooool02ol00019ooooo`0300000?oooooooooo00Oooooo000Uoooo
o`03o`000?oooooooooo02Oooooo1?l000001?oooooo0000ooooooooool6o`000004ooooool0003o
ooooooooo`?o00002_ooool00ol000000000ooooo`03ooooo`04o`000?oooooo0000o`0000;ooooo
00X00000oooooooooooooooo00000?l000000000o`000?oooooo00000_ooool00`00003o0000oooo
o`0:ooooo`Co000000Coooooo`000?oooooooooo0_l000000oooool00000o`000003o`000004oooo
ool000000000o`0000;ooooo00?o0000ooooooooool0A_ooool00`00003oooooooooo`07ooooo`00
9Oooool00ol0003oooooooooo`0Wooooo`;o000000Goooooo`000?oooooo000000000006o`0000;o
oooo00Go0000ooooooooool00000ooooo`02o`000003ooooool00000000000Wooooo00?o0000oooo
o`0000001?ooool00`00003ooooo00000003ooooo`0300000?oooooooooo00Gooooo00<00000o`00
0?ooool02?ooool4o`000004ooooo`00003o0000ooooo`Co000000Koooooo`000?ooooooooooo`00
00000005o`000003ooooool0003ooooo04Oooooo00<00000ooooooooool01oooool002Gooooo0_l0
000[ooooo`;o000000@00000ooooool0003ooooo1ol000001ooooooo0000oooooooooooo0000oooo
ool000004?ooool01Ol000000000oooooooooooo000000;ooooo0_l000001ooooooo0000ooooool0
00000000ooooool000003Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooool000001Ol0001:ooooo`03o`000000003ooooo00Sooooo000Uooooo`03o`00
0?oooooooooo02oooooo1?l000000ooooooo0000o`000003o`0000;ooooo0_l00002ooooo`Co0000
00Goooooo`000?ooool00000o`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`0500000?l0003oooooo`000?ooool00ol000000ooo
oooo0000ooooo`04o`000003ooooool0003ooooo00Co000000L00000o`000?l000000000o`000?oo
oooo000004[ooooo00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool0;_ooool2
o`000003ooooo`00003o000000Co000000Coooooo`000?l0003ooooo0_l00002ooooo`0400000?oo
oooo0000ooooo`;o00000_ooool00`00003o0000ooooo`02ooooo`03o`000?oooooooooo00;o0000
00Woooooo`000?l0003o0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Oo0000oooooooooooo0000ooooool00000000000?ooooo
1_l000001000003o0000o`000?ooool2o`0004gooooo00<00000ooooooooool01oooool002Gooooo
00?o0000ooooooooool0<?ooool2o`000003ooooool0003o000000;ooooo0ol000001_oooooo0000
ooooool0003oooooo`0000;ooooo00?o0000ooooool000000_l000001?ooool00000ooooo`000005
ooooo`?o00000oooool3o`0000;ooooo0_l000000ooooooo0000ooooo`02ooooo`0500000?ooool0
0000ooooo`0000000_ooool00ol00000000000000003ooooo`0300000?oooooooooo00;ooooo1Ol0
00001?oooooo0000o`000?l0001=ooooo`0300000?oooooooooo00Oooooo000Uooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooool000002Ol000000ooooooo0000o`000003o`000006ooooool0
00000000ooooool0003ooooo0ol000000oooool00000o`000003ooooo`;o000000Koooooo`000?oo
ooooooooo`0000000007ooooo`04o`000?oooooo0000000000Co000000Koooooo`000?l0003ooooo
o`000?ooool2o`000003ooooool0003o000000Wo0000C?ooool00`00003oooooooooo`07ooooo`00
9Oooool00ol0003oooooooooo`0gooooo`So000000Coooooo`000?oooooooooo1?l000000`00003o
oooo00000002ooooo`05o`000?oooooooooo00000?ooool00ol000000ooooooo0000ooooo`02o`00
0003ooooool0003o000000?o00000_ooool01`00003o0000o`000?oooooo0000ooooool000000_oo
ool00ol0003oooooo`000007o`000003ooooool0003ooooo00Co00000oooool00ol0003ooooooooo
o`19ooooo`0300000?oooooooooo00Oooooo000Uooooo`;o0000=Oooool00ol0003oooooooooo`03
ooooo`;o000000H00000o`000?ooooooooooo`000?ooool2o`000004ooooool0003o0000ooooo`?o
00000_ooool2o`00000300000?l0003o000000Cooooo0_l000001?ooool00000ooooooooool5o`00
00;ooooo0ol000000`00003o0000o`000002ooooo`03o`000?oooooooooo00[o000000@00000o`00
0?l0003o0000COooool00ol000000000ooooo`08ooooo`009Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooo000000?o000000?oooooo`000?ooool01_l000000ooooooo0000o`000002o`00
0003ooooool0003o000000Ko000000Gooooo00000?l0003oooooo`000002ooooo`03o`000000003o
oooo00Ko00000_ooool3o`00000700000?l0003o0000ooooool0003ooooo0000000:o`0004gooooo
00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool0>?ooool8o`000003ooooool0
003ooooo00Co00000_ooool00ol0003oooooo`000002o`000003ooooool0003ooooo00Go00001?oo
ool01`00003o0000ooooool0003oooooo`000?ooool01?l000000ooooooo0000ooooo`05o`000003
ooooool0003o000000Ko000000Coooooo`000?l0003ooooo1?l00002ooooo`03o`000?oooooooooo
04Oooooo00<00000ooooooooool01oooool002Gooooo00?o0000ooooooooool0>oooool6o`000003
ooooool0003ooooo00Oo00001?ooool3o`00000700000?oooooo0000ooooool0003oooooo`000002
ooooo`05o`000?oooooooooo00000?ooool00ol000001?oooooo0000ooooooooool5o`0000Cooooo
1Ol000001Ooooooo0000o`000?l0003ooooo00;o000000<00000o`000?ooool0Boooool00`00003o
ooooooooo`07ooooo`009Oooool00ol0003oooooooooo`0mooooo`08o`000?oooooo0000o`000000
003oooooo`000?ooool6o`000003ooooool0003o000000Co000000Goooooo`000?l0003o0000oooo
o`02o`000004ooooool0003o0000ooooo`?o000000Ooooooo`000?l0003oooooo`000?oooooo0000
00;ooooo00?o0000ooooool000000_l000000`00003o0000o`000003o`0000;ooooo00Co0000oooo
ool0003o00000P000004o`0004[ooooo00<00000ooooooooool01oooool002Gooooo00?o0000oooo
ooooool0?_ooool2o`000003ooooool0003ooooo00?o00000_ooool3o`000003ooooool0003o0000
00Oo00000_ooool01_l0003oooooo`000?oooooo0000ooooo`;o000000Coooooo`000?oooooo0000
0_ooool3o`000006ooooool0003o0000ooooool0003ooooo1ol000001?oooooo0000o`000?ooool2
o`000005ooooo`00003oooooooooool00000B_ooool00`00003oooooooooo`07ooooo`009Oooool0
0ol0003oooooooooo`0nooooo`Oo000000Coooooo`000?l0000000000ol000000ooooooo0000o`00
0004o`000003ooooool0003ooooo00Go00000oooool4o`000005ooooool0003o0000ooooool00000
0_ooool01?l0003oooooo`000?ooool3o`000006ooooool0003oooooo`000?oooooo00000oooool0
0ol0003oooooo`000003o`0004_ooooo00<00000ooooooooool01oooool002Gooooo0_l00012oooo
o`03o`000?oooooo000000;o000000Koooooo`000?ooooooooooo`000?ooool4o`000004ooooool0
003o0000ooooo`;o000000?oooooo`000?ooool02ol000001?oooooo0000o`000?ooool8o`0000;o
oooo00<00000o`000?l000000_ooool7o`0000;ooooo00?o0000ooooooooool0A_ooool00ol00000
0000ooooo`08ooooo`009Oooool00ol0003oooooooooo`10ooooo`04o`000?oooooo0000ooooo`Go
000000?oooooo`000?l000000_l000001Ooooooo0000o`000?l0003ooooo00Co000000Cooooo0000
0?l0003o00000_ooool2o`0000;ooooo1?l000000ooooooo0000ooooo`03o`000004ooooool0003o
0000ooooo`Oo000000D00000o`000?oooooo0000ooooo`02o`0004gooooo00<00000ooooooooool0
1oooool002Gooooo00?o0000ooooooooool0A_ooool01?l0003oooooo`0000000002o`000003oooo
ool0003ooooo00Ko000000Ooooooo`000?l0003o0000ooooool0003ooooo00Co000000Koooooo`00
0?oooooo0000ooooool00004ooooo`Co000000?oooooo`000?l000001Ol000001Ooooooo0000o`00
0?l0003ooooo00;o0000COooool00`00003oooooooooo`07ooooo`007Oooool3o`0000Gooooo00?o
0000ooooooooool0B?ooool2o`00000300000?l0003o000000;o000000?oooooo`000?l000000_l0
00000ooooooo0000ooooo`02o`000003ooooool0003o000000;o00000oooool3o`000006ooooool0
003oooooooooool0003ooooo0_l00002ooooo`;o000000?oooooo`000?l000001_l000000ooooooo
0000ooooo`1>ooooo`0300000?oooooooooo00Oooooo000Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0BOooool00ol0003oooooo`000008o`0000;ooooo0_l00003ooooo`;o0000
00Coooooo`000?l0003ooooo1?l000003?ooool00000oooooooooooo0000ooooo`00003oooooo`00
0000003o0000ooooo`Go000000?oooooo`000?ooool00ol000000ooooooo0000o`00001;ooooo`03
00000?oooooooooo00Oooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool01ol0003oooooooooool0003oooooo`000?ooool00_l000001?oooooo0000o`0000000002
ooooo`Co000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`0000Cooooo
1?l000000ooooooo0000o`000002o`000003ooooool0003o000000Oo000000?oooooo`000?ooool0
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo000Nooooo`03o`000?oo
oooooooo00CoooooC00000000ol000000000o`00000:000000?o00000P000002o`0000<000000_l0
000600000005o`000000003o000000000?l000002@000002o`00000300000?l0003o000005000000
2Oooool001kooooo00?o0000ooooooooool0foooool001gooooo0_l0003Mooooo`007_ooool00ol0
003oooooooooo`3Kooooo`00o?ooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 274}, {397.938, 274.438}} -> {-0.632957, \
2.52923, 0.00489262, 0.00791642}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stable and Unstable Directions", "Section"],

Cell["\<\
The example below shows the construction of the stable and unstable \
manifolds for the unstable fixed point at {0.5,0}.  The Jacobian of the map, \
evaluated at this fixed point is given by\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
            {\(1 + K\), "1"},
            {"K", "1"}
            }], "\[NegativeThinSpace]", ")"}], "."}]], "Input"],

Cell["\<\
We can determine the stability of the fixed point for any K by \
evaluating the trace of this matrix.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[K];\)\), "\[IndentingNewLine]", 
    \(\(Jac = {{1 + K, 1}, {K, 1}};\)\), "\[IndentingNewLine]", 
    \(Tr[Jac]\)}], "Input"],

Cell[BoxData[
    \(2 + K\)], "Output"]
}, Open  ]],

Cell["\<\
Since the trace of the stability matrix is greater than 2 for all \
K>0 we see that this fixed point is unstable for all K>0.\
\>", "Text"],

Cell[TextData[{
  "The eigenvalues and eigenvectors of the stability matrix can also be found \
with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[K];\)\), "\[IndentingNewLine]", 
    \(\(Jac = {{1 + K, 1}, {K, 1}};\)\), "\[IndentingNewLine]", 
    \(Eigenvalues[Jac]\)}], "Input"],

Cell[BoxData[
    \({1\/2\ \((2 + K - \@K\ \@\(4 + K\))\), 
      1\/2\ \((2 + K + \@K\ \@\(4 + K\))\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvectors[Jac]\)], "Input"],

Cell[BoxData[
    \({{\(-\(\(\(-\@K\) + \@\(4 + K\)\)\/\(2\ \@K\)\)\), 
        1}, {\(-\(\(\(-\@K\) - \@\(4 + K\)\)\/\(2\ \@K\)\)\), 1}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(In\ particular, \ for\ K = 1.5\ we\ \(\(find\)\(:\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 1.5;\)\), "\[IndentingNewLine]", 
    \(Eigenvalues[Jac]\)}], "Input"],

Cell[BoxData[
    \({3.186140661634507`, 0.31385933836549285`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eigenvectors[Jac]\)], "Input"],

Cell[BoxData[
    \({{0.8245648401323938`, 0.5657674649689924`}, {\(-0.4159735579192843`\), 
        0.9093767091321241`}}\)], "Output"]
}, Open  ]],

Cell["\<\
To help visualize how these eigenvectors influence trajectories in \
the vicinity of of the fixed point we can take two approaches.  The first is \
to start with a random distribution of points near the fixed point and let \
this distribution evolve under the map.  We will see that trajectories flow \
out along the direction of the unstable eigenvector (with eigenvalue greater \
than 1).  If we do the same thing using the inverse mapping function we will \
see that trajectories flow out along the stable eigenvector (with eigenvalue \
less than 1), although since this is the inverse map this really indicates \
trajectories that flow into the fixed point.\
\>", "Text"],

Cell["\<\
Note that in the following examples we remove the Mod 1 restriction \
to the mapping function.  This is done because we are only concerned with the \
dynamics in the immediate vicinity of the fixed point.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(K = 1.5; n = 5000; niter = 4; \[Theta]min = 0.49; \[Theta]max = 0.51; 
    rmin = \(-0.01\); rmax = 0.01; \[Theta]L = 0.4; \[Theta]R = 0.6; 
    rL = \(-0.1\); rR = 0.1; 
    f[{\[Theta]_, r_}] := 
      N[{\[Theta] + r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 
          r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]]}]; 
    L1 = Table[
        Nest[f, {Random[Real, {\[Theta]min, \[Theta]max}], 
            Random[Real, {rmin, rmax}]}, niter], {i, n}];\), "\n", 
    \(\(P1 = 
        ListPlot[L1, PlotStyle \[Rule] PointSize[0.005], 
          PlotRange \[Rule] {{\[Theta]L, \[Theta]R}, {rL, rR}}, 
          Axes \[Rule] False, Frame \[Rule] True, RotateLabel \[Rule] False, 
          FrameLabel \[Rule] {"\<\[Theta]\>", "\<r\>", "\<\>", "\<\>"}, 
          AspectRatio \[Rule] 1];\)\), "\[IndentingNewLine]", 
    \(\(finv[{\[Theta]_, r_}] := 
        N[{\[Theta] - r, 
            r + \((K/\((2*Pi)\))\)*
                Sin[2*Pi*\((\[Theta] - r)\)]}];\)\), "\[IndentingNewLine]", 
    \(\(L2 = 
        Table[Nest[
            finv, {Random[Real, {\[Theta]min, \[Theta]max}], 
              Random[Real, {rmin, rmax}]}, niter], {i, n}];\)\), "\n", 
    \(\(P2 = 
        ListPlot[L2, PlotStyle \[Rule] {PointSize[0.005], Hue[0]}, 
          PlotRange \[Rule] {{\[Theta]L, \[Theta]R}, {rL, rR}}, 
          Axes \[Rule] False, Frame \[Rule] True, RotateLabel \[Rule] False, 
          FrameLabel \[Rule] {"\<\[Theta]\>", "\<r\>", "\<\>", "\<\>"}, 
          AspectRatio \[Rule] 1];\)\), "\[IndentingNewLine]", 
    \(Show[P1, P2]\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(\[Theta]R\)\" is \
similar to existing symbol \"\!\(\[Theta]L\)\"."\)], "Message"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2 5 0.5 5 [
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -15 -9 ]
[.625 -0.0125 15 0 ]
[.75 -0.0125 -12 -9 ]
[.75 -0.0125 12 0 ]
[.875 -0.0125 -15 -9 ]
[.875 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .125 -36 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -30 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -36 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -30 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -24 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -30 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -18 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -46 -6 ]
[-0.01875 .5 -36 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.425)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.45)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.475)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.525)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.55)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.575)] .875 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .125 m
.00625 .125 L
s
[(-0.075)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-0.05)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-0.025)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(0.025)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(0.05)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(0.075)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(0.1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.005 w
.98184 .83036 Mdot
.59193 .56328 Mdot
.39365 .42704 Mdot
.51124 .50731 Mdot
.91888 .78674 Mdot
.22258 .31019 Mdot
.39864 .42987 Mdot
.77216 .68692 Mdot
.91824 .78616 Mdot
.84296 .73555 Mdot
.54621 .53223 Mdot
.24278 .32333 Mdot
.76942 .68529 Mdot
.24246 .32281 Mdot
.13005 .24594 Mdot
.37652 .4151 Mdot
.47568 .48349 Mdot
.73773 .66258 Mdot
.37026 .41067 Mdot
.67378 .61897 Mdot
.47147 .48023 Mdot
.19692 .29156 Mdot
.07998 .21208 Mdot
.77195 .68661 Mdot
.76208 .67948 Mdot
.68887 .62929 Mdot
.68506 .6263 Mdot
.48464 .48998 Mdot
.57983 .55461 Mdot
.30699 .36808 Mdot
.67434 .61994 Mdot
.30935 .36908 Mdot
.05388 .19372 Mdot
.84542 .73701 Mdot
.1139 .23583 Mdot
.6856 .62768 Mdot
.21704 .30596 Mdot
.16663 .27142 Mdot
.66802 .61562 Mdot
.48731 .49183 Mdot
.81868 .71801 Mdot
.84985 .73967 Mdot
.39311 .42673 Mdot
.1655 .27103 Mdot
.72178 .65232 Mdot
.37908 .41694 Mdot
.58148 .5561 Mdot
.2472 .32634 Mdot
.01384 .16638 Mdot
.27395 .34523 Mdot
.84785 .73892 Mdot
.55763 .53988 Mdot
.01671 .16831 Mdot
.3406 .39074 Mdot
.8236 .72241 Mdot
.51018 .50644 Mdot
.98118 .82928 Mdot
.77124 .68623 Mdot
.33017 .3836 Mdot
.78131 .69251 Mdot
.70225 .63881 Mdot
.31746 .37482 Mdot
.7956 .70238 Mdot
.86328 .74887 Mdot
.98271 .83033 Mdot
.92865 .79433 Mdot
.2007 .29484 Mdot
.18338 .2833 Mdot
.96764 .82055 Mdot
.31215 .37126 Mdot
.71575 .64833 Mdot
.46552 .47646 Mdot
.8375 .73077 Mdot
.58069 .55497 Mdot
.5565 .53896 Mdot
.08815 .21818 Mdot
.71288 .6457 Mdot
.68099 .62388 Mdot
.47036 .4803 Mdot
.92039 .78765 Mdot
.10286 .22785 Mdot
.08553 .21643 Mdot
.56409 .54405 Mdot
.69189 .63144 Mdot
.25084 .32889 Mdot
.37909 .41706 Mdot
.24271 .32416 Mdot
.1499 .25975 Mdot
.85465 .74303 Mdot
.76556 .68155 Mdot
.42018 .4453 Mdot
.55488 .53755 Mdot
.5367 .52546 Mdot
.69378 .63349 Mdot
.42839 .45058 Mdot
.89012 .76729 Mdot
.87156 .75478 Mdot
.19059 .28768 Mdot
.24085 .32181 Mdot
.56551 .54443 Mdot
.24747 .32656 Mdot
.18523 .28401 Mdot
.2514 .33009 Mdot
.53999 .52806 Mdot
.3452 .39349 Mdot
.45632 .4702 Mdot
.23364 .31715 Mdot
.16057 .26787 Mdot
.91972 .78723 Mdot
.88978 .76775 Mdot
.99856 .84122 Mdot
.58866 .56143 Mdot
.15088 .26033 Mdot
.96464 .81774 Mdot
.15816 .26568 Mdot
.90821 .7803 Mdot
.28116 .34928 Mdot
.23349 .31681 Mdot
.66413 .61274 Mdot
.92891 .79398 Mdot
.46213 .47458 Mdot
.95802 .81327 Mdot
.64905 .60194 Mdot
.48898 .49226 Mdot
.01304 .16667 Mdot
.56024 .54096 Mdot
.63142 .59008 Mdot
.71098 .64494 Mdot
.30811 .36817 Mdot
.27697 .34761 Mdot
.17134 .27464 Mdot
.95469 .81104 Mdot
.90968 .78056 Mdot
.6297 .58857 Mdot
.66917 .61584 Mdot
.4906 .49396 Mdot
.08737 .21666 Mdot
.34315 .39303 Mdot
.74597 .66929 Mdot
.84348 .73536 Mdot
.59565 .56522 Mdot
.51266 .50891 Mdot
.68948 .62981 Mdot
.90486 .77723 Mdot
.99924 .84204 Mdot
.04722 .19028 Mdot
.53042 .52043 Mdot
.60295 .57126 Mdot
.5562 .53863 Mdot
.54714 .53246 Mdot
.13661 .25138 Mdot
.52602 .51835 Mdot
.0628 .2001 Mdot
.6725 .61795 Mdot
.68044 .62415 Mdot
.35908 .40282 Mdot
.44242 .4611 Mdot
.20737 .29917 Mdot
.38768 .42272 Mdot
.50796 .50582 Mdot
.02733 .17657 Mdot
.39268 .42681 Mdot
.75288 .67325 Mdot
.41315 .44022 Mdot
.62532 .58654 Mdot
.20403 .29676 Mdot
.17908 .27964 Mdot
.09477 .22163 Mdot
.3457 .39436 Mdot
.47404 .48165 Mdot
.40538 .43492 Mdot
.09298 .22155 Mdot
.98973 .83593 Mdot
.05609 .19552 Mdot
.96385 .81833 Mdot
.90391 .77686 Mdot
.31764 .37499 Mdot
.18329 .28337 Mdot
.529 .51938 Mdot
.63196 .59032 Mdot
.38273 .42001 Mdot
.11705 .23726 Mdot
.25816 .33459 Mdot
.43229 .45405 Mdot
.42184 .44628 Mdot
.66737 .61521 Mdot
.90606 .77811 Mdot
.04052 .18474 Mdot
.5514 .53518 Mdot
.83457 .7299 Mdot
.22021 .30796 Mdot
.31436 .37282 Mdot
.64615 .60021 Mdot
.38099 .41869 Mdot
.4556 .46906 Mdot
.84621 .73771 Mdot
.36513 .40758 Mdot
.65525 .60701 Mdot
.23945 .32082 Mdot
.30734 .36773 Mdot
.6469 .60134 Mdot
.36798 .41005 Mdot
.95208 .81014 Mdot
.62191 .58324 Mdot
.31108 .37027 Mdot
.43211 .4537 Mdot
.27697 .34647 Mdot
.52274 .51527 Mdot
.52549 .51687 Mdot
.96274 .81745 Mdot
.45303 .46801 Mdot
.34333 .39293 Mdot
.19734 .29239 Mdot
.79917 .70499 Mdot
.5057 .50382 Mdot
.2784 .34842 Mdot
.48289 .48842 Mdot
.41297 .44076 Mdot
.66948 .61651 Mdot
.95787 .8135 Mdot
.25233 .32991 Mdot
.2437 .32445 Mdot
.06165 .20009 Mdot
.14887 .25987 Mdot
.09098 .21975 Mdot
.31421 .37196 Mdot
.9324 .79622 Mdot
.38763 .42282 Mdot
.56295 .54382 Mdot
.79142 .69942 Mdot
.10746 .2304 Mdot
.80222 .70773 Mdot
.35433 .40054 Mdot
.986 .83346 Mdot
.14325 .25498 Mdot
.19187 .2882 Mdot
.01547 .16828 Mdot
.27239 .34327 Mdot
.72627 .65462 Mdot
.11151 .23433 Mdot
.10983 .23245 Mdot
.66353 .61255 Mdot
.12931 .24631 Mdot
.29111 .35626 Mdot
.47177 .48127 Mdot
.81983 .719 Mdot
.47027 .47923 Mdot
.32585 .38085 Mdot
.61914 .58206 Mdot
.38981 .42451 Mdot
.57575 .55147 Mdot
.11666 .23697 Mdot
.34531 .39386 Mdot
.75426 .67376 Mdot
.38845 .42354 Mdot
.14944 .25943 Mdot
.49987 .50027 Mdot
.9042 .77741 Mdot
.20398 .29699 Mdot
.86762 .75237 Mdot
.45519 .46955 Mdot
.12064 .23984 Mdot
.30105 .36323 Mdot
.36872 .40962 Mdot
.50846 .50601 Mdot
.5474 .53206 Mdot
.0842 .21452 Mdot
.27391 .34514 Mdot
.87504 .75707 Mdot
.63944 .59608 Mdot
.23096 .31532 Mdot
.53283 .52211 Mdot
.23988 .32168 Mdot
.26323 .33775 Mdot
.26248 .33654 Mdot
.81618 .71635 Mdot
.7095 .64429 Mdot
.31289 .37111 Mdot
.10531 .22902 Mdot
.36008 .40402 Mdot
.56071 .54196 Mdot
.8668 .75103 Mdot
.11425 .23507 Mdot
.04395 .18775 Mdot
.1108 .2327 Mdot
.99371 .83822 Mdot
.61881 .58129 Mdot
.59394 .56436 Mdot
.78121 .69223 Mdot
.87879 .75946 Mdot
.28841 .35452 Mdot
.07654 .20973 Mdot
.55656 .53839 Mdot
.09022 .21937 Mdot
.5167 .51132 Mdot
.00553 .16118 Mdot
.79461 .70253 Mdot
.60124 .56985 Mdot
.11328 .23451 Mdot
.6411 .59692 Mdot
.35812 .40231 Mdot
.36051 .40481 Mdot
.04496 .18778 Mdot
.56743 .54592 Mdot
.45467 .46951 Mdot
.402 .43268 Mdot
.23333 .31685 Mdot
.97278 .82367 Mdot
.49071 .49385 Mdot
.90319 .77686 Mdot
.08584 .21667 Mdot
.83789 .73108 Mdot
.92317 .79043 Mdot
.83427 .72969 Mdot
.95935 .81435 Mdot
.53552 .5243 Mdot
.10376 .22783 Mdot
.09225 .22061 Mdot
.74658 .66974 Mdot
.79839 .705 Mdot
.53888 .52702 Mdot
.79052 .69965 Mdot
.33497 .38662 Mdot
.61372 .57755 Mdot
.98113 .82908 Mdot
.39694 .42874 Mdot
.79204 .69983 Mdot
.71975 .65026 Mdot
.47292 .48079 Mdot
.22234 .30942 Mdot
.47828 .48516 Mdot
.30596 .36685 Mdot
.75459 .67493 Mdot
.52273 .5151 Mdot
.11034 .23348 Mdot
.5957 .56614 Mdot
.74741 .6692 Mdot
.00025 .15727 Mdot
.43629 .45692 Mdot
.24924 .32758 Mdot
.78414 .69503 Mdot
.85084 .74005 Mdot
.73799 .6628 Mdot
.77936 .692 Mdot
.02154 .17185 Mdot
.95293 .81066 Mdot
.77631 .69002 Mdot
.8305 .72636 Mdot
.6631 .61198 Mdot
.94543 .80485 Mdot
.5068 .50439 Mdot
.30567 .36652 Mdot
.10774 .2306 Mdot
.63104 .59014 Mdot
.32964 .38327 Mdot
.05005 .1911 Mdot
.6363 .59364 Mdot
.71209 .64577 Mdot
.07997 .21239 Mdot
.42827 .45041 Mdot
.09699 .22422 Mdot
.60604 .57332 Mdot
.21829 .3071 Mdot
.95441 .81151 Mdot
.67273 .61867 Mdot
.00944 .16424 Mdot
.42584 .44864 Mdot
.50581 .50391 Mdot
.52107 .51495 Mdot
.91034 .78075 Mdot
.85241 .7417 Mdot
.95692 .81345 Mdot
.84083 .73404 Mdot
.72371 .65388 Mdot
.66908 .61603 Mdot
.37326 .41278 Mdot
.05668 .19636 Mdot
.93459 .79773 Mdot
.13806 .25206 Mdot
.18076 .28132 Mdot
.72336 .65378 Mdot
.4203 .44563 Mdot
.93185 .79627 Mdot
.53363 .52318 Mdot
.63674 .59378 Mdot
.09919 .22485 Mdot
.48474 .48992 Mdot
.24377 .32437 Mdot
.85204 .74141 Mdot
.65146 .60367 Mdot
.45856 .47156 Mdot
.90862 .77959 Mdot
.04036 .18544 Mdot
.66612 .61402 Mdot
.63119 .59046 Mdot
.38256 .41943 Mdot
.94148 .80225 Mdot
.98006 .82851 Mdot
.40637 .43588 Mdot
.24965 .32792 Mdot
.44902 .46555 Mdot
.97714 .82636 Mdot
.52354 .51637 Mdot
.52945 .52007 Mdot
.44205 .46005 Mdot
.4952 .49732 Mdot
.91483 .78434 Mdot
.26282 .33677 Mdot
.0177 .16997 Mdot
.02697 .17542 Mdot
.79089 .69931 Mdot
.09151 .22031 Mdot
.88148 .7614 Mdot
.54102 .5281 Mdot
.87879 .76024 Mdot
.28628 .3529 Mdot
.01876 .17073 Mdot
.08504 .21539 Mdot
.95291 .81047 Mdot
.51617 .51098 Mdot
.0942 .2213 Mdot
.25461 .33158 Mdot
.20629 .29857 Mdot
.70869 .64361 Mdot
.55583 .53784 Mdot
.57324 .54994 Mdot
.99605 .8402 Mdot
.79633 .70327 Mdot
.43643 .4561 Mdot
.7955 .70294 Mdot
.82332 .72227 Mdot
.48054 .48644 Mdot
.73744 .66339 Mdot
.85522 .74401 Mdot
.59788 .56728 Mdot
.69809 .6355 Mdot
.86908 .75322 Mdot
.26272 .33755 Mdot
.40615 .4351 Mdot
.68708 .6281 Mdot
.3686 .41046 Mdot
.7937 .70142 Mdot
.8844 .76346 Mdot
.90719 .77957 Mdot
.73504 .66163 Mdot
.44371 .46188 Mdot
.91211 .78223 Mdot
.82263 .72068 Mdot
.31493 .37354 Mdot
.21467 .30475 Mdot
.85236 .74135 Mdot
.98411 .83107 Mdot
.6523 .60428 Mdot
.89411 .77063 Mdot
.78647 .69629 Mdot
.53132 .52127 Mdot
.93868 .80122 Mdot
.71924 .6501 Mdot
.79965 .70603 Mdot
.54726 .53254 Mdot
.55236 .53543 Mdot
.70554 .64069 Mdot
.71474 .64671 Mdot
.95151 .80993 Mdot
.67756 .62164 Mdot
.6992 .6364 Mdot
.31542 .37392 Mdot
.71486 .64683 Mdot
.75374 .67368 Mdot
.4076 .43635 Mdot
.78843 .69805 Mdot
.7281 .65686 Mdot
.20713 .29922 Mdot
.69142 .63069 Mdot
.6013 .56987 Mdot
.09279 .22096 Mdot
.94506 .80505 Mdot
.63063 .58988 Mdot
.2476 .32651 Mdot
.81836 .71868 Mdot
.56965 .54821 Mdot
.47673 .48447 Mdot
.79208 .70004 Mdot
.50683 .50502 Mdot
.78212 .69324 Mdot
.2628 .33734 Mdot
.5085 .50526 Mdot
.65633 .60682 Mdot
.75176 .67285 Mdot
.11345 .23455 Mdot
.59844 .56763 Mdot
.33113 .38418 Mdot
.62718 .58712 Mdot
.12357 .24156 Mdot
.64585 .59969 Mdot
.21345 .303 Mdot
.32753 .38134 Mdot
.55934 .54102 Mdot
.98973 .83561 Mdot
.74951 .6705 Mdot
.98494 .83274 Mdot
.62968 .58862 Mdot
.39354 .42662 Mdot
.83298 .72785 Mdot
.83163 .72758 Mdot
.06983 .20487 Mdot
.66168 .61141 Mdot
.79139 .70032 Mdot
.60866 .57508 Mdot
.11221 .23384 Mdot
.19627 .29206 Mdot
.78633 .69606 Mdot
.40224 .43331 Mdot
.01869 .1703 Mdot
.78578 .69554 Mdot
.59721 .56616 Mdot
.96066 .81607 Mdot
.87434 .75621 Mdot
.37596 .4151 Mdot
.61822 .58054 Mdot
.89565 .77145 Mdot
.93184 .79572 Mdot
.87867 .75897 Mdot
.36447 .40718 Mdot
.69751 .63585 Mdot
.99627 .8404 Mdot
.15593 .26463 Mdot
.49238 .49456 Mdot
.22862 .31339 Mdot
.61673 .58022 Mdot
.03071 .17904 Mdot
.32763 .38134 Mdot
.2 .29424 Mdot
.13445 .24886 Mdot
.33077 .38394 Mdot
.62898 .58856 Mdot
.80072 .70642 Mdot
.73646 .66165 Mdot
.26822 .3411 Mdot
.27904 .3486 Mdot
.69153 .63079 Mdot
.56755 .54581 Mdot
.06609 .20248 Mdot
.37609 .41486 Mdot
.34621 .39399 Mdot
.84963 .73985 Mdot
.31374 .37215 Mdot
.53073 .52135 Mdot
.13513 .2504 Mdot
.77668 .68942 Mdot
.80983 .71309 Mdot
.78112 .69247 Mdot
.35067 .39706 Mdot
.63673 .5942 Mdot
.46014 .47255 Mdot
.85913 .74671 Mdot
.82801 .72482 Mdot
.01369 .16651 Mdot
.84159 .73386 Mdot
.36309 .40584 Mdot
.24318 .32377 Mdot
.62575 .58672 Mdot
.3954 .42818 Mdot
.28285 .35131 Mdot
.09969 .2255 Mdot
.4175 .44318 Mdot
.30407 .36506 Mdot
.57641 .5518 Mdot
.97674 .82653 Mdot
.11058 .23355 Mdot
.60366 .57141 Mdot
.42863 .45053 Mdot
.60915 .57544 Mdot
.09656 .22386 Mdot
.88484 .76377 Mdot
.90449 .7772 Mdot
.74564 .66837 Mdot
.92306 .78955 Mdot
.64764 .60148 Mdot
.73588 .66117 Mdot
.33224 .38432 Mdot
.54271 .5294 Mdot
.74034 .66502 Mdot
.55882 .53999 Mdot
.99012 .83558 Mdot
.24769 .32676 Mdot
.13592 .2502 Mdot
.08948 .21869 Mdot
.44057 .4593 Mdot
.08487 .21598 Mdot
.00775 .16221 Mdot
.65538 .60694 Mdot
.84389 .73614 Mdot
.91648 .78556 Mdot
.88894 .76614 Mdot
.14562 .2565 Mdot
.5261 .51778 Mdot
.09607 .22284 Mdot
.79931 .70474 Mdot
.32731 .38152 Mdot
.00454 .16031 Mdot
.00651 .16241 Mdot
.45823 .47097 Mdot
.89053 .76826 Mdot
.86178 .74749 Mdot
.42571 .44907 Mdot
.6979 .63627 Mdot
.54259 .52942 Mdot
.2479 .32705 Mdot
.78317 .69417 Mdot
.29153 .35707 Mdot
.05117 .19229 Mdot
.10535 .22924 Mdot
.59596 .56523 Mdot
.89532 .77055 Mdot
.18217 .2825 Mdot
.2836 .35117 Mdot
.11051 .23293 Mdot
.83162 .72691 Mdot
.00624 .16161 Mdot
.17208 .27481 Mdot
.62526 .58533 Mdot
.19693 .29274 Mdot
.26426 .33807 Mdot
.70201 .63915 Mdot
.18191 .28236 Mdot
.14807 .2591 Mdot
.02082 .17164 Mdot
.89915 .77345 Mdot
.88804 .76611 Mdot
.2524 .32983 Mdot
.40265 .43373 Mdot
.97463 .82547 Mdot
.48062 .48696 Mdot
.02382 .17408 Mdot
.18282 .28252 Mdot
.8668 .75193 Mdot
.82735 .72407 Mdot
.32066 .3765 Mdot
.72115 .65227 Mdot
.55203 .53618 Mdot
.98383 .83177 Mdot
.1902 .28806 Mdot
.87092 .75377 Mdot
.89596 .77147 Mdot
.69948 .63735 Mdot
.4283 .45128 Mdot
.84126 .73347 Mdot
.72093 .65156 Mdot
.70948 .64368 Mdot
.09856 .225 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Y_ooool3o`0007Oooooo002Uooooo`05o`000?ooooooooooooooool00000M_ooool00:Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1cooooo`00YOooool6o`0007Gooooo
002Vooooo`05o`000?ooooooooooooooool00000MOooool00:Oooooo0ol0001fooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00@_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`000003ooooool0003o000000?o00000_ooool3o`0000Oooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0ol00002ooooo`?o00001oooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Wooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000:ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
0_ooool5o`0000;ooooo0ol00006ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
0oooool3o`0000Oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Booooo`00@Oooool01?l0003oooooooooool0000:ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00002_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool03oooool0047ooooo00Co0000oooooooooooo00001oooool5o`0000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00005
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool0000;ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo0011
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`00@Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000000;ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Kooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000002ooooo`Co00001_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000000ol00008oooo
o`04o`000?ooooooooooo`0000Oooooo1?l00009ooooo`04o`000?ooooooooooo`0000Oooooo1?l0
0002ooooo`06o`000?ooooooooooooooool0003ooooo1?l00005ooooo`04o`000?ooooooooooo`00
00Oooooo1?l00002ooooo`Co00001_ooool01?l0003oooooooooool00007ooooo`Co00001_ooool0
0ol0003oooooo`000003o`0001;ooooo0011ooooo`04o`000?ooooooooooo`0000Wooooo0_l00002
ooooo`07o`000?ooooooooooooooool0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00002ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002Oooool2o`00
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool00oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
01Gooooo0012ooooo`;o00002oooool01?l0003oooooooooooooool3o`0000;ooooo1Ol00006oooo
o`;o00002oooool00ol0003oooooooooo`05o`0000Kooooo0_l0000;ooooo`03o`000?oooooooooo
00Go000000?oooooo`000?l000000ol00008ooooo`;o00002?ooool5o`0000Wooooo0_l00008oooo
o`Go00000_ooool3o`0000;ooooo1Ol00005ooooo`;o00002?ooool5o`000003ooooool0003o0000
00?o00001_ooool2o`0000Sooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00?o00004Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
03;oooooj`000001o`00004000000Oooool003;ooooo00<00000ooooooooool06_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Jooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo
000booooo`0300000?oooooooooo0>Wooooo0@000001ooooo`00<_ooool00`00003oooooooooo`3Y
ooooo`4000000Oooool003;ooooo00<00000o`000?ooool0j?ooool1o`00004000000Oooool003;o
oooo00<00000ooooooooool0jOooool10000007ooooo000booooo`0300000?oooooooooo0>Wooooo
0@000001ooooo`00<_ooool00`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000
ooooooooool0jOooool10000007ooooo000booooo`0300000?oooooooooo0>Wooooo0@000001oooo
o`00<_ooool00`00003o0000ooooo`3Xooooo`7o00000@000001ooooo`00<_ooool00`00003ooooo
ooooo`3Yooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000b
ooooo`0300000?oooooooooo0>Wooooo0@000001ooooo`00<_ooool00`00003oooooooooo`3Yoooo
o`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000booooo`030000
0?l0003ooooo0>Sooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo0>Wooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0jOooool10000007ooooo000booooo`0300000?oooooooooo0>Wooooo0@000001ooooo`00
<_ooool00`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000o`000?ooool0j?oo
ool1o`00004000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000boooo
o`0300000?oooooooooo0>Wooooo0@000001ooooo`00<_ooool00`00003oooooooooo`3Yooooo`40
00000Oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol00005ooooo`0300000?oooooooooo0>Wooooo0@000001ooooo`004_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0jOooool10000
007ooooo000;ooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`0300000?l0003o
oooo0>Sooooo0Ol000010000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00<0
0000ooooooooool0jOooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooo`000003o`0000Gooooo00<00000ooooooooool0
jOooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo
0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00<00000ooooooooool0jOooool10000
007ooooo000Cooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Co
oooo00<00000ooooooooool0jOooool10000007ooooo000booooo`0300000?oooooooooo0>Wooooo
0@000001ooooo`00<_ooool00`00003o0000ooooo`3Xooooo`7o00000@000001ooooo`00<_ooool0
0`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo0P00003Zooooo`4000000Oooool003;o
oooo0`00003Yooooo`4000000Oooool003;ooooo00<00000ooooooooool00P00003Wooooo`400000
0Oooool003;ooooo00@00000oooooooooooooooo0P00003Vooooo`4000000Oooool003;ooooo00<0
0000o`000?ooool00oooool00`00003oooooooooo`3Rooooo`7o00000@000001ooooo`00<_ooool0
0`00003oooooooooo`04ooooo`0300000?oooooooooo0>;ooooo0@000001ooooo`00<_ooool00`00
003oooooooooo`06ooooo`0300000?oooooooooo0>3ooooo0@000001ooooo`00<_ooool00`00003o
ooooooooo`07ooooo`800000h?ooool10000007ooooo000booooo`0300000?oooooooooo00Sooooo
0`00003Nooooo`4000000Oooool003;ooooo00<00000ooooooooool02_ooool00`00003ooooooooo
o`3Looooo`4000000Oooool003;ooooo00<00000o`000?ooool02oooool300000=[ooooo0Ol00001
0000007ooooo000booooo`0300000?oooooooooo00gooooo00<00000ooooooooool0fOooool10000
007ooooo000booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0eoooool10000007o
oooo000booooo`0300000?oooooooooo013ooooo0P00003Gooooo`4000000Oooool003;ooooo00<0
0000ooooooooool04Oooool200000=Kooooo0@000001ooooo`00<_ooool00`00003oooooooooo`0B
ooooo`<00000e?ooool10000007ooooo000booooo`0300000?l0003ooooo01Cooooo0P00003Boooo
o`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`0Fooooo`0300000?oooooooooo0=3o
oooo0@000001ooooo`00<_ooool00`00003oooooooooo`0Gooooo`800000d?ooool10000007ooooo
000Iooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00<0
0000ooooooooool06?ooool200000<oooooo0@000001ooooo`006?ooool01?l0003oooooooooool0
0008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03
00000?oooooooooo01[ooooo00<00000ooooooooool0c?ooool10000007ooooo000Aooooo`Go0000
0_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00_ooool00`00003oooooooooo`0Kooooo`<00000boooool10000007ooooo000Hooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02
ooooo`0300000?l0003ooooo01gooooo0P000039ooooo`7o00000@000001ooooo`006?ooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`0300000?oo
oooooooo01oooooo00<00000ooooooooool0aoooool10000007ooooo000Hooooo`04o`000?oooooo
ooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`0300000?oooooooooo023o
oooo0P000037ooooo`4000000Oooool001Wooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo
00<00000ooooooooool08_ooool00`00003oooooooooo`34ooooo`4000000Oooool003;ooooo00<0
0000ooooooooool08oooool00`00003oooooooooo`33ooooo`4000000Oooool003;ooooo00<00000
ooooooooool09?ooool00`00003oooooooooo`32ooooo`4000000Oooool003;ooooo00<00000o`00
0?ooool09Oooool200000<7ooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo02Oo
oooo0P000030ooooo`4000000Oooool003;ooooo00<00000ooooooooool0:?ooool200000;oooooo
0@000001ooooo`00<_ooool00`00003oooooooooo`0Zooooo`0300000?oooooooooo0;cooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`0[ooooo`800000_?ooool10000007ooooo000boooo
o`0300000?l0003ooooo02gooooo0P00002iooooo`7o00000@000001ooooo`00<_ooool00`00003o
ooooooooo`0_ooooo`0300000?oooooooooo0;Oooooo0@000001ooooo`00<_ooool00`00003ooooo
ooooo`0`ooooo`800000]oooool10000007ooooo000booooo`0300000?oooooooooo037ooooo0P00
002fooooo`4000000Oooool003;ooooo00<00000ooooooooool0<oooool200000;Cooooo0@000001
ooooo`00<_ooool00`00003oooooooooo`0dooooo`800000/oooool10000007ooooo000booooo`03
00000?l0003ooooo03Kooooo0P00002`ooooo`7o00000@000001ooooo`00<_ooool00`00003ooooo
ooooo`0gooooo`800000/?ooool10000007ooooo000booooo`0300000?oooooooooo03Sooooo0P00
002_ooooo`4000000Oooool003;ooooo00<00000ooooooooool0>_ooool200000:gooooo0@000001
ooooo`00<_ooool00`00003oooooooooo`0kooooo`800000[?ooool10000007ooooo000booooo`03
00000?oooooooooo03gooooo0P00002Zooooo`4000000Oooool003;ooooo00<00000o`000?ooool0
?_ooool200000:Sooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo043ooooo0P00
002Wooooo`4000000Oooool003;ooooo00<00000ooooooooool0@_ooool00`00003oooooooooo`2T
ooooo`4000000Oooool003;ooooo00<00000ooooooooool0A?ooool00`00003oooooooooo`2Roooo
o`4000000Oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go
00000_ooool3o`0000Gooooo00<00000ooooooooool0AOooool00`00003oooooooooo`2Qooooo`40
00000Oooool001;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo04Gooooo0`00002Qooooo`4000000Oooool000_ooooo1Ol00002ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00<00000o`000?ooool0Aoooool2000009oooooo0Ol000010000007ooooo
000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0BOooool00`00003o
ooooooooo`2Mooooo`4000000Oooool001;ooooo00Co0000oooooooooooo00002?ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005ooooo`0300000?oooooo
oooo04[ooooo0P00002Mooooo`4000000Oooool001;ooooo00Co0000oooooooooooo00002?ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000002?ooool00`00003ooooo
ooooo`1<ooooo`0300000?oooooooooo09[ooooo0@000001ooooo`004oooool2o`0000[ooooo0_l0
0003ooooo`?o00000_ooool5o`0000Cooooo00<00000ooooooooool0COooool2000009[ooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`1>ooooo`<00000V?ooool10000007ooooo000boooo
o`0300000?l0003ooooo057ooooo00<00000ooooooooool0U?ooool1o`00004000000Oooool003;o
oooo00<00000ooooooooool0D_ooool00`00003oooooooooo`2Dooooo`4000000Oooool003;ooooo
00<00000ooooooooool0Doooool2000009Cooooo0@000001ooooo`00<_ooool00`00003ooooooooo
o`1Dooooo`800000Toooool10000007ooooo000booooo`0300000?oooooooooo05Kooooo0P00002A
ooooo`4000000Oooool003;ooooo00<00000ooooooooool0Eoooool00`00003oooooooooo`2?oooo
o`4000000Oooool003;ooooo00<00000o`000?ooool0FOooool2000008gooooo0Ol000010000007o
oooo000booooo`0300000?oooooooooo05[ooooo0P00002=ooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0G?ooool2000008_ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1M
ooooo`0300000?oooooooooo08Wooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Ooooo
o`800000R?ooool10000007ooooo000booooo`0300000?oooooooooo063ooooo0P000027ooooo`40
00000Oooool003;ooooo00<00000o`000?ooool0H_ooool00`00003oooooooooo`23ooooo`7o0000
0@000001ooooo`00<_ooool00`00003oooooooooo`1Sooooo`800000Q?ooool10000007ooooo000b
ooooo`0300000?oooooooooo06Cooooo0P000023ooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0IOooool2000008;ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Wooooo`<0
0000Ooooool10000007ooooo000booooo`0300000?oooooooooo06Sooooo0`00001nooooo`400000
0Oooool003;ooooo00<00000o`000?ooool0J_ooool2000007cooooo0Ol000010000007ooooo000b
ooooo`0300000?oooooooooo06cooooo0P00001kooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0KOooool2000007[ooooo0@000001ooooo`00:oooool2o`0000Gooooo00<00000oooooooo
ool0K_ooool2000007Wooooo0@000001ooooo`000_ooool3o`0002Gooooo00Co0000oooooooooooo
00001?ooool00`00003oooooooooo`1`ooooo`800000Moooool10000007ooooo0003ooooo`03o`00
0?oooooooooo02Cooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1aooooo`80
0000M_ooool10000007ooooo0003ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo
00001?ooool00`00003o0000ooooo`1cooooo`0300000?oooooooooo07;ooooo0Ol000010000007o
oooo0003ooooo`;o00009Oooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07Co
oooo0`00001booooo`4000000Oooool000;ooooo0_l000000ooooooo0000o`00000Sooooo`04o`00
0?ooooooooooo`0000Cooooo00<00000ooooooooool0M_ooool20000077ooooo0@000001ooooo`00
:oooool2o`0000Gooooo00<00000ooooooooool0N?ooool00`00003oooooooooo`1^ooooo`400000
0Oooool003;ooooo00<00000ooooooooool0NOooool2000006kooooo0@000001ooooo`00<_ooool0
0`00003oooooooooo`1jooooo`800000KOooool10000007ooooo000booooo`0300000?l0003ooooo
07_ooooo0`00001Zooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`1mooooo`80
0000J_ooool10000007ooooo000booooo`0300000?oooooooooo07oooooo00<00000ooooooooool0
Ioooool10000007ooooo000booooo`0300000?oooooooooo083ooooo0P00001Wooooo`4000000Ooo
ool003;ooooo00<00000ooooooooool0POooool3000006Gooooo0@000001ooooo`00<_ooool00`00
003oooooooooo`23ooooo`800000I?ooool10000007ooooo000booooo`0300000?l0003ooooo08Co
oooo0P00001Rooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`26ooooo`030000
0?oooooooooo063ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`28ooooo`0300000?oo
oooooooo05kooooo0@000001ooooo`00<_ooool00`00003oooooooooo`29ooooo`800000G_ooool1
0000007ooooo000booooo`0300000?oooooooooo08[ooooo0P00001Mooooo`4000000Oooool003;o
oooo00<00000o`000?ooool0Roooool2000005_ooooo0Ol000010000007ooooo000booooo`030000
0?oooooooooo08gooooo0P00001Jooooo`4000000Oooool003;ooooo00<00000ooooooooool0Sooo
ool2000005Sooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2Aooooo`0300000?oooooo
oooo05Gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2Booooo`0300000?oooooooooo
05Cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2Cooooo`0300000?oooooooooo05?o
oooo0@000001ooooo`00<_ooool00`00003o0000ooooo`2Dooooo`0300000?ooool00000057ooooo
0Ol000010000007ooooo000booooo`0300000?oooooooooo09Kooooo0P00001Aooooo`4000000Ooo
ool003;ooooo00<00000ooooooooool0V?ooool00`00003oooooooooo`1>ooooo`4000000Oooool0
03;ooooo00<00000ooooooooool0VOooool2000004kooooo0@000001ooooo`004oooool2o`0000Co
oooo00?o0000ooooooooool00oooool2o`0000;ooooo1Ol00002ooooo`?o00001Oooool00`00003o
ooooooooo`2Jooooo`800000COooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00_ooool00`00003oooooooooo`2Looooo`0300000?oooooooooo04[ooooo0@00
0001ooooo`004_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`0300000?l0003ooooo09gooooo
0P000019ooooo`7o00000@000001ooooo`004_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
00000?oooooooooo09oooooo0P000018ooooo`4000000Oooool001;ooooo00Co0000oooooooooooo
00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000000ol00005
ooooo`0300000?oooooooooo0:3ooooo0P000017ooooo`4000000Oooool001;ooooo00Co0000oooo
oooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool00000
2?ooool00`00003oooooooooo`2Rooooo`0300000?oooooooooo04Cooooo0@000001ooooo`004ooo
ool2o`0000[ooooo0_l00003ooooo`?o00000_ooool5o`0000Cooooo00<00000ooooooooool0Xooo
ool2000004Cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2Tooooo`<00000@_ooool1
0000007ooooo000booooo`0300000?l0003ooooo0:Kooooo0P000010ooooo`7o00000@000001oooo
o`00<_ooool00`00003oooooooooo`2Wooooo`<00000?oooool10000007ooooo000booooo`030000
0?oooooooooo0:Wooooo00<00000ooooooooool0?Oooool10000007ooooo000booooo`0300000?oo
oooooooo0:_ooooo00<00000ooooooooool0>oooool10000007ooooo000booooo`0300000?oooooo
oooo0:cooooo00<00000ooooooooool0>_ooool10000007ooooo000booooo`0300000?oooooooooo
0:gooooo0P00000jooooo`4000000Oooool003;ooooo00<00000o`000?ooool0[oooool00`00003o
ooooooooo`0fooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`2aooooo`030000
0?oooooooooo03Gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2booooo`0300000?oo
oooooooo03Cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2cooooo`0300000?oooooo
oooo03?ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2dooooo`<00000<_ooool10000
007ooooo000booooo`0300000?oooooooooo0;Kooooo0P00000aooooo`4000000Oooool003;ooooo
00<00000o`000?ooool0]oooool3000002kooooo0Ol000010000007ooooo000booooo`0300000?oo
oooooooo0;Wooooo0P00000^ooooo`4000000Oooool003;ooooo00<00000ooooooooool0^_ooool2
000002gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2looooo`0300000?oooooooooo
02[ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2nooooo`0300000?oooooooooo02So
oooo0@000001ooooo`00<_ooool00`00003oooooooooo`2oooooo`800000:?ooool10000007ooooo
000booooo`0300000?l0003ooooo0<3ooooo0`00000Uooooo`7o00000@000001ooooo`00<_ooool0
0`00003oooooooooo`32ooooo`8000009Oooool10000007ooooo000booooo`0300000?oooooooooo
0<Cooooo00<00000ooooooooool08_ooool10000007ooooo000Iooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00<00000ooooooooool0a?ooool3000002;o
oooo0@000001ooooo`006?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo0<Kooooo0P00000Q
ooooo`4000000Oooool001Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0b?ooool2000001oooooo0@00
0001ooooo`006?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool00_ooool00`00003o0000ooooo`39ooooo`8000007Oooool1o`0000400000
0Oooool001Sooooo00Co0000oooooooooooo00002?ooool01Ol0003oooooooooool0003ooooo00Co
00001Oooool00`00003oooooooooo`3:ooooo`<000007?ooool10000007ooooo000Hooooo`04o`00
0?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00008ooooo`0300000?oooooo
oooo0<cooooo0P00000Kooooo`4000000Oooool001Wooooo0_l0000:ooooo`;o00000_ooool5o`00
00Cooooo00<00000ooooooooool0cOooool2000001[ooooo0@000001ooooo`00<_ooool00`00003o
ooooooooo`3?ooooo`0300000?oooooooooo01Oooooo0@000001ooooo`00<_ooool00`00003ooooo
ooooo`3@ooooo`8000005oooool10000007ooooo000booooo`0300000?l0003ooooo0=;ooooo0P00
000Dooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`3Cooooo`8000005?ooool1
0000007ooooo000booooo`0300000?oooooooooo0=Gooooo0P00000Booooo`4000000Oooool003;o
oooo00<00000ooooooooool0e_ooool20000017ooooo0@000001ooooo`00<_ooool00`00003ooooo
ooooo`3Hooooo`8000003oooool10000007ooooo000booooo`0300000?oooooooooo0=Wooooo0P00
000>ooooo`4000000Oooool003;ooooo00<00000o`000?ooool0foooool00`00003oooooooooo`0:
ooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`3Looooo`0300000?oooooooooo
00[ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`3Nooooo`8000002Oooool10000007o
oooo000booooo`0300000?oooooooooo0=oooooo0P000008ooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0h?ooool2000000Oooooo0@000001ooooo`00<_ooool00`00003oooooooooo`3R
ooooo`8000001Oooool10000007ooooo000booooo`0300000?l0003ooooo0>?ooooo0`000002oooo
o`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`3Uooooo`8000000_ooool10000007o
oooo000booooo`0300000?oooooooooo0>Kooooo0P000001ooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0j?ooool20000007ooooo000booooo`0300000?oooooooooo0>Wooooo0@000001
ooooo`00<_ooool00`00003o0000ooooo`3Xooooo`7o00000@000001ooooo`00<_ooool00`00003o
ooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo
000booooo`0300000?oooooooooo0>Wooooo0@000001ooooo`004oooool2o`0000Cooooo00?o0000
ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00<00000
ooooooooool0jOooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool00`00003oooooooooo`3Yooooo`4000000Oooool001;ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00`00003o0000ooooo`3Xooooo`7o00000@000001ooooo`004_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`0300000?oooooooooo0>Wooooo0@000001ooooo`004_ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000000ol00005
ooooo`0300000?oooooooooo0>Wooooo0@000001ooooo`004_ooool01?l0003oooooooooool00008
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`030000
0?oooooooooo0>Wooooo0@000001ooooo`004oooool2o`0000[ooooo0_l00002ooooo`Go000000?o
ooooo`000?l000000ol00004ooooo`0300000?oooooooooo0>Wooooo0@000001ooooo`00<_ooool0
0`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000o`000?ooool0j?ooool1o`00
004000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000booooo`030000
0?oooooooooo0>Wooooo0@000001ooooo`00<_ooool00`00003oooooooooo`3Yooooo`4000000Ooo
ool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000booooo`0300000?oooooooooo
0>Wooooo0@000001ooooo`00<_ooool00`00003o0000ooooo`3Xooooo`7o00000@000001ooooo`00
<_ooool00`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOoo
ool10000007ooooo000booooo`0300000?oooooooooo0>Wooooo0@000001ooooo`00<_ooool00`00
003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007o
oooo000booooo`0300000?l0003ooooo0>Sooooo0Ol000010000007ooooo000booooo`0300000?oo
oooooooo0>Wooooo0@000001ooooo`00<_ooool00`00003oooooooooo`3Yooooo`4000000Oooool0
03;ooooo00<00000ooooooooool0jOooool10000007ooooo000booooo`0300000?oooooooooo0>Wo
oooo0@000001ooooo`00<_ooool00`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<0
0000o`000?ooool0j?ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0jOooool1
0000007ooooo000booooo`0300000?oooooooooo0>Wooooo0@000001ooooo`007oooool2o`0000Co
oooo00?o0000ooooooooool00_ooool3o`0000Gooooo00<00000ooooooooool0jOooool10000007o
oooo000Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00`00003o
ooooooooo`0Jooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool06oooool00`00003o
ooooooooo`0Jooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool06_ooool00`00003o
ooooooooo`0Kooooo`0300000?oooooooooo01[ooooo0@000001ooooo`007_ooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00`00003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00`00003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool10000007o
oooo000Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooooo]0000007o
oooo000Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0l_ooool001kooooo
00Co0000oooooooooooo00002?ooool2o`000?Cooooo000Oooooo`;o00002_ooool00ol0003ooooo
ooooo`3booooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00\
\>"],
  ImageRangeCache->{{{73.4375, 302.812}, {286.438, 57.0625}} -> {0.279553, \
-0.0692379, 0.000846872, 0.000846872}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2 5 0.5 5 [
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -15 -9 ]
[.625 -0.0125 15 0 ]
[.75 -0.0125 -12 -9 ]
[.75 -0.0125 12 0 ]
[.875 -0.0125 -15 -9 ]
[.875 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .125 -36 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -30 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -36 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -30 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -24 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -30 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -18 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -46 -6 ]
[-0.01875 .5 -36 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.425)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.45)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.475)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.525)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.55)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.575)] .875 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .125 m
.00625 .125 L
s
[(-0.075)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-0.05)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-0.025)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(0.025)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(0.05)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(0.075)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(0.1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.005 w
.29744 .94015 Mdot
.53916 .41369 Mdot
.34408 .83855 Mdot
.28464 .96728 Mdot
.27445 .98751 Mdot
.41165 .69277 Mdot
.64702 .1791 Mdot
.30015 .93407 Mdot
.53075 .43388 Mdot
.7149 .03462 Mdot
.50628 .48535 Mdot
.72638 .00884 Mdot
.47098 .56251 Mdot
.55822 .37146 Mdot
.35492 .81656 Mdot
.37799 .76557 Mdot
.32604 .87743 Mdot
.63509 .20565 Mdot
.73048 .00182 Mdot
.55918 .3703 Mdot
.57809 .33011 Mdot
.53918 .41549 Mdot
.31536 .90135 Mdot
.4331 .64616 Mdot
.70042 .06477 Mdot
.52186 .4521 Mdot
.42969 .65434 Mdot
.54811 .39583 Mdot
.30988 .91424 Mdot
.60897 .26228 Mdot
.52357 .44762 Mdot
.32456 .88051 Mdot
.53469 .42335 Mdot
.32413 .88335 Mdot
.64934 .17567 Mdot
.29239 .95033 Mdot
.3734 .77573 Mdot
.35989 .80592 Mdot
.56023 .3671 Mdot
.34443 .83978 Mdot
.43231 .648 Mdot
.69137 .08337 Mdot
.52253 .45009 Mdot
.44821 .61296 Mdot
.45307 .60268 Mdot
.71266 .03989 Mdot
.60354 .27268 Mdot
.30143 .93081 Mdot
.56151 .36474 Mdot
.65647 .15981 Mdot
.29923 .93513 Mdot
.4694 .56635 Mdot
.40608 .70577 Mdot
.6684 .13421 Mdot
.32711 .87499 Mdot
.65834 .1567 Mdot
.54637 .39738 Mdot
.38209 .75719 Mdot
.60796 .2643 Mdot
.70049 .06406 Mdot
.37378 .77595 Mdot
.34944 .82806 Mdot
.69131 .08449 Mdot
.55699 .37509 Mdot
.28531 .96607 Mdot
.37923 .7626 Mdot
.64136 .19229 Mdot
.54732 .39552 Mdot
.48189 .53905 Mdot
.48589 .53043 Mdot
.6468 .18156 Mdot
.35734 .81078 Mdot
.41279 .68955 Mdot
.28728 .96207 Mdot
.62492 .22785 Mdot
.40828 .70103 Mdot
.66741 .13588 Mdot
.50915 .4813 Mdot
.5469 .39839 Mdot
.43651 .63983 Mdot
.42229 .66868 Mdot
.38043 .76076 Mdot
.33669 .85644 Mdot
.71785 .02735 Mdot
.4163 .68362 Mdot
.69192 .08385 Mdot
.68267 .10244 Mdot
.53047 .43254 Mdot
.47861 .54802 Mdot
.56087 .36666 Mdot
.71676 .03091 Mdot
.65233 .16829 Mdot
.47091 .56495 Mdot
.59808 .28728 Mdot
.47587 .55192 Mdot
.43544 .64203 Mdot
.39512 .72978 Mdot
.32093 .88876 Mdot
.33181 .86472 Mdot
.42533 .66403 Mdot
.53382 .42686 Mdot
.56185 .36456 Mdot
.70262 .05979 Mdot
.36596 .79174 Mdot
.44008 .62953 Mdot
.37447 .77319 Mdot
.52275 .44901 Mdot
.65561 .15992 Mdot
.57747 .32964 Mdot
.46945 .56728 Mdot
.69307 .08125 Mdot
.672 .125 Mdot
.61118 .25712 Mdot
.32509 .87932 Mdot
.39477 .73004 Mdot
.71345 .03741 Mdot
.6103 .2582 Mdot
.66709 .13717 Mdot
.55882 .37145 Mdot
.43936 .63389 Mdot
.5623 .36304 Mdot
.29449 .9471 Mdot
.3121 .90812 Mdot
.47711 .54921 Mdot
.3147 .9026 Mdot
.53643 .42096 Mdot
.60166 .27947 Mdot
.37549 .77211 Mdot
.5894 .30619 Mdot
.37213 .77919 Mdot
.71117 .042 Mdot
.33598 .85731 Mdot
.59912 .28436 Mdot
.35985 .80644 Mdot
.63799 .20011 Mdot
.55127 .38811 Mdot
.3444 .83753 Mdot
.43027 .65253 Mdot
.46996 .56684 Mdot
.50143 .49597 Mdot
.46121 .58553 Mdot
.57106 .34529 Mdot
.67449 .11942 Mdot
.48227 .54013 Mdot
.43863 .63339 Mdot
.52643 .44202 Mdot
.4949 .51084 Mdot
.49058 .51946 Mdot
.49653 .50819 Mdot
.46671 .57338 Mdot
.34364 .8399 Mdot
.38632 .74804 Mdot
.3116 .90982 Mdot
.63172 .21313 Mdot
.46728 .57146 Mdot
.412 .69281 Mdot
.64336 .18909 Mdot
.63232 .21241 Mdot
.45002 .60946 Mdot
.52132 .45342 Mdot
.37875 .76498 Mdot
.48038 .54351 Mdot
.42284 .66848 Mdot
.57042 .34553 Mdot
.55821 .3719 Mdot
.6343 .20776 Mdot
.52819 .43834 Mdot
.33789 .85394 Mdot
.52698 .44098 Mdot
.5385 .41684 Mdot
.43206 .64776 Mdot
.30698 .91956 Mdot
.42285 .66969 Mdot
.68236 .10309 Mdot
.68027 .10783 Mdot
.48548 .53278 Mdot
.52221 .45156 Mdot
.69078 .08643 Mdot
.34642 .83334 Mdot
.6653 .14031 Mdot
.43149 .64993 Mdot
.31785 .8945 Mdot
.52918 .43725 Mdot
.47531 .55438 Mdot
.54517 .4005 Mdot
.31319 .90666 Mdot
.64839 .17618 Mdot
.72555 .0126 Mdot
.28362 .9689 Mdot
.67377 .12317 Mdot
.42473 .66378 Mdot
.56746 .35355 Mdot
.34635 .83502 Mdot
.64363 .18769 Mdot
.28567 .96456 Mdot
.35414 .81659 Mdot
.34745 .83166 Mdot
.67052 .1283 Mdot
.42623 .66125 Mdot
.62213 .235 Mdot
.47658 .55017 Mdot
.69089 .08659 Mdot
.72002 .02259 Mdot
.61277 .25516 Mdot
.36621 .79058 Mdot
.30966 .91344 Mdot
.49087 .52009 Mdot
.45024 .60948 Mdot
.30398 .92616 Mdot
.55433 .38224 Mdot
.59831 .28526 Mdot
.37781 .76749 Mdot
.62065 .2378 Mdot
.48456 .53477 Mdot
.37811 .76554 Mdot
.69155 .08309 Mdot
.49152 .51831 Mdot
.51054 .47743 Mdot
.59934 .28226 Mdot
.37901 .76465 Mdot
.57727 .33072 Mdot
.70006 .06465 Mdot
.72168 .01862 Mdot
.28048 .97531 Mdot
.3849 .75113 Mdot
.65894 .15446 Mdot
.46284 .58094 Mdot
.62676 .22401 Mdot
.5829 .31886 Mdot
.41389 .68838 Mdot
.4495 .61016 Mdot
.70865 .04752 Mdot
.38147 .75855 Mdot
.58925 .30558 Mdot
.27806 .9822 Mdot
.66494 .14124 Mdot
.37586 .77063 Mdot
.50741 .48502 Mdot
.4678 .56986 Mdot
.71264 .03929 Mdot
.46083 .58427 Mdot
.60724 .26511 Mdot
.66245 .14721 Mdot
.28732 .96033 Mdot
.31217 .90866 Mdot
.64754 .17882 Mdot
.31047 .91205 Mdot
.45874 .59101 Mdot
.46854 .56819 Mdot
.49405 .51208 Mdot
.3142 .90384 Mdot
.39825 .7215 Mdot
.32149 .88859 Mdot
.37271 .77703 Mdot
.40692 .70197 Mdot
.63834 .19745 Mdot
.58173 .32025 Mdot
.27712 .98311 Mdot
.27972 .9771 Mdot
.56 .36769 Mdot
.53474 .42381 Mdot
.41176 .69323 Mdot
.49163 .51763 Mdot
.56719 .35398 Mdot
.47646 .55097 Mdot
.34831 .83144 Mdot
.27312 .99205 Mdot
.36269 .79889 Mdot
.40756 .70065 Mdot
.59992 .28299 Mdot
.35716 .81008 Mdot
.34381 .84022 Mdot
.38195 .75834 Mdot
.66879 .13216 Mdot
.37951 .76377 Mdot
.47662 .55211 Mdot
.42584 .66278 Mdot
.56827 .3498 Mdot
.4736 .55657 Mdot
.39007 .74105 Mdot
.27401 .99041 Mdot
.64898 .17535 Mdot
.61893 .24144 Mdot
.5495 .39129 Mdot
.61533 .24781 Mdot
.66974 .12956 Mdot
.32761 .87494 Mdot
.36144 .80051 Mdot
.55336 .38408 Mdot
.49058 .51988 Mdot
.38709 .74568 Mdot
.47233 .56056 Mdot
.43925 .63373 Mdot
.56668 .35354 Mdot
.72788 .00517 Mdot
.31178 .90976 Mdot
.5914 .30058 Mdot
.4913 .51876 Mdot
.46548 .57509 Mdot
.54163 .40981 Mdot
.7052 .05348 Mdot
.54839 .3949 Mdot
.675 .12032 Mdot
.63621 .20348 Mdot
.62199 .23313 Mdot
.43804 .6354 Mdot
.30635 .92058 Mdot
.3536 .81988 Mdot
.67408 .12244 Mdot
.69296 .0814 Mdot
.58234 .31948 Mdot
.65699 .15744 Mdot
.4564 .59657 Mdot
.7004 .06558 Mdot
.67721 .11443 Mdot
.32561 .87899 Mdot
.6167 .24414 Mdot
.52056 .45465 Mdot
.36617 .79272 Mdot
.44535 .61883 Mdot
.62933 .21824 Mdot
.46782 .5699 Mdot
.39314 .73318 Mdot
.62909 .22 Mdot
.30333 .92811 Mdot
.66156 .14892 Mdot
.57734 .33225 Mdot
.54214 .40916 Mdot
.6438 .18701 Mdot
.53152 .43164 Mdot
.65682 .15788 Mdot
.7264 .00834 Mdot
.29335 .94826 Mdot
.41294 .69004 Mdot
.71394 .03518 Mdot
.57306 .34048 Mdot
.60474 .27202 Mdot
.54319 .40502 Mdot
.32105 .88967 Mdot
.60266 .27624 Mdot
.49647 .50772 Mdot
.63801 .19825 Mdot
.5389 .41364 Mdot
.67344 .12346 Mdot
.52509 .44491 Mdot
.48267 .53899 Mdot
.2939 .9478 Mdot
.60138 .27836 Mdot
.45815 .59172 Mdot
.72057 .02194 Mdot
.29248 .94996 Mdot
.39664 .72524 Mdot
.65716 .15924 Mdot
.49497 .51052 Mdot
.72798 .00741 Mdot
.30911 .91554 Mdot
.39468 .7305 Mdot
.38097 .76079 Mdot
.51705 .46279 Mdot
.64062 .19285 Mdot
.50456 .49038 Mdot
.29674 .94186 Mdot
.43337 .6457 Mdot
.54823 .39445 Mdot
.69585 .07401 Mdot
.38951 .74019 Mdot
.52614 .44253 Mdot
.55532 .379 Mdot
.54091 .41033 Mdot
.36907 .78608 Mdot
.44657 .61674 Mdot
.66262 .14579 Mdot
.44087 .63044 Mdot
.67346 .12383 Mdot
.36987 .7834 Mdot
.48693 .52834 Mdot
.45969 .58943 Mdot
.4086 .69852 Mdot
.65156 .16871 Mdot
.55559 .3783 Mdot
.40464 .70838 Mdot
.4301 .65276 Mdot
.38708 .74567 Mdot
.46986 .56592 Mdot
.35387 .81895 Mdot
.36307 .79747 Mdot
.39534 .72775 Mdot
.55704 .37469 Mdot
.53979 .41373 Mdot
.63908 .19613 Mdot
.32509 .8797 Mdot
.44483 .62189 Mdot
.38269 .75621 Mdot
.58076 .3223 Mdot
.32324 .88434 Mdot
.38375 .75382 Mdot
.70378 .05865 Mdot
.59715 .28887 Mdot
.27973 .9766 Mdot
.59932 .2844 Mdot
.66812 .1342 Mdot
.49733 .50687 Mdot
.59692 .28823 Mdot
.55274 .38476 Mdot
.54053 .41223 Mdot
.28538 .96429 Mdot
.46304 .58001 Mdot
.60191 .27693 Mdot
.38308 .7553 Mdot
.41111 .69274 Mdot
.5663 .35397 Mdot
.33083 .8693 Mdot
.53878 .41627 Mdot
.60838 .26306 Mdot
.67526 .1191 Mdot
.43815 .6343 Mdot
.39494 .73006 Mdot
.27564 .9854 Mdot
.5308 .43316 Mdot
.51013 .47724 Mdot
.4744 .55499 Mdot
.31679 .89716 Mdot
.6853 .09783 Mdot
.48067 .54274 Mdot
.37161 .77932 Mdot
.68092 .10761 Mdot
.50053 .49878 Mdot
.56818 .35127 Mdot
.72746 .00802 Mdot
.37232 .77896 Mdot
.44754 .61392 Mdot
.71954 .02363 Mdot
.54498 .40091 Mdot
.34841 .83001 Mdot
.69248 .08213 Mdot
.28137 .97319 Mdot
.61436 .25141 Mdot
.66888 .13366 Mdot
.43998 .62977 Mdot
.70874 .04626 Mdot
.65607 .15903 Mdot
.27973 .97746 Mdot
.67231 .12476 Mdot
.3468 .8329 Mdot
.70224 .06043 Mdot
.64943 .17581 Mdot
.65336 .16541 Mdot
.55736 .37337 Mdot
.30376 .92488 Mdot
.40711 .70149 Mdot
.27172 .99347 Mdot
.5098 .47892 Mdot
.61874 .24059 Mdot
.64954 .17354 Mdot
.53214 .42986 Mdot
.3839 .75306 Mdot
.368 .78682 Mdot
.37851 .76377 Mdot
.342 .84253 Mdot
.45856 .5899 Mdot
.53739 .41711 Mdot
.64207 .18949 Mdot
.56078 .36623 Mdot
.56166 .36407 Mdot
.62563 .22557 Mdot
.46847 .56885 Mdot
.52629 .44386 Mdot
.46436 .57663 Mdot
.51483 .46701 Mdot
.32389 .8834 Mdot
.6991 .06843 Mdot
.63934 .19674 Mdot
.33505 .85788 Mdot
.5377 .41703 Mdot
.38188 .75819 Mdot
.55219 .38661 Mdot
.47712 .55018 Mdot
.50653 .48443 Mdot
.63981 .19561 Mdot
.40096 .71523 Mdot
.34948 .82913 Mdot
.52402 .44692 Mdot
.67671 .11654 Mdot
.65496 .16233 Mdot
.39271 .73348 Mdot
.67568 .11874 Mdot
.71157 .04187 Mdot
.69175 .08304 Mdot
.40328 .71061 Mdot
.54772 .39509 Mdot
.31416 .90375 Mdot
.648 .17889 Mdot
.36833 .78714 Mdot
.369 .78571 Mdot
.27904 .97822 Mdot
.68635 .09437 Mdot
.29665 .94265 Mdot
.61535 .24801 Mdot
.55921 .37017 Mdot
.37401 .7745 Mdot
.59408 .29523 Mdot
.57899 .32659 Mdot
.42218 .67106 Mdot
.31483 .90192 Mdot
.29171 .95044 Mdot
.27518 .98746 Mdot
.65104 .17145 Mdot
.58038 .32535 Mdot
.46876 .56762 Mdot
.70635 .05218 Mdot
.26999 .99837 Mdot
.52108 .45345 Mdot
.43859 .63393 Mdot
.69276 .08245 Mdot
.67007 .12939 Mdot
.4109 .69536 Mdot
.53368 .42579 Mdot
.69026 .086 Mdot
.61616 .24598 Mdot
.4688 .56947 Mdot
.31289 .90651 Mdot
.38699 .74644 Mdot
.29235 .95089 Mdot
.52451 .44571 Mdot
.45028 .60886 Mdot
.7007 .06531 Mdot
.38889 .74238 Mdot
.34552 .83747 Mdot
.34453 .83969 Mdot
.67996 .10812 Mdot
.45554 .59646 Mdot
.38549 .7505 Mdot
.63352 .21001 Mdot
.58356 .31653 Mdot
.44264 .62602 Mdot
.41403 .68854 Mdot
.58732 .31045 Mdot
.51708 .46376 Mdot
.46397 .57873 Mdot
.58169 .32191 Mdot
.72832 .00616 Mdot
.38392 .75356 Mdot
.677 .11497 Mdot
.57323 .33881 Mdot
.65723 .15866 Mdot
.46853 .56879 Mdot
.59978 .2836 Mdot
.46628 .57254 Mdot
.3921 .73443 Mdot
.50283 .49313 Mdot
.40525 .70808 Mdot
.46797 .56909 Mdot
.62733 .22112 Mdot
.58675 .31166 Mdot
.6483 .17696 Mdot
.43145 .64859 Mdot
.62422 .22842 Mdot
.63044 .21693 Mdot
.62453 .22851 Mdot
.49485 .51262 Mdot
.49284 .51669 Mdot
.67241 .12575 Mdot
.651 .1701 Mdot
.63724 .2022 Mdot
.47198 .5608 Mdot
.66764 .13423 Mdot
.4492 .60994 Mdot
.49453 .51294 Mdot
.30487 .9224 Mdot
.32731 .87414 Mdot
.49445 .51158 Mdot
.49545 .51131 Mdot
.48659 .5288 Mdot
.3233 .88495 Mdot
.71009 .04541 Mdot
.69159 .08432 Mdot
.41853 .67832 Mdot
.58222 .31927 Mdot
.70058 .0658 Mdot
.28436 .96717 Mdot
.5905 .30273 Mdot
.46317 .5792 Mdot
.46504 .57718 Mdot
.48515 .53174 Mdot
.57547 .33638 Mdot
.38319 .75553 Mdot
.65397 .16364 Mdot
.70372 .05674 Mdot
.31227 .9074 Mdot
.65847 .15616 Mdot
.35147 .8226 Mdot
.56342 .36109 Mdot
.65862 .15444 Mdot
.51549 .46479 Mdot
.40862 .70008 Mdot
.48726 .52867 Mdot
.45366 .60161 Mdot
.47825 .5487 Mdot
.43605 .63996 Mdot
.63734 .20041 Mdot
.37039 .7832 Mdot
.5647 .35869 Mdot
.54401 .40516 Mdot
.35417 .81771 Mdot
.63137 .21233 Mdot
.67459 .12035 Mdot
.70983 .04461 Mdot
.53849 .41615 Mdot
.63244 .21126 Mdot
.71926 .02487 Mdot
.48469 .53421 Mdot
.36049 .8044 Mdot
.42248 .66821 Mdot
.71152 .04152 Mdot
.51914 .45887 Mdot
.38863 .74317 Mdot
.50605 .48798 Mdot
.45957 .58961 Mdot
.55387 .38128 Mdot
.34664 .83419 Mdot
.58996 .30255 Mdot
.52171 .4529 Mdot
.4364 .63992 Mdot
.648 .17789 Mdot
.2759 .98505 Mdot
.47565 .55244 Mdot
.45451 .59899 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Y_ooool3o`0007Oooooo002Uooooo`05o`000?ooooooooooooooool00000M_ooool00:Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1cooooo`00YOooool6o`0007Gooooo
002Vooooo`05o`000?ooooooooooooooool00000MOooool00:Oooooo0ol0001fooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00@_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`000003ooooool0003o000000?o00000_ooool3o`0000Oooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0ol00002ooooo`?o00001oooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Wooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000:ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
0_ooool5o`0000;ooooo0ol00006ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
0oooool3o`0000Oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Booooo`00@Oooool01?l0003oooooooooool0000:ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00002_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool03oooool0047ooooo00Co0000oooooooooooo00001oooool5o`0000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00005
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool0000;ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo0011
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`00@Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000000;ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Kooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000002ooooo`Co00001_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000000ol00008oooo
o`04o`000?ooooooooooo`0000Oooooo1?l00009ooooo`04o`000?ooooooooooo`0000Oooooo1?l0
0002ooooo`06o`000?ooooooooooooooool0003ooooo1?l00005ooooo`04o`000?ooooooooooo`00
00Oooooo1?l00002ooooo`Co00001_ooool01?l0003oooooooooool00007ooooo`Co00001_ooool0
0ol0003oooooo`000003o`0001;ooooo0011ooooo`04o`000?ooooooooooo`0000Wooooo0_l00002
ooooo`07o`000?ooooooooooooooool0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00002ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002Oooool2o`00
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool00oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
01Gooooo0012ooooo`;o00002oooool01?l0003oooooooooooooool3o`0000;ooooo1Ol00006oooo
o`;o00002oooool00ol0003oooooooooo`05o`0000Kooooo0_l0000;ooooo`03o`000?oooooooooo
00Go000000?oooooo`000?l000000ol00008ooooo`;o00002?ooool5o`0000Wooooo0_l00008oooo
o`Go00000_ooool3o`0000;ooooo1Ol00005ooooo`;o00002?ooool5o`000003ooooool0003o0000
00?o00001_ooool2o`0000Sooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00?o00004Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
03;ooooo[@0000000`3o000000000000000k0000007o00000@000001ooooo`00<_ooool00`00003o
ooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00`3o003o
ooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool10000007o
oooo000booooo`0300000?oooooooooo0:Wooooo00<0o`00ooooooooool0?Oooool10000007ooooo
000booooo`0300000?oooooooooo0:Sooooo00<0o`00ooooooooool0?_ooool10000007ooooo000b
ooooo`0300000?oooooooooo0:Sooooo00<0o`00ooooooooool0?_ooool10000007ooooo000boooo
o`0300000?l0003ooooo0:Oooooo00<0o`00ooooooooool0?_ooool1o`00004000000Oooool003;o
oooo00<00000ooooooooool0Yoooool00`3o003oooooooooo`0oooooo`4000000Oooool003;ooooo
00<00000ooooooooool0Y_ooool00`3o003oooooooooo`10ooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0Y_ooool00`3o003oooooooooo`10ooooo`4000000Oooool003;ooooo00<00000
ooooooooool0YOooool00`3o003oooooooooo`11ooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0YOooool00`3o003oooooooooo`11ooooo`4000000Oooool003;ooooo00<00000o`000?oo
ool0Y?ooool00`3o003oooooooooo`11ooooo`7o00000@000001ooooo`00<_ooool00`00003ooooo
ooooo`2Tooooo`030?l00?oooooooooo04;ooooo0@000001ooooo`00<_ooool00`00003ooooooooo
o`2Sooooo`030?l00?oooooooooo04?ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2S
ooooo`030?l00?oooooooooo04?ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2Roooo
o`80o`00AOooool10000007ooooo000booooo`0300000?oooooooooo0:;ooooo00<0o`00oooooooo
ool0A?ooool10000007ooooo000booooo`0300000?l0003ooooo0:7ooooo00<0o`00ooooooooool0
A?ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000b
ooooo`0300000?oooooooooo0:3ooooo0P3o0017ooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0X?ooool00`3o003oooooooooo`16ooooo`4000000Oooool003;ooooo00<00000oooooooo
ool0jOooool10000007ooooo000booooo`0300000?oooooooooo09oooooo00<0o`00ooooooooool0
Aoooool10000007ooooo000booooo`0300000?l0003ooooo09oooooo00<0o`00ooooooooool0A_oo
ool1o`00004000000Oooool003;ooooo00<00000ooooooooool0W_ooool00`3o003oooooooooo`18
ooooo`4000000Oooool003;ooooo00<00000ooooooooool0W_ooool00`3o003oooooooooo`18oooo
o`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000Cooooo`;o0000
1?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00`00003oooooooooo`2Mooooo`030?l00?oooooooooo04Wooooo0@000001ooooo`004_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0W?ooool20?l0
04_ooooo0@000001ooooo`002oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0`00003o0000ooooo`2Looooo`030?l00?oooooooooo04Wooooo0Ol000010000007ooooo000Boooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0Voooool00`3o003ooooooooo
o`1;ooooo`4000000Oooool001;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooo000000?o00001Oooool00`00003oooooooooo`2Kooooo`030?l0
0?oooooooooo04_ooooo0@000001ooooo`004_ooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`0300000?oooooooooo
09_ooooo00<0o`00ooooooooool0Boooool10000007ooooo000Cooooo`;o00002_ooool2o`0000;o
oooo1Ol000000ooooooo0000o`000003o`0000Cooooo00<00000ooooooooool0V_ooool00`3o003o
ooooooooo`1<ooooo`4000000Oooool003;ooooo00<00000ooooooooool0V_ooool00`3o003ooooo
ooooo`1<ooooo`4000000Oooool003;ooooo00<00000o`000?ooool0VOooool00`3o003ooooooooo
o`1<ooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`2Iooooo`030?l00?oooooo
oooo04gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2Hooooo`80o`00Coooool10000
007ooooo000booooo`0300000?oooooooooo09Oooooo0P3o001@ooooo`4000000Oooool003;ooooo
00<00000ooooooooool0Uoooool00`3o003oooooooooo`1?ooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0Uoooool00`3o003oooooooooo`1?ooooo`4000000Oooool003;ooooo00<00000
o`000?ooool0U_ooool00`3o003oooooooooo`1?ooooo`7o00000@000001ooooo`00<_ooool00`00
003oooooooooo`2Fooooo`030?l00?oooooooooo053ooooo0@000001ooooo`00<_ooool00`00003o
ooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000ooooooooool0UOooool00`3o003ooooo
ooooo`1Aooooo`4000000Oooool003;ooooo00<00000ooooooooool0U?ooool20?l005?ooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`2Dooooo`030?l00?oooooooooo05;ooooo0@000001
ooooo`00<_ooool00`00003o0000ooooo`2Dooooo`030?l00?oooooooooo057ooooo0Ol000010000
007ooooo000booooo`0300000?oooooooooo09?ooooo00<0o`00ooooooooool0Doooool10000007o
oooo000booooo`0300000?oooooooooo09?ooooo00<0o`00ooooooooool0Doooool10000007ooooo
000booooo`0300000?oooooooooo09;ooooo00<0o`00ooooooooool0E?ooool10000007ooooo000b
ooooo`0300000?oooooooooo09;ooooo00<0o`00ooooooooool0E?ooool10000007ooooo000boooo
o`0300000?oooooooooo097ooooo0P3o001Fooooo`4000000Oooool003;ooooo00<00000o`000?oo
ool0TOooool00`3o003oooooooooo`1Dooooo`7o00000@000001ooooo`00<_ooool00`00003ooooo
ooooo`2@ooooo`80o`00Eoooool10000007ooooo000booooo`0300000?oooooooooo093ooooo00<0
o`00ooooooooool0E_ooool10000007ooooo000Iooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`;o00000oooool3o`0000Gooooo00<00000ooooooooool0Soooool20?l005Sooooo0@000001
ooooo`006?ooool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo08oooooo00<0o`00ooooooooool0
Eoooool10000007ooooo000Aooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`2>ooooo`80
o`00FOooool10000007ooooo000Hooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`02ooooo`0300000?l0003ooooo08kooooo00<0o`00oooo
ooooool0Eoooool1o`00004000000Oooool001Sooooo00Co0000oooooooooooo00002?ooool01Ol0
003oooooooooool0003ooooo00Co00001Oooool00`00003oooooooooo`2=ooooo`80o`00F_ooool1
0000007ooooo000Hooooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000oooo
ool00008ooooo`0300000?oooooooooo08gooooo00<0o`00ooooooooool0FOooool10000007ooooo
000Iooooo`;o00002_ooool2o`0000;ooooo1Ol00004ooooo`0300000?oooooooooo08cooooo0P3o
001Kooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000boooo
o`0300000?oooooooooo08cooooo00<0o`00ooooooooool0F_ooool10000007ooooo000booooo`03
00000?l0003ooooo08_ooooo00<0o`00ooooooooool0F_ooool1o`00004000000Oooool003;ooooo
00<00000ooooooooool0Roooool00`3o003oooooooooo`1Kooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0R_ooool20?l005gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2:
ooooo`030?l00?oooooooooo05cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`29oooo
o`030?l00?oooooooooo05gooooo0@000001ooooo`00<_ooool00`00003o0000ooooo`3Xooooo`7o
00000@000001ooooo`00<_ooool00`00003oooooooooo`28ooooo`80o`00Goooool10000007ooooo
000booooo`0300000?oooooooooo08Sooooo00<0o`00ooooooooool0G_ooool10000007ooooo000b
ooooo`0300000?oooooooooo08Sooooo00<0o`00ooooooooool0G_ooool10000007ooooo000boooo
o`0300000?oooooooooo08Oooooo00<0o`00ooooooooool0Goooool10000007ooooo000booooo`03
00000?oooooooooo08Kooooo0P3o001Qooooo`4000000Oooool003;ooooo00<00000o`000?ooool0
Q_ooool00`3o003oooooooooo`1Oooooo`7o00000@000001ooooo`00<_ooool00`00003ooooooooo
o`26ooooo`030?l00?oooooooooo063ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`25
ooooo`80o`00H_ooool10000007ooooo000booooo`0300000?oooooooooo08Gooooo00<0o`00oooo
ooooool0HOooool10000007ooooo000booooo`0300000?oooooooooo08Cooooo00<0o`00oooooooo
ool0H_ooool10000007ooooo000booooo`0300000?oooooooooo08Cooooo00<0o`00ooooooooool0
H_ooool10000007ooooo000booooo`0300000?l0003ooooo08?ooooo00<0o`00ooooooooool0H_oo
ool1o`00004000000Oooool003;ooooo00<00000ooooooooool0Poooool00`3o003oooooooooo`1S
ooooo`4000000Oooool003;ooooo00<00000ooooooooool0P_ooool00`3o003oooooooooo`1Toooo
o`4000000Oooool003;ooooo00<00000ooooooooool0P_ooool00`3o003oooooooooo`1Tooooo`40
00000Oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go0000
0_ooool3o`0000Gooooo00<00000ooooooooool0POooool20?l006Kooooo0@000001ooooo`004_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Ko0000oooooooo
oooo0000ooooool00003ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0POooool0
0`3o003oooooooooo`1Uooooo`4000000Oooool000_ooooo1Ol00002ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00<00000o`000?ooool0POooool00`3o003oooooooooo`1Tooooo`7o00000@00
0001ooooo`004_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo083ooooo
00<0o`00ooooooooool0I_ooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool00`00
003oooooooooo`20ooooo`030?l00?oooooooooo06Kooooo0@000001ooooo`004_ooool01?l0003o
ooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`00
0008ooooo`0300000?oooooooooo07oooooo0P3o001Xooooo`4000000Oooool001?ooooo0_l0000:
ooooo`;o00000oooool3o`0000;ooooo1Ol00004ooooo`0300000?oooooooooo07oooooo00<0o`00
ooooooooool0Ioooool10000007ooooo000booooo`0300000?oooooooooo07kooooo0P3o001Yoooo
o`4000000Oooool003;ooooo00<00000o`000?ooool0O_ooool00`3o003oooooooooo`1Wooooo`7o
00000@000001ooooo`00<_ooool00`00003oooooooooo`1mooooo`030?l00?oooooooooo06Wooooo
0@000001ooooo`00<_ooool00`00003oooooooooo`1mooooo`030?l00?oooooooooo06Wooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`1looooo`80o`00Joooool10000007ooooo000boooo
o`0300000?oooooooooo07cooooo00<0o`00ooooooooool0J_ooool10000007ooooo000booooo`03
00000?oooooooooo07cooooo00<0o`00ooooooooool0J_ooool10000007ooooo000booooo`030000
0?l0003ooooo07_ooooo00<0o`00ooooooooool0J_ooool1o`00004000000Oooool003;ooooo00<0
0000ooooooooool0Noooool00`3o003oooooooooo`1[ooooo`4000000Oooool003;ooooo00<00000
ooooooooool0N_ooool20?l006gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1joooo
o`030?l00?oooooooooo06cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1iooooo`03
0?l00?oooooooooo06gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1iooooo`030?l0
0?oooooooooo06gooooo0@000001ooooo`00<_ooool00`00003o0000ooooo`1hooooo`030?l00?oo
oooooooo06gooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo07Sooooo00<0o`00
ooooooooool0K_ooool10000007ooooo000booooo`0300000?oooooooooo07Sooooo00<0o`00oooo
ooooool0K_ooool10000007ooooo000booooo`0300000?oooooooooo07Oooooo00<0o`00oooooooo
ool0Koooool10000007ooooo000booooo`0300000?oooooooooo07Oooooo00<0o`00ooooooooool0
Koooool10000007ooooo000booooo`0300000?oooooooooo0>Wooooo0@000001ooooo`00<_ooool0
0`00003o0000ooooo`1eooooo`80o`00LOooool1o`00004000000Oooool003;ooooo00<00000oooo
ooooool0MOooool00`3o003oooooooooo`1aooooo`4000000Oooool003;ooooo00<00000oooooooo
ool0MOooool00`3o003oooooooooo`1aooooo`4000000Oooool002_ooooo0_l00005ooooo`030000
0?oooooooooo07Gooooo00<0o`00ooooooooool0LOooool10000007ooooo0002ooooo`?o00009Ooo
ool01?l0003oooooooooool00004ooooo`0300000?oooooooooo07Cooooo00<0o`00ooooooooool0
L_ooool10000007ooooo0003ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo0000
1?ooool00`00003oooooooooo`1cooooo`030?l00?oooooooooo07?ooooo0@000001ooooo`000ooo
ool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000?ooool0
j?ooool1o`00004000000Oooool000?ooooo0_l0000Uooooo`04o`000?ooooooooooo`0000Cooooo
00<00000ooooooooool0L_ooool00`3o003oooooooooo`1dooooo`4000000Oooool000;ooooo0_l0
00000ooooooo0000o`00000Sooooo`04o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0
L_ooool00`3o003oooooooooo`1dooooo`4000000Oooool002_ooooo0_l00005ooooo`0300000?oo
oooooooo07;ooooo00<0o`00ooooooooool0M?ooool10000007ooooo000booooo`0300000?oooooo
oooo077ooooo00<0o`00ooooooooool0MOooool10000007ooooo000booooo`0300000?oooooooooo
077ooooo00<0o`00ooooooooool0MOooool10000007ooooo000booooo`0300000?l0003ooooo073o
oooo00<0o`00ooooooooool0MOooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0
L?ooool00`3o003oooooooooo`1fooooo`4000000Oooool003;ooooo00<00000ooooooooool0Kooo
ool20?l007Sooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1_ooooo`030?l00?oooooo
oooo07Oooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1^ooooo`80o`00NOooool10000
007ooooo000booooo`0300000?oooooooooo06kooooo00<0o`00ooooooooool0N?ooool10000007o
oooo000booooo`0300000?l0003ooooo06gooooo0P3o001iooooo`7o00000@000001ooooo`00<_oo
ool00`00003oooooooooo`1]ooooo`030?l00?oooooooooo07Wooooo0@000001ooooo`00<_ooool0
0`00003oooooooooo`1/ooooo`80o`00Noooool10000007ooooo000booooo`0300000?oooooooooo
06cooooo00<0o`00ooooooooool0N_ooool10000007ooooo000booooo`0300000?oooooooooo06_o
oooo0P3o001looooo`4000000Oooool003;ooooo00<00000o`000?ooool0Joooool00`3o003ooooo
ooooo`1jooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`1[ooooo`030?l00?oo
oooooooo07_ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Zooooo`030?l00?oooooo
oooo07cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Zooooo`030?l00?oooooooooo
07cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Yooooo`80o`00O_ooool10000007o
oooo000booooo`0300000?oooooooooo0>Wooooo0@000001ooooo`00<_ooool00`00003o0000oooo
o`1Xooooo`80o`00O_ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0J?ooool0
0`3o003oooooooooo`1nooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000
007ooooo000booooo`0300000?oooooooooo06Oooooo00<0o`00ooooooooool0Ooooool10000007o
oooo000Cooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool5o`0000;ooooo
0ol00005ooooo`0300000?oooooooooo06Kooooo0P3o0021ooooo`4000000Oooool001;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo06Kooooo00<0o`00
ooooooooool0P?ooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00<0
0000o`000?ooool0I_ooool00`3o003oooooooooo`1oooooo`7o00000@000001ooooo`004_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo06Gooooo0P3o0022ooooo`400000
0Oooool001;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`00
00?ooooo00?o0000ooooool000000ol00005ooooo`0300000?oooooooooo06Gooooo00<0o`00oooo
ooooool0POooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooo000000Sooooo00<00000ooooooooool0I?oo
ool00`3o003oooooooooo`22ooooo`4000000Oooool001?ooooo0_l0000:ooooo`;o00000oooool3
o`0000;ooooo1Ol00004ooooo`0300000?oooooooooo06Cooooo00<0o`00ooooooooool0P_ooool1
0000007ooooo000booooo`0300000?oooooooooo06?ooooo00<0o`00ooooooooool0Poooool10000
007ooooo000booooo`0300000?l0003ooooo06?ooooo00<0o`00ooooooooool0P_ooool1o`000040
00000Oooool003;ooooo00<00000ooooooooool0H_ooool20?l008Gooooo0@000001ooooo`00<_oo
ool00`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000ooooooooool0H_ooool0
0`3o003oooooooooo`24ooooo`4000000Oooool003;ooooo00<00000ooooooooool0HOooool00`3o
003oooooooooo`25ooooo`4000000Oooool003;ooooo00<00000ooooooooool0HOooool00`3o003o
ooooooooo`25ooooo`4000000Oooool003;ooooo00<00000o`000?ooool0j?ooool1o`0000400000
0Oooool003;ooooo00<00000ooooooooool0H?ooool00`3o003oooooooooo`26ooooo`4000000Ooo
ool003;ooooo00<00000ooooooooool0Goooool00`3o003oooooooooo`27ooooo`4000000Oooool0
03;ooooo00<00000ooooooooool0Goooool00`3o003oooooooooo`27ooooo`4000000Oooool003;o
oooo00<00000ooooooooool0G_ooool20?l008Wooooo0@000001ooooo`00<_ooool00`00003ooooo
ooooo`1Nooooo`030?l00?oooooooooo08Sooooo0@000001ooooo`00<_ooool00`00003o0000oooo
o`1Mooooo`030?l00?oooooooooo08Sooooo0Ol000010000007ooooo000booooo`0300000?oooooo
oooo05gooooo00<0o`00ooooooooool0ROooool10000007ooooo000booooo`0300000?oooooooooo
05gooooo00<0o`00ooooooooool0ROooool10000007ooooo000booooo`0300000?oooooooooo05co
oooo00<0o`00ooooooooool0R_ooool10000007ooooo000booooo`0300000?oooooooooo05cooooo
00<0o`00ooooooooool0R_ooool10000007ooooo000booooo`0300000?oooooooooo05_ooooo00<0
o`00ooooooooool0Roooool10000007ooooo000booooo`0300000?l0003ooooo05_ooooo00<0o`00
ooooooooool0R_ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0F_ooool00`3o
003oooooooooo`2<ooooo`4000000Oooool003;ooooo00<00000ooooooooool0F_ooool00`3o003o
ooooooooo`2<ooooo`4000000Oooool001Wooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo
0_l00003ooooo`?o00001Oooool00`00003oooooooooo`3Yooooo`4000000Oooool001Sooooo00Co
0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooo
ooooool00_ooool00`00003oooooooooo`1Iooooo`030?l00?oooooooooo08gooooo0@000001oooo
o`006?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool00_ooool00`00003oooooooooo`1Hooooo`030?l00?oooooooooo08kooooo0@000001
ooooo`006?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool00_ooool00`00003o0000ooooo`1Hooooo`030?l00?oooooooooo08gooooo0Ol0
00010000007ooooo000Hooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo0000
ooooo`04o`0000Gooooo00<00000ooooooooool0Eoooool20?l0093ooooo0@000001ooooo`006?oo
ool01?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00`00
003oooooooooo`1Gooooo`030?l00?oooooooooo08oooooo0@000001ooooo`006Oooool2o`0000[o
oooo0_l00002ooooo`Go00001?ooool00`00003oooooooooo`1Fooooo`80o`00TOooool10000007o
oooo000booooo`0300000?oooooooooo05Kooooo00<0o`00ooooooooool0T?ooool10000007ooooo
000booooo`0300000?oooooooooo05Gooooo0P3o002Booooo`4000000Oooool003;ooooo00<00000
o`000?ooool0EOooool00`3o003oooooooooo`2@ooooo`7o00000@000001ooooo`00<_ooool00`00
003oooooooooo`1Eooooo`030?l00?oooooooooo097ooooo0@000001ooooo`00<_ooool00`00003o
ooooooooo`1Dooooo`030?l00?oooooooooo09;ooooo0@000001ooooo`00<_ooool00`00003ooooo
ooooo`1Cooooo`80o`00U?ooool10000007ooooo000booooo`0300000?oooooooooo05?ooooo00<0
o`00ooooooooool0Toooool10000007ooooo000booooo`0300000?oooooooooo05?ooooo00<0o`00
ooooooooool0Toooool10000007ooooo000booooo`0300000?l0003ooooo05;ooooo00<0o`00oooo
ooooool0Toooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0D_ooool00`3o003o
ooooooooo`2Dooooo`4000000Oooool003;ooooo00<00000ooooooooool0DOooool00`3o003ooooo
ooooo`2Eooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000b
ooooo`0300000?oooooooooo053ooooo0P3o002Gooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0D?ooool00`3o003oooooooooo`2Fooooo`4000000Oooool003;ooooo00<00000o`000?oo
ool0Coooool00`3o003oooooooooo`2Fooooo`7o00000@000001ooooo`00<_ooool00`00003ooooo
ooooo`1?ooooo`80o`00V?ooool10000007ooooo000booooo`0300000?oooooooooo04oooooo00<0
o`00ooooooooool0Uoooool10000007ooooo000booooo`0300000?oooooooooo04kooooo0P3o002I
ooooo`4000000Oooool003;ooooo00<00000ooooooooool0C_ooool00`3o003oooooooooo`2Hoooo
o`4000000Oooool003;ooooo00<00000o`000?ooool0j?ooool1o`00004000000Oooool003;ooooo
00<00000ooooooooool0COooool00`3o003oooooooooo`2Iooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0C?ooool00`3o003oooooooooo`2Jooooo`4000000Oooool003;ooooo00<00000
ooooooooool0jOooool10000007ooooo000Cooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00`00003oooooooooo`1;oooo
o`030?l00?oooooooooo09_ooooo0@000001ooooo`004_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00<00000ooooooooool0Boooool00`3o003oooooooooo`2Kooooo`4000000Ooo
ool001;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00`00003o0000ooooo`1:ooooo`030?l0
0?oooooooooo09_ooooo0Ol000010000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00<00000ooooooooool0B_ooool00`3o003oooooooooo`2Looooo`4000000Oooool001;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooo0000
00?o00001Oooool00`00003oooooooooo`19ooooo`80o`00W_ooool10000007ooooo000Booooo`04
o`000?ooooooooooo`0000Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooo000000Sooooo00<00000ooooooooool0BOooool00`3o003oooooooooo`2Mooooo`4000000Ooo
ool001?ooooo0_l0000:ooooo`;o00000_ooool5o`000003ooooool0003o000000?o00001?ooool0
0`00003oooooooooo`19ooooo`030?l00?oooooooooo09gooooo0@000001ooooo`00<_ooool00`00
003oooooooooo`18ooooo`030?l00?oooooooooo09kooooo0@000001ooooo`00<_ooool00`00003o
0000ooooo`18ooooo`030?l00?oooooooooo09gooooo0Ol000010000007ooooo000booooo`030000
0?oooooooooo04Oooooo00<0o`00ooooooooool0Woooool10000007ooooo000booooo`0300000?oo
oooooooo04Oooooo00<0o`00ooooooooool0Woooool10000007ooooo000booooo`0300000?oooooo
oooo04Kooooo0P3o002Qooooo`4000000Oooool003;ooooo00<00000ooooooooool0A_ooool00`3o
003oooooooooo`2Pooooo`4000000Oooool003;ooooo00<00000ooooooooool0AOooool00`3o003o
ooooooooo`2Qooooo`4000000Oooool003;ooooo00<00000o`000?ooool0AOooool00`3o003ooooo
ooooo`2Pooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`15ooooo`030?l00?oo
oooooooo0:7ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`14ooooo`030?l00?oooooo
oooo0:;ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`14ooooo`030?l00?oooooooooo
0:;ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`13ooooo`030?l00?oooooooooo0:?o
oooo0@000001ooooo`00<_ooool00`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<0
0000o`000?ooool0@_ooool20?l00:Cooooo0Ol000010000007ooooo000booooo`0300000?oooooo
oooo0>Wooooo0@000001ooooo`00<_ooool00`00003oooooooooo`3Yooooo`4000000Oooool003;o
oooo00<00000ooooooooool0@Oooool00`3o003oooooooooo`2Uooooo`4000000Oooool003;ooooo
00<00000ooooooooool0@?ooool00`3o003oooooooooo`2Vooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0@?ooool00`3o003oooooooooo`2Vooooo`4000000Oooool003;ooooo00<00000
o`000?ooool0?oooool00`3o003oooooooooo`2Vooooo`7o00000@000001ooooo`00<_ooool00`00
003oooooooooo`0oooooo`030?l00?oooooooooo0:Oooooo0@000001ooooo`00<_ooool00`00003o
ooooooooo`0nooooo`80o`00ZOooool10000007ooooo000Oooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`?o00001Oooool00`00003oooooooooo`0nooooo`030?l00?oooooooooo0:Sooooo
0@000001ooooo`007_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo
00<00000ooooooooool06_ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo00;ooooo
0P3o000Gooooo`0300000?oooooooooo01[ooooo00<00000ooooooooool06oooool00`00003ooooo
ooooo`0Jooooo`0300000?oooooooooo01_ooooo00<00000ooooooooool06_ooool10000007ooooo
000Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool00`00003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00`00003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`0300000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00`00003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00<00000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`4000000Oooool001kooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`04oooood00000000<0o`00000000000000ZP000001ooooo`007_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo0?;ooooo000Nooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003dooooo`007oooool2o`0000[ooooo00?o0000ooooooooool0l_ooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
0?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 302.812}, {523.188, 293.812}} -> {0.279553, \
0.181383, 0.000846872, 0.000846872}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2 5 0.5 5 [
[.125 -0.0125 -15 -9 ]
[.125 -0.0125 15 0 ]
[.25 -0.0125 -12 -9 ]
[.25 -0.0125 12 0 ]
[.375 -0.0125 -15 -9 ]
[.375 -0.0125 15 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.625 -0.0125 -15 -9 ]
[.625 -0.0125 15 0 ]
[.75 -0.0125 -12 -9 ]
[.75 -0.0125 12 0 ]
[.875 -0.0125 -15 -9 ]
[.875 -0.0125 15 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .125 -36 -4.5 ]
[-0.0125 .125 0 4.5 ]
[-0.0125 .25 -30 -4.5 ]
[-0.0125 .25 0 4.5 ]
[-0.0125 .375 -36 -4.5 ]
[-0.0125 .375 0 4.5 ]
[-0.0125 .5 -6 -4.5 ]
[-0.0125 .5 0 4.5 ]
[-0.0125 .625 -30 -4.5 ]
[-0.0125 .625 0 4.5 ]
[-0.0125 .75 -24 -4.5 ]
[-0.0125 .75 0 4.5 ]
[-0.0125 .875 -30 -4.5 ]
[-0.0125 .875 0 4.5 ]
[-0.0125 1 -18 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -46 -6 ]
[-0.01875 .5 -36 6 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.125 0 m
.125 .00625 L
s
[(0.425)] .125 -0.0125 0 1 Mshowa
.25 0 m
.25 .00625 L
s
[(0.45)] .25 -0.0125 0 1 Mshowa
.375 0 m
.375 .00625 L
s
[(0.475)] .375 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.625 0 m
.625 .00625 L
s
[(0.525)] .625 -0.0125 0 1 Mshowa
.75 0 m
.75 .00625 L
s
[(0.55)] .75 -0.0125 0 1 Mshowa
.875 0 m
.875 .00625 L
s
[(0.575)] .875 -0.0125 0 1 Mshowa
.125 Mabswid
.025 0 m
.025 .00375 L
s
.05 0 m
.05 .00375 L
s
.075 0 m
.075 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.175 0 m
.175 .00375 L
s
.2 0 m
.2 .00375 L
s
.225 0 m
.225 .00375 L
s
.275 0 m
.275 .00375 L
s
.3 0 m
.3 .00375 L
s
.325 0 m
.325 .00375 L
s
.35 0 m
.35 .00375 L
s
.4 0 m
.4 .00375 L
s
.425 0 m
.425 .00375 L
s
.45 0 m
.45 .00375 L
s
.475 0 m
.475 .00375 L
s
.525 0 m
.525 .00375 L
s
.55 0 m
.55 .00375 L
s
.575 0 m
.575 .00375 L
s
.6 0 m
.6 .00375 L
s
.65 0 m
.65 .00375 L
s
.675 0 m
.675 .00375 L
s
.7 0 m
.7 .00375 L
s
.725 0 m
.725 .00375 L
s
.775 0 m
.775 .00375 L
s
.8 0 m
.8 .00375 L
s
.825 0 m
.825 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.925 0 m
.925 .00375 L
s
.95 0 m
.95 .00375 L
s
.975 0 m
.975 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .125 m
.00625 .125 L
s
[(-0.075)] -0.0125 .125 1 0 Mshowa
0 .25 m
.00625 .25 L
s
[(-0.05)] -0.0125 .25 1 0 Mshowa
0 .375 m
.00625 .375 L
s
[(-0.025)] -0.0125 .375 1 0 Mshowa
0 .5 m
.00625 .5 L
s
[(0)] -0.0125 .5 1 0 Mshowa
0 .625 m
.00625 .625 L
s
[(0.025)] -0.0125 .625 1 0 Mshowa
0 .75 m
.00625 .75 L
s
[(0.05)] -0.0125 .75 1 0 Mshowa
0 .875 m
.00625 .875 L
s
[(0.075)] -0.0125 .875 1 0 Mshowa
0 1 m
.00625 1 L
s
[(0.1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .025 m
.00375 .025 L
s
0 .05 m
.00375 .05 L
s
0 .075 m
.00375 .075 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .175 m
.00375 .175 L
s
0 .2 m
.00375 .2 L
s
0 .225 m
.00375 .225 L
s
0 .275 m
.00375 .275 L
s
0 .3 m
.00375 .3 L
s
0 .325 m
.00375 .325 L
s
0 .35 m
.00375 .35 L
s
0 .4 m
.00375 .4 L
s
0 .425 m
.00375 .425 L
s
0 .45 m
.00375 .45 L
s
0 .475 m
.00375 .475 L
s
0 .525 m
.00375 .525 L
s
0 .55 m
.00375 .55 L
s
0 .575 m
.00375 .575 L
s
0 .6 m
.00375 .6 L
s
0 .65 m
.00375 .65 L
s
0 .675 m
.00375 .675 L
s
0 .7 m
.00375 .7 L
s
0 .725 m
.00375 .725 L
s
0 .775 m
.00375 .775 L
s
0 .8 m
.00375 .8 L
s
0 .825 m
.00375 .825 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .925 m
.00375 .925 L
s
0 .95 m
.00375 .95 L
s
0 .975 m
.00375 .975 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .99375 m
0 1 L
s
.125 .99375 m
.125 1 L
s
.25 .99375 m
.25 1 L
s
.375 .99375 m
.375 1 L
s
.5 .99375 m
.5 1 L
s
.625 .99375 m
.625 1 L
s
.75 .99375 m
.75 1 L
s
.875 .99375 m
.875 1 L
s
.125 Mabswid
.025 .99625 m
.025 1 L
s
.05 .99625 m
.05 1 L
s
.075 .99625 m
.075 1 L
s
.1 .99625 m
.1 1 L
s
.15 .99625 m
.15 1 L
s
.175 .99625 m
.175 1 L
s
.2 .99625 m
.2 1 L
s
.225 .99625 m
.225 1 L
s
.275 .99625 m
.275 1 L
s
.3 .99625 m
.3 1 L
s
.325 .99625 m
.325 1 L
s
.35 .99625 m
.35 1 L
s
.4 .99625 m
.4 1 L
s
.425 .99625 m
.425 1 L
s
.45 .99625 m
.45 1 L
s
.475 .99625 m
.475 1 L
s
.525 .99625 m
.525 1 L
s
.55 .99625 m
.55 1 L
s
.575 .99625 m
.575 1 L
s
.6 .99625 m
.6 1 L
s
.65 .99625 m
.65 1 L
s
.675 .99625 m
.675 1 L
s
.7 .99625 m
.7 1 L
s
.725 .99625 m
.725 1 L
s
.775 .99625 m
.775 1 L
s
.8 .99625 m
.8 1 L
s
.825 .99625 m
.825 1 L
s
.85 .99625 m
.85 1 L
s
.9 .99625 m
.9 1 L
s
.925 .99625 m
.925 1 L
s
.95 .99625 m
.95 1 L
s
.975 .99625 m
.975 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 0 m
1 0 L
s
.99375 .125 m
1 .125 L
s
.99375 .25 m
1 .25 L
s
.99375 .375 m
1 .375 L
s
.99375 .5 m
1 .5 L
s
.99375 .625 m
1 .625 L
s
.99375 .75 m
1 .75 L
s
.99375 .875 m
1 .875 L
s
.125 Mabswid
.99625 .025 m
1 .025 L
s
.99625 .05 m
1 .05 L
s
.99625 .075 m
1 .075 L
s
.99625 .1 m
1 .1 L
s
.99625 .15 m
1 .15 L
s
.99625 .175 m
1 .175 L
s
.99625 .2 m
1 .2 L
s
.99625 .225 m
1 .225 L
s
.99625 .275 m
1 .275 L
s
.99625 .3 m
1 .3 L
s
.99625 .325 m
1 .325 L
s
.99625 .35 m
1 .35 L
s
.99625 .4 m
1 .4 L
s
.99625 .425 m
1 .425 L
s
.99625 .45 m
1 .45 L
s
.99625 .475 m
1 .475 L
s
.99625 .525 m
1 .525 L
s
.99625 .55 m
1 .55 L
s
.99625 .575 m
1 .575 L
s
.99625 .6 m
1 .6 L
s
.99625 .65 m
1 .65 L
s
.99625 .675 m
1 .675 L
s
.99625 .7 m
1 .7 L
s
.99625 .725 m
1 .725 L
s
.99625 .775 m
1 .775 L
s
.99625 .8 m
1 .8 L
s
.99625 .825 m
1 .825 L
s
.99625 .85 m
1 .85 L
s
.99625 .9 m
1 .9 L
s
.99625 .925 m
1 .925 L
s
.99625 .95 m
1 .95 L
s
.99625 .975 m
1 .975 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.005 w
.98184 .83036 Mdot
.59193 .56328 Mdot
.39365 .42704 Mdot
.51124 .50731 Mdot
.91888 .78674 Mdot
.22258 .31019 Mdot
.39864 .42987 Mdot
.77216 .68692 Mdot
.91824 .78616 Mdot
.84296 .73555 Mdot
.54621 .53223 Mdot
.24278 .32333 Mdot
.76942 .68529 Mdot
.24246 .32281 Mdot
.13005 .24594 Mdot
.37652 .4151 Mdot
.47568 .48349 Mdot
.73773 .66258 Mdot
.37026 .41067 Mdot
.67378 .61897 Mdot
.47147 .48023 Mdot
.19692 .29156 Mdot
.07998 .21208 Mdot
.77195 .68661 Mdot
.76208 .67948 Mdot
.68887 .62929 Mdot
.68506 .6263 Mdot
.48464 .48998 Mdot
.57983 .55461 Mdot
.30699 .36808 Mdot
.67434 .61994 Mdot
.30935 .36908 Mdot
.05388 .19372 Mdot
.84542 .73701 Mdot
.1139 .23583 Mdot
.6856 .62768 Mdot
.21704 .30596 Mdot
.16663 .27142 Mdot
.66802 .61562 Mdot
.48731 .49183 Mdot
.81868 .71801 Mdot
.84985 .73967 Mdot
.39311 .42673 Mdot
.1655 .27103 Mdot
.72178 .65232 Mdot
.37908 .41694 Mdot
.58148 .5561 Mdot
.2472 .32634 Mdot
.01384 .16638 Mdot
.27395 .34523 Mdot
.84785 .73892 Mdot
.55763 .53988 Mdot
.01671 .16831 Mdot
.3406 .39074 Mdot
.8236 .72241 Mdot
.51018 .50644 Mdot
.98118 .82928 Mdot
.77124 .68623 Mdot
.33017 .3836 Mdot
.78131 .69251 Mdot
.70225 .63881 Mdot
.31746 .37482 Mdot
.7956 .70238 Mdot
.86328 .74887 Mdot
.98271 .83033 Mdot
.92865 .79433 Mdot
.2007 .29484 Mdot
.18338 .2833 Mdot
.96764 .82055 Mdot
.31215 .37126 Mdot
.71575 .64833 Mdot
.46552 .47646 Mdot
.8375 .73077 Mdot
.58069 .55497 Mdot
.5565 .53896 Mdot
.08815 .21818 Mdot
.71288 .6457 Mdot
.68099 .62388 Mdot
.47036 .4803 Mdot
.92039 .78765 Mdot
.10286 .22785 Mdot
.08553 .21643 Mdot
.56409 .54405 Mdot
.69189 .63144 Mdot
.25084 .32889 Mdot
.37909 .41706 Mdot
.24271 .32416 Mdot
.1499 .25975 Mdot
.85465 .74303 Mdot
.76556 .68155 Mdot
.42018 .4453 Mdot
.55488 .53755 Mdot
.5367 .52546 Mdot
.69378 .63349 Mdot
.42839 .45058 Mdot
.89012 .76729 Mdot
.87156 .75478 Mdot
.19059 .28768 Mdot
.24085 .32181 Mdot
.56551 .54443 Mdot
.24747 .32656 Mdot
.18523 .28401 Mdot
.2514 .33009 Mdot
.53999 .52806 Mdot
.3452 .39349 Mdot
.45632 .4702 Mdot
.23364 .31715 Mdot
.16057 .26787 Mdot
.91972 .78723 Mdot
.88978 .76775 Mdot
.99856 .84122 Mdot
.58866 .56143 Mdot
.15088 .26033 Mdot
.96464 .81774 Mdot
.15816 .26568 Mdot
.90821 .7803 Mdot
.28116 .34928 Mdot
.23349 .31681 Mdot
.66413 .61274 Mdot
.92891 .79398 Mdot
.46213 .47458 Mdot
.95802 .81327 Mdot
.64905 .60194 Mdot
.48898 .49226 Mdot
.01304 .16667 Mdot
.56024 .54096 Mdot
.63142 .59008 Mdot
.71098 .64494 Mdot
.30811 .36817 Mdot
.27697 .34761 Mdot
.17134 .27464 Mdot
.95469 .81104 Mdot
.90968 .78056 Mdot
.6297 .58857 Mdot
.66917 .61584 Mdot
.4906 .49396 Mdot
.08737 .21666 Mdot
.34315 .39303 Mdot
.74597 .66929 Mdot
.84348 .73536 Mdot
.59565 .56522 Mdot
.51266 .50891 Mdot
.68948 .62981 Mdot
.90486 .77723 Mdot
.99924 .84204 Mdot
.04722 .19028 Mdot
.53042 .52043 Mdot
.60295 .57126 Mdot
.5562 .53863 Mdot
.54714 .53246 Mdot
.13661 .25138 Mdot
.52602 .51835 Mdot
.0628 .2001 Mdot
.6725 .61795 Mdot
.68044 .62415 Mdot
.35908 .40282 Mdot
.44242 .4611 Mdot
.20737 .29917 Mdot
.38768 .42272 Mdot
.50796 .50582 Mdot
.02733 .17657 Mdot
.39268 .42681 Mdot
.75288 .67325 Mdot
.41315 .44022 Mdot
.62532 .58654 Mdot
.20403 .29676 Mdot
.17908 .27964 Mdot
.09477 .22163 Mdot
.3457 .39436 Mdot
.47404 .48165 Mdot
.40538 .43492 Mdot
.09298 .22155 Mdot
.98973 .83593 Mdot
.05609 .19552 Mdot
.96385 .81833 Mdot
.90391 .77686 Mdot
.31764 .37499 Mdot
.18329 .28337 Mdot
.529 .51938 Mdot
.63196 .59032 Mdot
.38273 .42001 Mdot
.11705 .23726 Mdot
.25816 .33459 Mdot
.43229 .45405 Mdot
.42184 .44628 Mdot
.66737 .61521 Mdot
.90606 .77811 Mdot
.04052 .18474 Mdot
.5514 .53518 Mdot
.83457 .7299 Mdot
.22021 .30796 Mdot
.31436 .37282 Mdot
.64615 .60021 Mdot
.38099 .41869 Mdot
.4556 .46906 Mdot
.84621 .73771 Mdot
.36513 .40758 Mdot
.65525 .60701 Mdot
.23945 .32082 Mdot
.30734 .36773 Mdot
.6469 .60134 Mdot
.36798 .41005 Mdot
.95208 .81014 Mdot
.62191 .58324 Mdot
.31108 .37027 Mdot
.43211 .4537 Mdot
.27697 .34647 Mdot
.52274 .51527 Mdot
.52549 .51687 Mdot
.96274 .81745 Mdot
.45303 .46801 Mdot
.34333 .39293 Mdot
.19734 .29239 Mdot
.79917 .70499 Mdot
.5057 .50382 Mdot
.2784 .34842 Mdot
.48289 .48842 Mdot
.41297 .44076 Mdot
.66948 .61651 Mdot
.95787 .8135 Mdot
.25233 .32991 Mdot
.2437 .32445 Mdot
.06165 .20009 Mdot
.14887 .25987 Mdot
.09098 .21975 Mdot
.31421 .37196 Mdot
.9324 .79622 Mdot
.38763 .42282 Mdot
.56295 .54382 Mdot
.79142 .69942 Mdot
.10746 .2304 Mdot
.80222 .70773 Mdot
.35433 .40054 Mdot
.986 .83346 Mdot
.14325 .25498 Mdot
.19187 .2882 Mdot
.01547 .16828 Mdot
.27239 .34327 Mdot
.72627 .65462 Mdot
.11151 .23433 Mdot
.10983 .23245 Mdot
.66353 .61255 Mdot
.12931 .24631 Mdot
.29111 .35626 Mdot
.47177 .48127 Mdot
.81983 .719 Mdot
.47027 .47923 Mdot
.32585 .38085 Mdot
.61914 .58206 Mdot
.38981 .42451 Mdot
.57575 .55147 Mdot
.11666 .23697 Mdot
.34531 .39386 Mdot
.75426 .67376 Mdot
.38845 .42354 Mdot
.14944 .25943 Mdot
.49987 .50027 Mdot
.9042 .77741 Mdot
.20398 .29699 Mdot
.86762 .75237 Mdot
.45519 .46955 Mdot
.12064 .23984 Mdot
.30105 .36323 Mdot
.36872 .40962 Mdot
.50846 .50601 Mdot
.5474 .53206 Mdot
.0842 .21452 Mdot
.27391 .34514 Mdot
.87504 .75707 Mdot
.63944 .59608 Mdot
.23096 .31532 Mdot
.53283 .52211 Mdot
.23988 .32168 Mdot
.26323 .33775 Mdot
.26248 .33654 Mdot
.81618 .71635 Mdot
.7095 .64429 Mdot
.31289 .37111 Mdot
.10531 .22902 Mdot
.36008 .40402 Mdot
.56071 .54196 Mdot
.8668 .75103 Mdot
.11425 .23507 Mdot
.04395 .18775 Mdot
.1108 .2327 Mdot
.99371 .83822 Mdot
.61881 .58129 Mdot
.59394 .56436 Mdot
.78121 .69223 Mdot
.87879 .75946 Mdot
.28841 .35452 Mdot
.07654 .20973 Mdot
.55656 .53839 Mdot
.09022 .21937 Mdot
.5167 .51132 Mdot
.00553 .16118 Mdot
.79461 .70253 Mdot
.60124 .56985 Mdot
.11328 .23451 Mdot
.6411 .59692 Mdot
.35812 .40231 Mdot
.36051 .40481 Mdot
.04496 .18778 Mdot
.56743 .54592 Mdot
.45467 .46951 Mdot
.402 .43268 Mdot
.23333 .31685 Mdot
.97278 .82367 Mdot
.49071 .49385 Mdot
.90319 .77686 Mdot
.08584 .21667 Mdot
.83789 .73108 Mdot
.92317 .79043 Mdot
.83427 .72969 Mdot
.95935 .81435 Mdot
.53552 .5243 Mdot
.10376 .22783 Mdot
.09225 .22061 Mdot
.74658 .66974 Mdot
.79839 .705 Mdot
.53888 .52702 Mdot
.79052 .69965 Mdot
.33497 .38662 Mdot
.61372 .57755 Mdot
.98113 .82908 Mdot
.39694 .42874 Mdot
.79204 .69983 Mdot
.71975 .65026 Mdot
.47292 .48079 Mdot
.22234 .30942 Mdot
.47828 .48516 Mdot
.30596 .36685 Mdot
.75459 .67493 Mdot
.52273 .5151 Mdot
.11034 .23348 Mdot
.5957 .56614 Mdot
.74741 .6692 Mdot
.00025 .15727 Mdot
.43629 .45692 Mdot
.24924 .32758 Mdot
.78414 .69503 Mdot
.85084 .74005 Mdot
.73799 .6628 Mdot
.77936 .692 Mdot
.02154 .17185 Mdot
.95293 .81066 Mdot
.77631 .69002 Mdot
.8305 .72636 Mdot
.6631 .61198 Mdot
.94543 .80485 Mdot
.5068 .50439 Mdot
.30567 .36652 Mdot
.10774 .2306 Mdot
.63104 .59014 Mdot
.32964 .38327 Mdot
.05005 .1911 Mdot
.6363 .59364 Mdot
.71209 .64577 Mdot
.07997 .21239 Mdot
.42827 .45041 Mdot
.09699 .22422 Mdot
.60604 .57332 Mdot
.21829 .3071 Mdot
.95441 .81151 Mdot
.67273 .61867 Mdot
.00944 .16424 Mdot
.42584 .44864 Mdot
.50581 .50391 Mdot
.52107 .51495 Mdot
.91034 .78075 Mdot
.85241 .7417 Mdot
.95692 .81345 Mdot
.84083 .73404 Mdot
.72371 .65388 Mdot
.66908 .61603 Mdot
.37326 .41278 Mdot
.05668 .19636 Mdot
.93459 .79773 Mdot
.13806 .25206 Mdot
.18076 .28132 Mdot
.72336 .65378 Mdot
.4203 .44563 Mdot
.93185 .79627 Mdot
.53363 .52318 Mdot
.63674 .59378 Mdot
.09919 .22485 Mdot
.48474 .48992 Mdot
.24377 .32437 Mdot
.85204 .74141 Mdot
.65146 .60367 Mdot
.45856 .47156 Mdot
.90862 .77959 Mdot
.04036 .18544 Mdot
.66612 .61402 Mdot
.63119 .59046 Mdot
.38256 .41943 Mdot
.94148 .80225 Mdot
.98006 .82851 Mdot
.40637 .43588 Mdot
.24965 .32792 Mdot
.44902 .46555 Mdot
.97714 .82636 Mdot
.52354 .51637 Mdot
.52945 .52007 Mdot
.44205 .46005 Mdot
.4952 .49732 Mdot
.91483 .78434 Mdot
.26282 .33677 Mdot
.0177 .16997 Mdot
.02697 .17542 Mdot
.79089 .69931 Mdot
.09151 .22031 Mdot
.88148 .7614 Mdot
.54102 .5281 Mdot
.87879 .76024 Mdot
.28628 .3529 Mdot
.01876 .17073 Mdot
.08504 .21539 Mdot
.95291 .81047 Mdot
.51617 .51098 Mdot
.0942 .2213 Mdot
.25461 .33158 Mdot
.20629 .29857 Mdot
.70869 .64361 Mdot
.55583 .53784 Mdot
.57324 .54994 Mdot
.99605 .8402 Mdot
.79633 .70327 Mdot
.43643 .4561 Mdot
.7955 .70294 Mdot
.82332 .72227 Mdot
.48054 .48644 Mdot
.73744 .66339 Mdot
.85522 .74401 Mdot
.59788 .56728 Mdot
.69809 .6355 Mdot
.86908 .75322 Mdot
.26272 .33755 Mdot
.40615 .4351 Mdot
.68708 .6281 Mdot
.3686 .41046 Mdot
.7937 .70142 Mdot
.8844 .76346 Mdot
.90719 .77957 Mdot
.73504 .66163 Mdot
.44371 .46188 Mdot
.91211 .78223 Mdot
.82263 .72068 Mdot
.31493 .37354 Mdot
.21467 .30475 Mdot
.85236 .74135 Mdot
.98411 .83107 Mdot
.6523 .60428 Mdot
.89411 .77063 Mdot
.78647 .69629 Mdot
.53132 .52127 Mdot
.93868 .80122 Mdot
.71924 .6501 Mdot
.79965 .70603 Mdot
.54726 .53254 Mdot
.55236 .53543 Mdot
.70554 .64069 Mdot
.71474 .64671 Mdot
.95151 .80993 Mdot
.67756 .62164 Mdot
.6992 .6364 Mdot
.31542 .37392 Mdot
.71486 .64683 Mdot
.75374 .67368 Mdot
.4076 .43635 Mdot
.78843 .69805 Mdot
.7281 .65686 Mdot
.20713 .29922 Mdot
.69142 .63069 Mdot
.6013 .56987 Mdot
.09279 .22096 Mdot
.94506 .80505 Mdot
.63063 .58988 Mdot
.2476 .32651 Mdot
.81836 .71868 Mdot
.56965 .54821 Mdot
.47673 .48447 Mdot
.79208 .70004 Mdot
.50683 .50502 Mdot
.78212 .69324 Mdot
.2628 .33734 Mdot
.5085 .50526 Mdot
.65633 .60682 Mdot
.75176 .67285 Mdot
.11345 .23455 Mdot
.59844 .56763 Mdot
.33113 .38418 Mdot
.62718 .58712 Mdot
.12357 .24156 Mdot
.64585 .59969 Mdot
.21345 .303 Mdot
.32753 .38134 Mdot
.55934 .54102 Mdot
.98973 .83561 Mdot
.74951 .6705 Mdot
.98494 .83274 Mdot
.62968 .58862 Mdot
.39354 .42662 Mdot
.83298 .72785 Mdot
.83163 .72758 Mdot
.06983 .20487 Mdot
.66168 .61141 Mdot
.79139 .70032 Mdot
.60866 .57508 Mdot
.11221 .23384 Mdot
.19627 .29206 Mdot
.78633 .69606 Mdot
.40224 .43331 Mdot
.01869 .1703 Mdot
.78578 .69554 Mdot
.59721 .56616 Mdot
.96066 .81607 Mdot
.87434 .75621 Mdot
.37596 .4151 Mdot
.61822 .58054 Mdot
.89565 .77145 Mdot
.93184 .79572 Mdot
.87867 .75897 Mdot
.36447 .40718 Mdot
.69751 .63585 Mdot
.99627 .8404 Mdot
.15593 .26463 Mdot
.49238 .49456 Mdot
.22862 .31339 Mdot
.61673 .58022 Mdot
.03071 .17904 Mdot
.32763 .38134 Mdot
.2 .29424 Mdot
.13445 .24886 Mdot
.33077 .38394 Mdot
.62898 .58856 Mdot
.80072 .70642 Mdot
.73646 .66165 Mdot
.26822 .3411 Mdot
.27904 .3486 Mdot
.69153 .63079 Mdot
.56755 .54581 Mdot
.06609 .20248 Mdot
.37609 .41486 Mdot
.34621 .39399 Mdot
.84963 .73985 Mdot
.31374 .37215 Mdot
.53073 .52135 Mdot
.13513 .2504 Mdot
.77668 .68942 Mdot
.80983 .71309 Mdot
.78112 .69247 Mdot
.35067 .39706 Mdot
.63673 .5942 Mdot
.46014 .47255 Mdot
.85913 .74671 Mdot
.82801 .72482 Mdot
.01369 .16651 Mdot
.84159 .73386 Mdot
.36309 .40584 Mdot
.24318 .32377 Mdot
.62575 .58672 Mdot
.3954 .42818 Mdot
.28285 .35131 Mdot
.09969 .2255 Mdot
.4175 .44318 Mdot
.30407 .36506 Mdot
.57641 .5518 Mdot
.97674 .82653 Mdot
.11058 .23355 Mdot
.60366 .57141 Mdot
.42863 .45053 Mdot
.60915 .57544 Mdot
.09656 .22386 Mdot
.88484 .76377 Mdot
.90449 .7772 Mdot
.74564 .66837 Mdot
.92306 .78955 Mdot
.64764 .60148 Mdot
.73588 .66117 Mdot
.33224 .38432 Mdot
.54271 .5294 Mdot
.74034 .66502 Mdot
.55882 .53999 Mdot
.99012 .83558 Mdot
.24769 .32676 Mdot
.13592 .2502 Mdot
.08948 .21869 Mdot
.44057 .4593 Mdot
.08487 .21598 Mdot
.00775 .16221 Mdot
.65538 .60694 Mdot
.84389 .73614 Mdot
.91648 .78556 Mdot
.88894 .76614 Mdot
.14562 .2565 Mdot
.5261 .51778 Mdot
.09607 .22284 Mdot
.79931 .70474 Mdot
.32731 .38152 Mdot
.00454 .16031 Mdot
.00651 .16241 Mdot
.45823 .47097 Mdot
.89053 .76826 Mdot
.86178 .74749 Mdot
.42571 .44907 Mdot
.6979 .63627 Mdot
.54259 .52942 Mdot
.2479 .32705 Mdot
.78317 .69417 Mdot
.29153 .35707 Mdot
.05117 .19229 Mdot
.10535 .22924 Mdot
.59596 .56523 Mdot
.89532 .77055 Mdot
.18217 .2825 Mdot
.2836 .35117 Mdot
.11051 .23293 Mdot
.83162 .72691 Mdot
.00624 .16161 Mdot
.17208 .27481 Mdot
.62526 .58533 Mdot
.19693 .29274 Mdot
.26426 .33807 Mdot
.70201 .63915 Mdot
.18191 .28236 Mdot
.14807 .2591 Mdot
.02082 .17164 Mdot
.89915 .77345 Mdot
.88804 .76611 Mdot
.2524 .32983 Mdot
.40265 .43373 Mdot
.97463 .82547 Mdot
.48062 .48696 Mdot
.02382 .17408 Mdot
.18282 .28252 Mdot
.8668 .75193 Mdot
.82735 .72407 Mdot
.32066 .3765 Mdot
.72115 .65227 Mdot
.55203 .53618 Mdot
.98383 .83177 Mdot
.1902 .28806 Mdot
.87092 .75377 Mdot
.89596 .77147 Mdot
.69948 .63735 Mdot
.4283 .45128 Mdot
.84126 .73347 Mdot
.72093 .65156 Mdot
.70948 .64368 Mdot
.09856 .225 Mdot
1 0 0 r
.29744 .94015 Mdot
.53916 .41369 Mdot
.34408 .83855 Mdot
.28464 .96728 Mdot
.27445 .98751 Mdot
.41165 .69277 Mdot
.64702 .1791 Mdot
.30015 .93407 Mdot
.53075 .43388 Mdot
.7149 .03462 Mdot
.50628 .48535 Mdot
.72638 .00884 Mdot
.47098 .56251 Mdot
.55822 .37146 Mdot
.35492 .81656 Mdot
.37799 .76557 Mdot
.32604 .87743 Mdot
.63509 .20565 Mdot
.73048 .00182 Mdot
.55918 .3703 Mdot
.57809 .33011 Mdot
.53918 .41549 Mdot
.31536 .90135 Mdot
.4331 .64616 Mdot
.70042 .06477 Mdot
.52186 .4521 Mdot
.42969 .65434 Mdot
.54811 .39583 Mdot
.30988 .91424 Mdot
.60897 .26228 Mdot
.52357 .44762 Mdot
.32456 .88051 Mdot
.53469 .42335 Mdot
.32413 .88335 Mdot
.64934 .17567 Mdot
.29239 .95033 Mdot
.3734 .77573 Mdot
.35989 .80592 Mdot
.56023 .3671 Mdot
.34443 .83978 Mdot
.43231 .648 Mdot
.69137 .08337 Mdot
.52253 .45009 Mdot
.44821 .61296 Mdot
.45307 .60268 Mdot
.71266 .03989 Mdot
.60354 .27268 Mdot
.30143 .93081 Mdot
.56151 .36474 Mdot
.65647 .15981 Mdot
.29923 .93513 Mdot
.4694 .56635 Mdot
.40608 .70577 Mdot
.6684 .13421 Mdot
.32711 .87499 Mdot
.65834 .1567 Mdot
.54637 .39738 Mdot
.38209 .75719 Mdot
.60796 .2643 Mdot
.70049 .06406 Mdot
.37378 .77595 Mdot
.34944 .82806 Mdot
.69131 .08449 Mdot
.55699 .37509 Mdot
.28531 .96607 Mdot
.37923 .7626 Mdot
.64136 .19229 Mdot
.54732 .39552 Mdot
.48189 .53905 Mdot
.48589 .53043 Mdot
.6468 .18156 Mdot
.35734 .81078 Mdot
.41279 .68955 Mdot
.28728 .96207 Mdot
.62492 .22785 Mdot
.40828 .70103 Mdot
.66741 .13588 Mdot
.50915 .4813 Mdot
.5469 .39839 Mdot
.43651 .63983 Mdot
.42229 .66868 Mdot
.38043 .76076 Mdot
.33669 .85644 Mdot
.71785 .02735 Mdot
.4163 .68362 Mdot
.69192 .08385 Mdot
.68267 .10244 Mdot
.53047 .43254 Mdot
.47861 .54802 Mdot
.56087 .36666 Mdot
.71676 .03091 Mdot
.65233 .16829 Mdot
.47091 .56495 Mdot
.59808 .28728 Mdot
.47587 .55192 Mdot
.43544 .64203 Mdot
.39512 .72978 Mdot
.32093 .88876 Mdot
.33181 .86472 Mdot
.42533 .66403 Mdot
.53382 .42686 Mdot
.56185 .36456 Mdot
.70262 .05979 Mdot
.36596 .79174 Mdot
.44008 .62953 Mdot
.37447 .77319 Mdot
.52275 .44901 Mdot
.65561 .15992 Mdot
.57747 .32964 Mdot
.46945 .56728 Mdot
.69307 .08125 Mdot
.672 .125 Mdot
.61118 .25712 Mdot
.32509 .87932 Mdot
.39477 .73004 Mdot
.71345 .03741 Mdot
.6103 .2582 Mdot
.66709 .13717 Mdot
.55882 .37145 Mdot
.43936 .63389 Mdot
.5623 .36304 Mdot
.29449 .9471 Mdot
.3121 .90812 Mdot
.47711 .54921 Mdot
.3147 .9026 Mdot
.53643 .42096 Mdot
.60166 .27947 Mdot
.37549 .77211 Mdot
.5894 .30619 Mdot
.37213 .77919 Mdot
.71117 .042 Mdot
.33598 .85731 Mdot
.59912 .28436 Mdot
.35985 .80644 Mdot
.63799 .20011 Mdot
.55127 .38811 Mdot
.3444 .83753 Mdot
.43027 .65253 Mdot
.46996 .56684 Mdot
.50143 .49597 Mdot
.46121 .58553 Mdot
.57106 .34529 Mdot
.67449 .11942 Mdot
.48227 .54013 Mdot
.43863 .63339 Mdot
.52643 .44202 Mdot
.4949 .51084 Mdot
.49058 .51946 Mdot
.49653 .50819 Mdot
.46671 .57338 Mdot
.34364 .8399 Mdot
.38632 .74804 Mdot
.3116 .90982 Mdot
.63172 .21313 Mdot
.46728 .57146 Mdot
.412 .69281 Mdot
.64336 .18909 Mdot
.63232 .21241 Mdot
.45002 .60946 Mdot
.52132 .45342 Mdot
.37875 .76498 Mdot
.48038 .54351 Mdot
.42284 .66848 Mdot
.57042 .34553 Mdot
.55821 .3719 Mdot
.6343 .20776 Mdot
.52819 .43834 Mdot
.33789 .85394 Mdot
.52698 .44098 Mdot
.5385 .41684 Mdot
.43206 .64776 Mdot
.30698 .91956 Mdot
.42285 .66969 Mdot
.68236 .10309 Mdot
.68027 .10783 Mdot
.48548 .53278 Mdot
.52221 .45156 Mdot
.69078 .08643 Mdot
.34642 .83334 Mdot
.6653 .14031 Mdot
.43149 .64993 Mdot
.31785 .8945 Mdot
.52918 .43725 Mdot
.47531 .55438 Mdot
.54517 .4005 Mdot
.31319 .90666 Mdot
.64839 .17618 Mdot
.72555 .0126 Mdot
.28362 .9689 Mdot
.67377 .12317 Mdot
.42473 .66378 Mdot
.56746 .35355 Mdot
.34635 .83502 Mdot
.64363 .18769 Mdot
.28567 .96456 Mdot
.35414 .81659 Mdot
.34745 .83166 Mdot
.67052 .1283 Mdot
.42623 .66125 Mdot
.62213 .235 Mdot
.47658 .55017 Mdot
.69089 .08659 Mdot
.72002 .02259 Mdot
.61277 .25516 Mdot
.36621 .79058 Mdot
.30966 .91344 Mdot
.49087 .52009 Mdot
.45024 .60948 Mdot
.30398 .92616 Mdot
.55433 .38224 Mdot
.59831 .28526 Mdot
.37781 .76749 Mdot
.62065 .2378 Mdot
.48456 .53477 Mdot
.37811 .76554 Mdot
.69155 .08309 Mdot
.49152 .51831 Mdot
.51054 .47743 Mdot
.59934 .28226 Mdot
.37901 .76465 Mdot
.57727 .33072 Mdot
.70006 .06465 Mdot
.72168 .01862 Mdot
.28048 .97531 Mdot
.3849 .75113 Mdot
.65894 .15446 Mdot
.46284 .58094 Mdot
.62676 .22401 Mdot
.5829 .31886 Mdot
.41389 .68838 Mdot
.4495 .61016 Mdot
.70865 .04752 Mdot
.38147 .75855 Mdot
.58925 .30558 Mdot
.27806 .9822 Mdot
.66494 .14124 Mdot
.37586 .77063 Mdot
.50741 .48502 Mdot
.4678 .56986 Mdot
.71264 .03929 Mdot
.46083 .58427 Mdot
.60724 .26511 Mdot
.66245 .14721 Mdot
.28732 .96033 Mdot
.31217 .90866 Mdot
.64754 .17882 Mdot
.31047 .91205 Mdot
.45874 .59101 Mdot
.46854 .56819 Mdot
.49405 .51208 Mdot
.3142 .90384 Mdot
.39825 .7215 Mdot
.32149 .88859 Mdot
.37271 .77703 Mdot
.40692 .70197 Mdot
.63834 .19745 Mdot
.58173 .32025 Mdot
.27712 .98311 Mdot
.27972 .9771 Mdot
.56 .36769 Mdot
.53474 .42381 Mdot
.41176 .69323 Mdot
.49163 .51763 Mdot
.56719 .35398 Mdot
.47646 .55097 Mdot
.34831 .83144 Mdot
.27312 .99205 Mdot
.36269 .79889 Mdot
.40756 .70065 Mdot
.59992 .28299 Mdot
.35716 .81008 Mdot
.34381 .84022 Mdot
.38195 .75834 Mdot
.66879 .13216 Mdot
.37951 .76377 Mdot
.47662 .55211 Mdot
.42584 .66278 Mdot
.56827 .3498 Mdot
.4736 .55657 Mdot
.39007 .74105 Mdot
.27401 .99041 Mdot
.64898 .17535 Mdot
.61893 .24144 Mdot
.5495 .39129 Mdot
.61533 .24781 Mdot
.66974 .12956 Mdot
.32761 .87494 Mdot
.36144 .80051 Mdot
.55336 .38408 Mdot
.49058 .51988 Mdot
.38709 .74568 Mdot
.47233 .56056 Mdot
.43925 .63373 Mdot
.56668 .35354 Mdot
.72788 .00517 Mdot
.31178 .90976 Mdot
.5914 .30058 Mdot
.4913 .51876 Mdot
.46548 .57509 Mdot
.54163 .40981 Mdot
.7052 .05348 Mdot
.54839 .3949 Mdot
.675 .12032 Mdot
.63621 .20348 Mdot
.62199 .23313 Mdot
.43804 .6354 Mdot
.30635 .92058 Mdot
.3536 .81988 Mdot
.67408 .12244 Mdot
.69296 .0814 Mdot
.58234 .31948 Mdot
.65699 .15744 Mdot
.4564 .59657 Mdot
.7004 .06558 Mdot
.67721 .11443 Mdot
.32561 .87899 Mdot
.6167 .24414 Mdot
.52056 .45465 Mdot
.36617 .79272 Mdot
.44535 .61883 Mdot
.62933 .21824 Mdot
.46782 .5699 Mdot
.39314 .73318 Mdot
.62909 .22 Mdot
.30333 .92811 Mdot
.66156 .14892 Mdot
.57734 .33225 Mdot
.54214 .40916 Mdot
.6438 .18701 Mdot
.53152 .43164 Mdot
.65682 .15788 Mdot
.7264 .00834 Mdot
.29335 .94826 Mdot
.41294 .69004 Mdot
.71394 .03518 Mdot
.57306 .34048 Mdot
.60474 .27202 Mdot
.54319 .40502 Mdot
.32105 .88967 Mdot
.60266 .27624 Mdot
.49647 .50772 Mdot
.63801 .19825 Mdot
.5389 .41364 Mdot
.67344 .12346 Mdot
.52509 .44491 Mdot
.48267 .53899 Mdot
.2939 .9478 Mdot
.60138 .27836 Mdot
.45815 .59172 Mdot
.72057 .02194 Mdot
.29248 .94996 Mdot
.39664 .72524 Mdot
.65716 .15924 Mdot
.49497 .51052 Mdot
.72798 .00741 Mdot
.30911 .91554 Mdot
.39468 .7305 Mdot
.38097 .76079 Mdot
.51705 .46279 Mdot
.64062 .19285 Mdot
.50456 .49038 Mdot
.29674 .94186 Mdot
.43337 .6457 Mdot
.54823 .39445 Mdot
.69585 .07401 Mdot
.38951 .74019 Mdot
.52614 .44253 Mdot
.55532 .379 Mdot
.54091 .41033 Mdot
.36907 .78608 Mdot
.44657 .61674 Mdot
.66262 .14579 Mdot
.44087 .63044 Mdot
.67346 .12383 Mdot
.36987 .7834 Mdot
.48693 .52834 Mdot
.45969 .58943 Mdot
.4086 .69852 Mdot
.65156 .16871 Mdot
.55559 .3783 Mdot
.40464 .70838 Mdot
.4301 .65276 Mdot
.38708 .74567 Mdot
.46986 .56592 Mdot
.35387 .81895 Mdot
.36307 .79747 Mdot
.39534 .72775 Mdot
.55704 .37469 Mdot
.53979 .41373 Mdot
.63908 .19613 Mdot
.32509 .8797 Mdot
.44483 .62189 Mdot
.38269 .75621 Mdot
.58076 .3223 Mdot
.32324 .88434 Mdot
.38375 .75382 Mdot
.70378 .05865 Mdot
.59715 .28887 Mdot
.27973 .9766 Mdot
.59932 .2844 Mdot
.66812 .1342 Mdot
.49733 .50687 Mdot
.59692 .28823 Mdot
.55274 .38476 Mdot
.54053 .41223 Mdot
.28538 .96429 Mdot
.46304 .58001 Mdot
.60191 .27693 Mdot
.38308 .7553 Mdot
.41111 .69274 Mdot
.5663 .35397 Mdot
.33083 .8693 Mdot
.53878 .41627 Mdot
.60838 .26306 Mdot
.67526 .1191 Mdot
.43815 .6343 Mdot
.39494 .73006 Mdot
.27564 .9854 Mdot
.5308 .43316 Mdot
.51013 .47724 Mdot
.4744 .55499 Mdot
.31679 .89716 Mdot
.6853 .09783 Mdot
.48067 .54274 Mdot
.37161 .77932 Mdot
.68092 .10761 Mdot
.50053 .49878 Mdot
.56818 .35127 Mdot
.72746 .00802 Mdot
.37232 .77896 Mdot
.44754 .61392 Mdot
.71954 .02363 Mdot
.54498 .40091 Mdot
.34841 .83001 Mdot
.69248 .08213 Mdot
.28137 .97319 Mdot
.61436 .25141 Mdot
.66888 .13366 Mdot
.43998 .62977 Mdot
.70874 .04626 Mdot
.65607 .15903 Mdot
.27973 .97746 Mdot
.67231 .12476 Mdot
.3468 .8329 Mdot
.70224 .06043 Mdot
.64943 .17581 Mdot
.65336 .16541 Mdot
.55736 .37337 Mdot
.30376 .92488 Mdot
.40711 .70149 Mdot
.27172 .99347 Mdot
.5098 .47892 Mdot
.61874 .24059 Mdot
.64954 .17354 Mdot
.53214 .42986 Mdot
.3839 .75306 Mdot
.368 .78682 Mdot
.37851 .76377 Mdot
.342 .84253 Mdot
.45856 .5899 Mdot
.53739 .41711 Mdot
.64207 .18949 Mdot
.56078 .36623 Mdot
.56166 .36407 Mdot
.62563 .22557 Mdot
.46847 .56885 Mdot
.52629 .44386 Mdot
.46436 .57663 Mdot
.51483 .46701 Mdot
.32389 .8834 Mdot
.6991 .06843 Mdot
.63934 .19674 Mdot
.33505 .85788 Mdot
.5377 .41703 Mdot
.38188 .75819 Mdot
.55219 .38661 Mdot
.47712 .55018 Mdot
.50653 .48443 Mdot
.63981 .19561 Mdot
.40096 .71523 Mdot
.34948 .82913 Mdot
.52402 .44692 Mdot
.67671 .11654 Mdot
.65496 .16233 Mdot
.39271 .73348 Mdot
.67568 .11874 Mdot
.71157 .04187 Mdot
.69175 .08304 Mdot
.40328 .71061 Mdot
.54772 .39509 Mdot
.31416 .90375 Mdot
.648 .17889 Mdot
.36833 .78714 Mdot
.369 .78571 Mdot
.27904 .97822 Mdot
.68635 .09437 Mdot
.29665 .94265 Mdot
.61535 .24801 Mdot
.55921 .37017 Mdot
.37401 .7745 Mdot
.59408 .29523 Mdot
.57899 .32659 Mdot
.42218 .67106 Mdot
.31483 .90192 Mdot
.29171 .95044 Mdot
.27518 .98746 Mdot
.65104 .17145 Mdot
.58038 .32535 Mdot
.46876 .56762 Mdot
.70635 .05218 Mdot
.26999 .99837 Mdot
.52108 .45345 Mdot
.43859 .63393 Mdot
.69276 .08245 Mdot
.67007 .12939 Mdot
.4109 .69536 Mdot
.53368 .42579 Mdot
.69026 .086 Mdot
.61616 .24598 Mdot
.4688 .56947 Mdot
.31289 .90651 Mdot
.38699 .74644 Mdot
.29235 .95089 Mdot
.52451 .44571 Mdot
.45028 .60886 Mdot
.7007 .06531 Mdot
.38889 .74238 Mdot
.34552 .83747 Mdot
.34453 .83969 Mdot
.67996 .10812 Mdot
.45554 .59646 Mdot
.38549 .7505 Mdot
.63352 .21001 Mdot
.58356 .31653 Mdot
.44264 .62602 Mdot
.41403 .68854 Mdot
.58732 .31045 Mdot
.51708 .46376 Mdot
.46397 .57873 Mdot
.58169 .32191 Mdot
.72832 .00616 Mdot
.38392 .75356 Mdot
.677 .11497 Mdot
.57323 .33881 Mdot
.65723 .15866 Mdot
.46853 .56879 Mdot
.59978 .2836 Mdot
.46628 .57254 Mdot
.3921 .73443 Mdot
.50283 .49313 Mdot
.40525 .70808 Mdot
.46797 .56909 Mdot
.62733 .22112 Mdot
.58675 .31166 Mdot
.6483 .17696 Mdot
.43145 .64859 Mdot
.62422 .22842 Mdot
.63044 .21693 Mdot
.62453 .22851 Mdot
.49485 .51262 Mdot
.49284 .51669 Mdot
.67241 .12575 Mdot
.651 .1701 Mdot
.63724 .2022 Mdot
.47198 .5608 Mdot
.66764 .13423 Mdot
.4492 .60994 Mdot
.49453 .51294 Mdot
.30487 .9224 Mdot
.32731 .87414 Mdot
.49445 .51158 Mdot
.49545 .51131 Mdot
.48659 .5288 Mdot
.3233 .88495 Mdot
.71009 .04541 Mdot
.69159 .08432 Mdot
.41853 .67832 Mdot
.58222 .31927 Mdot
.70058 .0658 Mdot
.28436 .96717 Mdot
.5905 .30273 Mdot
.46317 .5792 Mdot
.46504 .57718 Mdot
.48515 .53174 Mdot
.57547 .33638 Mdot
.38319 .75553 Mdot
.65397 .16364 Mdot
.70372 .05674 Mdot
.31227 .9074 Mdot
.65847 .15616 Mdot
.35147 .8226 Mdot
.56342 .36109 Mdot
.65862 .15444 Mdot
.51549 .46479 Mdot
.40862 .70008 Mdot
.48726 .52867 Mdot
.45366 .60161 Mdot
.47825 .5487 Mdot
.43605 .63996 Mdot
.63734 .20041 Mdot
.37039 .7832 Mdot
.5647 .35869 Mdot
.54401 .40516 Mdot
.35417 .81771 Mdot
.63137 .21233 Mdot
.67459 .12035 Mdot
.70983 .04461 Mdot
.53849 .41615 Mdot
.63244 .21126 Mdot
.71926 .02487 Mdot
.48469 .53421 Mdot
.36049 .8044 Mdot
.42248 .66821 Mdot
.71152 .04152 Mdot
.51914 .45887 Mdot
.38863 .74317 Mdot
.50605 .48798 Mdot
.45957 .58961 Mdot
.55387 .38128 Mdot
.34664 .83419 Mdot
.58996 .30255 Mdot
.52171 .4529 Mdot
.4364 .63992 Mdot
.648 .17789 Mdot
.2759 .98505 Mdot
.47565 .55244 Mdot
.45451 .59899 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Y_ooool3o`0007Oooooo002Uooooo`05o`000?ooooooooooooooool00000M_ooool00:Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1cooooo`00YOooool6o`0007Gooooo
002Vooooo`05o`000?ooooooooooooooool00000MOooool00:Oooooo0ol0001fooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00@_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`000003ooooool0003o000000?o00000_ooool3o`0000Oooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo0ol00002ooooo`?o00001oooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`0000?ooooo00?o0000ooooooooool00_ooool3o`0000Wooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000:ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
0_ooool5o`0000;ooooo0ol00006ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
0oooool3o`0000Oooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`00
0?oooooooooo00;ooooo0ol0000Booooo`00@Oooool01?l0003oooooooooool0000:ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00002_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000Oooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool03oooool0047ooooo00Co0000oooooooooooo00001oooool5o`0000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo1Ol00005
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool5o`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000_ooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool0000;ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo0011
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`00@Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000000;ooooo00Ko0000ooooooooooooooooo`000?ooool4o`0000Kooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000002ooooo`Co00001_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000000Kooooo00?o0000ooooool000000ol00008oooo
o`04o`000?ooooooooooo`0000Oooooo1?l00009ooooo`04o`000?ooooooooooo`0000Oooooo1?l0
0002ooooo`06o`000?ooooooooooooooool0003ooooo1?l00005ooooo`04o`000?ooooooooooo`00
00Oooooo1?l00002ooooo`Co00001_ooool01?l0003oooooooooool00007ooooo`Co00001_ooool0
0ol0003oooooo`000003o`0001;ooooo0011ooooo`04o`000?ooooooooooo`0000Wooooo0_l00002
ooooo`07o`000?ooooooooooooooool0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Wo
oooo0_l00002ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002Oooool2o`00
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000_ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool00oooool01ol0003ooooooooooooooooo0000ooooool000002?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
01Gooooo0012ooooo`;o00002oooool01?l0003oooooooooooooool3o`0000;ooooo1Ol00006oooo
o`;o00002oooool00ol0003oooooooooo`05o`0000Kooooo0_l0000;ooooo`03o`000?oooooooooo
00Go000000?oooooo`000?l000000ol00008ooooo`;o00002?ooool5o`0000Wooooo0_l00008oooo
o`Go00000_ooool3o`0000;ooooo1Ol00005ooooo`;o00002?ooool5o`000003ooooool0003o0000
00?o00001_ooool2o`0000Sooooo1Ol000000ooooooo0000o`000003o`000003ooooool0003o0000
00?o00004Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool0
03;ooooo[@0000000`3o000000000000000k0000007o00000@000001ooooo`00<_ooool00`00003o
ooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00`3o003o
ooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool10000007o
oooo000booooo`0300000?oooooooooo0:Wooooo00<0o`00ooooooooool0?Oooool10000007ooooo
000booooo`0300000?oooooooooo0:Sooooo00<0o`00ooooooooool0?_ooool10000007ooooo000b
ooooo`0300000?oooooooooo0:Sooooo00<0o`00ooooooooool0?_ooool10000007ooooo000boooo
o`0300000?l0003ooooo0:Oooooo00<0o`00ooooooooool0?_ooool1o`00004000000Oooool003;o
oooo00<00000ooooooooool0Yoooool00`3o003oooooooooo`0oooooo`4000000Oooool003;ooooo
00<00000ooooooooool0Y_ooool00`3o003oooooooooo`10ooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0Y_ooool00`3o003oooooooooo`10ooooo`4000000Oooool003;ooooo00<00000
ooooooooool0YOooool00`3o003oooooooooo`11ooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0YOooool00`3o003oooooooooo`11ooooo`4000000Oooool003;ooooo00<00000o`000?oo
ool0Y?ooool00`3o003oooooooooo`11ooooo`7o00000@000001ooooo`00<_ooool00`00003ooooo
ooooo`2Tooooo`030?l00?oooooooooo04;ooooo0@000001ooooo`00<_ooool00`00003ooooooooo
o`2Sooooo`030?l00?oooooooooo04?ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2S
ooooo`030?l00?oooooooooo04?ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2Roooo
o`80o`00AOooool10000007ooooo000booooo`0300000?oooooooooo0:;ooooo00<0o`00oooooooo
ool0A?ooool10000007ooooo000booooo`0300000?l0003ooooo0:7ooooo00<0o`00ooooooooool0
A?ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000b
ooooo`0300000?oooooooooo0:3ooooo0P3o0017ooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0X?ooool00`3o003oooooooooo`16ooooo`4000000Oooool003;ooooo00<00000oooooooo
ool0jOooool10000007ooooo000booooo`0300000?oooooooooo09oooooo00<0o`00ooooooooool0
Aoooool10000007ooooo000booooo`0300000?l0003ooooo09oooooo00<0o`00ooooooooool0A_oo
ool1o`00004000000Oooool003;ooooo00<00000ooooooooool0W_ooool00`3o003oooooooooo`18
ooooo`4000000Oooool003;ooooo00<00000ooooooooool0W_ooool00`3o003oooooooooo`18oooo
o`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000Cooooo`;o0000
1?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
1Oooool00`00003oooooooooo`2Mooooo`030?l00?oooooooooo04Wooooo0@000001ooooo`004_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0W?ooool20?l0
04_ooooo0@000001ooooo`002oooool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0`00003o0000ooooo`2Looooo`030?l00?oooooooooo04Wooooo0Ol000010000007ooooo000Boooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00<00000ooooooooool0Voooool00`3o003ooooooooo
o`1;ooooo`4000000Oooool001;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooo000000?o00001Oooool00`00003oooooooooo`2Kooooo`030?l0
0?oooooooooo04_ooooo0@000001ooooo`004_ooool01?l0003oooooooooool00008ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000008ooooo`0300000?oooooooooo
09_ooooo00<0o`00ooooooooool0Boooool10000007ooooo000Cooooo`;o00002_ooool2o`0000;o
oooo1Ol000000ooooooo0000o`000003o`0000Cooooo00<00000ooooooooool0V_ooool00`3o003o
ooooooooo`1<ooooo`4000000Oooool003;ooooo00<00000ooooooooool0V_ooool00`3o003ooooo
ooooo`1<ooooo`4000000Oooool003;ooooo00<00000o`000?ooool0VOooool00`3o003ooooooooo
o`1<ooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`2Iooooo`030?l00?oooooo
oooo04gooooo0@000001ooooo`00<_ooool2000009Wooooo0P3o001?ooooo`4000000Oooool003;o
oooo0`00002Gooooo`80o`00D?ooool10000007ooooo000booooo`0300000?oooooooooo00800000
UOooool00`3o003oooooooooo`1?ooooo`4000000Oooool003;ooooo00@00000oooooooooooooooo
0P00002Dooooo`030?l00?oooooooooo04oooooo0@000001ooooo`00<_ooool00`00003o0000oooo
o`03ooooo`0300000?oooooooooo093ooooo00<0o`00ooooooooool0Coooool1o`00004000000Ooo
ool003;ooooo00<00000ooooooooool01?ooool00`00003oooooooooo`2?ooooo`030?l00?oooooo
oooo053ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`06ooooo`0300000?oooooooooo
0>3ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`07ooooo`800000S?ooool00`3o003o
ooooooooo`1Aooooo`4000000Oooool003;ooooo00<00000ooooooooool02?ooool3000008Wooooo
0P3o001Cooooo`4000000Oooool003;ooooo00<00000ooooooooool02_ooool00`00003ooooooooo
o`27ooooo`030?l00?oooooooooo05;ooooo0@000001ooooo`00<_ooool00`00003o0000ooooo`0;
ooooo`<00000Q_ooool00`3o003oooooooooo`1Aooooo`7o00000@000001ooooo`00<_ooool00`00
003oooooooooo`0=ooooo`0300000?oooooooooo08?ooooo00<0o`00ooooooooool0Doooool10000
007ooooo000booooo`0300000?oooooooooo00oooooo00<00000ooooooooool0POooool00`3o003o
ooooooooo`1Cooooo`4000000Oooool003;ooooo00<00000ooooooooool04?ooool20000083ooooo
00<0o`00ooooooooool0E?ooool10000007ooooo000booooo`0300000?oooooooooo017ooooo0P00
001oooooo`030?l00?oooooooooo05Cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`0B
ooooo`<00000O?ooool20?l005Kooooo0@000001ooooo`00<_ooool00`00003o0000ooooo`0Doooo
o`800000Noooool00`3o003oooooooooo`1Dooooo`7o00000@000001ooooo`00<_ooool00`00003o
ooooooooo`0Fooooo`0300000?oooooooooo07Oooooo0P3o001Gooooo`4000000Oooool003;ooooo
00<00000ooooooooool05oooool2000007Oooooo00<0o`00ooooooooool0E_ooool10000007ooooo
000Iooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00<0
0000ooooooooool06?ooool2000007Gooooo0P3o001Hooooo`4000000Oooool001Sooooo00Co0000
oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo07;ooooo00<0o`00oooooooo
ool0Eoooool10000007ooooo000Aooooo`Go00000_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00`00003oooooooooo`0Koooo
o`<00000L?ooool20?l005Wooooo0@000001ooooo`006?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00`00003o0000ooooo`0M
ooooo`800000Koooool00`3o003oooooooooo`1Gooooo`7o00000@000001ooooo`006?ooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`0300000?oo
oooooooo01oooooo00<00000ooooooooool0Joooool20?l005[ooooo0@000001ooooo`006?ooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00`00003o
ooooooooo`0Pooooo`800000Joooool00`3o003oooooooooo`1Iooooo`4000000Oooool001Wooooo
0_l0000:ooooo`;o00000_ooool5o`0000Cooooo00<00000ooooooooool08_ooool00`00003ooooo
ooooo`1Wooooo`80o`00Foooool10000007ooooo000booooo`0300000?oooooooooo02?ooooo00<0
0000ooooooooool0`oooool10000007ooooo000booooo`0300000?oooooooooo02Cooooo00<00000
ooooooooool0IOooool00`3o003oooooooooo`1Jooooo`4000000Oooool003;ooooo00<00000o`00
0?ooool09Oooool2000006Cooooo00<0o`00ooooooooool0F_ooool1o`00004000000Oooool003;o
oooo00<00000ooooooooool09oooool2000006;ooooo00<0o`00ooooooooool0Foooool10000007o
oooo000booooo`0300000?oooooooooo02Sooooo0P00001Pooooo`80o`00GOooool10000007ooooo
000booooo`0300000?oooooooooo02[ooooo00<00000ooooooooool0GOooool00`3o003ooooooooo
o`1Looooo`4000000Oooool003;ooooo00<00000ooooooooool0:oooool2000005cooooo00<0o`00
ooooooooool0GOooool10000007ooooo000booooo`0300000?l0003ooooo02gooooo0P00002ioooo
o`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`0_ooooo`0300000?oooooooooo05Ko
oooo0P3o001Oooooo`4000000Oooool003;ooooo00<00000ooooooooool0<?ooool2000005Kooooo
00<0o`00ooooooooool0G_ooool10000007ooooo000booooo`0300000?oooooooooo037ooooo0P00
001Eooooo`030?l00?oooooooooo05kooooo0@000001ooooo`00<_ooool00`00003oooooooooo`0c
ooooo`800000D_ooool00`3o003oooooooooo`1Oooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0=?ooool20000053ooooo0P3o001Qooooo`4000000Oooool003;ooooo00<00000o`000?oo
ool0=_ooool2000004kooooo00<0o`00ooooooooool0Goooool1o`00004000000Oooool003;ooooo
00<00000ooooooooool0=oooool2000004gooooo00<0o`00ooooooooool0H?ooool10000007ooooo
000booooo`0300000?oooooooooo03Sooooo0P00001;ooooo`80o`00H_ooool10000007ooooo000b
ooooo`0300000?oooooooooo03[ooooo0P000019ooooo`030?l00?oooooooooo067ooooo0@000001
ooooo`00<_ooool00`00003oooooooooo`0kooooo`800000Aoooool00`3o003oooooooooo`1Roooo
o`4000000Oooool003;ooooo00<00000ooooooooool0?Oooool2000004Gooooo00<0o`00oooooooo
ool0H_ooool10000007ooooo000booooo`0300000?l0003ooooo03kooooo0P000013ooooo`030?l0
0?oooooooooo06;ooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo043ooooo0P00
0011ooooo`030?l00?oooooooooo06?ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`12
ooooo`0300000?oooooooooo03gooooo00<0o`00ooooooooool0I?ooool10000007ooooo000boooo
o`0300000?oooooooooo04Cooooo00<00000ooooooooool0>oooool00`3o003oooooooooo`1Toooo
o`4000000Oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go
00000_ooool3o`0000Gooooo00<00000ooooooooool0AOooool00`00003oooooooooo`0iooooo`80
o`00I_ooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00000_ooool01_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_oo
ool00`00003oooooooooo`15ooooo`<00000>Oooool00`3o003oooooooooo`1Uooooo`4000000Ooo
ool000_ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00<00000o`000?ooool0
Aoooool2000003Sooooo00<0o`00ooooooooool0I?ooool1o`00004000000Oooool001;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00`00003oooooooooo`19ooooo`0300000?oooooooooo03Co
oooo00<0o`00ooooooooool0I_ooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000So
oooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Oooool0
0`00003oooooooooo`1:ooooo`800000=?ooool00`3o003oooooooooo`1Vooooo`4000000Oooool0
01;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?ooooo
00?o0000ooooool000002?ooool00`00003oooooooooo`1<ooooo`0300000?oooooooooo033ooooo
0P3o001Xooooo`4000000Oooool001?ooooo0_l0000:ooooo`;o00000oooool3o`0000;ooooo1Ol0
0004ooooo`0300000?oooooooooo04gooooo0P00000`ooooo`030?l00?oooooooooo06Oooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`1>ooooo`<00000;Oooool20?l006Wooooo0@000001
ooooo`00<_ooool00`00003o0000ooooo`1Aooooo`0300000?oooooooooo02[ooooo00<0o`00oooo
ooooool0Ioooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0D_ooool00`00003o
ooooooooo`0Xooooo`030?l00?oooooooooo06Wooooo0@000001ooooo`00<_ooool00`00003ooooo
ooooo`1Cooooo`800000:?ooool00`3o003oooooooooo`1Yooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0E?ooool2000002Kooooo0P3o001[ooooo`4000000Oooool003;ooooo00<00000
ooooooooool0E_ooool2000002Cooooo00<0o`00ooooooooool0J_ooool10000007ooooo000boooo
o`0300000?oooooooooo05Oooooo00<00000ooooooooool08_ooool00`3o003oooooooooo`1Zoooo
o`4000000Oooool003;ooooo00<00000o`000?ooool0FOooool20000023ooooo00<0o`00oooooooo
ool0J_ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0F_ooool2000001oooooo
00<0o`00ooooooooool0Joooool10000007ooooo000booooo`0300000?oooooooooo05cooooo0P00
000Looooo`80o`00KOooool10000007ooooo000booooo`0300000?oooooooooo05gooooo00<00000
ooooooooool06_ooool00`3o003oooooooooo`1/ooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0Goooool2000001Sooooo00<0o`00ooooooooool0KOooool10000007ooooo000booooo`03
00000?oooooooooo063ooooo0P00000Gooooo`030?l00?oooooooooo06gooooo0@000001ooooo`00
<_ooool00`00003o0000ooooo`1Rooooo`0300000?oooooooooo01?ooooo00<0o`00ooooooooool0
KOooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0Hoooool2000001?ooooo00<0
o`00ooooooooool0K_ooool10000007ooooo000booooo`0300000?oooooooooo06Cooooo0P00000B
ooooo`030?l00?oooooooooo06kooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Uoooo
o`8000004?ooool00`3o003oooooooooo`1_ooooo`4000000Oooool003;ooooo00<00000oooooooo
ool0Ioooool3000000gooooo00<0o`00ooooooooool0Koooool10000007ooooo000booooo`030000
0?oooooooooo06Sooooo0`00001nooooo`4000000Oooool003;ooooo00<00000o`000?ooool0J_oo
ool2000000Wooooo0P3o001aooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`1/
ooooo`8000001oooool00`3o003oooooooooo`1aooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0KOooool2000000Kooooo00<0o`00ooooooooool0LOooool10000007ooooo000[ooooo`;o
00001Oooool00`00003oooooooooo`1^ooooo`8000001Oooool00`3o003oooooooooo`1aooooo`40
00000Oooool000;ooooo0ol0000Uooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool0L?ooool2000000;ooooo00<0o`00ooooooooool0L_ooool10000007ooooo0003ooooo`03o`00
0?oooooooooo02Cooooo00Co0000oooooooooooo00001?ooool00`00003oooooooooo`1aooooo`80
000000<0o`00ooooooooool0Loooool10000007ooooo0003ooooo`03o`000?oooooooooo02Cooooo
00Co0000oooooooooooo00001?ooool00`00003o0000ooooo`1cooooo`0300000?oooooooooo07;o
oooo0Ol000010000007ooooo0003ooooo`;o00009Oooool01?l0003oooooooooool00004ooooo`03
00000?oooooooooo07;ooooo00<0o`00ooooo`0000000P00001booooo`4000000Oooool000;ooooo
0_l000000ooooooo0000o`00000Sooooo`04o`000?ooooooooooo`0000Cooooo00<00000oooooooo
ool0L_ooool0103o003oooooooooooooool20000077ooooo0@000001ooooo`00:oooool2o`0000Go
oooo00<00000ooooooooool0L_ooool00`3o003oooooooooo`03ooooo`0300000?oooooooooo06ko
oooo0@000001ooooo`00<_ooool00`00003oooooooooo`1aooooo`030?l00?oooooooooo00Gooooo
0P00001^ooooo`4000000Oooool003;ooooo00<00000ooooooooool0LOooool00`3o003ooooooooo
o`06ooooo`800000KOooool10000007ooooo000booooo`0300000?l0003ooooo073ooooo00<0o`00
ooooooooool02?ooool3000006[ooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo
073ooooo00<0o`00ooooooooool02_ooool2000006[ooooo0@000001ooooo`00<_ooool00`00003o
ooooooooo`1_ooooo`80o`003_ooool00`00003oooooooooo`1Wooooo`4000000Oooool003;ooooo
00<00000ooooooooool0Koooool00`3o003oooooooooo`0>ooooo`800000Ioooool10000007ooooo
000booooo`0300000?oooooooooo06kooooo0P3o000Aooooo`<00000IOooool10000007ooooo000b
ooooo`0300000?oooooooooo06kooooo00<0o`00ooooooooool04_ooool2000006Cooooo0@000001
ooooo`00<_ooool00`00003o0000ooooo`1]ooooo`80o`005Oooool2000006;ooooo0Ol000010000
007ooooo000booooo`0300000?oooooooooo06gooooo00<0o`00ooooooooool05_ooool00`00003o
ooooooooo`1Pooooo`4000000Oooool003;ooooo00<00000ooooooooool0K?ooool20?l001[ooooo
00<00000ooooooooool0G_ooool10000007ooooo000booooo`0300000?oooooooooo06cooooo00<0
o`00ooooooooool06_ooool2000005kooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1[
ooooo`80o`007Oooool2000005gooooo0@000001ooooo`00<_ooool00`00003o0000ooooo`1[oooo
o`030?l00?oooooooooo01gooooo0P00001Kooooo`7o00000@000001ooooo`00<_ooool00`00003o
ooooooooo`1[ooooo`030?l00?oooooooooo01oooooo0P00001Jooooo`4000000Oooool003;ooooo
00<00000ooooooooool0J_ooool00`3o003oooooooooo`0Rooooo`800000F?ooool10000007ooooo
000booooo`0300000?oooooooooo06[ooooo00<0o`00ooooooooool09?ooool00`00003ooooooooo
o`1Eooooo`4000000Oooool003;ooooo00<00000ooooooooool0JOooool20?l002Oooooo00<00000
ooooooooool0E?ooool10000007ooooo000booooo`0300000?oooooooooo09?ooooo00<00000oooo
ooooool0Doooool10000007ooooo000booooo`0300000?l0003ooooo06Sooooo0P3o000Zooooo`03
00000?ooool00000057ooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo06Sooooo
00<0o`00ooooooooool0:oooool20000057ooooo0@000001ooooo`00<_ooool00`00003ooooooooo
o`2Hooooo`0300000?oooooooooo04kooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1W
ooooo`030?l00?oooooooooo02oooooo0P00001>ooooo`4000000Oooool001?ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00002ooooo`Go00000_ooool3o`0000Gooooo00<00000oooo
ooooool0I_ooool20?l003;ooooo0P00001=ooooo`4000000Oooool001;ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo0000
0oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo06Kooooo00<0o`00ooooooooool0
<oooool00`00003oooooooooo`1:ooooo`4000000Oooool001;ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00`00003o0000ooooo`1Vooooo`030?l00?oooooooooo03Cooooo0P000019ooooo`7o
00000@000001ooooo`004_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo
06Gooooo0P3o000hooooo`800000B?ooool10000007ooooo000Booooo`04o`000?ooooooooooo`00
00Sooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000?o00001Ooo
ool00`00003oooooooooo`1Uooooo`030?l00?oooooooooo03Sooooo0P000017ooooo`4000000Ooo
ool001;ooooo00Co0000oooooooooooo00002?ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooool000002?ooool00`00003oooooooooo`1Tooooo`030?l00?oooooooooo03_o
oooo00<00000ooooooooool0A?ooool10000007ooooo000Cooooo`;o00002_ooool2o`0000?ooooo
0ol00002ooooo`Go00001?ooool00`00003oooooooooo`1Tooooo`030?l00?oooooooooo03cooooo
0P000014ooooo`4000000Oooool003;ooooo00<00000ooooooooool0Hoooool00`3o003ooooooooo
o`0nooooo`<00000@_ooool10000007ooooo000booooo`0300000?l0003ooooo06?ooooo00<0o`00
ooooooooool0@?ooool20000043ooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo
06;ooooo0P3o0013ooooo`<00000?oooool10000007ooooo000booooo`0300000?oooooooooo0:Wo
oooo00<00000ooooooooool0?Oooool10000007ooooo000booooo`0300000?oooooooooo06;ooooo
00<0o`00ooooooooool0A_ooool00`00003oooooooooo`0kooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0HOooool00`3o003oooooooooo`18ooooo`0300000?oooooooooo03[ooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`1Qooooo`030?l00?oooooooooo04Wooooo0P00000j
ooooo`4000000Oooool003;ooooo00<00000o`000?ooool0[oooool00`00003oooooooooo`0foooo
o`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`1Pooooo`030?l00?oooooooooo04ko
oooo00<00000ooooooooool0=Oooool10000007ooooo000booooo`0300000?oooooooooo05oooooo
00<0o`00ooooooooool0D?ooool00`00003oooooooooo`0dooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0Goooool00`3o003oooooooooo`1Aooooo`0300000?oooooooooo03?ooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`1Nooooo`80o`00E?ooool3000003;ooooo0@000001
ooooo`00<_ooool00`00003oooooooooo`1Nooooo`030?l00?oooooooooo05Gooooo0P00000aoooo
o`4000000Oooool003;ooooo00<00000o`000?ooool0GOooool00`3o003oooooooooo`1Gooooo`<0
0000;_ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0GOooool00`3o003ooooo
ooooo`1Iooooo`800000;_ooool10000007ooooo000booooo`0300000?oooooooooo05gooooo00<0
o`00ooooooooool0F_ooool2000002gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1L
ooooo`030?l00?oooooooooo05gooooo00<00000ooooooooool0:_ooool10000007ooooo000boooo
o`0300000?oooooooooo05cooooo00<0o`00ooooooooool0Goooool00`00003oooooooooo`0Xoooo
o`4000000Oooool003;ooooo00<00000ooooooooool0Foooool00`3o003oooooooooo`1Qooooo`80
0000:?ooool10000007ooooo000booooo`0300000?l0003ooooo05_ooooo00<0o`00ooooooooool0
H_ooool3000002Gooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo05[ooooo00<0
o`00ooooooooool0IOooool2000002Gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1J
ooooo`030?l00?oooooooooo06Oooooo00<00000ooooooooool08_ooool10000007ooooo000Ioooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`;o00000oooool3o`0000Gooooo00<00000oooo
ooooool0a?ooool3000002;ooooo0@000001ooooo`006?ooool01?l0003oooooooooool00008oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`0300000?oo
oooooooo05Wooooo00<0o`00ooooooooool0J_ooool20000027ooooo0@000001ooooo`006?ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
0_ooool00`00003oooooooooo`1Hooooo`030?l00?oooooooooo06gooooo0P00000Oooooo`400000
0Oooool001Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00;ooooo00<00000o`000?ooool0F?ooool00`3o003oooooooooo`1^ooooo`80
00007Oooool1o`00004000000Oooool001Sooooo00Co0000oooooooooooo00002?ooool01Ol0003o
ooooooooool0003ooooo00Co00001Oooool00`00003oooooooooo`1Gooooo`80o`00LOooool30000
01cooooo0@000001ooooo`006?ooool01?l0003oooooooooool00008ooooo`06o`000?oooooooooo
o`000?oooooo00002?ooool00`00003oooooooooo`1Gooooo`030?l00?oooooooooo07;ooooo0P00
000Kooooo`4000000Oooool001Wooooo0_l0000:ooooo`;o00000_ooool5o`0000Cooooo00<00000
ooooooooool0E_ooool20?l007Gooooo0P00000Jooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0E_ooool00`3o003oooooooooo`1fooooo`0300000?oooooooooo01Oooooo0@000001oooo
o`00<_ooool00`00003oooooooooo`1Eooooo`80o`00NOooool2000001Oooooo0@000001ooooo`00
<_ooool00`00003o0000ooooo`1Eooooo`030?l00?oooooooooo07[ooooo0P00000Dooooo`7o0000
0@000001ooooo`00<_ooool00`00003oooooooooo`1Eooooo`030?l00?oooooooooo07_ooooo0P00
000Dooooo`4000000Oooool003;ooooo00<00000ooooooooool0E?ooool00`3o003oooooooooo`1n
ooooo`8000004_ooool10000007ooooo000booooo`0300000?oooooooooo05?ooooo0P3o0021oooo
o`8000004Oooool10000007ooooo000booooo`0300000?oooooooooo05?ooooo00<0o`00oooooooo
ool0P_ooool2000000oooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Cooooo`030?l0
0?oooooooooo08?ooooo0P00000>ooooo`4000000Oooool003;ooooo00<00000o`000?ooool0D_oo
ool00`3o003oooooooooo`26ooooo`0300000?oooooooooo00[ooooo0Ol000010000007ooooo000b
ooooo`0300000?oooooooooo05;ooooo00<0o`00ooooooooool0Qoooool00`00003oooooooooo`0:
ooooo`4000000Oooool003;ooooo00<00000ooooooooool0DOooool00`3o003oooooooooo`2:oooo
o`8000002Oooool10000007ooooo000booooo`0300000?oooooooooo0=oooooo0P000008ooooo`40
00000Oooool003;ooooo00<00000ooooooooool0D?ooool20?l008kooooo0P000007ooooo`400000
0Oooool003;ooooo00<00000ooooooooool0D?ooool00`3o003oooooooooo`2?ooooo`8000001Ooo
ool10000007ooooo000booooo`0300000?l0003ooooo04oooooo00<0o`00ooooooooool0TOooool3
000000;ooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo04oooooo0P3o002Doooo
o`8000000_ooool10000007ooooo000booooo`0300000?oooooooooo04oooooo00<0o`00oooooooo
ool0U?ooool20000007ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1>ooooo`80o`00
V?ooool20000007ooooo000booooo`0300000?oooooooooo04kooooo00<0o`00ooooooooool0V?oo
ool10000007ooooo000booooo`0300000?l0003ooooo0>Sooooo0Ol000010000007ooooo000boooo
o`0300000?oooooooooo04gooooo00<0o`00ooooooooool0VOooool10000007ooooo000booooo`03
00000?oooooooooo04cooooo00<0o`00ooooooooool0V_ooool10000007ooooo000booooo`030000
0?oooooooooo0>Wooooo0@000001ooooo`004oooool2o`0000Cooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Gooooo00<00000ooooooooool0Booo
ool00`3o003oooooooooo`2Kooooo`4000000Oooool001;ooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`02ooooo`0300000?oooooooooo04_ooooo00<0o`00ooooooooool0Voooool10000007o
oooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00<00000o`000?ooool0B_ooool00`3o
003oooooooooo`2Kooooo`7o00000@000001ooooo`004_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`0300000?oooooooooo04[ooooo00<0o`00ooooooooool0W?ooool10000007ooooo000Boooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`00
0003o`0000Gooooo00<00000ooooooooool0BOooool20?l009kooooo0@000001ooooo`004_ooool0
1?l0003oooooooooool00008ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003o
ooooo`000008ooooo`0300000?oooooooooo04Wooooo00<0o`00ooooooooool0WOooool10000007o
oooo000Cooooo`;o00002_ooool2o`0000;ooooo1Ol000000ooooooo0000o`000003o`0000Cooooo
00<00000ooooooooool0BOooool00`3o003oooooooooo`2Mooooo`4000000Oooool003;ooooo00<0
0000ooooooooool0B?ooool00`3o003oooooooooo`2Nooooo`4000000Oooool003;ooooo00<00000
o`000?ooool0B?ooool00`3o003oooooooooo`2Mooooo`7o00000@000001ooooo`00<_ooool00`00
003oooooooooo`17ooooo`030?l00?oooooooooo09oooooo0@000001ooooo`00<_ooool00`00003o
ooooooooo`17ooooo`030?l00?oooooooooo09oooooo0@000001ooooo`00<_ooool00`00003ooooo
ooooo`16ooooo`80o`00XOooool10000007ooooo000booooo`0300000?oooooooooo04Kooooo00<0
o`00ooooooooool0X?ooool10000007ooooo000booooo`0300000?oooooooooo04Gooooo00<0o`00
ooooooooool0XOooool10000007ooooo000booooo`0300000?l0003ooooo04Gooooo00<0o`00oooo
ooooool0X?ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0AOooool00`3o003o
ooooooooo`2Qooooo`4000000Oooool003;ooooo00<00000ooooooooool0A?ooool00`3o003ooooo
ooooo`2Rooooo`4000000Oooool003;ooooo00<00000ooooooooool0A?ooool00`3o003ooooooooo
o`2Rooooo`4000000Oooool003;ooooo00<00000ooooooooool0@oooool00`3o003oooooooooo`2S
ooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000booooo`03
00000?l0003ooooo04;ooooo0P3o002Tooooo`7o00000@000001ooooo`00<_ooool00`00003ooooo
ooooo`3Yooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000b
ooooo`0300000?oooooooooo047ooooo00<0o`00ooooooooool0YOooool10000007ooooo000boooo
o`0300000?oooooooooo043ooooo00<0o`00ooooooooool0Y_ooool10000007ooooo000booooo`03
00000?oooooooooo043ooooo00<0o`00ooooooooool0Y_ooool10000007ooooo000booooo`030000
0?l0003ooooo03oooooo00<0o`00ooooooooool0Y_ooool1o`00004000000Oooool003;ooooo00<0
0000ooooooooool0?oooool00`3o003oooooooooo`2Wooooo`4000000Oooool003;ooooo00<00000
ooooooooool0?_ooool20?l00:Wooooo0@000001ooooo`007oooool2o`0000Cooooo00?o0000oooo
ooooool00_ooool3o`0000Gooooo00<00000ooooooooool0?_ooool00`3o003oooooooooo`2Xoooo
o`4000000Oooool001kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04oooo
o`0300000?oooooooooo01[ooooo00<00000ooooooooool06oooool00`00003oooooooooo`02oooo
o`80o`005oooool00`00003oooooooooo`0Jooooo`0300000?oooooooooo01_ooooo00<00000oooo
ooooool06_ooool00`00003oooooooooo`0Kooooo`0300000?oooooooooo01[ooooo0@000001oooo
o`007_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00<00000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00<00000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00`00003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00<00000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool10000007ooooo000Nooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01?oooom0000000030?l00000000000000:X000000Oooool001kooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`3booooo`007_ooool01?l0003oooooooooool00008oooo
o`;o0000m?ooool001oooooo0_l0000:ooooo`03o`000?oooooooooo0?;ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo003oooooob7ooooo
003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{73.4375, 302.812}, {286.438, 57.0625}} -> {0.279553, \
-0.0692379, 0.000846872, 0.000846872}}]
}, Open  ]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Note that the slope of the line formed by the black points (the \
unstable direction) is approximately 0.7 and the slope of the first \
eigenvector is 0.69.  The slope of the line formed by the red points (the \
stable direction) is approximately -2.2 while the slope of the second \
eigenvector is -2.19.\
\>", "Text"],

Cell["\<\
By generating several such plots for different values of niter we \
can create an animation illustrating the outflow of trajectories along the \
unstable manifold (for the forward map) and along the stable manifold (for \
the inverse map).\
\>", "Text"],

Cell[TextData[{
  "The second approach to visualizing the effect of the eigenvectors is to \
construct a flow diagram for the dynamics in the vicinity of the fixed point. \
 To do this we must use the standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " package ",
  StyleBox["PlotField", "Input"],
  ".  "
}], "Text"],

Cell[BoxData[
    \(<< Graphics`PlotField`\)], "Input"],

Cell["\<\
Then we construct a vector field that shows the direction that that \
any point in the phase space will be mapped by the mapping function.  This \
vector field is simply the vector valued function with \[Theta]-coordinate \
equal to the change in \[Theta] produced by the map and with r-coordinate \
equal to the change in r produced by the map.  For the Standard Map this is \
just\
\>", "Text"],

Cell[BoxData[
    \(\(Flow[{\[Theta]_, r_}] := 
        N[{r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], \(-\((K/\((2*Pi)\))\)\)*
              Sin[2*Pi*\[Theta]]}];\)\)], "Input"],

Cell[TextData[{
  "Now we can construct our flow diagram by using the ",
  StyleBox["PlotVectorField", "Input"],
  " function from the ",
  StyleBox["PlotField", "Input"],
  " package."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 1.5;\)\), "\[IndentingNewLine]", 
    \(PlotVectorField[
      Flow[{\[Theta], r}], {\[Theta], 0.49, 0.51}, {r, \(-0.01\), 0.01}, 
      Frame \[Rule] True, PlotPoints \[Rule] 15, 
      FrameLabel \[Rule] {"\<\[Theta]\>", "\<r\>", "\<\>", "\<\>"}, 
      RotateLabel \[Rule] False]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .95633 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-20.711 42.422 0.478164 42.422 [
[.07578 -0.0125 -12 -9 ]
[.07578 -0.0125 12 0 ]
[.28789 -0.0125 -15 -9 ]
[.28789 -0.0125 15 0 ]
[.5 -0.0125 -9 -9 ]
[.5 -0.0125 9 0 ]
[.71211 -0.0125 -15 -9 ]
[.71211 -0.0125 15 0 ]
[.92422 -0.0125 -12 -9 ]
[.92422 -0.0125 12 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .05394 -30 -4.5 ]
[-0.0125 .05394 0 4.5 ]
[-0.0125 .26605 -36 -4.5 ]
[-0.0125 .26605 0 4.5 ]
[-0.0125 .47816 -6 -4.5 ]
[-0.0125 .47816 0 4.5 ]
[-0.0125 .69027 -30 -4.5 ]
[-0.0125 .69027 0 4.5 ]
[-0.0125 .90238 -24 -4.5 ]
[-0.0125 .90238 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .47816 -46 -6 ]
[-0.01875 .47816 -36 6 ]
[ 0 .95633 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .95633 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07578 0 m
.07578 .00625 L
s
[(0.49)] .07578 -0.0125 0 1 Mshowa
.28789 0 m
.28789 .00625 L
s
[(0.495)] .28789 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0.5)] .5 -0.0125 0 1 Mshowa
.71211 0 m
.71211 .00625 L
s
[(0.505)] .71211 -0.0125 0 1 Mshowa
.92422 0 m
.92422 .00625 L
s
[(0.51)] .92422 -0.0125 0 1 Mshowa
.125 Mabswid
.1182 0 m
.1182 .00375 L
s
.16062 0 m
.16062 .00375 L
s
.20305 0 m
.20305 .00375 L
s
.24547 0 m
.24547 .00375 L
s
.33031 0 m
.33031 .00375 L
s
.37273 0 m
.37273 .00375 L
s
.41516 0 m
.41516 .00375 L
s
.45758 0 m
.45758 .00375 L
s
.54242 0 m
.54242 .00375 L
s
.58484 0 m
.58484 .00375 L
s
.62727 0 m
.62727 .00375 L
s
.66969 0 m
.66969 .00375 L
s
.75453 0 m
.75453 .00375 L
s
.79695 0 m
.79695 .00375 L
s
.83938 0 m
.83938 .00375 L
s
.8818 0 m
.8818 .00375 L
s
.03336 0 m
.03336 .00375 L
s
.96664 0 m
.96664 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .05394 m
.00625 .05394 L
s
[(-0.01)] -0.0125 .05394 1 0 Mshowa
0 .26605 m
.00625 .26605 L
s
[(-0.005)] -0.0125 .26605 1 0 Mshowa
0 .47816 m
.00625 .47816 L
s
[(0)] -0.0125 .47816 1 0 Mshowa
0 .69027 m
.00625 .69027 L
s
[(0.005)] -0.0125 .69027 1 0 Mshowa
0 .90238 m
.00625 .90238 L
s
[(0.01)] -0.0125 .90238 1 0 Mshowa
.125 Mabswid
0 .09637 m
.00375 .09637 L
s
0 .13879 m
.00375 .13879 L
s
0 .18121 m
.00375 .18121 L
s
0 .22363 m
.00375 .22363 L
s
0 .30848 m
.00375 .30848 L
s
0 .3509 m
.00375 .3509 L
s
0 .39332 m
.00375 .39332 L
s
0 .43574 m
.00375 .43574 L
s
0 .52059 m
.00375 .52059 L
s
0 .56301 m
.00375 .56301 L
s
0 .60543 m
.00375 .60543 L
s
0 .64785 m
.00375 .64785 L
s
0 .7327 m
.00375 .7327 L
s
0 .77512 m
.00375 .77512 L
s
0 .81754 m
.00375 .81754 L
s
0 .85996 m
.00375 .85996 L
s
0 .01152 m
.00375 .01152 L
s
0 .94481 m
.00375 .94481 L
s
.25 Mabswid
0 0 m
0 .95633 L
s
gsave
-0.01875 .47816 -107 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.07578 .95008 m
.07578 .95633 L
s
.28789 .95008 m
.28789 .95633 L
s
.5 .95008 m
.5 .95633 L
s
.71211 .95008 m
.71211 .95633 L
s
.92422 .95008 m
.92422 .95633 L
s
.125 Mabswid
.1182 .95258 m
.1182 .95633 L
s
.16062 .95258 m
.16062 .95633 L
s
.20305 .95258 m
.20305 .95633 L
s
.24547 .95258 m
.24547 .95633 L
s
.33031 .95258 m
.33031 .95633 L
s
.37273 .95258 m
.37273 .95633 L
s
.41516 .95258 m
.41516 .95633 L
s
.45758 .95258 m
.45758 .95633 L
s
.54242 .95258 m
.54242 .95633 L
s
.58484 .95258 m
.58484 .95633 L
s
.62727 .95258 m
.62727 .95633 L
s
.66969 .95258 m
.66969 .95633 L
s
.75453 .95258 m
.75453 .95633 L
s
.79695 .95258 m
.79695 .95633 L
s
.83938 .95258 m
.83938 .95633 L
s
.8818 .95258 m
.8818 .95633 L
s
.03336 .95258 m
.03336 .95633 L
s
.96664 .95258 m
.96664 .95633 L
s
.25 Mabswid
0 .95633 m
1 .95633 L
s
.99375 .05394 m
1 .05394 L
s
.99375 .26605 m
1 .26605 L
s
.99375 .47816 m
1 .47816 L
s
.99375 .69027 m
1 .69027 L
s
.99375 .90238 m
1 .90238 L
s
.125 Mabswid
.99625 .09637 m
1 .09637 L
s
.99625 .13879 m
1 .13879 L
s
.99625 .18121 m
1 .18121 L
s
.99625 .22363 m
1 .22363 L
s
.99625 .30848 m
1 .30848 L
s
.99625 .3509 m
1 .3509 L
s
.99625 .39332 m
1 .39332 L
s
.99625 .43574 m
1 .43574 L
s
.99625 .52059 m
1 .52059 L
s
.99625 .56301 m
1 .56301 L
s
.99625 .60543 m
1 .60543 L
s
.99625 .64785 m
1 .64785 L
s
.99625 .7327 m
1 .7327 L
s
.99625 .77512 m
1 .77512 L
s
.99625 .81754 m
1 .81754 L
s
.99625 .85996 m
1 .85996 L
s
.99625 .01152 m
1 .01152 L
s
.99625 .94481 m
1 .94481 L
s
.25 Mabswid
1 0 m
1 .95633 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.07578 .05394 m
.02381 .02277 L
s
% Start of user PostScript
0.49 -0.01 0.488775 -0.0107349 MAarrowhead1
% End of user PostScript
.07578 .11455 m
.02678 .08337 L
s
% Start of user PostScript
0.49 -0.00857143 0.488845 -0.00930628 MAarrowhead1
% End of user PostScript
.07578 .17515 m
.02975 .14398 L
s
% Start of user PostScript
0.49 -0.00714286 0.488915 -0.00787771 MAarrowhead1
% End of user PostScript
.07578 .23575 m
.03272 .20458 L
s
% Start of user PostScript
0.49 -0.00571429 0.488985 -0.00644914 MAarrowhead1
% End of user PostScript
.07578 .29636 m
.03569 .26518 L
s
% Start of user PostScript
0.49 -0.00428571 0.489055 -0.00502057 MAarrowhead1
% End of user PostScript
.07578 .35696 m
.03866 .32578 L
s
% Start of user PostScript
0.49 -0.00285714 0.489125 -0.00359199 MAarrowhead1
% End of user PostScript
.07578 .41756 m
.04163 .38639 L
s
% Start of user PostScript
0.49 -0.00142857 0.489195 -0.00216342 MAarrowhead1
% End of user PostScript
.07578 .47816 m
.04461 .44699 L
s
% Start of user PostScript
0.49 0 0.489265 -0.000734852 MAarrowhead1
% End of user PostScript
.07578 .53877 m
.04758 .50759 L
s
% Start of user PostScript
0.49 0.00142857 0.489335 0.00069372 MAarrowhead1
% End of user PostScript
.07578 .59937 m
.05055 .5682 L
s
% Start of user PostScript
0.49 0.00285714 0.489405 0.00212229 MAarrowhead1
% End of user PostScript
.07578 .65997 m
.05352 .6288 L
s
% Start of user PostScript
0.49 0.00428571 0.489475 0.00355086 MAarrowhead1
% End of user PostScript
.07578 .72058 m
.05649 .6894 L
s
% Start of user PostScript
0.49 0.00571429 0.489545 0.00497943 MAarrowhead1
% End of user PostScript
.07578 .78118 m
.05946 .75 L
s
% Start of user PostScript
0.49 0.00714286 0.489615 0.00640801 MAarrowhead1
% End of user PostScript
.07578 .84178 m
.06243 .81061 L
s
% Start of user PostScript
0.49 0.00857143 0.489685 0.00783658 MAarrowhead1
% End of user PostScript
.07578 .90238 m
.0654 .87121 L
s
% Start of user PostScript
0.49 0.01 0.489755 0.00926515 MAarrowhead1
% End of user PostScript
.13638 .05394 m
.08886 .02722 L
s
% Start of user PostScript
0.491429 -0.01 0.490308 -0.01063 MAarrowhead1
% End of user PostScript
.13638 .11455 m
.09183 .08782 L
s
% Start of user PostScript
0.491429 -0.00857143 0.490378 -0.00920141 MAarrowhead1
% End of user PostScript
.13638 .17515 m
.0948 .14842 L
s
% Start of user PostScript
0.491429 -0.00714286 0.490448 -0.00777284 MAarrowhead1
% End of user PostScript
.13638 .23575 m
.09777 .20903 L
s
% Start of user PostScript
0.491429 -0.00571429 0.490518 -0.00634427 MAarrowhead1
% End of user PostScript
.13638 .29636 m
.10074 .26963 L
s
% Start of user PostScript
0.491429 -0.00428571 0.490588 -0.0049157 MAarrowhead1
% End of user PostScript
.13638 .35696 m
.10372 .33023 L
s
% Start of user PostScript
0.491429 -0.00285714 0.490659 -0.00348713 MAarrowhead1
% End of user PostScript
.13638 .41756 m
.10669 .39084 L
s
% Start of user PostScript
0.491429 -0.00142857 0.490729 -0.00205855 MAarrowhead1
% End of user PostScript
.13638 .47816 m
.10966 .45144 L
s
% Start of user PostScript
0.491429 0 0.490799 -0.000629983 MAarrowhead1
% End of user PostScript
.13638 .53877 m
.11263 .51204 L
s
% Start of user PostScript
0.491429 0.00142857 0.490869 0.000798589 MAarrowhead1
% End of user PostScript
.13638 .59937 m
.1156 .57264 L
s
% Start of user PostScript
0.491429 0.00285714 0.490939 0.00222716 MAarrowhead1
% End of user PostScript
.13638 .65997 m
.11857 .63325 L
s
% Start of user PostScript
0.491429 0.00428571 0.491009 0.00365573 MAarrowhead1
% End of user PostScript
.13638 .72058 m
.12154 .69385 L
s
% Start of user PostScript
0.491429 0.00571429 0.491079 0.0050843 MAarrowhead1
% End of user PostScript
.13638 .78118 m
.12451 .75445 L
s
% Start of user PostScript
0.491429 0.00714286 0.491149 0.00651287 MAarrowhead1
% End of user PostScript
.13638 .84178 m
.12748 .81506 L
s
% Start of user PostScript
0.491429 0.00857143 0.491219 0.00794145 MAarrowhead1
% End of user PostScript
.13638 .90238 m
.13045 .87566 L
s
% Start of user PostScript
0.491429 0.01 0.491289 0.00937002 MAarrowhead1
% End of user PostScript
.19699 .05394 m
.15391 .03167 L
s
% Start of user PostScript
0.492857 -0.01 0.491842 -0.0105251 MAarrowhead1
% End of user PostScript
.19699 .11455 m
.15689 .09227 L
s
% Start of user PostScript
0.492857 -0.00857143 0.491912 -0.00909649 MAarrowhead1
% End of user PostScript
.19699 .17515 m
.15986 .15288 L
s
% Start of user PostScript
0.492857 -0.00714286 0.491982 -0.00766792 MAarrowhead1
% End of user PostScript
.19699 .23575 m
.16283 .21348 L
s
% Start of user PostScript
0.492857 -0.00571429 0.492052 -0.00623935 MAarrowhead1
% End of user PostScript
.19699 .29636 m
.1658 .27408 L
s
% Start of user PostScript
0.492857 -0.00428571 0.492122 -0.00481078 MAarrowhead1
% End of user PostScript
.19699 .35696 m
.16877 .33468 L
s
% Start of user PostScript
0.492857 -0.00285714 0.492192 -0.00338221 MAarrowhead1
% End of user PostScript
.19699 .41756 m
.17174 .39529 L
s
% Start of user PostScript
0.492857 -0.00142857 0.492262 -0.00195363 MAarrowhead1
% End of user PostScript
.19699 .47816 m
.17471 .45589 L
s
% Start of user PostScript
0.492857 0 0.492332 -0.000525063 MAarrowhead1
% End of user PostScript
.19699 .53877 m
.17768 .51649 L
s
% Start of user PostScript
0.492857 0.00142857 0.492402 0.000903508 MAarrowhead1
% End of user PostScript
.19699 .59937 m
.18065 .5771 L
s
% Start of user PostScript
0.492857 0.00285714 0.492472 0.00233208 MAarrowhead1
% End of user PostScript
.19699 .65997 m
.18362 .6377 L
s
% Start of user PostScript
0.492857 0.00428571 0.492542 0.00376065 MAarrowhead1
% End of user PostScript
.19699 .72058 m
.18659 .6983 L
s
% Start of user PostScript
0.492857 0.00571429 0.492612 0.00518922 MAarrowhead1
% End of user PostScript
.19699 .78118 m
.18957 .7589 L
s
% Start of user PostScript
0.492857 0.00714286 0.492682 0.00661779 MAarrowhead1
% End of user PostScript
.19699 .84178 m
.19254 .81951 L
s
% Start of user PostScript
0.492857 0.00857143 0.492752 0.00804637 MAarrowhead1
% End of user PostScript
.19699 .90238 m
.19551 .88011 L
s
% Start of user PostScript
0.492857 0.01 0.492822 0.00947494 MAarrowhead1
% End of user PostScript
.25759 .05394 m
.21897 .03612 L
s
% Start of user PostScript
0.494286 -0.01 0.493375 -0.0104201 MAarrowhead1
% End of user PostScript
.25759 .11455 m
.22194 .09672 L
s
% Start of user PostScript
0.494286 -0.00857143 0.493445 -0.00899153 MAarrowhead1
% End of user PostScript
.25759 .17515 m
.22491 .15733 L
s
% Start of user PostScript
0.494286 -0.00714286 0.493515 -0.00756296 MAarrowhead1
% End of user PostScript
.25759 .23575 m
.22788 .21793 L
s
% Start of user PostScript
0.494286 -0.00571429 0.493585 -0.00613439 MAarrowhead1
% End of user PostScript
.25759 .29636 m
.23085 .27853 L
s
% Start of user PostScript
0.494286 -0.00428571 0.493656 -0.00470582 MAarrowhead1
% End of user PostScript
.25759 .35696 m
.23383 .33914 L
s
% Start of user PostScript
0.494286 -0.00285714 0.493726 -0.00327724 MAarrowhead1
% End of user PostScript
.25759 .41756 m
.2368 .39974 L
s
% Start of user PostScript
0.494286 -0.00142857 0.493796 -0.00184867 MAarrowhead1
% End of user PostScript
.25759 .47816 m
.23977 .46034 L
s
% Start of user PostScript
0.494286 0 0.493866 -0.000420101 MAarrowhead1
% End of user PostScript
.25759 .53877 m
.24274 .52095 L
s
% Start of user PostScript
0.494286 0.00142857 0.493936 0.00100847 MAarrowhead1
% End of user PostScript
.25759 .59937 m
.24571 .58155 L
s
% Start of user PostScript
0.494286 0.00285714 0.494006 0.00243704 MAarrowhead1
% End of user PostScript
.25759 .65997 m
.24868 .64215 L
s
% Start of user PostScript
0.494286 0.00428571 0.494076 0.00386561 MAarrowhead1
% End of user PostScript
.25759 .72058 m
.25165 .70275 L
s
% Start of user PostScript
0.494286 0.00571429 0.494146 0.00529418 MAarrowhead1
% End of user PostScript
.25759 .78118 m
.25462 .76336 L
s
% Start of user PostScript
0.494286 0.00714286 0.494216 0.00672276 MAarrowhead1
% End of user PostScript
.25759 .84178 m
.25759 .82396 L
s
% Start of user PostScript
0.494286 0.00857143 0.494286 0.00815133 MAarrowhead1
% End of user PostScript
.25759 .90238 m
.26056 .88456 L
s
% Start of user PostScript
0.494286 0.01 0.494356 0.0095799 MAarrowhead1
% End of user PostScript
.31819 .05394 m
.28403 .04058 L
s
% Start of user PostScript
0.495714 -0.01 0.494909 -0.0103151 MAarrowhead1
% End of user PostScript
.31819 .11455 m
.287 .10118 L
s
% Start of user PostScript
0.495714 -0.00857143 0.494979 -0.00888653 MAarrowhead1
% End of user PostScript
.31819 .17515 m
.28997 .16178 L
s
% Start of user PostScript
0.495714 -0.00714286 0.495049 -0.00745796 MAarrowhead1
% End of user PostScript
.31819 .23575 m
.29294 .22238 L
s
% Start of user PostScript
0.495714 -0.00571429 0.495119 -0.00602939 MAarrowhead1
% End of user PostScript
.31819 .29636 m
.29591 .28299 L
s
% Start of user PostScript
0.495714 -0.00428571 0.495189 -0.00460082 MAarrowhead1
% End of user PostScript
.31819 .35696 m
.29888 .34359 L
s
% Start of user PostScript
0.495714 -0.00285714 0.495259 -0.00317225 MAarrowhead1
% End of user PostScript
.31819 .41756 m
.30185 .40419 L
s
% Start of user PostScript
0.495714 -0.00142857 0.495329 -0.00174368 MAarrowhead1
% End of user PostScript
.31819 .47816 m
.30482 .4648 L
s
% Start of user PostScript
0.495714 0 0.495399 -0.000315106 MAarrowhead1
% End of user PostScript
.31819 .53877 m
.30779 .5254 L
s
% Start of user PostScript
0.495714 0.00142857 0.495469 0.00111347 MAarrowhead1
% End of user PostScript
.31819 .59937 m
.31077 .586 L
s
% Start of user PostScript
0.495714 0.00285714 0.495539 0.00254204 MAarrowhead1
% End of user PostScript
.31819 .65997 m
.31374 .64661 L
s
% Start of user PostScript
0.495714 0.00428571 0.495609 0.00397061 MAarrowhead1
% End of user PostScript
.31819 .72058 m
.31671 .70721 L
s
% Start of user PostScript
0.495714 0.00571429 0.495679 0.00539918 MAarrowhead1
% End of user PostScript
.31819 .78118 m
.31968 .76781 L
s
% Start of user PostScript
0.495714 0.00714286 0.495749 0.00682775 MAarrowhead1
% End of user PostScript
.31819 .84178 m
.32265 .82841 L
s
% Start of user PostScript
0.495714 0.00857143 0.495819 0.00825632 MAarrowhead1
% End of user PostScript
.31819 .90238 m
.32562 .88902 L
s
% Start of user PostScript
0.495714 0.01 0.495889 0.00968489 MAarrowhead1
% End of user PostScript
.37879 .05394 m
.34909 .04503 L
s
% Start of user PostScript
0.497143 -0.01 0.496443 -0.0102101 MAarrowhead1
% End of user PostScript
.37879 .11455 m
.35206 .10563 L
s
% Start of user PostScript
0.497143 -0.00857143 0.496513 -0.00878151 MAarrowhead1
% End of user PostScript
.37879 .17515 m
.35503 .16624 L
s
% Start of user PostScript
0.497143 -0.00714286 0.496583 -0.00735294 MAarrowhead1
% End of user PostScript
.37879 .23575 m
.358 .22684 L
s
% Start of user PostScript
0.497143 -0.00571429 0.496653 -0.00592437 MAarrowhead1
% End of user PostScript
.37879 .29636 m
.36097 .28744 L
s
% Start of user PostScript
0.497143 -0.00428571 0.496723 -0.0044958 MAarrowhead1
% End of user PostScript
.37879 .35696 m
.36394 .34805 L
s
% Start of user PostScript
0.497143 -0.00285714 0.496793 -0.00306723 MAarrowhead1
% End of user PostScript
.37879 .41756 m
.36691 .40865 L
s
% Start of user PostScript
0.497143 -0.00142857 0.496863 -0.00163866 MAarrowhead1
% End of user PostScript
.37879 .47816 m
.36988 .46925 L
s
% Start of user PostScript
0.497143 0 0.496933 -0.000210085 MAarrowhead1
% End of user PostScript
.37879 .53877 m
.37285 .52985 L
s
% Start of user PostScript
0.497143 0.00142857 0.497003 0.00121849 MAarrowhead1
% End of user PostScript
.37879 .59937 m
.37582 .59046 L
s
% Start of user PostScript
0.497143 0.00285714 0.497073 0.00264706 MAarrowhead1
% End of user PostScript
.37879 .65997 m
.37879 .65106 L
s
% Start of user PostScript
0.497143 0.00428571 0.497143 0.00407563 MAarrowhead1
% End of user PostScript
.37879 .72058 m
.38177 .71166 L
s
% Start of user PostScript
0.497143 0.00571429 0.497213 0.0055042 MAarrowhead1
% End of user PostScript
.37879 .78118 m
.38474 .77227 L
s
% Start of user PostScript
0.497143 0.00714286 0.497283 0.00693277 MAarrowhead1
% End of user PostScript
.37879 .84178 m
.38771 .83287 L
s
% Start of user PostScript
0.497143 0.00857143 0.497353 0.00836134 MAarrowhead1
% End of user PostScript
.37879 .90238 m
.39068 .89347 L
s
% Start of user PostScript
0.497143 0.01 0.497423 0.00978992 MAarrowhead1
% End of user PostScript
.4394 .05394 m
.41414 .04949 L
s
% Start of user PostScript
0.498571 -0.01 0.497976 -0.010105 MAarrowhead1
% End of user PostScript
.4394 .11455 m
.41712 .11009 L
s
% Start of user PostScript
0.498571 -0.00857143 0.498046 -0.00867648 MAarrowhead1
% End of user PostScript
.4394 .17515 m
.42009 .17069 L
s
% Start of user PostScript
0.498571 -0.00714286 0.498116 -0.0072479 MAarrowhead1
% End of user PostScript
.4394 .23575 m
.42306 .2313 L
s
% Start of user PostScript
0.498571 -0.00571429 0.498186 -0.00581933 MAarrowhead1
% End of user PostScript
.4394 .29636 m
.42603 .2919 L
s
% Start of user PostScript
0.498571 -0.00428571 0.498256 -0.00439076 MAarrowhead1
% End of user PostScript
.4394 .35696 m
.429 .3525 L
s
% Start of user PostScript
0.498571 -0.00285714 0.498326 -0.00296219 MAarrowhead1
% End of user PostScript
.4394 .41756 m
.43197 .4131 L
s
% Start of user PostScript
0.498571 -0.00142857 0.498396 -0.00153362 MAarrowhead1
% End of user PostScript
.4394 .47816 m
.43494 .47371 L
s
% Start of user PostScript
0.498571 0 0.498466 -0.000105047 MAarrowhead1
% End of user PostScript
.4394 .53877 m
.43791 .53431 L
s
% Start of user PostScript
0.498571 0.00142857 0.498536 0.00132352 MAarrowhead1
% End of user PostScript
.4394 .59937 m
.44088 .59491 L
s
% Start of user PostScript
0.498571 0.00285714 0.498606 0.0027521 MAarrowhead1
% End of user PostScript
.4394 .65997 m
.44385 .65552 L
s
% Start of user PostScript
0.498571 0.00428571 0.498676 0.00418067 MAarrowhead1
% End of user PostScript
.4394 .72058 m
.44682 .71612 L
s
% Start of user PostScript
0.498571 0.00571429 0.498747 0.00560924 MAarrowhead1
% End of user PostScript
.4394 .78118 m
.4498 .77672 L
s
% Start of user PostScript
0.498571 0.00714286 0.498817 0.00703781 MAarrowhead1
% End of user PostScript
.4394 .84178 m
.45277 .83733 L
s
% Start of user PostScript
0.498571 0.00857143 0.498887 0.00846638 MAarrowhead1
% End of user PostScript
.4394 .90238 m
.45574 .89793 L
s
% Start of user PostScript
0.498571 0.01 0.498957 0.00989495 MAarrowhead1
% End of user PostScript
.5 .05394 m
.4792 .05394 L
s
% Start of user PostScript
0.5 -0.01 0.49951 -0.01 MAarrowhead1
% End of user PostScript
.5 .11455 m
.48217 .11455 L
s
% Start of user PostScript
0.5 -0.00857143 0.49958 -0.00857143 MAarrowhead1
% End of user PostScript
.5 .17515 m
.48515 .17515 L
s
% Start of user PostScript
0.5 -0.00714286 0.49965 -0.00714286 MAarrowhead1
% End of user PostScript
.5 .23575 m
.48812 .23575 L
s
% Start of user PostScript
0.5 -0.00571429 0.49972 -0.00571429 MAarrowhead1
% End of user PostScript
.5 .29636 m
.49109 .29636 L
s
% Start of user PostScript
0.5 -0.00428571 0.49979 -0.00428571 MAarrowhead1
% End of user PostScript
.5 .35696 m
.49406 .35696 L
s
% Start of user PostScript
0.5 -0.00285714 0.49986 -0.00285714 MAarrowhead1
% End of user PostScript
.5 .41756 m
.49703 .41756 L
s
% Start of user PostScript
0.5 -0.00142857 0.49993 -0.00142857 MAarrowhead1
% End of user PostScript
.5 .47816 m
.5 .47816 L
s
% Start of user PostScript
0.5 0 MAarrowzero1
% End of user PostScript
.5 .53877 m
.50297 .53877 L
s
% Start of user PostScript
0.5 0.00142857 0.50007 0.00142857 MAarrowhead1
% End of user PostScript
.5 .59937 m
.50594 .59937 L
s
% Start of user PostScript
0.5 0.00285714 0.50014 0.00285714 MAarrowhead1
% End of user PostScript
.5 .65997 m
.50891 .65997 L
s
% Start of user PostScript
0.5 0.00428571 0.50021 0.00428571 MAarrowhead1
% End of user PostScript
.5 .72058 m
.51188 .72058 L
s
% Start of user PostScript
0.5 0.00571429 0.50028 0.00571429 MAarrowhead1
% End of user PostScript
.5 .78118 m
.51485 .78118 L
s
% Start of user PostScript
0.5 0.00714286 0.50035 0.00714286 MAarrowhead1
% End of user PostScript
.5 .84178 m
.51783 .84178 L
s
% Start of user PostScript
0.5 0.00857143 0.50042 0.00857143 MAarrowhead1
% End of user PostScript
.5 .90238 m
.5208 .90238 L
s
% Start of user PostScript
0.5 0.01 0.50049 0.01 MAarrowhead1
% End of user PostScript
.5606 .05394 m
.54426 .0584 L
s
% Start of user PostScript
0.501429 -0.01 0.501043 -0.00989495 MAarrowhead1
% End of user PostScript
.5606 .11455 m
.54723 .119 L
s
% Start of user PostScript
0.501429 -0.00857143 0.501113 -0.00846638 MAarrowhead1
% End of user PostScript
.5606 .17515 m
.5502 .17961 L
s
% Start of user PostScript
0.501429 -0.00714286 0.501183 -0.00703781 MAarrowhead1
% End of user PostScript
.5606 .23575 m
.55318 .24021 L
s
% Start of user PostScript
0.501429 -0.00571429 0.501253 -0.00560924 MAarrowhead1
% End of user PostScript
.5606 .29636 m
.55615 .30081 L
s
% Start of user PostScript
0.501429 -0.00428571 0.501324 -0.00418067 MAarrowhead1
% End of user PostScript
.5606 .35696 m
.55912 .36141 L
s
% Start of user PostScript
0.501429 -0.00285714 0.501394 -0.0027521 MAarrowhead1
% End of user PostScript
.5606 .41756 m
.56209 .42202 L
s
% Start of user PostScript
0.501429 -0.00142857 0.501464 -0.00132352 MAarrowhead1
% End of user PostScript
.5606 .47816 m
.56506 .48262 L
s
% Start of user PostScript
0.501429 0 0.501534 0.000105047 MAarrowhead1
% End of user PostScript
.5606 .53877 m
.56803 .54322 L
s
% Start of user PostScript
0.501429 0.00142857 0.501604 0.00153362 MAarrowhead1
% End of user PostScript
.5606 .59937 m
.571 .60383 L
s
% Start of user PostScript
0.501429 0.00285714 0.501674 0.00296219 MAarrowhead1
% End of user PostScript
.5606 .65997 m
.57397 .66443 L
s
% Start of user PostScript
0.501429 0.00428571 0.501744 0.00439076 MAarrowhead1
% End of user PostScript
.5606 .72058 m
.57694 .72503 L
s
% Start of user PostScript
0.501429 0.00571429 0.501814 0.00581933 MAarrowhead1
% End of user PostScript
.5606 .78118 m
.57991 .78563 L
s
% Start of user PostScript
0.501429 0.00714286 0.501884 0.0072479 MAarrowhead1
% End of user PostScript
.5606 .84178 m
.58288 .84624 L
s
% Start of user PostScript
0.501429 0.00857143 0.501954 0.00867648 MAarrowhead1
% End of user PostScript
.5606 .90238 m
.58586 .90684 L
s
% Start of user PostScript
0.501429 0.01 0.502024 0.010105 MAarrowhead1
% End of user PostScript
.62121 .05394 m
.60932 .06286 L
s
% Start of user PostScript
0.502857 -0.01 0.502577 -0.00978992 MAarrowhead1
% End of user PostScript
.62121 .11455 m
.61229 .12346 L
s
% Start of user PostScript
0.502857 -0.00857143 0.502647 -0.00836134 MAarrowhead1
% End of user PostScript
.62121 .17515 m
.61526 .18406 L
s
% Start of user PostScript
0.502857 -0.00714286 0.502717 -0.00693277 MAarrowhead1
% End of user PostScript
.62121 .23575 m
.61823 .24466 L
s
% Start of user PostScript
0.502857 -0.00571429 0.502787 -0.0055042 MAarrowhead1
% End of user PostScript
.62121 .29636 m
.62121 .30527 L
s
% Start of user PostScript
0.502857 -0.00428571 0.502857 -0.00407563 MAarrowhead1
% End of user PostScript
.62121 .35696 m
.62418 .36587 L
s
% Start of user PostScript
0.502857 -0.00285714 0.502927 -0.00264706 MAarrowhead1
% End of user PostScript
.62121 .41756 m
.62715 .42647 L
s
% Start of user PostScript
0.502857 -0.00142857 0.502997 -0.00121849 MAarrowhead1
% End of user PostScript
.62121 .47816 m
.63012 .48708 L
s
% Start of user PostScript
0.502857 0 0.503067 0.000210085 MAarrowhead1
% End of user PostScript
.62121 .53877 m
.63309 .54768 L
s
% Start of user PostScript
0.502857 0.00142857 0.503137 0.00163866 MAarrowhead1
% End of user PostScript
.62121 .59937 m
.63606 .60828 L
s
% Start of user PostScript
0.502857 0.00285714 0.503207 0.00306723 MAarrowhead1
% End of user PostScript
.62121 .65997 m
.63903 .66888 L
s
% Start of user PostScript
0.502857 0.00428571 0.503277 0.0044958 MAarrowhead1
% End of user PostScript
.62121 .72058 m
.642 .72949 L
s
% Start of user PostScript
0.502857 0.00571429 0.503347 0.00592437 MAarrowhead1
% End of user PostScript
.62121 .78118 m
.64497 .79009 L
s
% Start of user PostScript
0.502857 0.00714286 0.503417 0.00735294 MAarrowhead1
% End of user PostScript
.62121 .84178 m
.64794 .85069 L
s
% Start of user PostScript
0.502857 0.00857143 0.503487 0.00878151 MAarrowhead1
% End of user PostScript
.62121 .90238 m
.65091 .9113 L
s
% Start of user PostScript
0.502857 0.01 0.503557 0.0102101 MAarrowhead1
% End of user PostScript
.68181 .05394 m
.67438 .06731 L
s
% Start of user PostScript
0.504286 -0.01 0.504111 -0.00968489 MAarrowhead1
% End of user PostScript
.68181 .11455 m
.67735 .12791 L
s
% Start of user PostScript
0.504286 -0.00857143 0.504181 -0.00825632 MAarrowhead1
% End of user PostScript
.68181 .17515 m
.68032 .18852 L
s
% Start of user PostScript
0.504286 -0.00714286 0.504251 -0.00682775 MAarrowhead1
% End of user PostScript
.68181 .23575 m
.68329 .24912 L
s
% Start of user PostScript
0.504286 -0.00571429 0.504321 -0.00539918 MAarrowhead1
% End of user PostScript
.68181 .29636 m
.68626 .30972 L
s
% Start of user PostScript
0.504286 -0.00428571 0.504391 -0.00397061 MAarrowhead1
% End of user PostScript
.68181 .35696 m
.68923 .37033 L
s
% Start of user PostScript
0.504286 -0.00285714 0.504461 -0.00254204 MAarrowhead1
% End of user PostScript
.68181 .41756 m
.69221 .43093 L
s
% Start of user PostScript
0.504286 -0.00142857 0.504531 -0.00111347 MAarrowhead1
% End of user PostScript
.68181 .47816 m
.69518 .49153 L
s
% Start of user PostScript
0.504286 0 0.504601 0.000315106 MAarrowhead1
% End of user PostScript
.68181 .53877 m
.69815 .55213 L
s
% Start of user PostScript
0.504286 0.00142857 0.504671 0.00174368 MAarrowhead1
% End of user PostScript
.68181 .59937 m
.70112 .61274 L
s
% Start of user PostScript
0.504286 0.00285714 0.504741 0.00317225 MAarrowhead1
% End of user PostScript
.68181 .65997 m
.70409 .67334 L
s
% Start of user PostScript
0.504286 0.00428571 0.504811 0.00460082 MAarrowhead1
% End of user PostScript
.68181 .72058 m
.70706 .73394 L
s
% Start of user PostScript
0.504286 0.00571429 0.504881 0.00602939 MAarrowhead1
% End of user PostScript
.68181 .78118 m
.71003 .79455 L
s
% Start of user PostScript
0.504286 0.00714286 0.504951 0.00745796 MAarrowhead1
% End of user PostScript
.68181 .84178 m
.713 .85515 L
s
% Start of user PostScript
0.504286 0.00857143 0.505021 0.00888653 MAarrowhead1
% End of user PostScript
.68181 .90238 m
.71597 .91575 L
s
% Start of user PostScript
0.504286 0.01 0.505091 0.0103151 MAarrowhead1
% End of user PostScript
.74241 .05394 m
.73944 .07177 L
s
% Start of user PostScript
0.505714 -0.01 0.505644 -0.0095799 MAarrowhead1
% End of user PostScript
.74241 .11455 m
.74241 .13237 L
s
% Start of user PostScript
0.505714 -0.00857143 0.505714 -0.00815133 MAarrowhead1
% End of user PostScript
.74241 .17515 m
.74538 .19297 L
s
% Start of user PostScript
0.505714 -0.00714286 0.505784 -0.00672276 MAarrowhead1
% End of user PostScript
.74241 .23575 m
.74835 .25357 L
s
% Start of user PostScript
0.505714 -0.00571429 0.505854 -0.00529418 MAarrowhead1
% End of user PostScript
.74241 .29636 m
.75132 .31418 L
s
% Start of user PostScript
0.505714 -0.00428571 0.505924 -0.00386561 MAarrowhead1
% End of user PostScript
.74241 .35696 m
.75429 .37478 L
s
% Start of user PostScript
0.505714 -0.00285714 0.505994 -0.00243704 MAarrowhead1
% End of user PostScript
.74241 .41756 m
.75726 .43538 L
s
% Start of user PostScript
0.505714 -0.00142857 0.506064 -0.00100847 MAarrowhead1
% End of user PostScript
.74241 .47816 m
.76023 .49599 L
s
% Start of user PostScript
0.505714 0 0.506134 0.000420101 MAarrowhead1
% End of user PostScript
.74241 .53877 m
.7632 .55659 L
s
% Start of user PostScript
0.505714 0.00142857 0.506204 0.00184867 MAarrowhead1
% End of user PostScript
.74241 .59937 m
.76617 .61719 L
s
% Start of user PostScript
0.505714 0.00285714 0.506274 0.00327724 MAarrowhead1
% End of user PostScript
.74241 .65997 m
.76915 .67779 L
s
% Start of user PostScript
0.505714 0.00428571 0.506344 0.00470582 MAarrowhead1
% End of user PostScript
.74241 .72058 m
.77212 .7384 L
s
% Start of user PostScript
0.505714 0.00571429 0.506415 0.00613439 MAarrowhead1
% End of user PostScript
.74241 .78118 m
.77509 .799 L
s
% Start of user PostScript
0.505714 0.00714286 0.506485 0.00756296 MAarrowhead1
% End of user PostScript
.74241 .84178 m
.77806 .8596 L
s
% Start of user PostScript
0.505714 0.00857143 0.506555 0.00899153 MAarrowhead1
% End of user PostScript
.74241 .90238 m
.78103 .92021 L
s
% Start of user PostScript
0.505714 0.01 0.506625 0.0104201 MAarrowhead1
% End of user PostScript
.80301 .05394 m
.80449 .07622 L
s
% Start of user PostScript
0.507143 -0.01 0.507178 -0.00947494 MAarrowhead1
% End of user PostScript
.80301 .11455 m
.80746 .13682 L
s
% Start of user PostScript
0.507143 -0.00857143 0.507248 -0.00804637 MAarrowhead1
% End of user PostScript
.80301 .17515 m
.81043 .19742 L
s
% Start of user PostScript
0.507143 -0.00714286 0.507318 -0.00661779 MAarrowhead1
% End of user PostScript
.80301 .23575 m
.81341 .25803 L
s
% Start of user PostScript
0.507143 -0.00571429 0.507388 -0.00518922 MAarrowhead1
% End of user PostScript
.80301 .29636 m
.81638 .31863 L
s
% Start of user PostScript
0.507143 -0.00428571 0.507458 -0.00376065 MAarrowhead1
% End of user PostScript
.80301 .35696 m
.81935 .37923 L
s
% Start of user PostScript
0.507143 -0.00285714 0.507528 -0.00233208 MAarrowhead1
% End of user PostScript
.80301 .41756 m
.82232 .43984 L
s
% Start of user PostScript
0.507143 -0.00142857 0.507598 -0.000903508 MAarrowhead1
% End of user PostScript
.80301 .47816 m
.82529 .50044 L
s
% Start of user PostScript
0.507143 0 0.507668 0.000525063 MAarrowhead1
% End of user PostScript
.80301 .53877 m
.82826 .56104 L
s
% Start of user PostScript
0.507143 0.00142857 0.507738 0.00195363 MAarrowhead1
% End of user PostScript
.80301 .59937 m
.83123 .62164 L
s
% Start of user PostScript
0.507143 0.00285714 0.507808 0.00338221 MAarrowhead1
% End of user PostScript
.80301 .65997 m
.8342 .68225 L
s
% Start of user PostScript
0.507143 0.00428571 0.507878 0.00481078 MAarrowhead1
% End of user PostScript
.80301 .72058 m
.83717 .74285 L
s
% Start of user PostScript
0.507143 0.00571429 0.507948 0.00623935 MAarrowhead1
% End of user PostScript
.80301 .78118 m
.84014 .80345 L
s
% Start of user PostScript
0.507143 0.00714286 0.508018 0.00766792 MAarrowhead1
% End of user PostScript
.80301 .84178 m
.84311 .86406 L
s
% Start of user PostScript
0.507143 0.00857143 0.508088 0.00909649 MAarrowhead1
% End of user PostScript
.80301 .90238 m
.84609 .92466 L
s
% Start of user PostScript
0.507143 0.01 0.508158 0.0105251 MAarrowhead1
% End of user PostScript
.86362 .05394 m
.86955 .08067 L
s
% Start of user PostScript
0.508571 -0.01 0.508711 -0.00937002 MAarrowhead1
% End of user PostScript
.86362 .11455 m
.87252 .14127 L
s
% Start of user PostScript
0.508571 -0.00857143 0.508781 -0.00794145 MAarrowhead1
% End of user PostScript
.86362 .17515 m
.87549 .20187 L
s
% Start of user PostScript
0.508571 -0.00714286 0.508851 -0.00651287 MAarrowhead1
% End of user PostScript
.86362 .23575 m
.87846 .26248 L
s
% Start of user PostScript
0.508571 -0.00571429 0.508921 -0.0050843 MAarrowhead1
% End of user PostScript
.86362 .29636 m
.88143 .32308 L
s
% Start of user PostScript
0.508571 -0.00428571 0.508991 -0.00365573 MAarrowhead1
% End of user PostScript
.86362 .35696 m
.8844 .38368 L
s
% Start of user PostScript
0.508571 -0.00285714 0.509061 -0.00222716 MAarrowhead1
% End of user PostScript
.86362 .41756 m
.88737 .44429 L
s
% Start of user PostScript
0.508571 -0.00142857 0.509131 -0.000798589 MAarrowhead1
% End of user PostScript
.86362 .47816 m
.89034 .50489 L
s
% Start of user PostScript
0.508571 0 0.509201 0.000629983 MAarrowhead1
% End of user PostScript
.86362 .53877 m
.89331 .56549 L
s
% Start of user PostScript
0.508571 0.00142857 0.509271 0.00205855 MAarrowhead1
% End of user PostScript
.86362 .59937 m
.89628 .62609 L
s
% Start of user PostScript
0.508571 0.00285714 0.509341 0.00348713 MAarrowhead1
% End of user PostScript
.86362 .65997 m
.89926 .6867 L
s
% Start of user PostScript
0.508571 0.00428571 0.509412 0.0049157 MAarrowhead1
% End of user PostScript
.86362 .72058 m
.90223 .7473 L
s
% Start of user PostScript
0.508571 0.00571429 0.509482 0.00634427 MAarrowhead1
% End of user PostScript
.86362 .78118 m
.9052 .8079 L
s
% Start of user PostScript
0.508571 0.00714286 0.509552 0.00777284 MAarrowhead1
% End of user PostScript
.86362 .84178 m
.90817 .86851 L
s
% Start of user PostScript
0.508571 0.00857143 0.509622 0.00920141 MAarrowhead1
% End of user PostScript
.86362 .90238 m
.91114 .92911 L
s
% Start of user PostScript
0.508571 0.01 0.509692 0.01063 MAarrowhead1
% End of user PostScript
.92422 .05394 m
.9346 .08512 L
s
% Start of user PostScript
0.51 -0.01 0.510245 -0.00926515 MAarrowhead1
% End of user PostScript
.92422 .11455 m
.93757 .14572 L
s
% Start of user PostScript
0.51 -0.00857143 0.510315 -0.00783658 MAarrowhead1
% End of user PostScript
.92422 .17515 m
.94054 .20632 L
s
% Start of user PostScript
0.51 -0.00714286 0.510385 -0.00640801 MAarrowhead1
% End of user PostScript
.92422 .23575 m
.94351 .26693 L
s
% Start of user PostScript
0.51 -0.00571429 0.510455 -0.00497943 MAarrowhead1
% End of user PostScript
.92422 .29636 m
.94648 .32753 L
s
% Start of user PostScript
0.51 -0.00428571 0.510525 -0.00355086 MAarrowhead1
% End of user PostScript
.92422 .35696 m
.94945 .38813 L
s
% Start of user PostScript
0.51 -0.00285714 0.510595 -0.00212229 MAarrowhead1
% End of user PostScript
.92422 .41756 m
.95242 .44873 L
s
% Start of user PostScript
0.51 -0.00142857 0.510665 -0.00069372 MAarrowhead1
% End of user PostScript
.92422 .47816 m
.95539 .50934 L
s
% Start of user PostScript
0.51 0 0.510735 0.000734852 MAarrowhead1
% End of user PostScript
.92422 .53877 m
.95837 .56994 L
s
% Start of user PostScript
0.51 0.00142857 0.510805 0.00216342 MAarrowhead1
% End of user PostScript
.92422 .59937 m
.96134 .63054 L
s
% Start of user PostScript
0.51 0.00285714 0.510875 0.00359199 MAarrowhead1
% End of user PostScript
.92422 .65997 m
.96431 .69115 L
s
% Start of user PostScript
0.51 0.00428571 0.510945 0.00502057 MAarrowhead1
% End of user PostScript
.92422 .72058 m
.96728 .75175 L
s
% Start of user PostScript
0.51 0.00571429 0.511015 0.00644914 MAarrowhead1
% End of user PostScript
.92422 .78118 m
.97025 .81235 L
s
% Start of user PostScript
0.51 0.00714286 0.511085 0.00787771 MAarrowhead1
% End of user PostScript
.92422 .84178 m
.97322 .87296 L
s
% Start of user PostScript
0.51 0.00857143 0.511155 0.00930628 MAarrowhead1
% End of user PostScript
.92422 .90238 m
.97619 .93356 L
s
% Start of user PostScript
0.51 0.01 0.511225 0.0107349 MAarrowhead1
% End of user PostScript
0 0 m
1 0 L
1 .95633 L
0 .95633 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 275.375},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00014b000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Y_ooool3o`0007Oooooo002Uooooo`05o`000?ooooooooooooooool00000M_ooool00:Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1cooooo`00YOooool6o`0007Gooooo
002Vooooo`05o`000?ooooooooooooooool00000MOooool00:Oooooo0ol0001fooooo`00oooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00>_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool3o`0000;ooooo0_l0000Looooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o0000
0_ooool2o`0000Cooooo0ol0000Nooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o0000
7_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Cooooo0_l00003ooooo`?o0000
6oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000?ooooo0ol0000:ooooo`00>Ooo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6?ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`00000Looooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0G
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Wooooo000iooooo`04o`000?ooooooooooo`0000Oooooo1Ol00005ooooo`03o`00
0?oooooooooo01Oooooo00Co0000oooooooooooo00001oooool5o`0000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000_ooooo00?o0000oooo
ooooool06_ooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000_ooooo
00Go0000ooooooooooooooooo`00000;ooooo`00>Oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0000?ooooo1?l0000Iooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00000oooool4o`0000Gooooo00?o0000ooooooooool06_ooool01?l0003ooooooooo
ool0000;ooooo`03o`000?oooooooooo01[ooooo00Co0000oooooooooooo00002oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool01?l0
003oooooooooool0000;ooooo`05o`000?ooooooooooooooool000002oooool003Wooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool00000
6Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000;ooooo00Ko0000oooooooo
ooooooooo`000?ooool4o`0001gooooo00Co0000oooooooooooo00001oooool4o`0001gooooo00Co
0000oooooooooooo00001oooool4o`0000?ooooo00Go0000oooooooooooo0000ooooo`04o`0001[o
oooo00Co0000oooooooooooo00001oooool4o`0000Cooooo00?o0000ooooooooool02Oooool003Wo
oooo00Co0000oooooooooooo00002Oooool2o`0000;ooooo00Go0000ooooooooooooooooo`00000I
ooooo`04o`000?ooooooooooo`0000Wooooo0_l00002ooooo`07o`000?ooooooooooooooool0003o
ooooo`00000Pooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool07_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000oooo
ool0000Mooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool2o`0000_o
oooo000jooooo`;o00002oooool01?l0003oooooooooooooool3o`0001_ooooo0_l0000;ooooo`04
o`000?ooooooooooooooo`?o00000_ooool5o`0001gooooo0_l00008ooooo`Go00007Oooool2o`00
00Sooooo1Ol00003ooooo`;o00000_ooool5o`0001[ooooo0_l00008ooooo`Go00000oooool00ol0
003oooooooooo`09ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00<_ooooo]0000007ooooo000booooo`0300000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00<00000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`0300000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00`00003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00<00000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`4000000Oooool003;ooooo00<00000ooooooooool0
3oooool00`00003oooooooooo`0_ooooo`0300000?oooooooooo02oooooo00<00000ooooooooool0
;oooool00`00003oooooooooo`0_ooooo`0300000?oooooooooo00oooooo0@000001ooooo`00<_oo
ool00`00003o0000ooooo`3Xooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`3Y
ooooo`4000000Oooool003;ooooo00<00000ooooooooool0jOooool10000007ooooo000booooo`03
00000?oooooooooo00?ooooo0ol0003Sooooo`4000000Oooool003;ooooo00<00000ooooooooool0
1?ooool4o`0000[ooooo1?l0003Cooooo`4000000Oooool003;ooooo00<00000ooooooooool01Ooo
ool3o`0000_ooooo00?o00000000000000000_l00009ooooo`Co0000a?ooool10000007ooooo000b
ooooo`0300000?oooooooooo00Kooooo00Co0000ooooo`00000000002_ooool01?l000000000o`00
0?l0000;ooooo`04o`000000003o0000o`0000[ooooo0ol0002eooooo`4000000Oooool001Wooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`?o00001Oooool00`00003ooooo
ooooo`0:ooooo`8000002Oooool01?l0003oooooooooool0000;ooooo`04o`000000003o0000o`00
00[ooooo00Co000000000?l0003o00002_ooool6o`000:?ooooo0@000001ooooo`006?ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?oo
ool00`00003oooooooooo`0<ooooo`0300000?oooooooooo00[ooooo0_l0000:ooooo`03o`000?oo
oooooooo00;o00002Oooool00ol000000000o`000002o`0000[ooooo00Co000000000000003o0000
2Oooool6o`0003_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`18ooooo`400000
0Oooool0017ooooo1Ol00002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00000oooool00ol0003oooooooooo`04ooooo`0300000?oooooooooo00gooooo0P00000<ooooo`;o
00003Oooool2o`0000Sooooo00Co0000oooooooooooooooo0_l00009ooooo`Go00002Oooool4o`00
00[ooooo1_l0000<ooooo`?o00003Oooool2o`0000gooooo00?o0000ooooooooool02oooool2o`00
00_ooooo0ol0000kooooo`4000000Oooool001Sooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00<00000o`000?ooool03oooool0
0`00003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002oooool3o`0000[ooooo0_l0
00000`00003o0000o`000008ooooo`Co000000<00000o`000?ooool02_ooool2o`00000300000?l0
003ooooo00_ooooo0ol0000;ooooo`04o`000000003o0000o`0000[ooooo00Co000000000000003o
00003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool1o`00004000000Oooool001Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0Hoooool00ol0
003oooooooooo`0<ooooo`;o00002_ooool5o`0000_ooooo0_l0000=ooooo`;o00003?ooool01?l0
0000000000000?l0000;ooooo`?o00003?ooool3o`0000_ooooo00?o0000ooooooooool03oooool1
0000007ooooo000Hooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00000_oo
ool2o`0000Kooooo00<00000ooooooooool0SOooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00cooooo0_l0000<ooooo`03o`000000003o000000_ooooo0_l000000`00003o0000oooo
o`0;ooooo`03o`000?oooooooooo00kooooo0@000001ooooo`006Oooool2o`0000[ooooo0_l00004
ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0W?ooool00ol0003oooooooooo`0=
ooooo`;o00003?ooool00ol000000000o`00000;ooooo`04o`00000000000000o`0000_ooooo1?l0
000>ooooo`4000000Oooool003;ooooo00<00000ooooooooool0[?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o000000000?l000002oooool01?l00000000000000?l0
000>ooooo`4000000Oooool003;ooooo00<00000ooooooooool0^oooool00ol0003oooooooooo`0<
ooooo`;o00003?ooool00ol000000000o`00000>ooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0boooool00ol0003oooooooooo`0;ooooo`;o00003_ooool10000007ooooo000booooo`03
00000?oooooooooo00?ooooo0_l0003Eooooo`03o`000?oooooooooo00cooooo0@000001ooooo`00
<_ooool00`00003oooooooooo`04ooooo`Co00002oooool3o`000=?ooooo0@000001ooooo`00<_oo
ool00`00003oooooooooo`05ooooo`04o`00000000000000o`0000_ooooo00Co000000000?l0003o
00002_ooool4o`000<?ooooo0@000001ooooo`00<_ooool00`00003o0000ooooo`06ooooo`04o`00
0000003o0000o`0000_ooooo00?o000000000?l000003?ooool01?l000000000o`000?l00009oooo
o`Co0000/oooool1o`00004000000Oooool003;ooooo00<00000ooooooooool01oooool00ol0003o
ooooooooo`02o`0000[ooooo00Co0000ooooool0003o00002oooool00ol000000000o`00000;oooo
o`04o`000000003o0000o`0000[ooooo1?l0002Tooooo`4000000Oooool003;ooooo00<00000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`;o00002_ooool01?l0003oooooo`000?l0000:
ooooo`04o`000000003o0000o`0000_ooooo00Co000000000?l0003o00002Oooool4o`0003cooooo
00?o0000ooooooooool0E_ooool10000007ooooo000booooo`0300000?oooooooooo00gooooo0_l0
000=ooooo`03o`000?oooooooooo00_ooooo0_l00009ooooo`03o`000?oooooooooo00;o00002_oo
ool01?l000000000o`000?l0000:ooooo`04o`000000003o0000o`0000[ooooo1Ol0000=ooooo`?o
00003?ooool2o`0000gooooo0_l0000;ooooo`Co0000B?ooool10000007ooooo000booooo`030000
0?oooooooooo00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000:ooooo`04
o`000000003o0000o`0000_ooooo1?l00009ooooo`?o00000P0000000ol0003oooooooooo`08oooo
o`;o000000<00000o`000?ooool02oooool01?l000000000o`000?l0000:ooooo`04o`0000000000
0000o`0000[ooooo1?l0000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0?ooooo`4000000Oooool003;ooooo00<00000ooooooooool0E?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo1?l00009ooooo`Ko00002oooool2
o`0000cooooo00?o000000000?l000002oooool01?l00000000000000?l0000;ooooo`?o00003?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo0@000001ooooo`00<_ooool0
0`00003oooooooooo`1dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool2
o`0000cooooo00?o000000000?l000003?ooool00ol000000000o`00000<ooooo`?o00003?ooool0
0ol0003oooooooooo`0>ooooo`4000000Oooool003;ooooo00<00000ooooooooool0WOooool00ol0
003oooooooooo`0<ooooo`;o00003Oooool2o`0000cooooo00?o000000000?l000003?ooool3o`00
00kooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2/ooooo`;o00003Oooool2o`0000co
oooo00?o000000000?l000003?ooool00ol000000000o`00000>ooooo`4000000Oooool003;ooooo
00<00000ooooooooool0[?ooool00ol0003oooooooooo`0<ooooo`;o00003Oooool2o`0000cooooo
00?o000000000?l000003_ooool10000007ooooo000booooo`0300000?l0003ooooo0;cooooo00?o
0000ooooooooool02oooool2o`0000gooooo00?o000000000?l000003?ooool1o`00004000000Ooo
ool003;ooooo00<00000ooooooooool01?ooool2o`000<Gooooo00?o0000ooooooooool03?ooool2
o`0000gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`04ooooo`03o`000000003o0000
00;o00002_ooool2o`000<Kooooo00?o0000ooooooooool02oooool10000007ooooo000booooo`03
00000?oooooooooo00Gooooo00Go00000000000000000000o`00000:ooooo`Co00002oooool2o`00
0<Cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`06ooooo`04o`000000003o0000o`00
00_ooooo00Co000000000000003o00002_ooool01?l000000000o`000?l0000;ooooo`;o0000]Ooo
ool10000007ooooo000booooo`0300000?oooooooooo00Oooooo00Co0000oooooooooooo00002ooo
ool00ol000000000o`00000;ooooo`04o`00000000000000o`0000_ooooo1?l0000:ooooo`Co0000
Y?ooool10000007ooooo000booooo`0300000?oooooooooo00_ooooo0_l0000:ooooo`03o`000?oo
oooo000000_ooooo00Co000000000?l0003o00002oooool01?l00000000000000?l0000:ooooo`03
o`0000000000000000;o0000BOooool2o`0005Oooooo0@000001ooooo`00<_ooool00`00003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l0000:ooooo`03o`000?oooooooooo00;o0000
2_ooool01?l000000000o`000?l0000:ooooo`04o`00000000000000o`0000[ooooo1_l0000[oooo
o`;o00003?ooool00ol000000000o`00000:ooooo`?o0000BOooool10000007ooooo000booooo`03
00000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002_ooool4o`0000_ooooo0_l000000`00
003o0000ooooo`08ooooo`Ko00003?ooool3o`0000cooooo00?o000000000?l000002oooool00ol0
00000000o`00000;ooooo`03o`000000003o000000_ooooo1?l0000jooooo`4000000Oooool003;o
oooo00<00000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`00
00cooooo0_l0000;ooooo`Co00002_ooool3o`00000300000?l0003ooooo00[ooooo00?o00000000
0?l000000_l0000:ooooo`;o00003?ooool00ol000000000o`00000;ooooo`04o`00000000000000
o`0000cooooo0_l0000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool1
0000007ooooo000booooo`0300000?l0003ooooo06Gooooo00?o0000ooooooooool02oooool2o`00
00[ooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
00000000o`00000;ooooo`03o`000000003o000000cooooo0ol0000;ooooo`03o`000?oooooooooo
00kooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo08kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`;o00003?ooool00ol000000000o`00000<ooooo`03
o`000000003o000000cooooo0ol0000>ooooo`4000000Oooool003;ooooo00<00000ooooooooool0
W_ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool00ol000000000o`00000;ooooo`03o`00
0000003o000000cooooo00?o000000000?l000003_ooool10000007ooooo000booooo`0300000?oo
oooooooo0:gooooo00?o0000ooooooooool03?ooool2o`0000cooooo00?o000000000?l000002ooo
ool00ol000000000o`00000>ooooo`4000000Oooool003;ooooo00<00000ooooooooool0_Oooool0
0ol0003oooooooooo`0;ooooo`;o00003?ooool00ol000000000o`00000=ooooo`4000000Oooool0
03;ooooo00<00000ooooooooool0c?ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool10000
007ooooo000booooo`0300000?oooooooooo00Gooooo0ol0003Cooooo`03o`000?oooooooooo00_o
oooo0@000001ooooo`00<_ooool00`00003oooooooooo`06ooooo`04o`000000003o0000o`0000[o
oooo1?l0003Aooooo`4000000Oooool003;ooooo00<00000ooooooooool01oooool00ol000000000
o`00000;ooooo`03o`0000000000000000;o00002Oooool4o`000<;ooooo0@000001ooooo`00<_oo
ool00`00003oooooooooo`08ooooo`03o`000?oooooo000000_ooooo00?o000000000?l000003?oo
ool01?l000000000o`000?l0000:ooooo`?o0000/oooool10000007ooooo000booooo`0300000?l0
003ooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00000<ooooo`03o`000000
003o000000_ooooo00Co000000000?l0003o00002_ooool4o`0004Wooooo0ol0001Fooooo`7o0000
0@000001ooooo`00<_ooool00`00003oooooooooo`0<ooooo`;o00003?ooool2o`0000_ooooo00?o
0000ooooool000002oooool00ol000000000o`00000<ooooo`04o`000000003o0000o`0000[ooooo
0ol0000^ooooo`03o`000?oooooooooo00Wooooo00Co000000000000003o00002oooool2o`0004Wo
oooo0@000001ooooo`00<_ooool00`00003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool2o`0000[ooooo00Co0000ooooool0003o00002oooool00ol00000
0000o`00000;ooooo`04o`000000003o0000o`0000[ooooo1_l0000<ooooo`?o00003?ooool2o`00
00_ooooo00Co000000000000003o00002_ooool00ol000000000o`00000<ooooo`;o0000>oooool1
0000007ooooo000booooo`0300000?oooooooooo00oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooo`00000;ooooo`03o`000000003o000000cooooo0_l000000`00003o0000ooooo`08oooo
o`Co000000<00000o`000?ooool02_ooool4o`0000[ooooo00?o000000000?l000002oooool00ol0
00000000o`00000;ooooo`03o`000000003o000000gooooo0_l0000<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03oooool10000007ooooo000booooo`0300000?oooooooooo05Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00002_ooool2o`0000go
oooo0_l0000<ooooo`;o00003?ooool00ol000000000o`00000<ooooo`03o`000000003o000000co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`4000000Oooool003;ooooo
00<00000ooooooooool0Soooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o000000000?l000002oooool00ol000000000o`00000=ooooo`;o00003?ooool00ol0003ooooo
ooooo`0>ooooo`4000000Oooool003;ooooo00<00000ooooooooool0W_ooool00ol0003ooooooooo
o`0<ooooo`;o00003?ooool00ol000000000o`00000;ooooo`?o00003Oooool3o`0000gooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`2^ooooo`03o`000?oooooooooo00_ooooo0_l0000=
ooooo`;o00003?ooool00ol000000000o`00000=ooooo`4000000Oooool001?ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l00004ooooo`;o00000oooool3o`0000Gooooo00<00000oooo
ooooool0_Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000=oooo
o`4000000Oooool001;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002
ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`030000
0?oooooooooo0<gooooo00?o0000ooooooooool02oooool2o`0000cooooo0@000001ooooo`002ooo
ool5o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00_ooool00`00003o0000ooooo`05oooo
o`;o0000eOooool00ol0003oooooooooo`09ooooo`7o00000@000001ooooo`004_ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`02ooooo`0300000?oooooooooo00Gooooo00?o000000000?l000000_l0
000;ooooo`;o0000d_ooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Co00001Oooool00`00003o
ooooooooo`06ooooo`05o`0000000000000000000?l000002_ooool01?l000000000o`000?l0000;
ooooo`;o0000`oooool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000Sooooo00<00000oooooooo
ool01oooool01?l000000000o`000?l0000;ooooo`04o`00000000000000o`0000[ooooo00?o0000
00000?l000000_l0000;ooooo`;o0000/oooool10000007ooooo000Cooooo`;o00002_ooool2o`00
00Cooooo0_l00002ooooo`Go00001?ooool00`00003oooooooooo`08ooooo`04o`000?oooooooooo
o`0000_ooooo00Co000000000?l0003o00002_ooool01Ol00000000000000000003o000000[ooooo
00Co000000000?l0003o00002oooool2o`0003kooooo00?o0000ooooooooool0Hoooool10000007o
oooo000booooo`0300000?oooooooooo00cooooo0_l0000:ooooo`04o`000?ooooooooooo`0000[o
oooo00?o000000000?l000000_l0000:ooooo`04o`00000000000000o`0000[ooooo00?o00000000
0?l000000_l0000:ooooo`Co0000;Oooool2o`0000[ooooo0ol0001Gooooo`4000000Oooool003;o
oooo00<00000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`00000:ooooo`04o`000000003o0000o`0000[ooooo00Go0000
0000000000000000o`00000;ooooo`04o`000000003o0000o`0000[ooooo0ol0000?ooooo`?o0000
2oooool01?l000000000o`000?l00009ooooo`03o`000000003o000000_ooooo0ol00019ooooo`40
00000Oooool003;ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0000:ooooo`04
o`000000003o0000o`0000cooooo00?o000000000?l000003?ooool3o`0000[ooooo1?l000000`00
003o0000ooooo`09ooooo`?o00002oooool00ol000000000o`00000;ooooo`03o`000000003o0000
00cooooo0ol0000<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0?ooooo`4000000Oooool003;ooooo00<00000ooooooooool0A_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`;o00002Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`;o000000<00000o`000?oo
ool02oooool3o`0000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`40
00000Oooool003;ooooo00<00000ooooooooool0I_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00_ooooo0_l0000<ooooo`03o`000000003o000000_ooooo0_l000000`00003o0000
ooooo`0;ooooo`?o00002oooool00ol0003oooooooooo`0>ooooo`4000000Oooool003;ooooo00<0
0000o`000?ooool0Woooool00ol0003oooooooooo`0;ooooo`03o`000000003o000000_ooooo00?o
000000000?l000003?ooool00ol000000000o`00000<ooooo`03o`000?oooooo000000cooooo0Ol0
00010000007ooooo000booooo`0300000?oooooooooo0:kooooo0_l0000<ooooo`03o`000000003o
000000_ooooo00?o000000000?l000003Oooool2o`0000gooooo0@000001ooooo`00<_ooool00`00
003oooooooooo`2_ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`03o`000000003o0000
00_ooooo0_l000000`00003o0000ooooo`0;ooooo`4000000Oooool003;ooooo00<00000oooooooo
ool0__ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool2o`0000cooooo0@000001ooooo`00
<_ooool00`00003oooooooooo`06ooooo`;o0000aOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00[ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`06ooooo`04o`000000
003o0000o`0000_ooooo0_l00036ooooo`03o`000?oooooooooo00Wooooo0@000001ooooo`00<_oo
ool00`00003oooooooooo`07ooooo`04o`00000000000000o`0000[ooooo00?o000000000?l00000
0_l0000;ooooo`;o0000`_ooool10000007ooooo000booooo`0300000?oooooooooo00Sooooo00?o
000000000?l000002oooool01Ol00000000000000000003o000000[ooooo00Co000000000?l0003o
00002oooool2o`000;?ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`09ooooo`03o`00
0?oooooo000000_ooooo00?o000000000?l000003?ooool01?l00000000000000?l0000:ooooo`03
o`000000003o000000;o00002oooool2o`0003_ooooo0ol0001Uooooo`4000000Oooool003;ooooo
00<00000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000cooooo
00?o000000000?l000002oooool01Ol00000000000000000003o000000[ooooo00Co000000000?l0
003o0000>Oooool01?l00000000000000?l0000:ooooo`;o0000F?ooool10000007ooooo000boooo
o`0300000?l0003ooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooo000000_ooooo00?o000000000?l000003?ooool01?l00000000000000?l0000:
ooooo`Co0000:_ooool01?l00000000000000?l00009ooooo`03o`000000003o000000gooooo0_l0
0018ooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`0>ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
000000cooooo00?o000000000?l000002oooool00ol00000000000000002o`0000Wooooo1_l0000<
ooooo`?o00002_ooool00ol000000000o`00000:ooooo`03o`000000003o000000cooooo00?o0000
00000?l000003_ooool00ol0003oooooooooo`0hooooo`4000000Oooool003;ooooo00<00000oooo
ooooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`;o00003?ooool00ol000000000o`00000<oooo
o`04o`00000000000000o`0000[ooooo0ol000000`00003o0000ooooo`09ooooo`;o00003?ooool0
0ol000000000o`00000;ooooo`03o`000000003o000000cooooo0ol0000<ooooo`03o`000?oooooo
000000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`4000000Oooool0
03;ooooo00<00000ooooooooool0E_ooool00ol0003oooooooooo`0<ooooo`;o00003_ooool2o`00
00[ooooo00?o0000ooooooooool03?ooool2o`0000cooooo00?o000000000?l000002oooool00ol0
00000000o`00000<ooooo`?o00002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Vooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool02oooool2o`0000cooooo00?o000000000?l000002oooool2o`000003
00000?l0003ooooo00[ooooo0ol0000;ooooo`03o`000?oooooooooo00kooooo0@000001ooooo`00
<_ooool00`00003oooooooooo`2Pooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`;o0000
2oooool3o`0000cooooo0ol0000=ooooo`4000000Oooool003;ooooo00<00000ooooooooool0[ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`?o00003Ooo
ool10000007ooooo000booooo`0300000?oooooooooo0;oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`;o00003?ooool10000007ooooo000booooo`0300000?oooooooooo
0<kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`4000000Oooool003;o
oooo00<00000ooooooooool01oooool2o`000=Cooooo00?o0000ooooooooool02Oooool10000007o
oooo000booooo`0300000?l0003ooooo00Oooooo00Co000000000?l0003o00002oooool2o`000=3o
oooo0Ol000010000007ooooo000booooo`0300000?oooooooooo00Sooooo00Co000000000000003o
00002_ooool01?l000000000o`000?l0000<ooooo`;o0000`Oooool10000007ooooo000booooo`03
00000?oooooooooo00Sooooo00Co000000000?l0003o00002oooool01?l00000000000000?l0000;
ooooo`04o`000000003o0000o`0000_ooooo0_l00019ooooo`;o0000Ioooool10000007ooooo000b
ooooo`0300000?oooooooooo00Wooooo00Co0000oooooooooooo00002oooool00ol000000000o`00
000<ooooo`04o`00000000000000o`0000[ooooo00Co000000000?l0003o00002oooool2o`0003Wo
oooo00?o000000000?l00000Ioooool10000007ooooo000booooo`0300000?oooooooooo00gooooo
00?o0000ooooooooool02Oooool00ol0003oooooo`00000;ooooo`04o`000000003o0000o`0000_o
oooo00Co000000000000003o00002_ooool00ol000000000o`000002o`0000_ooooo0_l0000Yoooo
o`03o`000000003o000000gooooo0_l0001Hooooo`4000000Oooool003;ooooo00<00000oooooooo
ool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooo
oooo00002oooool00ol000000000o`00000;ooooo`05o`0000000000000000000?l000002_ooool0
1?l000000000o`000?l0000;ooooo`Co00003_ooool3o`0000Sooooo00?o000000000?l000002ooo
ool00ol000000000o`00000=ooooo`;o0000BOooool10000007ooooo000booooo`0300000?oooooo
oooo00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooool000002oooool00ol000000000o`00000<ooooo`04o`0000000000
0000o`0000_ooooo00?o00000000000000000_l00009ooooo`Co000000<00000o`000?ooool02?oo
ool2o`0000cooooo0_l0000<ooooo`?o00003?ooool3o`0000cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo0@000001ooooo`00<_ooool0
0`00003oooooooooo`17ooooo`03o`000?oooooooooo00cooooo00?o000000000?l000003?ooool0
0ol000000000o`00000>ooooo`;o00002_ooool00ol0003oooooooooo`0;ooooo`;o00003Oooool2
o`0000_ooooo0ol0000<ooooo`?o00003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00kooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Gooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo0_l0000;ooooo`?o00003Oooool2o`0000cooooo00?o0000ooooooooool03Oooool10000
007ooooo000booooo`0300000?oooooooooo0:7ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`;o00003Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000co
oooo0@000001ooooo`00<_ooool00`00003o0000ooooo`2`ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool3o`0000gooooo0_l0000;ooooo`7o00000@000001ooooo`00<_oo
ool00`00003oooooooooo`2oooooo`03o`000?oooooooooo00_ooooo0_l0000;ooooo`;o000000<0
0000o`000?ooool02_ooool10000007ooooo000booooo`0300000?oooooooooo0<oooooo00?o0000
ooooooooool02_ooool2o`0000_ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`07oooo
o`;o0000eOooool00ol0003oooooooooo`08ooooo`4000000Oooool003;ooooo00<00000oooooooo
ool01oooool00ol000000000o`000002o`0000_ooooo0_l0003@ooooo`4000000Oooool003;ooooo
00<00000ooooooooool02?ooool01Ol00000000000000000003o000000[ooooo00?o000000000?l0
00003?ooool2o`000<7ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`09ooooo`03o`00
0000003o000000cooooo00?o000000000?l000002oooool00ol000000000o`00000=ooooo`;o0000
/Oooool10000007ooooo000booooo`0300000?oooooooooo00[ooooo00?o0000ooooool000002ooo
ool01?l000000000o`000?l0000;ooooo`03o`000000003o000000cooooo00?o000000000?l00000
3?ooool2o`0003Wooooo00?o0000ooooooooool0I_ooool10000007ooooo0002ooooo`?o00009_oo
ool2o`0000Gooooo00<00000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooo000000cooooo00?o000000000?l000003?ooool00ol000000000o`00000;ooooo`03o`000000
003o000000cooooo0_l0000Yooooo`;o00003_ooool00ol0003oooooooooo`1Gooooo`4000000Ooo
ool000?ooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool00004ooooo`0300000?oo
oooooooo00kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooo000000_ooooo00Co000000000?l0003o00002oooool00ol000000000o`00000;ooooo`04o`00
0000003o0000o`0000cooooo0_l0000Hooooo`;o000000<00000o`000?ooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo04Oooooo0@000001ooooo`000oooool00ol0003ooooo
ooooo`0Tooooo`04o`000?ooooooooooo`0000Cooooo00<00000o`000?ooool03oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooo`00000<ooooo`03o`000000003o000000_ooooo00Co000000000000003o00002oooool00ol0
00000000o`00000<ooooo`03o`000?oooooooooo00[ooooo0ol0000;ooooo`?o00003Oooool2o`00
00cooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03_ooool1o`00004000000Oooool000?ooooo0_l0000Uooooo`04
o`000?ooooooooooo`0000Cooooo00<00000ooooooooool0B?ooool00ol0003oooooooooo`0;oooo
o`04o`000000003o0000o`0000_ooooo00?o000000000?l000006oooool00ol0003oooooooooo`0:
ooooo`;o00002oooool2o`00000300000?l0003ooooo00_ooooo0_l0000<ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`4000000Ooo
ool000;ooooo0_l000000ooooooo0000o`00000Sooooo`04o`000?ooooooooooo`0000Cooooo00<0
0000ooooooooool0Eoooool00ol0003oooooooooo`0;ooooo`04o`000000003o0000o`0002Wooooo
00?o0000ooooooooool02_ooool2o`0000_ooooo0_l000000`00003o0000ooooo`0;ooooo`?o0000
2oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00gooooo0@000001ooooo`00
:_ooool01?l0003oooooooooool00004ooooo`0300000?oooooooooo06Kooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0:ooooo`?o00002oooool2o`00000300000?l0003ooooo00[o
oooo0ol0000<ooooo`03o`000?oooooooooo00cooooo0@000001ooooo`00:oooool2o`0000Gooooo
00<00000ooooooooool0/?ooool00ol0003oooooooooo`0;ooooo`;o00002oooool2o`0000030000
0?l0003ooooo00_ooooo0_l0000<ooooo`4000000Oooool003;ooooo00<00000ooooooooool0/Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`;o00003?oo
ool10000007ooooo000booooo`0300000?oooooooooo0<3ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo0@000001ooooo`00<_ooool00`00
003oooooooooo`08ooooo`;o0000aOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Sooooo0@000001ooooo`00<_ooool00`00003oooooooooo`08ooooo`03o`000000003o000000go
oooo0_l00035ooooo`03o`000?oooooooooo00Oooooo0@000001ooooo`00<_ooool00`00003ooooo
ooooo`09ooooo`03o`000000003o000000cooooo00?o000000000?l000003?ooool2o`000<3ooooo
0@000001ooooo`00<_ooool00`00003o0000ooooo`09ooooo`04o`00000000000000o`0000cooooo
00?o000000000?l000002oooool00ol000000000o`00000<ooooo`;o0000/?ooool1o`0000400000
0Oooool003;ooooo00<00000ooooooooool02Oooool00ol000000000o`00000=ooooo`04o`000000
00000000o`0000_ooooo00?o000000000?l000002oooool00ol000000000o`00000=ooooo`;o0000
XOooool10000007ooooo000booooo`0300000?oooooooooo00[ooooo00?o0000ooooool000003?oo
ool00ol000000000o`00000<ooooo`04o`00000000000000o`0000_ooooo00?o000000000?l00000
3?ooool00ol000000000o`00000gooooo`03o`000?oooooooooo06Kooooo0@000001ooooo`00<_oo
ool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l0000<ooooo`03o`000000
003o000000cooooo00Co000000000000003o00003?ooool00ol000000000o`00000;ooooo`;o0000
6?ooool2o`0000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Fooooo`400000
0Oooool003;ooooo00<00000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooool000002oooool00ol000000000o`00000=ooooo`04o`000000
00000000o`0000[ooooo00?o000000000?l000003?ooool00ol0003oooooooooo`08ooooo`03o`00
0000003o000000;o00002oooool3o`0000gooooo0_l0000>ooooo`03o`000?oooooooooo04Oooooo
0@000001ooooo`00<_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000cooooo00?o
000000000?l000003?ooool00ol000000000o`00000;ooooo`;o00002Oooool00ol0000000000000
0003o`0000cooooo0_l0000;ooooo`;o000000<00000o`000?ooool02oooool2o`0000cooooo0_l0
00000ooooooo0000ooooo`0:ooooo`;o00003?ooool2o`0000cooooo0_l0000@ooooo`4000000Ooo
ool003;ooooo00<00000ooooooooool0B?ooool00ol0003oooooooooo`0;ooooo`04o`000000003o
0000o`0000[ooooo0_l00009ooooo`?o00004Oooool00ol0003oooooooooo`0:ooooo`?o00002ooo
ool3o`0000gooooo0_l0000=ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00gooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Gooooo`03o`000?oooooo
oooo00_ooooo0_l0000/ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`;o000000<00000
o`000?ooool02oooool2o`0000gooooo0_l0000<ooooo`03o`000?oooooooooo00cooooo0@000001
ooooo`00<_ooool00`00003oooooooooo`1Uooooo`?o0000>_ooool00ol0003oooooooooo`0:oooo
o`;o00002oooool2o`00000300000?l0003ooooo00cooooo00?o0000ooooooooool02oooool3o`00
00_ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2aooooo`03o`000?oooooooooo00[o
oooo0ol0000;ooooo`?o00003Oooool2o`0000_ooooo0@000001ooooo`00<_ooool00`00003o0000
ooooo`31ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`;o000000<00000o`000?ooool0
2?ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0d?ooool00ol0003ooooooooo
o`0:ooooo`?o00002Oooool10000007ooooo000booooo`0300000?oooooooooo00Wooooo0_l0003E
ooooo`03o`000?oooooooooo00Kooooo0@000001ooooo`00<_ooool00`00003oooooooooo`09oooo
o`03o`000000003o000000cooooo0_l0003?ooooo`4000000Oooool003;ooooo00<00000oooooooo
ool02_ooool00ol000000000o`00000;ooooo`03o`000000003o000000gooooo00?o0000oooooooo
ool0__ooool10000007ooooo000booooo`0300000?oooooooooo00[ooooo00Co000000000?l0003o
00002oooool00ol000000000o`00000<ooooo`;o00003Oooool2o`000;3ooooo0@000001ooooo`00
<_ooool00`00003oooooooooo`0;ooooo`;o00003?ooool01?l000000000o`000?l0000;ooooo`03
o`000000003o000000cooooo00?o000000000?l000003?ooool2o`000:7ooooo0@000001ooooo`00
<_ooool00`00003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`?o0000
3?ooool00ol000000000o`00000;ooooo`03o`000000003o000000gooooo00?o0000ooooooooool0
9oooool2o`0006Oooooo0@000001ooooo`00<_ooool00`00003oooooooooo`0>ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000<ooooo`04o`000000
003o0000o`0000_ooooo00?o000000000?l000003?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Sooooo1?l0000<ooooo`03o`000000003o000000gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`17ooooo`4000000Oooool003;ooooo00<00000ooooooooool03ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_oo
ool2o`0000cooooo00Co000000000000003o00002oooool2o`0000gooooo00?o0000ooooooooool0
2?ooool00ol00000000000000003o`0000Wooooo1Ol0000<ooooo`;o00003?ooool3o`0000_ooooo
0_l000000ooooooo0000ooooo`0:ooooo`;o00003?ooool2o`0000cooooo0_l0000@ooooo`400000
0Oooool003;ooooo00<00000o`000?ooool0Aoooool00ol000000000o`00000<ooooo`;o00003?oo
ool2o`0000[ooooo0ol0000@ooooo`;o00002_ooool4o`0000_ooooo0_l000000`00003o0000oooo
o`0;ooooo`;o00003Oooool2o`0000cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`7o00000@000001ooooo`00<_ooool00`00003oooooooooo`18ooooo`03o`000?oooooo
oooo00_ooooo0ol0000;ooooo`;o0000;?ooool2o`0000cooooo0ol0000;ooooo`?o00003Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool03?ooool1
0000007ooooo000booooo`0300000?oooooooooo05Kooooo00?o0000ooooooooool02_ooool3o`00
03gooooo00?o0000ooooooooool02_ooool2o`0000_ooooo0ol0000=ooooo`;o00003?ooool3o`00
00_ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`1Uooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool02_ooool2o`0000_ooooo0_l000000`00003o0000ooooo`0<ooooo`03
o`000?oooooooooo00Wooooo0@000001ooooo`00<_ooool00`00003oooooooooo`31ooooo`03o`00
0?oooooooooo00[ooooo0ol0000;ooooo`?o00002_ooool10000007ooooo000booooo`0300000?oo
oooooooo0=7ooooo00?o0000ooooooooool02_ooool2o`0000Wooooo0@000001ooooo`00<_ooool0
0`00003oooooooooo`0:ooooo`03o`000?oooooooooo0=?ooooo00?o0000ooooooooool01_ooool1
0000007ooooo000booooo`0300000?oooooooooo00[ooooo0_l0000=ooooo`;o0000c_ooool10000
007ooooo000booooo`0300000?oooooooooo00[ooooo00?o000000000?l000003?ooool00ol00000
0000o`00000<ooooo`;o0000_oooool10000007ooooo000booooo`0300000?oooooooooo00_ooooo
0ol0000<ooooo`03o`000000003o000000_ooooo00?o000000000?l000003Oooool00ol0003ooooo
ooooo`2^ooooo`4000000Oooool003;ooooo00<00000o`000?ooool02oooool00ol0003oooooo`00
000<ooooo`04o`00000000000000o`0000_ooooo00?o000000000?l000003?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo09kooooo0Ol000010000007ooooo000booooo`0300000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool00ol000000000o`00000<ooooo`04o`000000
00000000o`0000_ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
T?ooool10000007ooooo000booooo`0300000?oooooooooo00kooooo00?o0000ooooooooool02_oo
ool2o`0000cooooo00?o000000000?l000003Oooool2o`0000cooooo0_l0000=ooooo`03o`000?oo
oooooooo00cooooo0_l0000:ooooo`?o00003Oooool2o`0000gooooo0_l0001Gooooo`4000000Ooo
ool003;ooooo00<00000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooool000003?ooool3o`0000_ooooo00?o000000000?l000003?ooool2
o`0000cooooo00?o000000000?l000002_ooool00ol000000000o`000002o`0000_ooooo00Co0000
00000?l0003o00002oooool00ol000000000o`00000;ooooo`?o00002oooool2o`0000gooooo0_l0
000<ooooo`;o00003?ooool2o`00013ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`0i
ooooo`03o`000?oooooooooo00_ooooo00Co000000000?l0003o00002_ooool00ol000000000o`00
000;ooooo`03o`000000003o000000_ooooo0_l0000=ooooo`Ko00002Oooool5o`0000cooooo0_l0
000<ooooo`?o00003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03Oooool10000007ooooo000booooo`0300000?oooooooooo04Oooooo0_l0000<
ooooo`03o`000000003o000000[ooooo00?o000000000?l00000;_ooool2o`0000[ooooo1?l0000<
ooooo`03o`000000003o000000cooooo0_l0000<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03?ooool10000007ooooo000booooo`0300000?oooooooooo05Gooooo1?l0000:oooo
o`03o`000?oooooooooo03cooooo0_l0000:ooooo`Go00003?ooool00ol0003oooooooooo`0;oooo
o`;o00003?ooool00ol0003oooooooooo`0;ooooo`4000000Oooool003;ooooo00<00000oooooooo
ool0/_ooool2o`0000[ooooo0ol0000=ooooo`;o00003?ooool3o`0000[ooooo0@000001ooooo`00
4oooool2o`0000Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo0_l00003ooooo`?o0000
1Oooool00`00003oooooooooo`30ooooo`;o00002oooool2o`00000300000?l0003ooooo00_ooooo
0_l0000:ooooo`4000000Oooool001;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02
ooooo`0300000?oooooooooo0<;ooooo00?o0000ooooooooool02_ooool3o`0000[ooooo0_l00000
0`00003o0000ooooo`08ooooo`4000000Oooool001;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
0_ooool00`00003o0000ooooo`0:ooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool0
2Oooool3o`0000Oooooo0Ol000010000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
00;ooooo00<00000ooooooooool02_ooool2o`0000kooooo00?o0000ooooooooool0a?ooool00ol0
003oooooooooo`05ooooo`4000000Oooool001;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00002ooooo`05o`000?ooooooooooo`000?ooool01?l00005ooooo`0300000?oo
oooooooo00_ooooo0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0_Ooo
ool10000007ooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
0_ooool01_l0003oooooooooool0003oooooo`0000Sooooo00<00000ooooooooool02oooool00ol0
00000000o`00000<ooooo`;o00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0:kooooo0@000001ooooo`004oooool2o`0000[ooooo0_l00004ooooo`;o00000_ooool5o`0000Co
oooo00<00000ooooooooool02oooool01?l000000000o`000?l0000<ooooo`;o00003?ooool2o`00
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Nooooo`4000000Oooool003;o
oooo00<00000ooooooooool03?ooool2o`0000gooooo0ol0000<ooooo`;o00003?ooool2o`0000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2?ooooo`4000000Oooool003;ooooo
00<00000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`;o00003Oooool3o`0000cooooo
0_l0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool2o`0000kooooo
0_l0001Vooooo`4000000Oooool003;ooooo00<00000ooooooooool03_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`;o00003?ooool00ol000000000o`00
000<ooooo`;o00003Oooool3o`0000Wooooo00?o000000000?l000000_l0000;ooooo`03o`000000
003o000000gooooo0_l0001Fooooo`4000000Oooool003;ooooo00<00000ooooooooool03oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool3
o`0000_ooooo00?o000000000?l000003?ooool2o`0000[ooooo1?l0000;ooooo`03o`0000000000
000000?o00002Oooool01Ol00000000000000000003o000000_ooooo0_l000000`00003o0000oooo
o`09ooooo`Co00002_ooool2o`0000;ooooo00?o0000ooooooooool02?ooool2o`0000cooooo0_l0
000<ooooo`;o00004?ooool10000007ooooo000booooo`0300000?oooooooooo04Oooooo0ol0000<
ooooo`;o00002_ooool00ol000000000o`00000<ooooo`?o00003?ooool6o`0000[ooooo1Ol0000;
ooooo`03o`000000003o000000_ooooo1?l0000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`4000000Oooool003;ooooo00<00000
o`000?ooool0EOooool3o`0000_ooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo1Ol0000;
ooooo`;o000000<00000o`000?ooool02_ooool3o`0000_ooooo0_l000000ooooooo0000ooooo`09
ooooo`;o00003?ooool1o`00004000000Oooool003;ooooo00<00000ooooooooool0Xoooool2o`00
00cooooo0ol0000:ooooo`;o000000<00000o`000?ooool02oooool2o`0000cooooo0ol0000:oooo
o`4000000Oooool003;ooooo00<00000ooooooooool0/oooool2o`0000_ooooo0ol0000;ooooo`?o
00003Oooool2o`0000Wooooo0@000001ooooo`00<_ooool00`00003oooooooooo`33ooooo`03o`00
0?oooooooooo00[ooooo0_l0000;ooooo`;o000000<00000o`000?ooool01oooool10000007ooooo
000booooo`0300000?oooooooooo0=;ooooo00?o0000ooooooooool02_ooool3o`0000Oooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`0;ooooo`03o`000?oooooooooo0=Cooooo00?o0000
ooooooooool01?ooool10000007ooooo000booooo`0300000?oooooooooo00_ooooo0_l0000=oooo
o`03o`000?oooooooooo0<cooooo0@000001ooooo`00<_ooool00`00003oooooooooo`0;ooooo`03
o`000000003o000000cooooo0_l0000>ooooo`03o`000?oooooooooo0;cooooo0@000001ooooo`00
<_ooool00`00003oooooooooo`0<ooooo`?o00002oooool00ol000000000o`00000=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0[Oooool10000007ooooo000booooo`0300000?oo
oooooooo00cooooo0_l0000=ooooo`?o00003?ooool2o`0000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`2Mooooo`4000000Oooool003;ooooo00<00000ooooooooool03_ooool0
0ol0003oooooooooo`0:ooooo`;o00003Oooool2o`0000gooooo0_l0000>ooooo`03o`000?oooooo
oooo00_ooooo0_l0002@ooooo`4000000Oooool003;ooooo00<00000o`000?ooool03_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo0ol0000<ooooo`;o00003Oooool2o`00
00cooooo00?o000000000?l000003?ooool3o`0000[ooooo1?l0000<ooooo`;o00003Oooool2o`00
05Gooooo0Ol000010000007ooooo000booooo`0300000?oooooooooo00oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000cooooo0ol0000<ooooo`;o
00002oooool00ol000000000o`00000:ooooo`Co00003?ooool00ol00000000000000003o`0000Wo
oooo0_l000000`00003o0000o`00000:ooooo`;o000000<00000o`000?ooool02Oooool2o`000003
ooooool0003o000000Wooooo0_l0000=ooooo`;o00003?ooool2o`0000cooooo0_l0000@ooooo`40
00000Oooool003;ooooo00<00000ooooooooool0>Oooool00ol0003oooooooooo`0;ooooo`?o0000
2_ooool2o`00000300000?l0003ooooo00Wooooo00?o000000000?l000003Oooool3o`0000cooooo
1_l0000:ooooo`Co00002oooool2o`00000300000?l0003ooooo00Wooooo0_l000000ooooooo0000
ooooo`0:ooooo`;o00003?ooool2o`0000cooooo00?o0000ooooooooool03Oooool10000007ooooo
000booooo`0300000?oooooooooo04Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02kooooo0_l0000:ooooo`Go00002oooool00ol000000000o`00
000<ooooo`?o00002oooool00ol0003oooooooooo`0:ooooo`;o00003Oooool10000007ooooo000b
ooooo`0300000?oooooooooo0:Cooooo0_l00009ooooo`Go00003?ooool00ol000000000o`00000;
ooooo`?o00002oooool2o`0000_ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`2coooo
o`;o00002_ooool5o`0000_ooooo00?o000000000?l000003?ooool2o`0000Wooooo0@000001oooo
o`00<_ooool00`00003oooooooooo`33ooooo`;o00002Oooool5o`0000cooooo0_l00008ooooo`40
00000Oooool003;ooooo00<00000ooooooooool0d_ooool2o`0000[ooooo1?l00007ooooo`400000
0Oooool003;ooooo00<00000ooooooooool03?ooool00ol0003oooooooooo`3Booooo`;o00001_oo
ool10000007ooooo000booooo`0300000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`3;ooooo`4000000Oooool003;ooooo00<00000o`000?ooool03?ooool2o`00
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2kooooo`7o00000@000001oooo
o`00<_ooool00`00003oooooooooo`0<ooooo`03o`000000003o000000cooooo0_l0000=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0[?ooool10000007ooooo000booooo`030000
0?oooooooooo00cooooo00Co000000000?l0003o00002oooool00ol000000000o`00000<ooooo`;o
00003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09gooooo0@000001ooooo`00
<_ooool00`00003oooooooooo`0<ooooo`?o00003?ooool01?l000000000o`000?l0000;ooooo`03
o`000000003o000000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`;o
0000Soooool10000007ooooo000booooo`0300000?oooooooooo00kooooo00?o0000ooooooooool0
2_ooool3o`0000cooooo00Co000000000?l0003o00002oooool00ol000000000o`00000<ooooo`;o
00003?ooool2o`00000300000?l0003ooooo00_ooooo0ol0000:ooooo`?o00003?ooool2o`0006Go
oooo0@000001ooooo`00<_ooool00`00003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02_ooool3o`0000cooooo00?o000000000?l000003?ooool2o`0000_ooooo
00Co000000000000003o00002_ooool4o`0000cooooo00?o000000000?l000000_l00009ooooo`;o
000000@00000o`000?l0003o00002Oooool4o`0000[ooooo0_l0000<ooooo`;o00003Oooool2o`00
00cooooo0_l0000<ooooo`;o00004?ooool10000007ooooo000booooo`0300000?oooooooooo03Wo
oooo0ol0000;ooooo`?o00002_ooool2o`00000300000?l0003ooooo00[ooooo00?o000000000?l0
00003Oooool2o`0000gooooo00?o00000000000000000ol0000:ooooo`04o`000000003o0000o`00
00[ooooo1?l0000:ooooo`;o000000?oooooo`000?l000002_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool10000007ooooo000booooo`03
00000?oooooooooo04Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01_ooooo0ol0000<ooooo`Ko00002oooool01?l000000000o`000?l0000:oooo
o`;o000000<00000o`000?ooool02Oooool2o`000003ooooool0003ooooo00Wooooo0_l0000<oooo
o`;o00003Oooool10000007ooooo000booooo`0300000?oooooooooo0:7ooooo1_l00009ooooo`Go
00002oooool2o`0000cooooo0ol0000;ooooo`03o`000?oooooooooo00[ooooo0@000001ooooo`00
<_ooool00`00003oooooooooo`2dooooo`;o00002_ooool3o`0000gooooo0_l0000;ooooo`;o0000
00?oooooo`000?ooool01oooool10000007ooooo000booooo`0300000?l0003ooooo0<;ooooo0_l0
000;ooooo`;o000000<00000o`000?ooool02oooool2o`0000Oooooo0Ol000010000007ooooo000b
ooooo`0300000?oooooooooo0<Cooooo00?o0000ooooooooool02_ooool3o`0000[ooooo0_l00000
0`00003o0000ooooo`06ooooo`4000000Oooool003;ooooo00<00000ooooooooool03?ooool00ol0
003oooooooooo`35ooooo`03o`000?oooooooooo00Wooooo0ol00006ooooo`4000000Oooool003;o
oooo00<00000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<Co
oooo00?o0000ooooooooool00oooool10000007ooooo000booooo`0300000?oooooooooo00cooooo
0_l0000>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0^oooool10000007ooooo
000booooo`0300000?oooooooooo00gooooo0_l0000=ooooo`;o00003Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo0:_ooooo0@000001ooooo`00<_ooool00`00003oooooooooo`0=
ooooo`?o00003?ooool2o`0000gooooo0_l0000>ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0W?ooool10000007ooooo000Iooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`;o00000oooool3o`0000Gooooo00<00000ooooooooool03Oooool2o`0000gooooo0_l0000<oooo
o`03o`000000003o000000gooooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo0_l0002?oooo
o`4000000Oooool001Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool03_ooool00ol0003oooooooooo`0;
ooooo`?o00002oooool00ol000000000o`00000=ooooo`;o00003Oooool2o`0000_ooooo0_l00000
0`00003o0000ooooo`0Hooooo`;o0000M?ooool10000007ooooo000Hooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`0300000?oo
oooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`Co00003?oo
ool2o`0000cooooo0_l0000;ooooo`04o`00000000000000o`0000_ooooo1_l00009ooooo`03o`00
0000003o000000;o00002oooool2o`0000kooooo0_l0001Dooooo`4000000Oooool001Sooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Co
oooo00<00000o`000?ooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool3o`0000_ooooo0ol0000;ooooo`03o`000000003o000000co
oooo1?l0000;ooooo`03o`0000000000000000?o00002?ooool3o`00000300000?l0003o000000Wo
oooo1?l000000`00003o0000ooooo`07ooooo`;o00000_ooool2o`0000Sooooo0_l0000=ooooo`;o
00003?ooool2o`0000cooooo0_l0000?ooooo`7o00000@000001ooooo`006?ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00`00
003oooooooooo`19ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`?o00003Oooool5o`0000[ooooo00Go00000000000000000000o`000009
ooooo`?o000000<00000o`000?ooool02?ooool3o`000003ooooool0003o000000Wooooo0_l0000<
ooooo`;o00003?ooool2o`0000kooooo0@000001ooooo`006?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000;ooooo0_l00006ooooo`0300000?oooooooooo09;ooooo1_l0
0009ooooo`Go00002oooool2o`00000300000?l0003ooooo00Wooooo1?l0000:ooooo`;o00003?oo
ool2o`0000cooooo0@000001ooooo`006Oooool2o`0000[ooooo0_l00004ooooo`03o`000?oooooo
oooo00Cooooo00<00000ooooooooool0YOooool2o`0000[ooooo1Ol0000;ooooo`03o`000000003o
000000_ooooo00?o0000ooooool000002oooool2o`0000[ooooo0@000001ooooo`00<_ooool00`00
003oooooooooo`2eooooo`;o00002Oooool5o`0000_ooooo0ol0000<ooooo`?o00001oooool10000
007ooooo000booooo`0300000?oooooooooo0<Cooooo0_l0000:ooooo`Co00003?ooool00ol00000
0000o`000006ooooo`4000000Oooool003;ooooo00<00000ooooooooool0doooool2o`0000[ooooo
1Ol00005ooooo`4000000Oooool003;ooooo00<00000ooooooooool0hoooool2o`0000Cooooo0@00
0001ooooo`00<_ooool00`00003oooooooooo`3Yooooo`4000000Oooool003;ooooo00<00000oooo
ooooool0jOooool10000007ooooo000booooo`0300000?l0003ooooo0>Sooooo0Ol000010000007o
oooo000booooo`0300000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`4000000Oooool003;oooook@000001ooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQoooo
o`00\
\>"],
  ImageRangeCache->{{{73.4375, 302.812}, {319.812, 100.562}} -> {0.474017, \
-0.00232608, 9.98152*^-5, 9.98152*^-5}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Again, the trajectories that flow out away from the fixed point do \
so along the direction of the first eigenvector from above.  The trajectories \
that flow into the fixed point do so along the direction of the second \
eigenvector.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Homoclinic Tangle", "Section"],

Cell["\<\
These eigenvectors can be used to construct the stable and unstable \
manifolds of this fixed point.  Together these manifolds form what is called \
the \"homoclinic tangle.\"\
\>", "Text"],

Cell[TextData[{
  "To construct the unstable manifold we start with a large number of points \
that are randomly distributed close to the fixed point and in the direction \
of the first eigenvector (the one with eigenvalue greater than 1) from the \
fixed point.  Iterating these points will produce the unstable manifold of \
the fixed point.  The stable manifold is constructed in a similar fashion \
except that the second eigenvector (the one with eigenvalue less than 1) is \
used and instead of iterating the points using the normal map one must use \
the inverse map (",
  StyleBox["finv", "Input"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(fp = {0.5, 0}; n = 5000; K = 1.5; niter = 11;\), "\n", 
    \(\(Jac\  = \ {{1 + K, 1}, {K, 1}};\)\), "\n", 
    \(\(ev\  = \ Eigenvectors[Jac];\)\), "\n", 
    \(\(f[{\[Theta]_, r_}] := 
        N[{Mod[\[Theta] + r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1], 
            Mod[r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 1]}];\)\), "\n", 
    \(\(MapData\  = \ 
        Flatten[Table[
            NestList[f, fp + ev[\([1]\)]*Random[Real, {\(-0.001\), 0.001}], 
              niter], {i, 0, n}], 1];\)\), "\n", 
    \(\(Plot1\  = \ 
        ListPlot[MapData, PlotStyle \[Rule] PointSize[0.002], 
          PlotRange \[Rule] {{0, 1}, {0, 1}}, Frame \[Rule] True, 
          RotateLabel \[Rule] False, 
          FrameLabel \[Rule] {"\<\[Theta]\>", "\<r\>", "\<\>", "\<\>"}];\)\), \
"\n", 
    \(\(finv[{\[Theta]_, r_}] := 
        N[{Mod[\[Theta] - r, 1], 
            Mod[r + \((K/\((2*Pi)\))\)*Sin[2*Pi*\((\[Theta] - r)\)], 
              1]}];\)\), "\n", 
    \(\(MapData\  = \ 
        Flatten[Table[
            NestList[finv, 
              fp + ev[\([2]\)]*Random[Real, {\(-0.001\), 0.001}], niter], {i, 
              0, n}], 1];\)\), "\n", 
    \(\(Plot2 = 
        ListPlot[MapData, PlotStyle \[Rule] {PointSize[0.002], Hue[0]}, 
          PlotRange \[Rule] {{0, 1}, {0, 1}}, Frame \[Rule] True, 
          RotateLabel \[Rule] False, 
          FrameLabel \[Rule] {"\<\[Theta]\>", "\<r\>", "\<\>", "\<\>"}];\)\), \
"\n", 
    \(Show[Plot1, Plot2]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.5004 .00017 Mdot
.50127 .00054 Mdot
.50403 .00171 Mdot
.51285 .00545 Mdot
.54092 .01735 Mdot
.62968 .05486 Mdot
.89215 .16222 Mdot
.3043 .25472 Mdot
.49146 .11567 Mdot
.66583 .10776 Mdot
.0463 .23515 Mdot
.3583 .19283 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60744 Mdot
.42058 .58439 Mdot
.25189 .51378 Mdot
.84449 .36625 Mdot
.63497 .48854 Mdot
.60449 .5992 Mdot
.71972 .07122 Mdot
.06937 .2161 Mdot
.31823 .15381 Mdot
.4974 .61693 Mdot
.4917 .61451 Mdot
.47357 .60683 Mdot
.41596 .58243 Mdot
.23807 .50809 Mdot
.82212 .36096 Mdot
.6208 .49362 Mdot
.58379 .59516 Mdot
.66675 .05127 Mdot
.95651 .17908 Mdot
.3107 .2189 Mdot
.49773 .61707 Mdot
.49275 .61496 Mdot
.47692 .60825 Mdot
.42658 .58692 Mdot
.26997 .52125 Mdot
.87651 .37486 Mdot
.65025 .4782 Mdot
.61734 .5977 Mdot
.74494 .07886 Mdot
.11114 .22633 Mdot
.32386 .13147 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50277 .00117 Mdot
.50883 .00374 Mdot
.52811 .01192 Mdot
.58935 .03785 Mdot
.77768 .11639 Mdot
.20114 .26171 Mdot
.39703 .12107 Mdot
.44902 .03213 Mdot
.42583 .6037 Mdot
.29536 .5374 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50741 .00314 Mdot
.52362 .01002 Mdot
.57513 .03183 Mdot
.73519 .09892 Mdot
.13295 .24583 Mdot
.35368 .13642 Mdot
.38458 .01909 Mdot
.25712 .53926 Mdot
.89116 .39186 Mdot
.67604 .48508 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51269 .00538 Mdot
.5404 .01713 Mdot
.62808 .05419 Mdot
.88779 .16051 Mdot
.30222 .25613 Mdot
.49065 .11645 Mdot
.66505 .10779 Mdot
.04498 .23481 Mdot
.35833 .19366 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48938 .61353 Mdot
.46616 .60369 Mdot
.39257 .57255 Mdot
.1698 .48035 Mdot
.73797 .35115 Mdot
.54419 .49827 Mdot
.41584 .53871 Mdot
.16707 .46428 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51774 .00752 Mdot
.55647 .02394 Mdot
.67815 .0752 Mdot
.01464 .20796 Mdot
.3292 .19441 Mdot
.43398 .06476 Mdot
.44256 .0053 Mdot
.36682 .57123 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48037 .60971 Mdot
.43753 .59156 Mdot
.30337 .53512 Mdot
.94378 .39579 Mdot
.66677 .44684 Mdot
.5966 .57467 Mdot
.6626 .04079 Mdot
.93223 .16664 Mdot
.30047 .22759 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48243 .61058 Mdot
.44408 .59433 Mdot
.32356 .54355 Mdot
.98936 .41149 Mdot
.67111 .42134 Mdot
.56285 .55113 Mdot
.54643 .60789 Mdot
.59869 .03229 Mdot
.78967 .11803 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50971 .00412 Mdot
.53092 .01311 Mdot
.59822 .0416 Mdot
.80368 .12698 Mdot
.23442 .26621 Mdot
.42757 .11937 Mdot
.5158 .05452 Mdot
.62767 .06914 Mdot
.49965 .61788 Mdot
.49888 .61756 Mdot
.49642 .61652 Mdot
.48859 .6132 Mdot
.46366 .60263 Mdot
.3847 .56923 Mdot
.14753 .47145 Mdot
.71942 .35345 Mdot
.52565 .49828 Mdot
.37018 .52195 Mdot
.04087 .41451 Mdot
.49922 .6177 Mdot
.4975 .61697 Mdot
.49203 .61466 Mdot
.47462 .60727 Mdot
.41931 .58385 Mdot
.24809 .51221 Mdot
.83815 .36468 Mdot
.63125 .49016 Mdot
.59967 .59851 Mdot
.70799 .06695 Mdot
.04679 .20939 Mdot
.49932 .61775 Mdot
.49783 .61711 Mdot
.49309 .6151 Mdot
.47799 .6087 Mdot
.42999 .58837 Mdot
.28032 .52554 Mdot
.89625 .38066 Mdot
.65701 .47018 Mdot
.6169 .59324 Mdot
.73679 .0741 Mdot
.09458 .22113 Mdot
.49817 .61726 Mdot
.49416 .61556 Mdot
.48139 .61014 Mdot
.44078 .59293 Mdot
.31336 .53929 Mdot
.96588 .40328 Mdot
.66919 .43467 Mdot
.58111 .5636 Mdot
.60951 .01755 Mdot
.78951 .11125 Mdot
.20092 .25427 Mdot
.49827 .6173 Mdot
.49448 .61569 Mdot
.48241 .61058 Mdot
.44402 .59431 Mdot
.32338 .54347 Mdot
.98893 .41133 Mdot
.67107 .42159 Mdot
.56319 .55136 Mdot
.54762 .60841 Mdot
.60241 .03386 Mdot
.80043 .12238 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50598 .00254 Mdot
.51905 .00808 Mdot
.56062 .02569 Mdot
.69094 .08054 Mdot
.04373 .21804 Mdot
.33175 .17801 Mdot
.41185 .0495 Mdot
.36638 .58993 Mdot
.14322 .48011 Mdot
.73307 .36455 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51075 .00456 Mdot
.53423 .01451 Mdot
.60868 .04601 Mdot
.83375 .13911 Mdot
.26527 .26669 Mdot
.45914 .11982 Mdot
.5924 .08236 Mdot
.8566 .16329 Mdot
.30796 .27895 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50814 .00345 Mdot
.52594 .011 Mdot
.58248 .03494 Mdot
.75727 .10803 Mdot
.17054 .25542 Mdot
.37422 .12588 Mdot
.40827 .02104 Mdot
.31221 .55867 Mdot
.99542 .42225 Mdot
.6855 .42649 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50773 .00328 Mdot
.52463 .01044 Mdot
.57831 .03318 Mdot
.74478 .10289 Mdot
.14986 .25035 Mdot
.36192 .13106 Mdot
.39188 .01852 Mdot
.27186 .54386 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.507 .00297 Mdot
.52228 .00945 Mdot
.57089 .03004 Mdot
.72236 .09361 Mdot
.10896 .23894 Mdot
.3446 .14563 Mdot
.38244 .02339 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .0024 Mdot
.51806 .00766 Mdot
.55749 .02437 Mdot
.6813 .07652 Mdot
.02195 .21053 Mdot
.32978 .19025 Mdot
.42824 .06085 Mdot
.42266 .61459 Mdot
.30559 .54568 Mdot
.96419 .40704 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48375 .61114 Mdot
.44826 .5961 Mdot
.33652 .54898 Mdot
.02047 .4227 Mdot
.6738 .40378 Mdot
.53901 .53473 Mdot
.46216 .57053 Mdot
.32907 .53578 Mdot
.9861 .40607 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51625 .00689 Mdot
.55172 .02192 Mdot
.66341 .06903 Mdot
.97936 .19527 Mdot
.32619 .21435 Mdot
.46111 .08339 Mdot
.53829 .0477 Mdot
.67233 .08285 Mdot
.01725 .21317 Mdot
.4999 .61799 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48984 .61373 Mdot
.46765 .60432 Mdot
.39725 .57453 Mdot
.18323 .48576 Mdot
.75117 .35101 Mdot
.55784 .49855 Mdot
.44938 .551 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.5056 .00237 Mdot
.51784 .00756 Mdot
.55677 .02406 Mdot
.67906 .07558 Mdot
.01676 .20871 Mdot
.32937 .1932 Mdot
.43231 .06362 Mdot
.43676 .00275 Mdot
.34883 .56369 Mdot
.06674 .44369 Mdot
.49805 .61721 Mdot
.49377 .61539 Mdot
.48017 .60962 Mdot
.43688 .59128 Mdot
.30138 .53429 Mdot
.93949 .39437 Mdot
.66619 .44912 Mdot
.59928 .57668 Mdot
.67181 .04483 Mdot
.95484 .17492 Mdot
.30471 .21623 Mdot
.4981 .61723 Mdot
.49396 .61547 Mdot
.48075 .60987 Mdot
.43875 .59207 Mdot
.30712 .53668 Mdot
.95198 .39854 Mdot
.66778 .44239 Mdot
.59115 .57068 Mdot
.64391 .0326 Mdot
.88429 .14856 Mdot
.28335 .24663 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50204 .00087 Mdot
.50651 .00276 Mdot
.52074 .0088 Mdot
.56601 .02797 Mdot
.70746 .08743 Mdot
.07918 .22973 Mdot
.33696 .15932 Mdot
.39078 .03326 Mdot
.29332 .5578 Mdot
.49788 .61713 Mdot
.49325 .61517 Mdot
.47848 .60891 Mdot
.43154 .58902 Mdot
.28505 .5275 Mdot
.90559 .38351 Mdot
.65959 .466 Mdot
.61482 .59037 Mdot
.72772 .06978 Mdot
.07702 .21588 Mdot
.31525 .14723 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50319 .00135 Mdot
.51017 .00431 Mdot
.53238 .01373 Mdot
.60284 .04354 Mdot
.81704 .13238 Mdot
.24911 .26703 Mdot
.44244 .11949 Mdot
.55132 .06729 Mdot
.73584 .11404 Mdot
.15814 .261 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.5059 .0025 Mdot
.5188 .00797 Mdot
.55983 .02536 Mdot
.6885 .07952 Mdot
.03831 .21619 Mdot
.3312 .18102 Mdot
.41578 .05227 Mdot
.37983 .59582 Mdot
.49951 .61783 Mdot
.49843 .61737 Mdot
.49501 .61592 Mdot
.48409 .61129 Mdot
.44936 .59657 Mdot
.33995 .55041 Mdot
.02892 .42581 Mdot
.67475 .39915 Mdot
.53313 .5305 Mdot
.44083 .56099 Mdot
.26182 .5074 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50713 .00302 Mdot
.52271 .00963 Mdot
.57226 .03062 Mdot
.72649 .09532 Mdot
.11687 .24126 Mdot
.34727 .1424 Mdot
.38216 .02156 Mdot
.25602 .54007 Mdot
.89131 .39263 Mdot
.67725 .48574 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48045 .60975 Mdot
.4378 .59167 Mdot
.30419 .53546 Mdot
.94555 .39639 Mdot
.667 .44588 Mdot
.59546 .57382 Mdot
.65866 .03906 Mdot
.92236 .16297 Mdot
.29795 .23213 Mdot
.49791 .61715 Mdot
.49333 .61521 Mdot
.47877 .60903 Mdot
.43244 .5894 Mdot
.2878 .52864 Mdot
.91112 .38524 Mdot
.66094 .46341 Mdot
.61308 .58845 Mdot
.72093 .06665 Mdot
.06353 .21174 Mdot
.31335 .1544 Mdot
.49767 .61704 Mdot
.49256 .61488 Mdot
.47631 .60799 Mdot
.42465 .58611 Mdot
.26413 .51883 Mdot
.86582 .37187 Mdot
.64577 .48203 Mdot
.61507 .59906 Mdot
.74231 .07864 Mdot
.108 .22601 Mdot
.32384 .1334 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00125 Mdot
.50942 .004 Mdot
.53001 .01272 Mdot
.59534 .04038 Mdot
.79529 .12357 Mdot
.22437 .26518 Mdot
.4178 .11955 Mdot
.49335 .04669 Mdot
.55892 .04052 Mdot
.5008 .00034 Mdot
.50253 .00107 Mdot
.50808 .00342 Mdot
.52573 .01091 Mdot
.58179 .03465 Mdot
.75522 .10719 Mdot
.16726 .25465 Mdot
.3721 .1266 Mdot
.40509 .02039 Mdot
.304 .55556 Mdot
.9778 .41643 Mdot
.68479 .43694 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00306 Mdot
.52302 .00976 Mdot
.57322 .03102 Mdot
.7294 .09653 Mdot
.12233 .24284 Mdot
.3493 .14028 Mdot
.38252 .02053 Mdot
.25509 .53928 Mdot
.88905 .39181 Mdot
.67628 .48653 Mdot
.49842 .61736 Mdot
.49495 .61589 Mdot
.48393 .61122 Mdot
.44882 .59634 Mdot
.33828 .54971 Mdot
.02479 .42429 Mdot
.67427 .4014 Mdot
.53596 .53255 Mdot
.45112 .5656 Mdot
.29413 .521 Mdot
.90751 .37909 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51888 .008 Mdot
.56007 .02546 Mdot
.68926 .07984 Mdot
.03999 .21677 Mdot
.33137 .18008 Mdot
.41454 .0514 Mdot
.3756 .59397 Mdot
.16849 .49003 Mdot
.75327 .36142 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.5083 .00352 Mdot
.52645 .01121 Mdot
.58408 .03562 Mdot
.76205 .10999 Mdot
.17807 .25711 Mdot
.37933 .12438 Mdot
.41642 .02293 Mdot
.33384 .56699 Mdot
.04489 .43945 Mdot
.68949 .39839 Mdot
.4994 .61778 Mdot
.49809 .61723 Mdot
.49393 .61546 Mdot
.48065 .60983 Mdot
.43842 .59193 Mdot
.30609 .53625 Mdot
.94972 .39778 Mdot
.66751 .44362 Mdot
.5927 .57179 Mdot
.64919 .03492 Mdot
.89811 .15384 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.5099 .0042 Mdot
.53155 .01338 Mdot
.6002 .04243 Mdot
.80941 .1293 Mdot
.24092 .26669 Mdot
.43408 .11938 Mdot
.53117 .06 Mdot
.67471 .08871 Mdot
.03076 .22005 Mdot
.49745 .61695 Mdot
.49188 .61459 Mdot
.47415 .60707 Mdot
.4178 .58321 Mdot
.24358 .51035 Mdot
.83081 .36293 Mdot
.62666 .49186 Mdot
.59307 .59727 Mdot
.69125 .06068 Mdot
.01208 .19829 Mdot
.31481 .18709 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50503 .00213 Mdot
.51604 .0068 Mdot
.55105 .02164 Mdot
.66135 .06816 Mdot
.97428 .1934 Mdot
.32563 .21714 Mdot
.46469 .08595 Mdot
.55122 .05348 Mdot
.71326 .10015 Mdot
.10771 .24378 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50435 .00184 Mdot
.51385 .00587 Mdot
.54411 .0187 Mdot
.6397 .05908 Mdot
.91895 .17259 Mdot
.31459 .24452 Mdot
.49088 .10895 Mdot
.6535 .1005 Mdot
.01229 .22175 Mdot
.49845 .61738 Mdot
.49505 .61594 Mdot
.48424 .61135 Mdot
.44981 .59676 Mdot
.34136 .551 Mdot
.03243 .4271 Mdot
.67519 .39725 Mdot
.5308 .5288 Mdot
.43233 .55717 Mdot
.23538 .49631 Mdot
.80071 .34939 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48298 .61082 Mdot
.44581 .59506 Mdot
.32892 .54579 Mdot
.00206 .41602 Mdot
.67211 .41411 Mdot
.55286 .54434 Mdot
.51146 .59245 Mdot
.48723 .60306 Mdot
.44386 .59123 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50289 .00123 Mdot
.50921 .0039 Mdot
.52932 .01243 Mdot
.59317 .03946 Mdot
.78893 .12098 Mdot
.21631 .26414 Mdot
.41029 .11989 Mdot
.47672 .04106 Mdot
.50837 .01956 Mdot
.55255 .02731 Mdot
.4997 .61791 Mdot
.49904 .61763 Mdot
.49693 .61673 Mdot
.49021 .61388 Mdot
.46882 .60481 Mdot
.40095 .57609 Mdot
.19391 .49008 Mdot
.76282 .3516 Mdot
.56968 .49867 Mdot
.47775 .56122 Mdot
.35254 .54065 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50278 .00118 Mdot
.50886 .00376 Mdot
.52823 .01197 Mdot
.58971 .038 Mdot
.77874 .11683 Mdot
.20262 .26197 Mdot
.39827 .12092 Mdot
.4515 .0329 Mdot
.4331 .60666 Mdot
.31728 .54645 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47783 .60863 Mdot
.42947 .58815 Mdot
.27875 .52488 Mdot
.89318 .37974 Mdot
.65608 .4715 Mdot
.61733 .59409 Mdot
.73907 .07524 Mdot
.09897 .22243 Mdot
.3198 .13648 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.5257 .0109 Mdot
.58172 .03462 Mdot
.75501 .1071 Mdot
.16691 .25457 Mdot
.37188 .12668 Mdot
.40476 .02032 Mdot
.30316 .55524 Mdot
.97603 .41585 Mdot
.68471 .43799 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50682 .00289 Mdot
.52174 .00922 Mdot
.56917 .02931 Mdot
.71712 .09144 Mdot
.09872 .23584 Mdot
.34156 .15008 Mdot
.38409 .02629 Mdot
.26772 .54611 Mdot
.9141 .39948 Mdot
.68316 .47531 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.48718 .6126 Mdot
.45919 .60073 Mdot
.37065 .56331 Mdot
.10875 .45617 Mdot
.69612 .36302 Mdot
.50869 .50219 Mdot
.33427 .51024 Mdot
.95381 .3829 Mdot
.64167 .42512 Mdot
.4982 .61727 Mdot
.49428 .61561 Mdot
.48178 .61031 Mdot
.44201 .59345 Mdot
.31716 .54087 Mdot
.97452 .40627 Mdot
.66994 .42979 Mdot
.57451 .55906 Mdot
.58682 .00761 Mdot
.72299 .08416 Mdot
.09446 .22958 Mdot
.50057 .00024 Mdot
.50183 .00078 Mdot
.50583 .00247 Mdot
.51859 .00788 Mdot
.55915 .02507 Mdot
.68642 .07865 Mdot
.03361 .21458 Mdot
.33076 .18365 Mdot
.41927 .0547 Mdot
.3918 .60106 Mdot
.21426 .50831 Mdot
.80398 .36447 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50512 .00217 Mdot
.51631 .00692 Mdot
.55192 .02201 Mdot
.66405 .0693 Mdot
.98093 .19584 Mdot
.32635 .21348 Mdot
.45998 .08259 Mdot
.53421 .04588 Mdot
.65935 .07734 Mdot
.98553 .20159 Mdot
.49844 .61737 Mdot
.49504 .61593 Mdot
.48421 .61134 Mdot
.44974 .59673 Mdot
.34111 .5509 Mdot
.03182 .42688 Mdot
.67511 .39758 Mdot
.5312 .52909 Mdot
.43378 .55783 Mdot
.23987 .49819 Mdot
.80772 .35095 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51749 .00742 Mdot
.55568 .0236 Mdot
.67568 .07417 Mdot
.00887 .20592 Mdot
.32876 .1977 Mdot
.43855 .06786 Mdot
.45844 .01229 Mdot
.41669 .59223 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50613 .0026 Mdot
.51952 .00828 Mdot
.56213 .02633 Mdot
.69559 .08248 Mdot
.05396 .22149 Mdot
.33293 .17242 Mdot
.40486 .04445 Mdot
.34243 .57945 Mdot
.08041 .4561 Mdot
.70284 .38468 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51996 .00846 Mdot
.56351 .02692 Mdot
.69981 .08424 Mdot
.06308 .22451 Mdot
.33418 .16755 Mdot
.39918 .04017 Mdot
.32287 .57087 Mdot
.03242 .43853 Mdot
.69367 .40867 Mdot
.4974 .61693 Mdot
.49172 .61452 Mdot
.47362 .60685 Mdot
.41614 .58251 Mdot
.23862 .50832 Mdot
.82297 .36115 Mdot
.6214 .49346 Mdot
.58478 .5954 Mdot
.66939 .05229 Mdot
.96276 .18131 Mdot
.31148 .21552 Mdot
.50041 .00017 Mdot
.50131 .00055 Mdot
.50417 .00177 Mdot
.51328 .00563 Mdot
.54229 .01793 Mdot
.634 .05668 Mdot
.90379 .16674 Mdot
.30927 .25059 Mdot
.49237 .11316 Mdot
.66402 .10609 Mdot
.04041 .23262 Mdot
.35683 .19556 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.5062 .00263 Mdot
.51974 .00837 Mdot
.56282 .02662 Mdot
.69769 .08336 Mdot
.05852 .223 Mdot
.33353 .16997 Mdot
.40195 .04228 Mdot
.33242 .57506 Mdot
.05546 .44686 Mdot
.69698 .39649 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49798 .61718 Mdot
.49355 .6153 Mdot
.47945 .60932 Mdot
.43462 .59033 Mdot
.29445 .5314 Mdot
.92479 .38958 Mdot
.6638 .45673 Mdot
.60736 .58316 Mdot
.49905 .61763 Mdot
.49698 .61675 Mdot
.49038 .61396 Mdot
.46937 .60505 Mdot
.40269 .57682 Mdot
.19896 .49213 Mdot
.76867 .3521 Mdot
.57548 .49863 Mdot
.49131 .56601 Mdot
.3941 .55796 Mdot
.1495 .46686 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51247 .00529 Mdot
.53971 .01684 Mdot
.6259 .05327 Mdot
.88186 .15819 Mdot
.29919 .25793 Mdot
.48911 .11738 Mdot
.66271 .10729 Mdot
.04003 .23319 Mdot
.35793 .19648 Mdot
.49774 .61707 Mdot
.49279 .61498 Mdot
.47704 .6083 Mdot
.42696 .58708 Mdot
.27113 .52173 Mdot
.87867 .37548 Mdot
.65108 .47737 Mdot
.61758 .59733 Mdot
.74483 .07865 Mdot
.1107 .22611 Mdot
.32358 .13157 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.52168 .00919 Mdot
.56898 .02923 Mdot
.71654 .0912 Mdot
.09758 .2355 Mdot
.34125 .15059 Mdot
.38435 .02664 Mdot
.26886 .54665 Mdot
.9163 .40014 Mdot
.68359 .47421 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47948 .60933 Mdot
.43471 .59036 Mdot
.29472 .53152 Mdot
.92537 .38976 Mdot
.6639 .45644 Mdot
.60708 .58292 Mdot
.69905 .05684 Mdot
.01761 .19688 Mdot
.30981 .18059 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50283 .0012 Mdot
.509 .00382 Mdot
.52867 .01216 Mdot
.59113 .0386 Mdot
.78292 .11853 Mdot
.20835 .26293 Mdot
.40319 .12041 Mdot
.46159 .03609 Mdot
.46293 .00083 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48247 .6106 Mdot
.44421 .59439 Mdot
.32398 .54372 Mdot
.99033 .41183 Mdot
.67118 .42079 Mdot
.56208 .55061 Mdot
.54376 .60671 Mdot
.59025 .02873 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.4806 .60981 Mdot
.43827 .59187 Mdot
.30564 .53606 Mdot
.94872 .39744 Mdot
.6674 .44417 Mdot
.59337 .57228 Mdot
.6515 .03593 Mdot
.49973 .61792 Mdot
.49915 .61767 Mdot
.49729 .61688 Mdot
.49135 .61437 Mdot
.47246 .60636 Mdot
.41245 .58095 Mdot
.22765 .50382 Mdot
.80646 .35773 Mdot
.60914 .49608 Mdot
.563 .58952 Mdot
.60891 .02837 Mdot
.49984 .61796 Mdot
.49948 .61781 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48304 .61084 Mdot
.44601 .59515 Mdot
.32955 .54606 Mdot
.00356 .41656 Mdot
.67223 .41326 Mdot
.55169 .54354 Mdot
.50734 .59062 Mdot
.49955 .61784 Mdot
.49858 .61743 Mdot
.49546 .61611 Mdot
.48554 .6119 Mdot
.45395 .59851 Mdot
.35426 .55642 Mdot
.06524 .43941 Mdot
.68108 .38061 Mdot
.51362 .51454 Mdot
.36657 .52715 Mdot
.04201 .41744 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50301 .00128 Mdot
.5096 .00407 Mdot
.53058 .01297 Mdot
.59716 .04115 Mdot
.80058 .12572 Mdot
.23079 .26588 Mdot
.42399 .11941 Mdot
.50747 .05159 Mdot
.60216 .05852 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48343 .61101 Mdot
.44726 .59568 Mdot
.33343 .54768 Mdot
.01291 .41994 Mdot
.67305 .40799 Mdot
.54456 .53862 Mdot
.48204 .57939 Mdot
.39263 .56278 Mdot
.15412 .47062 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48988 .61374 Mdot
.46777 .60437 Mdot
.39765 .5747 Mdot
.18438 .48622 Mdot
.75238 .35104 Mdot
.55909 .49857 Mdot
.4524 .5521 Mdot
.27536 .50862 Mdot
.86262 .36295 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51129 .00479 Mdot
.53595 .01524 Mdot
.61408 .04829 Mdot
.84906 .14522 Mdot
.278 .2651 Mdot
.47189 .11983 Mdot
.62384 .09391 Mdot
.94337 .19748 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.5042 .00178 Mdot
.51337 .00567 Mdot
.54258 .01805 Mdot
.63489 .05705 Mdot
.90617 .16766 Mdot
.31018 .24969 Mdot
.49233 .11257 Mdot
.66297 .10546 Mdot
.03753 .23149 Mdot
.35632 .19702 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.52589 .01098 Mdot
.5823 .03487 Mdot
.75674 .10781 Mdot
.1697 .25522 Mdot
.37367 .12606 Mdot
.40743 .02087 Mdot
.31004 .55784 Mdot
.9907 .42067 Mdot
.6853 .42929 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51106 .00469 Mdot
.53523 .01494 Mdot
.61181 .04733 Mdot
.84263 .14266 Mdot
.27289 .26591 Mdot
.46687 .11989 Mdot
.61152 .0894 Mdot
.91008 .18452 Mdot
.33646 .26352 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51069 .00453 Mdot
.53404 .01443 Mdot
.60805 .04574 Mdot
.83197 .13839 Mdot
.26365 .2668 Mdot
.45748 .11979 Mdot
.5883 .08085 Mdot
.84487 .15857 Mdot
.299 .28067 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.5063 .00267 Mdot
.52008 .00851 Mdot
.56389 .02708 Mdot
.70099 .08473 Mdot
.06559 .22534 Mdot
.33457 .16623 Mdot
.39772 .03903 Mdot
.31781 .56864 Mdot
.0205 .43429 Mdot
.69253 .41533 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50804 .00341 Mdot
.5256 .01085 Mdot
.58139 .03448 Mdot
.75403 .10669 Mdot
.16531 .25419 Mdot
.37088 .12704 Mdot
.40331 .02005 Mdot
.29947 .55386 Mdot
.96834 .41338 Mdot
.68439 .44254 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52444 .01036 Mdot
.57774 .03294 Mdot
.74305 .10217 Mdot
.14687 .24957 Mdot
.36035 .13194 Mdot
.39021 .01846 Mdot
.26814 .54259 Mdot
.90889 .39601 Mdot
.67896 .47593 Mdot
.50054 .00023 Mdot
.50174 .00074 Mdot
.50553 .00234 Mdot
.51761 .00747 Mdot
.55606 .02376 Mdot
.67687 .07467 Mdot
.01166 .20691 Mdot
.32897 .19611 Mdot
.43635 .06636 Mdot
.45076 .00891 Mdot
.3925 .58202 Mdot
.18496 .48977 Mdot
.49941 .61779 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48103 .60999 Mdot
.43964 .59245 Mdot
.30987 .53783 Mdot
.95806 .4006 Mdot
.66843 .43904 Mdot
.58687 .56763 Mdot
.62924 .02619 Mdot
.84486 .13326 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50855 .00363 Mdot
.52724 .01155 Mdot
.58659 .03668 Mdot
.76951 .11305 Mdot
.18938 .25949 Mdot
.38762 .12252 Mdot
.43095 .02678 Mdot
.37392 .58279 Mdot
.14694 .47775 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.48531 .6118 Mdot
.45323 .5982 Mdot
.35199 .55546 Mdot
.05937 .43719 Mdot
.67975 .38342 Mdot
.51598 .51682 Mdot
.37615 .53161 Mdot
.06874 .42804 Mdot
.66139 .36628 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50437 .00185 Mdot
.51391 .0059 Mdot
.54429 .01878 Mdot
.64025 .05931 Mdot
.9204 .17314 Mdot
.31503 .2439 Mdot
.49059 .1085 Mdot
.65203 .09978 Mdot
.00839 .22024 Mdot
.35217 .21246 Mdot
.4999 .61799 Mdot
.4997 .6179 Mdot
.49903 .61762 Mdot
.49691 .61672 Mdot
.49016 .61386 Mdot
.46866 .60475 Mdot
.40046 .57588 Mdot
.19249 .4895 Mdot
.7612 .35149 Mdot
.56806 .49866 Mdot
.47393 .55986 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50766 .00325 Mdot
.5244 .01035 Mdot
.57761 .03288 Mdot
.74267 .10201 Mdot
.14622 .2494 Mdot
.36001 .13213 Mdot
.38987 .01845 Mdot
.2674 .54234 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50287 .00122 Mdot
.50915 .00388 Mdot
.52915 .01236 Mdot
.59264 .03924 Mdot
.78737 .12035 Mdot
.21429 .26385 Mdot
.40845 .12 Mdot
.47274 .03974 Mdot
.49635 .01459 Mdot
.5145 .01121 Mdot
.49928 .61773 Mdot
.49772 .61707 Mdot
.49274 .61496 Mdot
.47688 .60823 Mdot
.42645 .58687 Mdot
.26959 .52109 Mdot
.8758 .37466 Mdot
.64997 .47846 Mdot
.61725 .59781 Mdot
.74492 .07891 Mdot
.11121 .22638 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.47428 .60713 Mdot
.41822 .58339 Mdot
.2448 .51086 Mdot
.83279 .36339 Mdot
.62793 .49142 Mdot
.59495 .59765 Mdot
.69611 .06252 Mdot
.02243 .20168 Mdot
.31522 .18095 Mdot
.49788 .61713 Mdot
.49324 .61517 Mdot
.47845 .6089 Mdot
.43144 .58898 Mdot
.28476 .52737 Mdot
.905 .38333 Mdot
.65943 .46626 Mdot
.61498 .59056 Mdot
.72838 .07008 Mdot
.0783 .21627 Mdot
.31546 .14657 Mdot
.49844 .61737 Mdot
.49503 .61592 Mdot
.48416 .61132 Mdot
.44956 .59665 Mdot
.34055 .55066 Mdot
.03042 .42636 Mdot
.67494 .39833 Mdot
.53212 .52977 Mdot
.43717 .55935 Mdot
.2504 .5026 Mdot
.8249 .35506 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50752 .00319 Mdot
.52395 .01015 Mdot
.57616 .03227 Mdot
.7383 .10021 Mdot
.13853 .24735 Mdot
.35622 .13455 Mdot
.38642 .01866 Mdot
.26034 .54011 Mdot
.89603 .39288 Mdot
.67682 .48256 Mdot
.4998 .61795 Mdot
.49935 .61776 Mdot
.49793 .61716 Mdot
.4934 .61523 Mdot
.47897 .60912 Mdot
.43309 .58968 Mdot
.28979 .52947 Mdot
.91517 .38651 Mdot
.66186 .46148 Mdot
.61159 .58697 Mdot
.71533 .06412 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.52168 .00919 Mdot
.56898 .02923 Mdot
.71655 .0912 Mdot
.09759 .2355 Mdot
.34125 .15059 Mdot
.38435 .02664 Mdot
.26885 .54665 Mdot
.91629 .40014 Mdot
.68358 .47422 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50657 .00279 Mdot
.52094 .00888 Mdot
.56662 .02823 Mdot
.70935 .08821 Mdot
.08305 .23096 Mdot
.33776 .15742 Mdot
.38912 .03174 Mdot
.28728 .5551 Mdot
.95323 .41158 Mdot
.68833 .45431 Mdot
.49938 .61777 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60957 Mdot
.43652 .59113 Mdot
.30026 .53382 Mdot
.93708 .39358 Mdot
.66584 .4504 Mdot
.60072 .57779 Mdot
.67681 .04702 Mdot
.96682 .17924 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50352 .00149 Mdot
.51123 .00476 Mdot
.53575 .01516 Mdot
.61346 .04803 Mdot
.84731 .14453 Mdot
.27664 .26534 Mdot
.47057 .11986 Mdot
.62062 .09273 Mdot
.93476 .19415 Mdot
.34405 .25295 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52246 .00952 Mdot
.57145 .03028 Mdot
.72405 .09431 Mdot
.11222 .2399 Mdot
.34566 .14427 Mdot
.38222 .02259 Mdot
.25778 .54113 Mdot
.89491 .39376 Mdot
.67846 .48426 Mdot
.49835 .61733 Mdot
.49473 .6158 Mdot
.48321 .61092 Mdot
.44656 .59538 Mdot
.33124 .54676 Mdot
.00763 .41803 Mdot
.67258 .41096 Mdot
.54856 .54139 Mdot
.49625 .58571 Mdot
.43833 .58224 Mdot
.2902 .52649 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53096 .01313 Mdot
.59836 .04165 Mdot
.80407 .12714 Mdot
.23487 .26625 Mdot
.42802 .11937 Mdot
.51683 .05489 Mdot
.63084 .07046 Mdot
.91974 .17855 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50559 .00237 Mdot
.51781 .00755 Mdot
.5567 .02403 Mdot
.67884 .07549 Mdot
.01626 .20853 Mdot
.32933 .19349 Mdot
.43271 .06389 Mdot
.43813 .00335 Mdot
.35308 .56547 Mdot
.07763 .4478 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52353 .00998 Mdot
.57483 .03171 Mdot
.73428 .09855 Mdot
.1313 .24537 Mdot
.35296 .13699 Mdot
.38413 .01926 Mdot
.25646 .53913 Mdot
.89024 .3917 Mdot
.67592 .48558 Mdot
.49856 .61743 Mdot
.49543 .6161 Mdot
.48543 .61186 Mdot
.45362 .59837 Mdot
.35321 .55598 Mdot
.06254 .43839 Mdot
.68045 .38189 Mdot
.51467 .51557 Mdot
.37085 .52915 Mdot
.05387 .42213 Mdot
.65762 .37314 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51877 .00796 Mdot
.55975 .02533 Mdot
.68827 .07943 Mdot
.03778 .21601 Mdot
.33115 .18132 Mdot
.41616 .05254 Mdot
.38116 .5964 Mdot
.18399 .49618 Mdot
.76833 .36114 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49075 .61411 Mdot
.47055 .60555 Mdot
.40643 .5784 Mdot
.20989 .49657 Mdot
.78217 .35368 Mdot
.58831 .49823 Mdot
.52024 .57596 Mdot
.48244 .59467 Mdot
.49885 .61755 Mdot
.49633 .61648 Mdot
.48831 .61308 Mdot
.46277 .60225 Mdot
.38189 .56805 Mdot
.13965 .46833 Mdot
.71381 .35485 Mdot
.52055 .49859 Mdot
.35802 .51759 Mdot
.00967 .40274 Mdot
.64682 .39378 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47346 .60678 Mdot
.41563 .58229 Mdot
.23708 .50769 Mdot
.82058 .36063 Mdot
.61973 .4939 Mdot
.58199 .59471 Mdot
.66189 .04938 Mdot
.94485 .17488 Mdot
.30889 .22499 Mdot
.49785 .61712 Mdot
.49316 .61513 Mdot
.4782 .60879 Mdot
.43065 .58864 Mdot
.28232 .52637 Mdot
.90018 .38185 Mdot
.65814 .46845 Mdot
.61616 .59209 Mdot
.73335 .07243 Mdot
.08797 .21917 Mdot
.31725 .1417 Mdot
.50076 .00032 Mdot
.50244 .00103 Mdot
.50776 .00329 Mdot
.52473 .01049 Mdot
.57865 .03332 Mdot
.7458 .1033 Mdot
.15159 .2508 Mdot
.36286 .13057 Mdot
.39293 .01859 Mdot
.27425 .54469 Mdot
.91961 .39885 Mdot
.68049 .47025 Mdot
.50039 .00016 Mdot
.50124 .00053 Mdot
.50395 .00167 Mdot
.51257 .00533 Mdot
.54004 .01698 Mdot
.62694 .05371 Mdot
.88469 .1593 Mdot
.30067 .25709 Mdot
.4899 .11696 Mdot
.66401 .1076 Mdot
.04285 .23413 Mdot
.35819 .19489 Mdot
.49911 .61766 Mdot
.49717 .61683 Mdot
.49097 .61421 Mdot
.47124 .60584 Mdot
.4086 .57932 Mdot
.21629 .49917 Mdot
.79057 .35493 Mdot
.59588 .4977 Mdot
.53645 .58131 Mdot
.53122 .6148 Mdot
.57252 .02553 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.50381 .00161 Mdot
.51212 .00514 Mdot
.53861 .01637 Mdot
.62245 .05182 Mdot
.87238 .15446 Mdot
.29387 .2605 Mdot
.48565 .11852 Mdot
.65592 .10523 Mdot
.02441 .22774 Mdot
.35643 .2052 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.52379 .01009 Mdot
.57567 .03206 Mdot
.73682 .0996 Mdot
.13588 .24663 Mdot
.355 .13542 Mdot
.38548 .01884 Mdot
.25861 .53963 Mdot
.89337 .3923 Mdot
.67637 .48392 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50746 .00316 Mdot
.52375 .01007 Mdot
.57554 .03201 Mdot
.73643 .09944 Mdot
.13518 .24644 Mdot
.35468 .13566 Mdot
.38525 .01889 Mdot
.25822 .53953 Mdot
.89278 .39218 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48015 .60962 Mdot
.43683 .59126 Mdot
.30123 .53423 Mdot
.93917 .39426 Mdot
.66614 .4493 Mdot
.59947 .57683 Mdot
.67249 .04513 Mdot
.95648 .17552 Mdot
.30494 .21536 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51484 .00629 Mdot
.54726 .02003 Mdot
.64953 .06321 Mdot
.94452 .18232 Mdot
.32106 .23271 Mdot
.48226 .09963 Mdot
.6169 .08321 Mdot
.91155 .1821 Mdot
.33215 .25995 Mdot
.49992 .618 Mdot
.49975 .61793 Mdot
.4992 .61769 Mdot
.49744 .61695 Mdot
.49185 .61458 Mdot
.47404 .60703 Mdot
.41748 .58307 Mdot
.2426 .50995 Mdot
.82924 .36257 Mdot
.62564 .4922 Mdot
.59151 .59694 Mdot
.50038 .00016 Mdot
.50123 .00052 Mdot
.5039 .00166 Mdot
.51244 .00527 Mdot
.53961 .01679 Mdot
.62559 .05314 Mdot
.88101 .15786 Mdot
.29874 .25817 Mdot
.48885 .11749 Mdot
.66225 .10717 Mdot
.03902 .23285 Mdot
.35784 .19704 Mdot
.49861 .61744 Mdot
.49557 .61615 Mdot
.48588 .61204 Mdot
.45503 .59897 Mdot
.35762 .55783 Mdot
.074 .44275 Mdot
.68334 .37659 Mdot
.51078 .51138 Mdot
.35436 .52137 Mdot
.00873 .40442 Mdot
.65001 .39633 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49444 .61567 Mdot
.48228 .61052 Mdot
.44359 .59412 Mdot
.32204 .54291 Mdot
.9858 .41023 Mdot
.67083 .42337 Mdot
.56566 .55304 Mdot
.55622 .6122 Mdot
.62936 .0452 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51464 .00621 Mdot
.54661 .01976 Mdot
.64751 .06236 Mdot
.93932 .18035 Mdot
.31996 .23525 Mdot
.48457 .10173 Mdot
.62607 .08745 Mdot
.93751 .19248 Mdot
.34029 .24893 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50522 .00222 Mdot
.51664 .00706 Mdot
.55298 .02246 Mdot
.66733 .07067 Mdot
.98892 .19875 Mdot
.32712 .20902 Mdot
.45407 .07846 Mdot
.51307 .03647 Mdot
.59166 .04857 Mdot
.80026 .12892 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.476 .60786 Mdot
.42367 .58569 Mdot
.26118 .51761 Mdot
.86055 .37043 Mdot
.64334 .48379 Mdot
.61322 .59942 Mdot
.73898 .07772 Mdot
.10289 .22491 Mdot
.323 .13603 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50357 .00152 Mdot
.51139 .00483 Mdot
.53626 .01537 Mdot
.61506 .0487 Mdot
.85179 .14631 Mdot
.28007 .26469 Mdot
.47387 .11977 Mdot
.62866 .09566 Mdot
.95609 .20236 Mdot
.34855 .24256 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00313 Mdot
.52349 .00996 Mdot
.57472 .03166 Mdot
.73395 .09841 Mdot
.13069 .2452 Mdot
.3527 .13721 Mdot
.38398 .01933 Mdot
.25625 .53909 Mdot
.88996 .39166 Mdot
.67589 .48573 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51978 .00839 Mdot
.56295 .02668 Mdot
.69809 .08352 Mdot
.05939 .22329 Mdot
.33365 .16951 Mdot
.40141 .04188 Mdot
.33056 .57425 Mdot
.05092 .4452 Mdot
.69619 .3988 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50541 .00229 Mdot
.51723 .00731 Mdot
.55485 .02325 Mdot
.67312 .0731 Mdot
.00281 .20376 Mdot
.32828 .20115 Mdot
.44333 .0711 Mdot
.47514 .01966 Mdot
.46982 .61475 Mdot
.41951 .58694 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50605 .00257 Mdot
.51928 .00817 Mdot
.56135 .026 Mdot
.69317 .08147 Mdot
.04867 .21971 Mdot
.3323 .17529 Mdot
.4084 .04703 Mdot
.35456 .58476 Mdot
.11169 .46793 Mdot
.7147 .37268 Mdot
.49997 .61802 Mdot
.49991 .618 Mdot
.49973 .61792 Mdot
.49913 .61767 Mdot
.49723 .61686 Mdot
.49118 .61429 Mdot
.47191 .60612 Mdot
.41072 .58022 Mdot
.22252 .50172 Mdot
.79914 .35637 Mdot
.60321 .49694 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.5048 .00204 Mdot
.51531 .00649 Mdot
.54874 .02066 Mdot
.65414 .06514 Mdot
.95626 .18672 Mdot
.32317 .22676 Mdot
.47613 .09454 Mdot
.59343 .0725 Mdot
.84297 .15422 Mdot
.50053 .00022 Mdot
.50169 .00071 Mdot
.50537 .00228 Mdot
.51711 .00725 Mdot
.55446 .02308 Mdot
.67191 .07259 Mdot
.99992 .20272 Mdot
.32805 .2028 Mdot
.4456 .07265 Mdot
.48311 .02319 Mdot
.49535 .00756 Mdot
.50061 .00325 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.51441 .00611 Mdot
.54589 .01945 Mdot
.64524 .0614 Mdot
.93345 .17812 Mdot
.3186 .23804 Mdot
.48686 .10399 Mdot
.63542 .09182 Mdot
.96347 .20275 Mdot
.34584 .23632 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55363 .02273 Mdot
.66935 .07152 Mdot
.99381 .20052 Mdot
.32755 .20626 Mdot
.45034 .07589 Mdot
.49984 .03059 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50593 .00252 Mdot
.5189 .00801 Mdot
.56015 .02549 Mdot
.68948 .07993 Mdot
.04049 .21694 Mdot
.33142 .1798 Mdot
.41418 .05115 Mdot
.37436 .59342 Mdot
.16505 .48867 Mdot
.75021 .36165 Mdot
.49995 .61801 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.49831 .61732 Mdot
.4946 .61574 Mdot
.4828 .61074 Mdot
.44526 .59483 Mdot
.3272 .54507 Mdot
.99796 .41455 Mdot
.67178 .41644 Mdot
.55607 .54652 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47562 .6077 Mdot
.42247 .58519 Mdot
.25758 .51612 Mdot
.85422 .36875 Mdot
.64021 .48577 Mdot
.61036 .59958 Mdot
.73308 .07585 Mdot
.0932 .22256 Mdot
.32137 .14102 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51445 .00613 Mdot
.546 .0195 Mdot
.64558 .06155 Mdot
.93434 .17846 Mdot
.31882 .23762 Mdot
.48653 .10365 Mdot
.63407 .09118 Mdot
.95976 .20129 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48478 .61158 Mdot
.45153 .59749 Mdot
.3467 .55324 Mdot
.04586 .43211 Mdot
.67718 .39018 Mdot
.52267 .52254 Mdot
.40207 .54349 Mdot
.14365 .45833 Mdot
.69785 .34251 Mdot
.49928 .61773 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47659 .60811 Mdot
.42554 .58648 Mdot
.26683 .51994 Mdot
.87071 .37322 Mdot
.6479 .48032 Mdot
.61634 .59853 Mdot
.74417 .079 Mdot
.11058 .22645 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48744 .61271 Mdot
.46001 .60108 Mdot
.37323 .5644 Mdot
.11576 .45891 Mdot
.69957 .36081 Mdot
.51021 .50101 Mdot
.33617 .51047 Mdot
.95755 .38403 Mdot
.64185 .42292 Mdot
.4979 .61714 Mdot
.4933 .61519 Mdot
.47867 .60899 Mdot
.43214 .58928 Mdot
.28687 .52825 Mdot
.90924 .38465 Mdot
.66049 .4643 Mdot
.61371 .58912 Mdot
.72335 .06776 Mdot
.06838 .21324 Mdot
.31397 .15178 Mdot
.4999 .61799 Mdot
.49969 .6179 Mdot
.49901 .61761 Mdot
.49683 .61669 Mdot
.48991 .61375 Mdot
.46785 .6044 Mdot
.3979 .5748 Mdot
.18509 .48651 Mdot
.75313 .35107 Mdot
.55985 .49858 Mdot
.45426 .55277 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48011 .6096 Mdot
.4367 .59121 Mdot
.30083 .53406 Mdot
.9383 .39398 Mdot
.66602 .44976 Mdot
.6 .57723 Mdot
.6743 .04592 Mdot
.96085 .17709 Mdot
.30553 .21303 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50618 .00262 Mdot
.51967 .00834 Mdot
.5626 .02653 Mdot
.69704 .08309 Mdot
.05711 .22254 Mdot
.33334 .17072 Mdot
.40283 .04295 Mdot
.33546 .57639 Mdot
.06295 .44961 Mdot
.69846 .39277 Mdot
.49908 .61765 Mdot
.49708 .6168 Mdot
.4907 .61409 Mdot
.47037 .60547 Mdot
.40584 .57816 Mdot
.20817 .49587 Mdot
.77997 .35339 Mdot
.58628 .49833 Mdot
.51576 .57445 Mdot
.46884 .58904 Mdot
.37548 .56033 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50283 .0012 Mdot
.50903 .00383 Mdot
.52877 .0122 Mdot
.59142 .03872 Mdot
.78378 .11889 Mdot
.20952 .26312 Mdot
.4042 .12032 Mdot
.46371 .03678 Mdot
.46927 .00343 Mdot
.42901 .59315 Mdot
.49778 .61709 Mdot
.49292 .61503 Mdot
.47744 .60847 Mdot
.42825 .58763 Mdot
.27504 .52335 Mdot
.88605 .37762 Mdot
.65375 .47447 Mdot
.61784 .59584 Mdot
.74298 .07734 Mdot
.10661 .22474 Mdot
.32202 .13313 Mdot
.49819 .61727 Mdot
.49423 .61559 Mdot
.48162 .61024 Mdot
.44151 .59324 Mdot
.31561 .54023 Mdot
.97099 .40505 Mdot
.66964 .43179 Mdot
.57723 .56092 Mdot
.59618 .01171 Mdot
.75078 .09555 Mdot
.1441 .24309 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49387 .61543 Mdot
.48047 .60975 Mdot
.43786 .5917 Mdot
.30439 .53554 Mdot
.94599 .39653 Mdot
.66706 .44565 Mdot
.59517 .57361 Mdot
.65769 .03864 Mdot
.9199 .16206 Mdot
.50049 .00021 Mdot
.50157 .00066 Mdot
.505 .00212 Mdot
.51592 .00675 Mdot
.55067 .02148 Mdot
.66015 .06766 Mdot
.97133 .19232 Mdot
.32528 .21875 Mdot
.4667 .08741 Mdot
.55855 .05676 Mdot
.73626 .10983 Mdot
.15181 .25682 Mdot
.49871 .61749 Mdot
.49588 .61629 Mdot
.48688 .61247 Mdot
.45822 .60032 Mdot
.3676 .56203 Mdot
.1005 .45296 Mdot
.69248 .36586 Mdot
.50776 .50387 Mdot
.33466 .51106 Mdot
.95583 .3839 Mdot
.6424 .42433 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.48901 .61337 Mdot
.465 .6032 Mdot
.38892 .57101 Mdot
.15941 .47619 Mdot
.72881 .35191 Mdot
.53483 .49815 Mdot
.39268 .53018 Mdot
.10147 .43806 Mdot
.66816 .35023 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.52081 .00882 Mdot
.56621 .02806 Mdot
.7081 .08769 Mdot
.08049 .23015 Mdot
.33723 .15867 Mdot
.3902 .03274 Mdot
.29123 .55687 Mdot
.96149 .41424 Mdot
.68895 .4496 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48444 .61144 Mdot
.45047 .59704 Mdot
.34341 .55186 Mdot
.03756 .42901 Mdot
.67589 .39451 Mdot
.52754 .52635 Mdot
.4203 .55176 Mdot
.19845 .48092 Mdot
.75028 .34105 Mdot
.49965 .61789 Mdot
.49888 .61756 Mdot
.49644 .61652 Mdot
.48865 .61322 Mdot
.46387 .60271 Mdot
.38534 .5695 Mdot
.14933 .47217 Mdot
.72077 .35317 Mdot
.52693 .49823 Mdot
.37329 .52308 Mdot
.04904 .41763 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51288 .00546 Mdot
.54101 .01738 Mdot
.62997 .05498 Mdot
.89292 .16251 Mdot
.30465 .25446 Mdot
.49158 .11553 Mdot
.66588 .10772 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49248 .61485 Mdot
.47606 .60788 Mdot
.42385 .58577 Mdot
.26172 .51783 Mdot
.86151 .37069 Mdot
.64379 .48348 Mdot
.61359 .59937 Mdot
.73969 .07793 Mdot
.10401 .22516 Mdot
.49923 .61771 Mdot
.49756 .617 Mdot
.49221 .61473 Mdot
.47519 .60751 Mdot
.42111 .58461 Mdot
.25347 .51443 Mdot
.84716 .36692 Mdot
.63646 .48781 Mdot
.60628 .59938 Mdot
.72393 .07271 Mdot
.07711 .21828 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57518 .03185 Mdot
.73533 .09898 Mdot
.13321 .2459 Mdot
.3538 .13633 Mdot
.38465 .01907 Mdot
.25723 .53929 Mdot
.89133 .39189 Mdot
.67606 .48499 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48966 .61365 Mdot
.46707 .60407 Mdot
.39545 .57377 Mdot
.17803 .48366 Mdot
.74587 .35095 Mdot
.55237 .49844 Mdot
.43601 .54612 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54654 .01973 Mdot
.64729 .06227 Mdot
.93877 .18014 Mdot
.31984 .23552 Mdot
.4848 .10195 Mdot
.627 .08788 Mdot
.9401 .19351 Mdot
.34095 .24774 Mdot
.49811 .61723 Mdot
.49396 .61547 Mdot
.48077 .60988 Mdot
.4388 .5921 Mdot
.30727 .53675 Mdot
.95231 .39865 Mdot
.66781 .44221 Mdot
.59092 .57051 Mdot
.64312 .03226 Mdot
.88221 .14777 Mdot
.28229 .24726 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50136 .00057 Mdot
.50432 .00183 Mdot
.51376 .00584 Mdot
.54382 .01858 Mdot
.63879 .05869 Mdot
.91655 .17166 Mdot
.31382 .24553 Mdot
.49131 .10969 Mdot
.65576 .10164 Mdot
.0183 .22406 Mdot
.49851 .6174 Mdot
.49525 .61602 Mdot
.48487 .61162 Mdot
.45183 .59761 Mdot
.34763 .55364 Mdot
.04823 .43299 Mdot
.67758 .38896 Mdot
.52138 .5215 Mdot
.39717 .54126 Mdot
.12921 .45243 Mdot
.68803 .34538 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00124 Mdot
.50928 .00394 Mdot
.52957 .01254 Mdot
.59394 .03979 Mdot
.79119 .12191 Mdot
.21922 .26454 Mdot
.41297 .11974 Mdot
.48258 .04302 Mdot
.52612 .02691 Mdot
.60867 .05102 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00112 Mdot
.50843 .00358 Mdot
.52686 .01139 Mdot
.58537 .03617 Mdot
.7659 .11157 Mdot
.18397 .25838 Mdot
.38356 .12335 Mdot
.42365 .02478 Mdot
.35357 .57472 Mdot
.09354 .45733 Mdot
.49976 .61793 Mdot
.49923 .61771 Mdot
.49754 .61699 Mdot
.49218 .61472 Mdot
.47508 .60747 Mdot
.42074 .58445 Mdot
.25237 .51398 Mdot
.8453 .36645 Mdot
.63542 .48832 Mdot
.60504 .59926 Mdot
.72103 .07168 Mdot
.4992 .61769 Mdot
.49745 .61695 Mdot
.49186 .61458 Mdot
.47408 .60704 Mdot
.4176 .58312 Mdot
.24296 .5101 Mdot
.82982 .3627 Mdot
.62601 .49208 Mdot
.59209 .59707 Mdot
.68871 .05972 Mdot
.00658 .19646 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47425 .60712 Mdot
.41812 .58335 Mdot
.24453 .51075 Mdot
.83235 .36329 Mdot
.62765 .49152 Mdot
.59454 .59757 Mdot
.69505 .06212 Mdot
.02021 .20096 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52606 .01105 Mdot
.58287 .03511 Mdot
.75843 .1085 Mdot
.17239 .25584 Mdot
.37544 .1255 Mdot
.41016 .02145 Mdot
.31715 .56055 Mdot
.00634 .42595 Mdot
.68603 .42007 Mdot
.49935 .61776 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47908 .60916 Mdot
.43344 .58983 Mdot
.29084 .5299 Mdot
.91733 .38719 Mdot
.66232 .46043 Mdot
.61072 .58614 Mdot
.71213 .06267 Mdot
.04555 .20606 Mdot
.49838 .61735 Mdot
.49484 .61585 Mdot
.48358 .61107 Mdot
.44771 .59587 Mdot
.33482 .54827 Mdot
.01632 .42118 Mdot
.67338 .40609 Mdot
.54203 .53686 Mdot
.473 .57537 Mdot
.36367 .55046 Mdot
.07395 .43898 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50776 .00329 Mdot
.52471 .01048 Mdot
.57858 .03329 Mdot
.74559 .10322 Mdot
.15124 .2507 Mdot
.36266 .13067 Mdot
.39271 .01857 Mdot
.27375 .54451 Mdot
.9187 .3986 Mdot
.68037 .47074 Mdot
.49837 .61734 Mdot
.49482 .61584 Mdot
.48348 .61103 Mdot
.44742 .59575 Mdot
.33392 .54789 Mdot
.01411 .42038 Mdot
.67316 .40732 Mdot
.54366 .538 Mdot
.47884 .57797 Mdot
.38237 .55841 Mdot
.12507 .45902 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47989 .60951 Mdot
.436 .59091 Mdot
.29868 .53317 Mdot
.93372 .39247 Mdot
.66532 .45216 Mdot
.60267 .57931 Mdot
.68355 .04999 Mdot
.98266 .18486 Mdot
.30773 .20091 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00283 Mdot
.52123 .009 Mdot
.56755 .02862 Mdot
.71217 .08938 Mdot
.0888 .23278 Mdot
.33904 .15466 Mdot
.38694 .02961 Mdot
.27917 .55143 Mdot
.93666 .40635 Mdot
.68667 .46353 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47724 .60838 Mdot
.42759 .58735 Mdot
.27303 .52251 Mdot
.88224 .37651 Mdot
.65241 .47599 Mdot
.61781 .59665 Mdot
.74422 .07813 Mdot
.10921 .22558 Mdot
.32294 .13209 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.5257 .0109 Mdot
.58173 .03462 Mdot
.75502 .1071 Mdot
.16693 .25457 Mdot
.37189 .12667 Mdot
.40478 .02033 Mdot
.30322 .55526 Mdot
.97614 .41589 Mdot
.68472 .43793 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53222 .01366 Mdot
.60232 .04333 Mdot
.81556 .13179 Mdot
.24756 .26699 Mdot
.44085 .11946 Mdot
.54745 .06588 Mdot
.72417 .10922 Mdot
.13648 .25482 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.49329 .61519 Mdot
.47864 .60898 Mdot
.43204 .58923 Mdot
.28656 .52813 Mdot
.90863 .38446 Mdot
.66035 .46459 Mdot
.61391 .58933 Mdot
.72411 .06811 Mdot
.0699 .21371 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51142 .00484 Mdot
.53636 .01542 Mdot
.61539 .04884 Mdot
.85272 .14668 Mdot
.28076 .26455 Mdot
.47452 .11975 Mdot
.63023 .09623 Mdot
.96019 .20393 Mdot
.34925 .24045 Mdot
.50021 9e-05 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52175 .00922 Mdot
.5692 .02932 Mdot
.7172 .09147 Mdot
.09888 .23589 Mdot
.3416 .15001 Mdot
.38405 .02623 Mdot
.26756 .54604 Mdot
.91378 .39939 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50413 .00175 Mdot
.51314 .00557 Mdot
.54186 .01775 Mdot
.63264 .0561 Mdot
.90013 .16532 Mdot
.30779 .25195 Mdot
.49228 .11402 Mdot
.66519 .10687 Mdot
.04374 .23395 Mdot
.3575 .19392 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50659 .00279 Mdot
.52098 .0089 Mdot
.56675 .02829 Mdot
.70974 .08837 Mdot
.08387 .23122 Mdot
.33793 .15702 Mdot
.38879 .03143 Mdot
.28607 .55455 Mdot
.95072 .41078 Mdot
.68812 .45574 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00312 Mdot
.52346 .00995 Mdot
.57463 .03162 Mdot
.7337 .09831 Mdot
.13024 .24508 Mdot
.35251 .13737 Mdot
.38387 .01939 Mdot
.2561 .53907 Mdot
.88977 .39163 Mdot
.67588 .48584 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43731 .59146 Mdot
.3027 .53484 Mdot
.94232 .39531 Mdot
.66658 .44762 Mdot
.59752 .57535 Mdot
.49824 .61729 Mdot
.4944 .61566 Mdot
.48216 .61047 Mdot
.44321 .59396 Mdot
.32087 .54242 Mdot
.98308 .40927 Mdot
.67062 .42493 Mdot
.56782 .5545 Mdot
.56369 .61548 Mdot
.65256 .05493 Mdot
.9368 .17567 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00126 Mdot
.50944 .004 Mdot
.53008 .01275 Mdot
.59557 .04047 Mdot
.79594 .12384 Mdot
.22518 .26528 Mdot
.41857 .11953 Mdot
.49509 .04729 Mdot
.56424 .04274 Mdot
.72716 .10069 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.48752 .61274 Mdot
.46025 .60118 Mdot
.37398 .56471 Mdot
.11781 .45971 Mdot
.70063 .3602 Mdot
.51079 .50071 Mdot
.33712 .5107 Mdot
.9596 .38471 Mdot
.64203 .42177 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50553 .00235 Mdot
.51763 .00747 Mdot
.55611 .02378 Mdot
.67702 .07473 Mdot
.01201 .20703 Mdot
.329 .19591 Mdot
.43606 .06617 Mdot
.44978 .00848 Mdot
.38943 .58073 Mdot
.17623 .48627 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51128 .00478 Mdot
.53593 .01523 Mdot
.61401 .04826 Mdot
.84886 .14514 Mdot
.27784 .26513 Mdot
.47174 .11984 Mdot
.62347 .09377 Mdot
.94238 .1971 Mdot
.34584 .24935 Mdot
.4991 .61765 Mdot
.49715 .61682 Mdot
.49091 .61418 Mdot
.47105 .60576 Mdot
.40799 .57906 Mdot
.21449 .49844 Mdot
.78817 .35455 Mdot
.59375 .49788 Mdot
.53196 .57985 Mdot
.51779 .60928 Mdot
.53026 .0077 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52227 .00944 Mdot
.57084 .03002 Mdot
.72219 .09354 Mdot
.10864 .23884 Mdot
.34449 .14577 Mdot
.38247 .02347 Mdot
.25974 .54219 Mdot
.89873 .39492 Mdot
.67958 .48259 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51823 .00773 Mdot
.55802 .02459 Mdot
.68291 .07719 Mdot
.02565 .21182 Mdot
.33008 .18815 Mdot
.42536 .05889 Mdot
.41274 .61023 Mdot
.27569 .53333 Mdot
.903 .3877 Mdot
.49913 .61767 Mdot
.49723 .61686 Mdot
.49118 .61429 Mdot
.4719 .60612 Mdot
.41069 .5802 Mdot
.22244 .50169 Mdot
.79902 .35635 Mdot
.60311 .49695 Mdot
.55125 .58599 Mdot
.57496 .01465 Mdot
.70699 .0816 Mdot
.4981 .61723 Mdot
.49393 .61546 Mdot
.48067 .60984 Mdot
.43848 .59196 Mdot
.30629 .53634 Mdot
.95015 .39793 Mdot
.66757 .44339 Mdot
.5924 .57158 Mdot
.64818 .03447 Mdot
.89549 .15284 Mdot
.28853 .24292 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.5076 .00322 Mdot
.52422 .01027 Mdot
.57703 .03264 Mdot
.74092 .10129 Mdot
.14316 .2486 Mdot
.35847 .13307 Mdot
.38837 .01848 Mdot
.26422 .54131 Mdot
.90229 .39435 Mdot
.67789 .47935 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50808 .00343 Mdot
.52573 .01091 Mdot
.58181 .03466 Mdot
.75528 .10721 Mdot
.16735 .25467 Mdot
.37216 .12658 Mdot
.40517 .0204 Mdot
.30422 .55564 Mdot
.97825 .41657 Mdot
.49849 .61739 Mdot
.49517 .61599 Mdot
.48462 .61151 Mdot
.45105 .59728 Mdot
.34519 .55261 Mdot
.04205 .43068 Mdot
.67656 .39215 Mdot
.52484 .52427 Mdot
.41024 .5472 Mdot
.16802 .46833 Mdot
.71804 .33993 Mdot
.49863 .61745 Mdot
.49564 .61618 Mdot
.4861 .61214 Mdot
.45575 .59928 Mdot
.35988 .55878 Mdot
.07995 .44503 Mdot
.68507 .37399 Mdot
.50934 .50942 Mdot
.34761 .51808 Mdot
.99065 .39742 Mdot
.64771 .40608 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .0027 Mdot
.52032 .00862 Mdot
.56466 .0274 Mdot
.70335 .08571 Mdot
.07058 .22696 Mdot
.33538 .16365 Mdot
.39498 .03684 Mdot
.30824 .56443 Mdot
.99858 .42665 Mdot
.69105 .42797 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .0012 Mdot
.50904 .00383 Mdot
.52879 .01221 Mdot
.59149 .03875 Mdot
.78399 .11897 Mdot
.20979 .26316 Mdot
.40445 .1203 Mdot
.46422 .03694 Mdot
.47079 .00406 Mdot
.43378 .59516 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50375 .00159 Mdot
.51194 .00507 Mdot
.53804 .01613 Mdot
.62065 .05106 Mdot
.8674 .1525 Mdot
.29082 .26169 Mdot
.48332 .11897 Mdot
.65086 .10354 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50611 .00259 Mdot
.51948 .00826 Mdot
.56198 .02627 Mdot
.69512 .08229 Mdot
.05294 .22114 Mdot
.33281 .17297 Mdot
.40553 .04495 Mdot
.34473 .58046 Mdot
.08624 .45828 Mdot
.70463 .38219 Mdot
.49825 .61729 Mdot
.49442 .61567 Mdot
.48224 .6105 Mdot
.44346 .59407 Mdot
.32165 .54275 Mdot
.98489 .40991 Mdot
.67076 .42389 Mdot
.56639 .55353 Mdot
.55873 .6133 Mdot
.63717 .04848 Mdot
.89682 .16047 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47555 .60766 Mdot
.42223 .58508 Mdot
.25685 .51582 Mdot
.85296 .36841 Mdot
.63956 .48615 Mdot
.6097 .59958 Mdot
.73165 .07537 Mdot
.09075 .22194 Mdot
.32098 .14229 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.50461 .00196 Mdot
.5147 .00623 Mdot
.5468 .01984 Mdot
.64811 .06261 Mdot
.94087 .18094 Mdot
.3203 .2345 Mdot
.48391 .10112 Mdot
.62343 .08623 Mdot
.93008 .18952 Mdot
.33827 .25228 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52516 .01067 Mdot
.58 .0339 Mdot
.74987 .10498 Mdot
.15846 .25252 Mdot
.36673 .12872 Mdot
.39766 .01911 Mdot
.28543 .54867 Mdot
.94037 .40477 Mdot
.68267 .45877 Mdot
.49857 .61743 Mdot
.49543 .6161 Mdot
.48544 .61186 Mdot
.45363 .59838 Mdot
.35325 .55599 Mdot
.06263 .43842 Mdot
.68047 .38185 Mdot
.51463 .51554 Mdot
.37069 .52908 Mdot
.05345 .42196 Mdot
.65753 .37334 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50282 .0012 Mdot
.50898 .00381 Mdot
.52862 .01213 Mdot
.59094 .03852 Mdot
.78238 .11832 Mdot
.20763 .26282 Mdot
.40255 .12047 Mdot
.46027 .03567 Mdot
.45901 .61725 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50588 .00249 Mdot
.51872 .00794 Mdot
.55957 .02525 Mdot
.68771 .0792 Mdot
.03654 .21559 Mdot
.33104 .18201 Mdot
.41708 .05318 Mdot
.3843 .59777 Mdot
.19285 .49971 Mdot
.49892 .61758 Mdot
.49656 .61658 Mdot
.48905 .61339 Mdot
.46513 .60325 Mdot
.38933 .57118 Mdot
.16058 .47666 Mdot
.72979 .3518 Mdot
.53582 .49815 Mdot
.39513 .53108 Mdot
.10827 .44074 Mdot
.67124 .34794 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00327 Mdot
.52458 .01042 Mdot
.57818 .03312 Mdot
.74438 .10272 Mdot
.14916 .25017 Mdot
.36155 .13126 Mdot
.39148 .0185 Mdot
.27095 .54354 Mdot
.91376 .39728 Mdot
.67969 .47337 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51186 .00503 Mdot
.53777 .01601 Mdot
.6198 .0507 Mdot
.86504 .15157 Mdot
.28932 .26222 Mdot
.48211 .11915 Mdot
.64811 .1026 Mdot
.00557 .22092 Mdot
.35468 .21576 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52126 .00902 Mdot
.56764 .02867 Mdot
.71246 .0895 Mdot
.08941 .23296 Mdot
.33918 .15437 Mdot
.38674 .02939 Mdot
.27838 .55106 Mdot
.93507 .40586 Mdot
.68648 .4644 Mdot
.50077 .00033 Mdot
.50244 .00104 Mdot
.50779 .0033 Mdot
.52481 .01052 Mdot
.57888 .03342 Mdot
.7465 .10359 Mdot
.1528 .2511 Mdot
.36352 .13023 Mdot
.3937 .01865 Mdot
.27601 .5453 Mdot
.92278 .39972 Mdot
.68089 .46854 Mdot
.4976 .61702 Mdot
.49236 .61479 Mdot
.47565 .60771 Mdot
.42257 .58523 Mdot
.25786 .51624 Mdot
.85472 .36888 Mdot
.64047 .48562 Mdot
.61061 .59958 Mdot
.73363 .07603 Mdot
.09411 .22279 Mdot
.32152 .14054 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.5203 .00861 Mdot
.56459 .02737 Mdot
.70312 .08562 Mdot
.0701 .22681 Mdot
.3353 .1639 Mdot
.39524 .03705 Mdot
.30915 .56482 Mdot
.00061 .42735 Mdot
.69116 .42678 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50342 .00145 Mdot
.51088 .00462 Mdot
.53466 .0147 Mdot
.61002 .04658 Mdot
.83759 .14064 Mdot
.26864 .2664 Mdot
.46259 .11987 Mdot
.60093 .0855 Mdot
.88074 .17293 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50548 .00233 Mdot
.51747 .00741 Mdot
.55562 .02358 Mdot
.67551 .0741 Mdot
.00845 .20577 Mdot
.32872 .19794 Mdot
.43888 .06808 Mdot
.45958 .0128 Mdot
.42031 .59376 Mdot
.26643 .52293 Mdot
.49784 .61712 Mdot
.49312 .61512 Mdot
.47809 .60875 Mdot
.43031 .5885 Mdot
.2813 .52594 Mdot
.89817 .38124 Mdot
.65757 .46934 Mdot
.61656 .59269 Mdot
.73518 .07331 Mdot
.09149 .22021 Mdot
.318 .13999 Mdot
.49858 .61743 Mdot
.49547 .61611 Mdot
.48555 .61191 Mdot
.454 .59853 Mdot
.35441 .55648 Mdot
.06564 .43956 Mdot
.68118 .38043 Mdot
.51348 .51439 Mdot
.36597 .52687 Mdot
.04034 .41679 Mdot
.65485 .37979 Mdot
.49922 .6177 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.47491 .60739 Mdot
.42021 .58423 Mdot
.25078 .51332 Mdot
.84263 .36578 Mdot
.6339 .48903 Mdot
.60315 .59903 Mdot
.71652 .07007 Mdot
.06336 .21436 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.5047 .00199 Mdot
.51498 .00635 Mdot
.5477 .02022 Mdot
.6509 .06378 Mdot
.94802 .18363 Mdot
.32174 .23097 Mdot
.48056 .09816 Mdot
.61029 .08018 Mdot
.89252 .17443 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48444 .61144 Mdot
.45046 .59703 Mdot
.34335 .55184 Mdot
.03742 .42896 Mdot
.67587 .39458 Mdot
.52763 .52641 Mdot
.42061 .55189 Mdot
.19939 .48131 Mdot
.75141 .34116 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51014 .0043 Mdot
.53231 .0137 Mdot
.60261 .04345 Mdot
.81638 .13212 Mdot
.24842 .26701 Mdot
.44174 .11948 Mdot
.54961 .06667 Mdot
.73069 .11191 Mdot
.50054 .00023 Mdot
.50174 .00074 Mdot
.50553 .00234 Mdot
.51761 .00747 Mdot
.55607 .02377 Mdot
.67689 .07467 Mdot
.0117 .20692 Mdot
.32898 .19608 Mdot
.43631 .06634 Mdot
.45063 .00885 Mdot
.39209 .58185 Mdot
.18379 .4893 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51189 .00504 Mdot
.53788 .01606 Mdot
.62014 .05084 Mdot
.86598 .15194 Mdot
.28992 .26201 Mdot
.4826 .11908 Mdot
.64923 .10298 Mdot
.00831 .22193 Mdot
.35493 .21422 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47554 .60766 Mdot
.4222 .58507 Mdot
.25677 .51579 Mdot
.85282 .36838 Mdot
.63949 .48619 Mdot
.60962 .59957 Mdot
.73149 .07532 Mdot
.09047 .22186 Mdot
.32094 .14244 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00132 Mdot
.50988 .00419 Mdot
.53147 .01334 Mdot
.59997 .04233 Mdot
.80875 .12903 Mdot
.24018 .26664 Mdot
.43333 .11938 Mdot
.52938 .05936 Mdot
.49766 .61704 Mdot
.49254 .61487 Mdot
.47625 .60796 Mdot
.42446 .58603 Mdot
.26357 .5186 Mdot
.86482 .37159 Mdot
.64532 .48238 Mdot
.61475 .59914 Mdot
.74178 .07851 Mdot
.10722 .22586 Mdot
.32372 .1338 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00178 Mdot
.5134 .00568 Mdot
.54266 .01809 Mdot
.63516 .05716 Mdot
.90688 .16793 Mdot
.31045 .24942 Mdot
.4923 .11239 Mdot
.66261 .10526 Mdot
.03656 .23111 Mdot
.35615 .19752 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50526 .00223 Mdot
.51676 .00711 Mdot
.55337 .02262 Mdot
.66853 .07118 Mdot
.99183 .19981 Mdot
.32738 .20738 Mdot
.45186 .07693 Mdot
.50522 .03298 Mdot
.5664 .03781 Mdot
.72431 .0976 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50779 .0033 Mdot
.52482 .01052 Mdot
.57892 .03344 Mdot
.74662 .10364 Mdot
.15299 .25115 Mdot
.36362 .13018 Mdot
.39382 .01866 Mdot
.2763 .5454 Mdot
.9233 .39987 Mdot
.68095 .46825 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49057 .61403 Mdot
.46996 .6053 Mdot
.40455 .57761 Mdot
.20439 .49433 Mdot
.77523 .3528 Mdot
.58182 .4985 Mdot
.50579 .57105 Mdot
.43846 .57642 Mdot
.49977 .61794 Mdot
.49927 .61772 Mdot
.49768 .61705 Mdot
.4926 .61489 Mdot
.47642 .60803 Mdot
.42499 .58625 Mdot
.26518 .51926 Mdot
.86771 .37239 Mdot
.64661 .48138 Mdot
.61561 .59887 Mdot
.74316 .07883 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51885 .00799 Mdot
.55998 .02542 Mdot
.68897 .07972 Mdot
.03934 .21655 Mdot
.33131 .18044 Mdot
.41502 .05174 Mdot
.37722 .59467 Mdot
.17298 .49181 Mdot
.75743 .36121 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.48629 .61222 Mdot
.45636 .59953 Mdot
.36178 .55958 Mdot
.08496 .44695 Mdot
.68667 .37188 Mdot
.50846 .50789 Mdot
.34294 .51573 Mdot
.97824 .39264 Mdot
.64608 .41275 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50779 .0033 Mdot
.52482 .01052 Mdot
.57893 .03344 Mdot
.74663 .10365 Mdot
.15301 .25116 Mdot
.36364 .13017 Mdot
.39383 .01866 Mdot
.27634 .54542 Mdot
.49995 .61801 Mdot
.49985 .61797 Mdot
.49953 .61784 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48495 .61165 Mdot
.45209 .59772 Mdot
.34845 .55398 Mdot
.05031 .43377 Mdot
.67796 .38791 Mdot
.52029 .52059 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.50519 .0022 Mdot
.51653 .00701 Mdot
.55262 .02231 Mdot
.66621 .0702 Mdot
.98621 .19777 Mdot
.32687 .21054 Mdot
.4561 .07987 Mdot
.5203 .03968 Mdot
.61488 .05845 Mdot
.86719 .15594 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47663 .60812 Mdot
.42567 .58654 Mdot
.26721 .5201 Mdot
.87141 .37342 Mdot
.64819 .48007 Mdot
.61649 .59845 Mdot
.74435 .07902 Mdot
.11078 .22647 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.52569 .01089 Mdot
.58169 .03461 Mdot
.75493 .10706 Mdot
.16678 .25454 Mdot
.3718 .12671 Mdot
.40464 .0203 Mdot
.30285 .55513 Mdot
.97538 .41564 Mdot
.68469 .43838 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50274 .00116 Mdot
.50873 .0037 Mdot
.52781 .01179 Mdot
.58838 .03744 Mdot
.77481 .11522 Mdot
.19707 .26098 Mdot
.39369 .12151 Mdot
.44243 .03012 Mdot
.40669 .59595 Mdot
.23887 .51431 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51177 .00499 Mdot
.53748 .01589 Mdot
.6189 .05032 Mdot
.86255 .15058 Mdot
.28768 .26274 Mdot
.48073 .11932 Mdot
.64496 .1015 Mdot
.99779 .21806 Mdot
.35393 .22011 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48044 .60974 Mdot
.43777 .59166 Mdot
.3041 .53542 Mdot
.94536 .39632 Mdot
.66698 .44599 Mdot
.59558 .57391 Mdot
.6591 .03926 Mdot
.92346 .16338 Mdot
.29826 .23163 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50691 .00293 Mdot
.522 .00933 Mdot
.56999 .02966 Mdot
.71962 .09248 Mdot
.10365 .23734 Mdot
.34296 .1479 Mdot
.38312 .02482 Mdot
.2633 .54398 Mdot
.90557 .39695 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47736 .60843 Mdot
.42798 .58752 Mdot
.27423 .52301 Mdot
.88451 .37717 Mdot
.65322 .47508 Mdot
.61785 .59618 Mdot
.74355 .07769 Mdot
.10779 .22511 Mdot
.32242 .13265 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52144 .00909 Mdot
.56822 .02891 Mdot
.71424 .09024 Mdot
.09298 .23408 Mdot
.34005 .1527 Mdot
.3856 .02815 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51251 .00531 Mdot
.53984 .01689 Mdot
.62632 .05345 Mdot
.88301 .15864 Mdot
.2998 .25759 Mdot
.48945 .11721 Mdot
.66328 .10743 Mdot
.04127 .23361 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00212 Mdot
.51596 .00677 Mdot
.55081 .02154 Mdot
.66057 .06784 Mdot
.97237 .1927 Mdot
.3254 .21819 Mdot
.466 .08689 Mdot
.55598 .05561 Mdot
.7282 .10644 Mdot
.13692 .2526 Mdot
.49923 .61771 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.42031 .58427 Mdot
.25109 .51345 Mdot
.84313 .3659 Mdot
.63419 .4889 Mdot
.60352 .59908 Mdot
.71741 .07039 Mdot
.06505 .21485 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49846 .61738 Mdot
.4951 .61595 Mdot
.48438 .61141 Mdot
.45026 .59695 Mdot
.34276 .55159 Mdot
.03593 .4284 Mdot
.67566 .39538 Mdot
.52856 .52712 Mdot
.42407 .55346 Mdot
.49766 .61704 Mdot
.49256 .61488 Mdot
.47629 .60798 Mdot
.42458 .58608 Mdot
.26394 .51875 Mdot
.86549 .37177 Mdot
.64562 .48215 Mdot
.61496 .59909 Mdot
.74214 .0786 Mdot
.10775 .22596 Mdot
.32381 .13353 Mdot
.5004 .00017 Mdot
.50129 .00054 Mdot
.50409 .00174 Mdot
.51304 .00553 Mdot
.54154 .01761 Mdot
.63164 .05568 Mdot
.89743 .16427 Mdot
.30665 .25291 Mdot
.4921 .11461 Mdot
.6657 .10729 Mdot
.04532 .23462 Mdot
.35788 .19317 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51722 .0073 Mdot
.55481 .02323 Mdot
.673 .07305 Mdot
.00252 .20366 Mdot
.32826 .20132 Mdot
.44356 .07126 Mdot
.47595 .02002 Mdot
.4724 .61584 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50836 .00355 Mdot
.52664 .0113 Mdot
.5847 .03588 Mdot
.7639 .11075 Mdot
.18092 .25773 Mdot
.38135 .12387 Mdot
.41982 .02378 Mdot
.34306 .57059 Mdot
.06723 .44756 Mdot
.49785 .61712 Mdot
.49314 .61512 Mdot
.47813 .60876 Mdot
.43044 .58855 Mdot
.28168 .5261 Mdot
.89891 .38147 Mdot
.65778 .46901 Mdot
.61642 .59247 Mdot
.73452 .07299 Mdot
.09023 .21984 Mdot
.31773 .1406 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48934 .61351 Mdot
.46604 .60363 Mdot
.39217 .57238 Mdot
.16866 .4799 Mdot
.73692 .3512 Mdot
.54311 .49825 Mdot
.41318 .53773 Mdot
.15937 .46117 Mdot
.70451 .33691 Mdot
.49813 .61724 Mdot
.49406 .61551 Mdot
.48106 .61 Mdot
.43972 .59249 Mdot
.31012 .53793 Mdot
.95862 .40079 Mdot
.66849 .43873 Mdot
.58647 .56734 Mdot
.62785 .02558 Mdot
.84105 .13176 Mdot
.25497 .25581 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50508 .00215 Mdot
.51618 .00686 Mdot
.55152 .02184 Mdot
.66281 .06878 Mdot
.97788 .19473 Mdot
.32603 .21517 Mdot
.46216 .08414 Mdot
.54208 .04939 Mdot
.68439 .08795 Mdot
.04543 .22313 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00246 Mdot
.5185 .00785 Mdot
.55889 .02496 Mdot
.68562 .07832 Mdot
.03182 .21396 Mdot
.3306 .18466 Mdot
.42063 .05564 Mdot
.39646 .6031 Mdot
.22771 .51374 Mdot
.82256 .36764 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .0018 Mdot
.51356 .00575 Mdot
.54318 .0183 Mdot
.63677 .05784 Mdot
.91117 .16959 Mdot
.31201 .24773 Mdot
.49201 .11124 Mdot
.66002 .10384 Mdot
.02961 .22842 Mdot
.35504 .20113 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.5261 .01107 Mdot
.58298 .03515 Mdot
.75877 .10864 Mdot
.17292 .25596 Mdot
.3758 .12538 Mdot
.41072 .02158 Mdot
.31863 .56112 Mdot
.00967 .42708 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52632 .01116 Mdot
.58367 .03545 Mdot
.76083 .10949 Mdot
.17617 .25669 Mdot
.37801 .12474 Mdot
.41426 .0224 Mdot
.32802 .56474 Mdot
.03116 .43457 Mdot
.68786 .40586 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49917 .61768 Mdot
.49737 .61692 Mdot
.49161 .61447 Mdot
.47326 .6067 Mdot
.41499 .58202 Mdot
.23518 .5069 Mdot
.81767 .36 Mdot
.61764 .49441 Mdot
.57843 .5938 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51453 .00616 Mdot
.54626 .01961 Mdot
.64642 .0619 Mdot
.9365 .17928 Mdot
.31933 .2366 Mdot
.48572 .10283 Mdot
.63071 .08961 Mdot
.95045 .19761 Mdot
.34332 .24281 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52613 .01108 Mdot
.58307 .03519 Mdot
.75904 .10875 Mdot
.17335 .25606 Mdot
.37609 .1253 Mdot
.41117 .02168 Mdot
.31982 .56158 Mdot
.01234 .428 Mdot
.68637 .41657 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48789 .6129 Mdot
.46142 .60168 Mdot
.37764 .56626 Mdot
.12789 .46368 Mdot
.70629 .35747 Mdot
.51447 .49949 Mdot
.34433 .51288 Mdot
.97618 .3905 Mdot
.64363 .4125 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49206 .61467 Mdot
.47471 .60731 Mdot
.41959 .58397 Mdot
.24893 .51256 Mdot
.83955 .36502 Mdot
.63209 .48982 Mdot
.60079 .59869 Mdot
.71078 .06798 Mdot
.0523 .21107 Mdot
.49812 .61724 Mdot
.49402 .6155 Mdot
.48096 .60996 Mdot
.43939 .59235 Mdot
.3091 .53751 Mdot
.95635 .40002 Mdot
.66826 .43998 Mdot
.58809 .56849 Mdot
.63341 .02801 Mdot
.85623 .13771 Mdot
.26655 .25359 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50694 .00294 Mdot
.5221 .00937 Mdot
.57032 .0298 Mdot
.72061 .09289 Mdot
.10558 .23792 Mdot
.34354 .14707 Mdot
.38283 .02428 Mdot
.26181 .54324 Mdot
.90272 .3961 Mdot
.68063 .48077 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51389 .00589 Mdot
.54423 .01875 Mdot
.64006 .05923 Mdot
.91991 .17295 Mdot
.31488 .24411 Mdot
.49069 .10865 Mdot
.65254 .10003 Mdot
.00974 .22076 Mdot
.35234 .21174 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.5148 .00628 Mdot
.54713 .01998 Mdot
.64913 .06304 Mdot
.94351 .18193 Mdot
.32085 .23321 Mdot
.48273 .10005 Mdot
.61875 .08407 Mdot
.91683 .18422 Mdot
.33406 .25786 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47345 .60677 Mdot
.41558 .58227 Mdot
.23695 .50763 Mdot
.82038 .36058 Mdot
.61959 .49393 Mdot
.58176 .59465 Mdot
.66124 .04912 Mdot
.94327 .17431 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.5033 .0014 Mdot
.51053 .00446 Mdot
.53353 .01422 Mdot
.60646 .04507 Mdot
.82744 .13657 Mdot
.25944 .26699 Mdot
.45313 .11971 Mdot
.57754 .07689 Mdot
.81371 .14596 Mdot
.49889 .61756 Mdot
.49647 .61654 Mdot
.48876 .61327 Mdot
.46421 .60286 Mdot
.38641 .56995 Mdot
.15233 .47336 Mdot
.72307 .35274 Mdot
.52915 .49818 Mdot
.3787 .52505 Mdot
.06341 .42317 Mdot
.6555 .36593 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51185 .00503 Mdot
.53774 .016 Mdot
.61971 .05066 Mdot
.86479 .15147 Mdot
.28915 .26227 Mdot
.48197 .11917 Mdot
.6478 .10249 Mdot
.00481 .22064 Mdot
.35461 .21619 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55364 .02274 Mdot
.66936 .07152 Mdot
.99383 .20053 Mdot
.32755 .20625 Mdot
.45032 .07588 Mdot
.49979 .03057 Mdot
.54893 .03037 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52456 .01042 Mdot
.57812 .0331 Mdot
.7442 .10264 Mdot
.14886 .25009 Mdot
.36139 .13135 Mdot
.39131 .01849 Mdot
.27056 .54341 Mdot
.91308 .3971 Mdot
.67959 .47373 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50707 .003 Mdot
.52251 .00954 Mdot
.5716 .03034 Mdot
.72452 .09451 Mdot
.11311 .24016 Mdot
.34596 .14391 Mdot
.38218 .02238 Mdot
.25738 .5409 Mdot
.8941 .39352 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52246 .00952 Mdot
.57145 .03028 Mdot
.72405 .09431 Mdot
.11222 .2399 Mdot
.34566 .14428 Mdot
.38222 .02259 Mdot
.25779 .54113 Mdot
.89491 .39376 Mdot
.49894 .61759 Mdot
.49664 .61661 Mdot
.48928 .61349 Mdot
.46587 .60356 Mdot
.39165 .57216 Mdot
.16717 .4793 Mdot
.73556 .35129 Mdot
.54171 .49823 Mdot
.40971 .53645 Mdot
.14942 .45717 Mdot
.69651 .33812 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51684 .00714 Mdot
.55361 .02272 Mdot
.66927 .07148 Mdot
.99361 .20045 Mdot
.32753 .20638 Mdot
.45049 .076 Mdot
.50039 .03084 Mdot
.55087 .0312 Mdot
.67638 .07756 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50551 .00234 Mdot
.51755 .00744 Mdot
.55586 .02368 Mdot
.67624 .0744 Mdot
.01017 .20638 Mdot
.32886 .19696 Mdot
.43752 .06716 Mdot
.45485 .01071 Mdot
.40536 .58745 Mdot
.22214 .50479 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50478 .00202 Mdot
.51521 .00645 Mdot
.54844 .02053 Mdot
.6532 .06474 Mdot
.95387 .18583 Mdot
.32278 .228 Mdot
.47747 .09561 Mdot
.5985 .0748 Mdot
.85801 .16039 Mdot
.30336 .27524 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50762 .00323 Mdot
.52429 .0103 Mdot
.57725 .03273 Mdot
.74157 .10156 Mdot
.1443 .2489 Mdot
.35904 .13271 Mdot
.38891 .01846 Mdot
.26535 .54167 Mdot
.49822 .61728 Mdot
.49434 .61564 Mdot
.48198 .61039 Mdot
.44264 .59372 Mdot
.31912 .54169 Mdot
.97904 .40785 Mdot
.6703 .42723 Mdot
.57099 .55666 Mdot
.57467 .00227 Mdot
.68629 .06899 Mdot
.01777 .20487 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50562 .00238 Mdot
.51789 .00759 Mdot
.55695 .02414 Mdot
.67963 .07582 Mdot
.01808 .20917 Mdot
.32947 .19245 Mdot
.43127 .06292 Mdot
.43317 .00117 Mdot
.33773 .55905 Mdot
.03892 .43336 Mdot
.49895 .61759 Mdot
.49666 .61662 Mdot
.48937 .61353 Mdot
.46615 .60368 Mdot
.39253 .57254 Mdot
.16968 .48031 Mdot
.73786 .35115 Mdot
.54408 .49827 Mdot
.41558 .53861 Mdot
.1663 .46397 Mdot
.71055 .33636 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51453 .00616 Mdot
.54627 .01961 Mdot
.64644 .06191 Mdot
.93655 .1793 Mdot
.31934 .23658 Mdot
.48569 .10281 Mdot
.63062 .08957 Mdot
.95021 .19752 Mdot
.34327 .24292 Mdot
.49828 .6173 Mdot
.49451 .61571 Mdot
.48252 .61062 Mdot
.44435 .59444 Mdot
.32438 .54389 Mdot
.99129 .41217 Mdot
.67126 .42024 Mdot
.56132 .55009 Mdot
.54112 .60555 Mdot
.5819 .02521 Mdot
.74018 .09782 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50334 .00142 Mdot
.51064 .00451 Mdot
.5339 .01437 Mdot
.60761 .04556 Mdot
.83073 .13789 Mdot
.26252 .26686 Mdot
.45631 .11977 Mdot
.58539 .07978 Mdot
.83651 .1552 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52397 .01017 Mdot
.57625 .03231 Mdot
.73857 .10032 Mdot
.13901 .24749 Mdot
.35645 .13439 Mdot
.3866 .01863 Mdot
.26069 .54022 Mdot
.89659 .393 Mdot
.67691 .48227 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50691 .00293 Mdot
.52201 .00933 Mdot
.57001 .02967 Mdot
.71969 .0925 Mdot
.10377 .23738 Mdot
.343 .14785 Mdot
.3831 .02478 Mdot
.2632 .54393 Mdot
.90538 .39689 Mdot
.49873 .61749 Mdot
.49594 .61631 Mdot
.48708 .61255 Mdot
.45885 .60059 Mdot
.36957 .56286 Mdot
.10583 .45503 Mdot
.69479 .36399 Mdot
.50825 .50275 Mdot
.33409 .51039 Mdot
.95374 .38297 Mdot
.64181 .42525 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00215 Mdot
.51612 .00683 Mdot
.55131 .02175 Mdot
.66214 .0685 Mdot
.97625 .19413 Mdot
.32585 .21606 Mdot
.46332 .08496 Mdot
.54625 .05125 Mdot
.69757 .09352 Mdot
.07479 .23314 Mdot
.49828 .6173 Mdot
.49451 .61571 Mdot
.48251 .61062 Mdot
.44432 .59443 Mdot
.3243 .54386 Mdot
.99109 .4121 Mdot
.67124 .42036 Mdot
.56148 .5502 Mdot
.54167 .60579 Mdot
.58367 .02595 Mdot
.74545 .09999 Mdot
.49887 .61756 Mdot
.49641 .61651 Mdot
.48858 .61319 Mdot
.46361 .60261 Mdot
.38455 .56917 Mdot
.1471 .47128 Mdot
.7191 .35352 Mdot
.52535 .49829 Mdot
.36946 .52169 Mdot
.03899 .41379 Mdot
.65062 .37801 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50328 .00139 Mdot
.51044 .00443 Mdot
.53326 .0141 Mdot
.60559 .04471 Mdot
.82495 .13557 Mdot
.25705 .26705 Mdot
.45066 .11966 Mdot
.57143 .07464 Mdot
.7958 .13867 Mdot
.24908 .28014 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52227 .00944 Mdot
.57084 .03002 Mdot
.7222 .09354 Mdot
.10866 .23884 Mdot
.3445 .14576 Mdot
.38247 .02347 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49147 .61442 Mdot
.47284 .60652 Mdot
.41367 .58146 Mdot
.23125 .50529 Mdot
.81175 .35877 Mdot
.61325 .49535 Mdot
.57063 .5917 Mdot
.63051 .03701 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00133 Mdot
.50996 .00422 Mdot
.53171 .01344 Mdot
.60071 .04265 Mdot
.81091 .12991 Mdot
.24257 .26678 Mdot
.43575 .11939 Mdot
.53516 .06144 Mdot
.68687 .09377 Mdot
.05879 .22986 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51254 .00532 Mdot
.53994 .01693 Mdot
.62662 .05357 Mdot
.88381 .15895 Mdot
.30021 .25735 Mdot
.48967 .11709 Mdot
.66364 .10752 Mdot
.04206 .23387 Mdot
.35812 .19533 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52029 .0086 Mdot
.56456 .02736 Mdot
.70304 .08559 Mdot
.06994 .22676 Mdot
.33527 .16398 Mdot
.39532 .03711 Mdot
.30943 .56495 Mdot
.00126 .42757 Mdot
.6912 .4264 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00225 Mdot
.51694 .00718 Mdot
.55393 .02286 Mdot
.67027 .0719 Mdot
.99601 .20132 Mdot
.32773 .20502 Mdot
.44864 .07472 Mdot
.49383 .02793 Mdot
.52976 .02221 Mdot
.61007 .04964 Mdot
.49941 .61778 Mdot
.49812 .61724 Mdot
.494 .61549 Mdot
.48089 .60993 Mdot
.4392 .59226 Mdot
.30849 .53726 Mdot
.955 .39956 Mdot
.66811 .44073 Mdot
.58904 .56917 Mdot
.63668 .02944 Mdot
.86505 .14114 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52237 .00948 Mdot
.57115 .03015 Mdot
.72314 .09394 Mdot
.11048 .23939 Mdot
.34509 .145 Mdot
.38232 .02301 Mdot
.25867 .54162 Mdot
.89665 .39429 Mdot
.67899 .48351 Mdot
.49764 .61703 Mdot
.49249 .61485 Mdot
.47608 .60789 Mdot
.42392 .5858 Mdot
.26193 .51792 Mdot
.86188 .37079 Mdot
.64396 .48336 Mdot
.61373 .59935 Mdot
.73995 .078 Mdot
.10442 .22526 Mdot
.32326 .13525 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47506 .60746 Mdot
.42071 .58444 Mdot
.25227 .51393 Mdot
.84512 .3664 Mdot
.63532 .48837 Mdot
.60492 .59924 Mdot
.72074 .07158 Mdot
.07127 .21664 Mdot
.31843 .15275 Mdot
.50057 .00024 Mdot
.5018 .00076 Mdot
.50574 .00243 Mdot
.51828 .00775 Mdot
.55817 .02466 Mdot
.6834 .07739 Mdot
.02676 .21221 Mdot
.33017 .18752 Mdot
.4245 .0583 Mdot
.40978 .60894 Mdot
.26685 .5297 Mdot
.88653 .38298 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51372 .00582 Mdot
.54369 .01852 Mdot
.63839 .05852 Mdot
.91547 .17125 Mdot
.31347 .24598 Mdot
.49148 .11001 Mdot
.6567 .10211 Mdot
.0208 .22502 Mdot
.35379 .2058 Mdot
.49851 .6174 Mdot
.49524 .61602 Mdot
.48485 .61161 Mdot
.45176 .59758 Mdot
.34742 .55355 Mdot
.04769 .43279 Mdot
.67749 .38924 Mdot
.52167 .52173 Mdot
.39826 .54176 Mdot
.13243 .45374 Mdot
.6901 .34465 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00164 Mdot
.51236 .00524 Mdot
.53935 .01668 Mdot
.62478 .05279 Mdot
.87877 .15698 Mdot
.29753 .25881 Mdot
.48812 .11779 Mdot
.66091 .10679 Mdot
.03599 .23181 Mdot
.35755 .19873 Mdot
.49774 .61708 Mdot
.49281 .61498 Mdot
.47708 .60832 Mdot
.4271 .58714 Mdot
.27154 .5219 Mdot
.87944 .3757 Mdot
.65137 .47708 Mdot
.61765 .59719 Mdot
.74475 .07855 Mdot
.11045 .22602 Mdot
.32346 .13165 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50454 .00192 Mdot
.51446 .00613 Mdot
.54605 .01952 Mdot
.64574 .06161 Mdot
.93474 .17862 Mdot
.31891 .23743 Mdot
.48638 .1035 Mdot
.63345 .09089 Mdot
.95806 .20062 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52605 .01104 Mdot
.58282 .03509 Mdot
.75828 .10844 Mdot
.17215 .25579 Mdot
.37529 .12554 Mdot
.40992 .0214 Mdot
.31652 .56031 Mdot
.00494 .42547 Mdot
.50047 .0002 Mdot
.50148 .00063 Mdot
.50472 .002 Mdot
.51505 .00638 Mdot
.54791 .02031 Mdot
.65155 .06405 Mdot
.94969 .18426 Mdot
.32204 .23013 Mdot
.47971 .09744 Mdot
.60703 .07869 Mdot
.88306 .1706 Mdot
.31914 .26951 Mdot
.49969 .6179 Mdot
.49901 .61761 Mdot
.49684 .61669 Mdot
.48993 .61376 Mdot
.46792 .60443 Mdot
.39811 .57489 Mdot
.18568 .48675 Mdot
.75376 .35109 Mdot
.5605 .49859 Mdot
.45582 .55334 Mdot
.28571 .5129 Mdot
.49909 .61765 Mdot
.49711 .61681 Mdot
.49079 .61413 Mdot
.47067 .6056 Mdot
.40681 .57857 Mdot
.21103 .49703 Mdot
.78363 .35389 Mdot
.58966 .49815 Mdot
.52316 .57694 Mdot
.49129 .59834 Mdot
.44637 .59027 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50588 .00249 Mdot
.51873 .00794 Mdot
.5596 .02526 Mdot
.68779 .07923 Mdot
.03672 .21565 Mdot
.33105 .18191 Mdot
.41695 .05309 Mdot
.38385 .59758 Mdot
.19159 .49921 Mdot
.77649 .36149 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.51871 .00793 Mdot
.55955 .02524 Mdot
.68765 .07917 Mdot
.03639 .21553 Mdot
.33102 .18209 Mdot
.4172 .05326 Mdot
.38469 .59795 Mdot
.19396 .50016 Mdot
.49819 .61727 Mdot
.49422 .61558 Mdot
.4816 .61023 Mdot
.44142 .59321 Mdot
.31536 .54012 Mdot
.97041 .40484 Mdot
.66959 .43212 Mdot
.57768 .56123 Mdot
.59771 .01238 Mdot
.75528 .09738 Mdot
.15144 .24484 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52237 .00948 Mdot
.57115 .03015 Mdot
.72315 .09394 Mdot
.11049 .23939 Mdot
.34509 .14499 Mdot
.38232 .02301 Mdot
.25867 .54162 Mdot
.89664 .39429 Mdot
.49915 .61767 Mdot
.49729 .61689 Mdot
.49137 .61437 Mdot
.47251 .60638 Mdot
.41262 .58102 Mdot
.22815 .50402 Mdot
.80719 .35787 Mdot
.60972 .49599 Mdot
.56409 .58983 Mdot
.61201 .02962 Mdot
.81442 .12509 Mdot
.49822 .61728 Mdot
.49431 .61562 Mdot
.48188 .61035 Mdot
.44233 .59359 Mdot
.31816 .54129 Mdot
.97681 .40707 Mdot
.67012 .42849 Mdot
.57273 .55784 Mdot
.58067 .00491 Mdot
.7045 .07653 Mdot
.05737 .21809 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.49831 .61732 Mdot
.49461 .61575 Mdot
.48282 .61075 Mdot
.44532 .59486 Mdot
.32741 .54516 Mdot
.99844 .41472 Mdot
.67181 .41617 Mdot
.55569 .54626 Mdot
.52139 .59684 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50664 .00281 Mdot
.52115 .00897 Mdot
.56728 .02851 Mdot
.71135 .08904 Mdot
.08716 .23226 Mdot
.33866 .15544 Mdot
.38753 .0302 Mdot
.28138 .55243 Mdot
.94113 .40775 Mdot
.68718 .46108 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49775 .61708 Mdot
.49282 .61499 Mdot
.47713 .60834 Mdot
.42727 .58721 Mdot
.27205 .52211 Mdot
.8804 .37598 Mdot
.65173 .47671 Mdot
.61771 .59701 Mdot
.74461 .07842 Mdot
.49917 .61768 Mdot
.49737 .61692 Mdot
.49161 .61447 Mdot
.47326 .6067 Mdot
.415 .58203 Mdot
.23522 .50692 Mdot
.81774 .36001 Mdot
.61769 .4944 Mdot
.57852 .59382 Mdot
.6524 .04566 Mdot
.92151 .16632 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47764 .60855 Mdot
.42887 .58789 Mdot
.27691 .52412 Mdot
.88962 .37868 Mdot
.65495 .473 Mdot
.61768 .595 Mdot
.74127 .07638 Mdot
.10324 .22371 Mdot
.32098 .13457 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52544 .01079 Mdot
.5809 .03427 Mdot
.75255 .10609 Mdot
.1629 .25361 Mdot
.36939 .12761 Mdot
.40122 .01967 Mdot
.2942 .55189 Mdot
.9576 .41 Mdot
.68385 .44885 Mdot
.49951 .61783 Mdot
.49843 .61737 Mdot
.495 .61592 Mdot
.48408 .61129 Mdot
.44933 .59656 Mdot
.33985 .55037 Mdot
.02869 .42572 Mdot
.67472 .39927 Mdot
.53328 .53062 Mdot
.44141 .56125 Mdot
.26362 .50815 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48988 .61374 Mdot
.46776 .60436 Mdot
.39761 .57468 Mdot
.18426 .48617 Mdot
.75225 .35104 Mdot
.55895 .49857 Mdot
.45207 .55198 Mdot
.27439 .50822 Mdot
.86076 .3624 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48603 .61211 Mdot
.45551 .59917 Mdot
.35911 .55846 Mdot
.07792 .44425 Mdot
.68446 .37487 Mdot
.50978 .51008 Mdot
.34977 .51914 Mdot
.99642 .39965 Mdot
.64844 .40297 Mdot
.49853 .61741 Mdot
.49531 .61605 Mdot
.48506 .6117 Mdot
.45242 .59787 Mdot
.34948 .55441 Mdot
.05295 .43477 Mdot
.67845 .38658 Mdot
.51896 .51946 Mdot
.38783 .53699 Mdot
.10204 .44141 Mdot
.67346 .35316 Mdot
.49837 .61734 Mdot
.49482 .61584 Mdot
.48349 .61103 Mdot
.44744 .59575 Mdot
.33396 .5479 Mdot
.01421 .42042 Mdot
.67317 .40726 Mdot
.54359 .53794 Mdot
.47856 .57785 Mdot
.38149 .55804 Mdot
.12261 .45804 Mdot
.50013 5e-05 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50419 .00178 Mdot
.51335 .00566 Mdot
.54251 .01802 Mdot
.63467 .05696 Mdot
.90558 .16743 Mdot
.30996 .24992 Mdot
.49234 .11272 Mdot
.66325 .10563 Mdot
.0383 .23179 Mdot
.49825 .61729 Mdot
.49444 .61568 Mdot
.48228 .61052 Mdot
.4436 .59413 Mdot
.32208 .54293 Mdot
.98588 .41026 Mdot
.67084 .42333 Mdot
.5656 .55299 Mdot
.556 .6121 Mdot
.62868 .04492 Mdot
.87402 .15163 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50719 .00305 Mdot
.52289 .00971 Mdot
.57283 .03086 Mdot
.72822 .09604 Mdot
.12012 .24221 Mdot
.34846 .14112 Mdot
.38232 .02093 Mdot
.25531 .53954 Mdot
.8897 .39208 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00267 Mdot
.52009 .00852 Mdot
.56392 .02709 Mdot
.70108 .08477 Mdot
.06578 .2254 Mdot
.3346 .16614 Mdot
.39762 .03895 Mdot
.31745 .56849 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50496 .0021 Mdot
.51581 .0067 Mdot
.55033 .02134 Mdot
.65911 .06723 Mdot
.96873 .19136 Mdot
.32496 .22016 Mdot
.46844 .08868 Mdot
.5649 .05961 Mdot
.75602 .11812 Mdot
.1857 .26556 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.51211 .00514 Mdot
.53856 .01635 Mdot
.6223 .05175 Mdot
.87196 .1543 Mdot
.29362 .2606 Mdot
.48546 .11856 Mdot
.65553 .10511 Mdot
.02349 .22741 Mdot
.35634 .20571 Mdot
.49899 .6176 Mdot
.49677 .61667 Mdot
.48972 .61368 Mdot
.46727 .60416 Mdot
.39607 .57403 Mdot
.17982 .48438 Mdot
.74767 .35095 Mdot
.55423 .49848 Mdot
.44058 .54779 Mdot
.23984 .49397 Mdot
.80086 .34673 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.50992 .00421 Mdot
.5316 .0134 Mdot
.60036 .0425 Mdot
.80988 .12949 Mdot
.24144 .26672 Mdot
.43461 .11938 Mdot
.53242 .06045 Mdot
.67854 .09031 Mdot
.03973 .22323 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48327 .61094 Mdot
.44674 .59546 Mdot
.33181 .547 Mdot
.009 .41853 Mdot
.6727 .41019 Mdot
.54751 .54067 Mdot
.49254 .58406 Mdot
.42638 .57715 Mdot
.25369 .5113 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51225 .0052 Mdot
.53903 .01655 Mdot
.62375 .05236 Mdot
.87596 .15587 Mdot
.29596 .25957 Mdot
.4871 .11813 Mdot
.65892 .10619 Mdot
.03145 .23023 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50937 .00397 Mdot
.52985 .01266 Mdot
.59485 .04017 Mdot
.79385 .12299 Mdot
.22258 .26497 Mdot
.41611 .11961 Mdot
.48955 .04539 Mdot
.54733 .03571 Mdot
.67505 .07894 Mdot
.4992 .61769 Mdot
.49745 .61695 Mdot
.49188 .61459 Mdot
.47414 .60707 Mdot
.41777 .5832 Mdot
.24347 .51031 Mdot
.83065 .36289 Mdot
.62655 .4919 Mdot
.59291 .59724 Mdot
.69084 .06053 Mdot
.0112 .19799 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47472 .60732 Mdot
.41963 .58398 Mdot
.24904 .5126 Mdot
.83972 .36506 Mdot
.63219 .48978 Mdot
.60093 .59871 Mdot
.71112 .0681 Mdot
.05296 .21127 Mdot
.31681 .16307 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47887 .60908 Mdot
.43278 .58955 Mdot
.28882 .52906 Mdot
.9132 .38589 Mdot
.66142 .46243 Mdot
.61234 .5877 Mdot
.71812 .06538 Mdot
.05787 .20997 Mdot
.31271 .1575 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50467 .00198 Mdot
.51489 .00631 Mdot
.54741 .0201 Mdot
.65001 .06341 Mdot
.94576 .18278 Mdot
.3213 .2321 Mdot
.48167 .09911 Mdot
.61461 .08216 Mdot
.90498 .17946 Mdot
.32956 .26241 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.5208 .00882 Mdot
.56618 .02805 Mdot
.70801 .08765 Mdot
.0803 .23009 Mdot
.33719 .15877 Mdot
.39028 .03281 Mdot
.29153 .557 Mdot
.96212 .41445 Mdot
.689 .44923 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50978 .00415 Mdot
.53116 .01321 Mdot
.59897 .04191 Mdot
.80586 .12786 Mdot
.23693 .26641 Mdot
.43007 .11937 Mdot
.52165 .0566 Mdot
.64562 .07661 Mdot
.95878 .19355 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41914 .58378 Mdot
.24757 .512 Mdot
.83729 .36447 Mdot
.63073 .49037 Mdot
.59895 .59839 Mdot
.70621 .06629 Mdot
.04323 .20829 Mdot
.3162 .1687 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00214 Mdot
.51611 .00683 Mdot
.5513 .02174 Mdot
.6621 .06848 Mdot
.97614 .19409 Mdot
.32584 .21613 Mdot
.4634 .08502 Mdot
.54654 .05138 Mdot
.6985 .09392 Mdot
.07679 .2338 Mdot
.49991 .618 Mdot
.49973 .61792 Mdot
.49913 .61766 Mdot
.49723 .61686 Mdot
.49116 .61429 Mdot
.47185 .6061 Mdot
.41053 .58014 Mdot
.22198 .5015 Mdot
.79838 .35624 Mdot
.60257 .49702 Mdot
.55018 .58566 Mdot
.49933 .61775 Mdot
.49788 .61713 Mdot
.49324 .61517 Mdot
.47845 .6089 Mdot
.43144 .58898 Mdot
.28473 .52737 Mdot
.90496 .38332 Mdot
.65942 .46628 Mdot
.61499 .59057 Mdot
.72842 .07011 Mdot
.0784 .2163 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02052 Mdot
.65314 .06472 Mdot
.95372 .18577 Mdot
.32275 .22807 Mdot
.47756 .09568 Mdot
.59882 .07494 Mdot
.85895 .16077 Mdot
.30404 .27508 Mdot
.50014 6e-05 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51398 .00593 Mdot
.54452 .01887 Mdot
.64096 .0596 Mdot
.92226 .17385 Mdot
.31559 .24309 Mdot
.49017 .1079 Mdot
.65003 .0988 Mdot
.00305 .21818 Mdot
.49891 .61757 Mdot
.49654 .61657 Mdot
.48897 .61336 Mdot
.46488 .60314 Mdot
.38854 .57085 Mdot
.15834 .47576 Mdot
.72792 .35202 Mdot
.53393 .49815 Mdot
.39046 .52936 Mdot
.09535 .43565 Mdot
.66562 .35244 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50493 .00209 Mdot
.51571 .00666 Mdot
.55003 .02121 Mdot
.65815 .06683 Mdot
.96635 .19048 Mdot
.32465 .22144 Mdot
.46999 .08983 Mdot
.57058 .06217 Mdot
.77361 .12548 Mdot
.21276 .2714 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50626 .00265 Mdot
.51994 .00846 Mdot
.56346 .02689 Mdot
.69966 .08418 Mdot
.06274 .2244 Mdot
.33413 .16773 Mdot
.39938 .04032 Mdot
.32355 .57117 Mdot
.03404 .4391 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50749 .00318 Mdot
.52387 .01012 Mdot
.57591 .03216 Mdot
.73754 .09989 Mdot
.13717 .24699 Mdot
.35559 .13499 Mdot
.38592 .01874 Mdot
.25941 .53985 Mdot
.89459 .39256 Mdot
.67657 .48329 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50429 .00182 Mdot
.51366 .00579 Mdot
.54351 .01844 Mdot
.6378 .05828 Mdot
.91392 .17065 Mdot
.31296 .24662 Mdot
.49169 .11047 Mdot
.65798 .10277 Mdot
.02419 .22633 Mdot
.35426 .20399 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52657 .01126 Mdot
.58446 .03578 Mdot
.76318 .11045 Mdot
.17981 .25749 Mdot
.38055 .12407 Mdot
.41848 .02344 Mdot
.3394 .56916 Mdot
.05827 .44429 Mdot
.69167 .39147 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.52082 .00883 Mdot
.56623 .02807 Mdot
.70816 .08771 Mdot
.08061 .23019 Mdot
.33725 .15861 Mdot
.39014 .03269 Mdot
.29103 .55678 Mdot
.96107 .41411 Mdot
.68893 .44984 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52382 .0101 Mdot
.57576 .0321 Mdot
.73709 .09971 Mdot
.13636 .24677 Mdot
.35522 .13526 Mdot
.38564 .0188 Mdot
.2589 .53971 Mdot
.89381 .39239 Mdot
.49774 .61708 Mdot
.4928 .61498 Mdot
.47708 .60831 Mdot
.42709 .58714 Mdot
.27151 .52188 Mdot
.87938 .37568 Mdot
.65135 .4771 Mdot
.61764 .5972 Mdot
.74476 .07856 Mdot
.11048 .22603 Mdot
.32347 .13164 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50522 .00221 Mdot
.51663 .00705 Mdot
.55295 .02245 Mdot
.66724 .07063 Mdot
.9887 .19867 Mdot
.3271 .20914 Mdot
.45423 .07857 Mdot
.51365 .03673 Mdot
.59353 .04937 Mdot
.80578 .13117 Mdot
.49904 .61763 Mdot
.49696 .61674 Mdot
.4903 .61392 Mdot
.46911 .60494 Mdot
.40189 .57649 Mdot
.19664 .49118 Mdot
.76595 .35185 Mdot
.57279 .49866 Mdot
.48506 .56381 Mdot
.37497 .54999 Mdot
.09602 .44564 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50778 .0033 Mdot
.52477 .0105 Mdot
.57877 .03337 Mdot
.74615 .10345 Mdot
.1522 .25095 Mdot
.36319 .1304 Mdot
.39331 .01862 Mdot
.27513 .54499 Mdot
.92118 .39928 Mdot
.68069 .4694 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51186 .00503 Mdot
.53778 .01602 Mdot
.61983 .05071 Mdot
.86511 .15159 Mdot
.28936 .2622 Mdot
.48214 .11915 Mdot
.64819 .10262 Mdot
.00576 .22099 Mdot
.3547 .21565 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51524 .00646 Mdot
.54854 .02058 Mdot
.65351 .06488 Mdot
.95468 .18613 Mdot
.32291 .22758 Mdot
.47703 .09525 Mdot
.59681 .07403 Mdot
.853 .15834 Mdot
.29966 .27605 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48477 .61157 Mdot
.4515 .59747 Mdot
.34659 .5532 Mdot
.04559 .432 Mdot
.67713 .39031 Mdot
.52282 .52266 Mdot
.40263 .54375 Mdot
.14533 .45901 Mdot
.69909 .34224 Mdot
.49835 .61733 Mdot
.49473 .6158 Mdot
.48321 .61092 Mdot
.44656 .59538 Mdot
.33125 .54677 Mdot
.00766 .41804 Mdot
.67258 .41094 Mdot
.54854 .54137 Mdot
.49618 .58568 Mdot
.43811 .58214 Mdot
.28951 .5262 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50556 .00236 Mdot
.51773 .00752 Mdot
.55642 .02392 Mdot
.678 .07514 Mdot
.01428 .20784 Mdot
.32917 .19461 Mdot
.43427 .06495 Mdot
.44355 .00574 Mdot
.36992 .57253 Mdot
.12217 .46492 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.4788 .60904 Mdot
.43254 .58945 Mdot
.28809 .52876 Mdot
.91172 .38542 Mdot
.66108 .46313 Mdot
.61287 .58824 Mdot
.72013 .06629 Mdot
.06193 .21124 Mdot
.31316 .15527 Mdot
.49838 .61735 Mdot
.49483 .61584 Mdot
.48353 .61105 Mdot
.44758 .59581 Mdot
.3344 .54809 Mdot
.01527 .42081 Mdot
.67327 .40667 Mdot
.5428 .5374 Mdot
.47575 .5766 Mdot
.37247 .5542 Mdot
.09772 .44823 Mdot
.49939 .61777 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48014 .60961 Mdot
.43682 .59126 Mdot
.30118 .53421 Mdot
.93906 .39423 Mdot
.66613 .44935 Mdot
.59954 .57688 Mdot
.67271 .04522 Mdot
.95702 .17571 Mdot
.4992 .6177 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.47429 .60713 Mdot
.41826 .5834 Mdot
.24493 .51091 Mdot
.83299 .36344 Mdot
.62806 .49138 Mdot
.59514 .59769 Mdot
.69659 .0627 Mdot
.02346 .20201 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50384 .00163 Mdot
.51223 .00519 Mdot
.53894 .01651 Mdot
.62349 .05225 Mdot
.87523 .15558 Mdot
.29554 .25977 Mdot
.48682 .11822 Mdot
.65835 .10601 Mdot
.03011 .22976 Mdot
.35698 .20201 Mdot
.49951 .61782 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48405 .61127 Mdot
.44921 .5965 Mdot
.33948 .55022 Mdot
.02776 .42538 Mdot
.67461 .39978 Mdot
.53391 .53108 Mdot
.4437 .56228 Mdot
.27079 .51117 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51605 .0068 Mdot
.55109 .02166 Mdot
.66145 .06821 Mdot
.97455 .1935 Mdot
.32566 .217 Mdot
.4645 .08581 Mdot
.55054 .05318 Mdot
.71113 .09925 Mdot
.10337 .24242 Mdot
.49766 .61704 Mdot
.49256 .61488 Mdot
.47629 .60798 Mdot
.42459 .58608 Mdot
.26397 .51876 Mdot
.86553 .37178 Mdot
.64564 .48214 Mdot
.61497 .59908 Mdot
.74216 .0786 Mdot
.10778 .22597 Mdot
.32381 .13351 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57373 .03124 Mdot
.73095 .09717 Mdot
.1252 .24366 Mdot
.35043 .1392 Mdot
.3829 .02007 Mdot
.25513 .53907 Mdot
.88876 .3916 Mdot
.67599 .48654 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50483 .00205 Mdot
.5154 .00653 Mdot
.54903 .02079 Mdot
.65506 .06553 Mdot
.95859 .18759 Mdot
.32354 .22555 Mdot
.47478 .09347 Mdot
.58835 .07019 Mdot
.82775 .14796 Mdot
.27796 .27824 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51885 .00799 Mdot
.55998 .02542 Mdot
.68896 .07972 Mdot
.03934 .21654 Mdot
.33131 .18045 Mdot
.41502 .05174 Mdot
.37724 .59468 Mdot
.17303 .49183 Mdot
.75747 .3612 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.48929 .61349 Mdot
.4659 .60357 Mdot
.39174 .5722 Mdot
.16742 .4794 Mdot
.7358 .35127 Mdot
.54195 .49823 Mdot
.4103 .53667 Mdot
.15111 .45785 Mdot
.69781 .33788 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52328 .00987 Mdot
.57403 .03137 Mdot
.73188 .09755 Mdot
.12691 .24414 Mdot
.35112 .13857 Mdot
.38318 .01982 Mdot
.25533 .53902 Mdot
.88888 .39155 Mdot
.67589 .4864 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52125 .00901 Mdot
.56761 .02865 Mdot
.71236 .08946 Mdot
.0892 .2329 Mdot
.33913 .15447 Mdot
.38681 .02946 Mdot
.27865 .55119 Mdot
.93562 .40603 Mdot
.68655 .4641 Mdot
.49849 .61739 Mdot
.4952 .616 Mdot
.4847 .61155 Mdot
.45129 .59739 Mdot
.34596 .55294 Mdot
.04399 .43141 Mdot
.67687 .39114 Mdot
.52372 .52338 Mdot
.40603 .54529 Mdot
.15542 .46315 Mdot
.70701 .3409 Mdot
.49858 .61743 Mdot
.49546 .61611 Mdot
.48555 .61191 Mdot
.45399 .59853 Mdot
.35437 .55647 Mdot
.06555 .43953 Mdot
.68116 .38047 Mdot
.51351 .51442 Mdot
.3661 .52693 Mdot
.04071 .41693 Mdot
.65492 .3796 Mdot
.49803 .6172 Mdot
.49371 .61537 Mdot
.47998 .60954 Mdot
.43629 .59103 Mdot
.29955 .53353 Mdot
.93557 .39308 Mdot
.66561 .45119 Mdot
.60161 .57848 Mdot
.67988 .04837 Mdot
.97407 .18182 Mdot
.30699 .20575 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50428 .00181 Mdot
.51364 .00578 Mdot
.54342 .01841 Mdot
.63753 .05816 Mdot
.91321 .17038 Mdot
.31272 .24691 Mdot
.49178 .11067 Mdot
.65853 .10306 Mdot
.02566 .2269 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.4866 .61235 Mdot
.45732 .59994 Mdot
.36479 .56084 Mdot
.09296 .45004 Mdot
.68949 .36868 Mdot
.5077 .50568 Mdot
.33747 .51282 Mdot
.96366 .38701 Mdot
.64389 .4204 Mdot
.50001 0 Mdot
.50004 1e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50362 .00153 Mdot
.51153 .00489 Mdot
.53672 .01557 Mdot
.61651 .04931 Mdot
.85587 .14793 Mdot
.28306 .26402 Mdot
.47665 .11965 Mdot
.49915 .61767 Mdot
.4973 .61689 Mdot
.4914 .61439 Mdot
.4726 .60642 Mdot
.41291 .58114 Mdot
.229 .50437 Mdot
.80843 .35811 Mdot
.61069 .49582 Mdot
.56591 .59036 Mdot
.61719 .03169 Mdot
.8288 .13078 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.42751 .58731 Mdot
.27278 .52241 Mdot
.88177 .37637 Mdot
.65223 .47618 Mdot
.61779 .59675 Mdot
.74433 .07821 Mdot
.10946 .22566 Mdot
.49771 .61706 Mdot
.49269 .61493 Mdot
.47672 .60816 Mdot
.42595 .58666 Mdot
.26806 .52046 Mdot
.87298 .37386 Mdot
.64884 .4795 Mdot
.6168 .59823 Mdot
.74465 .07902 Mdot
.11111 .22648 Mdot
.32411 .13164 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.5093 .00394 Mdot
.52962 .01256 Mdot
.5941 .03985 Mdot
.79165 .12209 Mdot
.21981 .26462 Mdot
.41352 .11972 Mdot
.48379 .04343 Mdot
.52978 .02843 Mdot
.62018 .05587 Mdot
.49861 .61745 Mdot
.49559 .61616 Mdot
.48594 .61207 Mdot
.45522 .59905 Mdot
.3582 .55808 Mdot
.07554 .44334 Mdot
.68377 .37591 Mdot
.51037 .51086 Mdot
.35249 .52046 Mdot
.00371 .40247 Mdot
.64936 .39904 Mdot
.49829 .61731 Mdot
.49455 .61572 Mdot
.48265 .61068 Mdot
.44476 .59462 Mdot
.32568 .54444 Mdot
.99434 .41326 Mdot
.67149 .4185 Mdot
.55891 .54846 Mdot
.5327 .60183 Mdot
.55519 .0139 Mdot
.65881 .06404 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50962 .00408 Mdot
.53063 .01299 Mdot
.59731 .04121 Mdot
.80101 .1259 Mdot
.2313 .26593 Mdot
.42449 .1194 Mdot
.50863 .052 Mdot
.6057 .05999 Mdot
.84991 .15093 Mdot
.49908 .61765 Mdot
.49708 .6168 Mdot
.4907 .61409 Mdot
.47037 .60547 Mdot
.40587 .57817 Mdot
.20825 .4959 Mdot
.78006 .3534 Mdot
.58637 .49832 Mdot
.51595 .57452 Mdot
.46942 .58928 Mdot
.37731 .56111 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51216 .00515 Mdot
.53871 .01641 Mdot
.62277 .05195 Mdot
.87324 .1548 Mdot
.29438 .26028 Mdot
.48601 .11843 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51432 .00607 Mdot
.5456 .01933 Mdot
.64435 .06103 Mdot
.93114 .17724 Mdot
.31803 .23911 Mdot
.48766 .10484 Mdot
.63879 .0934 Mdot
.9727 .20637 Mdot
.34736 .23155 Mdot
.50063 .00027 Mdot
.50199 .00085 Mdot
.50635 .00269 Mdot
.52023 .00858 Mdot
.56439 .02729 Mdot
.70251 .08536 Mdot
.06881 .22639 Mdot
.33508 .16457 Mdot
.39593 .03761 Mdot
.31157 .56589 Mdot
.00612 .42925 Mdot
.69149 .42358 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48774 .61284 Mdot
.46097 .60149 Mdot
.37623 .56566 Mdot
.12398 .46214 Mdot
.70401 .35848 Mdot
.51288 .49991 Mdot
.34103 .51183 Mdot
.96845 .38777 Mdot
.64289 .41682 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50386 .00164 Mdot
.51231 .00522 Mdot
.53919 .01662 Mdot
.62427 .05258 Mdot
.87737 .15643 Mdot
.29675 .25919 Mdot
.48763 .11797 Mdot
.65996 .10651 Mdot
.03383 .23106 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .00341 Mdot
.52558 .01085 Mdot
.58135 .03446 Mdot
.75389 .10664 Mdot
.16509 .25414 Mdot
.37074 .1271 Mdot
.40311 .02001 Mdot
.29897 .55367 Mdot
.96731 .41306 Mdot
.68434 .44315 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47473 .60732 Mdot
.41963 .58398 Mdot
.24904 .5126 Mdot
.83973 .36506 Mdot
.6322 .48977 Mdot
.60094 .59871 Mdot
.71114 .06811 Mdot
.05299 .21128 Mdot
.31682 .16305 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50788 .00334 Mdot
.52511 .01065 Mdot
.57986 .03384 Mdot
.74944 .1048 Mdot
.15774 .25235 Mdot
.36631 .1289 Mdot
.39712 .01904 Mdot
.28413 .5482 Mdot
.93788 .40404 Mdot
.68246 .46018 Mdot
.50022 .0001 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50725 .00308 Mdot
.5231 .0098 Mdot
.57349 .03114 Mdot
.73023 .09687 Mdot
.12387 .24328 Mdot
.3499 .13969 Mdot
.38271 .02027 Mdot
.25507 .53915 Mdot
.88882 .39168 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47767 .60857 Mdot
.42897 .58793 Mdot
.27722 .52425 Mdot
.89021 .37885 Mdot
.65514 .47275 Mdot
.61763 .59485 Mdot
.74094 .07621 Mdot
.10259 .22351 Mdot
.32079 .13486 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51669 .00708 Mdot
.55312 .02252 Mdot
.66777 .07085 Mdot
.98998 .19914 Mdot
.32721 .20842 Mdot
.45327 .0779 Mdot
.51022 .0352 Mdot
.58249 .04466 Mdot
.77302 .11776 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50405 .00172 Mdot
.5129 .00547 Mdot
.54108 .01742 Mdot
.6302 .05508 Mdot
.89356 .16276 Mdot
.30494 .25425 Mdot
.49167 .1154 Mdot
.66591 .10768 Mdot
.04632 .23511 Mdot
.35823 .19277 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50617 .00262 Mdot
.51967 .00834 Mdot
.5626 .02653 Mdot
.69702 .08308 Mdot
.05707 .22252 Mdot
.33334 .17074 Mdot
.40286 .04297 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50585 .00248 Mdot
.51862 .0079 Mdot
.55927 .02512 Mdot
.68678 .07881 Mdot
.03443 .21486 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.51091 .00462 Mdot
.53473 .01473 Mdot
.61025 .04667 Mdot
.83823 .1409 Mdot
.26919 .26635 Mdot
.46315 .11987 Mdot
.60232 .08601 Mdot
.88461 .17447 Mdot
.49861 .61744 Mdot
.49557 .61615 Mdot
.48588 .61204 Mdot
.45503 .59897 Mdot
.35761 .55783 Mdot
.07399 .44275 Mdot
.68334 .3766 Mdot
.51078 .51139 Mdot
.35438 .52137 Mdot
.00877 .40444 Mdot
.65001 .39631 Mdot
.49828 .6173 Mdot
.49452 .61571 Mdot
.48254 .61063 Mdot
.44443 .59448 Mdot
.32464 .544 Mdot
.99191 .41239 Mdot
.6713 .41989 Mdot
.56084 .54976 Mdot
.53942 .6048 Mdot
.57655 .02294 Mdot
.72411 .0912 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48054 .60978 Mdot
.43808 .59179 Mdot
.30507 .53583 Mdot
.94747 .39703 Mdot
.66724 .44484 Mdot
.5942 .57289 Mdot
.65433 .03717 Mdot
.91136 .15885 Mdot
.29458 .23684 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.5004 .00017 Mdot
.50126 .00053 Mdot
.50401 .0017 Mdot
.51279 .00542 Mdot
.54073 .01727 Mdot
.6291 .05461 Mdot
.89056 .1616 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50325 .00138 Mdot
.51035 .00439 Mdot
.53295 .01397 Mdot
.60463 .0443 Mdot
.82218 .13446 Mdot
.25433 .26709 Mdot
.44784 .1196 Mdot
.56451 .0721 Mdot
.77532 .13028 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52327 .00987 Mdot
.57402 .03136 Mdot
.73184 .09754 Mdot
.12684 .24412 Mdot
.35109 .1386 Mdot
.38317 .01983 Mdot
.25532 .53902 Mdot
.88887 .39156 Mdot
.6759 .48641 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52456 .01041 Mdot
.57811 .03309 Mdot
.74416 .10263 Mdot
.14879 .25007 Mdot
.36135 .13137 Mdot
.39127 .01849 Mdot
.27048 .54338 Mdot
.91293 .39706 Mdot
.67957 .47381 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50536 .00227 Mdot
.51709 .00725 Mdot
.5544 .02306 Mdot
.67174 .07252 Mdot
.99953 .20258 Mdot
.32802 .20302 Mdot
.4459 .07285 Mdot
.48419 .02367 Mdot
.49882 .00904 Mdot
.51166 .00794 Mdot
.49861 .61744 Mdot
.49557 .61615 Mdot
.48588 .61205 Mdot
.45504 .59897 Mdot
.35765 .55784 Mdot
.07408 .44278 Mdot
.68336 .37656 Mdot
.51076 .51136 Mdot
.35427 .52132 Mdot
.00848 .40432 Mdot
.64998 .39647 Mdot
.49963 .61788 Mdot
.49882 .61753 Mdot
.49623 .61644 Mdot
.48799 .61294 Mdot
.46175 .60182 Mdot
.37867 .56669 Mdot
.13073 .4648 Mdot
.70801 .35678 Mdot
.51577 .49922 Mdot
.34713 .51381 Mdot
.98286 .3929 Mdot
.49838 .61735 Mdot
.49484 .61585 Mdot
.48357 .61107 Mdot
.44771 .59587 Mdot
.33482 .54826 Mdot
.01629 .42118 Mdot
.67337 .4061 Mdot
.54205 .53687 Mdot
.47306 .5754 Mdot
.36386 .55054 Mdot
.07446 .43917 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52352 .00997 Mdot
.57481 .0317 Mdot
.73423 .09853 Mdot
.1312 .24535 Mdot
.35292 .13703 Mdot
.38411 .01928 Mdot
.25642 .53912 Mdot
.8902 .39169 Mdot
.67592 .4856 Mdot
.50077 .00033 Mdot
.50244 .00104 Mdot
.50779 .0033 Mdot
.5248 .01052 Mdot
.57887 .03341 Mdot
.74645 .10357 Mdot
.1527 .25108 Mdot
.36346 .13026 Mdot
.39363 .01865 Mdot
.27587 .54525 Mdot
.92252 .39965 Mdot
.68085 .46868 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50597 .00253 Mdot
.51903 .00807 Mdot
.56058 .02568 Mdot
.69081 .08049 Mdot
.04346 .21795 Mdot
.33172 .17816 Mdot
.41205 .04964 Mdot
.36705 .59022 Mdot
.14502 .48081 Mdot
.73434 .36422 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48465 .61153 Mdot
.45114 .59732 Mdot
.34549 .55274 Mdot
.0428 .43096 Mdot
.67668 .39176 Mdot
.52441 .52392 Mdot
.4086 .54646 Mdot
.16312 .46631 Mdot
.7136 .34021 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50695 .00295 Mdot
.52213 .00938 Mdot
.57041 .02984 Mdot
.72088 .093 Mdot
.1061 .23808 Mdot
.3437 .14684 Mdot
.38276 .02414 Mdot
.26143 .54305 Mdot
.90199 .39589 Mdot
.68044 .48111 Mdot
.50081 .00035 Mdot
.5026 .0011 Mdot
.50827 .00351 Mdot
.52635 .01117 Mdot
.58377 .03549 Mdot
.76112 .10961 Mdot
.17663 .25679 Mdot
.37832 .12465 Mdot
.41476 .02252 Mdot
.32938 .56526 Mdot
.03434 .43569 Mdot
.68819 .4041 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48512 .61172 Mdot
.45261 .59794 Mdot
.35006 .55466 Mdot
.05443 .43532 Mdot
.67874 .38584 Mdot
.51824 .51884 Mdot
.38503 .53571 Mdot
.09399 .43816 Mdot
.67002 .356 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48032 .60969 Mdot
.43737 .59149 Mdot
.30288 .53491 Mdot
.94271 .39544 Mdot
.66663 .44741 Mdot
.59728 .57517 Mdot
.66493 .04181 Mdot
.93801 .16877 Mdot
.30174 .2248 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.47878 .60904 Mdot
.43249 .58942 Mdot
.28793 .52869 Mdot
.91139 .38532 Mdot
.661 .46329 Mdot
.61299 .58836 Mdot
.72057 .06649 Mdot
.06282 .21152 Mdot
.31327 .15478 Mdot
.4987 .61748 Mdot
.49585 .61628 Mdot
.48678 .61243 Mdot
.45792 .60019 Mdot
.36666 .56163 Mdot
.09798 .45198 Mdot
.69144 .36678 Mdot
.50765 .50445 Mdot
.33534 .51154 Mdot
.95781 .38471 Mdot
.64282 .42336 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51118 .00474 Mdot
.53559 .01509 Mdot
.61296 .04781 Mdot
.84588 .14396 Mdot
.27551 .26553 Mdot
.46947 .11987 Mdot
.61792 .09175 Mdot
.92751 .19134 Mdot
.34211 .25624 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50693 .00294 Mdot
.52207 .00936 Mdot
.57022 .02976 Mdot
.72032 .09277 Mdot
.10502 .23775 Mdot
.34337 .14731 Mdot
.38291 .02444 Mdot
.26223 .54345 Mdot
.90352 .39634 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50202 .00086 Mdot
.50645 .00273 Mdot
.52054 .00871 Mdot
.56536 .0277 Mdot
.70549 .08661 Mdot
.07508 .22842 Mdot
.33618 .16137 Mdot
.3927 .03493 Mdot
.30018 .56086 Mdot
.49746 .61696 Mdot
.49191 .61461 Mdot
.47425 .60711 Mdot
.41811 .58334 Mdot
.24449 .51073 Mdot
.83229 .36328 Mdot
.62761 .49154 Mdot
.59448 .59756 Mdot
.6949 .06206 Mdot
.01988 .20085 Mdot
.31512 .18247 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51996 .00846 Mdot
.5635 .02691 Mdot
.6998 .08424 Mdot
.06305 .2245 Mdot
.33418 .16757 Mdot
.3992 .04018 Mdot
.32292 .57089 Mdot
.49997 .61802 Mdot
.49991 .618 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49089 .61417 Mdot
.47099 .60573 Mdot
.40781 .57899 Mdot
.21396 .49822 Mdot
.78747 .35445 Mdot
.59312 .49792 Mdot
.49757 .617 Mdot
.49225 .61475 Mdot
.47532 .60757 Mdot
.42152 .58478 Mdot
.2547 .51494 Mdot
.84926 .36746 Mdot
.6376 .48723 Mdot
.60759 .59948 Mdot
.72694 .07376 Mdot
.08252 .21976 Mdot
.31979 .14664 Mdot
.49977 .61794 Mdot
.49927 .61772 Mdot
.49766 .61704 Mdot
.49255 .61488 Mdot
.47627 .60797 Mdot
.42453 .58606 Mdot
.26378 .51868 Mdot
.86519 .37169 Mdot
.64549 .48225 Mdot
.61487 .59911 Mdot
.74198 .07856 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50536 .00227 Mdot
.51708 .00724 Mdot
.55436 .02304 Mdot
.67161 .07246 Mdot
.99922 .20247 Mdot
.328 .2032 Mdot
.44614 .07302 Mdot
.48503 .02404 Mdot
.5015 .01018 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00246 Mdot
.5185 .00784 Mdot
.55888 .02496 Mdot
.68559 .07831 Mdot
.03174 .21393 Mdot
.3306 .18471 Mdot
.42069 .05568 Mdot
.39667 .60319 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.48489 .61163 Mdot
.4519 .59765 Mdot
.34786 .55373 Mdot
.04882 .43321 Mdot
.67769 .38866 Mdot
.52107 .52124 Mdot
.39597 .54072 Mdot
.12571 .451 Mdot
.68588 .34621 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48511 .61172 Mdot
.45261 .59794 Mdot
.35006 .55465 Mdot
.05442 .43532 Mdot
.67873 .38585 Mdot
.51825 .51885 Mdot
.38507 .53573 Mdot
.09409 .4382 Mdot
.67005 .35597 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48246 .6106 Mdot
.44418 .59437 Mdot
.32386 .54368 Mdot
.99007 .41174 Mdot
.67116 .42094 Mdot
.56229 .55075 Mdot
.54448 .60703 Mdot
.59252 .02969 Mdot
.77166 .11071 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47318 .60666 Mdot
.41474 .58191 Mdot
.23443 .5066 Mdot
.81653 .35976 Mdot
.6168 .4946 Mdot
.57698 .59342 Mdot
.64818 .044 Mdot
.91089 .16237 Mdot
.49882 .61753 Mdot
.49625 .61644 Mdot
.48804 .61296 Mdot
.46191 .60188 Mdot
.37917 .5669 Mdot
.13212 .46534 Mdot
.70887 .35646 Mdot
.51644 .4991 Mdot
.34861 .51431 Mdot
.98643 .39419 Mdot
.64458 .40676 Mdot
.49872 .61749 Mdot
.49591 .6163 Mdot
.48698 .61251 Mdot
.45853 .60045 Mdot
.36859 .56245 Mdot
.10319 .454 Mdot
.69362 .36491 Mdot
.50796 .50329 Mdot
.33423 .51066 Mdot
.95442 .3833 Mdot
.64205 .42498 Mdot
.49902 .61762 Mdot
.49689 .61672 Mdot
.49009 .61383 Mdot
.46845 .60466 Mdot
.39978 .5756 Mdot
.19053 .48871 Mdot
.75902 .35134 Mdot
.56585 .49865 Mdot
.46868 .55798 Mdot
.32482 .52913 Mdot
.96813 .39759 Mdot
.49806 .61721 Mdot
.4938 .61541 Mdot
.48026 .60966 Mdot
.43718 .59141 Mdot
.3023 .53467 Mdot
.94146 .39502 Mdot
.66646 .44807 Mdot
.59806 .57576 Mdot
.66762 .04299 Mdot
.94464 .17121 Mdot
.30303 .2215 Mdot
.49927 .61772 Mdot
.49767 .61705 Mdot
.49257 .61488 Mdot
.47634 .608 Mdot
.42474 .58615 Mdot
.26442 .51895 Mdot
.86634 .37201 Mdot
.646 .48186 Mdot
.61522 .59901 Mdot
.74256 .0787 Mdot
.10837 .22608 Mdot
.49875 .6175 Mdot
.49601 .61634 Mdot
.48729 .61265 Mdot
.45954 .60088 Mdot
.37173 .56377 Mdot
.11169 .45732 Mdot
.69753 .36207 Mdot
.50924 .50167 Mdot
.33482 .51023 Mdot
.95476 .38315 Mdot
.64165 .42452 Mdot
.49786 .61713 Mdot
.49319 .61515 Mdot
.47831 .60884 Mdot
.431 .58879 Mdot
.28341 .52682 Mdot
.90232 .38251 Mdot
.65873 .46748 Mdot
.61567 .59142 Mdot
.73124 .07143 Mdot
.08388 .21795 Mdot
.31645 .14373 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.5266 .01128 Mdot
.58458 .03583 Mdot
.76353 .1106 Mdot
.18035 .25761 Mdot
.38094 .12397 Mdot
.41913 .0236 Mdot
.34116 .56985 Mdot
.06257 .44586 Mdot
.69252 .38933 Mdot
.49873 .6175 Mdot
.49596 .61632 Mdot
.48713 .61257 Mdot
.459 .60065 Mdot
.37006 .56307 Mdot
.10716 .45555 Mdot
.69539 .36355 Mdot
.50843 .50249 Mdot
.33413 .51031 Mdot
.95366 .3829 Mdot
.64173 .42525 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47384 .60694 Mdot
.41684 .58281 Mdot
.24071 .50918 Mdot
.82625 .36188 Mdot
.62364 .49282 Mdot
.5884 .59625 Mdot
.67904 .05602 Mdot
.98507 .18914 Mdot
.31346 .20296 Mdot
.49939 .61778 Mdot
.49805 .61721 Mdot
.4938 .61541 Mdot
.48026 .60966 Mdot
.43718 .59141 Mdot
.30228 .53467 Mdot
.94143 .39501 Mdot
.66646 .44809 Mdot
.59808 .57578 Mdot
.6677 .04302 Mdot
.94483 .17128 Mdot
.49931 .61774 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47774 .60859 Mdot
.42918 .58802 Mdot
.27786 .52451 Mdot
.89145 .37922 Mdot
.65554 .47223 Mdot
.61752 .59454 Mdot
.7402 .07582 Mdot
.10116 .22308 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51177 .00499 Mdot
.53749 .01589 Mdot
.61891 .05033 Mdot
.86258 .15059 Mdot
.2877 .26274 Mdot
.48075 .11931 Mdot
.645 .10151 Mdot
.99788 .21809 Mdot
.35394 .22006 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50824 .0035 Mdot
.52626 .01114 Mdot
.5835 .03537 Mdot
.76031 .10928 Mdot
.17536 .25651 Mdot
.37745 .1249 Mdot
.41334 .02219 Mdot
.32559 .5638 Mdot
.02552 .43258 Mdot
.68734 .40903 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00246 Mdot
.5185 .00785 Mdot
.55889 .02496 Mdot
.68562 .07832 Mdot
.03182 .21396 Mdot
.3306 .18466 Mdot
.42062 .05563 Mdot
.39645 .60309 Mdot
.22767 .51372 Mdot
.82251 .36763 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51996 .00846 Mdot
.56352 .02692 Mdot
.69984 .08425 Mdot
.06314 .22453 Mdot
.33419 .16752 Mdot
.39915 .04015 Mdot
.32275 .57082 Mdot
.03213 .43842 Mdot
.69364 .40883 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50979 .00415 Mdot
.53117 .01322 Mdot
.59901 .04193 Mdot
.80598 .12791 Mdot
.23706 .26642 Mdot
.4302 .11937 Mdot
.52196 .05671 Mdot
.64656 .077 Mdot
.96121 .19447 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50617 .00262 Mdot
.51966 .00834 Mdot
.56258 .02652 Mdot
.69696 .08305 Mdot
.05693 .22248 Mdot
.33332 .17082 Mdot
.40295 .04303 Mdot
.33586 .57657 Mdot
.49867 .61747 Mdot
.49576 .61623 Mdot
.48648 .6123 Mdot
.45694 .59978 Mdot
.36359 .56034 Mdot
.08979 .44881 Mdot
.68833 .36992 Mdot
.50791 .50653 Mdot
.33934 .51385 Mdot
.96867 .38895 Mdot
.64469 .4178 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49147 .61442 Mdot
.47283 .60651 Mdot
.41363 .58145 Mdot
.23115 .50525 Mdot
.81161 .35874 Mdot
.61314 .49537 Mdot
.57043 .59164 Mdot
.62995 .03679 Mdot
.86346 .14431 Mdot
.49983 .61796 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49434 .61563 Mdot
.48197 .61039 Mdot
.44262 .59371 Mdot
.31906 .54167 Mdot
.97888 .40779 Mdot
.67029 .42731 Mdot
.57111 .55674 Mdot
.57509 .00246 Mdot
.49903 .61762 Mdot
.49691 .61672 Mdot
.49015 .61386 Mdot
.46864 .60474 Mdot
.40039 .57585 Mdot
.19228 .48942 Mdot
.76097 .35147 Mdot
.56782 .49866 Mdot
.47336 .55965 Mdot
.33912 .53507 Mdot
.0026 .41005 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42795 .5875 Mdot
.27412 .52297 Mdot
.8843 .37711 Mdot
.65314 .47517 Mdot
.61785 .59622 Mdot
.74362 .07773 Mdot
.10793 .22516 Mdot
.32247 .13259 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00353 Mdot
.52655 .01126 Mdot
.58442 .03576 Mdot
.76306 .1104 Mdot
.17962 .25745 Mdot
.38042 .1241 Mdot
.41825 .02338 Mdot
.33879 .56892 Mdot
.05679 .44375 Mdot
.6914 .39221 Mdot
.49838 .61735 Mdot
.49483 .61584 Mdot
.48352 .61104 Mdot
.44753 .59579 Mdot
.33426 .54803 Mdot
.01493 .42068 Mdot
.67324 .40686 Mdot
.54305 .53757 Mdot
.47665 .577 Mdot
.37535 .55543 Mdot
.10562 .45133 Mdot
.49769 .61705 Mdot
.49263 .61491 Mdot
.47651 .60807 Mdot
.42529 .58638 Mdot
.26607 .51963 Mdot
.86933 .37284 Mdot
.64731 .48082 Mdot
.61602 .5987 Mdot
.74376 .07895 Mdot
.11005 .22638 Mdot
.32411 .1323 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50437 .00185 Mdot
.51392 .0059 Mdot
.54433 .01879 Mdot
.64037 .05936 Mdot
.92071 .17326 Mdot
.31513 .24376 Mdot
.49052 .1084 Mdot
.65171 .09962 Mdot
.00753 .21991 Mdot
.35206 .21293 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51963 .00832 Mdot
.56247 .02648 Mdot
.69663 .08292 Mdot
.05623 .22224 Mdot
.33323 .17119 Mdot
.40339 .04337 Mdot
.33738 .57724 Mdot
.06773 .45138 Mdot
.69952 .39047 Mdot
.50054 .00023 Mdot
.50174 .00074 Mdot
.50553 .00234 Mdot
.51761 .00747 Mdot
.55606 .02376 Mdot
.67687 .07467 Mdot
.01166 .20691 Mdot
.32897 .19611 Mdot
.43634 .06636 Mdot
.45075 .0089 Mdot
.39245 .582 Mdot
.18482 .48971 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50498 .00211 Mdot
.51588 .00673 Mdot
.55056 .02143 Mdot
.65981 .06752 Mdot
.97048 .192 Mdot
.32518 .21921 Mdot
.46727 .08782 Mdot
.56063 .0577 Mdot
.74275 .11255 Mdot
.16335 .25995 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50894 .00379 Mdot
.52849 .01208 Mdot
.59053 .03834 Mdot
.78116 .11782 Mdot
.20596 .26254 Mdot
.40111 .12061 Mdot
.45729 .03472 Mdot
.45017 .61363 Mdot
.36951 .56819 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50618 .00262 Mdot
.51969 .00835 Mdot
.56266 .02656 Mdot
.69721 .08316 Mdot
.05748 .22266 Mdot
.33339 .17052 Mdot
.4026 .04277 Mdot
.33466 .57604 Mdot
.06097 .44888 Mdot
.69805 .39374 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51217 .00516 Mdot
.53875 .01643 Mdot
.62289 .052 Mdot
.87359 .15494 Mdot
.29458 .26019 Mdot
.48616 .1184 Mdot
.65699 .10558 Mdot
.02693 .22864 Mdot
.50048 .0002 Mdot
.50151 .00064 Mdot
.50483 .00205 Mdot
.51537 .00652 Mdot
.54895 .02075 Mdot
.65478 .06541 Mdot
.95789 .18733 Mdot
.32343 .22592 Mdot
.47519 .0938 Mdot
.5899 .07089 Mdot
.83239 .14987 Mdot
.28233 .27808 Mdot
.49886 .61755 Mdot
.49638 .6165 Mdot
.48847 .61314 Mdot
.46328 .60247 Mdot
.3835 .56873 Mdot
.14416 .47012 Mdot
.71696 .35401 Mdot
.52337 .49839 Mdot
.3647 .51997 Mdot
.02666 .40911 Mdot
.64882 .38451 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51215 .00515 Mdot
.53868 .0164 Mdot
.62267 .05191 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.51872 .00794 Mdot
.55957 .02525 Mdot
.68769 .07919 Mdot
.03649 .21557 Mdot
.33103 .18204 Mdot
.41712 .05321 Mdot
.38443 .59783 Mdot
.19323 .49986 Mdot
.77832 .36161 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50495 .0021 Mdot
.51577 .00669 Mdot
.55022 .02129 Mdot
.65875 .06707 Mdot
.96783 .19102 Mdot
.32484 .22064 Mdot
.46903 .08911 Mdot
.56706 .06058 Mdot
.76273 .12093 Mdot
.19636 .268 Mdot
.49967 .61789 Mdot
.49894 .61759 Mdot
.49663 .61661 Mdot
.48927 .61349 Mdot
.46584 .60355 Mdot
.39155 .57212 Mdot
.16688 .47918 Mdot
.7353 .35131 Mdot
.54144 .49822 Mdot
.40904 .53621 Mdot
.14752 .4564 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50211 .00089 Mdot
.50672 .00285 Mdot
.5214 .00908 Mdot
.56809 .02886 Mdot
.71384 .09008 Mdot
.09218 .23383 Mdot
.33985 .15307 Mdot
.38584 .02842 Mdot
.27489 .54947 Mdot
.92813 .40372 Mdot
.49825 .61729 Mdot
.49443 .61567 Mdot
.48226 .61051 Mdot
.44354 .5941 Mdot
.32191 .54286 Mdot
.98549 .41012 Mdot
.67081 .42355 Mdot
.56591 .5532 Mdot
.55707 .61257 Mdot
.63202 .04632 Mdot
.88306 .15515 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .61259 Mdot
.45914 .60071 Mdot
.37049 .56324 Mdot
.10831 .456 Mdot
.69592 .36316 Mdot
.50861 .50227 Mdot
.33422 .51025 Mdot
.95375 .38289 Mdot
.64168 .42517 Mdot
.49837 .61734 Mdot
.49482 .61584 Mdot
.48349 .61103 Mdot
.44744 .59575 Mdot
.33397 .54791 Mdot
.01423 .42042 Mdot
.67317 .40725 Mdot
.54358 .53794 Mdot
.47853 .57783 Mdot
.38137 .55799 Mdot
.12229 .45791 Mdot
.49887 .61756 Mdot
.49642 .61651 Mdot
.48858 .61319 Mdot
.46363 .60261 Mdot
.38458 .56918 Mdot
.1472 .47132 Mdot
.71917 .3535 Mdot
.52542 .49829 Mdot
.36963 .52175 Mdot
.03942 .41396 Mdot
.65069 .37778 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00143 Mdot
.51071 .00454 Mdot
.5341 .01446 Mdot
.60826 .04583 Mdot
.83257 .13863 Mdot
.2642 .26676 Mdot
.45804 .1198 Mdot
.58968 .08135 Mdot
.84882 .16016 Mdot
.30214 .28017 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52368 .01004 Mdot
.57531 .03191 Mdot
.73575 .09916 Mdot
.13396 .24611 Mdot
.35413 .13607 Mdot
.38487 .019 Mdot
.25759 .53937 Mdot
.89184 .39199 Mdot
.67613 .48472 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47947 .60933 Mdot
.43469 .59036 Mdot
.29466 .53149 Mdot
.92525 .38972 Mdot
.66388 .4565 Mdot
.60714 .58297 Mdot
.69925 .05693 Mdot
.01806 .19703 Mdot
.30984 .18033 Mdot
.49889 .61756 Mdot
.49645 .61653 Mdot
.48869 .61324 Mdot
.46397 .60276 Mdot
.38568 .56965 Mdot
.15027 .47255 Mdot
.72149 .35303 Mdot
.52761 .49821 Mdot
.37496 .52369 Mdot
.05344 .41933 Mdot
.65326 .37071 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55364 .02274 Mdot
.66936 .07152 Mdot
.99383 .20053 Mdot
.32755 .20625 Mdot
.45032 .07588 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52051 .0087 Mdot
.56525 .02765 Mdot
.70514 .08646 Mdot
.07435 .22818 Mdot
.33605 .16174 Mdot
.39305 .03523 Mdot
.30145 .56142 Mdot
.98348 .42152 Mdot
.69024 .43681 Mdot
.49923 .61771 Mdot
.49756 .617 Mdot
.49222 .61473 Mdot
.47522 .60753 Mdot
.42119 .58464 Mdot
.25371 .51453 Mdot
.84756 .36702 Mdot
.63668 .4877 Mdot
.60654 .5994 Mdot
.72452 .07292 Mdot
.07819 .21858 Mdot
.49958 .61786 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48638 .61226 Mdot
.45662 .59964 Mdot
.36259 .55992 Mdot
.08712 .44778 Mdot
.6874 .37099 Mdot
.50818 .50727 Mdot
.34122 .51485 Mdot
.97367 .39088 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.50301 .00127 Mdot
.50958 .00406 Mdot
.5305 .01293 Mdot
.5969 .04104 Mdot
.79984 .12542 Mdot
.2299 .26579 Mdot
.42313 .11942 Mdot
.50548 .0509 Mdot
.59604 .05597 Mdot
.82208 .1397 Mdot
.49783 .61711 Mdot
.49308 .6151 Mdot
.47796 .60869 Mdot
.42988 .58832 Mdot
.28 .5254 Mdot
.89561 .38047 Mdot
.65682 .47045 Mdot
.617 .59342 Mdot
.73729 .07435 Mdot
.09556 .22142 Mdot
.31894 .13806 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50995 .00422 Mdot
.53168 .01343 Mdot
.60062 .04261 Mdot
.81064 .1298 Mdot
.24227 .26676 Mdot
.43545 .11939 Mdot
.53444 .06118 Mdot
.6847 .09286 Mdot
.05387 .22816 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00115 Mdot
.5086 .00365 Mdot
.52741 .01162 Mdot
.58712 .03691 Mdot
.77109 .1137 Mdot
.1917 .25995 Mdot
.38942 .12219 Mdot
.43428 .02773 Mdot
.38335 .58656 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47909 .60917 Mdot
.43347 .58984 Mdot
.29094 .52994 Mdot
.91752 .38725 Mdot
.66236 .46034 Mdot
.61065 .58607 Mdot
.71185 .06255 Mdot
.04496 .20587 Mdot
.31152 .16475 Mdot
.49894 .61758 Mdot
.49663 .6166 Mdot
.48925 .61348 Mdot
.46577 .60352 Mdot
.39132 .57203 Mdot
.16625 .47893 Mdot
.73473 .35135 Mdot
.54086 .49821 Mdot
.4076 .53568 Mdot
.1434 .45475 Mdot
.69204 .33908 Mdot
.49949 .61782 Mdot
.49837 .61734 Mdot
.49481 .61583 Mdot
.48346 .61102 Mdot
.44733 .59571 Mdot
.33364 .54777 Mdot
.01342 .42013 Mdot
.6731 .4077 Mdot
.54418 .53836 Mdot
.48067 .57878 Mdot
.38823 .56091 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47602 .60787 Mdot
.42375 .58572 Mdot
.26141 .51771 Mdot
.86096 .37054 Mdot
.64353 .48366 Mdot
.61339 .5994 Mdot
.73929 .07781 Mdot
.10339 .22502 Mdot
.32308 .13578 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48704 .61254 Mdot
.45873 .60054 Mdot
.3692 .5627 Mdot
.10483 .45464 Mdot
.69434 .36433 Mdot
.50813 .50295 Mdot
.3341 .51048 Mdot
.95391 .38306 Mdot
.64189 .42519 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51502 .00637 Mdot
.54781 .02027 Mdot
.65125 .06393 Mdot
.94892 .18397 Mdot
.3219 .23052 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.5078 .00331 Mdot
.52484 .01053 Mdot
.57898 .03346 Mdot
.74681 .10372 Mdot
.15331 .25123 Mdot
.3638 .13009 Mdot
.39403 .01868 Mdot
.27679 .54558 Mdot
.92419 .40012 Mdot
.68105 .46777 Mdot
.4996 .61787 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48716 .61259 Mdot
.45912 .6007 Mdot
.37042 .56322 Mdot
.10814 .45593 Mdot
.69584 .36322 Mdot
.50859 .5023 Mdot
.3342 .51026 Mdot
.95372 .38289 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47811 .60875 Mdot
.43036 .58852 Mdot
.28146 .52601 Mdot
.89848 .38134 Mdot
.65766 .4692 Mdot
.6165 .5926 Mdot
.7349 .07317 Mdot
.09096 .22006 Mdot
.31789 .14025 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.48631 .61223 Mdot
.4564 .59955 Mdot
.36192 .55964 Mdot
.08533 .4471 Mdot
.68679 .37172 Mdot
.50841 .50778 Mdot
.34262 .51557 Mdot
.97741 .39232 Mdot
.64597 .41319 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.50461 .00195 Mdot
.51469 .00623 Mdot
.54676 .01982 Mdot
.64796 .06255 Mdot
.94049 .18079 Mdot
.32022 .23468 Mdot
.48407 .10127 Mdot
.62408 .08653 Mdot
.93191 .19025 Mdot
.33879 .25146 Mdot
.4981 .61723 Mdot
.49395 .61547 Mdot
.48072 .60986 Mdot
.43866 .59204 Mdot
.30684 .53657 Mdot
.95135 .39833 Mdot
.66771 .44273 Mdot
.59158 .57099 Mdot
.64537 .03325 Mdot
.88814 .15004 Mdot
.28522 .24541 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49407 .61552 Mdot
.48111 .61002 Mdot
.43988 .59255 Mdot
.3106 .53813 Mdot
.95968 .40115 Mdot
.6686 .43814 Mdot
.5857 .5668 Mdot
.62522 .02443 Mdot
.8338 .12891 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.48929 .61349 Mdot
.4659 .60358 Mdot
.39175 .57221 Mdot
.16746 .47942 Mdot
.73583 .35127 Mdot
.54199 .49823 Mdot
.41039 .5367 Mdot
.15138 .45795 Mdot
.69802 .33784 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50854 .00362 Mdot
.52722 .01154 Mdot
.58652 .03665 Mdot
.7693 .11297 Mdot
.18907 .25943 Mdot
.38738 .12256 Mdot
.43051 .02666 Mdot
.3727 .5823 Mdot
.14365 .47647 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.5187 .00793 Mdot
.55952 .02523 Mdot
.68756 .07913 Mdot
.0362 .21547 Mdot
.331 .1822 Mdot
.41734 .05336 Mdot
.38517 .59816 Mdot
.19533 .50071 Mdot
.7807 .36178 Mdot
.50063 .00027 Mdot
.50199 .00084 Mdot
.50635 .00269 Mdot
.52022 .00857 Mdot
.56433 .02726 Mdot
.70233 .08529 Mdot
.06844 .22627 Mdot
.33502 .16476 Mdot
.39614 .03777 Mdot
.31228 .56621 Mdot
.00774 .42982 Mdot
.69159 .42265 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49546 .61611 Mdot
.48552 .61189 Mdot
.45389 .59849 Mdot
.35408 .55634 Mdot
.06477 .43924 Mdot
.68097 .38083 Mdot
.5138 .51471 Mdot
.36729 .52749 Mdot
.04401 .41823 Mdot
.49898 .6176 Mdot
.49675 .61666 Mdot
.48966 .61365 Mdot
.46705 .60406 Mdot
.39538 .57374 Mdot
.17784 .48359 Mdot
.74569 .35095 Mdot
.55218 .49844 Mdot
.43555 .54595 Mdot
.22486 .48782 Mdot
.77841 .34211 Mdot
.49964 .61788 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48825 .61305 Mdot
.46257 .60216 Mdot
.38126 .56778 Mdot
.13791 .46764 Mdot
.71263 .35519 Mdot
.51953 .49869 Mdot
.35565 .51675 Mdot
.00372 .40053 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48397 .61124 Mdot
.44898 .59641 Mdot
.33876 .54992 Mdot
.02599 .42473 Mdot
.6744 .40074 Mdot
.53513 .53196 Mdot
.44811 .56425 Mdot
.28463 .517 Mdot
.88804 .37293 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49083 .61415 Mdot
.47079 .60565 Mdot
.40718 .57872 Mdot
.2121 .49747 Mdot
.78503 .35409 Mdot
.59093 .49807 Mdot
.52592 .57786 Mdot
.49961 .60177 Mdot
.47271 .60141 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .0027 Mdot
.52032 .00862 Mdot
.56466 .0274 Mdot
.70334 .08571 Mdot
.07057 .22696 Mdot
.33538 .16366 Mdot
.39499 .03684 Mdot
.30827 .56444 Mdot
.99864 .42667 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52028 .0086 Mdot
.56452 .02735 Mdot
.70292 .08554 Mdot
.06969 .22667 Mdot
.33523 .16411 Mdot
.39546 .03722 Mdot
.30991 .56516 Mdot
.00234 .42795 Mdot
.69126 .42578 Mdot
.49785 .61712 Mdot
.49316 .61513 Mdot
.47822 .6088 Mdot
.43071 .58867 Mdot
.28251 .52644 Mdot
.90054 .38196 Mdot
.65824 .46829 Mdot
.61608 .59198 Mdot
.73301 .07227 Mdot
.08731 .21897 Mdot
.31712 .14203 Mdot
.49753 .61699 Mdot
.49213 .61469 Mdot
.47491 .6074 Mdot
.42023 .58424 Mdot
.25084 .51334 Mdot
.84272 .3658 Mdot
.63395 .48901 Mdot
.60322 .59904 Mdot
.71668 .07012 Mdot
.06367 .21445 Mdot
.31768 .15699 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.4849 .61163 Mdot
.45193 .59766 Mdot
.34796 .55377 Mdot
.04905 .4333 Mdot
.67773 .38854 Mdot
.52095 .52114 Mdot
.3955 .5405 Mdot
.12431 .45043 Mdot
.68505 .34656 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50552 .00234 Mdot
.51759 .00746 Mdot
.55599 .02373 Mdot
.67665 .07457 Mdot
.01112 .20672 Mdot
.32893 .19641 Mdot
.43677 .06665 Mdot
.45223 .00955 Mdot
.39709 .58396 Mdot
.19814 .49507 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.5056 .00238 Mdot
.51784 .00757 Mdot
.5568 .02407 Mdot
.67915 .07562 Mdot
.01697 .20878 Mdot
.32938 .19308 Mdot
.43214 .06351 Mdot
.43618 .00249 Mdot
.34703 .56294 Mdot
.06215 .44197 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00194 Mdot
.51454 .00617 Mdot
.54631 .01963 Mdot
.64655 .06196 Mdot
.93686 .17942 Mdot
.31941 .23643 Mdot
.48557 .1027 Mdot
.63013 .08934 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48673 .61241 Mdot
.45774 .60012 Mdot
.36611 .5614 Mdot
.0965 .45141 Mdot
.69085 .36733 Mdot
.50763 .5048 Mdot
.33587 .51188 Mdot
.95928 .38529 Mdot
.64311 .42263 Mdot
.4995 .61782 Mdot
.49842 .61736 Mdot
.49495 .61589 Mdot
.48391 .61121 Mdot
.44879 .59633 Mdot
.33816 .54966 Mdot
.02451 .42418 Mdot
.67424 .40155 Mdot
.53615 .53269 Mdot
.45183 .56592 Mdot
.29636 .52195 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.5041 .00174 Mdot
.51307 .00554 Mdot
.54161 .01764 Mdot
.63187 .05578 Mdot
.89807 .16452 Mdot
.30692 .25268 Mdot
.49215 .11448 Mdot
.66561 .1072 Mdot
.04501 .23449 Mdot
.3578 .19331 Mdot
.49886 .61755 Mdot
.49638 .6165 Mdot
.48846 .61314 Mdot
.46323 .60245 Mdot
.38335 .56866 Mdot
.14374 .46995 Mdot
.71666 .35408 Mdot
.52309 .4984 Mdot
.36404 .51974 Mdot
.02497 .40847 Mdot
.6486 .38542 Mdot
.49987 .61798 Mdot
.4996 .61786 Mdot
.49871 .61749 Mdot
.4959 .61629 Mdot
.48693 .61249 Mdot
.45836 .60038 Mdot
.36806 .56222 Mdot
.10175 .45344 Mdot
.693 .36541 Mdot
.50784 .5036 Mdot
.33442 .51086 Mdot
.49877 .61751 Mdot
.4961 .61638 Mdot
.48756 .61276 Mdot
.46038 .60124 Mdot
.37439 .56489 Mdot
.11893 .46015 Mdot
.70122 .35988 Mdot
.51113 .50055 Mdot
.33771 .51086 Mdot
.96091 .38516 Mdot
.64215 .42103 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49233 .61478 Mdot
.47556 .60767 Mdot
.42229 .58511 Mdot
.25701 .51589 Mdot
.85324 .36849 Mdot
.63971 .48606 Mdot
.60985 .59958 Mdot
.73198 .07548 Mdot
.09132 .22208 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50811 .00344 Mdot
.52583 .01095 Mdot
.58211 .03479 Mdot
.75617 .10758 Mdot
.16879 .25501 Mdot
.37308 .12626 Mdot
.40654 .02068 Mdot
.30774 .55697 Mdot
.98574 .41903 Mdot
.6851 .43223 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50528 .00224 Mdot
.51684 .00714 Mdot
.55359 .02272 Mdot
.66923 .07147 Mdot
.9935 .20041 Mdot
.32752 .20644 Mdot
.45057 .07605 Mdot
.50067 .03096 Mdot
.55178 .03159 Mdot
.67919 .07875 Mdot
.49956 .61785 Mdot
.4986 .61744 Mdot
.49552 .61614 Mdot
.48574 .61199 Mdot
.45459 .59878 Mdot
.35625 .55726 Mdot
.07043 .44139 Mdot
.68238 .37821 Mdot
.51184 .51263 Mdot
.35903 .5236 Mdot
.02135 .40934 Mdot
.49988 .61798 Mdot
.49962 .61787 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.48761 .61278 Mdot
.46054 .6013 Mdot
.37489 .5651 Mdot
.1203 .46069 Mdot
.70196 .35949 Mdot
.51157 .50036 Mdot
.33851 .51108 Mdot
.50011 5e-05 Mdot
.50037 .00015 Mdot
.50116 .00049 Mdot
.50371 .00157 Mdot
.51181 .00501 Mdot
.53761 .01594 Mdot
.61929 .05048 Mdot
.86362 .15101 Mdot
.28839 .26252 Mdot
.48134 .11925 Mdot
.64635 .10198 Mdot
.00123 .21933 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.50519 .0022 Mdot
.51655 .00702 Mdot
.55268 .02233 Mdot
.66641 .07029 Mdot
.9867 .19795 Mdot
.32691 .21027 Mdot
.45573 .07962 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50812 .00344 Mdot
.52588 .01097 Mdot
.58227 .03486 Mdot
.75666 .10778 Mdot
.16957 .25519 Mdot
.37359 .12609 Mdot
.4073 .02084 Mdot
.3097 .55771 Mdot
.98997 .42043 Mdot
.68527 .42972 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .613 Mdot
.46222 .60202 Mdot
.38016 .56732 Mdot
.13486 .46643 Mdot
.71062 .35584 Mdot
.51784 .49889 Mdot
.35178 .5154 Mdot
.99415 .39701 Mdot
.6453 .40243 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.48621 .61219 Mdot
.45608 .59942 Mdot
.36091 .55922 Mdot
.08268 .44607 Mdot
.68593 .37283 Mdot
.50882 .50858 Mdot
.34495 .51675 Mdot
.98358 .39469 Mdot
.6468 .40989 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.5208 .00882 Mdot
.56618 .02805 Mdot
.708 .08765 Mdot
.08029 .23009 Mdot
.33719 .15877 Mdot
.39029 .03282 Mdot
.29155 .55701 Mdot
.96216 .41446 Mdot
.689 .44921 Mdot
.49792 .61715 Mdot
.49339 .61523 Mdot
.47894 .6091 Mdot
.43298 .58963 Mdot
.28944 .52932 Mdot
.91445 .38628 Mdot
.6617 .46182 Mdot
.61187 .58724 Mdot
.71636 .06458 Mdot
.05427 .20884 Mdot
.31234 .1595 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44669 .59544 Mdot
.33164 .54693 Mdot
.00859 .41838 Mdot
.67266 .41042 Mdot
.54783 .54088 Mdot
.49366 .58456 Mdot
.42998 .57868 Mdot
.26464 .51584 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48463 .61152 Mdot
.45106 .59729 Mdot
.34525 .55264 Mdot
.04219 .43073 Mdot
.67659 .39208 Mdot
.52476 .5242 Mdot
.40994 .54707 Mdot
.16711 .46796 Mdot
.7172 .33998 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50923 .00391 Mdot
.5294 .01247 Mdot
.59343 .03957 Mdot
.78969 .1213 Mdot
.2173 .26428 Mdot
.41119 .11983 Mdot
.47869 .04171 Mdot
.51431 .02201 Mdot
.57136 .03526 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48801 .61295 Mdot
.46182 .60185 Mdot
.37891 .56679 Mdot
.13139 .46506 Mdot
.70842 .35662 Mdot
.51608 .49916 Mdot
.34782 .51404 Mdot
.98453 .3935 Mdot
.6444 .40783 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47475 .60733 Mdot
.41972 .58402 Mdot
.24932 .51272 Mdot
.84018 .36517 Mdot
.63247 .48966 Mdot
.60129 .59877 Mdot
.71201 .06843 Mdot
.05469 .21179 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00131 Mdot
.50987 .00418 Mdot
.53142 .01332 Mdot
.59981 .04226 Mdot
.80828 .12885 Mdot
.23966 .26661 Mdot
.43281 .11937 Mdot
.52815 .05892 Mdot
.66549 .08488 Mdot
.00868 .21211 Mdot
.49959 .61786 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48672 .6124 Mdot
.45772 .60011 Mdot
.36605 .56138 Mdot
.09635 .45135 Mdot
.69079 .36738 Mdot
.50763 .50484 Mdot
.33592 .51191 Mdot
.95944 .38535 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50619 .00263 Mdot
.51973 .00837 Mdot
.56278 .02661 Mdot
.69758 .08331 Mdot
.05827 .22292 Mdot
.3335 .1701 Mdot
.4021 .0424 Mdot
.33295 .57529 Mdot
.05676 .44734 Mdot
.69722 .39583 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.51808 .00767 Mdot
.55755 .02439 Mdot
.68148 .07659 Mdot
.02235 .21067 Mdot
.32981 .19002 Mdot
.42792 .06064 Mdot
.42158 .61412 Mdot
.30232 .54433 Mdot
.49948 .61781 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44666 .59543 Mdot
.33157 .5469 Mdot
.00841 .41831 Mdot
.67264 .41052 Mdot
.54796 .54098 Mdot
.49414 .58477 Mdot
.43152 .57934 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.52379 .01009 Mdot
.57565 .03205 Mdot
.73677 .09958 Mdot
.1358 .24661 Mdot
.35496 .13545 Mdot
.38545 .01884 Mdot
.25857 .53962 Mdot
.8933 .39229 Mdot
.67636 .48396 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.5055 .00233 Mdot
.51753 .00743 Mdot
.5558 .02365 Mdot
.67605 .07432 Mdot
.00973 .20623 Mdot
.32882 .19721 Mdot
.43787 .06739 Mdot
.45605 .01124 Mdot
.40916 .58905 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48668 .61238 Mdot
.45758 .60005 Mdot
.3656 .56119 Mdot
.09513 .45088 Mdot
.69031 .36785 Mdot
.50764 .50514 Mdot
.33643 .51222 Mdot
.96083 .3859 Mdot
.64339 .42185 Mdot
.49956 .61785 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48592 .61206 Mdot
.45516 .59902 Mdot
.35802 .558 Mdot
.07505 .44315 Mdot
.68363 .37612 Mdot
.51049 .51103 Mdot
.35308 .52075 Mdot
.00527 .40308 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48029 .60967 Mdot
.43727 .59145 Mdot
.30256 .53478 Mdot
.94203 .39521 Mdot
.66654 .44777 Mdot
.59771 .57549 Mdot
.66639 .04245 Mdot
.94163 .1701 Mdot
.30247 .22301 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.48331 .61096 Mdot
.44687 .59551 Mdot
.33221 .54717 Mdot
.00996 .41887 Mdot
.67278 .40965 Mdot
.54678 .54016 Mdot
.48995 .58291 Mdot
.41806 .5736 Mdot
.22862 .50095 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50457 .00194 Mdot
.51457 .00618 Mdot
.54638 .01966 Mdot
.64678 .06205 Mdot
.93745 .17964 Mdot
.31955 .23615 Mdot
.48534 .10247 Mdot
.62917 .08889 Mdot
.94617 .19592 Mdot
.34239 .24488 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51854 .00786 Mdot
.55901 .02501 Mdot
.68598 .07847 Mdot
.03263 .21424 Mdot
.33068 .1842 Mdot
.42001 .05521 Mdot
.39435 .60217 Mdot
.22159 .51126 Mdot
.8139 .36606 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52052 .0087 Mdot
.5653 .02767 Mdot
.70531 .08653 Mdot
.07469 .22829 Mdot
.33611 .16156 Mdot
.39289 .03509 Mdot
.30085 .56115 Mdot
.98216 .42107 Mdot
.49843 .61737 Mdot
.49501 .61592 Mdot
.4841 .61129 Mdot
.44937 .59657 Mdot
.33998 .55043 Mdot
.029 .42584 Mdot
.67476 .3991 Mdot
.53307 .53046 Mdot
.44063 .5609 Mdot
.26119 .50713 Mdot
.84361 .35995 Mdot
.49998 .61802 Mdot
.49993 .618 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49228 .61476 Mdot
.4754 .6076 Mdot
.42175 .58488 Mdot
.25542 .51523 Mdot
.85048 .36777 Mdot
.63826 .48687 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .0024 Mdot
.51805 .00765 Mdot
.55746 .02435 Mdot
.68118 .07647 Mdot
.02167 .21043 Mdot
.32975 .19041 Mdot
.42846 .061 Mdot
.42342 .61492 Mdot
.30789 .54663 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50386 .00164 Mdot
.51231 .00522 Mdot
.5392 .01662 Mdot
.62429 .05259 Mdot
.87744 .15645 Mdot
.29679 .25917 Mdot
.48765 .11796 Mdot
.66001 .10652 Mdot
.03394 .2311 Mdot
.35735 .19988 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.4785 .60892 Mdot
.43159 .58904 Mdot
.28519 .52756 Mdot
.90587 .3836 Mdot
.65966 .46586 Mdot
.61474 .59027 Mdot
.72739 .06963 Mdot
.07638 .21568 Mdot
.31514 .14756 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48984 .61373 Mdot
.46764 .60431 Mdot
.39724 .57452 Mdot
.18318 .48574 Mdot
.75112 .35101 Mdot
.55779 .49855 Mdot
.44926 .55096 Mdot
.2659 .50471 Mdot
.845 .3579 Mdot
.49945 .6178 Mdot
.49823 .61728 Mdot
.49437 .61565 Mdot
.48206 .61043 Mdot
.44289 .59383 Mdot
.31988 .54201 Mdot
.98078 .40846 Mdot
.67044 .42623 Mdot
.56962 .55572 Mdot
.56993 .00019 Mdot
.6718 .06296 Mdot
.49768 .61705 Mdot
.4926 .61489 Mdot
.47641 .60803 Mdot
.42498 .58625 Mdot
.26513 .51924 Mdot
.86763 .37236 Mdot
.64657 .48141 Mdot
.61558 .59888 Mdot
.74313 .07883 Mdot
.10918 .22623 Mdot
.32401 .13277 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51715 .00727 Mdot
.55459 .02314 Mdot
.67233 .07277 Mdot
.00093 .20309 Mdot
.32814 .20222 Mdot
.44481 .07211 Mdot
.48033 .02196 Mdot
.48643 .00377 Mdot
.47221 .60924 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52443 .01036 Mdot
.57769 .03292 Mdot
.74293 .10212 Mdot
.14665 .24952 Mdot
.36024 .132 Mdot
.3901 .01846 Mdot
.2679 .54251 Mdot
.90847 .3959 Mdot
.6789 .47615 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51117 .00474 Mdot
.53558 .01509 Mdot
.61292 .0478 Mdot
.84577 .14391 Mdot
.27542 .26554 Mdot
.46938 .11987 Mdot
.6177 .09166 Mdot
.92691 .1911 Mdot
.34194 .25651 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50724 .00307 Mdot
.52308 .00979 Mdot
.57341 .03111 Mdot
.72999 .09677 Mdot
.12342 .24315 Mdot
.34973 .13986 Mdot
.38265 .02035 Mdot
.25506 .53918 Mdot
.88887 .39171 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50756 .00321 Mdot
.52409 .01021 Mdot
.5766 .03246 Mdot
.73964 .10076 Mdot
.14091 .248 Mdot
.35736 .13378 Mdot
.38737 .01855 Mdot
.26219 .54067 Mdot
.89898 .39356 Mdot
.67733 .48104 Mdot
.49922 .6177 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.4748 .60735 Mdot
.41988 .58409 Mdot
.24979 .51291 Mdot
.84097 .36537 Mdot
.63293 .48946 Mdot
.6019 .59886 Mdot
.7135 .06897 Mdot
.05758 .21265 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48976 .61369 Mdot
.46739 .60421 Mdot
.39644 .57419 Mdot
.1809 .48482 Mdot
.74877 .35096 Mdot
.55537 .4985 Mdot
.44334 .5488 Mdot
.24813 .49738 Mdot
.81419 .34985 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53224 .01367 Mdot
.6024 .04336 Mdot
.81578 .13188 Mdot
.24779 .267 Mdot
.44109 .11947 Mdot
.54803 .06609 Mdot
.72593 .10995 Mdot
.13984 .25581 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47426 .60712 Mdot
.41816 .58336 Mdot
.24463 .51079 Mdot
.83251 .36333 Mdot
.62775 .49148 Mdot
.5947 .5976 Mdot
.69545 .06227 Mdot
.02105 .20123 Mdot
.49791 .61715 Mdot
.49333 .6152 Mdot
.47875 .60902 Mdot
.43238 .58938 Mdot
.2876 .52856 Mdot
.91073 .38511 Mdot
.66085 .4636 Mdot
.61322 .5886 Mdot
.72144 .06689 Mdot
.06457 .21206 Mdot
.31348 .15383 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50654 .00278 Mdot
.52085 .00884 Mdot
.56634 .02811 Mdot
.70847 .08784 Mdot
.08126 .23039 Mdot
.33738 .1583 Mdot
.38987 .03244 Mdot
.29002 .55633 Mdot
.95896 .41342 Mdot
.68877 .45105 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53217 .01364 Mdot
.60216 .04326 Mdot
.8151 .1316 Mdot
.24707 .26697 Mdot
.44035 .11945 Mdot
.54623 .06544 Mdot
.72049 .1077 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48194 .61038 Mdot
.44253 .59367 Mdot
.31876 .54154 Mdot
.9782 .40756 Mdot
.67024 .4277 Mdot
.57165 .5571 Mdot
.57694 .00327 Mdot
.69318 .07185 Mdot
.03312 .21009 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49085 .61415 Mdot
.47084 .60567 Mdot
.40734 .57879 Mdot
.21257 .49766 Mdot
.78564 .35418 Mdot
.59148 .49804 Mdot
.52711 .57825 Mdot
.50321 .60326 Mdot
.48412 .60624 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47564 .60771 Mdot
.42254 .58521 Mdot
.25778 .51621 Mdot
.85458 .36884 Mdot
.6404 .48566 Mdot
.61054 .59958 Mdot
.73348 .07598 Mdot
.09386 .22273 Mdot
.32147 .14067 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50734 .00311 Mdot
.52339 .00992 Mdot
.57441 .03153 Mdot
.73301 .09802 Mdot
.12899 .24473 Mdot
.35198 .13782 Mdot
.38359 .01954 Mdot
.25575 .53902 Mdot
.88933 .39157 Mdot
.67586 .4861 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52451 .01039 Mdot
.57794 .03302 Mdot
.74368 .10243 Mdot
.14796 .24986 Mdot
.36091 .13161 Mdot
.3908 .01847 Mdot
.26944 .54303 Mdot
.91113 .39658 Mdot
.6793 .47476 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51775 .00753 Mdot
.5565 .02395 Mdot
.67825 .07524 Mdot
.01486 .20804 Mdot
.32922 .19428 Mdot
.43381 .06464 Mdot
.44195 .00503 Mdot
.36494 .57044 Mdot
.1088 .45973 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.4893 .6135 Mdot
.46593 .60359 Mdot
.39184 .57224 Mdot
.1677 .47951 Mdot
.73605 .35126 Mdot
.54221 .49824 Mdot
.41095 .53691 Mdot
.15297 .45859 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48442 .61143 Mdot
.4504 .59701 Mdot
.34317 .55177 Mdot
.03697 .42879 Mdot
.67581 .39482 Mdot
.52791 .52663 Mdot
.42166 .55237 Mdot
.20258 .48264 Mdot
.75529 .34159 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50607 .00258 Mdot
.51935 .0082 Mdot
.56158 .0261 Mdot
.69388 .08177 Mdot
.05023 .22024 Mdot
.33248 .17444 Mdot
.40734 .04627 Mdot
.35094 .58318 Mdot
.10223 .46432 Mdot
.71051 .37593 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51263 .00535 Mdot
.54021 .01705 Mdot
.62746 .05393 Mdot
.88612 .15986 Mdot
.30139 .25665 Mdot
.49026 .11673 Mdot
.66454 .10771 Mdot
.4976 .61701 Mdot
.49234 .61479 Mdot
.47561 .60769 Mdot
.42243 .58517 Mdot
.25746 .51607 Mdot
.85401 .36869 Mdot
.64011 .48583 Mdot
.61025 .59958 Mdot
.73286 .07578 Mdot
.09281 .22246 Mdot
.32131 .14122 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48134 .61012 Mdot
.44062 .59287 Mdot
.31289 .53909 Mdot
.96481 .40291 Mdot
.66909 .43527 Mdot
.58191 .56415 Mdot
.61224 .01875 Mdot
.79733 .11439 Mdot
.21067 .25546 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47553 .60766 Mdot
.42219 .58507 Mdot
.25674 .51578 Mdot
.85277 .36837 Mdot
.63947 .4862 Mdot
.6096 .59957 Mdot
.73143 .0753 Mdot
.09038 .22184 Mdot
.32093 .14249 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00147 Mdot
.51108 .0047 Mdot
.53529 .01496 Mdot
.61201 .04741 Mdot
.84321 .14289 Mdot
.27336 .26585 Mdot
.46734 .11989 Mdot
.61267 .08982 Mdot
.91324 .18576 Mdot
.49912 .61766 Mdot
.49721 .61685 Mdot
.4911 .61426 Mdot
.47166 .60602 Mdot
.40993 .57988 Mdot
.22019 .50077 Mdot
.79589 .3558 Mdot
.60047 .49726 Mdot
.54595 .58434 Mdot
.5594 .00831 Mdot
.65988 .0621 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00032 Mdot
.50244 .00104 Mdot
.50778 .0033 Mdot
.52478 .01051 Mdot
.5788 .03339 Mdot
.74625 .10349 Mdot
.15237 .25099 Mdot
.36328 .13035 Mdot
.39342 .01863 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47811 .60875 Mdot
.43036 .58852 Mdot
.28146 .52601 Mdot
.89848 .38134 Mdot
.65766 .4692 Mdot
.6165 .5926 Mdot
.7349 .07318 Mdot
.09096 .22006 Mdot
.31789 .14025 Mdot
.49849 .6174 Mdot
.4952 .616 Mdot
.48472 .61155 Mdot
.45135 .59741 Mdot
.34613 .55301 Mdot
.04443 .43157 Mdot
.67694 .39092 Mdot
.52348 .52319 Mdot
.4051 .54487 Mdot
.15265 .46202 Mdot
.70476 .34122 Mdot
.4975 .61698 Mdot
.49205 .61466 Mdot
.47468 .6073 Mdot
.41948 .58392 Mdot
.24859 .51242 Mdot
.83897 .36488 Mdot
.63175 .48996 Mdot
.60033 .59862 Mdot
.70965 .06756 Mdot
.05007 .21039 Mdot
.31662 .16474 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50543 .0023 Mdot
.51731 .00734 Mdot
.5551 .02336 Mdot
.6739 .07342 Mdot
.00467 .20442 Mdot
.32843 .2001 Mdot
.44187 .07011 Mdot
.47003 .0174 Mdot
.45349 .60781 Mdot
.36818 .56531 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54094 .01736 Mdot
.62977 .0549 Mdot
.89239 .16231 Mdot
.30441 .25464 Mdot
.4915 .11563 Mdot
.66584 .10775 Mdot
.04632 .23515 Mdot
.35829 .19281 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47931 .60926 Mdot
.43416 .59013 Mdot
.29305 .53082 Mdot
.92188 .38864 Mdot
.66324 .45819 Mdot
.60874 .58435 Mdot
.70495 .05946 Mdot
.0304 .20114 Mdot
.31052 .17313 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.48049 .60976 Mdot
.43792 .59172 Mdot
.30457 .53562 Mdot
.94638 .39666 Mdot
.66711 .44543 Mdot
.59492 .57342 Mdot
.6568 .03825 Mdot
.91765 .16121 Mdot
.29658 .23419 Mdot
.49877 .61751 Mdot
.49607 .61637 Mdot
.48747 .61272 Mdot
.46011 .60112 Mdot
.37353 .56452 Mdot
.11658 .45923 Mdot
.69999 .36057 Mdot
.51044 .50089 Mdot
.33653 .51055 Mdot
.95831 .38428 Mdot
.64191 .42249 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50133 .00057 Mdot
.50425 .0018 Mdot
.51353 .00574 Mdot
.54309 .01827 Mdot
.63649 .05773 Mdot
.91045 .16931 Mdot
.31175 .24802 Mdot
.49207 .11144 Mdot
.66051 .1041 Mdot
.03091 .22892 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51513 .00642 Mdot
.54817 .02042 Mdot
.65236 .06439 Mdot
.95174 .18503 Mdot
.32241 .22909 Mdot
.47863 .09655 Mdot
.60289 .0768 Mdot
.87097 .16568 Mdot
.31208 .27262 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47818 .60878 Mdot
.4306 .58862 Mdot
.28217 .5263 Mdot
.89988 .38176 Mdot
.65805 .46858 Mdot
.61622 .59218 Mdot
.73363 .07256 Mdot
.08852 .21933 Mdot
.31737 .14144 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49074 .61411 Mdot
.47052 .60553 Mdot
.40633 .57836 Mdot
.20959 .49645 Mdot
.78178 .35363 Mdot
.58796 .49824 Mdot
.51946 .5757 Mdot
.48007 .59369 Mdot
.41086 .57526 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.5064 .00271 Mdot
.5204 .00865 Mdot
.5649 .02751 Mdot
.70408 .08602 Mdot
.07212 .22746 Mdot
.33565 .16287 Mdot
.39418 .03618 Mdot
.30542 .56318 Mdot
.99226 .42449 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52404 .01019 Mdot
.57646 .0324 Mdot
.7392 .10058 Mdot
.14013 .24779 Mdot
.35699 .13402 Mdot
.38705 .01858 Mdot
.26155 .54047 Mdot
.89796 .39332 Mdot
.67715 .48157 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50821 .00348 Mdot
.52615 .01109 Mdot
.58313 .03522 Mdot
.75922 .10883 Mdot
.17364 .25613 Mdot
.37628 .12524 Mdot
.41148 .02175 Mdot
.32064 .56189 Mdot
.0142 .42864 Mdot
.498 .61718 Mdot
.49361 .61533 Mdot
.47966 .60941 Mdot
.43527 .5906 Mdot
.29645 .53224 Mdot
.92899 .39093 Mdot
.66455 .4546 Mdot
.60524 .58138 Mdot
.69254 .05395 Mdot
.00318 .19199 Mdot
.30905 .18904 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51372 .00582 Mdot
.54369 .01852 Mdot
.63837 .05852 Mdot
.91543 .17123 Mdot
.31346 .246 Mdot
.49148 .11003 Mdot
.65674 .10213 Mdot
.0209 .22506 Mdot
.3538 .20574 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49613 .61639 Mdot
.48768 .61281 Mdot
.46075 .60139 Mdot
.37555 .56538 Mdot
.12213 .46141 Mdot
.70297 .35898 Mdot
.51219 .50013 Mdot
.33969 .51142 Mdot
.96537 .38669 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50593 .00252 Mdot
.5189 .00802 Mdot
.56016 .0255 Mdot
.68954 .07996 Mdot
.04062 .21698 Mdot
.33143 .17973 Mdot
.41408 .05108 Mdot
.37403 .59328 Mdot
.16415 .48832 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00333 Mdot
.52498 .01059 Mdot
.57943 .03365 Mdot
.74814 .10427 Mdot
.15557 .25181 Mdot
.36507 .12948 Mdot
.39556 .01884 Mdot
.28039 .54686 Mdot
.93084 .40199 Mdot
.68179 .46411 Mdot
.50036 .00015 Mdot
.50113 .00048 Mdot
.50362 .00153 Mdot
.51152 .00489 Mdot
.53669 .01556 Mdot
.61642 .04927 Mdot
.85561 .14783 Mdot
.28287 .26406 Mdot
.47648 .11966 Mdot
.63494 .09793 Mdot
.97241 .20857 Mdot
.35106 .23402 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50606 .00257 Mdot
.51932 .00819 Mdot
.56149 .02606 Mdot
.69361 .08166 Mdot
.04963 .22004 Mdot
.33241 .17476 Mdot
.40775 .04656 Mdot
.35232 .58378 Mdot
.10582 .46569 Mdot
.71203 .37466 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48816 .61301 Mdot
.4623 .60205 Mdot
.38041 .56743 Mdot
.13556 .4667 Mdot
.71107 .35569 Mdot
.51822 .49884 Mdot
.35263 .51569 Mdot
.99624 .39777 Mdot
.64549 .40126 Mdot
.49976 .61793 Mdot
.49923 .61771 Mdot
.49755 .61699 Mdot
.49219 .61472 Mdot
.47511 .60748 Mdot
.42087 .58451 Mdot
.25275 .51413 Mdot
.84593 .36661 Mdot
.63578 .48815 Mdot
.60547 .5993 Mdot
.72203 .07204 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52148 .00911 Mdot
.56835 .02897 Mdot
.71463 .0904 Mdot
.09377 .23432 Mdot
.34025 .15233 Mdot
.38537 .02788 Mdot
.27302 .5486 Mdot
.92443 .40259 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52528 .01072 Mdot
.58038 .03406 Mdot
.75099 .10544 Mdot
.16033 .25299 Mdot
.36784 .12824 Mdot
.39911 .01933 Mdot
.28898 .54997 Mdot
.94724 .40683 Mdot
.4987 .61748 Mdot
.49586 .61628 Mdot
.48682 .61245 Mdot
.45803 .60024 Mdot
.36702 .56179 Mdot
.09896 .45236 Mdot
.69184 .36642 Mdot
.50768 .50422 Mdot
.33505 .51134 Mdot
.95697 .38437 Mdot
.64265 .42377 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50691 .00293 Mdot
.522 .00933 Mdot
.56999 .02966 Mdot
.7196 .09247 Mdot
.1036 .23733 Mdot
.34295 .14792 Mdot
.38313 .02483 Mdot
.26334 .544 Mdot
.90565 .39697 Mdot
.50064 .00027 Mdot
.50202 .00086 Mdot
.50645 .00274 Mdot
.52055 .00872 Mdot
.5654 .02772 Mdot
.7056 .08665 Mdot
.07531 .22849 Mdot
.33622 .16125 Mdot
.39258 .03483 Mdot
.29978 .56068 Mdot
.97982 .42029 Mdot
.69005 .43894 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50625 .00265 Mdot
.5199 .00844 Mdot
.56334 .02684 Mdot
.69928 .08402 Mdot
.06194 .22414 Mdot
.33402 .16815 Mdot
.39986 .04069 Mdot
.3252 .57189 Mdot
.498 .61718 Mdot
.49362 .61533 Mdot
.47966 .60941 Mdot
.43529 .59061 Mdot
.2965 .53226 Mdot
.9291 .39097 Mdot
.66457 .45454 Mdot
.60518 .58133 Mdot
.69234 .05387 Mdot
.00273 .19183 Mdot
.30903 .1893 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49276 .61497 Mdot
.47695 .60826 Mdot
.42667 .58696 Mdot
.27026 .52137 Mdot
.87705 .37501 Mdot
.65046 .47799 Mdot
.61741 .59761 Mdot
.74493 .07881 Mdot
.11106 .22628 Mdot
.49898 .6176 Mdot
.49675 .61665 Mdot
.48964 .61364 Mdot
.467 .60404 Mdot
.39521 .57367 Mdot
.17736 .48339 Mdot
.74521 .35095 Mdot
.55169 .49843 Mdot
.43434 .54551 Mdot
.22127 .48635 Mdot
.77335 .3412 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.5135 .00572 Mdot
.54299 .01823 Mdot
.63618 .0576 Mdot
.90962 .16899 Mdot
.31146 .24835 Mdot
.49214 .11167 Mdot
.66104 .10439 Mdot
.03235 .22948 Mdot
.35546 .1997 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.47482 .60736 Mdot
.41992 .58411 Mdot
.2499 .51296 Mdot
.84115 .36541 Mdot
.63304 .48941 Mdot
.60205 .59888 Mdot
.71385 .0691 Mdot
.05825 .21285 Mdot
.31721 .16005 Mdot
.49757 .617 Mdot
.49226 .61475 Mdot
.47535 .60758 Mdot
.42162 .58483 Mdot
.25503 .51507 Mdot
.84981 .3676 Mdot
.6379 .48707 Mdot
.60792 .5995 Mdot
.7277 .07403 Mdot
.08386 .22012 Mdot
.31998 .14593 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.50991 .0042 Mdot
.53155 .01338 Mdot
.60022 .04244 Mdot
.80946 .12932 Mdot
.24097 .26669 Mdot
.43414 .11938 Mdot
.5313 .06005 Mdot
.67512 .08888 Mdot
.03172 .22039 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00215 Mdot
.51612 .00684 Mdot
.55133 .02176 Mdot
.66221 .06853 Mdot
.97641 .19419 Mdot
.32587 .21597 Mdot
.4632 .08488 Mdot
.54583 .05107 Mdot
.69627 .09297 Mdot
.07196 .23219 Mdot
.49934 .61775 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47856 .60894 Mdot
.4318 .58913 Mdot
.28584 .52783 Mdot
.90718 .38401 Mdot
.65999 .46526 Mdot
.61435 .58983 Mdot
.72587 .06892 Mdot
.07337 .21477 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52236 .00948 Mdot
.57113 .03014 Mdot
.72308 .09391 Mdot
.11035 .23935 Mdot
.34504 .14505 Mdot
.38233 .02304 Mdot
.25875 .54166 Mdot
.89679 .39434 Mdot
.67903 .48345 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50717 .00304 Mdot
.52285 .00969 Mdot
.57269 .0308 Mdot
.7278 .09587 Mdot
.11934 .24198 Mdot
.34817 .14143 Mdot
.38227 .02107 Mdot
.25544 .53965 Mdot
.89002 .39219 Mdot
.67675 .48623 Mdot
.49934 .61776 Mdot
.4979 .61715 Mdot
.49332 .6152 Mdot
.47873 .60902 Mdot
.43234 .58936 Mdot
.28747 .5285 Mdot
.91046 .38503 Mdot
.66079 .46373 Mdot
.61331 .58869 Mdot
.72179 .06705 Mdot
.06527 .21228 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.5044 .00186 Mdot
.51401 .00594 Mdot
.5446 .01891 Mdot
.64121 .05971 Mdot
.92293 .17411 Mdot
.31579 .2428 Mdot
.49002 .10768 Mdot
.64928 .09843 Mdot
.00103 .2174 Mdot
.35124 .21644 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52404 .0102 Mdot
.57647 .0324 Mdot
.73924 .1006 Mdot
.14019 .2478 Mdot
.35702 .13401 Mdot
.38707 .01858 Mdot
.2616 .54049 Mdot
.89803 .39334 Mdot
.67716 .48153 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48466 .61153 Mdot
.45118 .59734 Mdot
.34559 .55278 Mdot
.04306 .43106 Mdot
.67672 .39162 Mdot
.52426 .5238 Mdot
.40803 .5462 Mdot
.16141 .46561 Mdot
.71209 .34034 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.5068 .00289 Mdot
.52168 .00919 Mdot
.56896 .02922 Mdot
.71648 .09117 Mdot
.09746 .23546 Mdot
.34121 .15065 Mdot
.38438 .02668 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49918 .61768 Mdot
.49737 .61692 Mdot
.49163 .61448 Mdot
.47334 .60673 Mdot
.41525 .58213 Mdot
.23594 .50722 Mdot
.81884 .36025 Mdot
.61848 .49421 Mdot
.57988 .59418 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49983 .61796 Mdot
.49946 .61781 Mdot
.49828 .61731 Mdot
.49453 .61572 Mdot
.48259 .61065 Mdot
.44457 .59454 Mdot
.32509 .54419 Mdot
.99296 .41277 Mdot
.67138 .41929 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54655 .01973 Mdot
.64732 .06228 Mdot
.93884 .18017 Mdot
.31986 .23548 Mdot
.48477 .10192 Mdot
.62688 .08783 Mdot
.93978 .19338 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00823 Mdot
.56174 .02617 Mdot
.6944 .08198 Mdot
.05136 .22062 Mdot
.33261 .17382 Mdot
.40658 .04571 Mdot
.34833 .58203 Mdot
.09547 .46176 Mdot
.70784 .37847 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48569 .61196 Mdot
.45442 .59871 Mdot
.35573 .55704 Mdot
.06907 .44087 Mdot
.68203 .37883 Mdot
.51228 .51312 Mdot
.36092 .52449 Mdot
.0265 .41135 Mdot
.65251 .3869 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.51959 .00831 Mdot
.56235 .02643 Mdot
.69626 .08276 Mdot
.05542 .22197 Mdot
.33312 .17163 Mdot
.40392 .04375 Mdot
.33918 .57803 Mdot
.07222 .45304 Mdot
.70061 .38837 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00142 Mdot
.5107 .00454 Mdot
.53409 .01445 Mdot
.60822 .04581 Mdot
.83244 .13858 Mdot
.26408 .26677 Mdot
.45793 .1198 Mdot
.58939 .08125 Mdot
.84801 .15983 Mdot
.3015 .28027 Mdot
.49909 .61765 Mdot
.4971 .61681 Mdot
.49077 .61412 Mdot
.47061 .60557 Mdot
.40662 .57848 Mdot
.21045 .4968 Mdot
.78289 .35378 Mdot
.58898 .49819 Mdot
.52168 .57645 Mdot
.48682 .59649 Mdot
.43221 .58428 Mdot
.49797 .61717 Mdot
.49352 .61529 Mdot
.47936 .60928 Mdot
.43432 .5902 Mdot
.29353 .53102 Mdot
.92288 .38896 Mdot
.66344 .45769 Mdot
.60828 .58394 Mdot
.7033 .05872 Mdot
.02684 .19996 Mdot
.31031 .1752 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51668 .00707 Mdot
.55311 .02251 Mdot
.66773 .07084 Mdot
.98988 .1991 Mdot
.3272 .20848 Mdot
.49945 .6178 Mdot
.49824 .61729 Mdot
.49439 .61566 Mdot
.48214 .61046 Mdot
.44316 .59394 Mdot
.32072 .54236 Mdot
.98272 .40914 Mdot
.67059 .42513 Mdot
.5681 .55469 Mdot
.56466 .61591 Mdot
.65556 .05618 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51256 .00533 Mdot
.54 .01696 Mdot
.62681 .05365 Mdot
.88432 .15916 Mdot
.30048 .2572 Mdot
.48981 .11701 Mdot
.66386 .10757 Mdot
.04253 .23403 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47788 .60865 Mdot
.42963 .58821 Mdot
.27922 .52508 Mdot
.89409 .38001 Mdot
.65636 .47111 Mdot
.61722 .59384 Mdot
.73843 .07491 Mdot
.09775 .22207 Mdot
.31949 .13704 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48115 .61004 Mdot
.44001 .59261 Mdot
.311 .5383 Mdot
.96057 .40146 Mdot
.66869 .43764 Mdot
.58505 .56634 Mdot
.62299 .02345 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00149 Mdot
.51116 .00473 Mdot
.53554 .01507 Mdot
.61278 .04774 Mdot
.84538 .14376 Mdot
.27511 .26559 Mdot
.46908 .11988 Mdot
.61695 .09139 Mdot
.92488 .19031 Mdot
.34135 .2574 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50455 .00193 Mdot
.51449 .00614 Mdot
.54612 .01955 Mdot
.64598 .06171 Mdot
.93537 .17885 Mdot
.31906 .23714 Mdot
.48615 .10327 Mdot
.63249 .09044 Mdot
.95538 .19956 Mdot
.34433 .24038 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51127 .00478 Mdot
.5359 .01522 Mdot
.61393 .04822 Mdot
.84863 .14505 Mdot
.27767 .26516 Mdot
.47157 .11984 Mdot
.62306 .09362 Mdot
.94128 .19667 Mdot
.3456 .24988 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.5078 .00331 Mdot
.52486 .01054 Mdot
.57906 .03349 Mdot
.74702 .10381 Mdot
.15367 .25132 Mdot
.364 .12999 Mdot
.39426 .0187 Mdot
.27734 .54577 Mdot
.50046 .0002 Mdot
.50147 .00063 Mdot
.5047 .00199 Mdot
.51497 .00635 Mdot
.54767 .02021 Mdot
.6508 .06374 Mdot
.94779 .18354 Mdot
.32169 .23109 Mdot
.48068 .09826 Mdot
.61075 .08039 Mdot
.89385 .17497 Mdot
.32463 .26624 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48245 .61059 Mdot
.44415 .59436 Mdot
.32379 .54364 Mdot
.98989 .41167 Mdot
.67115 .42104 Mdot
.56243 .55084 Mdot
.54498 .60725 Mdot
.59409 .03036 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50751 .00319 Mdot
.52393 .01015 Mdot
.57611 .03225 Mdot
.73816 .10015 Mdot
.13828 .24729 Mdot
.35611 .13463 Mdot
.38633 .01867 Mdot
.26016 .54006 Mdot
.89575 .39282 Mdot
.67677 .4827 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50507 .00215 Mdot
.51615 .00685 Mdot
.55142 .0218 Mdot
.6625 .06865 Mdot
.97712 .19445 Mdot
.32595 .21558 Mdot
.4627 .08452 Mdot
.54402 .05026 Mdot
.69054 .09055 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50364 .00154 Mdot
.5116 .00492 Mdot
.53693 .01566 Mdot
.61717 .04959 Mdot
.8577 .14866 Mdot
.28436 .26369 Mdot
.47783 .11957 Mdot
.63815 .09908 Mdot
.98064 .21167 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.52049 .00869 Mdot
.5652 .02763 Mdot
.70499 .08639 Mdot
.07402 .22808 Mdot
.33599 .1619 Mdot
.39322 .03537 Mdot
.30203 .56168 Mdot
.98475 .42194 Mdot
.69031 .43606 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49392 .61545 Mdot
.48062 .60982 Mdot
.43833 .5919 Mdot
.30583 .53614 Mdot
.94913 .39758 Mdot
.66745 .44394 Mdot
.59309 .57208 Mdot
.65054 .0355 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47857 .60895 Mdot
.43183 .58914 Mdot
.28592 .52786 Mdot
.90734 .38406 Mdot
.66003 .46519 Mdot
.6143 .58978 Mdot
.72567 .06883 Mdot
.07299 .21465 Mdot
.31462 .14933 Mdot
.5008 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.52571 .0109 Mdot
.58176 .03464 Mdot
.75512 .10714 Mdot
.1671 .25461 Mdot
.372 .12664 Mdot
.40494 .02036 Mdot
.30362 .55541 Mdot
.97698 .41616 Mdot
.68475 .43743 Mdot
.49748 .61697 Mdot
.49197 .61463 Mdot
.47442 .60719 Mdot
.41868 .58358 Mdot
.24619 .51143 Mdot
.83503 .36393 Mdot
.62934 .49091 Mdot
.597 .59804 Mdot
.7013 .06447 Mdot
.03326 .20516 Mdot
.31569 .17455 Mdot
.49859 .61744 Mdot
.49552 .61614 Mdot
.48574 .61199 Mdot
.45458 .59878 Mdot
.35623 .55725 Mdot
.07037 .44136 Mdot
.68236 .37823 Mdot
.51185 .51265 Mdot
.35911 .52363 Mdot
.02156 .40942 Mdot
.65177 .38949 Mdot
.49859 .61743 Mdot
.49549 .61612 Mdot
.48565 .61195 Mdot
.45429 .59866 Mdot
.35532 .55686 Mdot
.068 .44046 Mdot
.68176 .37932 Mdot
.51263 .51351 Mdot
.36244 .52521 Mdot
.03066 .41298 Mdot
.65317 .38473 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48835 .61309 Mdot
.46289 .6023 Mdot
.38227 .56821 Mdot
.14073 .46875 Mdot
.71455 .35464 Mdot
.5212 .49854 Mdot
.35955 .51813 Mdot
.01351 .40417 Mdot
.64724 .39166 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50324 .00137 Mdot
.51031 .00437 Mdot
.53285 .01393 Mdot
.60431 .04417 Mdot
.82128 .13409 Mdot
.25344 .26709 Mdot
.44691 .11958 Mdot
.56223 .07127 Mdot
.76854 .1275 Mdot
.21196 .27405 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.47971 .60943 Mdot
.43545 .59068 Mdot
.29699 .53246 Mdot
.93013 .3913 Mdot
.66474 .45401 Mdot
.60464 .58089 Mdot
.69042 .05302 Mdot
.99841 .19035 Mdot
.30878 .19182 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51215 .00515 Mdot
.5387 .01641 Mdot
.62272 .05193 Mdot
.87312 .15476 Mdot
.29431 .26031 Mdot
.48596 .11845 Mdot
.65658 .10545 Mdot
.02598 .2283 Mdot
.35658 .20432 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50647 .00274 Mdot
.52062 .00874 Mdot
.56561 .02781 Mdot
.70625 .08692 Mdot
.07666 .22893 Mdot
.33648 .16057 Mdot
.39194 .03428 Mdot
.29748 .55965 Mdot
.97482 .41862 Mdot
.68978 .44187 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.4797 .60943 Mdot
.43542 .59066 Mdot
.2969 .53243 Mdot
.92994 .39124 Mdot
.66471 .45411 Mdot
.60474 .58097 Mdot
.69078 .05317 Mdot
.99921 .19062 Mdot
.30883 .19136 Mdot
.49755 .617 Mdot
.49221 .61473 Mdot
.47517 .60751 Mdot
.42105 .58458 Mdot
.25329 .51435 Mdot
.84685 .36684 Mdot
.63629 .4879 Mdot
.60608 .59936 Mdot
.72346 .07255 Mdot
.07626 .21804 Mdot
.319 .15002 Mdot
.49875 .61751 Mdot
.49603 .61635 Mdot
.48734 .61267 Mdot
.45968 .60094 Mdot
.3722 .56396 Mdot
.11296 .45781 Mdot
.69815 .36167 Mdot
.50952 .50145 Mdot
.33516 .51028 Mdot
.95545 .38335 Mdot
.64169 .42412 Mdot
.49831 .61732 Mdot
.4946 .61574 Mdot
.4828 .61074 Mdot
.44524 .59482 Mdot
.32715 .54505 Mdot
.99782 .4145 Mdot
.67177 .41652 Mdot
.55617 .54659 Mdot
.5231 .59759 Mdot
.52455 .0009 Mdot
.56269 .02357 Mdot
.4992 .6177 Mdot
.49745 .61695 Mdot
.49189 .61459 Mdot
.47415 .60707 Mdot
.41782 .58322 Mdot
.24361 .51037 Mdot
.83086 .36294 Mdot
.62669 .49185 Mdot
.59311 .59728 Mdot
.69138 .06073 Mdot
.01236 .19838 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49056 .61403 Mdot
.46994 .60529 Mdot
.4045 .57759 Mdot
.20426 .49428 Mdot
.77507 .35278 Mdot
.58166 .4985 Mdot
.50545 .57093 Mdot
.4374 .57598 Mdot
.27786 .51943 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51156 .0049 Mdot
.53681 .01561 Mdot
.6168 .04943 Mdot
.85667 .14825 Mdot
.28363 .26388 Mdot
.47717 .11961 Mdot
.63659 .09853 Mdot
.97666 .21017 Mdot
.35161 .23173 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48245 .61059 Mdot
.44414 .59436 Mdot
.32375 .54363 Mdot
.9898 .41164 Mdot
.67114 .42109 Mdot
.5625 .55089 Mdot
.54523 .60736 Mdot
.59488 .03069 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50755 .0032 Mdot
.52406 .0102 Mdot
.57651 .03242 Mdot
.73937 .10065 Mdot
.14042 .24786 Mdot
.35713 .13393 Mdot
.38717 .01857 Mdot
.26179 .54054 Mdot
.89833 .3934 Mdot
.67721 .48138 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.4933 .61519 Mdot
.47865 .60898 Mdot
.43206 .58924 Mdot
.28663 .52816 Mdot
.90877 .3845 Mdot
.66038 .46452 Mdot
.61386 .58928 Mdot
.72394 .06803 Mdot
.06955 .2136 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47982 .60948 Mdot
.43579 .59082 Mdot
.29804 .5329 Mdot
.93236 .39203 Mdot
.66511 .45286 Mdot
.60343 .57991 Mdot
.68619 .05115 Mdot
.98876 .187 Mdot
.30817 .19741 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.5055 .00233 Mdot
.51752 .00743 Mdot
.55577 .02364 Mdot
.67596 .07429 Mdot
.00952 .20615 Mdot
.32881 .19733 Mdot
.43803 .0675 Mdot
.45663 .0115 Mdot
.41099 .58982 Mdot
.23867 .51154 Mdot
.49772 .61707 Mdot
.49275 .61496 Mdot
.4769 .60824 Mdot
.42654 .58691 Mdot
.26985 .52119 Mdot
.87628 .3748 Mdot
.65016 .47828 Mdot
.61731 .59774 Mdot
.74493 .07887 Mdot
.11117 .22634 Mdot
.32388 .13146 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50687 .00291 Mdot
.52187 .00927 Mdot
.56958 .02949 Mdot
.71838 .09196 Mdot
.10121 .2366 Mdot
.34225 .14897 Mdot
.38356 .02553 Mdot
.26538 .54499 Mdot
.90957 .39814 Mdot
.68223 .47753 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47459 .60726 Mdot
.41919 .5838 Mdot
.24772 .51206 Mdot
.83755 .36453 Mdot
.63089 .49031 Mdot
.59916 .59843 Mdot
.70674 .06649 Mdot
.04429 .20862 Mdot
.31626 .16808 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51847 .00783 Mdot
.55878 .02491 Mdot
.68528 .07818 Mdot
.03104 .21369 Mdot
.33053 .1851 Mdot
.42122 .05605 Mdot
.3985 .60399 Mdot
.23364 .51615 Mdot
.83131 .36938 Mdot
.49762 .61702 Mdot
.49241 .61481 Mdot
.47582 .60778 Mdot
.42309 .58545 Mdot
.25944 .51689 Mdot
.85748 .36961 Mdot
.64185 .48477 Mdot
.61192 .59954 Mdot
.73638 .07692 Mdot
.0987 .22392 Mdot
.32228 .13818 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50947 .00402 Mdot
.53016 .01279 Mdot
.59584 .04059 Mdot
.79673 .12416 Mdot
.22614 .26539 Mdot
.41949 .1195 Mdot
.49717 .04801 Mdot
.57061 .04539 Mdot
.74653 .10872 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.5049 .00208 Mdot
.5156 .00662 Mdot
.54968 .02106 Mdot
.65707 .06637 Mdot
.96365 .18947 Mdot
.32428 .22288 Mdot
.47171 .09112 Mdot
.57692 .06502 Mdot
.79307 .13359 Mdot
.23927 .27576 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00467 Mdot
.53505 .01486 Mdot
.61124 .04709 Mdot
.84104 .14202 Mdot
.27156 .26608 Mdot
.46554 .11989 Mdot
.60825 .08819 Mdot
.90108 .18098 Mdot
.49923 .61771 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47505 .60746 Mdot
.42067 .58442 Mdot
.25215 .51388 Mdot
.84491 .36635 Mdot
.63521 .48843 Mdot
.60478 .59923 Mdot
.72041 .07146 Mdot
.07066 .21647 Mdot
.5001 4e-05 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50309 .00131 Mdot
.50984 .00417 Mdot
.53135 .01329 Mdot
.59958 .04217 Mdot
.80762 .12858 Mdot
.23892 .26656 Mdot
.43206 .11937 Mdot
.52637 .05828 Mdot
.66005 .08262 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47679 .60819 Mdot
.42617 .58675 Mdot
.26873 .52073 Mdot
.87421 .37421 Mdot
.64934 .47905 Mdot
.61701 .59806 Mdot
.74482 .07899 Mdot
.11123 .22645 Mdot
.32405 .13153 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00126 Mdot
.5095 .00403 Mdot
.53026 .01283 Mdot
.59614 .04072 Mdot
.79763 .12453 Mdot
.22724 .26551 Mdot
.42055 .11947 Mdot
.49958 .04884 Mdot
.57796 .04845 Mdot
.76867 .11787 Mdot
.4986 .61744 Mdot
.49554 .61614 Mdot
.4858 .61201 Mdot
.45478 .59886 Mdot
.35683 .5575 Mdot
.07194 .44196 Mdot
.68278 .37752 Mdot
.51137 .5121 Mdot
.357 .52263 Mdot
.01585 .40719 Mdot
.65096 .39252 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50399 .00169 Mdot
.51272 .00539 Mdot
.5405 .01717 Mdot
.62836 .05431 Mdot
.88857 .16082 Mdot
.3026 .25588 Mdot
.49081 .11632 Mdot
.66525 .10781 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00214 Mdot
.51611 .00683 Mdot
.5513 .02174 Mdot
.6621 .06848 Mdot
.97614 .19409 Mdot
.32584 .21612 Mdot
.46339 .08501 Mdot
.54652 .05138 Mdot
.69844 .09389 Mdot
.07667 .23376 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50378 .0016 Mdot
.51203 .0051 Mdot
.53832 .01625 Mdot
.62155 .05143 Mdot
.86987 .15348 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52058 .00873 Mdot
.56548 .02775 Mdot
.70584 .08675 Mdot
.07581 .22865 Mdot
.33632 .161 Mdot
.39234 .03463 Mdot
.29892 .5603 Mdot
.97795 .41967 Mdot
.68995 .44004 Mdot
.49843 .61737 Mdot
.49498 .61591 Mdot
.48402 .61126 Mdot
.44913 .59647 Mdot
.33923 .55011 Mdot
.02713 .42515 Mdot
.67454 .40012 Mdot
.53434 .53139 Mdot
.44525 .56298 Mdot
.27565 .51322 Mdot
.87042 .36758 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47789 .60866 Mdot
.42966 .58823 Mdot
.27932 .52512 Mdot
.89428 .38007 Mdot
.65642 .47103 Mdot
.61719 .59379 Mdot
.73829 .07484 Mdot
.09748 .22199 Mdot
.31942 .13717 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47888 .60908 Mdot
.4328 .58955 Mdot
.28888 .52909 Mdot
.91333 .38593 Mdot
.66145 .46236 Mdot
.61229 .58765 Mdot
.71795 .0653 Mdot
.05751 .20986 Mdot
.31267 .1577 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57374 .03125 Mdot
.731 .09719 Mdot
.12529 .24368 Mdot
.35046 .13917 Mdot
.38291 .02005 Mdot
.25514 .53907 Mdot
.88876 .3916 Mdot
.67598 .48653 Mdot
.50054 .00023 Mdot
.50171 .00073 Mdot
.50546 .00231 Mdot
.51739 .00737 Mdot
.55536 .02346 Mdot
.6747 .07375 Mdot
.00654 .20509 Mdot
.32858 .19903 Mdot
.44039 .06911 Mdot
.46487 .01513 Mdot
.43708 .60086 Mdot
.31735 .54404 Mdot
.50076 .00032 Mdot
.50244 .00103 Mdot
.50776 .00329 Mdot
.52473 .01049 Mdot
.57864 .03332 Mdot
.74578 .1033 Mdot
.15156 .25079 Mdot
.36284 .13058 Mdot
.39291 .01859 Mdot
.27421 .54467 Mdot
.91952 .39883 Mdot
.68048 .47029 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48802 .61296 Mdot
.46186 .60186 Mdot
.37903 .56684 Mdot
.13173 .46519 Mdot
.70863 .35655 Mdot
.51625 .49913 Mdot
.34819 .51417 Mdot
.9854 .39382 Mdot
.64448 .40734 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51962 .00832 Mdot
.56242 .02646 Mdot
.69648 .08285 Mdot
.0559 .22213 Mdot
.33318 .17137 Mdot
.40361 .04353 Mdot
.33812 .57756 Mdot
.06958 .45206 Mdot
.69996 .3896 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50696 .00295 Mdot
.52218 .00941 Mdot
.57057 .0299 Mdot
.72137 .0932 Mdot
.10706 .23837 Mdot
.344 .14643 Mdot
.38264 .02388 Mdot
.26077 .54271 Mdot
.90071 .3955 Mdot
.68011 .4817 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00313 Mdot
.52348 .00996 Mdot
.57468 .03165 Mdot
.73385 .09837 Mdot
.13052 .24515 Mdot
.35263 .13727 Mdot
.38394 .01935 Mdot
.25619 .53908 Mdot
.88988 .39165 Mdot
.67589 .48578 Mdot
.49963 .61788 Mdot
.49881 .61753 Mdot
.49622 .61643 Mdot
.48796 .61293 Mdot
.46167 .60178 Mdot
.37843 .56659 Mdot
.13006 .46453 Mdot
.7076 .35694 Mdot
.51545 .49928 Mdot
.34644 .51358 Mdot
.9812 .3923 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51713 .00727 Mdot
.55454 .02312 Mdot
.67217 .0727 Mdot
.00054 .20295 Mdot
.3281 .20245 Mdot
.44511 .07231 Mdot
.4814 .02243 Mdot
.48987 .00523 Mdot
.48314 .61388 Mdot
.49863 .61745 Mdot
.49562 .61618 Mdot
.48605 .61212 Mdot
.45557 .5992 Mdot
.35932 .55854 Mdot
.07846 .44446 Mdot
.68462 .37463 Mdot
.50966 .5099 Mdot
.34918 .51885 Mdot
.99484 .39904 Mdot
.64824 .40382 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61007 Mdot
.4402 .59269 Mdot
.3116 .53855 Mdot
.96192 .40192 Mdot
.66882 .43689 Mdot
.58406 .56565 Mdot
.61961 .02197 Mdot
.81815 .1227 Mdot
.23387 .25693 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.5061 .00259 Mdot
.51944 .00824 Mdot
.56185 .02621 Mdot
.69473 .08212 Mdot
.05208 .22086 Mdot
.3327 .17343 Mdot
.4061 .04536 Mdot
.34668 .58131 Mdot
.09124 .46016 Mdot
.70631 .38013 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49458 .61573 Mdot
.48272 .61071 Mdot
.445 .59472 Mdot
.3264 .54474 Mdot
.99604 .41386 Mdot
.67162 .41753 Mdot
.55757 .54755 Mdot
.52801 .59976 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50963 .00408 Mdot
.53066 .013 Mdot
.59741 .04125 Mdot
.80132 .12602 Mdot
.23165 .26596 Mdot
.42484 .1194 Mdot
.50944 .05228 Mdot
.60819 .06103 Mdot
.85702 .15378 Mdot
.49781 .6171 Mdot
.49302 .61507 Mdot
.47776 .6086 Mdot
.42925 .58805 Mdot
.27807 .5246 Mdot
.89186 .37935 Mdot
.65567 .47206 Mdot
.61748 .59443 Mdot
.73994 .07569 Mdot
.10066 .22294 Mdot
.32025 .13572 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48327 .61094 Mdot
.44674 .59546 Mdot
.3318 .547 Mdot
.00897 .41851 Mdot
.67269 .4102 Mdot
.54754 .54068 Mdot
.49263 .5841 Mdot
.42667 .57727 Mdot
.25456 .51166 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48583 .61203 Mdot
.45489 .59891 Mdot
.35718 .55765 Mdot
.07286 .44231 Mdot
.68303 .3771 Mdot
.5111 .51178 Mdot
.3558 .52206 Mdot
.01261 .40593 Mdot
.65052 .39425 Mdot
.4982 .61727 Mdot
.49426 .6156 Mdot
.48171 .61028 Mdot
.44178 .59336 Mdot
.31644 .54057 Mdot
.97288 .4057 Mdot
.6698 .43072 Mdot
.57578 .55993 Mdot
.59119 .00952 Mdot
.73601 .08951 Mdot
.11864 .23648 Mdot
.49885 .61755 Mdot
.49633 .61648 Mdot
.48831 .61308 Mdot
.46278 .60225 Mdot
.38191 .56806 Mdot
.13972 .46835 Mdot
.71385 .35483 Mdot
.52058 .49859 Mdot
.35811 .51762 Mdot
.00989 .40282 Mdot
.64685 .39366 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.5099 .0042 Mdot
.53153 .01337 Mdot
.60016 .04241 Mdot
.80929 .12925 Mdot
.24078 .26668 Mdot
.43394 .11938 Mdot
.53084 .05989 Mdot
.67371 .0883 Mdot
.02842 .21922 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47426 .60712 Mdot
.41817 .58337 Mdot
.24468 .51081 Mdot
.83258 .36335 Mdot
.6278 .49147 Mdot
.59476 .59762 Mdot
.69562 .06233 Mdot
.0214 .20135 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50764 .00324 Mdot
.52435 .01032 Mdot
.57744 .03281 Mdot
.74215 .1018 Mdot
.14531 .24916 Mdot
.35955 .13241 Mdot
.38941 .01845 Mdot
.2664 .54201 Mdot
.90594 .39525 Mdot
.67849 .47747 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48376 .61115 Mdot
.44829 .59612 Mdot
.33662 .54902 Mdot
.02072 .42279 Mdot
.67382 .40364 Mdot
.53883 .53461 Mdot
.46151 .57025 Mdot
.32703 .53492 Mdot
.98123 .40432 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51387 .00588 Mdot
.54418 .01873 Mdot
.63991 .05916 Mdot
.9195 .1728 Mdot
.31476 .24428 Mdot
.49077 .10878 Mdot
.65295 .10023 Mdot
.01083 .22118 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48535 .61182 Mdot
.45337 .59826 Mdot
.35242 .55565 Mdot
.0605 .43761 Mdot
.68 .38287 Mdot
.5155 .51637 Mdot
.37423 .53072 Mdot
.06334 .42589 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48029 .60968 Mdot
.43729 .59146 Mdot
.30264 .53482 Mdot
.9422 .39527 Mdot
.66657 .44768 Mdot
.5976 .57541 Mdot
.66603 .04229 Mdot
.94072 .16977 Mdot
.30229 .22346 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48569 .61197 Mdot
.45444 .59872 Mdot
.35578 .55706 Mdot
.06921 .44092 Mdot
.68206 .37876 Mdot
.51223 .51307 Mdot
.36072 .52439 Mdot
.02595 .41113 Mdot
.65243 .38719 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48966 .61365 Mdot
.46707 .60407 Mdot
.39545 .57377 Mdot
.17803 .48366 Mdot
.74587 .35095 Mdot
.55237 .49844 Mdot
.43601 .54612 Mdot
.22624 .48839 Mdot
.78039 .34248 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50782 .00332 Mdot
.52491 .01056 Mdot
.57923 .03357 Mdot
.74753 .10402 Mdot
.15453 .25154 Mdot
.36448 .12976 Mdot
.39484 .01876 Mdot
.2787 .54625 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48478 .61158 Mdot
.45153 .59749 Mdot
.3467 .55325 Mdot
.04586 .43211 Mdot
.67718 .39017 Mdot
.52267 .52254 Mdot
.40206 .54349 Mdot
.14362 .45831 Mdot
.69783 .34252 Mdot
.4989 .61757 Mdot
.49651 .61655 Mdot
.48888 .61332 Mdot
.46457 .60301 Mdot
.38756 .57044 Mdot
.15557 .47466 Mdot
.72565 .35233 Mdot
.53168 .49815 Mdot
.38491 .52732 Mdot
.08015 .42969 Mdot
.66019 .35848 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.52011 .00853 Mdot
.56398 .02712 Mdot
.70126 .08485 Mdot
.06617 .22553 Mdot
.33466 .16593 Mdot
.39739 .03877 Mdot
.31666 .56814 Mdot
.01784 .43335 Mdot
.69231 .41685 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .0016 Mdot
.51199 .00508 Mdot
.53818 .01619 Mdot
.62109 .05124 Mdot
.86862 .15298 Mdot
.29159 .26141 Mdot
.48392 .11887 Mdot
.65219 .10399 Mdot
.0155 .22454 Mdot
.3556 .21019 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50797 .00338 Mdot
.52539 .01077 Mdot
.58074 .03421 Mdot
.75208 .10589 Mdot
.16213 .25342 Mdot
.36891 .1278 Mdot
.40056 .01956 Mdot
.29258 .55129 Mdot
.95435 .409 Mdot
.68366 .45074 Mdot
.49813 .61724 Mdot
.49404 .6155 Mdot
.481 .60998 Mdot
.43953 .5924 Mdot
.30951 .53768 Mdot
.95726 .40033 Mdot
.66835 .43948 Mdot
.58744 .56803 Mdot
.63119 .02704 Mdot
.85019 .13535 Mdot
.26216 .25461 Mdot
.49744 .61695 Mdot
.49184 .61457 Mdot
.47401 .60701 Mdot
.41736 .58302 Mdot
.24225 .50981 Mdot
.82868 .36244 Mdot
.62527 .49232 Mdot
.59095 .59682 Mdot
.68574 .05858 Mdot
6e-05 .19426 Mdot
.31429 .19421 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48702 .61253 Mdot
.45867 .60051 Mdot
.36903 .56263 Mdot
.10436 .45446 Mdot
.69413 .3645 Mdot
.50808 .50305 Mdot
.33413 .51053 Mdot
.95403 .38312 Mdot
.64193 .42515 Mdot
.49893 .61758 Mdot
.49658 .61658 Mdot
.4891 .61341 Mdot
.46529 .60332 Mdot
.38983 .5714 Mdot
.162 .47723 Mdot
.73101 .35167 Mdot
.53705 .49816 Mdot
.39818 .5322 Mdot
.11678 .44412 Mdot
.67551 .34532 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47657 .6081 Mdot
.42549 .58646 Mdot
.26669 .51989 Mdot
.87046 .37315 Mdot
.64779 .48042 Mdot
.61629 .59857 Mdot
.7441 .079 Mdot
.11049 .22644 Mdot
.32414 .13204 Mdot
.50054 .00023 Mdot
.50171 .00073 Mdot
.50546 .00232 Mdot
.5174 .00738 Mdot
.55539 .02348 Mdot
.67481 .0738 Mdot
.00681 .20519 Mdot
.3286 .19888 Mdot
.44018 .06896 Mdot
.46412 .0148 Mdot
.43471 .59985 Mdot
.31007 .54101 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47453 .60723 Mdot
.419 .58372 Mdot
.24715 .51183 Mdot
.83661 .36431 Mdot
.63032 .49054 Mdot
.59837 .59829 Mdot
.70477 .06576 Mdot
.04032 .20738 Mdot
.31604 .1704 Mdot
.4981 .61723 Mdot
.49395 .61547 Mdot
.48073 .60986 Mdot
.43868 .59204 Mdot
.30689 .53659 Mdot
.95147 .39837 Mdot
.66772 .44267 Mdot
.5915 .57093 Mdot
.6451 .03313 Mdot
.88743 .14977 Mdot
.28488 .24564 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51493 .00633 Mdot
.54753 .02015 Mdot
.65037 .06356 Mdot
.94668 .18313 Mdot
.32148 .23164 Mdot
.48122 .09873 Mdot
.61287 .08136 Mdot
.89999 .17745 Mdot
.32744 .26418 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48084 .60991 Mdot
.43901 .59219 Mdot
.30793 .53702 Mdot
.95376 .39914 Mdot
.66798 .44141 Mdot
.58992 .56979 Mdot
.63967 .03075 Mdot
.87306 .14424 Mdot
.2773 .24984 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00123 Mdot
.50927 .00393 Mdot
.52952 .01252 Mdot
.59381 .03973 Mdot
.79081 .12175 Mdot
.21873 .26447 Mdot
.41252 .11977 Mdot
.48158 .04269 Mdot
.52309 .02565 Mdot
.59911 .04698 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48304 .61084 Mdot
.44603 .59516 Mdot
.32959 .54607 Mdot
.00366 .4166 Mdot
.67224 .4132 Mdot
.55162 .54349 Mdot
.50707 .5905 Mdot
.47312 .59705 Mdot
.39904 .57225 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51435 .00608 Mdot
.54568 .01937 Mdot
.6446 .06113 Mdot
.93178 .17749 Mdot
.31819 .23881 Mdot
.48744 .1046 Mdot
.63787 .09297 Mdot
.97019 .20539 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50315 .00134 Mdot
.51003 .00425 Mdot
.53196 .01355 Mdot
.60149 .04298 Mdot
.81315 .13081 Mdot
.245 .2669 Mdot
.43823 .11942 Mdot
.54111 .06359 Mdot
.70499 .10128 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.4872 .61261 Mdot
.45923 .60075 Mdot
.37077 .56337 Mdot
.10909 .4563 Mdot
.69628 .36291 Mdot
.50874 .50213 Mdot
.33431 .51023 Mdot
.95388 .38291 Mdot
.64166 .42507 Mdot
.49764 .61703 Mdot
.49249 .61485 Mdot
.47609 .60789 Mdot
.42394 .58581 Mdot
.26201 .51795 Mdot
.86202 .37083 Mdot
.64403 .48331 Mdot
.61378 .59934 Mdot
.74004 .07803 Mdot
.10457 .22529 Mdot
.32328 .13517 Mdot
.49923 .61771 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47497 .60742 Mdot
.42041 .58431 Mdot
.25137 .51356 Mdot
.84361 .36602 Mdot
.63446 .48878 Mdot
.60386 .59912 Mdot
.71823 .07068 Mdot
.06659 .2153 Mdot
.4987 .61748 Mdot
.49586 .61628 Mdot
.48682 .61244 Mdot
.45802 .60024 Mdot
.36699 .56177 Mdot
.09888 .45233 Mdot
.6918 .36645 Mdot
.50768 .50424 Mdot
.33507 .51136 Mdot
.95704 .38439 Mdot
.64266 .42374 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53634 .01541 Mdot
.61532 .04881 Mdot
.85252 .1466 Mdot
.28062 .26458 Mdot
.47439 .11976 Mdot
.6299 .09611 Mdot
.95934 .2036 Mdot
.34911 .24089 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51797 .00762 Mdot
.55721 .02425 Mdot
.68042 .07615 Mdot
.01991 .20982 Mdot
.32961 .1914 Mdot
.42983 .06194 Mdot
.42817 .61701 Mdot
.32239 .55266 Mdot
.00214 .42011 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.4766 .60811 Mdot
.42558 .5865 Mdot
.26694 .51999 Mdot
.87092 .37328 Mdot
.64798 .48025 Mdot
.61639 .59851 Mdot
.74423 .07901 Mdot
.11064 .22646 Mdot
.32414 .13195 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49338 .61523 Mdot
.4789 .60909 Mdot
.43288 .58959 Mdot
.28913 .52919 Mdot
.91383 .38609 Mdot
.66156 .46212 Mdot
.61211 .58747 Mdot
.71724 .06498 Mdot
.05608 .20941 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.52609 .01106 Mdot
.58294 .03514 Mdot
.75864 .10859 Mdot
.17273 .25592 Mdot
.37567 .12543 Mdot
.41051 .02153 Mdot
.31809 .56091 Mdot
.00845 .42667 Mdot
.68614 .41884 Mdot
.5006 .00025 Mdot
.5019 .0008 Mdot
.50604 .00256 Mdot
.51924 .00816 Mdot
.56124 .02596 Mdot
.69286 .08134 Mdot
.04799 .21948 Mdot
.33222 .17567 Mdot
.40887 .04737 Mdot
.35618 .58547 Mdot
.11595 .46956 Mdot
.71677 .37133 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52227 .00944 Mdot
.57084 .03002 Mdot
.72219 .09354 Mdot
.10863 .23884 Mdot
.34449 .14577 Mdot
.38247 .02347 Mdot
.25975 .54219 Mdot
.89874 .39492 Mdot
.67958 .48259 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47677 .60818 Mdot
.4261 .58672 Mdot
.26852 .52064 Mdot
.87382 .3741 Mdot
.64918 .4792 Mdot
.61695 .59811 Mdot
.74477 .079 Mdot
.1112 .22647 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.5124 .00526 Mdot
.53949 .01674 Mdot
.62521 .05298 Mdot
.87996 .15744 Mdot
.29818 .25847 Mdot
.48852 .11764 Mdot
.66165 .107 Mdot
.03767 .23239 Mdot
.35771 .1978 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51107 .00469 Mdot
.53526 .01495 Mdot
.61191 .04737 Mdot
.84293 .14278 Mdot
.27313 .26588 Mdot
.46711 .11989 Mdot
.61212 .08962 Mdot
.91173 .18517 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50597 .00253 Mdot
.51903 .00807 Mdot
.56056 .02567 Mdot
.69075 .08046 Mdot
.04332 .2179 Mdot
.33171 .17824 Mdot
.41215 .04971 Mdot
.36739 .59037 Mdot
.14596 .48118 Mdot
.73501 .36405 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52002 .00849 Mdot
.56369 .02699 Mdot
.70038 .08448 Mdot
.06429 .22491 Mdot
.33437 .16692 Mdot
.39848 .03962 Mdot
.32042 .56979 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.5357 .01514 Mdot
.61331 .04796 Mdot
.84687 .14435 Mdot
.2763 .2654 Mdot
.47024 .11986 Mdot
.6198 .09243 Mdot
.93256 .1933 Mdot
.34348 .25396 Mdot
.49961 .61787 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.4875 .61273 Mdot
.4602 .60116 Mdot
.37382 .56465 Mdot
.11738 .45955 Mdot
.70041 .36033 Mdot
.51066 .50077 Mdot
.33691 .51065 Mdot
.95913 .38456 Mdot
.49778 .61709 Mdot
.49292 .61503 Mdot
.47744 .60847 Mdot
.42822 .58762 Mdot
.27495 .52331 Mdot
.88587 .37757 Mdot
.65369 .47454 Mdot
.61784 .59588 Mdot
.74305 .07738 Mdot
.10675 .22478 Mdot
.32207 .13307 Mdot
.49946 .6178 Mdot
.49826 .6173 Mdot
.49447 .61569 Mdot
.48238 .61056 Mdot
.4439 .59426 Mdot
.32301 .54332 Mdot
.98807 .41103 Mdot
.67101 .42208 Mdot
.56387 .55182 Mdot
.55 .60946 Mdot
.60989 .03701 Mdot
.49756 .617 Mdot
.49224 .61474 Mdot
.47528 .60755 Mdot
.42138 .58472 Mdot
.25429 .51477 Mdot
.84856 .36728 Mdot
.63723 .48742 Mdot
.60716 .59945 Mdot
.72596 .07342 Mdot
.08078 .21929 Mdot
.31956 .14758 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61225 Mdot
.45658 .59963 Mdot
.36248 .55988 Mdot
.08682 .44767 Mdot
.6873 .37111 Mdot
.50821 .50735 Mdot
.34144 .51496 Mdot
.97426 .39111 Mdot
.64552 .41486 Mdot
.49996 .61802 Mdot
.49987 .61798 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49592 .6163 Mdot
.48701 .61252 Mdot
.45863 .60049 Mdot
.36888 .56257 Mdot
.10396 .45431 Mdot
.69396 .36464 Mdot
.50803 .50313 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50565 .00239 Mdot
.51799 .00763 Mdot
.55725 .02427 Mdot
.68055 .0762 Mdot
.02021 .20992 Mdot
.32964 .19124 Mdot
.4296 .06178 Mdot
.42737 .61666 Mdot
.31995 .55164 Mdot
.99649 .41812 Mdot
.50046 .00019 Mdot
.50145 .00062 Mdot
.50463 .00196 Mdot
.51474 .00625 Mdot
.54695 .0199 Mdot
.64855 .06279 Mdot
.942 .18136 Mdot
.32054 .23395 Mdot
.48341 .10066 Mdot
.62145 .08531 Mdot
.9245 .18729 Mdot
.3366 .25469 Mdot
.49839 .61735 Mdot
.49486 .61585 Mdot
.48361 .61109 Mdot
.44784 .59592 Mdot
.33521 .54843 Mdot
.01726 .42153 Mdot
.67347 .40556 Mdot
.54134 .53637 Mdot
.47051 .57426 Mdot
.35571 .54708 Mdot
.05291 .4309 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.48079 .60989 Mdot
.43886 .59212 Mdot
.30746 .53682 Mdot
.95272 .39879 Mdot
.66786 .44198 Mdot
.59064 .57031 Mdot
.64215 .03183 Mdot
.87963 .14678 Mdot
.28095 .24802 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51434 .00608 Mdot
.54566 .01936 Mdot
.64455 .06111 Mdot
.93164 .17744 Mdot
.31815 .23888 Mdot
.48749 .10465 Mdot
.63807 .09306 Mdot
.97073 .2056 Mdot
.4977 .61706 Mdot
.49268 .61493 Mdot
.47667 .60814 Mdot
.42579 .58659 Mdot
.26758 .52026 Mdot
.87209 .37361 Mdot
.64847 .47983 Mdot
.61663 .59836 Mdot
.74449 .07902 Mdot
.11095 .22648 Mdot
.32413 .13176 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.4755 .60764 Mdot
.42207 .58502 Mdot
.25637 .51562 Mdot
.85213 .3682 Mdot
.63913 .48639 Mdot
.60925 .59956 Mdot
.73066 .07504 Mdot
.08905 .2215 Mdot
.49779 .61709 Mdot
.49294 .61504 Mdot
.47752 .6085 Mdot
.4285 .58773 Mdot
.27579 .52366 Mdot
.88748 .37804 Mdot
.65424 .47388 Mdot
.6178 .59551 Mdot
.74235 .07698 Mdot
.10537 .22436 Mdot
.32163 .13365 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48446 .61144 Mdot
.45051 .59705 Mdot
.34352 .55191 Mdot
.03783 .42911 Mdot
.67593 .39437 Mdot
.52737 .52622 Mdot
.41968 .55147 Mdot
.19655 .48013 Mdot
.74802 .34083 Mdot
.49776 .61708 Mdot
.49286 .615 Mdot
.47725 .60839 Mdot
.42762 .58736 Mdot
.27312 .52255 Mdot
.8824 .37656 Mdot
.65246 .47592 Mdot
.61781 .59662 Mdot
.74418 .0781 Mdot
.10912 .22555 Mdot
.32291 .13213 Mdot
.49997 .61802 Mdot
.49992 .618 Mdot
.49973 .61792 Mdot
.49914 .61767 Mdot
.49726 .61687 Mdot
.49128 .61434 Mdot
.47223 .60626 Mdot
.41173 .58064 Mdot
.2255 .50294 Mdot
.80337 .35714 Mdot
.60667 .49647 Mdot
.49822 .61728 Mdot
.49432 .61563 Mdot
.48192 .61037 Mdot
.44245 .59364 Mdot
.31854 .54145 Mdot
.97768 .40737 Mdot
.67019 .428 Mdot
.57205 .55738 Mdot
.57833 .00388 Mdot
.69743 .07361 Mdot
.04236 .21317 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50578 .00245 Mdot
.51841 .00781 Mdot
.55861 .02484 Mdot
.68475 .07796 Mdot
.02983 .21327 Mdot
.33043 .18578 Mdot
.42214 .05668 Mdot
.40165 .60537 Mdot
.24285 .51989 Mdot
.84556 .37249 Mdot
.49916 .61768 Mdot
.49734 .6169 Mdot
.49151 .61443 Mdot
.47296 .60657 Mdot
.41403 .58162 Mdot
.23233 .50574 Mdot
.81337 .3591 Mdot
.61447 .4951 Mdot
.57284 .59231 Mdot
.6367 .03947 Mdot
.88131 .15118 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.5072 .00305 Mdot
.52292 .00972 Mdot
.57291 .03089 Mdot
.72848 .09615 Mdot
.1206 .24234 Mdot
.34864 .14094 Mdot
.38236 .02084 Mdot
.25525 .53947 Mdot
.88953 .39201 Mdot
.67653 .48639 Mdot
.49897 .6176 Mdot
.49672 .61664 Mdot
.48956 .61361 Mdot
.46674 .60393 Mdot
.3944 .57332 Mdot
.17502 .48245 Mdot
.74291 .35098 Mdot
.54931 .49838 Mdot
.42848 .54336 Mdot
.20395 .47927 Mdot
.75061 .33786 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48978 .6137 Mdot
.46743 .60423 Mdot
.39659 .57425 Mdot
.1813 .48498 Mdot
.74918 .35097 Mdot
.55579 .49851 Mdot
.44439 .54918 Mdot
.25126 .49867 Mdot
.8194 .35113 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50697 .00296 Mdot
.5222 .00941 Mdot
.57062 .02993 Mdot
.72154 .09327 Mdot
.10737 .23846 Mdot
.34409 .1463 Mdot
.3826 .0238 Mdot
.26056 .5426 Mdot
.9003 .39538 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50576 .00244 Mdot
.51836 .00778 Mdot
.55843 .02476 Mdot
.68418 .07772 Mdot
.02855 .21283 Mdot
.33032 .18651 Mdot
.49857 .61743 Mdot
.49544 .6161 Mdot
.48546 .61187 Mdot
.45369 .5984 Mdot
.35345 .55608 Mdot
.06315 .43862 Mdot
.68059 .3816 Mdot
.51442 .51534 Mdot
.36986 .52869 Mdot
.05112 .42104 Mdot
.65701 .37446 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.5069 .00292 Mdot
.52197 .00932 Mdot
.56991 .02962 Mdot
.71936 .09237 Mdot
.10313 .23718 Mdot
.34281 .14813 Mdot
.38321 .02497 Mdot
.26372 .54419 Mdot
.90639 .39719 Mdot
.68152 .47905 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50503 .00213 Mdot
.51601 .00679 Mdot
.55098 .02161 Mdot
.66113 .06807 Mdot
.97374 .19321 Mdot
.32556 .21744 Mdot
.46506 .08621 Mdot
.55256 .05408 Mdot
.71749 .10193 Mdot
.49873 .6175 Mdot
.49597 .61632 Mdot
.48714 .61258 Mdot
.45906 .60068 Mdot
.37025 .56314 Mdot
.10766 .45575 Mdot
.69562 .36338 Mdot
.50851 .50239 Mdot
.33416 .51028 Mdot
.95368 .38289 Mdot
.64171 .42522 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51253 .00531 Mdot
.53989 .01691 Mdot
.62647 .05351 Mdot
.88341 .1588 Mdot
.30001 .25747 Mdot
.48956 .11715 Mdot
.66347 .10748 Mdot
.04168 .23375 Mdot
.35808 .19555 Mdot
.49777 .61709 Mdot
.49288 .61502 Mdot
.47732 .60842 Mdot
.42786 .58747 Mdot
.27387 .52286 Mdot
.88382 .37697 Mdot
.65297 .47536 Mdot
.61785 .59633 Mdot
.74378 .07783 Mdot
.10826 .22526 Mdot
.32259 .13246 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00226 Mdot
.51695 .00719 Mdot
.55396 .02287 Mdot
.67035 .07194 Mdot
.99621 .20139 Mdot
.32775 .2049 Mdot
.44849 .07462 Mdot
.49329 .02769 Mdot
.52804 .02147 Mdot
.60462 .04733 Mdot
.49772 .61707 Mdot
.49274 .61495 Mdot
.47687 .60822 Mdot
.42641 .58685 Mdot
.26947 .52104 Mdot
.87558 .3746 Mdot
.64988 .47855 Mdot
.61722 .59785 Mdot
.74492 .07892 Mdot
.11122 .22639 Mdot
.32395 .13147 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50507 .00215 Mdot
.51616 .00685 Mdot
.55144 .0218 Mdot
.66254 .06866 Mdot
.97721 .19448 Mdot
.32596 .21553 Mdot
.46264 .08448 Mdot
.54379 .05016 Mdot
.68981 .09025 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.49949 .61782 Mdot
.49837 .61734 Mdot
.49479 .61583 Mdot
.48341 .611 Mdot
.4472 .59565 Mdot
.33324 .5476 Mdot
.01246 .41978 Mdot
.67301 .40824 Mdot
.5449 .53886 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50427 .00181 Mdot
.51362 .00577 Mdot
.54336 .01838 Mdot
.63734 .05808 Mdot
.9127 .17018 Mdot
.31254 .24711 Mdot
.49184 .11082 Mdot
.65892 .10326 Mdot
.02669 .2273 Mdot
.35461 .20267 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50352 .00149 Mdot
.51122 .00476 Mdot
.53574 .01515 Mdot
.61343 .04801 Mdot
.84721 .14449 Mdot
.27657 .26535 Mdot
.4705 .11986 Mdot
.62044 .09267 Mdot
.93429 .19397 Mdot
.34393 .25317 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50896 .0038 Mdot
.52854 .0121 Mdot
.5907 .03842 Mdot
.78166 .11802 Mdot
.20664 .26266 Mdot
.4017 .12055 Mdot
.45851 .03511 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48836 .6131 Mdot
.46294 .60232 Mdot
.38243 .56828 Mdot
.14118 .46893 Mdot
.71486 .35455 Mdot
.52147 .49851 Mdot
.3602 .51836 Mdot
.01517 .40479 Mdot
.64742 .39075 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50971 .00412 Mdot
.53092 .01311 Mdot
.59821 .04159 Mdot
.80365 .12697 Mdot
.23439 .26621 Mdot
.42754 .11937 Mdot
.51571 .05449 Mdot
.62741 .06903 Mdot
.91045 .17493 Mdot
.4985 .6174 Mdot
.49524 .61601 Mdot
.48482 .6116 Mdot
.45168 .59755 Mdot
.34717 .55344 Mdot
.04706 .43256 Mdot
.67738 .38956 Mdot
.52201 .52201 Mdot
.39956 .54235 Mdot
.13625 .4553 Mdot
.69263 .34386 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61477 Mdot
.47546 .60763 Mdot
.42194 .58496 Mdot
.25599 .51547 Mdot
.85147 .36803 Mdot
.63878 .48659 Mdot
.60888 .59955 Mdot
.72984 .07476 Mdot
.08763 .22112 Mdot
.49967 .61789 Mdot
.49894 .61758 Mdot
.49662 .6166 Mdot
.48922 .61346 Mdot
.46566 .60348 Mdot
.391 .57189 Mdot
.16533 .47856 Mdot
.73392 .35141 Mdot
.54003 .4982 Mdot
.40554 .53492 Mdot
.13753 .4524 Mdot
.49917 .61768 Mdot
.49734 .61691 Mdot
.49153 .61444 Mdot
.47301 .60659 Mdot
.4142 .58169 Mdot
.23284 .50595 Mdot
.81414 .35926 Mdot
.61504 .49498 Mdot
.57386 .59259 Mdot
.63955 .0406 Mdot
.88875 .15401 Mdot
.49887 .61756 Mdot
.49641 .61651 Mdot
.48857 .61319 Mdot
.46359 .6026 Mdot
.38448 .56914 Mdot
.14689 .4712 Mdot
.71895 .35355 Mdot
.52521 .4983 Mdot
.36912 .52157 Mdot
.0381 .41345 Mdot
.65048 .37847 Mdot
.49764 .61703 Mdot
.49249 .61485 Mdot
.47607 .60789 Mdot
.4239 .58579 Mdot
.26188 .5179 Mdot
.86179 .37076 Mdot
.64392 .48339 Mdot
.6137 .59936 Mdot
.73989 .07799 Mdot
.10432 .22523 Mdot
.32324 .1353 Mdot
.49805 .61721 Mdot
.49378 .61539 Mdot
.48017 .60963 Mdot
.43691 .59129 Mdot
.30147 .53433 Mdot
.93966 .39443 Mdot
.66621 .44903 Mdot
.59917 .5766 Mdot
.67145 .04467 Mdot
.95396 .1746 Mdot
.30457 .21669 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50352 .00149 Mdot
.51123 .00476 Mdot
.53576 .01516 Mdot
.61348 .04803 Mdot
.84735 .14454 Mdot
.27667 .26534 Mdot
.47061 .11986 Mdot
.6207 .09276 Mdot
.93498 .19424 Mdot
.3441 .25285 Mdot
.50047 .0002 Mdot
.50148 .00063 Mdot
.50473 .002 Mdot
.51506 .00639 Mdot
.54794 .02032 Mdot
.65166 .0641 Mdot
.94997 .18436 Mdot
.32209 .22999 Mdot
.47957 .09732 Mdot
.60647 .07843 Mdot
.88144 .16994 Mdot
.31825 .26996 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51728 .00733 Mdot
.55501 .02332 Mdot
.6736 .0733 Mdot
.00396 .20417 Mdot
.32838 .2005 Mdot
.44243 .07049 Mdot
.47199 .01827 Mdot
.45974 .61047 Mdot
.38774 .57354 Mdot
.49851 .6174 Mdot
.49525 .61602 Mdot
.48486 .61162 Mdot
.45181 .59761 Mdot
.34758 .55361 Mdot
.04809 .43294 Mdot
.67756 .38904 Mdot
.52146 .52156 Mdot
.39745 .54139 Mdot
.13005 .45277 Mdot
.68857 .34518 Mdot
.49798 .61718 Mdot
.49358 .61531 Mdot
.47953 .60936 Mdot
.43488 .59044 Mdot
.29524 .53174 Mdot
.92646 .39011 Mdot
.6641 .45589 Mdot
.60654 .58246 Mdot
.69712 .05598 Mdot
.01338 .19546 Mdot
.30959 .18307 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51264 .00536 Mdot
.54026 .01707 Mdot
.62762 .05399 Mdot
.88655 .16002 Mdot
.3016 .25652 Mdot
.49036 .11666 Mdot
.66468 .10773 Mdot
.49784 .61712 Mdot
.49312 .61512 Mdot
.47809 .60874 Mdot
.43029 .58849 Mdot
.28124 .52592 Mdot
.89804 .3812 Mdot
.65753 .46939 Mdot
.61658 .59273 Mdot
.73529 .07336 Mdot
.0917 .22028 Mdot
.31805 .13989 Mdot
.49812 .61724 Mdot
.494 .61549 Mdot
.48088 .60993 Mdot
.43914 .59224 Mdot
.30833 .53719 Mdot
.95464 .39944 Mdot
.66807 .44093 Mdot
.5893 .56935 Mdot
.63756 .02983 Mdot
.86741 .14205 Mdot
.27392 .25124 Mdot
.49894 .61758 Mdot
.49663 .6166 Mdot
.48925 .61348 Mdot
.46576 .60352 Mdot
.39131 .57202 Mdot
.16621 .47891 Mdot
.73471 .35135 Mdot
.54083 .49821 Mdot
.40753 .53565 Mdot
.1432 .45467 Mdot
.6919 .33912 Mdot
.49977 .61794 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.49272 .61495 Mdot
.47681 .6082 Mdot
.42622 .58677 Mdot
.2689 .5208 Mdot
.87452 .3743 Mdot
.64946 .47894 Mdot
.61706 .59801 Mdot
.74485 .07898 Mdot
.49997 .61802 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49899 .61761 Mdot
.49678 .61667 Mdot
.48974 .61368 Mdot
.46733 .60418 Mdot
.39626 .57411 Mdot
.18037 .48461 Mdot
.74823 .35096 Mdot
.55481 .49849 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50806 .00342 Mdot
.52567 .01088 Mdot
.58161 .03458 Mdot
.75468 .10696 Mdot
.16637 .25444 Mdot
.37154 .1268 Mdot
.40427 .02023 Mdot
.30191 .55477 Mdot
.97339 .415 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .00991 Mdot
.57432 .03149 Mdot
.73273 .09791 Mdot
.12848 .24459 Mdot
.35177 .138 Mdot
.38349 .0196 Mdot
.25563 .53901 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54191 .01777 Mdot
.6328 .05617 Mdot
.90056 .16548 Mdot
.30796 .25179 Mdot
.4923 .11392 Mdot
.66508 .10679 Mdot
.04342 .23382 Mdot
.35743 .19407 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52546 .0108 Mdot
.58097 .0343 Mdot
.75276 .10617 Mdot
.16324 .25369 Mdot
.36959 .12753 Mdot
.4015 .01972 Mdot
.29491 .55216 Mdot
.95902 .41045 Mdot
.68393 .44802 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49302 .61508 Mdot
.47778 .60861 Mdot
.42931 .58808 Mdot
.27825 .52468 Mdot
.89221 .37945 Mdot
.65578 .47191 Mdot
.61744 .59434 Mdot
.73972 .07557 Mdot
.10023 .22281 Mdot
.5006 .00025 Mdot
.5019 .0008 Mdot
.50605 .00256 Mdot
.51926 .00817 Mdot
.5613 .02598 Mdot
.69304 .08142 Mdot
.04838 .21961 Mdot
.33226 .17545 Mdot
.4086 .04718 Mdot
.35526 .58506 Mdot
.11351 .46863 Mdot
.71557 .37209 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00225 Mdot
.51694 .00718 Mdot
.55392 .02285 Mdot
.67023 .07189 Mdot
.99591 .20128 Mdot
.32773 .20507 Mdot
.44872 .07478 Mdot
.4941 .02805 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50204 .00087 Mdot
.50651 .00276 Mdot
.52072 .00879 Mdot
.56594 .02795 Mdot
.70727 .08734 Mdot
.07877 .2296 Mdot
.33688 .15952 Mdot
.39096 .03342 Mdot
.29398 .5581 Mdot
.96733 .41615 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50724 .00307 Mdot
.52307 .00978 Mdot
.57339 .0311 Mdot
.72994 .09675 Mdot
.12333 .24313 Mdot
.34969 .1399 Mdot
.38264 .02036 Mdot
.25506 .53919 Mdot
.88888 .39172 Mdot
.67616 .48657 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.5034 .00144 Mdot
.51084 .0046 Mdot
.53454 .01464 Mdot
.60964 .04641 Mdot
.8365 .1402 Mdot
.26769 .26649 Mdot
.46162 .11986 Mdot
.59854 .08462 Mdot
.49866 .61747 Mdot
.49574 .61623 Mdot
.48643 .61228 Mdot
.4568 .59972 Mdot
.36315 .56016 Mdot
.08859 .44835 Mdot
.68791 .3704 Mdot
.50802 .50685 Mdot
.34014 .51428 Mdot
.97082 .38978 Mdot
.64502 .41668 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50377 .0016 Mdot
.512 .00509 Mdot
.53823 .01621 Mdot
.62125 .05131 Mdot
.86906 .15316 Mdot
.29186 .2613 Mdot
.48414 .11883 Mdot
.65266 .10415 Mdot
.01663 .22495 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51624 .00688 Mdot
.55169 .02191 Mdot
.66331 .06899 Mdot
.97911 .19518 Mdot
.32616 .21449 Mdot
.46129 .08351 Mdot
.53892 .04798 Mdot
.67434 .0837 Mdot
.02202 .21488 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.50518 .0022 Mdot
.51651 .007 Mdot
.55255 .02228 Mdot
.666 .07012 Mdot
.98571 .19759 Mdot
.32682 .21082 Mdot
.45647 .08013 Mdot
.52165 .04028 Mdot
.6192 .06029 Mdot
.87929 .16075 Mdot
.49981 .61795 Mdot
.49939 .61777 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48013 .60961 Mdot
.43676 .59123 Mdot
.301 .53413 Mdot
.93866 .3941 Mdot
.66607 .44956 Mdot
.59978 .57706 Mdot
.67355 .04559 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54189 .01776 Mdot
.63274 .05615 Mdot
.90041 .16543 Mdot
.3079 .25184 Mdot
.49229 .11396 Mdot
.66512 .10681 Mdot
.04353 .23387 Mdot
.35745 .19402 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.5047 .00199 Mdot
.51498 .00635 Mdot
.54771 .02022 Mdot
.65093 .06379 Mdot
.9481 .18366 Mdot
.32175 .23093 Mdot
.48052 .09812 Mdot
.61014 .08011 Mdot
.89209 .17425 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50324 .00137 Mdot
.51031 .00437 Mdot
.53283 .01392 Mdot
.60426 .04414 Mdot
.82113 .13403 Mdot
.25328 .26709 Mdot
.44675 .11957 Mdot
.56184 .07113 Mdot
.76736 .12702 Mdot
.2102 .27369 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00312 Mdot
.52346 .00995 Mdot
.57462 .03162 Mdot
.73367 .09829 Mdot
.13019 .24506 Mdot
.35249 .13739 Mdot
.38386 .01939 Mdot
.25608 .53906 Mdot
.88975 .39163 Mdot
.67588 .48585 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58508 .03604 Mdot
.76502 .11121 Mdot
.18263 .2581 Mdot
.38258 .12358 Mdot
.42194 .02433 Mdot
.34886 .57287 Mdot
.08163 .45288 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49716 .61683 Mdot
.49095 .61419 Mdot
.47116 .60581 Mdot
.40836 .57922 Mdot
.21556 .49888 Mdot
.78959 .35477 Mdot
.59501 .49778 Mdot
.53464 .58072 Mdot
.52581 .61258 Mdot
.49945 .6178 Mdot
.49824 .61729 Mdot
.49439 .61565 Mdot
.48212 .61045 Mdot
.4431 .59392 Mdot
.32055 .54229 Mdot
.98233 .409 Mdot
.67056 .42535 Mdot
.56841 .5549 Mdot
.56573 .61638 Mdot
.65887 .05756 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49068 .61408 Mdot
.47031 .60545 Mdot
.40567 .57808 Mdot
.20768 .49567 Mdot
.77934 .35331 Mdot
.58569 .49835 Mdot
.51447 .57401 Mdot
.49823 .61728 Mdot
.49437 .61564 Mdot
.48205 .61042 Mdot
.44287 .59382 Mdot
.31982 .54199 Mdot
.98064 .40841 Mdot
.67043 .42631 Mdot
.56973 .5558 Mdot
.57031 .00036 Mdot
.67296 .06344 Mdot
.98692 .19404 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50495 .0021 Mdot
.51577 .00669 Mdot
.5502 .02128 Mdot
.6587 .06706 Mdot
.96772 .19098 Mdot
.32483 .22071 Mdot
.4691 .08917 Mdot
.56733 .06071 Mdot
.76356 .12128 Mdot
.19766 .26829 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51875 .00795 Mdot
.55969 .0253 Mdot
.68807 .07935 Mdot
.03735 .21586 Mdot
.33111 .18156 Mdot
.41648 .05276 Mdot
.38225 .59688 Mdot
.18708 .49741 Mdot
.77159 .36125 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50395 .00168 Mdot
.51259 .00534 Mdot
.54009 .017 Mdot
.6271 .05377 Mdot
.88513 .15947 Mdot
.30089 .25695 Mdot
.49002 .11689 Mdot
.66418 .10764 Mdot
.04321 .23425 Mdot
.35821 .19468 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44668 .59543 Mdot
.33162 .54692 Mdot
.00853 .41836 Mdot
.67265 .41045 Mdot
.54787 .54091 Mdot
.49382 .58463 Mdot
.43049 .5789 Mdot
.26618 .51648 Mdot
.49961 .61787 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.4875 .61273 Mdot
.46019 .60116 Mdot
.37379 .56464 Mdot
.11731 .45952 Mdot
.70037 .36035 Mdot
.51064 .50078 Mdot
.33687 .51064 Mdot
.95905 .38453 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50821 .00348 Mdot
.52616 .01109 Mdot
.58316 .03523 Mdot
.7593 .10886 Mdot
.17376 .25615 Mdot
.37636 .12522 Mdot
.41161 .02178 Mdot
.32097 .56202 Mdot
.01496 .4289 Mdot
.68654 .41506 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48425 .61136 Mdot
.44987 .59678 Mdot
.34152 .55107 Mdot
.03284 .42726 Mdot
.67525 .39703 Mdot
.53054 .5286 Mdot
.43135 .55673 Mdot
.23235 .49505 Mdot
.79609 .34841 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50341 .00145 Mdot
.51087 .00461 Mdot
.53463 .01468 Mdot
.60993 .04654 Mdot
.83732 .14054 Mdot
.26841 .26642 Mdot
.46235 .11987 Mdot
.60035 .08529 Mdot
.8791 .17227 Mdot
.49997 .61802 Mdot
.4999 .61799 Mdot
.49967 .61789 Mdot
.49894 .61759 Mdot
.49663 .61661 Mdot
.48928 .61349 Mdot
.46585 .60355 Mdot
.39159 .57214 Mdot
.167 .47923 Mdot
.73541 .3513 Mdot
.54155 .49822 Mdot
.49984 .61797 Mdot
.49951 .61782 Mdot
.49842 .61737 Mdot
.49498 .6159 Mdot
.484 .61125 Mdot
.44905 .59644 Mdot
.33899 .55001 Mdot
.02655 .42493 Mdot
.67447 .40044 Mdot
.53474 .53168 Mdot
.44671 .56363 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52449 .01038 Mdot
.57787 .03299 Mdot
.74345 .10233 Mdot
.14756 .24975 Mdot
.3607 .13173 Mdot
.39058 .01846 Mdot
.26896 .54287 Mdot
.91029 .39637 Mdot
.67918 .4752 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52631 .01116 Mdot
.58364 .03543 Mdot
.76074 .10945 Mdot
.17603 .25666 Mdot
.37791 .12477 Mdot
.41409 .02236 Mdot
.32759 .56457 Mdot
.03015 .43421 Mdot
.68776 .40642 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53217 .01364 Mdot
.60218 .04326 Mdot
.81513 .13161 Mdot
.24711 .26697 Mdot
.44039 .11945 Mdot
.54633 .06548 Mdot
.7208 .10783 Mdot
.12999 .25289 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50269 .00114 Mdot
.50858 .00364 Mdot
.52734 .01159 Mdot
.58691 .03681 Mdot
.77045 .11344 Mdot
.19076 .25976 Mdot
.38868 .12232 Mdot
.43291 .02734 Mdot
.37947 .585 Mdot
.16203 .48365 Mdot
.49998 .61802 Mdot
.49993 .618 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49775 .61708 Mdot
.49284 .615 Mdot
.47719 .60836 Mdot
.42744 .58729 Mdot
.27259 .52233 Mdot
.8814 .37627 Mdot
.6521 .47632 Mdot
.49867 .61747 Mdot
.49576 .61624 Mdot
.48649 .61231 Mdot
.45698 .5998 Mdot
.36372 .5604 Mdot
.09013 .44894 Mdot
.68845 .36979 Mdot
.50788 .50643 Mdot
.33912 .51374 Mdot
.96809 .38872 Mdot
.6446 .41811 Mdot
.4979 .61715 Mdot
.49332 .6152 Mdot
.47873 .60902 Mdot
.43233 .58936 Mdot
.28746 .5285 Mdot
.91044 .38502 Mdot
.66078 .46374 Mdot
.61331 .5887 Mdot
.72182 .06706 Mdot
.06533 .2123 Mdot
.31357 .15342 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50783 .00332 Mdot
.52494 .01057 Mdot
.5793 .0336 Mdot
.74776 .10411 Mdot
.15493 .25164 Mdot
.36471 .12965 Mdot
.39512 .01879 Mdot
.27934 .54648 Mdot
.92888 .40144 Mdot
.68158 .4652 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00126 Mdot
.5095 .00403 Mdot
.53026 .01283 Mdot
.59614 .04072 Mdot
.79763 .12452 Mdot
.22724 .26551 Mdot
.42055 .11947 Mdot
.49957 .04884 Mdot
.57796 .04844 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51516 .00643 Mdot
.54826 .02046 Mdot
.65263 .06451 Mdot
.95245 .18529 Mdot
.32253 .22873 Mdot
.47825 .09624 Mdot
.60145 .07614 Mdot
.86674 .16395 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50824 .00349 Mdot
.52625 .01113 Mdot
.58345 .03535 Mdot
.76016 .10921 Mdot
.17512 .25646 Mdot
.37728 .12495 Mdot
.41308 .02212 Mdot
.32488 .56352 Mdot
.02389 .43201 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51238 .00525 Mdot
.53942 .01671 Mdot
.62499 .05288 Mdot
.87935 .15721 Mdot
.29785 .25864 Mdot
.48832 .11772 Mdot
.66128 .1069 Mdot
.03683 .2321 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47723 .60838 Mdot
.42758 .58735 Mdot
.27302 .52251 Mdot
.88221 .3765 Mdot
.65239 .476 Mdot
.61781 .59666 Mdot
.74423 .07813 Mdot
.10923 .22558 Mdot
.32295 .13208 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49604 .61635 Mdot
.48738 .61268 Mdot
.45981 .60099 Mdot
.37259 .56413 Mdot
.11402 .45823 Mdot
.69868 .36134 Mdot
.50977 .50128 Mdot
.33551 .51033 Mdot
.95615 .38358 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50601 .00255 Mdot
.51914 .00811 Mdot
.5609 .02581 Mdot
.69181 .0809 Mdot
.04567 .2187 Mdot
.33196 .17694 Mdot
.41049 .04853 Mdot
.36171 .58789 Mdot
.13063 .47522 Mdot
.72488 .36726 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.5037 .00157 Mdot
.5118 .005 Mdot
.53757 .01593 Mdot
.61918 .05044 Mdot
.86332 .15089 Mdot
.28819 .26258 Mdot
.48117 .11927 Mdot
.64597 .10185 Mdot
.00029 .21898 Mdot
.35418 .21872 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.49131 .61435 Mdot
.47232 .6063 Mdot
.41202 .58076 Mdot
.22636 .50329 Mdot
.8046 .35737 Mdot
.60766 .49632 Mdot
.56017 .58868 Mdot
.6008 .02511 Mdot
.78272 .11243 Mdot
.49863 .61745 Mdot
.49564 .61619 Mdot
.48612 .61215 Mdot
.45581 .5993 Mdot
.36005 .55885 Mdot
.0804 .4452 Mdot
.68521 .3738 Mdot
.50925 .50928 Mdot
.34716 .51785 Mdot
.98945 .39696 Mdot
.64756 .40673 Mdot
.49964 .61788 Mdot
.49887 .61755 Mdot
.49639 .6165 Mdot
.48851 .61316 Mdot
.4634 .60252 Mdot
.38387 .56888 Mdot
.14519 .47052 Mdot
.71771 .35383 Mdot
.52405 .49835 Mdot
.36634 .52056 Mdot
.03088 .41071 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50386 .00164 Mdot
.51231 .00522 Mdot
.53919 .01661 Mdot
.62426 .05258 Mdot
.87737 .15643 Mdot
.29675 .25919 Mdot
.48762 .11797 Mdot
.65996 .10651 Mdot
.03382 .23106 Mdot
.35734 .19994 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48039 .60972 Mdot
.4376 .59159 Mdot
.30358 .53521 Mdot
.94423 .39594 Mdot
.66683 .44659 Mdot
.59631 .57445 Mdot
.6616 .04035 Mdot
.92973 .16572 Mdot
.29988 .22876 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50938 .00398 Mdot
.52987 .01266 Mdot
.5949 .04019 Mdot
.79399 .12304 Mdot
.22275 .26499 Mdot
.41627 .1196 Mdot
.48991 .04551 Mdot
.54841 .03616 Mdot
.67842 .08035 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50734 .00311 Mdot
.52339 .00992 Mdot
.5744 .03152 Mdot
.73298 .09801 Mdot
.12892 .24471 Mdot
.35195 .13784 Mdot
.38358 .01955 Mdot
.25573 .53902 Mdot
.88931 .39157 Mdot
.67586 .48611 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48721 .61261 Mdot
.45928 .60077 Mdot
.37094 .56343 Mdot
.10953 .45648 Mdot
.69649 .36276 Mdot
.50882 .50205 Mdot
.33438 .51022 Mdot
.95398 .38293 Mdot
.64165 .42501 Mdot
.49828 .61731 Mdot
.49453 .61571 Mdot
.48257 .61064 Mdot
.44452 .59452 Mdot
.32491 .54412 Mdot
.99254 .41262 Mdot
.67135 .41953 Mdot
.56034 .54942 Mdot
.53768 .60403 Mdot
.57101 .0206 Mdot
.70736 .08427 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .0013 Mdot
.50973 .00413 Mdot
.531 .01314 Mdot
.59847 .0417 Mdot
.80439 .12727 Mdot
.23524 .26628 Mdot
.42838 .11937 Mdot
.51769 .0552 Mdot
.63348 .07156 Mdot
.92683 .1813 Mdot
.49868 .61748 Mdot
.4958 .61625 Mdot
.48662 .61236 Mdot
.4574 .59998 Mdot
.36505 .56096 Mdot
.09368 .45032 Mdot
.68976 .3684 Mdot
.50768 .5055 Mdot
.33711 .51262 Mdot
.96267 .38662 Mdot
.64372 .42091 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.51688 .00716 Mdot
.55375 .02278 Mdot
.66971 .07167 Mdot
.99465 .20083 Mdot
.32762 .20578 Mdot
.44969 .07544 Mdot
.49754 .02957 Mdot
.54169 .02729 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50946 .00401 Mdot
.53013 .01277 Mdot
.59572 .04054 Mdot
.79639 .12402 Mdot
.22572 .26534 Mdot
.41909 .11951 Mdot
.49626 .04769 Mdot
.56783 .04423 Mdot
.73808 .10522 Mdot
.49966 .61789 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48908 .6134 Mdot
.46523 .60329 Mdot
.38962 .57131 Mdot
.16141 .47699 Mdot
.73051 .35172 Mdot
.53654 .49816 Mdot
.39691 .53174 Mdot
.11324 .44272 Mdot
.49815 .61725 Mdot
.49411 .61554 Mdot
.48123 .61007 Mdot
.44025 .59271 Mdot
.31175 .53861 Mdot
.96225 .40203 Mdot
.66885 .4367 Mdot
.58381 .56548 Mdot
.61877 .0216 Mdot
.8158 .12177 Mdot
.23145 .25688 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00094 Mdot
.50703 .00298 Mdot
.52238 .00949 Mdot
.57119 .03017 Mdot
.72327 .09399 Mdot
.11073 .23946 Mdot
.34517 .14489 Mdot
.3823 .02295 Mdot
.25854 .54155 Mdot
.89639 .39421 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.47981 .60947 Mdot
.43575 .59081 Mdot
.29792 .53285 Mdot
.9321 .39194 Mdot
.66507 .453 Mdot
.60357 .58003 Mdot
.68669 .05137 Mdot
.98991 .1874 Mdot
.30825 .19674 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51848 .00784 Mdot
.55883 .02493 Mdot
.68542 .07824 Mdot
.03136 .2138 Mdot
.33056 .18492 Mdot
.42098 .05588 Mdot
.39766 .60363 Mdot
.23121 .51516 Mdot
.82768 .36864 Mdot
.49997 .61802 Mdot
.49989 .61799 Mdot
.49965 .61789 Mdot
.4989 .61757 Mdot
.49649 .61655 Mdot
.48883 .6133 Mdot
.46443 .60295 Mdot
.38712 .57025 Mdot
.15433 .47416 Mdot
.72466 .35248 Mdot
.5307 .49816 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47647 .60806 Mdot
.42517 .58633 Mdot
.26573 .51949 Mdot
.86871 .37266 Mdot
.64704 .48103 Mdot
.61587 .59877 Mdot
.74355 .07891 Mdot
.10976 .22633 Mdot
.32408 .13245 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47591 .60782 Mdot
.42339 .58557 Mdot
.26034 .51726 Mdot
.85906 .37003 Mdot
.64262 .48427 Mdot
.61261 .59949 Mdot
.73778 .07736 Mdot
.10098 .22447 Mdot
.32267 .13701 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49578 .61624 Mdot
.48655 .61233 Mdot
.45716 .59987 Mdot
.36428 .56063 Mdot
.09162 .44952 Mdot
.68899 .3692 Mdot
.50777 .50603 Mdot
.33821 .51324 Mdot
.96565 .38778 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50719 .00305 Mdot
.52289 .00971 Mdot
.57281 .03085 Mdot
.72818 .09602 Mdot
.12004 .24218 Mdot
.34843 .14116 Mdot
.38232 .02094 Mdot
.25532 .53955 Mdot
.88973 .39209 Mdot
.49915 .61767 Mdot
.49728 .61688 Mdot
.49134 .61436 Mdot
.47242 .60634 Mdot
.41234 .5809 Mdot
.22732 .50368 Mdot
.80598 .35763 Mdot
.60876 .49615 Mdot
.56228 .58931 Mdot
.60686 .02755 Mdot
.79994 .11933 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51127 .00478 Mdot
.53588 .01521 Mdot
.61386 .0482 Mdot
.84844 .14498 Mdot
.27752 .26519 Mdot
.47143 .11984 Mdot
.62272 .0935 Mdot
.94038 .19632 Mdot
.34539 .25031 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48299 .61082 Mdot
.44585 .59508 Mdot
.32904 .54584 Mdot
.00234 .41612 Mdot
.67213 .41395 Mdot
.55264 .54419 Mdot
.51068 .5921 Mdot
.48473 .60199 Mdot
.4359 .58786 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48412 .6113 Mdot
.44946 .59661 Mdot
.34024 .55054 Mdot
.02966 .42608 Mdot
.67484 .39874 Mdot
.53263 .53014 Mdot
.43902 .56018 Mdot
.25615 .50502 Mdot
.83473 .35758 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51818 .00771 Mdot
.55785 .02452 Mdot
.68241 .07698 Mdot
.02449 .21142 Mdot
.32998 .1888 Mdot
.42625 .0595 Mdot
.41582 .61159 Mdot
.28493 .53714 Mdot
.50013 6e-05 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00178 Mdot
.51341 .00569 Mdot
.5427 .0181 Mdot
.63527 .05721 Mdot
.90719 .16805 Mdot
.31057 .2493 Mdot
.49229 .11231 Mdot
.66245 .10516 Mdot
.03612 .23094 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .00121 Mdot
.50905 .00384 Mdot
.52884 .01223 Mdot
.59166 .03882 Mdot
.78448 .11917 Mdot
.21045 .26327 Mdot
.40503 .12025 Mdot
.49876 .61751 Mdot
.49604 .61636 Mdot
.4874 .61269 Mdot
.45987 .60102 Mdot
.37279 .56421 Mdot
.11457 .45844 Mdot
.69896 .36117 Mdot
.50991 .50119 Mdot
.3357 .51037 Mdot
.95655 .38371 Mdot
.64177 .42349 Mdot
.49919 .61769 Mdot
.49743 .61695 Mdot
.49182 .61457 Mdot
.47395 .60699 Mdot
.41718 .58295 Mdot
.24172 .50959 Mdot
.82784 .36225 Mdot
.62471 .49249 Mdot
.59008 .59663 Mdot
.68348 .05772 Mdot
.99505 .19256 Mdot
.4995 .61782 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48398 .61124 Mdot
.449 .59641 Mdot
.33882 .54994 Mdot
.02612 .42478 Mdot
.67442 .40067 Mdot
.53503 .53189 Mdot
.44777 .5641 Mdot
.28357 .51655 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51722 .0073 Mdot
.5548 .02323 Mdot
.67298 .07304 Mdot
.00247 .20364 Mdot
.32826 .20135 Mdot
.4436 .07129 Mdot
.4761 .02009 Mdot
.47289 .61605 Mdot
.42919 .59103 Mdot
.49745 .61695 Mdot
.49187 .61459 Mdot
.47411 .60706 Mdot
.41769 .58316 Mdot
.24323 .51021 Mdot
.83026 .3628 Mdot
.6263 .49198 Mdot
.59253 .59716 Mdot
.68985 .06015 Mdot
.00906 .19728 Mdot
.31469 .18889 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.51319 .00559 Mdot
.54201 .01781 Mdot
.63311 .0563 Mdot
.9014 .16581 Mdot
.30831 .25148 Mdot
.49233 .11373 Mdot
.66485 .10662 Mdot
.04274 .23355 Mdot
.35729 .1944 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51218 .00517 Mdot
.5388 .01645 Mdot
.62303 .05206 Mdot
.87396 .15509 Mdot
.2948 .26009 Mdot
.48631 .11836 Mdot
.65731 .10568 Mdot
.02768 .2289 Mdot
.35674 .20337 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.48081 .60989 Mdot
.43891 .59214 Mdot
.30763 .53689 Mdot
.95309 .39892 Mdot
.6679 .44178 Mdot
.59038 .57013 Mdot
.64127 .03145 Mdot
.87732 .14588 Mdot
.5006 .00026 Mdot
.50193 .00082 Mdot
.50614 .0026 Mdot
.51955 .00829 Mdot
.56221 .02637 Mdot
.69583 .08258 Mdot
.05448 .22166 Mdot
.333 .17213 Mdot
.40452 .0442 Mdot
.34125 .57893 Mdot
.07743 .45498 Mdot
.70199 .386 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.4795 .60934 Mdot
.43477 .59039 Mdot
.29492 .5316 Mdot
.92577 .38989 Mdot
.66398 .45624 Mdot
.60688 .58275 Mdot
.69833 .05652 Mdot
.01605 .19636 Mdot
.30973 .18151 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51818 .00771 Mdot
.55786 .02452 Mdot
.68242 .07699 Mdot
.02452 .21143 Mdot
.32998 .18879 Mdot
.42623 .05949 Mdot
.41576 .61156 Mdot
.28473 .53706 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50688 .00292 Mdot
.52191 .00929 Mdot
.56972 .02954 Mdot
.71879 .09213 Mdot
.10201 .23685 Mdot
.34248 .14862 Mdot
.38341 .02529 Mdot
.26467 .54465 Mdot
.49933 .61775 Mdot
.49787 .61713 Mdot
.49323 .61516 Mdot
.47842 .60888 Mdot
.43135 .58894 Mdot
.28447 .52726 Mdot
.90443 .38316 Mdot
.65929 .46652 Mdot
.61513 .59075 Mdot
.729 .07038 Mdot
.07953 .21664 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47636 .60801 Mdot
.42482 .58618 Mdot
.26465 .51904 Mdot
.86675 .37212 Mdot
.64619 .48172 Mdot
.61534 .59897 Mdot
.74275 .07874 Mdot
.10865 .22614 Mdot
.32394 .13306 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50997 .00423 Mdot
.53176 .01346 Mdot
.60086 .04271 Mdot
.81133 .13008 Mdot
.24302 .2668 Mdot
.43621 .1194 Mdot
.53627 .06184 Mdot
.69026 .09517 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.47972 .60943 Mdot
.43545 .59068 Mdot
.297 .53247 Mdot
.93015 .39131 Mdot
.66474 .454 Mdot
.60463 .58088 Mdot
.69039 .053 Mdot
.99834 .19032 Mdot
.30878 .19186 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50399 .00169 Mdot
.51271 .00539 Mdot
.54048 .01716 Mdot
.6283 .05428 Mdot
.88841 .16075 Mdot
.30252 .25593 Mdot
.49078 .11635 Mdot
.66521 .1078 Mdot
.04528 .2349 Mdot
.35835 .19348 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00156 Mdot
.51168 .00495 Mdot
.53721 .01578 Mdot
.61805 .04996 Mdot
.86018 .14964 Mdot
.28608 .26322 Mdot
.47935 .11945 Mdot
.64175 .10037 Mdot
.98975 .21508 Mdot
.35312 .22457 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51853 .00786 Mdot
.55898 .025 Mdot
.68588 .07843 Mdot
.03239 .21416 Mdot
.33065 .18434 Mdot
.42019 .05534 Mdot
.39496 .60244 Mdot
.22337 .51198 Mdot
.81638 .3665 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50734 .00311 Mdot
.52339 .00992 Mdot
.5744 .03152 Mdot
.73298 .09801 Mdot
.12893 .24471 Mdot
.35196 .13784 Mdot
.38358 .01954 Mdot
.25574 .53902 Mdot
.88932 .39157 Mdot
.67586 .48611 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50611 .00259 Mdot
.51947 .00826 Mdot
.56196 .02626 Mdot
.69507 .08226 Mdot
.05283 .22111 Mdot
.33279 .17303 Mdot
.4056 .045 Mdot
.34498 .58057 Mdot
.49796 .61717 Mdot
.49351 .61528 Mdot
.47931 .60926 Mdot
.43418 .59014 Mdot
.2931 .53084 Mdot
.92198 .38867 Mdot
.66326 .45814 Mdot
.6087 .58431 Mdot
.70479 .05939 Mdot
.03005 .20102 Mdot
.3105 .17333 Mdot
.49878 .61752 Mdot
.49613 .61639 Mdot
.48765 .6128 Mdot
.46068 .60137 Mdot
.37534 .56529 Mdot
.12154 .46118 Mdot
.70264 .35914 Mdot
.51199 .5002 Mdot
.33929 .5113 Mdot
.96447 .38638 Mdot
.6425 .41905 Mdot
.49965 .61789 Mdot
.49888 .61756 Mdot
.49645 .61653 Mdot
.48867 .61323 Mdot
.46393 .60274 Mdot
.38553 .56958 Mdot
.14987 .47238 Mdot
.72118 .35309 Mdot
.52732 .49822 Mdot
.37424 .52342 Mdot
.05154 .41859 Mdot
.4988 .61753 Mdot
.49619 .61642 Mdot
.48785 .61288 Mdot
.46131 .60163 Mdot
.3773 .56611 Mdot
.12693 .4633 Mdot
.70572 .35771 Mdot
.51406 .49958 Mdot
.34347 .5126 Mdot
.97413 .38977 Mdot
.64343 .41365 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51416 .006 Mdot
.54508 .01911 Mdot
.64271 .06034 Mdot
.92685 .17561 Mdot
.31689 .24106 Mdot
.48899 .10636 Mdot
.64457 .09616 Mdot
.98839 .21249 Mdot
.34961 .22325 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50607 .00258 Mdot
.51935 .0082 Mdot
.56158 .0261 Mdot
.69389 .08177 Mdot
.05024 .22024 Mdot
.33248 .17443 Mdot
.40733 .04626 Mdot
.3509 .58316 Mdot
.10213 .46429 Mdot
.71046 .37597 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.5059 .0025 Mdot
.51879 .00797 Mdot
.55979 .02534 Mdot
.68839 .07948 Mdot
.03804 .2161 Mdot
.33118 .18117 Mdot
.41597 .0524 Mdot
.38049 .5961 Mdot
.18211 .49543 Mdot
.49873 .61749 Mdot
.49594 .61631 Mdot
.48707 .61255 Mdot
.45884 .60058 Mdot
.36955 .56285 Mdot
.10577 .45501 Mdot
.69476 .36401 Mdot
.50824 .50276 Mdot
.33409 .5104 Mdot
.95375 .38297 Mdot
.64181 .42525 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.4743 .60714 Mdot
.41829 .58342 Mdot
.24502 .51095 Mdot
.83313 .36347 Mdot
.62815 .49135 Mdot
.59527 .59772 Mdot
.69693 .06282 Mdot
.02416 .20224 Mdot
.31529 .17993 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.4805 .60977 Mdot
.43795 .59174 Mdot
.30467 .53566 Mdot
.9466 .39673 Mdot
.66714 .44532 Mdot
.59478 .57331 Mdot
.65632 .03804 Mdot
.91643 .16076 Mdot
.29621 .23472 Mdot
.49855 .61742 Mdot
.49537 .61607 Mdot
.48525 .61178 Mdot
.45305 .59813 Mdot
.35143 .55523 Mdot
.05794 .43665 Mdot
.67945 .38411 Mdot
.51661 .5174 Mdot
.37865 .53277 Mdot
.0758 .43086 Mdot
.6635 .36322 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.49419 .61557 Mdot
.4815 .61019 Mdot
.44112 .59308 Mdot
.31441 .53973 Mdot
.96827 .4041 Mdot
.6694 .43333 Mdot
.57931 .56235 Mdot
.60333 .01484 Mdot
.77167 .10404 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50674 .00286 Mdot
.52146 .0091 Mdot
.56829 .02894 Mdot
.71443 .09032 Mdot
.09336 .23419 Mdot
.34015 .15252 Mdot
.38549 .02802 Mdot
.27349 .54882 Mdot
.92536 .40288 Mdot
.68513 .46956 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51486 .0063 Mdot
.54731 .02005 Mdot
.64967 .06327 Mdot
.94489 .18245 Mdot
.32113 .23253 Mdot
.48209 .09948 Mdot
.61622 .0829 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50306 .0013 Mdot
.50976 .00414 Mdot
.5311 .01318 Mdot
.59878 .04183 Mdot
.80529 .12763 Mdot
.23628 .26636 Mdot
.42942 .11937 Mdot
.52013 .05606 Mdot
.64094 .07467 Mdot
.94659 .1889 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.4743 .60714 Mdot
.41829 .58342 Mdot
.24503 .51095 Mdot
.83316 .36348 Mdot
.62816 .49134 Mdot
.5953 .59772 Mdot
.69699 .06285 Mdot
.02429 .20228 Mdot
.3153 .17985 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50579 .00245 Mdot
.51844 .00782 Mdot
.55868 .02487 Mdot
.68497 .07805 Mdot
.03033 .21345 Mdot
.33047 .1855 Mdot
.42175 .05641 Mdot
.40034 .6048 Mdot
.23901 .51833 Mdot
.83952 .37114 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.525 .0106 Mdot
.57949 .03368 Mdot
.74834 .10435 Mdot
.1559 .25189 Mdot
.36525 .12939 Mdot
.39579 .01887 Mdot
.28093 .54705 Mdot
.93184 .40228 Mdot
.68189 .46356 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50338 .00143 Mdot
.51077 .00457 Mdot
.53431 .01455 Mdot
.60891 .04611 Mdot
.83443 .13938 Mdot
.26587 .26664 Mdot
.45976 .11983 Mdot
.59393 .08292 Mdot
.86095 .16503 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48826 .61305 Mdot
.4626 .60218 Mdot
.38135 .56782 Mdot
.13816 .46773 Mdot
.7128 .35514 Mdot
.51967 .49868 Mdot
.35598 .51687 Mdot
.00455 .40084 Mdot
.6463 .39662 Mdot
.49804 .6172 Mdot
.49375 .61538 Mdot
.48009 .60959 Mdot
.43663 .59118 Mdot
.30062 .53397 Mdot
.93785 .39383 Mdot
.66595 .44999 Mdot
.60027 .57744 Mdot
.67522 .04633 Mdot
.96304 .17788 Mdot
.3058 .21184 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.4798 .60947 Mdot
.43574 .5908 Mdot
.29787 .53283 Mdot
.932 .39191 Mdot
.66505 .45305 Mdot
.60362 .58007 Mdot
.68688 .05146 Mdot
.99035 .18755 Mdot
.30828 .19649 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00282 Mdot
.5212 .00899 Mdot
.56746 .02859 Mdot
.71192 .08928 Mdot
.0883 .23262 Mdot
.33892 .15489 Mdot
.38712 .02979 Mdot
.27984 .55173 Mdot
.93801 .40677 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54142 .01756 Mdot
.63125 .05552 Mdot
.8964 .16387 Mdot
.3062 .25327 Mdot
.492 .11483 Mdot
.66582 .10742 Mdot
.04573 .2348 Mdot
.35799 .19299 Mdot
.49745 .61695 Mdot
.49187 .61459 Mdot
.47411 .60706 Mdot
.41769 .58316 Mdot
.24322 .51021 Mdot
.83024 .3628 Mdot
.62629 .49199 Mdot
.59251 .59716 Mdot
.6898 .06013 Mdot
.00896 .19725 Mdot
.31468 .18895 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.50591 .0025 Mdot
.51882 .00798 Mdot
.55988 .02538 Mdot
.68867 .0796 Mdot
.03869 .21632 Mdot
.33124 .18081 Mdot
.41549 .05207 Mdot
.37886 .59539 Mdot
.17757 .49363 Mdot
.76184 .3611 Mdot
.49838 .61735 Mdot
.49483 .61584 Mdot
.48354 .61106 Mdot
.44761 .59583 Mdot
.3345 .54813 Mdot
.01553 .4209 Mdot
.6733 .40652 Mdot
.54261 .53726 Mdot
.47508 .5763 Mdot
.37032 .55329 Mdot
.09186 .44594 Mdot
.49985 .61797 Mdot
.49953 .61783 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48464 .61152 Mdot
.45111 .59731 Mdot
.34537 .55269 Mdot
.04251 .43085 Mdot
.67664 .39191 Mdot
.52458 .52406 Mdot
.40924 .54675 Mdot
.49868 .61747 Mdot
.4958 .61625 Mdot
.48662 .61236 Mdot
.45739 .59997 Mdot
.365 .56093 Mdot
.09353 .45026 Mdot
.68971 .36845 Mdot
.50768 .50554 Mdot
.33718 .51266 Mdot
.96287 .3867 Mdot
.64375 .42081 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52613 .01108 Mdot
.58308 .03519 Mdot
.75905 .10876 Mdot
.17338 .25607 Mdot
.3761 .12529 Mdot
.4112 .02169 Mdot
.3199 .56161 Mdot
.01251 .42806 Mdot
.68638 .41647 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51374 .00583 Mdot
.54377 .01855 Mdot
.63861 .05862 Mdot
.91607 .17148 Mdot
.31367 .24573 Mdot
.49138 .10983 Mdot
.65618 .10185 Mdot
.01943 .2245 Mdot
.4985 .6174 Mdot
.49521 .616 Mdot
.48474 .61156 Mdot
.45143 .59744 Mdot
.34638 .55311 Mdot
.04506 .43181 Mdot
.67705 .39059 Mdot
.52312 .5229 Mdot
.40376 .54426 Mdot
.14867 .46038 Mdot
.70162 .34174 Mdot
.49859 .61743 Mdot
.4955 .61612 Mdot
.48565 .61195 Mdot
.45432 .59867 Mdot
.35541 .5569 Mdot
.06823 .44055 Mdot
.68182 .37922 Mdot
.51256 .51343 Mdot
.36211 .52505 Mdot
.02976 .41263 Mdot
.65303 .3852 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50595 .00252 Mdot
.51896 .00804 Mdot
.56035 .02558 Mdot
.69012 .0802 Mdot
.04192 .21743 Mdot
.33156 .17901 Mdot
.41314 .05042 Mdot
.37081 .59187 Mdot
.15529 .48483 Mdot
.74207 .36265 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47576 .60776 Mdot
.42292 .58538 Mdot
.25894 .51668 Mdot
.85659 .36937 Mdot
.64141 .48504 Mdot
.61152 .59956 Mdot
.73554 .07665 Mdot
.09732 .22359 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51722 .0073 Mdot
.55481 .02323 Mdot
.673 .07305 Mdot
.00252 .20366 Mdot
.32826 .20132 Mdot
.44355 .07125 Mdot
.47594 .02002 Mdot
.47239 .61584 Mdot
.42761 .59036 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49086 .61416 Mdot
.47087 .60568 Mdot
.40745 .57883 Mdot
.21289 .49779 Mdot
.78605 .35424 Mdot
.59185 .49801 Mdot
.52791 .57852 Mdot
.50562 .60426 Mdot
.49177 .60947 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49083 .61415 Mdot
.4708 .60565 Mdot
.40721 .57874 Mdot
.2122 .49751 Mdot
.78516 .35411 Mdot
.59104 .49807 Mdot
.52617 .57794 Mdot
.50038 .60209 Mdot
.47515 .60244 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.5093 .00394 Mdot
.52962 .01256 Mdot
.59411 .03986 Mdot
.79168 .12211 Mdot
.21984 .26462 Mdot
.41355 .11972 Mdot
.48386 .04345 Mdot
.52999 .02851 Mdot
.62084 .05615 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51625 .00689 Mdot
.55174 .02193 Mdot
.66348 .06906 Mdot
.97953 .19533 Mdot
.3262 .21425 Mdot
.46099 .0833 Mdot
.53784 .0475 Mdot
.67091 .08224 Mdot
.01383 .21194 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49072 .6141 Mdot
.47045 .60551 Mdot
.40612 .57827 Mdot
.20899 .4962 Mdot
.78102 .35353 Mdot
.58725 .49828 Mdot
.5179 .57517 Mdot
.49926 .61772 Mdot
.49765 .61704 Mdot
.4925 .61485 Mdot
.4761 .6079 Mdot
.424 .58583 Mdot
.26217 .51802 Mdot
.86232 .37091 Mdot
.64417 .48321 Mdot
.6139 .59932 Mdot
.74025 .07809 Mdot
.10489 .22536 Mdot
.49796 .61717 Mdot
.49349 .61527 Mdot
.47925 .60924 Mdot
.43398 .59005 Mdot
.29249 .53059 Mdot
.92073 .38827 Mdot
.66302 .45876 Mdot
.60926 .58481 Mdot
.70683 .0603 Mdot
.03439 .20245 Mdot
.31077 .17081 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .0018 Mdot
.51349 .00572 Mdot
.54296 .01821 Mdot
.63609 .05756 Mdot
.90938 .1689 Mdot
.31137 .24845 Mdot
.49216 .11173 Mdot
.66119 .10447 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49233 .61478 Mdot
.47557 .60768 Mdot
.42232 .58512 Mdot
.25711 .51593 Mdot
.85342 .36853 Mdot
.6398 .48601 Mdot
.60994 .59958 Mdot
.73218 .07555 Mdot
.09166 .22217 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48603 .61211 Mdot
.45551 .59917 Mdot
.35912 .55846 Mdot
.07794 .44426 Mdot
.68447 .37485 Mdot
.50978 .51007 Mdot
.34975 .51913 Mdot
.99635 .39962 Mdot
.64843 .40301 Mdot
.49993 .618 Mdot
.49977 .61794 Mdot
.49926 .61772 Mdot
.49765 .61704 Mdot
.4925 .61486 Mdot
.47612 .60791 Mdot
.42405 .58585 Mdot
.26233 .51808 Mdot
.86259 .37098 Mdot
.6443 .48312 Mdot
.61399 .59931 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51499 .00636 Mdot
.54773 .02023 Mdot
.651 .06382 Mdot
.94827 .18373 Mdot
.32178 .23084 Mdot
.48043 .09805 Mdot
.6098 .07996 Mdot
.89113 .17387 Mdot
.32332 .26711 Mdot
.49917 .61768 Mdot
.49735 .61691 Mdot
.49156 .61445 Mdot
.47311 .60663 Mdot
.41451 .58182 Mdot
.23376 .50632 Mdot
.81551 .35955 Mdot
.61606 .49477 Mdot
.57567 .59307 Mdot
.64457 .04258 Mdot
.9017 .15892 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.4805 .60976 Mdot
.43794 .59173 Mdot
.30462 .53564 Mdot
.94649 .3967 Mdot
.66712 .44537 Mdot
.59484 .57336 Mdot
.65656 .03814 Mdot
.91703 .16098 Mdot
.49892 .61758 Mdot
.49656 .61658 Mdot
.48905 .61339 Mdot
.46513 .60325 Mdot
.38931 .57118 Mdot
.16053 .47664 Mdot
.72976 .3518 Mdot
.53579 .49815 Mdot
.39504 .53105 Mdot
.10802 .44065 Mdot
.67113 .34802 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48984 .61372 Mdot
.46763 .60431 Mdot
.39719 .5745 Mdot
.18304 .48568 Mdot
.75097 .351 Mdot
.55764 .49855 Mdot
.44888 .55082 Mdot
.26476 .50424 Mdot
.84293 .35733 Mdot
.49786 .61713 Mdot
.49318 .61514 Mdot
.47827 .60882 Mdot
.43088 .58874 Mdot
.28303 .52666 Mdot
.90158 .38228 Mdot
.65852 .46782 Mdot
.61584 .59166 Mdot
.73199 .07178 Mdot
.08534 .21838 Mdot
.31673 .143 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.4822 .61049 Mdot
.44334 .59402 Mdot
.32126 .54259 Mdot
.98399 .40959 Mdot
.67069 .42441 Mdot
.5671 .55401 Mdot
.56119 .61438 Mdot
.64482 .05169 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53633 .0154 Mdot
.61526 .04878 Mdot
.85237 .14654 Mdot
.2805 .2646 Mdot
.47428 .11976 Mdot
.62964 .09602 Mdot
.95865 .20334 Mdot
.34899 .24124 Mdot
.49787 .61713 Mdot
.49323 .61516 Mdot
.47843 .60889 Mdot
.43136 .58895 Mdot
.2845 .52727 Mdot
.9045 .38318 Mdot
.6593 .4665 Mdot
.61512 .59073 Mdot
.72894 .07034 Mdot
.0794 .2166 Mdot
.31564 .14601 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50605 .00257 Mdot
.51928 .00818 Mdot
.56137 .02601 Mdot
.69325 .08151 Mdot
.04885 .21977 Mdot
.33232 .17519 Mdot
.40828 .04695 Mdot
.35415 .58458 Mdot
.1106 .46751 Mdot
.71419 .37304 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52147 .0091 Mdot
.56831 .02895 Mdot
.7145 .09035 Mdot
.09352 .23424 Mdot
.34019 .15245 Mdot
.38544 .02797 Mdot
.27331 .54874 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49234 .61479 Mdot
.47561 .60769 Mdot
.42244 .58517 Mdot
.25749 .51609 Mdot
.85407 .36871 Mdot
.64014 .48581 Mdot
.61028 .59958 Mdot
.73292 .0758 Mdot
.09292 .22249 Mdot
.49881 .61753 Mdot
.49619 .61642 Mdot
.48787 .61289 Mdot
.46138 .60166 Mdot
.37752 .56621 Mdot
.12754 .46354 Mdot
.70608 .35756 Mdot
.51432 .49952 Mdot
.34401 .51278 Mdot
.97542 .39023 Mdot
.64355 .41293 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51788 .00758 Mdot
.5569 .02412 Mdot
.67948 .07576 Mdot
.01774 .20905 Mdot
.32944 .19265 Mdot
.43154 .0631 Mdot
.4341 .00158 Mdot
.49848 .61739 Mdot
.49517 .61599 Mdot
.48461 .61151 Mdot
.45101 .59727 Mdot
.34509 .55257 Mdot
.04179 .43059 Mdot
.67652 .39228 Mdot
.52499 .52438 Mdot
.4108 .54746 Mdot
.16971 .46903 Mdot
.71962 .33987 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53094 .01312 Mdot
.5983 .04163 Mdot
.80391 .12707 Mdot
.23468 .26623 Mdot
.42783 .11937 Mdot
.5164 .05474 Mdot
.62952 .06991 Mdot
.91617 .17716 Mdot
.49983 .61796 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49454 .61572 Mdot
.48262 .61066 Mdot
.44467 .59458 Mdot
.3254 .54432 Mdot
.99369 .41303 Mdot
.67144 .41887 Mdot
.55943 .54881 Mdot
.5345 .60263 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47601 .60786 Mdot
.4237 .58571 Mdot
.26128 .51765 Mdot
.86073 .37048 Mdot
.64342 .48373 Mdot
.61329 .59941 Mdot
.73911 .07776 Mdot
.1031 .22496 Mdot
.32303 .13592 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.5059 .0025 Mdot
.51878 .00796 Mdot
.55978 .02534 Mdot
.68834 .07946 Mdot
.03794 .21607 Mdot
.33117 .18122 Mdot
.41604 .05245 Mdot
.38074 .59622 Mdot
.18283 .49572 Mdot
.76713 .36112 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.5121 .00513 Mdot
.53853 .01634 Mdot
.62221 .05171 Mdot
.8717 .1542 Mdot
.29347 .26067 Mdot
.48535 .11859 Mdot
.65528 .10503 Mdot
.02291 .22721 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00314 Mdot
.52362 .01002 Mdot
.57514 .03184 Mdot
.73522 .09893 Mdot
.133 .24584 Mdot
.35371 .1364 Mdot
.38459 .01909 Mdot
.25714 .53926 Mdot
.8912 .39187 Mdot
.67604 .48506 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50325 .00138 Mdot
.51034 .00439 Mdot
.53294 .01397 Mdot
.6046 .04429 Mdot
.82211 .13443 Mdot
.25427 .26709 Mdot
.44777 .11959 Mdot
.56434 .07204 Mdot
.7748 .13007 Mdot
.22111 .27583 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.51939 .00822 Mdot
.56172 .02616 Mdot
.69432 .08195 Mdot
.0512 .22056 Mdot
.33259 .17391 Mdot
.40669 .04579 Mdot
.3487 .58219 Mdot
.09642 .46212 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47787 .60865 Mdot
.4296 .5882 Mdot
.27914 .52504 Mdot
.89393 .37996 Mdot
.65631 .47118 Mdot
.61724 .59389 Mdot
.73854 .07497 Mdot
.09796 .22213 Mdot
.31954 .13694 Mdot
.49822 .61728 Mdot
.49434 .61563 Mdot
.48197 .61039 Mdot
.44261 .59371 Mdot
.31901 .54165 Mdot
.97878 .40776 Mdot
.67028 .42737 Mdot
.5712 .5568 Mdot
.57538 .00258 Mdot
.68845 .06988 Mdot
.02262 .20653 Mdot
.49922 .6177 Mdot
.49753 .61698 Mdot
.49212 .61469 Mdot
.47489 .60738 Mdot
.42014 .5842 Mdot
.25056 .51323 Mdot
.84226 .36569 Mdot
.63369 .48913 Mdot
.60288 .59899 Mdot
.71587 .06983 Mdot
.06212 .214 Mdot
.49858 .61743 Mdot
.49546 .61611 Mdot
.48554 .6119 Mdot
.45396 .59852 Mdot
.35428 .55643 Mdot
.06531 .43944 Mdot
.6811 .38058 Mdot
.51359 .51451 Mdot
.36646 .5271 Mdot
.0417 .41732 Mdot
.6551 .37911 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.51548 .00657 Mdot
.5493 .0209 Mdot
.65589 .06587 Mdot
.96067 .18837 Mdot
.32385 .22446 Mdot
.47354 .09251 Mdot
.58373 .0681 Mdot
.81379 .14218 Mdot
.26366 .27804 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.5059 .0025 Mdot
.5188 .00797 Mdot
.55983 .02536 Mdot
.6885 .07953 Mdot
.03831 .21619 Mdot
.3312 .18102 Mdot
.41577 .05227 Mdot
.37981 .59581 Mdot
.18023 .49468 Mdot
.76448 .36109 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.48718 .6126 Mdot
.45916 .60072 Mdot
.37057 .56328 Mdot
.10852 .45608 Mdot
.69602 .36309 Mdot
.50865 .50223 Mdot
.33424 .51025 Mdot
.95377 .38289 Mdot
.64167 .42515 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50559 .00237 Mdot
.5178 .00755 Mdot
.55664 .02401 Mdot
.67868 .07542 Mdot
.01586 .20839 Mdot
.3293 .19371 Mdot
.43302 .0641 Mdot
.43921 .00383 Mdot
.35642 .56687 Mdot
.0863 .45109 Mdot
.49777 .61709 Mdot
.49291 .61503 Mdot
.47741 .60846 Mdot
.42815 .58759 Mdot
.27474 .52322 Mdot
.88548 .37746 Mdot
.65355 .4747 Mdot
.61785 .59597 Mdot
.7432 .07747 Mdot
.10707 .22488 Mdot
.32218 .13294 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.51371 .00581 Mdot
.54365 .01851 Mdot
.63825 .05847 Mdot
.91511 .17111 Mdot
.31335 .24613 Mdot
.49153 .11012 Mdot
.65701 .10227 Mdot
.02162 .22534 Mdot
.3539 .20536 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48266 .61068 Mdot
.44482 .59464 Mdot
.32585 .54451 Mdot
.99474 .4134 Mdot
.67152 .41827 Mdot
.5586 .54824 Mdot
.5316 .60135 Mdot
.55169 .01242 Mdot
.49892 .61758 Mdot
.49655 .61657 Mdot
.48901 .61337 Mdot
.46501 .6032 Mdot
.38893 .57102 Mdot
.15946 .47621 Mdot
.72885 .3519 Mdot
.53487 .49815 Mdot
.39278 .53022 Mdot
.10174 .43816 Mdot
.66828 .35014 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50368 .00156 Mdot
.51173 .00498 Mdot
.53737 .01585 Mdot
.61856 .05017 Mdot
.86158 .15019 Mdot
.28703 .26294 Mdot
.48018 .11937 Mdot
.64367 .10104 Mdot
.99457 .21687 Mdot
.35361 .2219 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49917 .61768 Mdot
.49735 .61691 Mdot
.49155 .61445 Mdot
.47307 .60661 Mdot
.41438 .58177 Mdot
.23338 .50617 Mdot
.81495 .35943 Mdot
.61564 .49486 Mdot
.57493 .59288 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50611 .00259 Mdot
.51946 .00825 Mdot
.56194 .02625 Mdot
.69501 .08224 Mdot
.0527 .22106 Mdot
.33278 .1731 Mdot
.40569 .04506 Mdot
.34528 .5807 Mdot
.08765 .45881 Mdot
.70509 .3816 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47773 .60859 Mdot
.42917 .58802 Mdot
.27782 .5245 Mdot
.89138 .3792 Mdot
.65551 .47226 Mdot
.61753 .59456 Mdot
.74024 .07584 Mdot
.10124 .22311 Mdot
.32041 .13546 Mdot
.49757 .617 Mdot
.49226 .61475 Mdot
.47536 .60758 Mdot
.42163 .58483 Mdot
.25503 .51507 Mdot
.84983 .3676 Mdot
.63791 .48706 Mdot
.60793 .5995 Mdot
.72772 .07403 Mdot
.0839 .22013 Mdot
.31998 .14591 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47422 .6071 Mdot
.41802 .5833 Mdot
.24421 .51062 Mdot
.83183 .36317 Mdot
.62732 .49164 Mdot
.59405 .59747 Mdot
.6938 .06165 Mdot
.01754 .20009 Mdot
.31503 .18386 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50527 .00223 Mdot
.51679 .00712 Mdot
.55345 .02266 Mdot
.66878 .07128 Mdot
.99243 .20003 Mdot
.32743 .20704 Mdot
.45139 .07661 Mdot
.50357 .03225 Mdot
.56111 .03556 Mdot
.70809 .09084 Mdot
.49858 .61743 Mdot
.49549 .61612 Mdot
.48562 .61193 Mdot
.4542 .59862 Mdot
.35504 .55675 Mdot
.06726 .44018 Mdot
.68157 .37966 Mdot
.51289 .51378 Mdot
.36352 .52572 Mdot
.03362 .41414 Mdot
.65366 .38321 Mdot
.49982 .61796 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49434 .61563 Mdot
.48195 .61038 Mdot
.44256 .59369 Mdot
.31885 .54158 Mdot
.97841 .40763 Mdot
.67025 .42758 Mdot
.57148 .55699 Mdot
.57636 .00301 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47726 .60839 Mdot
.42765 .58738 Mdot
.27321 .52259 Mdot
.88258 .37661 Mdot
.65253 .47585 Mdot
.61782 .59658 Mdot
.74413 .07807 Mdot
.10902 .22551 Mdot
.32287 .13216 Mdot
.49801 .61719 Mdot
.49365 .61534 Mdot
.47978 .60946 Mdot
.43566 .59077 Mdot
.29765 .53274 Mdot
.93152 .39176 Mdot
.66497 .4533 Mdot
.60388 .58028 Mdot
.68779 .05186 Mdot
.99243 .18828 Mdot
.30842 .19529 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50195 .00082 Mdot
.5062 .00263 Mdot
.51974 .00837 Mdot
.56283 .02663 Mdot
.69773 .08337 Mdot
.0586 .22303 Mdot
.33354 .16992 Mdot
.4019 .04224 Mdot
.33224 .57498 Mdot
.05502 .4467 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47988 .6095 Mdot
.43599 .59091 Mdot
.29865 .53315 Mdot
.93364 .39245 Mdot
.66531 .4522 Mdot
.60271 .57934 Mdot
.6837 .05006 Mdot
.98301 .18498 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52195 .00931 Mdot
.56983 .02959 Mdot
.71914 .09227 Mdot
.1027 .23705 Mdot
.34268 .14832 Mdot
.38328 .02509 Mdot
.26408 .54436 Mdot
.90708 .3974 Mdot
.68168 .47872 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51433 .00608 Mdot
.54563 .01935 Mdot
.64445 .06107 Mdot
.93141 .17735 Mdot
.31809 .23898 Mdot
.48757 .10474 Mdot
.63841 .09322 Mdot
.97166 .20596 Mdot
.3472 .2321 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49399 .61548 Mdot
.48085 .60991 Mdot
.43904 .5922 Mdot
.30803 .53706 Mdot
.95397 .39922 Mdot
.668 .44129 Mdot
.58977 .56968 Mdot
.63916 .03053 Mdot
.87169 .14371 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00206 Mdot
.51551 .00658 Mdot
.54939 .02094 Mdot
.65617 .066 Mdot
.96139 .18863 Mdot
.32396 .22408 Mdot
.4731 .09218 Mdot
.58209 .06736 Mdot
.80882 .14013 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47649 .60806 Mdot
.42522 .58635 Mdot
.26585 .51954 Mdot
.86894 .37273 Mdot
.64714 .48095 Mdot
.61593 .59874 Mdot
.74363 .07892 Mdot
.10987 .22635 Mdot
.32409 .13239 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50495 .0021 Mdot
.51577 .00669 Mdot
.5502 .02128 Mdot
.65868 .06705 Mdot
.96766 .19096 Mdot
.32482 .22074 Mdot
.46914 .0892 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.50911 .00386 Mdot
.52902 .01231 Mdot
.59223 .03906 Mdot
.78616 .11986 Mdot
.21269 .26361 Mdot
.40702 .1201 Mdot
.46968 .03872 Mdot
.48712 .01078 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50079 .00033 Mdot
.50252 .00107 Mdot
.50802 .0034 Mdot
.52554 .01083 Mdot
.58121 .0344 Mdot
.75346 .10646 Mdot
.1644 .25397 Mdot
.37031 .12726 Mdot
.4025 .0199 Mdot
.49896 .61759 Mdot
.49669 .61663 Mdot
.48945 .61356 Mdot
.46638 .60378 Mdot
.39327 .57285 Mdot
.17179 .48115 Mdot
.73982 .35107 Mdot
.54611 .49831 Mdot
.42059 .54046 Mdot
.18083 .46986 Mdot
.72454 .33603 Mdot
.49796 .61717 Mdot
.49349 .61527 Mdot
.47926 .60924 Mdot
.43402 .59007 Mdot
.2926 .53064 Mdot
.92096 .38835 Mdot
.66306 .45864 Mdot
.60916 .58472 Mdot
.70645 .06013 Mdot
.0336 .20219 Mdot
.31072 .17127 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.48718 .6126 Mdot
.45917 .60072 Mdot
.37058 .56328 Mdot
.10857 .4561 Mdot
.69604 .36308 Mdot
.50866 .50222 Mdot
.33425 .51024 Mdot
.95378 .38289 Mdot
.64167 .42514 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51572 .00667 Mdot
.55006 .02122 Mdot
.65824 .06686 Mdot
.96658 .19056 Mdot
.32468 .22132 Mdot
.46984 .08972 Mdot
.57005 .06193 Mdot
.77197 .12479 Mdot
.21036 .27094 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00226 Mdot
.51695 .00719 Mdot
.55394 .02287 Mdot
.67031 .07192 Mdot
.99611 .20136 Mdot
.32774 .20496 Mdot
.44856 .07467 Mdot
.49355 .0278 Mdot
.52886 .02182 Mdot
.60722 .04843 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48646 .61229 Mdot
.45689 .59976 Mdot
.36345 .56028 Mdot
.08941 .44867 Mdot
.6882 .37007 Mdot
.50794 .50663 Mdot
.33959 .51399 Mdot
.96933 .3892 Mdot
.6448 .41746 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48278 .61073 Mdot
.44518 .5948 Mdot
.32698 .54498 Mdot
.99743 .41436 Mdot
.67173 .41674 Mdot
.55648 .5468 Mdot
.52419 .59807 Mdot
.52803 .00238 Mdot
.57371 .02823 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.5137 .00581 Mdot
.54364 .0185 Mdot
.6382 .05845 Mdot
.91499 .17106 Mdot
.31331 .24618 Mdot
.49155 .11015 Mdot
.65711 .10232 Mdot
.02187 .22544 Mdot
.35393 .20522 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51607 .00681 Mdot
.55115 .02168 Mdot
.66164 .06829 Mdot
.97501 .19367 Mdot
.32571 .21675 Mdot
.46419 .08558 Mdot
.54939 .05266 Mdot
.7075 .09772 Mdot
.09588 .24003 Mdot
.49964 .61788 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48834 .61309 Mdot
.46286 .60229 Mdot
.38219 .56817 Mdot
.14049 .46866 Mdot
.71438 .35468 Mdot
.52105 .49855 Mdot
.3592 .51801 Mdot
.01265 .40385 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52383 .0101 Mdot
.57578 .03211 Mdot
.73716 .09974 Mdot
.1365 .2468 Mdot
.35528 .13521 Mdot
.38569 .01879 Mdot
.25899 .53973 Mdot
.89394 .39242 Mdot
.67646 .48363 Mdot
.4989 .61757 Mdot
.49649 .61655 Mdot
.48881 .61329 Mdot
.46437 .60293 Mdot
.38693 .57017 Mdot
.1538 .47395 Mdot
.72423 .35255 Mdot
.53028 .49816 Mdot
.38147 .52606 Mdot
.07085 .42606 Mdot
.65743 .36253 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51215 .00515 Mdot
.53868 .0164 Mdot
.62267 .05191 Mdot
.87298 .1547 Mdot
.29423 .26034 Mdot
.4859 .11846 Mdot
.65646 .10541 Mdot
.02569 .2282 Mdot
.35655 .20449 Mdot
.499 .61761 Mdot
.49683 .61669 Mdot
.48989 .61375 Mdot
.4678 .60438 Mdot
.39775 .57474 Mdot
.18465 .48633 Mdot
.75267 .35105 Mdot
.55938 .49858 Mdot
.45311 .55236 Mdot
.27752 .50951 Mdot
.86675 .36417 Mdot
.49911 .61766 Mdot
.49716 .61683 Mdot
.49096 .6142 Mdot
.47122 .60583 Mdot
.40854 .5793 Mdot
.2161 .4991 Mdot
.79032 .35489 Mdot
.59565 .49772 Mdot
.53599 .58116 Mdot
.52984 .61424 Mdot
.56819 .0237 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50684 .0029 Mdot
.52179 .00924 Mdot
.56933 .02938 Mdot
.71761 .09164 Mdot
.0997 .23614 Mdot
.34183 .14964 Mdot
.38387 .02598 Mdot
.26676 .54566 Mdot
.91225 .39893 Mdot
.68279 .47622 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51686 .00715 Mdot
.55367 .02275 Mdot
.66948 .07157 Mdot
.99411 .20063 Mdot
.32757 .20609 Mdot
.45011 .07573 Mdot
.49903 .03023 Mdot
.5465 .02934 Mdot
.66272 .07183 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50223 .00094 Mdot
.5071 .00301 Mdot
.52261 .00959 Mdot
.57193 .03048 Mdot
.72552 .09492 Mdot
.11501 .24072 Mdot
.34662 .14314 Mdot
.38215 .02196 Mdot
.25662 .54045 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.5752 .03186 Mdot
.73539 .09901 Mdot
.13332 .24593 Mdot
.35385 .13629 Mdot
.38468 .01906 Mdot
.25728 .5393 Mdot
.8914 .39191 Mdot
.67607 .48495 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49026 .6139 Mdot
.46897 .60488 Mdot
.40143 .57629 Mdot
.1953 .49064 Mdot
.76441 .35172 Mdot
.57126 .49867 Mdot
.48148 .56254 Mdot
.36398 .54541 Mdot
.06639 .43412 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.51371 .00581 Mdot
.54365 .01851 Mdot
.63825 .05847 Mdot
.91511 .17111 Mdot
.31335 .24613 Mdot
.49153 .11012 Mdot
.65701 .10227 Mdot
.02161 .22534 Mdot
.3539 .20536 Mdot
.49754 .61699 Mdot
.49218 .61472 Mdot
.47508 .60747 Mdot
.42074 .58445 Mdot
.25238 .51398 Mdot
.8453 .36645 Mdot
.63543 .48832 Mdot
.60505 .59926 Mdot
.72104 .07169 Mdot
.07183 .2168 Mdot
.31849 .15245 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48126 .61009 Mdot
.44035 .59275 Mdot
.31205 .53874 Mdot
.96294 .40227 Mdot
.66892 .43632 Mdot
.5833 .56512 Mdot
.61702 .02084 Mdot
.81088 .11981 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00215 Mdot
.51614 .00684 Mdot
.55137 .02178 Mdot
.66233 .06858 Mdot
.9767 .19429 Mdot
.3259 .21582 Mdot
.463 .08473 Mdot
.5451 .05074 Mdot
.69394 .09199 Mdot
.06686 .23048 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49234 .61478 Mdot
.47558 .60768 Mdot
.42235 .58514 Mdot
.25722 .51598 Mdot
.8536 .36858 Mdot
.6399 .48596 Mdot
.61004 .59958 Mdot
.73239 .07562 Mdot
.5007 .00029 Mdot
.50221 .00094 Mdot
.50706 .00299 Mdot
.52248 .00953 Mdot
.5715 .0303 Mdot
.72421 .09438 Mdot
.11252 .23999 Mdot
.34577 .14415 Mdot
.3822 .02252 Mdot
.25764 .54105 Mdot
.89463 .39368 Mdot
.67837 .48438 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48027 .60967 Mdot
.43722 .59143 Mdot
.30243 .53473 Mdot
.94173 .39511 Mdot
.6665 .44793 Mdot
.59789 .57563 Mdot
.66704 .04274 Mdot
.94322 .17069 Mdot
.30277 .22222 Mdot
.49741 .61694 Mdot
.49176 .61454 Mdot
.47375 .6069 Mdot
.41654 .58268 Mdot
.23981 .50881 Mdot
.82483 .36156 Mdot
.62268 .4931 Mdot
.58686 .5959 Mdot
.67496 .05445 Mdot
.97575 .1859 Mdot
.31277 .20829 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.5023 .00097 Mdot
.50732 .0031 Mdot
.52331 .00988 Mdot
.57414 .03141 Mdot
.73219 .09768 Mdot
.12749 .24431 Mdot
.35136 .13836 Mdot
.38329 .01973 Mdot
.25543 .53901 Mdot
.88897 .39155 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50293 .00124 Mdot
.50935 .00396 Mdot
.52978 .01263 Mdot
.59462 .04007 Mdot
.79317 .12271 Mdot
.22172 .26486 Mdot
.4153 .11964 Mdot
.48775 .04478 Mdot
.54184 .03343 Mdot
.65798 .07178 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00322 Mdot
.52416 .01024 Mdot
.57683 .03255 Mdot
.74031 .10104 Mdot
.14209 .24831 Mdot
.35794 .1334 Mdot
.38788 .01851 Mdot
.26322 .54099 Mdot
.90065 .39395 Mdot
.67761 .48019 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48671 .6124 Mdot
.45768 .60009 Mdot
.36591 .56132 Mdot
.09597 .4512 Mdot
.69064 .36753 Mdot
.50763 .50493 Mdot
.33607 .512 Mdot
.95985 .38552 Mdot
.64322 .42234 Mdot
.50055 .00023 Mdot
.50177 .00075 Mdot
.50562 .00238 Mdot
.51792 .0076 Mdot
.55703 .02417 Mdot
.67986 .07592 Mdot
.01862 .20936 Mdot
.32951 .19214 Mdot
.43085 .06263 Mdot
.43168 .00052 Mdot
.33317 .55715 Mdot
.02778 .42929 Mdot
.49865 .61746 Mdot
.49571 .61622 Mdot
.48634 .61224 Mdot
.4565 .59959 Mdot
.36223 .55977 Mdot
.08616 .44742 Mdot
.68707 .37138 Mdot
.50829 .50754 Mdot
.34195 .51523 Mdot
.97563 .39163 Mdot
.64572 .41414 Mdot
.49741 .61693 Mdot
.49173 .61453 Mdot
.47367 .60687 Mdot
.41628 .58257 Mdot
.23902 .50848 Mdot
.8236 .36129 Mdot
.62184 .49334 Mdot
.58549 .59557 Mdot
.6713 .05303 Mdot
.96725 .18291 Mdot
.31198 .21305 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52456 .01041 Mdot
.57811 .03309 Mdot
.74417 .10263 Mdot
.1488 .25008 Mdot
.36136 .13137 Mdot
.39127 .01849 Mdot
.27049 .54339 Mdot
.91295 .39706 Mdot
.67957 .4738 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47911 .60917 Mdot
.43352 .58986 Mdot
.29108 .53 Mdot
.91782 .38734 Mdot
.66242 .46019 Mdot
.61052 .58596 Mdot
.7114 .06235 Mdot
.04403 .20557 Mdot
.31145 .16528 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52311 .0098 Mdot
.57352 .03115 Mdot
.73033 .09691 Mdot
.12405 .24333 Mdot
.34997 .13963 Mdot
.38273 .02025 Mdot
.25507 .53914 Mdot
.8888 .39167 Mdot
.67609 .48657 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50936 .00397 Mdot
.52983 .01265 Mdot
.59478 .04014 Mdot
.79364 .1229 Mdot
.22231 .26494 Mdot
.41586 .11962 Mdot
.48898 .0452 Mdot
.5456 .03499 Mdot
.66969 .07669 Mdot
.49765 .61704 Mdot
.4925 .61485 Mdot
.4761 .6079 Mdot
.424 .58583 Mdot
.26218 .51802 Mdot
.86232 .37091 Mdot
.64417 .48321 Mdot
.6139 .59932 Mdot
.74026 .07809 Mdot
.1049 .22536 Mdot
.32334 .13501 Mdot
.49891 .61757 Mdot
.49652 .61656 Mdot
.48891 .61333 Mdot
.46468 .60306 Mdot
.3879 .57058 Mdot
.15653 .47504 Mdot
.72643 .35222 Mdot
.53245 .49815 Mdot
.38681 .52802 Mdot
.08533 .43171 Mdot
.6619 .35634 Mdot
.49943 .61779 Mdot
.49819 .61726 Mdot
.49422 .61558 Mdot
.48159 .61023 Mdot
.4414 .59319 Mdot
.31527 .54009 Mdot
.97021 .40478 Mdot
.66957 .43223 Mdot
.57783 .56133 Mdot
.59823 .01261 Mdot
.7568 .098 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51239 .00525 Mdot
.53945 .01673 Mdot
.62508 .05292 Mdot
.87961 .15731 Mdot
.29799 .25857 Mdot
.4884 .11768 Mdot
.66144 .10694 Mdot
.03719 .23223 Mdot
.35766 .19806 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51251 .00531 Mdot
.53984 .01689 Mdot
.62632 .05344 Mdot
.88299 .15863 Mdot
.29979 .2576 Mdot
.48944 .11721 Mdot
.66327 .10743 Mdot
.04125 .23361 Mdot
.35805 .19579 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50596 .00253 Mdot
.51898 .00805 Mdot
.56042 .02561 Mdot
.69032 .08028 Mdot
.04236 .21757 Mdot
.33161 .17877 Mdot
.41283 .0502 Mdot
.36975 .59141 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49248 .61485 Mdot
.47604 .60788 Mdot
.42381 .58575 Mdot
.26161 .51779 Mdot
.86131 .37064 Mdot
.6437 .48354 Mdot
.61352 .59938 Mdot
.73954 .07789 Mdot
.10379 .22511 Mdot
.49917 .61768 Mdot
.49736 .61692 Mdot
.4916 .61447 Mdot
.47325 .60669 Mdot
.41495 .58201 Mdot
.23507 .50686 Mdot
.81751 .35997 Mdot
.61752 .49443 Mdot
.57823 .59375 Mdot
.65162 .04536 Mdot
.91956 .1656 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52304 .00977 Mdot
.57329 .03105 Mdot
.72962 .09662 Mdot
.12273 .24296 Mdot
.34946 .14012 Mdot
.38256 .02046 Mdot
.25508 .53924 Mdot
.88898 .39177 Mdot
.67623 .48655 Mdot
.49779 .6171 Mdot
.49297 .61505 Mdot
.47761 .60854 Mdot
.42877 .58785 Mdot
.27663 .524 Mdot
.88909 .37852 Mdot
.65477 .47322 Mdot
.61771 .59513 Mdot
.74156 .07654 Mdot
.1038 .22388 Mdot
.32115 .13433 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48939 .61353 Mdot
.46619 .6037 Mdot
.39267 .5726 Mdot
.17009 .48047 Mdot
.73823 .35114 Mdot
.54446 .49828 Mdot
.41653 .53896 Mdot
.16904 .46508 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48466 .61153 Mdot
.45117 .59733 Mdot
.34558 .55277 Mdot
.04302 .43104 Mdot
.67672 .39165 Mdot
.52428 .52382 Mdot
.40812 .54624 Mdot
.16168 .46572 Mdot
.71233 .34032 Mdot
.5007 .0003 Mdot
.50223 .00095 Mdot
.5071 .00301 Mdot
.52263 .00959 Mdot
.57198 .0305 Mdot
.72565 .09498 Mdot
.11527 .2408 Mdot
.34671 .14304 Mdot
.38215 .0219 Mdot
.25653 .5404 Mdot
.89237 .39297 Mdot
.67763 .48532 Mdot
.4997 .61791 Mdot
.49905 .61763 Mdot
.49696 .61674 Mdot
.49031 .61393 Mdot
.46914 .60495 Mdot
.40197 .57652 Mdot
.19687 .49128 Mdot
.76621 .35188 Mdot
.57306 .49866 Mdot
.48568 .56403 Mdot
.37685 .55077 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51399 .00593 Mdot
.54454 .01888 Mdot
.64104 .05964 Mdot
.92247 .17393 Mdot
.31565 .243 Mdot
.49013 .10783 Mdot
.6498 .09869 Mdot
.00244 .21794 Mdot
.35142 .21568 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .61259 Mdot
.45914 .60071 Mdot
.37051 .56325 Mdot
.10836 .45602 Mdot
.69594 .36315 Mdot
.50862 .50226 Mdot
.33423 .51025 Mdot
.95375 .38289 Mdot
.64168 .42516 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50925 .00392 Mdot
.52947 .0125 Mdot
.59364 .03966 Mdot
.79031 .12155 Mdot
.2181 .26439 Mdot
.41193 .1198 Mdot
.48029 .04225 Mdot
.51918 .02403 Mdot
.58675 .04176 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51819 .00771 Mdot
.5579 .02454 Mdot
.68255 .07704 Mdot
.02482 .21153 Mdot
.33001 .18862 Mdot
.426 .05933 Mdot
.41495 .6112 Mdot
.28231 .53606 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50995 .00422 Mdot
.53168 .01343 Mdot
.60063 .04261 Mdot
.81066 .12981 Mdot
.24229 .26676 Mdot
.43548 .11939 Mdot
.5345 .0612 Mdot
.4987 .61748 Mdot
.49587 .61628 Mdot
.48684 .61245 Mdot
.4581 .60027 Mdot
.36722 .56187 Mdot
.09948 .45256 Mdot
.69205 .36623 Mdot
.5077 .5041 Mdot
.33491 .51124 Mdot
.95655 .3842 Mdot
.64256 .42398 Mdot
.50035 .00015 Mdot
.50112 .00047 Mdot
.50356 .00151 Mdot
.51136 .00482 Mdot
.53617 .01533 Mdot
.61476 .04857 Mdot
.85096 .14598 Mdot
.27945 .26482 Mdot
.47328 .11979 Mdot
.62722 .09514 Mdot
.9523 .20091 Mdot
.34787 .24447 Mdot
.49999 .61803 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49937 .61777 Mdot
.498 .61719 Mdot
.49364 .61534 Mdot
.47973 .60944 Mdot
.43551 .5907 Mdot
.29718 .53254 Mdot
.93054 .39143 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51444 .00612 Mdot
.54597 .01949 Mdot
.6455 .06151 Mdot
.93413 .17838 Mdot
.31877 .23772 Mdot
.48661 .10373 Mdot
.63439 .09133 Mdot
.96064 .20163 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.5132 .0056 Mdot
.54205 .01783 Mdot
.63324 .05636 Mdot
.90175 .16595 Mdot
.30845 .25136 Mdot
.49234 .11365 Mdot
.66474 .10655 Mdot
.04243 .23343 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00114 Mdot
.50859 .00364 Mdot
.52735 .0116 Mdot
.58694 .03683 Mdot
.77056 .11348 Mdot
.19092 .2598 Mdot
.38881 .1223 Mdot
.43315 .0274 Mdot
.38014 .58527 Mdot
.16386 .48436 Mdot
.49846 .61738 Mdot
.49509 .61595 Mdot
.48436 .6114 Mdot
.45021 .59693 Mdot
.34258 .55152 Mdot
.03548 .42824 Mdot
.6756 .39561 Mdot
.52884 .52733 Mdot
.4251 .55392 Mdot
.21311 .48702 Mdot
.76877 .34342 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48364 .6111 Mdot
.44793 .59596 Mdot
.33549 .54854 Mdot
.01794 .42178 Mdot
.67354 .40518 Mdot
.54084 .53602 Mdot
.46872 .57347 Mdot
.35 .54466 Mdot
.03813 .42529 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50578 .00245 Mdot
.51842 .00781 Mdot
.55864 .02485 Mdot
.68484 .07799 Mdot
.03004 .21334 Mdot
.33045 .18566 Mdot
.42198 .05657 Mdot
.40111 .60514 Mdot
.24128 .51925 Mdot
.84307 .37193 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50714 .00303 Mdot
.52274 .00964 Mdot
.57234 .03065 Mdot
.72675 .09543 Mdot
.11734 .2414 Mdot
.34744 .14221 Mdot
.38218 .02147 Mdot
.25588 .53998 Mdot
.89102 .39254 Mdot
.67715 .48585 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50287 .00122 Mdot
.50916 .00388 Mdot
.52917 .01237 Mdot
.5927 .03926 Mdot
.78755 .12042 Mdot
.21451 .26388 Mdot
.40866 .11999 Mdot
.47319 .03988 Mdot
.49768 .01514 Mdot
.5187 .01299 Mdot
.50055 .00023 Mdot
.50176 .00074 Mdot
.5056 .00237 Mdot
.51783 .00756 Mdot
.55675 .02405 Mdot
.67901 .07556 Mdot
.01664 .20867 Mdot
.32936 .19327 Mdot
.43241 .06369 Mdot
.4371 .0029 Mdot
.34987 .56413 Mdot
.0694 .44469 Mdot
.5 0 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00213 Mdot
.51598 .00677 Mdot
.55086 .02156 Mdot
.66076 .06792 Mdot
.97282 .19287 Mdot
.32546 .21794 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52636 .01118 Mdot
.58382 .03551 Mdot
.76127 .10967 Mdot
.17685 .25685 Mdot
.37848 .12461 Mdot
.41502 .02259 Mdot
.33007 .56553 Mdot
.03596 .43627 Mdot
.68837 .40321 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51556 .0066 Mdot
.54953 .02099 Mdot
.65659 .06617 Mdot
.96244 .18902 Mdot
.32411 .22352 Mdot
.47246 .09169 Mdot
.57971 .06628 Mdot
.80158 .13713 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48246 .61059 Mdot
.44416 .59436 Mdot
.32381 .54365 Mdot
.98993 .41169 Mdot
.67115 .42102 Mdot
.5624 .55082 Mdot
.54486 .6072 Mdot
.59374 .0302 Mdot
.4989 .61757 Mdot
.49649 .61655 Mdot
.48882 .61329 Mdot
.46441 .60294 Mdot
.38704 .57022 Mdot
.1541 .47407 Mdot
.72447 .35251 Mdot
.53051 .49816 Mdot
.38205 .52628 Mdot
.07241 .42667 Mdot
.65787 .36183 Mdot
.49774 .61708 Mdot
.4928 .61498 Mdot
.47707 .60831 Mdot
.42708 .58713 Mdot
.27148 .52187 Mdot
.87932 .37567 Mdot
.65132 .47713 Mdot
.61763 .59721 Mdot
.74476 .07857 Mdot
.1105 .22604 Mdot
.32348 .13163 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48126 .61009 Mdot
.44035 .59275 Mdot
.31203 .53873 Mdot
.96289 .40225 Mdot
.66891 .43634 Mdot
.58334 .56515 Mdot
.61714 .02089 Mdot
.81122 .11995 Mdot
.22659 .25671 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50717 .00304 Mdot
.52285 .00969 Mdot
.5727 .0308 Mdot
.72783 .09588 Mdot
.11938 .24199 Mdot
.34819 .14141 Mdot
.38227 .02107 Mdot
.25543 .53964 Mdot
.89 .39218 Mdot
.49754 .61699 Mdot
.49215 .6147 Mdot
.47499 .60743 Mdot
.42047 .58434 Mdot
.25155 .51364 Mdot
.84391 .3661 Mdot
.63464 .4887 Mdot
.60408 .59915 Mdot
.71874 .07087 Mdot
.06755 .21558 Mdot
.31805 .15481 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48244 .61059 Mdot
.4441 .59434 Mdot
.32363 .54358 Mdot
.98951 .41154 Mdot
.67112 .42125 Mdot
.56273 .55105 Mdot
.54601 .6077 Mdot
.59736 .03174 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52247 .00953 Mdot
.57147 .03029 Mdot
.72413 .09434 Mdot
.11236 .23994 Mdot
.34571 .14422 Mdot
.38221 .02256 Mdot
.25772 .54109 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.47953 .60935 Mdot
.43486 .59043 Mdot
.29518 .53171 Mdot
.92632 .39007 Mdot
.66408 .45596 Mdot
.60661 .58252 Mdot
.69738 .05609 Mdot
.01394 .19565 Mdot
.30962 .18274 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.51481 .00628 Mdot
.54716 .01999 Mdot
.64922 .06308 Mdot
.94373 .18202 Mdot
.3209 .2331 Mdot
.48263 .09995 Mdot
.61835 .08388 Mdot
.91567 .18376 Mdot
.33365 .25833 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50308 .0013 Mdot
.5098 .00416 Mdot
.53122 .01324 Mdot
.59916 .04199 Mdot
.80641 .12809 Mdot
.23755 .26646 Mdot
.43069 .11937 Mdot
.52312 .05713 Mdot
.65012 .07849 Mdot
.97036 .19792 Mdot
.4976 .61701 Mdot
.49234 .61479 Mdot
.47561 .60769 Mdot
.42244 .58517 Mdot
.25747 .51608 Mdot
.85403 .3687 Mdot
.64012 .48583 Mdot
.61026 .59958 Mdot
.73287 .07578 Mdot
.09284 .22247 Mdot
.32131 .1412 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.5053 .00225 Mdot
.51687 .00716 Mdot
.55372 .02277 Mdot
.66961 .07163 Mdot
.99443 .20075 Mdot
.3276 .20591 Mdot
.44986 .07556 Mdot
.49814 .02984 Mdot
.49842 .61737 Mdot
.49498 .6159 Mdot
.484 .61125 Mdot
.44906 .59644 Mdot
.33902 .55002 Mdot
.02662 .42496 Mdot
.67448 .4004 Mdot
.53469 .53164 Mdot
.44653 .56355 Mdot
.27965 .5149 Mdot
.87818 .36991 Mdot
.49749 .61697 Mdot
.49201 .61465 Mdot
.47455 .60724 Mdot
.41908 .58375 Mdot
.24738 .51192 Mdot
.83699 .3644 Mdot
.63055 .49045 Mdot
.5987 .59835 Mdot
.70558 .06606 Mdot
.04196 .20789 Mdot
.31613 .16945 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50562 .00238 Mdot
.51791 .0076 Mdot
.55702 .02417 Mdot
.67984 .07591 Mdot
.01857 .20935 Mdot
.32951 .19217 Mdot
.43089 .06266 Mdot
.43184 .00058 Mdot
.33363 .55734 Mdot
.0289 .4297 Mdot
.49915 .61767 Mdot
.49729 .61688 Mdot
.49135 .61437 Mdot
.47245 .60635 Mdot
.41243 .58094 Mdot
.22759 .50379 Mdot
.80637 .35771 Mdot
.60907 .4961 Mdot
.56287 .58948 Mdot
.60853 .02822 Mdot
.80467 .12122 Mdot
.49924 .61771 Mdot
.49757 .617 Mdot
.49224 .61474 Mdot
.47529 .60756 Mdot
.42141 .58474 Mdot
.25439 .51481 Mdot
.84873 .36732 Mdot
.63732 .48737 Mdot
.60727 .59946 Mdot
.72621 .07351 Mdot
.08122 .21941 Mdot
.49788 .61713 Mdot
.49324 .61517 Mdot
.47847 .60891 Mdot
.43151 .58901 Mdot
.28496 .52746 Mdot
.9054 .38346 Mdot
.65954 .46608 Mdot
.61487 .59043 Mdot
.72793 .06987 Mdot
.07742 .216 Mdot
.31531 .14702 Mdot
.49824 .61729 Mdot
.49438 .61565 Mdot
.48209 .61044 Mdot
.44299 .59387 Mdot
.3202 .54215 Mdot
.98153 .40872 Mdot
.6705 .42581 Mdot
.56903 .55532 Mdot
.5679 .61733 Mdot
.66555 .06035 Mdot
.96912 .18761 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50612 .0026 Mdot
.5195 .00827 Mdot
.56205 .0263 Mdot
.69535 .08238 Mdot
.05344 .22131 Mdot
.33287 .1727 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51875 .00795 Mdot
.55969 .0253 Mdot
.68808 .07935 Mdot
.03735 .21586 Mdot
.33111 .18156 Mdot
.41648 .05276 Mdot
.38224 .59687 Mdot
.18705 .4974 Mdot
.77156 .36124 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.47877 .60903 Mdot
.43246 .58941 Mdot
.28785 .52866 Mdot
.91122 .38527 Mdot
.66097 .46336 Mdot
.61305 .58842 Mdot
.72079 .06659 Mdot
.06326 .21166 Mdot
.31332 .15454 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50387 .00164 Mdot
.51235 .00524 Mdot
.53932 .01667 Mdot
.62466 .05275 Mdot
.87846 .15686 Mdot
.29736 .25889 Mdot
.48801 .11783 Mdot
.66071 .10673 Mdot
.03554 .23166 Mdot
.49793 .61716 Mdot
.49342 .61524 Mdot
.47903 .60914 Mdot
.43328 .58976 Mdot
.29034 .5297 Mdot
.91631 .38687 Mdot
.6621 .46093 Mdot
.61114 .58654 Mdot
.71367 .06337 Mdot
.04874 .20708 Mdot
.31184 .1626 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.5104 .00441 Mdot
.53312 .01404 Mdot
.60517 .04453 Mdot
.82373 .13508 Mdot
.25586 .26707 Mdot
.44943 .11963 Mdot
.5684 .07353 Mdot
.78685 .13501 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60745 Mdot
.42061 .5844 Mdot
.25198 .51381 Mdot
.84463 .36628 Mdot
.63505 .4885 Mdot
.60458 .59921 Mdot
.71995 .0713 Mdot
.0698 .21622 Mdot
.31828 .15357 Mdot
.4996 .61786 Mdot
.49873 .6175 Mdot
.49595 .61632 Mdot
.4871 .61256 Mdot
.45892 .60062 Mdot
.36981 .56296 Mdot
.10648 .45529 Mdot
.69508 .36377 Mdot
.50834 .50262 Mdot
.3341 .51035 Mdot
.95368 .38292 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.485 .61167 Mdot
.45223 .59778 Mdot
.34888 .55416 Mdot
.05142 .43419 Mdot
.67816 .38735 Mdot
.51972 .52012 Mdot
.3908 .53835 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50513 .00218 Mdot
.51635 .00693 Mdot
.55204 .02206 Mdot
.66441 .06945 Mdot
.98181 .19617 Mdot
.32644 .21299 Mdot
.45934 .08214 Mdot
.53191 .04485 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50721 .00306 Mdot
.52297 .00974 Mdot
.57307 .03096 Mdot
.72895 .09634 Mdot
.12149 .2426 Mdot
.34898 .1406 Mdot
.38244 .02068 Mdot
.25515 .53937 Mdot
.88926 .3919 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.5064 .00272 Mdot
.5204 .00865 Mdot
.56493 .02752 Mdot
.70416 .08605 Mdot
.07229 .22752 Mdot
.33568 .16278 Mdot
.39409 .0361 Mdot
.30511 .56304 Mdot
.99157 .42425 Mdot
.69067 .43207 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49233 .61478 Mdot
.47556 .60767 Mdot
.42228 .5851 Mdot
.25699 .51588 Mdot
.8532 .36848 Mdot
.63969 .48608 Mdot
.60982 .59958 Mdot
.73193 .07547 Mdot
.09124 .22206 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .00179 Mdot
.51347 .00571 Mdot
.54288 .01818 Mdot
.63584 .05745 Mdot
.90871 .16864 Mdot
.31113 .24871 Mdot
.49221 .11191 Mdot
.6616 .10469 Mdot
.03383 .23005 Mdot
.3557 .19893 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50756 .0032 Mdot
.52407 .01021 Mdot
.57657 .03244 Mdot
.73953 .10072 Mdot
.1407 .24794 Mdot
.35726 .13384 Mdot
.38729 .01856 Mdot
.26202 .54062 Mdot
.89871 .39349 Mdot
.67728 .48118 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51813 .00769 Mdot
.55771 .02446 Mdot
.68195 .07679 Mdot
.02345 .21105 Mdot
.3299 .1894 Mdot
.42707 .06006 Mdot
.41863 .61282 Mdot
.29339 .54063 Mdot
.93823 .39853 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50544 .00231 Mdot
.51733 .00735 Mdot
.55517 .02339 Mdot
.67413 .07352 Mdot
.0052 .20461 Mdot
.32847 .19979 Mdot
.44144 .06982 Mdot
.46855 .01675 Mdot
.44879 .60582 Mdot
.35353 .55916 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.5028 .00119 Mdot
.50892 .00378 Mdot
.5284 .01204 Mdot
.59026 .03823 Mdot
.78036 .11749 Mdot
.20486 .26236 Mdot
.40017 .12071 Mdot
.45536 .03411 Mdot
.44445 .6113 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00304 Mdot
.52286 .00969 Mdot
.57272 .03081 Mdot
.7279 .09591 Mdot
.11951 .24203 Mdot
.34824 .14136 Mdot
.38228 .02104 Mdot
.25541 .53962 Mdot
.88994 .39216 Mdot
.67672 .48625 Mdot
.49739 .61693 Mdot
.4917 .61451 Mdot
.47355 .60682 Mdot
.41592 .58241 Mdot
.23795 .50804 Mdot
.82192 .36092 Mdot
.62067 .49365 Mdot
.58357 .59511 Mdot
.66615 .05104 Mdot
.95509 .17857 Mdot
.3105 .21966 Mdot
.49993 .61801 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47783 .60863 Mdot
.42947 .58814 Mdot
.27873 .52488 Mdot
.89315 .37973 Mdot
.65607 .47151 Mdot
.61734 .5941 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48389 .6112 Mdot
.44871 .59629 Mdot
.33791 .54956 Mdot
.02387 .42395 Mdot
.67416 .4019 Mdot
.5366 .53301 Mdot
.45344 .56664 Mdot
.30143 .52409 Mdot
.92305 .38418 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50556 .00236 Mdot
.51772 .00752 Mdot
.55642 .02391 Mdot
.67797 .07512 Mdot
.01422 .20781 Mdot
.32917 .19465 Mdot
.43432 .06499 Mdot
.44372 .00581 Mdot
.37046 .57275 Mdot
.12364 .46549 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51813 .00769 Mdot
.55769 .02445 Mdot
.68191 .07677 Mdot
.02335 .21102 Mdot
.32989 .18945 Mdot
.42714 .06011 Mdot
.41889 .61293 Mdot
.29417 .54095 Mdot
.93985 .39905 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00343 Mdot
.52579 .01094 Mdot
.582 .03474 Mdot
.75583 .10744 Mdot
.16824 .25488 Mdot
.37273 .12638 Mdot
.40601 .02057 Mdot
.30638 .55645 Mdot
.98282 .41807 Mdot
.68499 .43396 Mdot
.49919 .61769 Mdot
.49743 .61694 Mdot
.4918 .61456 Mdot
.47388 .60696 Mdot
.41694 .58285 Mdot
.24101 .5093 Mdot
.82672 .36199 Mdot
.62396 .49272 Mdot
.5889 .59637 Mdot
.68036 .05653 Mdot
.98807 .19017 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50386 .00164 Mdot
.51229 .00521 Mdot
.53913 .01659 Mdot
.62408 .0525 Mdot
.87685 .15622 Mdot
.29646 .25933 Mdot
.48743 .11803 Mdot
.65958 .10639 Mdot
.03297 .23076 Mdot
.35725 .20042 Mdot
.49878 .61752 Mdot
.4961 .61638 Mdot
.48758 .61277 Mdot
.46046 .60127 Mdot
.37463 .56499 Mdot
.1196 .46042 Mdot
.70158 .35969 Mdot
.51134 .50046 Mdot
.33809 .51096 Mdot
.96175 .38544 Mdot
.64223 .42056 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.5201 .00852 Mdot
.56395 .0271 Mdot
.70116 .0848 Mdot
.06596 .22546 Mdot
.33462 .16604 Mdot
.39752 .03887 Mdot
.31709 .56833 Mdot
.01882 .4337 Mdot
.69239 .41629 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.5152 .00645 Mdot
.54841 .02052 Mdot
.6531 .06471 Mdot
.95364 .18574 Mdot
.32274 .22812 Mdot
.4776 .09571 Mdot
.59899 .07502 Mdot
.85946 .16098 Mdot
.3044 .27499 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50332 .00141 Mdot
.51059 .00449 Mdot
.53372 .0143 Mdot
.60707 .04533 Mdot
.82918 .13727 Mdot
.26108 .26693 Mdot
.45483 .11974 Mdot
.58173 .07843 Mdot
.82589 .1509 Mdot
.28216 .28199 Mdot
.50057 .00024 Mdot
.5018 .00076 Mdot
.50574 .00244 Mdot
.5183 .00776 Mdot
.55824 .02469 Mdot
.68361 .07748 Mdot
.02725 .21238 Mdot
.33021 .18724 Mdot
.42412 .05804 Mdot
.40847 .60836 Mdot
.26297 .52811 Mdot
.87953 .38106 Mdot
.4995 .61782 Mdot
.4984 .61736 Mdot
.49491 .61587 Mdot
.48378 .61115 Mdot
.44835 .59614 Mdot
.3368 .54909 Mdot
.02114 .42295 Mdot
.67387 .40341 Mdot
.53853 .53439 Mdot
.46043 .56976 Mdot
.32357 .53345 Mdot
.49871 .61749 Mdot
.4959 .61629 Mdot
.48693 .61249 Mdot
.45836 .60038 Mdot
.36806 .56222 Mdot
.10175 .45345 Mdot
.693 .36541 Mdot
.50784 .5036 Mdot
.33442 .51086 Mdot
.95508 .38359 Mdot
.64223 .42468 Mdot
.49771 .61706 Mdot
.49269 .61493 Mdot
.47671 .60816 Mdot
.42593 .58665 Mdot
.26801 .52043 Mdot
.87288 .37383 Mdot
.64879 .47954 Mdot
.61678 .59825 Mdot
.74464 .07902 Mdot
.11109 .22648 Mdot
.32411 .13165 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52456 .01041 Mdot
.5781 .03309 Mdot
.74415 .10262 Mdot
.14876 .25007 Mdot
.36134 .13138 Mdot
.39125 .01849 Mdot
.27044 .54337 Mdot
.91287 .39704 Mdot
.67956 .47384 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47591 .60782 Mdot
.4234 .58558 Mdot
.26037 .51727 Mdot
.85911 .37004 Mdot
.64265 .48425 Mdot
.61264 .59949 Mdot
.73782 .07737 Mdot
.10104 .22448 Mdot
.32268 .13698 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50412 .00175 Mdot
.51314 .00557 Mdot
.54184 .01774 Mdot
.63258 .05608 Mdot
.89998 .16526 Mdot
.30773 .252 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.4793 .60926 Mdot
.43414 .59012 Mdot
.29299 .5308 Mdot
.92176 .3886 Mdot
.66322 .45825 Mdot
.6088 .5844 Mdot
.70516 .05955 Mdot
.03084 .20128 Mdot
.31055 .17287 Mdot
.49801 .61719 Mdot
.49365 .61534 Mdot
.47976 .60945 Mdot
.43561 .59075 Mdot
.29748 .53267 Mdot
.93117 .39164 Mdot
.66491 .45348 Mdot
.60408 .58043 Mdot
.68846 .05215 Mdot
.99395 .1888 Mdot
.30851 .19441 Mdot
.49855 .61742 Mdot
.49537 .61607 Mdot
.48525 .61178 Mdot
.45302 .59812 Mdot
.35135 .5552 Mdot
.05773 .43657 Mdot
.6794 .38421 Mdot
.51671 .51748 Mdot
.37902 .53294 Mdot
.07685 .43128 Mdot
.66383 .36278 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52399 .01017 Mdot
.57631 .03233 Mdot
.73876 .1004 Mdot
.13935 .24758 Mdot
.35661 .13428 Mdot
.38674 .01862 Mdot
.26094 .54029 Mdot
.89698 .39309 Mdot
.67698 .48207 Mdot
.49834 .61733 Mdot
.4947 .61579 Mdot
.48311 .61087 Mdot
.44622 .59524 Mdot
.33019 .54632 Mdot
.00509 .41711 Mdot
.67236 .41239 Mdot
.55051 .54273 Mdot
.50316 .58877 Mdot
.46055 .5917 Mdot
.35938 .5555 Mdot
.49799 .61718 Mdot
.49358 .61531 Mdot
.47955 .60936 Mdot
.43493 .59046 Mdot
.29539 .5318 Mdot
.92676 .39021 Mdot
.66416 .45573 Mdot
.60639 .58233 Mdot
.69658 .05574 Mdot
.01218 .19505 Mdot
.30953 .18377 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50395 .00168 Mdot
.5126 .00534 Mdot
.54012 .01701 Mdot
.62719 .05381 Mdot
.88538 .15957 Mdot
.30102 .25688 Mdot
.49008 .11685 Mdot
.66428 .10766 Mdot
.04341 .23432 Mdot
.35823 .19457 Mdot
.50042 .00018 Mdot
.50132 .00056 Mdot
.50422 .00179 Mdot
.51344 .0057 Mdot
.5428 .01815 Mdot
.6356 .05735 Mdot
.90807 .1684 Mdot
.31089 .24896 Mdot
.49224 .11208 Mdot
.66196 .10489 Mdot
.03482 .23044 Mdot
.35586 .19842 Mdot
.49922 .6177 Mdot
.4975 .61698 Mdot
.49205 .61466 Mdot
.47467 .60729 Mdot
.41945 .58391 Mdot
.24851 .51238 Mdot
.83884 .36485 Mdot
.63167 .49 Mdot
.60023 .5986 Mdot
.70938 .06746 Mdot
.04954 .21023 Mdot
.49883 .61754 Mdot
.49626 .61645 Mdot
.48809 .61298 Mdot
.46207 .60195 Mdot
.37968 .56712 Mdot
.13353 .4659 Mdot
.70976 .35613 Mdot
.51715 .49899 Mdot
.3502 .51485 Mdot
.99029 .3956 Mdot
.64494 .4046 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .00179 Mdot
.51347 .00571 Mdot
.5429 .01819 Mdot
.63592 .05748 Mdot
.90891 .16872 Mdot
.3112 .24863 Mdot
.49219 .11186 Mdot
.66148 .10462 Mdot
.03351 .22993 Mdot
.35565 .19909 Mdot
.4995 .61782 Mdot
.49842 .61737 Mdot
.49497 .6159 Mdot
.48399 .61124 Mdot
.44903 .59643 Mdot
.33891 .54998 Mdot
.02634 .42486 Mdot
.67445 .40055 Mdot
.53488 .53178 Mdot
.44722 .56386 Mdot
.28185 .51582 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.52048 .00869 Mdot
.56518 .02762 Mdot
.70494 .08637 Mdot
.07392 .22804 Mdot
.33597 .16196 Mdot
.39327 .03542 Mdot
.30221 .56176 Mdot
.98515 .42208 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47384 .60694 Mdot
.41683 .5828 Mdot
.24068 .50916 Mdot
.8262 .36187 Mdot
.62361 .49283 Mdot
.58835 .59624 Mdot
.67891 .05597 Mdot
.98479 .18904 Mdot
.31345 .20312 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50629 .00267 Mdot
.52004 .0085 Mdot
.56378 .02703 Mdot
.70064 .08459 Mdot
.06485 .22509 Mdot
.33445 .16662 Mdot
.39815 .03937 Mdot
.3193 .5693 Mdot
.02398 .43552 Mdot
.69283 .41337 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52051 .0087 Mdot
.56527 .02766 Mdot
.70522 .08649 Mdot
.07451 .22823 Mdot
.33607 .16166 Mdot
.39298 .03517 Mdot
.30117 .5613 Mdot
.98287 .42131 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50707 .003 Mdot
.52251 .00954 Mdot
.5716 .03034 Mdot
.7245 .0945 Mdot
.11307 .24015 Mdot
.34595 .14393 Mdot
.38218 .02239 Mdot
.2574 .54091 Mdot
.89414 .39353 Mdot
.67822 .48459 Mdot
.49825 .61729 Mdot
.49441 .61567 Mdot
.48221 .61049 Mdot
.44336 .59403 Mdot
.32134 .54262 Mdot
.98418 .40966 Mdot
.67071 .4243 Mdot
.56695 .55391 Mdot
.56067 .61415 Mdot
.6432 .05101 Mdot
.91271 .16656 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48445 .61144 Mdot
.4505 .59705 Mdot
.34348 .55189 Mdot
.03774 .42908 Mdot
.67592 .39441 Mdot
.52743 .52626 Mdot
.41988 .55156 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49284 .615 Mdot
.47721 .60837 Mdot
.4275 .58731 Mdot
.27275 .5224 Mdot
.88171 .37636 Mdot
.65221 .4762 Mdot
.61779 .59676 Mdot
.74435 .07822 Mdot
.10949 .22567 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00255 Mdot
.51913 .00811 Mdot
.56088 .0258 Mdot
.69175 .08088 Mdot
.04553 .21865 Mdot
.33195 .17702 Mdot
.41058 .0486 Mdot
.36204 .58803 Mdot
.1315 .47556 Mdot
.72541 .36705 Mdot
.49845 .61738 Mdot
.49508 .61595 Mdot
.48431 .61138 Mdot
.45005 .59686 Mdot
.3421 .55131 Mdot
.03428 .42779 Mdot
.67544 .39626 Mdot
.52961 .52791 Mdot
.42793 .5552 Mdot
.22182 .49065 Mdot
.7807 .34541 Mdot
.4996 .61786 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.4869 .61248 Mdot
.45829 .60035 Mdot
.36783 .56213 Mdot
.10112 .4532 Mdot
.69274 .36564 Mdot
.50779 .50373 Mdot
.33454 .51096 Mdot
.95544 .38374 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50608 .00258 Mdot
.51938 .00822 Mdot
.56169 .02615 Mdot
.69423 .08191 Mdot
.05099 .22049 Mdot
.33257 .17402 Mdot
.40683 .04589 Mdot
.34917 .5824 Mdot
.09765 .46258 Mdot
.70867 .37763 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54192 .01777 Mdot
.63282 .05618 Mdot
.90063 .16551 Mdot
.30799 .25176 Mdot
.4923 .11391 Mdot
.66506 .10677 Mdot
.04336 .2338 Mdot
.35742 .1941 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47788 .60866 Mdot
.42964 .58822 Mdot
.27925 .52509 Mdot
.89416 .38003 Mdot
.65638 .47108 Mdot
.61721 .59382 Mdot
.73838 .07489 Mdot
.09765 .22204 Mdot
.31946 .13709 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48398 .61124 Mdot
.44899 .59641 Mdot
.33878 .54992 Mdot
.02604 .42475 Mdot
.67441 .40072 Mdot
.53509 .53193 Mdot
.44799 .5642 Mdot
.28425 .51684 Mdot
.88729 .3727 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50692 .00294 Mdot
.52205 .00935 Mdot
.57016 .02973 Mdot
.72013 .09269 Mdot
.10465 .23764 Mdot
.34326 .14747 Mdot
.38296 .02454 Mdot
.26251 .54359 Mdot
.90406 .3965 Mdot
.68096 .48015 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.5108 .00458 Mdot
.53441 .01459 Mdot
.60922 .04624 Mdot
.8353 .13973 Mdot
.26664 .26658 Mdot
.46055 .11984 Mdot
.59588 .08364 Mdot
.8665 .16725 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.525 .0106 Mdot
.57949 .03368 Mdot
.74831 .10434 Mdot
.15586 .25188 Mdot
.36523 .1294 Mdot
.39576 .01887 Mdot
.28087 .54703 Mdot
.93172 .40225 Mdot
.68188 .46363 Mdot
.49981 .61795 Mdot
.49939 .61777 Mdot
.49805 .6172 Mdot
.49377 .61539 Mdot
.48016 .60962 Mdot
.43685 .59127 Mdot
.3013 .53426 Mdot
.93931 .39431 Mdot
.66616 .44922 Mdot
.59939 .57677 Mdot
.6722 .045 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48195 .61038 Mdot
.44254 .59368 Mdot
.3188 .54156 Mdot
.97829 .40759 Mdot
.67024 .42765 Mdot
.57157 .55705 Mdot
.57668 .00316 Mdot
.69241 .07153 Mdot
.03142 .20952 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48467 .61154 Mdot
.45121 .59735 Mdot
.34569 .55282 Mdot
.0433 .43115 Mdot
.67676 .3915 Mdot
.52412 .5237 Mdot
.40751 .54597 Mdot
.15986 .46497 Mdot
.71075 .34047 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00136 Mdot
.51024 .00434 Mdot
.53263 .01383 Mdot
.6036 .04387 Mdot
.81924 .13327 Mdot
.25138 .26707 Mdot
.44478 .11953 Mdot
.55702 .06937 Mdot
.75297 .1211 Mdot
.18761 .26862 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50353 .0015 Mdot
.51124 .00477 Mdot
.5358 .01518 Mdot
.6136 .04808 Mdot
.8477 .14468 Mdot
.27694 .26529 Mdot
.47087 .11985 Mdot
.62135 .093 Mdot
.93671 .19491 Mdot
.34453 .25204 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50428 .00182 Mdot
.51364 .00578 Mdot
.54343 .01841 Mdot
.63757 .05818 Mdot
.91331 .17042 Mdot
.31275 .24687 Mdot
.49177 .11064 Mdot
.65846 .10302 Mdot
.02547 .22682 Mdot
.35444 .20331 Mdot
.50015 6e-05 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51565 .00664 Mdot
.54983 .02112 Mdot
.65754 .06657 Mdot
.96481 .18991 Mdot
.32444 .22226 Mdot
.47097 .09056 Mdot
.5742 .0638 Mdot
.78475 .13012 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50306 .0013 Mdot
.50974 .00413 Mdot
.53102 .01315 Mdot
.59853 .04172 Mdot
.80456 .12734 Mdot
.23544 .2663 Mdot
.42858 .11937 Mdot
.51816 .05536 Mdot
.63493 .07217 Mdot
.9307 .1828 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51786 .00757 Mdot
.55686 .0241 Mdot
.67933 .0757 Mdot
.0174 .20893 Mdot
.32942 .19284 Mdot
.43181 .06328 Mdot
.43502 .00199 Mdot
.34346 .56144 Mdot
.05315 .43862 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48053 .60978 Mdot
.43805 .59178 Mdot
.30498 .53579 Mdot
.94727 .39696 Mdot
.66722 .44495 Mdot
.59433 .57298 Mdot
.65479 .03737 Mdot
.91253 .15929 Mdot
.29497 .23636 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50285 .00121 Mdot
.50907 .00385 Mdot
.5289 .01225 Mdot
.59183 .03889 Mdot
.78498 .11937 Mdot
.21112 .26337 Mdot
.40562 .12021 Mdot
.4667 .03775 Mdot
.47819 .0071 Mdot
.45706 .60498 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00117 Mdot
.50877 .00372 Mdot
.52794 .01185 Mdot
.5888 .03761 Mdot
.77605 .11573 Mdot
.19884 .2613 Mdot
.39513 .12131 Mdot
.44525 .03098 Mdot
.49928 .61773 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47683 .60821 Mdot
.4263 .58681 Mdot
.26914 .5209 Mdot
.87497 .37442 Mdot
.64964 .47877 Mdot
.61713 .59794 Mdot
.74488 .07895 Mdot
.11124 .22642 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50451 .00191 Mdot
.51436 .00609 Mdot
.54571 .01938 Mdot
.64469 .06117 Mdot
.93202 .17758 Mdot
.31825 .2387 Mdot
.48736 .10452 Mdot
.63753 .09281 Mdot
.96927 .20502 Mdot
.34682 .23334 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50521 .00221 Mdot
.51661 .00704 Mdot
.55287 .02241 Mdot
.66698 .07052 Mdot
.98807 .19845 Mdot
.32704 .20949 Mdot
.4547 .0789 Mdot
.51534 .03747 Mdot
.59895 .05167 Mdot
.8216 .1376 Mdot
.499 .61761 Mdot
.49683 .61669 Mdot
.48988 .61374 Mdot
.46778 .60437 Mdot
.39768 .57471 Mdot
.18444 .48625 Mdot
.75245 .35104 Mdot
.55915 .49857 Mdot
.45256 .55216 Mdot
.27586 .50883 Mdot
.86357 .36323 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.5235 .00997 Mdot
.57476 .03168 Mdot
.73406 .09846 Mdot
.13091 .24526 Mdot
.3528 .13713 Mdot
.38404 .01931 Mdot
.25632 .5391 Mdot
.89006 .39167 Mdot
.6759 .48568 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52164 .00917 Mdot
.56883 .02917 Mdot
.71609 .09101 Mdot
.09669 .23522 Mdot
.34101 .151 Mdot
.38458 .02693 Mdot
.26979 .54709 Mdot
.91811 .40069 Mdot
.68392 .47329 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47678 .60819 Mdot
.42614 .58674 Mdot
.26864 .5207 Mdot
.87405 .37416 Mdot
.64927 .47911 Mdot
.61699 .59808 Mdot
.7448 .07899 Mdot
.11122 .22646 Mdot
.32406 .13154 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48534 .61182 Mdot
.45331 .59824 Mdot
.35226 .55558 Mdot
.06007 .43745 Mdot
.6799 .38308 Mdot
.51568 .51654 Mdot
.37496 .53106 Mdot
.06537 .4267 Mdot
.66046 .36779 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54096 .01737 Mdot
.62982 .05492 Mdot
.89253 .16236 Mdot
.30447 .25459 Mdot
.49152 .1156 Mdot
.66585 .10775 Mdot
.04633 .23514 Mdot
.35829 .1928 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50824 .00349 Mdot
.52624 .01113 Mdot
.58344 .03535 Mdot
.76014 .10921 Mdot
.17509 .25645 Mdot
.37726 .12495 Mdot
.41305 .02212 Mdot
.3248 .56349 Mdot
.0237 .43195 Mdot
.68718 .41005 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51774 .00752 Mdot
.55648 .02394 Mdot
.67817 .07521 Mdot
.01468 .20798 Mdot
.49872 .61749 Mdot
.49592 .6163 Mdot
.487 .61252 Mdot
.45862 .60049 Mdot
.36885 .56255 Mdot
.10388 .45427 Mdot
.69392 .36467 Mdot
.50802 .50315 Mdot
.33416 .51058 Mdot
.95417 .38319 Mdot
.64198 .42509 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48815 .61301 Mdot
.46226 .60203 Mdot
.38028 .56737 Mdot
.13519 .46656 Mdot
.71083 .35577 Mdot
.51802 .49887 Mdot
.35217 .51554 Mdot
.99512 .39737 Mdot
.64539 .40188 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50554 .00235 Mdot
.51763 .00748 Mdot
.55613 .02379 Mdot
.67709 .07476 Mdot
.01216 .20709 Mdot
.32901 .19582 Mdot
.43594 .06609 Mdot
.44937 .0083 Mdot
.38812 .58018 Mdot
.17253 .48479 Mdot
.49889 .61756 Mdot
.49646 .61653 Mdot
.48871 .61325 Mdot
.46405 .60279 Mdot
.38591 .56974 Mdot
.15093 .47281 Mdot
.72199 .35294 Mdot
.5281 .4982 Mdot
.37615 .52412 Mdot
.0566 .42054 Mdot
.65393 .36917 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51093 .00463 Mdot
.5348 .01476 Mdot
.61047 .04676 Mdot
.83885 .14115 Mdot
.26972 .26629 Mdot
.46369 .11988 Mdot
.60366 .08651 Mdot
.88835 .17595 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.5114 .00483 Mdot
.5363 .01539 Mdot
.61519 .04876 Mdot
.85218 .14646 Mdot
.28036 .26463 Mdot
.47414 .11976 Mdot
.62932 .0959 Mdot
.95781 .20302 Mdot
.49777 .61709 Mdot
.49288 .61502 Mdot
.47733 .60842 Mdot
.42789 .58748 Mdot
.27393 .52289 Mdot
.88394 .37701 Mdot
.65301 .47531 Mdot
.61785 .5963 Mdot
.74374 .07781 Mdot
.10818 .22524 Mdot
.32256 .13249 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .00139 Mdot
.51047 .00444 Mdot
.53334 .01414 Mdot
.60586 .04482 Mdot
.82571 .13588 Mdot
.25779 .26704 Mdot
.45142 .11967 Mdot
.57331 .07533 Mdot
.80133 .14092 Mdot
.25577 .28086 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50639 .00271 Mdot
.52036 .00863 Mdot
.56478 .02745 Mdot
.70372 .08587 Mdot
.07136 .22722 Mdot
.33551 .16326 Mdot
.39457 .0365 Mdot
.30681 .56379 Mdot
.99536 .42555 Mdot
.69087 .42985 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51238 .00525 Mdot
.53943 .01672 Mdot
.62503 .0529 Mdot
.87946 .15725 Mdot
.29791 .25861 Mdot
.48835 .1177 Mdot
.66135 .10692 Mdot
.03698 .23216 Mdot
.35764 .19818 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50736 .00312 Mdot
.52346 .00995 Mdot
.57462 .03162 Mdot
.73364 .09828 Mdot
.13014 .24505 Mdot
.35247 .1374 Mdot
.38385 .0194 Mdot
.25607 .53906 Mdot
.88973 .39162 Mdot
.67588 .48586 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47473 .60732 Mdot
.41965 .58399 Mdot
.24911 .51263 Mdot
.83984 .36509 Mdot
.63226 .48975 Mdot
.60102 .59873 Mdot
.71135 .06819 Mdot
.0534 .2114 Mdot
.31685 .16282 Mdot
.49929 .61773 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47715 .60835 Mdot
.42732 .58724 Mdot
.27223 .52218 Mdot
.88073 .37607 Mdot
.65185 .47658 Mdot
.61773 .59695 Mdot
.74455 .07837 Mdot
.10995 .22583 Mdot
.49931 .61774 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47766 .60856 Mdot
.42892 .58791 Mdot
.27708 .52419 Mdot
.88994 .37877 Mdot
.65505 .47286 Mdot
.61765 .59492 Mdot
.74109 .07629 Mdot
.10289 .2236 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48244 .61059 Mdot
.4441 .59434 Mdot
.32364 .54358 Mdot
.98954 .41155 Mdot
.67112 .42124 Mdot
.56271 .55103 Mdot
.54596 .60768 Mdot
.59719 .03166 Mdot
.7853 .11626 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.48479 .61158 Mdot
.45157 .5975 Mdot
.34682 .5533 Mdot
.04617 .43222 Mdot
.67723 .39002 Mdot
.5225 .52241 Mdot
.40142 .5432 Mdot
.14173 .45754 Mdot
.69645 .34284 Mdot
.49766 .61704 Mdot
.49255 .61488 Mdot
.47628 .60798 Mdot
.42455 .58607 Mdot
.26385 .51871 Mdot
.86532 .37173 Mdot
.64554 .48221 Mdot
.61491 .5991 Mdot
.74205 .07858 Mdot
.10762 .22594 Mdot
.32379 .1336 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48773 .61283 Mdot
.46092 .60146 Mdot
.37607 .56559 Mdot
.12355 .46197 Mdot
.70376 .35859 Mdot
.51271 .49996 Mdot
.34071 .51173 Mdot
.9677 .3875 Mdot
.49877 .61751 Mdot
.49607 .61637 Mdot
.48747 .61272 Mdot
.46009 .60112 Mdot
.37348 .56451 Mdot
.11646 .45919 Mdot
.69993 .3606 Mdot
.5104 .5009 Mdot
.33648 .51054 Mdot
.9582 .38425 Mdot
.6419 .42255 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48135 .61012 Mdot
.44063 .59287 Mdot
.3129 .5391 Mdot
.96485 .40292 Mdot
.66909 .43525 Mdot
.58189 .56414 Mdot
.61216 .01871 Mdot
.79709 .11429 Mdot
.21037 .25543 Mdot
.50054 .00023 Mdot
.50173 .00074 Mdot
.50553 .00234 Mdot
.51761 .00747 Mdot
.55604 .02375 Mdot
.67681 .07464 Mdot
.01152 .20686 Mdot
.32896 .19619 Mdot
.43645 .06643 Mdot
.45114 .00908 Mdot
.39369 .58253 Mdot
.18836 .49114 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50995 .00422 Mdot
.53171 .01344 Mdot
.6007 .04264 Mdot
.81087 .12989 Mdot
.24252 .26678 Mdot
.43571 .11939 Mdot
.53506 .0614 Mdot
.68656 .09364 Mdot
.05809 .22962 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48789 .6129 Mdot
.46143 .60168 Mdot
.37767 .56627 Mdot
.12795 .4637 Mdot
.70632 .35745 Mdot
.5145 .49948 Mdot
.34439 .5129 Mdot
.97632 .39055 Mdot
.64364 .41243 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.5025 .00106 Mdot
.50796 .00337 Mdot
.52535 .01075 Mdot
.58061 .03415 Mdot
.75168 .10573 Mdot
.16148 .25327 Mdot
.36852 .12796 Mdot
.40003 .01947 Mdot
.29125 .5508 Mdot
.9517 .40819 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51254 .00532 Mdot
.53992 .01693 Mdot
.62656 .05355 Mdot
.88366 .1589 Mdot
.30014 .2574 Mdot
.48963 .11711 Mdot
.66358 .10751 Mdot
.04192 .23383 Mdot
.49952 .61783 Mdot
.49847 .61739 Mdot
.49514 .61597 Mdot
.48451 .61146 Mdot
.45067 .59712 Mdot
.34401 .55212 Mdot
.03908 .42957 Mdot
.67611 .39371 Mdot
.52662 .52564 Mdot
.41685 .5502 Mdot
.18797 .47658 Mdot
.4997 .61791 Mdot
.49903 .61762 Mdot
.49692 .61673 Mdot
.49019 .61387 Mdot
.46875 .60478 Mdot
.40073 .576 Mdot
.19329 .48982 Mdot
.7621 .35155 Mdot
.56896 .49867 Mdot
.47606 .56062 Mdot
.34739 .53851 Mdot
.49927 .61772 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47636 .60801 Mdot
.4248 .58617 Mdot
.26459 .51902 Mdot
.86665 .37209 Mdot
.64614 .48175 Mdot
.61531 .59898 Mdot
.7427 .07873 Mdot
.10858 .22612 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47384 .60694 Mdot
.41683 .5828 Mdot
.24067 .50916 Mdot
.82619 .36187 Mdot
.6236 .49283 Mdot
.58834 .59624 Mdot
.67888 .05596 Mdot
.98472 .18902 Mdot
.31344 .20316 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51823 .00773 Mdot
.55801 .02459 Mdot
.6829 .07718 Mdot
.02561 .21181 Mdot
.33007 .18817 Mdot
.42538 .05891 Mdot
.41283 .61027 Mdot
.27595 .53344 Mdot
.9035 .38785 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49293 .61503 Mdot
.47746 .60848 Mdot
.4283 .58765 Mdot
.2752 .52341 Mdot
.88636 .37771 Mdot
.65386 .47434 Mdot
.61783 .59577 Mdot
.74285 .07726 Mdot
.10636 .22466 Mdot
.50027 .00012 Mdot
.50086 .00037 Mdot
.50276 .00117 Mdot
.50878 .00372 Mdot
.52796 .01186 Mdot
.58888 .03765 Mdot
.7763 .11583 Mdot
.1992 .26137 Mdot
.39542 .12127 Mdot
.44583 .03115 Mdot
.41653 .59993 Mdot
.2677 .52605 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48015 .60962 Mdot
.43682 .59126 Mdot
.30119 .53421 Mdot
.93908 .39423 Mdot
.66613 .44934 Mdot
.59953 .57687 Mdot
.67268 .04521 Mdot
.95693 .17568 Mdot
.305 .21512 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47918 .60921 Mdot
.43375 .58996 Mdot
.29179 .5303 Mdot
.91929 .38781 Mdot
.66273 .45947 Mdot
.6099 .58538 Mdot
.70912 .06132 Mdot
.03924 .20403 Mdot
.3111 .16801 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49613 .61639 Mdot
.48767 .61281 Mdot
.46074 .60139 Mdot
.37552 .56536 Mdot
.12205 .46138 Mdot
.70292 .359 Mdot
.51216 .50014 Mdot
.33963 .5114 Mdot
.96524 .38665 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52352 .00997 Mdot
.57481 .0317 Mdot
.73421 .09852 Mdot
.13118 .24534 Mdot
.35291 .13704 Mdot
.3841 .01928 Mdot
.25641 .53912 Mdot
.89018 .39169 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51398 .00593 Mdot
.54453 .01888 Mdot
.641 .05962 Mdot
.92236 .17389 Mdot
.31562 .24305 Mdot
.49015 .10787 Mdot
.64992 .09874 Mdot
.00275 .21806 Mdot
.35146 .21551 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54095 .01736 Mdot
.62979 .05491 Mdot
.89244 .16233 Mdot
.30442 .25462 Mdot
.4915 .11562 Mdot
.66585 .10775 Mdot
.04632 .23515 Mdot
.35829 .19281 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48702 .61253 Mdot
.45868 .60052 Mdot
.36905 .56264 Mdot
.10441 .45448 Mdot
.69415 .36448 Mdot
.50808 .50304 Mdot
.33412 .51052 Mdot
.95402 .38311 Mdot
.64193 .42515 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48702 .61253 Mdot
.45866 .60051 Mdot
.369 .56262 Mdot
.10428 .45443 Mdot
.6941 .36452 Mdot
.50807 .50306 Mdot
.33413 .51054 Mdot
.95405 .38313 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51104 .00468 Mdot
.53516 .01491 Mdot
.61161 .04724 Mdot
.84207 .14243 Mdot
.27242 .26597 Mdot
.4664 .11989 Mdot
.61037 .08898 Mdot
.90694 .18329 Mdot
.33528 .26473 Mdot
.49902 .61762 Mdot
.49687 .61671 Mdot
.49004 .61381 Mdot
.46828 .60459 Mdot
.39926 .57538 Mdot
.18902 .4881 Mdot
.75736 .35125 Mdot
.56418 .49864 Mdot
.46467 .55653 Mdot
.31259 .52404 Mdot
.94 .38776 Mdot
.50081 .00034 Mdot
.50258 .0011 Mdot
.50823 .00349 Mdot
.52622 .01112 Mdot
.58336 .03531 Mdot
.75989 .10911 Mdot
.1747 .25637 Mdot
.377 .12503 Mdot
.41263 .02202 Mdot
.32368 .56306 Mdot
.02112 .43104 Mdot
.68698 .41152 Mdot
.49881 .61753 Mdot
.49621 .61643 Mdot
.48791 .61291 Mdot
.46151 .60171 Mdot
.37793 .56638 Mdot
.12867 .46399 Mdot
.70676 .35728 Mdot
.51482 .49941 Mdot
.34507 .51313 Mdot
.97794 .39113 Mdot
.64379 .41152 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.5201 .00852 Mdot
.56396 .02711 Mdot
.7012 .08482 Mdot
.06604 .22548 Mdot
.33464 .166 Mdot
.39747 .03883 Mdot
.31693 .56826 Mdot
.01845 .43357 Mdot
.69236 .4165 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50676 .00287 Mdot
.52153 .00913 Mdot
.56848 .02902 Mdot
.71503 .09057 Mdot
.09457 .23457 Mdot
.34045 .15197 Mdot
.38514 .02762 Mdot
.27211 .54818 Mdot
.92264 .40205 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50366 .00155 Mdot
.51167 .00495 Mdot
.53716 .01575 Mdot
.61789 .04989 Mdot
.85971 .14945 Mdot
.28576 .26331 Mdot
.47907 .11948 Mdot
.64108 .10013 Mdot
.98807 .21445 Mdot
.35294 .2255 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50662 .00281 Mdot
.5211 .00895 Mdot
.56714 .02845 Mdot
.71094 .08887 Mdot
.08631 .23199 Mdot
.33847 .15584 Mdot
.38784 .03051 Mdot
.28256 .55297 Mdot
.94353 .4085 Mdot
.49897 .6176 Mdot
.4967 .61664 Mdot
.4895 .61358 Mdot
.46655 .60385 Mdot
.39381 .57307 Mdot
.17333 .48177 Mdot
.74129 .35102 Mdot
.54762 .49834 Mdot
.42433 .54183 Mdot
.19176 .4743 Mdot
.73626 .33652 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48495 .61165 Mdot
.45209 .59772 Mdot
.34844 .55398 Mdot
.05029 .43377 Mdot
.67795 .38792 Mdot
.5203 .5206 Mdot
.39302 .53937 Mdot
.11709 .4475 Mdot
.68094 .34848 Mdot
.49883 .61754 Mdot
.49626 .61645 Mdot
.48808 .61298 Mdot
.46203 .60194 Mdot
.37958 .56707 Mdot
.13324 .46579 Mdot
.70958 .3562 Mdot
.517 .49901 Mdot
.34987 .51474 Mdot
.98948 .3953 Mdot
.64486 .40505 Mdot
.49876 .61751 Mdot
.49604 .61635 Mdot
.48738 .61268 Mdot
.4598 .60099 Mdot
.37257 .56412 Mdot
.11398 .45821 Mdot
.69866 .36135 Mdot
.50976 .50129 Mdot
.33549 .51033 Mdot
.95612 .38357 Mdot
.64173 .42373 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.48899 .61337 Mdot
.46495 .60317 Mdot
.38874 .57094 Mdot
.15892 .476 Mdot
.7284 .35196 Mdot
.53442 .49815 Mdot
.39166 .52981 Mdot
.09866 .43695 Mdot
.66697 .35123 Mdot
.49935 .61776 Mdot
.49793 .61715 Mdot
.49339 .61523 Mdot
.47895 .60911 Mdot
.43303 .58965 Mdot
.28958 .52938 Mdot
.91474 .38637 Mdot
.66176 .46168 Mdot
.61176 .58713 Mdot
.71595 .06439 Mdot
.05343 .20857 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .0029 Mdot
.52182 .00925 Mdot
.56942 .02942 Mdot
.71787 .09175 Mdot
.1002 .2363 Mdot
.34197 .14942 Mdot
.38376 .02583 Mdot
.2663 .54544 Mdot
.91135 .39866 Mdot
.68261 .47666 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50527 .00223 Mdot
.51678 .00712 Mdot
.55342 .02264 Mdot
.66869 .07124 Mdot
.99221 .19995 Mdot
.32741 .20716 Mdot
.45156 .07673 Mdot
.50418 .03252 Mdot
.56306 .03639 Mdot
.49824 .61729 Mdot
.49441 .61566 Mdot
.48218 .61048 Mdot
.44329 .594 Mdot
.32111 .54253 Mdot
.98364 .40947 Mdot
.67067 .4246 Mdot
.56737 .55419 Mdot
.56214 .6148 Mdot
.64777 .05292 Mdot
.92454 .17106 Mdot
.49877 .61751 Mdot
.49609 .61638 Mdot
.48755 .61275 Mdot
.46034 .60122 Mdot
.37427 .56484 Mdot
.11861 .46003 Mdot
.70105 .35997 Mdot
.51103 .50059 Mdot
.33754 .51081 Mdot
.96052 .38502 Mdot
.64212 .42125 Mdot
.4999 .61799 Mdot
.49969 .6179 Mdot
.49902 .61762 Mdot
.49688 .61671 Mdot
.49007 .61383 Mdot
.46839 .60463 Mdot
.39959 .57552 Mdot
.18998 .48848 Mdot
.75841 .35131 Mdot
.56524 .49865 Mdot
.4672 .55745 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52455 .01041 Mdot
.57807 .03308 Mdot
.74405 .10258 Mdot
.1486 .25003 Mdot
.36125 .13142 Mdot
.39116 .01848 Mdot
.27024 .5433 Mdot
.91252 .39695 Mdot
.67951 .47402 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48364 .6111 Mdot
.44792 .59596 Mdot
.33548 .54854 Mdot
.01791 .42177 Mdot
.67353 .4052 Mdot
.54086 .53604 Mdot
.46881 .57351 Mdot
.35029 .54478 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50432 .00183 Mdot
.51377 .00584 Mdot
.54386 .01859 Mdot
.6389 .05874 Mdot
.91684 .17178 Mdot
.31392 .24541 Mdot
.49126 .1096 Mdot
.65549 .1015 Mdot
.49855 .61742 Mdot
.4954 .61608 Mdot
.48533 .61181 Mdot
.45329 .59823 Mdot
.35219 .55555 Mdot
.0599 .43739 Mdot
.67987 .38316 Mdot
.51576 .51661 Mdot
.37525 .53119 Mdot
.06619 .42703 Mdot
.66068 .36742 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50196 .00083 Mdot
.50624 .00265 Mdot
.51988 .00843 Mdot
.56326 .02681 Mdot
.69906 .08393 Mdot
.06146 .22398 Mdot
.33395 .1684 Mdot
.40014 .04091 Mdot
.32619 .57233 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .0014 Mdot
.51049 .00445 Mdot
.53342 .01417 Mdot
.60612 .04493 Mdot
.82645 .13617 Mdot
.2585 .26702 Mdot
.45216 .11969 Mdot
.57513 .076 Mdot
.80666 .14309 Mdot
.26195 .28139 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48465 .61152 Mdot
.45112 .59731 Mdot
.34541 .5527 Mdot
.04261 .43089 Mdot
.67665 .39186 Mdot
.52452 .52401 Mdot
.40903 .54665 Mdot
.16438 .46683 Mdot
.71472 .34013 Mdot
.4986 .61744 Mdot
.49554 .61614 Mdot
.48577 .612 Mdot
.45471 .59883 Mdot
.35661 .55741 Mdot
.07136 .44174 Mdot
.68262 .37778 Mdot
.51155 .5123 Mdot
.35777 .523 Mdot
.01793 .408 Mdot
.65125 .39141 Mdot
.49876 .61751 Mdot
.49604 .61635 Mdot
.48738 .61268 Mdot
.4598 .60099 Mdot
.37256 .56412 Mdot
.11395 .4582 Mdot
.69864 .36136 Mdot
.50975 .50129 Mdot
.33548 .51033 Mdot
.95609 .38356 Mdot
.64173 .42375 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51706 .00723 Mdot
.5543 .02302 Mdot
.67143 .07239 Mdot
.99879 .20232 Mdot
.32796 .20344 Mdot
.44648 .07325 Mdot
.48623 .02456 Mdot
.50533 .01181 Mdot
.53244 .01675 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51452 .00616 Mdot
.54624 .0196 Mdot
.64633 .06186 Mdot
.93629 .1792 Mdot
.31928 .2367 Mdot
.4858 .10291 Mdot
.63104 .08976 Mdot
.95137 .19797 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50787 .00334 Mdot
.52507 .01063 Mdot
.57972 .03378 Mdot
.74901 .10463 Mdot
.15703 .25217 Mdot
.3659 .12909 Mdot
.3966 .01897 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57519 .03186 Mdot
.73537 .099 Mdot
.13329 .24592 Mdot
.35383 .1363 Mdot
.38467 .01906 Mdot
.25727 .53929 Mdot
.89138 .3919 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .00121 Mdot
.50906 .00384 Mdot
.52886 .01224 Mdot
.59171 .03884 Mdot
.78464 .11924 Mdot
.21067 .2633 Mdot
.40522 .12024 Mdot
.46585 .03747 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49294 .61504 Mdot
.4775 .60849 Mdot
.42843 .58771 Mdot
.27558 .52357 Mdot
.88708 .37793 Mdot
.6541 .47405 Mdot
.61781 .59561 Mdot
.74254 .07709 Mdot
.10574 .22447 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48603 .61211 Mdot
.45551 .59917 Mdot
.35913 .55847 Mdot
.07797 .44427 Mdot
.68448 .37484 Mdot
.50977 .51006 Mdot
.34972 .51912 Mdot
.99628 .3996 Mdot
.64842 .40304 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47889 .60908 Mdot
.43284 .58957 Mdot
.28902 .52915 Mdot
.91361 .38602 Mdot
.66151 .46223 Mdot
.61219 .58755 Mdot
.71755 .06512 Mdot
.05669 .2096 Mdot
.49854 .61742 Mdot
.49536 .61607 Mdot
.48523 .61177 Mdot
.45297 .5981 Mdot
.3512 .55513 Mdot
.05735 .43642 Mdot
.67932 .3844 Mdot
.51688 .51764 Mdot
.37971 .53326 Mdot
.07879 .43206 Mdot
.66446 .36196 Mdot
.50081 .00034 Mdot
.50258 .0011 Mdot
.50823 .00349 Mdot
.52621 .01111 Mdot
.58332 .0353 Mdot
.7598 .10907 Mdot
.17455 .25633 Mdot
.3769 .12506 Mdot
.41246 .02198 Mdot
.32323 .56289 Mdot
.0201 .43069 Mdot
.6869 .41211 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49087 .61416 Mdot
.47093 .60571 Mdot
.40763 .57891 Mdot
.21343 .49801 Mdot
.78677 .35434 Mdot
.5925 .49797 Mdot
.52929 .57897 Mdot
.50976 .60597 Mdot
.50488 .61501 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50464 .00197 Mdot
.51478 .00627 Mdot
.54705 .01994 Mdot
.64886 .06293 Mdot
.9428 .18167 Mdot
.32071 .23356 Mdot
.48305 .10033 Mdot
.62002 .08465 Mdot
.92044 .18567 Mdot
.33529 .25639 Mdot
.49767 .61705 Mdot
.49259 .61489 Mdot
.47638 .60802 Mdot
.42488 .58621 Mdot
.26485 .51913 Mdot
.86712 .37222 Mdot
.64635 .48159 Mdot
.61544 .59893 Mdot
.74291 .07878 Mdot
.10888 .22618 Mdot
.32397 .13293 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50377 .0016 Mdot
.512 .00509 Mdot
.53821 .0162 Mdot
.62118 .05128 Mdot
.86887 .15308 Mdot
.29174 .26135 Mdot
.48405 .11885 Mdot
.65246 .10408 Mdot
.01615 .22477 Mdot
.35566 .20983 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00247 Mdot
.51852 .00785 Mdot
.55894 .02498 Mdot
.68577 .07839 Mdot
.03216 .21408 Mdot
.33063 .18447 Mdot
.42036 .05546 Mdot
.39556 .60271 Mdot
.22511 .51269 Mdot
.81884 .36695 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.51689 .00716 Mdot
.55377 .02279 Mdot
.66977 .0717 Mdot
.99482 .20089 Mdot
.32763 .20569 Mdot
.44956 .07535 Mdot
.49708 .02937 Mdot
.54024 .02667 Mdot
.6431 .06357 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52607 .01105 Mdot
.58288 .03511 Mdot
.75845 .10851 Mdot
.17243 .25585 Mdot
.37547 .12549 Mdot
.4102 .02147 Mdot
.31727 .5606 Mdot
.00662 .42604 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48397 .61124 Mdot
.44898 .5964 Mdot
.33875 .54991 Mdot
.02595 .42472 Mdot
.6744 .40076 Mdot
.53515 .53197 Mdot
.4482 .5643 Mdot
.28491 .51712 Mdot
.88861 .37311 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50652 .00277 Mdot
.52078 .00881 Mdot
.56612 .02802 Mdot
.70781 .08757 Mdot
.07989 .22996 Mdot
.33711 .15897 Mdot
.39046 .03298 Mdot
.29218 .55729 Mdot
.96349 .4149 Mdot
.49884 .61754 Mdot
.49632 .61647 Mdot
.48826 .61306 Mdot
.46263 .60219 Mdot
.38144 .56786 Mdot
.13841 .46783 Mdot
.71296 .35509 Mdot
.51981 .49866 Mdot
.35631 .51698 Mdot
.00538 .40115 Mdot
.64638 .39616 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50765 .00324 Mdot
.52435 .01033 Mdot
.57745 .03282 Mdot
.7422 .10182 Mdot
.14539 .24918 Mdot
.35959 .13238 Mdot
.38944 .01845 Mdot
.26649 .54204 Mdot
.90607 .39529 Mdot
.67851 .47739 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52599 .01102 Mdot
.58263 .03501 Mdot
.75773 .10822 Mdot
.17128 .25559 Mdot
.37471 .12573 Mdot
.40902 .0212 Mdot
.31416 .55941 Mdot
.99972 .4237 Mdot
.6857 .42396 Mdot
.49942 .61779 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48114 .61004 Mdot
.43997 .59259 Mdot
.31088 .53825 Mdot
.96031 .40137 Mdot
.66866 .43778 Mdot
.58524 .56648 Mdot
.62364 .02374 Mdot
.82941 .12717 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47422 .6071 Mdot
.41805 .58331 Mdot
.2443 .51065 Mdot
.83197 .3632 Mdot
.62741 .49161 Mdot
.59418 .5975 Mdot
.69413 .06177 Mdot
.01826 .20032 Mdot
.31506 .18343 Mdot
.49809 .61722 Mdot
.49392 .61546 Mdot
.48063 .60982 Mdot
.43836 .59191 Mdot
.30592 .53618 Mdot
.94934 .39765 Mdot
.66747 .44383 Mdot
.59295 .57198 Mdot
.65006 .0353 Mdot
.90036 .15469 Mdot
.29055 .24115 Mdot
.49948 .61782 Mdot
.49836 .61734 Mdot
.49477 .61582 Mdot
.48333 .61097 Mdot
.44694 .59554 Mdot
.33242 .54726 Mdot
.01048 .41906 Mdot
.67283 .40935 Mdot
.54639 .53989 Mdot
.48854 .58229 Mdot
.41353 .57167 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51997 .00847 Mdot
.56355 .02693 Mdot
.69995 .0843 Mdot
.06336 .2246 Mdot
.33423 .1674 Mdot
.39901 .04004 Mdot
.32228 .57061 Mdot
.03102 .43803 Mdot
.69352 .40945 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49347 .61526 Mdot
.47919 .60921 Mdot
.43378 .58997 Mdot
.29189 .53034 Mdot
.91949 .38788 Mdot
.66277 .45937 Mdot
.60981 .5853 Mdot
.7088 .06118 Mdot
.03858 .20381 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50641 .00272 Mdot
.52041 .00865 Mdot
.56493 .02752 Mdot
.70418 .08606 Mdot
.07234 .22753 Mdot
.33569 .16275 Mdot
.39407 .03608 Mdot
.30502 .563 Mdot
.99137 .42419 Mdot
.49755 .617 Mdot
.4922 .61473 Mdot
.47517 .6075 Mdot
.42103 .58458 Mdot
.25324 .51433 Mdot
.84676 .36682 Mdot
.63624 .48792 Mdot
.60602 .59936 Mdot
.72332 .0725 Mdot
.07601 .21797 Mdot
.31897 .15016 Mdot
.50022 .0001 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57373 .03124 Mdot
.73097 .09718 Mdot
.12523 .24367 Mdot
.35044 .13919 Mdot
.3829 .02006 Mdot
.25513 .53907 Mdot
.88876 .3916 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47343 .60677 Mdot
.41553 .58225 Mdot
.23679 .50757 Mdot
.82014 .36053 Mdot
.61941 .49398 Mdot
.58146 .59458 Mdot
.66043 .04881 Mdot
.94132 .1736 Mdot
.30825 .22677 Mdot
.49946 .6178 Mdot
.49828 .6173 Mdot
.49451 .6157 Mdot
.4825 .61061 Mdot
.4443 .59442 Mdot
.32423 .54383 Mdot
.99094 .41205 Mdot
.67123 .42044 Mdot
.56161 .55028 Mdot
.5421 .60598 Mdot
.58501 .02652 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47562 .6077 Mdot
.42247 .58518 Mdot
.25757 .51612 Mdot
.85421 .36874 Mdot
.64021 .48577 Mdot
.61035 .59958 Mdot
.73307 .07584 Mdot
.09317 .22256 Mdot
.32136 .14103 Mdot
.49899 .61761 Mdot
.49678 .61667 Mdot
.48973 .61368 Mdot
.4673 .60417 Mdot
.39616 .57407 Mdot
.18007 .48448 Mdot
.74792 .35095 Mdot
.55449 .49849 Mdot
.44121 .54802 Mdot
.24174 .49475 Mdot
.80385 .34741 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.48532 .61181 Mdot
.45325 .59822 Mdot
.35206 .5555 Mdot
.05957 .43726 Mdot
.67979 .38332 Mdot
.5159 .51674 Mdot
.37582 .53146 Mdot
.0678 .42767 Mdot
.66113 .3667 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49146 .61441 Mdot
.47279 .6065 Mdot
.41351 .5814 Mdot
.23079 .50511 Mdot
.81108 .35864 Mdot
.61273 .49545 Mdot
.56969 .59143 Mdot
.62788 .03596 Mdot
.85791 .14216 Mdot
.49904 .61763 Mdot
.49695 .61674 Mdot
.49029 .61392 Mdot
.46907 .60492 Mdot
.40173 .57642 Mdot
.19619 .491 Mdot
.76543 .35181 Mdot
.57228 .49866 Mdot
.48387 .56339 Mdot
.37131 .54846 Mdot
.08606 .44174 Mdot
.49979 .61795 Mdot
.49933 .61775 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.47849 .60891 Mdot
.43156 .58903 Mdot
.28509 .52752 Mdot
.90568 .38354 Mdot
.65961 .46595 Mdot
.61479 .59034 Mdot
.72761 .06973 Mdot
.49952 .61783 Mdot
.49846 .61738 Mdot
.49509 .61595 Mdot
.48437 .61141 Mdot
.45023 .59694 Mdot
.34265 .55155 Mdot
.03567 .42831 Mdot
.67563 .39552 Mdot
.52872 .52724 Mdot
.42467 .55373 Mdot
.21181 .48647 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50994 .00422 Mdot
.53168 .01343 Mdot
.60061 .0426 Mdot
.8106 .12978 Mdot
.24223 .26676 Mdot
.4354 .11939 Mdot
.53433 .06114 Mdot
.68435 .09272 Mdot
.05307 .22788 Mdot
.498 .61718 Mdot
.49361 .61533 Mdot
.47965 .6094 Mdot
.43524 .59059 Mdot
.29636 .5322 Mdot
.92881 .39087 Mdot
.66452 .45469 Mdot
.60534 .58146 Mdot
.69288 .0541 Mdot
.00394 .19225 Mdot
.30909 .1886 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51803 .00764 Mdot
.55737 .02432 Mdot
.68093 .07636 Mdot
.02108 .21023 Mdot
.32971 .19074 Mdot
.42892 .06131 Mdot
.42501 .61562 Mdot
.31273 .54864 Mdot
.98002 .41241 Mdot
.49805 .61721 Mdot
.49377 .61539 Mdot
.48016 .60962 Mdot
.43687 .59128 Mdot
.30135 .53428 Mdot
.93942 .39435 Mdot
.66618 .44916 Mdot
.59932 .57671 Mdot
.67197 .0449 Mdot
.95522 .17506 Mdot
.30476 .21603 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51226 .0052 Mdot
.53903 .01655 Mdot
.62376 .05237 Mdot
.87598 .15588 Mdot
.29597 .25957 Mdot
.48711 .11813 Mdot
.65894 .1062 Mdot
.03147 .23024 Mdot
.35711 .20125 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48032 .60969 Mdot
.43738 .5915 Mdot
.30292 .53493 Mdot
.9428 .39547 Mdot
.66665 .44736 Mdot
.59722 .57513 Mdot
.66473 .04172 Mdot
.93751 .16859 Mdot
.30164 .22504 Mdot
.49973 .61792 Mdot
.49915 .61767 Mdot
.49728 .61688 Mdot
.49133 .61436 Mdot
.47238 .60632 Mdot
.41219 .58084 Mdot
.22689 .50351 Mdot
.80536 .35752 Mdot
.60827 .49622 Mdot
.56133 .58903 Mdot
.60414 .02646 Mdot
.49796 .61717 Mdot
.49349 .61528 Mdot
.47927 .60925 Mdot
.43405 .59009 Mdot
.29272 .53068 Mdot
.9212 .38842 Mdot
.66311 .45853 Mdot
.60905 .58463 Mdot
.70608 .05996 Mdot
.0328 .20192 Mdot
.31067 .17174 Mdot
.50015 6e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50496 .0021 Mdot
.51579 .0067 Mdot
.55028 .02132 Mdot
.65895 .06716 Mdot
.96833 .19121 Mdot
.32491 .22037 Mdot
.4687 .08887 Mdot
.56585 .06004 Mdot
.75898 .11936 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50384 .00163 Mdot
.51222 .00518 Mdot
.53892 .0165 Mdot
.62342 .05223 Mdot
.87505 .15552 Mdot
.29544 .25981 Mdot
.48675 .11824 Mdot
.65821 .10597 Mdot
.02979 .22965 Mdot
.35694 .20219 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00169 Mdot
.51266 .00537 Mdot
.54032 .01709 Mdot
.62781 .05407 Mdot
.88707 .16023 Mdot
.30186 .25636 Mdot
.49048 .11658 Mdot
.66484 .10776 Mdot
.04457 .23468 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51247 .00529 Mdot
.53972 .01684 Mdot
.62593 .05328 Mdot
.88194 .15822 Mdot
.29924 .2579 Mdot
.48914 .11736 Mdot
.66275 .1073 Mdot
.04012 .23323 Mdot
.35794 .19642 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50792 .00336 Mdot
.52522 .01069 Mdot
.58018 .03397 Mdot
.7504 .1052 Mdot
.15935 .25274 Mdot
.36725 .12849 Mdot
.39834 .01921 Mdot
.28708 .54928 Mdot
.94355 .40572 Mdot
.68293 .45696 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.51039 .00441 Mdot
.5331 .01403 Mdot
.60509 .04449 Mdot
.8235 .13499 Mdot
.25564 .26708 Mdot
.4492 .11962 Mdot
.56783 .07332 Mdot
.78516 .13432 Mdot
.23543 .27828 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .00991 Mdot
.57431 .03149 Mdot
.73272 .0979 Mdot
.12845 .24458 Mdot
.35175 .13801 Mdot
.38348 .01961 Mdot
.25562 .53901 Mdot
.88918 .39156 Mdot
.67586 .48619 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51238 .00525 Mdot
.53943 .01671 Mdot
.62501 .05289 Mdot
.8794 .15722 Mdot
.29787 .25863 Mdot
.48833 .11771 Mdot
.66131 .1069 Mdot
.0369 .23213 Mdot
.35763 .19823 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00172 Mdot
.51289 .00546 Mdot
.54104 .0174 Mdot
.63007 .05502 Mdot
.89319 .16262 Mdot
.30477 .25437 Mdot
.49162 .11548 Mdot
.66589 .10771 Mdot
.04633 .23513 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50811 .00344 Mdot
.52582 .01095 Mdot
.58209 .03478 Mdot
.75611 .10755 Mdot
.16869 .25499 Mdot
.37302 .12628 Mdot
.40645 .02066 Mdot
.30749 .55687 Mdot
.9852 .41885 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50696 .00295 Mdot
.52219 .00941 Mdot
.57058 .02991 Mdot
.72141 .09322 Mdot
.10714 .23839 Mdot
.34402 .1464 Mdot
.38263 .02386 Mdot
.26071 .54269 Mdot
.90061 .39548 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50126 .00053 Mdot
.50401 .0017 Mdot
.51277 .00541 Mdot
.54065 .01724 Mdot
.62886 .05452 Mdot
.88993 .16135 Mdot
.30325 .25545 Mdot
.49108 .11608 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48592 .61206 Mdot
.45516 .59902 Mdot
.35803 .558 Mdot
.07507 .44316 Mdot
.68364 .37612 Mdot
.51049 .51102 Mdot
.35305 .52074 Mdot
.00521 .40306 Mdot
.64955 .39822 Mdot
.49913 .61766 Mdot
.49722 .61686 Mdot
.49115 .61428 Mdot
.4718 .60608 Mdot
.41038 .58007 Mdot
.22153 .50131 Mdot
.79775 .35612 Mdot
.60204 .49708 Mdot
.54912 .58533 Mdot
.5687 .01211 Mdot
.68818 .07384 Mdot
.49827 .6173 Mdot
.49448 .61569 Mdot
.48242 .61058 Mdot
.44403 .59431 Mdot
.32341 .54349 Mdot
.989 .41136 Mdot
.67108 .42155 Mdot
.56313 .55132 Mdot
.54743 .60833 Mdot
.60181 .03361 Mdot
.7987 .12169 Mdot
.4979 .61714 Mdot
.49329 .61519 Mdot
.47863 .60897 Mdot
.43203 .58923 Mdot
.28652 .52811 Mdot
.90855 .38443 Mdot
.66033 .46462 Mdot
.61393 .58936 Mdot
.72421 .06815 Mdot
.07009 .21377 Mdot
.3142 .15087 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.50842 .00357 Mdot
.52681 .01137 Mdot
.58522 .0361 Mdot
.76543 .11138 Mdot
.18325 .25823 Mdot
.38303 .12347 Mdot
.42274 .02454 Mdot
.35104 .57372 Mdot
.49851 .6174 Mdot
.49524 .61602 Mdot
.48483 .6116 Mdot
.45171 .59756 Mdot
.34725 .55348 Mdot
.04726 .43263 Mdot
.67742 .38946 Mdot
.5219 .52192 Mdot
.39914 .54216 Mdot
.13502 .4548 Mdot
.6918 .34411 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49106 .61424 Mdot
.47151 .60596 Mdot
.40947 .57969 Mdot
.21884 .50022 Mdot
.79403 .35549 Mdot
.59888 .49742 Mdot
.5427 .58331 Mdot
.54979 .00439 Mdot
.63036 .0498 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50789 .00335 Mdot
.52514 .01066 Mdot
.57993 .03386 Mdot
.74964 .10489 Mdot
.15809 .25243 Mdot
.36652 .12881 Mdot
.39738 .01907 Mdot
.28476 .54843 Mdot
.93908 .40439 Mdot
.68256 .4595 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51705 .00723 Mdot
.55429 .02301 Mdot
.67138 .07237 Mdot
.99865 .20227 Mdot
.32795 .20352 Mdot
.44658 .07332 Mdot
.48659 .02472 Mdot
.5065 .0123 Mdot
.53614 .01832 Mdot
.49782 .61711 Mdot
.49305 .61508 Mdot
.47784 .60864 Mdot
.42952 .58817 Mdot
.27889 .52494 Mdot
.89345 .37982 Mdot
.65616 .47138 Mdot
.6173 .59402 Mdot
.73888 .07514 Mdot
.09862 .22233 Mdot
.31971 .13664 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50642 .00272 Mdot
.52045 .00867 Mdot
.56506 .02757 Mdot
.70456 .08622 Mdot
.07314 .22779 Mdot
.33583 .16235 Mdot
.39366 .03574 Mdot
.3036 .56237 Mdot
.98821 .42311 Mdot
.69049 .43403 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50603 .00256 Mdot
.5192 .00814 Mdot
.5611 .0259 Mdot
.69242 .08116 Mdot
.04701 .21915 Mdot
.33211 .1762 Mdot
.40955 .04786 Mdot
.35849 .58648 Mdot
.12206 .47191 Mdot
.71997 .36952 Mdot
.49856 .61743 Mdot
.49543 .61609 Mdot
.48543 .61186 Mdot
.45361 .59837 Mdot
.35317 .55596 Mdot
.06243 .43835 Mdot
.68043 .38194 Mdot
.51471 .51561 Mdot
.37103 .52923 Mdot
.05437 .42233 Mdot
.65774 .3729 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61476 Mdot
.47543 .60762 Mdot
.42188 .58493 Mdot
.25579 .51538 Mdot
.85112 .36794 Mdot
.6386 .48669 Mdot
.60868 .59954 Mdot
.72941 .07461 Mdot
.08688 .22093 Mdot
.499 .61761 Mdot
.4968 .61668 Mdot
.48981 .61371 Mdot
.46753 .60427 Mdot
.39688 .57437 Mdot
.18216 .48533 Mdot
.75006 .35098 Mdot
.5567 .49853 Mdot
.4466 .54999 Mdot
.25791 .50141 Mdot
.83077 .35405 Mdot
.49804 .6172 Mdot
.49374 .61538 Mdot
.48006 .60958 Mdot
.43655 .59114 Mdot
.30037 .53387 Mdot
.9373 .39365 Mdot
.66587 .45028 Mdot
.60059 .57769 Mdot
.67635 .04682 Mdot
.96573 .17885 Mdot
.30612 .21037 Mdot
.49871 .61749 Mdot
.49588 .61629 Mdot
.48688 .61247 Mdot
.45821 .60032 Mdot
.36758 .56202 Mdot
.10045 .45294 Mdot
.69245 .36588 Mdot
.50775 .50388 Mdot
.33468 .51107 Mdot
.95587 .38392 Mdot
.64241 .42431 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50269 .00114 Mdot
.50857 .00363 Mdot
.52729 .01157 Mdot
.58674 .03674 Mdot
.76996 .11323 Mdot
.19003 .25962 Mdot
.38812 .12243 Mdot
.43188 .02704 Mdot
.37655 .58384 Mdot
.15405 .48052 Mdot
.49932 .61775 Mdot
.49784 .61712 Mdot
.49311 .61511 Mdot
.47804 .60872 Mdot
.43015 .58843 Mdot
.28081 .52574 Mdot
.8972 .38095 Mdot
.65729 .46976 Mdot
.61674 .59297 Mdot
.736 .07371 Mdot
.09308 .22069 Mdot
.49944 .6178 Mdot
.49823 .61728 Mdot
.49435 .61564 Mdot
.48199 .6104 Mdot
.44268 .59374 Mdot
.31925 .54175 Mdot
.97932 .40795 Mdot
.67033 .42707 Mdot
.57077 .55651 Mdot
.57391 .00194 Mdot
.68398 .06803 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00126 Mdot
.5095 .00403 Mdot
.53026 .01283 Mdot
.59614 .04072 Mdot
.79763 .12452 Mdot
.22723 .26551 Mdot
.42054 .11947 Mdot
.49956 .04884 Mdot
.57793 .04843 Mdot
.76856 .11782 Mdot
.49742 .61694 Mdot
.49177 .61455 Mdot
.4738 .60692 Mdot
.4167 .58274 Mdot
.24026 .50899 Mdot
.82555 .36172 Mdot
.62317 .49296 Mdot
.58764 .59608 Mdot
.67704 .05525 Mdot
.98052 .18756 Mdot
.31315 .20557 Mdot
.5004 .00017 Mdot
.50126 .00054 Mdot
.50402 .00171 Mdot
.51281 .00543 Mdot
.5408 .0173 Mdot
.62932 .05471 Mdot
.89117 .16183 Mdot
.30384 .25504 Mdot
.4913 .11586 Mdot
.66572 .1078 Mdot
.04617 .23513 Mdot
.35833 .19293 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50647 .00274 Mdot
.52062 .00874 Mdot
.56561 .02781 Mdot
.70625 .08692 Mdot
.07666 .22893 Mdot
.33647 .16057 Mdot
.39194 .03428 Mdot
.29748 .55965 Mdot
.97483 .41863 Mdot
.68978 .44186 Mdot
.4997 .61791 Mdot
.49903 .61762 Mdot
.49691 .61673 Mdot
.49017 .61387 Mdot
.46869 .60476 Mdot
.40054 .57592 Mdot
.19274 .4896 Mdot
.76148 .3515 Mdot
.56834 .49867 Mdot
.47459 .56009 Mdot
.34287 .53663 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.50931 .00395 Mdot
.52967 .01258 Mdot
.59426 .03992 Mdot
.79213 .12229 Mdot
.22041 .26469 Mdot
.41408 .11969 Mdot
.48503 .04385 Mdot
.53356 .02999 Mdot
.63206 .06087 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51188 .00504 Mdot
.53783 .01604 Mdot
.62 .05078 Mdot
.86559 .15178 Mdot
.28967 .2621 Mdot
.48239 .11911 Mdot
.64876 .10282 Mdot
.00718 .22151 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.50481 .00204 Mdot
.51532 .0065 Mdot
.54878 .02068 Mdot
.65425 .06519 Mdot
.95655 .18683 Mdot
.32322 .22661 Mdot
.47596 .0944 Mdot
.5928 .07221 Mdot
.84107 .15344 Mdot
.29005 .27748 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50657 .00279 Mdot
.52094 .00888 Mdot
.56663 .02824 Mdot
.70936 .08821 Mdot
.08308 .23097 Mdot
.33777 .1574 Mdot
.38911 .03173 Mdot
.28724 .55508 Mdot
.95315 .41155 Mdot
.68832 .45436 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.4778 .60862 Mdot
.42939 .58811 Mdot
.2785 .52478 Mdot
.89269 .37959 Mdot
.65593 .4717 Mdot
.61739 .59422 Mdot
.7394 .07541 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.486 .6121 Mdot
.45543 .59914 Mdot
.35887 .55836 Mdot
.07729 .44401 Mdot
.68428 .37514 Mdot
.50993 .51028 Mdot
.35047 .51948 Mdot
.99828 .40037 Mdot
.64867 .40197 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55363 .02273 Mdot
.66934 .07151 Mdot
.99378 .20052 Mdot
.32755 .20628 Mdot
.45036 .0759 Mdot
.49991 .03062 Mdot
.54931 .03054 Mdot
.67151 .07552 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47722 .60838 Mdot
.42754 .58733 Mdot
.2729 .52246 Mdot
.88199 .37644 Mdot
.65231 .47609 Mdot
.6178 .5967 Mdot
.74428 .07817 Mdot
.10935 .22562 Mdot
.32299 .13204 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.4933 .61519 Mdot
.47866 .60899 Mdot
.43212 .58927 Mdot
.28681 .52823 Mdot
.90913 .38461 Mdot
.66047 .46435 Mdot
.61375 .58916 Mdot
.72349 .06782 Mdot
.06865 .21332 Mdot
.49923 .61771 Mdot
.49756 .617 Mdot
.49222 .61474 Mdot
.47523 .60753 Mdot
.42122 .58466 Mdot
.2538 .51457 Mdot
.84772 .36706 Mdot
.63677 .48766 Mdot
.60664 .59941 Mdot
.72476 .073 Mdot
.07862 .2187 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50763 .00324 Mdot
.52431 .01031 Mdot
.57732 .03276 Mdot
.7418 .10165 Mdot
.14469 .249 Mdot
.35923 .13259 Mdot
.3891 .01846 Mdot
.26575 .5418 Mdot
.90483 .39498 Mdot
.67831 .47804 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50579 .00246 Mdot
.51846 .00783 Mdot
.55875 .0249 Mdot
.68517 .07813 Mdot
.03079 .21361 Mdot
.33051 .18524 Mdot
.4214 .05617 Mdot
.39913 .60427 Mdot
.23549 .5169 Mdot
.83411 .36997 Mdot
.49747 .61696 Mdot
.49195 .61462 Mdot
.47435 .60716 Mdot
.41844 .58348 Mdot
.24549 .51114 Mdot
.8339 .36366 Mdot
.62863 .49117 Mdot
.59598 .59785 Mdot
.69873 .0635 Mdot
.02792 .20345 Mdot
.31545 .1777 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47575 .60775 Mdot
.42289 .58536 Mdot
.25883 .51664 Mdot
.8564 .36932 Mdot
.64131 .4851 Mdot
.61143 .59956 Mdot
.73535 .07659 Mdot
.097 .22351 Mdot
.32199 .13905 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50552 .00234 Mdot
.51759 .00746 Mdot
.55598 .02373 Mdot
.67663 .07456 Mdot
.01108 .2067 Mdot
.32893 .19644 Mdot
.4368 .06667 Mdot
.45234 .00961 Mdot
.39747 .58412 Mdot
.19922 .49551 Mdot
.50015 6e-05 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51566 .00664 Mdot
.54985 .02113 Mdot
.65759 .06659 Mdot
.96494 .18995 Mdot
.32446 .22219 Mdot
.47089 .0905 Mdot
.57391 .06367 Mdot
.78385 .12975 Mdot
.49926 .61772 Mdot
.49763 .61703 Mdot
.49245 .61483 Mdot
.47594 .60783 Mdot
.42349 .58561 Mdot
.26063 .51738 Mdot
.85958 .37017 Mdot
.64287 .4841 Mdot
.61283 .59947 Mdot
.73821 .07749 Mdot
.10167 .22463 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.50931 .00395 Mdot
.52965 .01257 Mdot
.59422 .03991 Mdot
.79202 .12224 Mdot
.22027 .26468 Mdot
.41394 .1197 Mdot
.48473 .04375 Mdot
.53265 .02962 Mdot
.62921 .05968 Mdot
.49966 .61789 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48908 .6134 Mdot
.46521 .60329 Mdot
.38958 .57129 Mdot
.1613 .47695 Mdot
.73041 .35173 Mdot
.53645 .49816 Mdot
.39668 .53165 Mdot
.11258 .44245 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50693 .00294 Mdot
.52208 .00936 Mdot
.57024 .02977 Mdot
.72038 .09279 Mdot
.10512 .23779 Mdot
.3434 .14726 Mdot
.38289 .02441 Mdot
.26215 .54341 Mdot
.90337 .39629 Mdot
.68079 .48048 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49199 .61464 Mdot
.47447 .60721 Mdot
.41883 .58365 Mdot
.24665 .51162 Mdot
.83579 .36411 Mdot
.62981 .49073 Mdot
.59766 .59817 Mdot
.70299 .06509 Mdot
.0367 .20625 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52316 .00982 Mdot
.57368 .03122 Mdot
.7308 .09711 Mdot
.12492 .24358 Mdot
.35032 .1393 Mdot
.38285 .02011 Mdot
.25511 .53908 Mdot
.88876 .39162 Mdot
.67601 .48655 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52658 .01127 Mdot
.5845 .0358 Mdot
.76331 .11051 Mdot
.18002 .25754 Mdot
.3807 .12403 Mdot
.41873 .0235 Mdot
.34007 .56942 Mdot
.49985 .61797 Mdot
.49953 .61783 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48476 .61157 Mdot
.45149 .59747 Mdot
.34657 .55319 Mdot
.04552 .43198 Mdot
.67712 .39035 Mdot
.52286 .5227 Mdot
.40278 .54382 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50293 .00124 Mdot
.50934 .00396 Mdot
.52976 .01262 Mdot
.59455 .04004 Mdot
.79296 .12263 Mdot
.22146 .26483 Mdot
.41506 .11965 Mdot
.4872 .04459 Mdot
.54017 .03274 Mdot
.65275 .06958 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47696 .60827 Mdot
.42673 .58699 Mdot
.27042 .52143 Mdot
.87735 .3751 Mdot
.65057 .47788 Mdot
.61744 .59756 Mdot
.74492 .07879 Mdot
.11101 .22625 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50438 .00186 Mdot
.51397 .00592 Mdot
.54447 .01885 Mdot
.64082 .05955 Mdot
.92191 .17372 Mdot
.31549 .24324 Mdot
.49026 .10801 Mdot
.65042 .09899 Mdot
.00409 .21858 Mdot
.35163 .21479 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .00179 Mdot
.51346 .00571 Mdot
.54287 .01817 Mdot
.6358 .05744 Mdot
.90861 .1686 Mdot
.31109 .24875 Mdot
.49221 .11194 Mdot
.66165 .10472 Mdot
.03398 .23011 Mdot
.49851 .6174 Mdot
.49525 .61602 Mdot
.48486 .61161 Mdot
.4518 .5976 Mdot
.34753 .55359 Mdot
.04797 .4329 Mdot
.67754 .38909 Mdot
.52152 .52161 Mdot
.39769 .5415 Mdot
.13074 .45305 Mdot
.68901 .34503 Mdot
.49804 .6172 Mdot
.49375 .61539 Mdot
.4801 .6096 Mdot
.43667 .5912 Mdot
.30075 .53403 Mdot
.93812 .39392 Mdot
.66599 .44985 Mdot
.60011 .57731 Mdot
.67467 .04608 Mdot
.96173 .17741 Mdot
.30564 .21255 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.52378 .01009 Mdot
.57565 .03205 Mdot
.73675 .09957 Mdot
.13576 .2466 Mdot
.35494 .13546 Mdot
.38544 .01885 Mdot
.25855 .53961 Mdot
.89327 .39228 Mdot
.67635 .48397 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51092 .00463 Mdot
.53477 .01474 Mdot
.61037 .04672 Mdot
.83857 .14103 Mdot
.26948 .26632 Mdot
.46344 .11988 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51822 .00773 Mdot
.558 .02459 Mdot
.68288 .07718 Mdot
.02557 .21179 Mdot
.33007 .18819 Mdot
.42542 .05893 Mdot
.41295 .61033 Mdot
.27633 .53359 Mdot
.90422 .38806 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00194 Mdot
.51454 .00617 Mdot
.54631 .01963 Mdot
.64655 .06196 Mdot
.93685 .17941 Mdot
.31941 .23643 Mdot
.48558 .1027 Mdot
.63014 .08934 Mdot
.94887 .19699 Mdot
.34298 .24358 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.5082 .00348 Mdot
.52614 .01108 Mdot
.58309 .0352 Mdot
.7591 .10878 Mdot
.17346 .25608 Mdot
.37616 .12528 Mdot
.41129 .02171 Mdot
.32012 .56169 Mdot
.01303 .42824 Mdot
.68641 .41617 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50855 .00362 Mdot
.52723 .01154 Mdot
.58654 .03666 Mdot
.76937 .11299 Mdot
.18917 .25945 Mdot
.38746 .12255 Mdot
.43066 .0267 Mdot
.3731 .58246 Mdot
.14472 .47689 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51721 .0073 Mdot
.55478 .02322 Mdot
.67292 .07301 Mdot
.00233 .20359 Mdot
.32825 .20143 Mdot
.44371 .07136 Mdot
.47649 .02026 Mdot
.47413 .61657 Mdot
.43312 .59269 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.50381 .00161 Mdot
.51213 .00514 Mdot
.53862 .01637 Mdot
.62247 .05182 Mdot
.87242 .15448 Mdot
.29389 .26049 Mdot
.48566 .11852 Mdot
.65595 .10524 Mdot
.02448 .22777 Mdot
.35644 .20516 Mdot
.49822 .61728 Mdot
.49431 .61562 Mdot
.48188 .61035 Mdot
.44234 .59359 Mdot
.31819 .5413 Mdot
.97688 .40709 Mdot
.67013 .42845 Mdot
.57268 .55781 Mdot
.5805 .00483 Mdot
.70398 .07632 Mdot
.05628 .21773 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47697 .60827 Mdot
.42674 .58699 Mdot
.27045 .52144 Mdot
.87739 .37511 Mdot
.65059 .47786 Mdot
.61745 .59755 Mdot
.74492 .07878 Mdot
.111 .22625 Mdot
.32375 .13149 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49809 .61723 Mdot
.49393 .61546 Mdot
.48066 .60983 Mdot
.43844 .59194 Mdot
.30616 .53628 Mdot
.94987 .39783 Mdot
.66753 .44354 Mdot
.59259 .57172 Mdot
.64883 .03476 Mdot
.49765 .61704 Mdot
.49251 .61486 Mdot
.47615 .60792 Mdot
.42415 .5859 Mdot
.26263 .51821 Mdot
.86313 .37113 Mdot
.64455 .48294 Mdot
.61419 .59927 Mdot
.74078 .07824 Mdot
.10571 .22554 Mdot
.32348 .13459 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .00159 Mdot
.51198 .00508 Mdot
.53815 .01618 Mdot
.62101 .05121 Mdot
.86838 .15289 Mdot
.29144 .26146 Mdot
.48381 .11889 Mdot
.65193 .10391 Mdot
.01488 .22431 Mdot
.35554 .21054 Mdot
.49818 .61726 Mdot
.49421 .61558 Mdot
.48155 .61021 Mdot
.44128 .59315 Mdot
.31492 .53994 Mdot
.96942 .4045 Mdot
.66951 .43268 Mdot
.57843 .56175 Mdot
.6003 .01352 Mdot
.76287 .10047 Mdot
.16339 .24753 Mdot
.49797 .61718 Mdot
.49355 .6153 Mdot
.47944 .60932 Mdot
.43458 .59031 Mdot
.29434 .53136 Mdot
.92457 .3895 Mdot
.66376 .45684 Mdot
.60747 .58325 Mdot
.70043 .05745 Mdot
.02063 .1979 Mdot
.30997 .17882 Mdot
.498 .61718 Mdot
.49361 .61533 Mdot
.47965 .60941 Mdot
.43525 .59059 Mdot
.29639 .53221 Mdot
.92886 .39089 Mdot
.66452 .45466 Mdot
.60531 .58144 Mdot
.69278 .05406 Mdot
.00372 .19217 Mdot
.30908 .18872 Mdot
.49829 .61731 Mdot
.49457 .61573 Mdot
.48269 .6107 Mdot
.44491 .59468 Mdot
.32613 .54462 Mdot
.99542 .41364 Mdot
.67158 .41789 Mdot
.55807 .54788 Mdot
.52974 .60053 Mdot
.54575 .0099 Mdot
.62945 .05173 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53096 .01313 Mdot
.59835 .04165 Mdot
.80405 .12713 Mdot
.23485 .26625 Mdot
.42799 .11937 Mdot
.51678 .05487 Mdot
.63067 .07039 Mdot
.91929 .17838 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49677 .61666 Mdot
.4897 .61366 Mdot
.46718 .60412 Mdot
.39578 .57391 Mdot
.179 .48405 Mdot
.74684 .35095 Mdot
.55338 .49846 Mdot
.43848 .54702 Mdot
.23359 .4914 Mdot
.50042 .00018 Mdot
.50133 .00057 Mdot
.50425 .0018 Mdot
.51355 .00575 Mdot
.54315 .01829 Mdot
.63667 .0578 Mdot
.91092 .16949 Mdot
.31192 .24783 Mdot
.49203 .11131 Mdot
.66019 .10393 Mdot
.03008 .2286 Mdot
.35511 .20088 Mdot
.49955 .61784 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.48532 .61181 Mdot
.45327 .59822 Mdot
.35213 .55553 Mdot
.05975 .43733 Mdot
.67983 .38323 Mdot
.51582 .51667 Mdot
.37551 .53131 Mdot
.06692 .42732 Mdot
.49791 .61715 Mdot
.49335 .61522 Mdot
.47883 .60906 Mdot
.43264 .58949 Mdot
.2884 .52889 Mdot
.91233 .38561 Mdot
.66122 .46284 Mdot
.61265 .58802 Mdot
.71931 .06592 Mdot
.06027 .21073 Mdot
.31297 .15618 Mdot
.49855 .61742 Mdot
.49537 .61607 Mdot
.48524 .61177 Mdot
.453 .59811 Mdot
.35128 .55517 Mdot
.05755 .4365 Mdot
.67937 .38431 Mdot
.51679 .51756 Mdot
.37935 .53309 Mdot
.07778 .43165 Mdot
.66413 .36238 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50678 .00288 Mdot
.52161 .00916 Mdot
.56875 .02913 Mdot
.71583 .0909 Mdot
.09617 .23506 Mdot
.34087 .15123 Mdot
.38471 .02709 Mdot
.27034 .54735 Mdot
.91919 .40101 Mdot
.49983 .61796 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48249 .61061 Mdot
.44425 .5944 Mdot
.32409 .54377 Mdot
.99061 .41193 Mdot
.6712 .42063 Mdot
.56186 .55046 Mdot
.54299 .60637 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51643 .00697 Mdot
.5523 .02217 Mdot
.66523 .06979 Mdot
.98382 .1969 Mdot
.32664 .21187 Mdot
.45787 .08111 Mdot
.52664 .0425 Mdot
.6352 .06709 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47987 .6095 Mdot
.43594 .59088 Mdot
.29849 .53308 Mdot
.9333 .39233 Mdot
.66526 .45238 Mdot
.6029 .5795 Mdot
.68437 .05035 Mdot
.98456 .18553 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50593 .00252 Mdot
.51891 .00802 Mdot
.56017 .0255 Mdot
.68956 .07997 Mdot
.04067 .217 Mdot
.33144 .17971 Mdot
.41405 .05106 Mdot
.37392 .59323 Mdot
.16383 .48819 Mdot
.74915 .36175 Mdot
.49988 .61798 Mdot
.49962 .61787 Mdot
.4988 .61753 Mdot
.49619 .61642 Mdot
.48785 .61288 Mdot
.4613 .60163 Mdot
.37728 .56611 Mdot
.1269 .46329 Mdot
.7057 .35772 Mdot
.51405 .49959 Mdot
.34344 .51259 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52328 .00987 Mdot
.57403 .03137 Mdot
.73188 .09755 Mdot
.12691 .24414 Mdot
.35112 .13857 Mdot
.38318 .01981 Mdot
.25533 .53902 Mdot
.88888 .39155 Mdot
.67589 .4864 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50314 .00133 Mdot
.51 .00424 Mdot
.53185 .0135 Mdot
.60116 .04283 Mdot
.81218 .13042 Mdot
.24395 .26685 Mdot
.43716 .11941 Mdot
.53854 .06266 Mdot
.69717 .09804 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48012 .6096 Mdot
.43672 .59122 Mdot
.30089 .53409 Mdot
.93844 .39402 Mdot
.66604 .44968 Mdot
.59991 .57717 Mdot
.67401 .04579 Mdot
.96014 .17684 Mdot
.30544 .21341 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49025 .6139 Mdot
.46895 .60487 Mdot
.40136 .57626 Mdot
.19511 .49056 Mdot
.76418 .35171 Mdot
.57104 .49867 Mdot
.48096 .56236 Mdot
.36238 .54475 Mdot
.06215 .43248 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50617 .00261 Mdot
.51964 .00833 Mdot
.56251 .0265 Mdot
.69676 .08297 Mdot
.05652 .22234 Mdot
.33326 .17104 Mdot
.40321 .04323 Mdot
.33676 .57696 Mdot
.06618 .4508 Mdot
.69916 .39121 Mdot
.49787 .61713 Mdot
.49321 .61516 Mdot
.47838 .60887 Mdot
.43121 .58888 Mdot
.28404 .52708 Mdot
.90358 .38289 Mdot
.65906 .46692 Mdot
.61536 .59102 Mdot
.72993 .07081 Mdot
.08134 .21718 Mdot
.31598 .14502 Mdot
.49776 .61709 Mdot
.49287 .61501 Mdot
.4773 .60841 Mdot
.42779 .58744 Mdot
.27365 .52277 Mdot
.8834 .37685 Mdot
.65282 .47553 Mdot
.61784 .59641 Mdot
.74391 .07791 Mdot
.10853 .22535 Mdot
.32268 .13236 Mdot
.50015 6e-05 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51574 .00667 Mdot
.55011 .02124 Mdot
.6584 .06693 Mdot
.96697 .19071 Mdot
.32473 .22111 Mdot
.46959 .08953 Mdot
.56911 .06151 Mdot
.76907 .12358 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51143 .00485 Mdot
.53639 .01543 Mdot
.61548 .04888 Mdot
.85298 .14678 Mdot
.28096 .26451 Mdot
.4747 .11974 Mdot
.63067 .09639 Mdot
.96134 .20437 Mdot
.34944 .23985 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50804 .00341 Mdot
.5256 .01086 Mdot
.5814 .03449 Mdot
.75404 .1067 Mdot
.16534 .2542 Mdot
.37089 .12704 Mdot
.40334 .02005 Mdot
.29954 .55388 Mdot
.96848 .41343 Mdot
.68439 .44246 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50763 .00324 Mdot
.52431 .01031 Mdot
.57732 .03276 Mdot
.74179 .10165 Mdot
.14468 .249 Mdot
.35923 .1326 Mdot
.38909 .01846 Mdot
.26574 .5418 Mdot
.90482 .39497 Mdot
.67831 .47804 Mdot
.49956 .61785 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48591 .61206 Mdot
.45515 .59902 Mdot
.358 .55799 Mdot
.075 .44313 Mdot
.68362 .37615 Mdot
.51051 .51104 Mdot
.35314 .52077 Mdot
.00543 .40314 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47504 .60745 Mdot
.42064 .58441 Mdot
.25206 .51385 Mdot
.84478 .36632 Mdot
.63513 .48846 Mdot
.60469 .59922 Mdot
.72019 .07138 Mdot
.07025 .21635 Mdot
.31832 .15332 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50692 .00293 Mdot
.52203 .00934 Mdot
.57009 .0297 Mdot
.7199 .09259 Mdot
.1042 .23751 Mdot
.34312 .14766 Mdot
.38303 .02466 Mdot
.26286 .54376 Mdot
.49843 .61737 Mdot
.49501 .61592 Mdot
.4841 .61129 Mdot
.44937 .59657 Mdot
.33999 .55043 Mdot
.02902 .42585 Mdot
.67476 .39909 Mdot
.53306 .53046 Mdot
.44059 .56088 Mdot
.26106 .50708 Mdot
.84337 .35989 Mdot
.49739 .61693 Mdot
.49169 .61451 Mdot
.47352 .60681 Mdot
.41582 .58237 Mdot
.23766 .50792 Mdot
.82148 .36082 Mdot
.62036 .49373 Mdot
.58306 .59498 Mdot
.66476 .0505 Mdot
.95177 .17738 Mdot
.31002 .22141 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00305 Mdot
.52288 .0097 Mdot
.57278 .03084 Mdot
.72807 .09598 Mdot
.11983 .24212 Mdot
.34836 .14123 Mdot
.3823 .02098 Mdot
.25536 .53958 Mdot
.88981 .39212 Mdot
.67666 .4863 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49026 .61391 Mdot
.46899 .60489 Mdot
.40149 .57632 Mdot
.19549 .49072 Mdot
.76462 .35174 Mdot
.57148 .49866 Mdot
.48198 .56272 Mdot
.36551 .54605 Mdot
.07048 .43569 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51269 .00538 Mdot
.54041 .01713 Mdot
.62811 .0542 Mdot
.88788 .16055 Mdot
.30226 .2561 Mdot
.49066 .11644 Mdot
.66507 .10779 Mdot
.04502 .23482 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00822 Mdot
.56172 .02616 Mdot
.69434 .08196 Mdot
.05123 .22057 Mdot
.3326 .17389 Mdot
.40667 .04578 Mdot
.34862 .58216 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49106 .61424 Mdot
.47151 .60595 Mdot
.40946 .57968 Mdot
.2188 .5002 Mdot
.79398 .35548 Mdot
.59884 .49743 Mdot
.5426 .58328 Mdot
.54952 .00427 Mdot
.62951 .04944 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.5073 .00309 Mdot
.52325 .00986 Mdot
.57395 .03133 Mdot
.73162 .09745 Mdot
.12644 .24401 Mdot
.35093 .13874 Mdot
.3831 .01988 Mdot
.25526 .53903 Mdot
.88882 .39156 Mdot
.67591 .48645 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00156 Mdot
.51174 .00498 Mdot
.5374 .01586 Mdot
.61865 .05021 Mdot
.86183 .15029 Mdot
.2872 .26289 Mdot
.48032 .11936 Mdot
.64401 .10116 Mdot
.99541 .21718 Mdot
.3537 .22143 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47644 .60805 Mdot
.42507 .58629 Mdot
.26542 .51936 Mdot
.86815 .37251 Mdot
.6468 .48123 Mdot
.61572 .59883 Mdot
.74334 .07887 Mdot
.10948 .22629 Mdot
.32405 .13261 Mdot
.49945 .6178 Mdot
.49826 .61729 Mdot
.49445 .61568 Mdot
.4823 .61053 Mdot
.44368 .59416 Mdot
.32231 .54303 Mdot
.98644 .41045 Mdot
.67088 .42301 Mdot
.56516 .55269 Mdot
.55447 .61143 Mdot
.6239 .04291 Mdot
.49935 .61776 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47912 .60918 Mdot
.43356 .58988 Mdot
.2912 .53005 Mdot
.91807 .38742 Mdot
.66248 .46007 Mdot
.61042 .58586 Mdot
.71102 .06218 Mdot
.04323 .20532 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50496 .0021 Mdot
.51581 .0067 Mdot
.55033 .02133 Mdot
.65909 .06722 Mdot
.96868 .19134 Mdot
.32495 .22019 Mdot
.46847 .0887 Mdot
.56501 .05966 Mdot
.75638 .11827 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54094 .01736 Mdot
.62976 .05489 Mdot
.89237 .1623 Mdot
.30439 .25465 Mdot
.49149 .11563 Mdot
.66584 .10775 Mdot
.04632 .23515 Mdot
.35829 .19281 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50468 .00198 Mdot
.5149 .00632 Mdot
.54745 .02012 Mdot
.65013 .06346 Mdot
.94606 .1829 Mdot
.32136 .23195 Mdot
.48152 .09899 Mdot
.61404 .0819 Mdot
.49886 .61755 Mdot
.49636 .61649 Mdot
.4884 .61312 Mdot
.46306 .60237 Mdot
.3828 .56843 Mdot
.14222 .46934 Mdot
.71558 .35436 Mdot
.52212 .49847 Mdot
.36172 .5189 Mdot
.01904 .40624 Mdot
.64787 .38863 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50317 .00135 Mdot
.51011 .00429 Mdot
.5322 .01365 Mdot
.60227 .0433 Mdot
.8154 .13172 Mdot
.24739 .26698 Mdot
.44068 .11946 Mdot
.54704 .06573 Mdot
.49815 .61725 Mdot
.49411 .61554 Mdot
.48125 .61008 Mdot
.44032 .59274 Mdot
.31197 .5387 Mdot
.96274 .4022 Mdot
.6689 .43643 Mdot
.58345 .56523 Mdot
.61753 .02106 Mdot
.8123 .12038 Mdot
.22775 .25676 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50524 .00222 Mdot
.51671 .00709 Mdot
.55319 .02255 Mdot
.66798 .07094 Mdot
.99049 .19932 Mdot
.32726 .20814 Mdot
.45288 .07764 Mdot
.50884 .03459 Mdot
.57805 .04278 Mdot
.75971 .11227 Mdot
.49896 .61759 Mdot
.49669 .61663 Mdot
.48946 .61357 Mdot
.46644 .60381 Mdot
.39346 .57293 Mdot
.17235 .48138 Mdot
.74035 .35105 Mdot
.54666 .49832 Mdot
.42194 .54096 Mdot
.18478 .47146 Mdot
.72865 .33613 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51067 .00452 Mdot
.53398 .01441 Mdot
.60789 .04567 Mdot
.83151 .13821 Mdot
.26323 .26682 Mdot
.45705 .11979 Mdot
.58722 .08045 Mdot
.84178 .15733 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50387 .00164 Mdot
.51234 .00523 Mdot
.53929 .01666 Mdot
.62458 .05271 Mdot
.87823 .15677 Mdot
.29723 .25896 Mdot
.48793 .11786 Mdot
.66055 .10668 Mdot
.03518 .23153 Mdot
.35747 .19918 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.515 .00636 Mdot
.54776 .02025 Mdot
.6511 .06386 Mdot
.94853 .18383 Mdot
.32183 .23071 Mdot
.4803 .09794 Mdot
.6093 .07972 Mdot
.88965 .17327 Mdot
.32258 .26757 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50438 .00186 Mdot
.51396 .00592 Mdot
.54446 .01885 Mdot
.64078 .05953 Mdot
.9218 .17368 Mdot
.31545 .24329 Mdot
.49028 .10805 Mdot
.65054 .09905 Mdot
.00441 .21871 Mdot
.35167 .21461 Mdot
.49927 .61772 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47637 .60801 Mdot
.42485 .58619 Mdot
.26474 .51908 Mdot
.86691 .37217 Mdot
.64626 .48166 Mdot
.61538 .59895 Mdot
.74282 .07876 Mdot
.10875 .22616 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51215 .00515 Mdot
.5387 .01641 Mdot
.62273 .05193 Mdot
.87313 .15476 Mdot
.29432 .26031 Mdot
.48597 .11845 Mdot
.65659 .10545 Mdot
.026 .22831 Mdot
.35658 .20431 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.5059 .0025 Mdot
.51879 .00797 Mdot
.55979 .02534 Mdot
.68839 .07948 Mdot
.03806 .21611 Mdot
.33118 .18116 Mdot
.41596 .05239 Mdot
.38044 .59609 Mdot
.18199 .49538 Mdot
.76627 .36111 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49054 .61402 Mdot
.46986 .60525 Mdot
.40424 .57748 Mdot
.20348 .49396 Mdot
.77412 .35267 Mdot
.58075 .49853 Mdot
.50338 .57022 Mdot
.43108 .57335 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51527 .00647 Mdot
.54861 .02061 Mdot
.65374 .06497 Mdot
.95525 .18634 Mdot
.323 .22729 Mdot
.47671 .09499 Mdot
.5956 .07348 Mdot
.84941 .15687 Mdot
.29688 .27655 Mdot
.49838 .61735 Mdot
.49484 .61585 Mdot
.48357 .61107 Mdot
.44771 .59587 Mdot
.3348 .54826 Mdot
.01626 .42116 Mdot
.67337 .40612 Mdot
.54207 .53689 Mdot
.47315 .57544 Mdot
.36413 .55066 Mdot
.07517 .43945 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.5108 .00458 Mdot
.5344 .01459 Mdot
.6092 .04623 Mdot
.83525 .13971 Mdot
.2666 .26659 Mdot
.46051 .11984 Mdot
.59578 .08361 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51444 .00612 Mdot
.54598 .01949 Mdot
.64552 .06152 Mdot
.93418 .1784 Mdot
.31878 .23769 Mdot
.48659 .10371 Mdot
.49772 .61707 Mdot
.49274 .61495 Mdot
.47686 .60822 Mdot
.42639 .58684 Mdot
.26941 .52101 Mdot
.87547 .37456 Mdot
.64984 .47859 Mdot
.6172 .59786 Mdot
.74491 .07893 Mdot
.11123 .2264 Mdot
.32396 .13147 Mdot
.49808 .61722 Mdot
.49387 .61543 Mdot
.48047 .60975 Mdot
.43784 .59169 Mdot
.30432 .53551 Mdot
.94583 .39648 Mdot
.66704 .44573 Mdot
.59527 .57368 Mdot
.65803 .03879 Mdot
.92077 .16238 Mdot
.2975 .23283 Mdot
.49802 .6172 Mdot
.49371 .61537 Mdot
.47995 .60953 Mdot
.4362 .591 Mdot
.2993 .53342 Mdot
.93503 .3929 Mdot
.66553 .45148 Mdot
.60192 .57872 Mdot
.68096 .04885 Mdot
.97661 .18273 Mdot
.30722 .20433 Mdot
.49806 .61721 Mdot
.49383 .61542 Mdot
.48033 .6097 Mdot
.43742 .59151 Mdot
.30303 .53498 Mdot
.94304 .39555 Mdot
.66668 .44723 Mdot
.59707 .57502 Mdot
.66421 .04149 Mdot
.93623 .16812 Mdot
.30137 .22566 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49542 .61609 Mdot
.48541 .61185 Mdot
.45354 .59834 Mdot
.35298 .55588 Mdot
.06193 .43816 Mdot
.68031 .38218 Mdot
.51491 .51581 Mdot
.37185 .52962 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49428 .61561 Mdot
.48177 .6103 Mdot
.44197 .59344 Mdot
.31703 .54082 Mdot
.97422 .40617 Mdot
.66991 .42996 Mdot
.57474 .55921 Mdot
.58761 .00795 Mdot
.72534 .08513 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50515 .00218 Mdot
.51641 .00696 Mdot
.55223 .02214 Mdot
.66501 .0697 Mdot
.98328 .1967 Mdot
.32658 .21217 Mdot
.45827 .08138 Mdot
.52807 .04314 Mdot
.63975 .06902 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50584 .00248 Mdot
.5186 .00789 Mdot
.55919 .02509 Mdot
.68655 .07871 Mdot
.03391 .21468 Mdot
.33079 .18348 Mdot
.41904 .05454 Mdot
.39103 .60072 Mdot
.21204 .50741 Mdot
.80107 .36404 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50761 .00323 Mdot
.52423 .01027 Mdot
.57706 .03265 Mdot
.74103 .10133 Mdot
.14334 .24864 Mdot
.35856 .13301 Mdot
.38845 .01848 Mdot
.26439 .54136 Mdot
.90258 .39442 Mdot
.67794 .4792 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48636 .61225 Mdot
.45657 .59962 Mdot
.36243 .55986 Mdot
.0867 .44762 Mdot
.68725 .37116 Mdot
.50823 .50739 Mdot
.34153 .51501 Mdot
.97451 .3912 Mdot
.64556 .41473 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.51511 .00641 Mdot
.5481 .02039 Mdot
.65216 .06431 Mdot
.95125 .18484 Mdot
.32232 .22934 Mdot
.47889 .09677 Mdot
.6039 .07726 Mdot
.87392 .16688 Mdot
.31389 .27192 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52504 .01062 Mdot
.57962 .03373 Mdot
.74871 .1045 Mdot
.15652 .25204 Mdot
.36561 .12922 Mdot
.39623 .01892 Mdot
.28199 .54743 Mdot
.49943 .61779 Mdot
.49819 .61726 Mdot
.49422 .61558 Mdot
.48158 .61022 Mdot
.44137 .59318 Mdot
.31519 .54005 Mdot
.97002 .40471 Mdot
.66956 .43234 Mdot
.57797 .56143 Mdot
.59873 .01283 Mdot
.75826 .09859 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52237 .00948 Mdot
.57115 .03015 Mdot
.72315 .09394 Mdot
.11049 .23939 Mdot
.34509 .14499 Mdot
.38232 .02301 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47344 .60677 Mdot
.41558 .58227 Mdot
.23693 .50762 Mdot
.82035 .36058 Mdot
.61956 .49394 Mdot
.58171 .59464 Mdot
.66112 .04908 Mdot
.94299 .17421 Mdot
.30856 .22593 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51517 .00643 Mdot
.54831 .02048 Mdot
.65279 .06458 Mdot
.95284 .18544 Mdot
.3226 .22852 Mdot
.47804 .09606 Mdot
.60063 .07577 Mdot
.86432 .16297 Mdot
.30776 .27406 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47497 .60742 Mdot
.42041 .58431 Mdot
.25138 .51357 Mdot
.84362 .36603 Mdot
.63447 .48877 Mdot
.60387 .59912 Mdot
.71825 .07069 Mdot
.06662 .21531 Mdot
.31796 .15533 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02053 Mdot
.65314 .06472 Mdot
.95374 .18578 Mdot
.32275 .22806 Mdot
.47755 .09567 Mdot
.59877 .07492 Mdot
.85881 .16072 Mdot
.30393 .2751 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48132 .61011 Mdot
.44055 .59284 Mdot
.31266 .53899 Mdot
.9643 .40274 Mdot
.66904 .43556 Mdot
.5823 .56442 Mdot
.61356 .01932 Mdot
.80109 .1159 Mdot
.21515 .2559 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49147 .61442 Mdot
.47284 .60652 Mdot
.41367 .58146 Mdot
.23125 .50529 Mdot
.81175 .35877 Mdot
.61324 .49535 Mdot
.57063 .5917 Mdot
.63051 .03701 Mdot
.86494 .14489 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61225 Mdot
.45659 .59963 Mdot
.3625 .55988 Mdot
.08687 .44769 Mdot
.68731 .37109 Mdot
.50821 .50734 Mdot
.3414 .51494 Mdot
.97416 .39107 Mdot
.64551 .41491 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50497 .00211 Mdot
.51583 .00671 Mdot
.55038 .02136 Mdot
.65926 .06729 Mdot
.96911 .1915 Mdot
.325 .21996 Mdot
.46819 .08849 Mdot
.56398 .0592 Mdot
.75317 .11693 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50692 .00294 Mdot
.52206 .00935 Mdot
.57017 .02973 Mdot
.72015 .0927 Mdot
.10468 .23765 Mdot
.34327 .14745 Mdot
.38296 .02453 Mdot
.26248 .54358 Mdot
.90401 .39649 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50555 .00236 Mdot
.5177 .0075 Mdot
.55632 .02387 Mdot
.67769 .07501 Mdot
.01356 .20758 Mdot
.32912 .19503 Mdot
.43484 .06534 Mdot
.44553 .00661 Mdot
.37611 .57513 Mdot
.13905 .47153 Mdot
.49831 .61732 Mdot
.49461 .61575 Mdot
.48284 .61076 Mdot
.44539 .59488 Mdot
.32761 .54524 Mdot
.99892 .4149 Mdot
.67185 .41589 Mdot
.55531 .54601 Mdot
.52007 .59626 Mdot
.51487 .61482 Mdot
.53194 .01055 Mdot
.49979 .61794 Mdot
.49932 .61775 Mdot
.49783 .61712 Mdot
.4931 .61511 Mdot
.47801 .60871 Mdot
.43005 .58839 Mdot
.28052 .52562 Mdot
.89662 .38077 Mdot
.65712 .47001 Mdot
.61684 .59314 Mdot
.73648 .07395 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00131 Mdot
.50987 .00419 Mdot
.53145 .01333 Mdot
.59988 .0423 Mdot
.8085 .12893 Mdot
.2399 .26662 Mdot
.43305 .11937 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00142 Mdot
.51069 .00454 Mdot
.53406 .01444 Mdot
.60814 .04578 Mdot
.83222 .13849 Mdot
.26389 .26678 Mdot
.45772 .1198 Mdot
.58888 .08106 Mdot
.84655 .15925 Mdot
.30035 .28046 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50344 .00146 Mdot
.51095 .00464 Mdot
.53487 .01478 Mdot
.61068 .04685 Mdot
.83945 .14139 Mdot
.27022 .26624 Mdot
.4642 .11988 Mdot
.60491 .08697 Mdot
.89185 .17734 Mdot
.32881 .27006 Mdot
.49772 .61707 Mdot
.49275 .61496 Mdot
.47689 .60824 Mdot
.4265 .58689 Mdot
.26972 .52114 Mdot
.87605 .37473 Mdot
.65007 .47837 Mdot
.61728 .59777 Mdot
.74493 .07889 Mdot
.11119 .22636 Mdot
.3239 .13146 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .0029 Mdot
.52182 .00925 Mdot
.56942 .02942 Mdot
.71789 .09176 Mdot
.10024 .23631 Mdot
.34198 .1494 Mdot
.38376 .02582 Mdot
.26626 .54542 Mdot
.91128 .39864 Mdot
.68259 .4767 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51876 .00796 Mdot
.55971 .02531 Mdot
.68814 .07938 Mdot
.03751 .21592 Mdot
.33113 .18147 Mdot
.41637 .05268 Mdot
.38185 .5967 Mdot
.18594 .49696 Mdot
.77038 .3612 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.5042 .00178 Mdot
.51338 .00567 Mdot
.54261 .01806 Mdot
.635 .0571 Mdot
.90645 .16777 Mdot
.31029 .24958 Mdot
.49232 .1125 Mdot
.66283 .10538 Mdot
.03715 .23134 Mdot
.35625 .19722 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.5054 .00229 Mdot
.5172 .00729 Mdot
.55474 .0232 Mdot
.67278 .07295 Mdot
.00199 .20347 Mdot
.32822 .20162 Mdot
.44397 .07154 Mdot
.47741 .02067 Mdot
.47708 .61783 Mdot
.44249 .59665 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60957 Mdot
.43651 .59113 Mdot
.30024 .53381 Mdot
.93703 .39356 Mdot
.66583 .45042 Mdot
.60075 .57781 Mdot
.6769 .04706 Mdot
.96705 .17932 Mdot
.30627 .20965 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48963 .61364 Mdot
.46696 .60403 Mdot
.3951 .57362 Mdot
.17704 .48326 Mdot
.74489 .35095 Mdot
.55135 .49842 Mdot
.43352 .54521 Mdot
.21883 .48535 Mdot
.76998 .34063 Mdot
.49926 .61772 Mdot
.49764 .61704 Mdot
.49249 .61485 Mdot
.47609 .6079 Mdot
.42396 .58582 Mdot
.26207 .51798 Mdot
.86212 .37086 Mdot
.64408 .48328 Mdot
.61382 .59933 Mdot
.74012 .07805 Mdot
.10468 .22531 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48984 .61372 Mdot
.46763 .60431 Mdot
.39719 .5745 Mdot
.18305 .48569 Mdot
.75099 .351 Mdot
.55766 .49855 Mdot
.44893 .55084 Mdot
.26491 .5043 Mdot
.8432 .3574 Mdot
.49802 .6172 Mdot
.4937 .61536 Mdot
.47994 .60953 Mdot
.43617 .59098 Mdot
.29919 .53338 Mdot
.9348 .39283 Mdot
.66549 .45159 Mdot
.60205 .57882 Mdot
.6814 .04904 Mdot
.97766 .1831 Mdot
.30732 .20374 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53634 .01541 Mdot
.61529 .0488 Mdot
.85246 .14658 Mdot
.28057 .26459 Mdot
.47434 .11976 Mdot
.6298 .09607 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49086 .61416 Mdot
.47089 .60569 Mdot
.40748 .57885 Mdot
.21299 .49783 Mdot
.7862 .35426 Mdot
.59198 .498 Mdot
.52819 .57861 Mdot
.50646 .6046 Mdot
.49441 .61059 Mdot
.50004 2e-05 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54192 .01777 Mdot
.63282 .05618 Mdot
.90062 .16551 Mdot
.30799 .25177 Mdot
.4923 .11391 Mdot
.66506 .10677 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52528 .01072 Mdot
.5804 .03406 Mdot
.75105 .10547 Mdot
.16042 .25301 Mdot
.36789 .12822 Mdot
.39918 .01934 Mdot
.28915 .55003 Mdot
.94757 .40693 Mdot
.68322 .45466 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48298 .61082 Mdot
.44583 .59507 Mdot
.32898 .54582 Mdot
.00218 .41607 Mdot
.67212 .41404 Mdot
.55276 .54427 Mdot
.51111 .59229 Mdot
.48612 .60259 Mdot
.44032 .58973 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47783 .60863 Mdot
.42946 .58814 Mdot
.27872 .52487 Mdot
.89313 .37972 Mdot
.65606 .47152 Mdot
.61734 .5941 Mdot
.7391 .07526 Mdot
.09904 .22245 Mdot
.31982 .13645 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.52299 .00975 Mdot
.57314 .03099 Mdot
.72919 .09644 Mdot
.12193 .24273 Mdot
.34915 .14043 Mdot
.38248 .0206 Mdot
.25512 .53932 Mdot
.88915 .39185 Mdot
.67633 .48651 Mdot
.49918 .61769 Mdot
.49739 .61693 Mdot
.4917 .61451 Mdot
.47355 .60682 Mdot
.41591 .58241 Mdot
.23792 .50803 Mdot
.82189 .36091 Mdot
.62064 .49366 Mdot
.58353 .59509 Mdot
.66603 .05099 Mdot
.9548 .17847 Mdot
.49921 .6177 Mdot
.49747 .61696 Mdot
.49195 .61462 Mdot
.47437 .60717 Mdot
.4185 .58351 Mdot
.24566 .51121 Mdot
.83417 .36372 Mdot
.6288 .49111 Mdot
.59622 .5979 Mdot
.69935 .06373 Mdot
.02921 .20387 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.5068 .00288 Mdot
.52165 .00918 Mdot
.56887 .02919 Mdot
.71622 .09106 Mdot
.09693 .2353 Mdot
.34107 .15089 Mdot
.38451 .02685 Mdot
.26953 .54697 Mdot
.91761 .40054 Mdot
.68383 .47355 Mdot
.49985 .61797 Mdot
.49953 .61783 Mdot
.4985 .6174 Mdot
.49521 .616 Mdot
.48473 .61156 Mdot
.45138 .59742 Mdot
.34623 .55305 Mdot
.04466 .43166 Mdot
.67698 .39079 Mdot
.52334 .52308 Mdot
.4046 .54465 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .0024 Mdot
.51806 .00766 Mdot
.55748 .02436 Mdot
.68126 .0765 Mdot
.02184 .21049 Mdot
.32977 .19031 Mdot
.42832 .06091 Mdot
.42296 .61472 Mdot
.30648 .54605 Mdot
.96616 .4077 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50793 .00336 Mdot
.52525 .01071 Mdot
.5803 .03402 Mdot
.75075 .10535 Mdot
.15993 .25289 Mdot
.3676 .12834 Mdot
.39879 .01928 Mdot
.28821 .54969 Mdot
.94573 .40637 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48403 .61126 Mdot
.44917 .59649 Mdot
.33936 .55017 Mdot
.02746 .42527 Mdot
.67458 .39994 Mdot
.53411 .53122 Mdot
.44443 .5626 Mdot
.27306 .51213 Mdot
.86547 .36613 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .6112 Mdot
.44866 .59627 Mdot
.33778 .5495 Mdot
.02355 .42383 Mdot
.67413 .40208 Mdot
.53682 .53317 Mdot
.45426 .56701 Mdot
.30403 .52519 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50719 .00305 Mdot
.5229 .00971 Mdot
.57285 .03087 Mdot
.72829 .09607 Mdot
.12025 .24224 Mdot
.34851 .14107 Mdot
.38233 .0209 Mdot
.25529 .53952 Mdot
.88965 .39206 Mdot
.67659 .48635 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50497 .00211 Mdot
.51583 .00671 Mdot
.5504 .02137 Mdot
.65932 .06732 Mdot
.96926 .19155 Mdot
.32502 .21987 Mdot
.46809 .08842 Mdot
.5636 .05903 Mdot
.75199 .11643 Mdot
.1791 .26397 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49146 .61441 Mdot
.47281 .6065 Mdot
.41357 .58142 Mdot
.23096 .50518 Mdot
.81132 .35869 Mdot
.61292 .49541 Mdot
.57003 .59153 Mdot
.62883 .03634 Mdot
.50014 6e-05 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.50441 .00187 Mdot
.51405 .00596 Mdot
.54474 .01897 Mdot
.64167 .05991 Mdot
.92414 .17457 Mdot
.31614 .24227 Mdot
.48972 .10728 Mdot
.64788 .09775 Mdot
.9973 .21595 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50508 .00215 Mdot
.51619 .00686 Mdot
.55154 .02185 Mdot
.66285 .0688 Mdot
.978 .19477 Mdot
.32604 .2151 Mdot
.46208 .08408 Mdot
.54179 .04926 Mdot
.68347 .08756 Mdot
.04332 .2224 Mdot
.49995 .61801 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.485 .61167 Mdot
.45224 .59779 Mdot
.3489 .55417 Mdot
.05146 .4342 Mdot
.67817 .38733 Mdot
.5197 .5201 Mdot
.49785 .61712 Mdot
.49314 .61513 Mdot
.47816 .60877 Mdot
.43052 .58859 Mdot
.28193 .5262 Mdot
.8994 .38162 Mdot
.65792 .46879 Mdot
.61632 .59232 Mdot
.73407 .07278 Mdot
.08936 .21958 Mdot
.31754 .14102 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48791 .61291 Mdot
.46148 .6017 Mdot
.37785 .56634 Mdot
.12845 .4639 Mdot
.70662 .35733 Mdot
.51472 .49943 Mdot
.34486 .51306 Mdot
.97743 .39095 Mdot
.64374 .4118 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.50301 .00128 Mdot
.50958 .00406 Mdot
.53052 .01294 Mdot
.59697 .04107 Mdot
.80003 .1255 Mdot
.23013 .26581 Mdot
.42335 .11942 Mdot
.506 .05108 Mdot
.59765 .05664 Mdot
.82675 .14159 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50787 .00334 Mdot
.52508 .01063 Mdot
.57974 .03378 Mdot
.74907 .10465 Mdot
.15714 .2522 Mdot
.36596 .12906 Mdot
.39667 .01898 Mdot
.28306 .54782 Mdot
.93584 .40344 Mdot
.68228 .46132 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50438 .00186 Mdot
.51397 .00592 Mdot
.54447 .01885 Mdot
.64081 .05954 Mdot
.92187 .17371 Mdot
.31547 .24326 Mdot
.49026 .10803 Mdot
.65046 .09901 Mdot
.00419 .21862 Mdot
.35164 .21473 Mdot
.50041 .00017 Mdot
.50131 .00055 Mdot
.50417 .00177 Mdot
.51328 .00563 Mdot
.54228 .01792 Mdot
.63396 .05666 Mdot
.90368 .1667 Mdot
.30922 .25064 Mdot
.49237 .11319 Mdot
.66406 .10612 Mdot
.04053 .23267 Mdot
.35686 .1955 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50344 .00146 Mdot
.51096 .00465 Mdot
.53492 .0148 Mdot
.61082 .04691 Mdot
.83985 .14155 Mdot
.27057 .2662 Mdot
.46454 .11988 Mdot
.60578 .08729 Mdot
.89425 .17828 Mdot
.32993 .26927 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51543 .00654 Mdot
.54913 .02083 Mdot
.65535 .06565 Mdot
.95932 .18786 Mdot
.32365 .22517 Mdot
.47435 .09314 Mdot
.58674 .06946 Mdot
.82291 .14596 Mdot
.27319 .27829 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50947 .00402 Mdot
.53017 .01279 Mdot
.59586 .0406 Mdot
.7968 .12419 Mdot
.22623 .2654 Mdot
.41958 .1195 Mdot
.49737 .04808 Mdot
.57121 .04564 Mdot
.74834 .10947 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00226 Mdot
.51695 .00719 Mdot
.55395 .02287 Mdot
.67033 .07193 Mdot
.99615 .20137 Mdot
.32775 .20494 Mdot
.44853 .07465 Mdot
.49346 .02776 Mdot
.52857 .0217 Mdot
.6063 .04804 Mdot
.49927 .61772 Mdot
.49768 .61705 Mdot
.4926 .61489 Mdot
.47642 .60803 Mdot
.42499 .58625 Mdot
.26518 .51926 Mdot
.86772 .37239 Mdot
.64661 .48138 Mdot
.61561 .59887 Mdot
.74317 .07884 Mdot
.10924 .22624 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48983 .61372 Mdot
.46761 .6043 Mdot
.39715 .57449 Mdot
.18293 .48564 Mdot
.75087 .351 Mdot
.55753 .49854 Mdot
.44862 .55072 Mdot
.26396 .50391 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50455 .00193 Mdot
.51449 .00614 Mdot
.54614 .01956 Mdot
.64602 .06173 Mdot
.93548 .17889 Mdot
.31909 .23708 Mdot
.48611 .10322 Mdot
.63232 .09036 Mdot
.95491 .19938 Mdot
.34424 .24062 Mdot
.49919 .61769 Mdot
.49742 .61694 Mdot
.49178 .61455 Mdot
.47383 .60694 Mdot
.41679 .58278 Mdot
.24054 .50911 Mdot
.82598 .36182 Mdot
.62346 .49287 Mdot
.58811 .59619 Mdot
.67828 .05573 Mdot
.98335 .18854 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51224 .00519 Mdot
.53899 .01653 Mdot
.62363 .05231 Mdot
.87564 .15575 Mdot
.29577 .25966 Mdot
.48698 .11817 Mdot
.65867 .10611 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51555 .00659 Mdot
.54951 .02099 Mdot
.65653 .06614 Mdot
.96228 .18896 Mdot
.32408 .22361 Mdot
.47256 .09176 Mdot
.58007 .06645 Mdot
.80269 .13758 Mdot
.25107 .27712 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50379 .00161 Mdot
.51207 .00512 Mdot
.53843 .01629 Mdot
.62188 .05158 Mdot
.87081 .15384 Mdot
.29293 .26089 Mdot
.48495 .11868 Mdot
.65443 .10474 Mdot
.02087 .22647 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52351 .00997 Mdot
.57478 .03169 Mdot
.73413 .09849 Mdot
.13103 .2453 Mdot
.35285 .13709 Mdot
.38407 .01929 Mdot
.25636 .53911 Mdot
.89011 .39168 Mdot
.67591 .48565 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50497 .00211 Mdot
.51583 .00671 Mdot
.55041 .02137 Mdot
.65934 .06732 Mdot
.96932 .19157 Mdot
.32503 .21984 Mdot
.46805 .08839 Mdot
.56347 .05897 Mdot
.75159 .11627 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52638 .01119 Mdot
.58387 .03553 Mdot
.76142 .10973 Mdot
.17709 .2569 Mdot
.37864 .12457 Mdot
.4153 .02265 Mdot
.3308 .56582 Mdot
.03769 .43688 Mdot
.68857 .40226 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.4798 .60947 Mdot
.43572 .59079 Mdot
.29783 .53281 Mdot
.93189 .39188 Mdot
.66503 .4531 Mdot
.60368 .58012 Mdot
.68709 .05155 Mdot
.99081 .18771 Mdot
.30831 .19623 Mdot
.49925 .61772 Mdot
.49763 .61703 Mdot
.49243 .61483 Mdot
.4759 .60781 Mdot
.42335 .58556 Mdot
.26022 .51722 Mdot
.85886 .36998 Mdot
.64252 .48433 Mdot
.61253 .5995 Mdot
.73761 .0773 Mdot
.1007 .2244 Mdot
.50048 .0002 Mdot
.50152 .00065 Mdot
.50485 .00206 Mdot
.51545 .00655 Mdot
.54918 .02085 Mdot
.65552 .06572 Mdot
.95975 .18802 Mdot
.32371 .22494 Mdot
.47409 .09294 Mdot
.58577 .06902 Mdot
.81998 .14475 Mdot
.27021 .27826 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00248 Mdot
.51867 .00792 Mdot
.55941 .02518 Mdot
.68722 .07899 Mdot
.03543 .2152 Mdot
.33093 .18263 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47498 .60742 Mdot
.42043 .58432 Mdot
.25143 .51359 Mdot
.84371 .36605 Mdot
.63452 .48875 Mdot
.60393 .59913 Mdot
.7184 .07074 Mdot
.06691 .21539 Mdot
.31798 .15517 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47786 .60865 Mdot
.42958 .58819 Mdot
.27907 .52502 Mdot
.8938 .37993 Mdot
.65627 .47123 Mdot
.61725 .59392 Mdot
.73864 .07502 Mdot
.09814 .22219 Mdot
.31959 .13686 Mdot
.49795 .61716 Mdot
.49347 .61527 Mdot
.4792 .60921 Mdot
.43382 .58999 Mdot
.29199 .53038 Mdot
.9197 .38794 Mdot
.66281 .45927 Mdot
.60972 .58522 Mdot
.70847 .06103 Mdot
.03788 .20359 Mdot
.311 .1688 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51796 .00761 Mdot
.55715 .02422 Mdot
.68024 .07607 Mdot
.0195 .20967 Mdot
.32958 .19164 Mdot
.43016 .06216 Mdot
.4293 .6175 Mdot
.49879 .61752 Mdot
.49613 .61639 Mdot
.48768 .61281 Mdot
.46075 .60139 Mdot
.37554 .56537 Mdot
.1221 .4614 Mdot
.70296 .35899 Mdot
.51219 .50013 Mdot
.33967 .51142 Mdot
.96534 .38668 Mdot
.64258 .41856 Mdot
.49914 .61767 Mdot
.49725 .61687 Mdot
.49125 .61432 Mdot
.47213 .60622 Mdot
.41143 .58052 Mdot
.22461 .50258 Mdot
.8021 .35691 Mdot
.60564 .49662 Mdot
.55625 .58751 Mdot
.58951 .02055 Mdot
.75006 .09922 Mdot
.4995 .61782 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48376 .61115 Mdot
.4483 .59612 Mdot
.33666 .54903 Mdot
.02081 .42283 Mdot
.67383 .40359 Mdot
.53877 .53456 Mdot
.46128 .57014 Mdot
.32628 .5346 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54142 .01756 Mdot
.63126 .05552 Mdot
.89641 .16387 Mdot
.30621 .25327 Mdot
.492 .11483 Mdot
.66581 .10742 Mdot
.04573 .2348 Mdot
.35799 .19299 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00207 Mdot
.51552 .00658 Mdot
.54941 .02095 Mdot
.65623 .06602 Mdot
.96153 .18869 Mdot
.32398 .224 Mdot
.47302 .09211 Mdot
.58178 .06722 Mdot
.80787 .13974 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00131 Mdot
.50987 .00419 Mdot
.53144 .01333 Mdot
.59986 .04229 Mdot
.80844 .12891 Mdot
.23983 .26662 Mdot
.43298 .11937 Mdot
.52855 .05906 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47564 .60771 Mdot
.42253 .58521 Mdot
.25776 .5162 Mdot
.85453 .36883 Mdot
.64037 .48568 Mdot
.61052 .59958 Mdot
.73343 .07596 Mdot
.09378 .22271 Mdot
.32146 .14072 Mdot
.49897 .6176 Mdot
.49671 .61664 Mdot
.48953 .61359 Mdot
.46665 .60389 Mdot
.39411 .5732 Mdot
.17419 .48212 Mdot
.74212 .351 Mdot
.54848 .49836 Mdot
.42645 .54261 Mdot
.19798 .47683 Mdot
.74342 .3371 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51705 .00723 Mdot
.55427 .023 Mdot
.67133 .07235 Mdot
.99854 .20223 Mdot
.32794 .20358 Mdot
.44667 .07338 Mdot
.4869 .02486 Mdot
.5075 .01273 Mdot
.53936 .01969 Mdot
.49828 .6173 Mdot
.49451 .61571 Mdot
.48252 .61062 Mdot
.44436 .59445 Mdot
.32444 .54392 Mdot
.99142 .41222 Mdot
.67127 .42017 Mdot
.56122 .55002 Mdot
.54077 .60539 Mdot
.5808 .02474 Mdot
.7369 .09647 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.5035 .00149 Mdot
.51116 .00473 Mdot
.53556 .01508 Mdot
.61284 .04776 Mdot
.84556 .14383 Mdot
.27525 .26557 Mdot
.46922 .11988 Mdot
.61729 .09152 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50658 .00279 Mdot
.52095 .00888 Mdot
.56665 .02824 Mdot
.70942 .08824 Mdot
.08322 .23102 Mdot
.33779 .15734 Mdot
.38905 .03168 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.48659 .61235 Mdot
.45731 .59994 Mdot
.36475 .56083 Mdot
.09288 .45001 Mdot
.68946 .36871 Mdot
.50771 .50571 Mdot
.33752 .51285 Mdot
.96378 .38705 Mdot
.64391 .42034 Mdot
.49859 .61744 Mdot
.4955 .61613 Mdot
.48568 .61196 Mdot
.45439 .5987 Mdot
.35562 .55699 Mdot
.06878 .44076 Mdot
.68195 .37896 Mdot
.51237 .51323 Mdot
.36133 .52469 Mdot
.02763 .41179 Mdot
.65269 .38631 Mdot
.5007 .0003 Mdot
.50225 .00095 Mdot
.50716 .00303 Mdot
.5228 .00967 Mdot
.57251 .03073 Mdot
.72727 .09565 Mdot
.11833 .24169 Mdot
.3478 .14182 Mdot
.38222 .02127 Mdot
.25564 .53981 Mdot
.89049 .39236 Mdot
.67694 .48606 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00126 Mdot
.50944 .00401 Mdot
.53008 .01276 Mdot
.59558 .04048 Mdot
.79598 .12386 Mdot
.22522 .26529 Mdot
.41862 .11952 Mdot
.49519 .04733 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48013 .60961 Mdot
.43677 .59123 Mdot
.30103 .53414 Mdot
.93872 .39412 Mdot
.66608 .44953 Mdot
.59975 .57704 Mdot
.67343 .04554 Mdot
.95874 .17633 Mdot
.30525 .21416 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50625 .00265 Mdot
.51991 .00844 Mdot
.56335 .02685 Mdot
.69932 .08404 Mdot
.06202 .22416 Mdot
.33403 .16811 Mdot
.39981 .04065 Mdot
.32503 .57182 Mdot
.03757 .44037 Mdot
.69427 .40586 Mdot
.4981 .61723 Mdot
.49394 .61546 Mdot
.48068 .60984 Mdot
.43852 .59198 Mdot
.30643 .53639 Mdot
.95045 .39803 Mdot
.6676 .44322 Mdot
.5922 .57143 Mdot
.64748 .03417 Mdot
.89366 .15215 Mdot
.28774 .24356 Mdot
.49745 .61695 Mdot
.49186 .61458 Mdot
.47409 .60705 Mdot
.41761 .58313 Mdot
.24298 .51011 Mdot
.82986 .36271 Mdot
.62604 .49207 Mdot
.59213 .59708 Mdot
.68882 .05976 Mdot
.00682 .19654 Mdot
.31459 .19022 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.47849 .60891 Mdot
.43156 .58903 Mdot
.28511 .52752 Mdot
.90571 .38355 Mdot
.65962 .46594 Mdot
.61478 .59032 Mdot
.72758 .06971 Mdot
.07674 .2158 Mdot
.3152 .14738 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50483 .00205 Mdot
.51538 .00652 Mdot
.54896 .02076 Mdot
.65484 .06544 Mdot
.95803 .18738 Mdot
.32345 .22584 Mdot
.47511 .09373 Mdot
.58958 .07075 Mdot
.83145 .14948 Mdot
.28146 .27812 Mdot
.49752 .61698 Mdot
.4921 .61468 Mdot
.47482 .60736 Mdot
.41993 .58411 Mdot
.24994 .51297 Mdot
.84122 .36543 Mdot
.63308 .4894 Mdot
.6021 .59889 Mdot
.71398 .06914 Mdot
.0585 .21293 Mdot
.31723 .15991 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49675 .61666 Mdot
.48965 .61364 Mdot
.46703 .60406 Mdot
.39531 .57371 Mdot
.17764 .48351 Mdot
.74549 .35095 Mdot
.55198 .49844 Mdot
.43505 .54577 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51748 .00741 Mdot
.55564 .02358 Mdot
.67556 .07412 Mdot
.00858 .20582 Mdot
.32873 .19787 Mdot
.43878 .06801 Mdot
.45924 .01265 Mdot
.41924 .59331 Mdot
.26323 .52161 Mdot
.49975 .61793 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.4919 .6146 Mdot
.47421 .6071 Mdot
.41801 .5833 Mdot
.24418 .5106 Mdot
.83178 .36316 Mdot
.62729 .49165 Mdot
.59401 .59747 Mdot
.69368 .0616 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50207 .00088 Mdot
.50658 .00279 Mdot
.52097 .00889 Mdot
.56671 .02827 Mdot
.7096 .08832 Mdot
.08359 .23113 Mdot
.33787 .15716 Mdot
.3889 .03154 Mdot
.28649 .55474 Mdot
.95159 .41105 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51264 .00536 Mdot
.54026 .01707 Mdot
.62763 .054 Mdot
.88657 .16003 Mdot
.30161 .25651 Mdot
.49037 .11666 Mdot
.66469 .10773 Mdot
.04425 .23459 Mdot
.35829 .19409 Mdot
.49861 .61745 Mdot
.49559 .61616 Mdot
.48594 .61207 Mdot
.45523 .59906 Mdot
.35825 .5581 Mdot
.07567 .44339 Mdot
.68381 .37585 Mdot
.51033 .51082 Mdot
.35234 .52039 Mdot
.00329 .40231 Mdot
.64931 .39926 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52315 .00982 Mdot
.57364 .0312 Mdot
.7307 .09707 Mdot
.12473 .24353 Mdot
.35024 .13937 Mdot
.38282 .02014 Mdot
.2551 .53909 Mdot
.88876 .39163 Mdot
.67603 .48656 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50428 .00181 Mdot
.51362 .00578 Mdot
.54337 .01839 Mdot
.63738 .0581 Mdot
.91281 .17022 Mdot
.31258 .24707 Mdot
.49183 .11079 Mdot
.65884 .10322 Mdot
.02648 .22721 Mdot
.49965 .61789 Mdot
.49888 .61756 Mdot
.49644 .61653 Mdot
.48867 .61323 Mdot
.46392 .60274 Mdot
.38553 .56958 Mdot
.14984 .47237 Mdot
.72116 .35309 Mdot
.5273 .49822 Mdot
.37419 .52341 Mdot
.05141 .41855 Mdot
.49956 .61785 Mdot
.49861 .61744 Mdot
.49556 .61615 Mdot
.48585 .61203 Mdot
.45495 .59894 Mdot
.35737 .55773 Mdot
.07336 .4425 Mdot
.68316 .37688 Mdot
.51096 .5116 Mdot
.35517 .52175 Mdot
.01091 .40527 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50438 .00186 Mdot
.51397 .00592 Mdot
.54447 .01885 Mdot
.64082 .05955 Mdot
.92191 .17372 Mdot
.31548 .24325 Mdot
.49026 .10801 Mdot
.65042 .09899 Mdot
.0041 .21858 Mdot
.35163 .21479 Mdot
.49769 .61705 Mdot
.49263 .61491 Mdot
.47651 .60807 Mdot
.42529 .58638 Mdot
.26607 .51963 Mdot
.86933 .37284 Mdot
.64731 .48082 Mdot
.61602 .5987 Mdot
.74376 .07895 Mdot
.11005 .22638 Mdot
.32411 .1323 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52246 .00952 Mdot
.57146 .03028 Mdot
.72407 .09432 Mdot
.11226 .23991 Mdot
.34568 .14426 Mdot
.38222 .02258 Mdot
.25777 .54112 Mdot
.89487 .39375 Mdot
.67845 .48428 Mdot
.49826 .61729 Mdot
.49444 .61568 Mdot
.4823 .61053 Mdot
.44366 .59415 Mdot
.32225 .543 Mdot
.98629 .4104 Mdot
.67087 .42309 Mdot
.56528 .55277 Mdot
.55488 .61161 Mdot
.62517 .04344 Mdot
.86446 .14789 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51648 .00699 Mdot
.55247 .02224 Mdot
.66575 .07001 Mdot
.98508 .19736 Mdot
.32676 .21117 Mdot
.45694 .08046 Mdot
.52332 .04103 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48038 .60971 Mdot
.43756 .59157 Mdot
.30346 .53516 Mdot
.94397 .39586 Mdot
.6668 .44673 Mdot
.59648 .57457 Mdot
.66216 .0406 Mdot
.93114 .16624 Mdot
.30021 .2281 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48365 .6111 Mdot
.44794 .59596 Mdot
.33552 .54856 Mdot
.01801 .4218 Mdot
.67354 .40514 Mdot
.54079 .53599 Mdot
.46856 .57339 Mdot
.34948 .54444 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.47551 .60765 Mdot
.4221 .58503 Mdot
.25647 .51567 Mdot
.8523 .36824 Mdot
.63922 .48634 Mdot
.60934 .59957 Mdot
.73087 .07511 Mdot
.08941 .22159 Mdot
.32078 .143 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50263 .00112 Mdot
.50838 .00356 Mdot
.52671 .01132 Mdot
.5849 .03597 Mdot
.76449 .11099 Mdot
.18182 .25793 Mdot
.38199 .12371 Mdot
.42094 .02407 Mdot
.3461 .57178 Mdot
.07474 .45033 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50827 .00351 Mdot
.52636 .01118 Mdot
.5838 .0355 Mdot
.76122 .10965 Mdot
.17677 .25683 Mdot
.37842 .12463 Mdot
.41493 .02256 Mdot
.32983 .56544 Mdot
.0354 .43607 Mdot
.68831 .40352 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48126 .61009 Mdot
.44035 .59275 Mdot
.31206 .53874 Mdot
.96296 .40228 Mdot
.66892 .43631 Mdot
.58329 .56511 Mdot
.61697 .02082 Mdot
.81074 .11975 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52368 .01004 Mdot
.57532 .03191 Mdot
.73576 .09916 Mdot
.13399 .24612 Mdot
.35414 .13606 Mdot
.38488 .019 Mdot
.2576 .53937 Mdot
.89186 .39199 Mdot
.67613 .48471 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50617 .00262 Mdot
.51967 .00834 Mdot
.5626 .02653 Mdot
.69702 .08308 Mdot
.05707 .22252 Mdot
.33334 .17074 Mdot
.40286 .04297 Mdot
.33554 .57643 Mdot
.06315 .44969 Mdot
.6985 .39267 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50781 .00331 Mdot
.52488 .01055 Mdot
.57911 .03352 Mdot
.74717 .10387 Mdot
.15392 .25139 Mdot
.36414 .12992 Mdot
.39443 .01872 Mdot
.27773 .54591 Mdot
.92592 .4006 Mdot
.68126 .46682 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50684 .0029 Mdot
.5218 .00925 Mdot
.56937 .02939 Mdot
.71771 .09168 Mdot
.0999 .2362 Mdot
.34188 .14956 Mdot
.38383 .02592 Mdot
.26658 .54557 Mdot
.9119 .39883 Mdot
.68272 .47639 Mdot
.49798 .61718 Mdot
.49358 .61531 Mdot
.47954 .60936 Mdot
.43489 .59044 Mdot
.29528 .53175 Mdot
.92653 .39014 Mdot
.66411 .45585 Mdot
.60651 .58243 Mdot
.697 .05593 Mdot
.0131 .19536 Mdot
.30958 .18323 Mdot
.49956 .61785 Mdot
.4986 .61744 Mdot
.49554 .61614 Mdot
.48581 .61201 Mdot
.4548 .59887 Mdot
.35691 .55753 Mdot
.07216 .44205 Mdot
.68284 .37742 Mdot
.5113 .51202 Mdot
.35671 .52249 Mdot
.01507 .40689 Mdot
.49918 .61768 Mdot
.49737 .61692 Mdot
.49163 .61448 Mdot
.47334 .60673 Mdot
.41524 .58213 Mdot
.23594 .50722 Mdot
.81884 .36025 Mdot
.61848 .49421 Mdot
.57988 .59418 Mdot
.65613 .04712 Mdot
.93077 .16974 Mdot
.49828 .6173 Mdot
.49451 .6157 Mdot
.4825 .61061 Mdot
.44428 .59442 Mdot
.32419 .54381 Mdot
.99084 .41201 Mdot
.67122 .4205 Mdot
.56168 .55034 Mdot
.54237 .6061 Mdot
.58588 .02689 Mdot
.75204 .10269 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50636 .0027 Mdot
.52026 .00859 Mdot
.56448 .02733 Mdot
.70278 .08548 Mdot
.06938 .22657 Mdot
.33518 .16427 Mdot
.39562 .03736 Mdot
.31049 .56542 Mdot
.00365 .4284 Mdot
.69134 .42501 Mdot
.49991 .61799 Mdot
.4997 .61791 Mdot
.49906 .61763 Mdot
.497 .61676 Mdot
.49044 .61398 Mdot
.46954 .60512 Mdot
.40322 .57705 Mdot
.20052 .49276 Mdot
.77054 .35229 Mdot
.57729 .4986 Mdot
.49549 .56748 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.5044 .00187 Mdot
.51402 .00595 Mdot
.54465 .01893 Mdot
.64139 .05979 Mdot
.9234 .17429 Mdot
.31592 .24259 Mdot
.4899 .10753 Mdot
.64874 .09817 Mdot
.99961 .21685 Mdot
.35106 .21721 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50399 .00169 Mdot
.51272 .00539 Mdot
.5405 .01717 Mdot
.62838 .05431 Mdot
.88863 .16084 Mdot
.30263 .25586 Mdot
.49082 .11631 Mdot
.66526 .10781 Mdot
.04538 .23493 Mdot
.35835 .19342 Mdot
.49981 .61795 Mdot
.49938 .61777 Mdot
.49804 .6172 Mdot
.49374 .61538 Mdot
.48007 .60958 Mdot
.43657 .59115 Mdot
.30043 .53389 Mdot
.93743 .39369 Mdot
.66589 .45021 Mdot
.60052 .57763 Mdot
.67609 .04671 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51176 .00499 Mdot
.53745 .01588 Mdot
.6188 .05028 Mdot
.86226 .15047 Mdot
.28749 .2628 Mdot
.48057 .11933 Mdot
.64459 .10137 Mdot
.99686 .21772 Mdot
.35384 .22063 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50341 .00144 Mdot
.51085 .0046 Mdot
.53455 .01465 Mdot
.60968 .04643 Mdot
.83661 .14025 Mdot
.26779 .26648 Mdot
.46173 .11986 Mdot
.5988 .08472 Mdot
.87474 .17054 Mdot
.31977 .27504 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50531 .00225 Mdot
.51692 .00717 Mdot
.55386 .02283 Mdot
.67006 .07182 Mdot
.99552 .20114 Mdot
.32769 .2053 Mdot
.44902 .07498 Mdot
.49518 .02853 Mdot
.53411 .02406 Mdot
.62381 .05544 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48907 .6134 Mdot
.46519 .60327 Mdot
.38951 .57126 Mdot
.16109 .47686 Mdot
.73023 .35175 Mdot
.53626 .49816 Mdot
.39621 .53148 Mdot
.11129 .44194 Mdot
.67271 .34697 Mdot
.49837 .61734 Mdot
.49481 .61583 Mdot
.48347 .61102 Mdot
.44737 .59573 Mdot
.33376 .54782 Mdot
.01373 .42024 Mdot
.67313 .40753 Mdot
.54395 .5382 Mdot
.47985 .57842 Mdot
.38561 .55979 Mdot
.13417 .46264 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.51212 .00514 Mdot
.53859 .01636 Mdot
.62239 .05179 Mdot
.87219 .15439 Mdot
.29376 .26054 Mdot
.48556 .11854 Mdot
.65574 .10518 Mdot
.024 .22759 Mdot
.49955 .61784 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.4853 .6118 Mdot
.45319 .59819 Mdot
.35188 .55542 Mdot
.05911 .43709 Mdot
.6797 .38354 Mdot
.5161 .51693 Mdot
.37661 .53182 Mdot
.07002 .42855 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.4869 .61248 Mdot
.45828 .60035 Mdot
.36781 .56212 Mdot
.10107 .45318 Mdot
.69271 .36566 Mdot
.50779 .50374 Mdot
.33455 .51096 Mdot
.95547 .38375 Mdot
.64232 .4245 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50558 .00237 Mdot
.51779 .00754 Mdot
.55661 .024 Mdot
.67857 .07538 Mdot
.01563 .20831 Mdot
.32928 .19385 Mdot
.4332 .06423 Mdot
.43985 .00411 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.50411 .00174 Mdot
.51309 .00555 Mdot
.54168 .01767 Mdot
.63207 .05586 Mdot
.89859 .16472 Mdot
.30714 .2525 Mdot
.49219 .11436 Mdot
.66552 .10712 Mdot
.04473 .23436 Mdot
.4975 .61697 Mdot
.49203 .61465 Mdot
.4746 .60727 Mdot
.41925 .58382 Mdot
.2479 .51213 Mdot
.83783 .3646 Mdot
.63106 .49024 Mdot
.5994 .59847 Mdot
.70734 .06671 Mdot
.04548 .20898 Mdot
.31633 .16739 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48988 .61374 Mdot
.46778 .60437 Mdot
.39767 .57471 Mdot
.18444 .48625 Mdot
.75244 .35104 Mdot
.55915 .49857 Mdot
.45254 .55215 Mdot
.27581 .50881 Mdot
.86347 .3632 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00116 Mdot
.50875 .00371 Mdot
.52787 .01182 Mdot
.58857 .03752 Mdot
.77538 .11545 Mdot
.19789 .26113 Mdot
.39435 .12142 Mdot
.44373 .03051 Mdot
.41043 .59746 Mdot
.24978 .51874 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.5059 .0025 Mdot
.51878 .00797 Mdot
.55978 .02534 Mdot
.68836 .07947 Mdot
.038 .21609 Mdot
.33117 .18119 Mdot
.416 .05243 Mdot
.3806 .59616 Mdot
.18244 .49556 Mdot
.49798 .61718 Mdot
.49355 .6153 Mdot
.47946 .60933 Mdot
.43466 .59034 Mdot
.29457 .53145 Mdot
.92504 .38965 Mdot
.66384 .45661 Mdot
.60724 .58305 Mdot
.69961 .05709 Mdot
.01885 .1973 Mdot
.30988 .17987 Mdot
.49839 .61735 Mdot
.49488 .61586 Mdot
.48368 .61111 Mdot
.44805 .59601 Mdot
.33586 .5487 Mdot
.01885 .42211 Mdot
.67363 .40468 Mdot
.54018 .53556 Mdot
.46636 .57241 Mdot
.34247 .54146 Mdot
.019 .41812 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48653 .61232 Mdot
.45712 .59986 Mdot
.36417 .56059 Mdot
.09132 .4494 Mdot
.68888 .36932 Mdot
.50779 .50611 Mdot
.33839 .51334 Mdot
.96613 .38797 Mdot
.64429 .41913 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.4876 .61277 Mdot
.4605 .60129 Mdot
.37476 .56504 Mdot
.11996 .46056 Mdot
.70178 .35958 Mdot
.51146 .50041 Mdot
.3383 .51102 Mdot
.96223 .38561 Mdot
.64228 .42029 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52363 .01002 Mdot
.57517 .03185 Mdot
.7353 .09897 Mdot
.13316 .24589 Mdot
.35377 .13635 Mdot
.38463 .01907 Mdot
.25721 .53928 Mdot
.8913 .39189 Mdot
.67605 .48501 Mdot
.49902 .61762 Mdot
.49689 .61671 Mdot
.49008 .61383 Mdot
.46842 .60464 Mdot
.39968 .57555 Mdot
.19024 .48859 Mdot
.7587 .35133 Mdot
.56553 .49865 Mdot
.46791 .5577 Mdot
.32249 .52816 Mdot
.96268 .39566 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51414 .006 Mdot
.54504 .01909 Mdot
.6426 .06029 Mdot
.92655 .1755 Mdot
.31681 .24119 Mdot
.48907 .10646 Mdot
.64494 .09633 Mdot
.98939 .21288 Mdot
.34974 .22271 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.5078 .00331 Mdot
.52485 .01054 Mdot
.57903 .03348 Mdot
.74694 .10378 Mdot
.15354 .25129 Mdot
.36393 .13003 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48425 .61136 Mdot
.44986 .59678 Mdot
.34149 .55106 Mdot
.03275 .42723 Mdot
.67524 .39708 Mdot
.53059 .52864 Mdot
.43155 .55682 Mdot
.23297 .4953 Mdot
.79702 .3486 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.51872 .00794 Mdot
.55956 .02525 Mdot
.68769 .07918 Mdot
.03648 .21556 Mdot
.33103 .18204 Mdot
.41713 .05321 Mdot
.38446 .59784 Mdot
.1933 .49989 Mdot
.7784 .36161 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47572 .60774 Mdot
.42279 .58532 Mdot
.25852 .51651 Mdot
.85586 .36918 Mdot
.64105 .48527 Mdot
.61117 .59957 Mdot
.73482 .07642 Mdot
.09612 .22329 Mdot
.32184 .13951 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51606 .00681 Mdot
.55113 .02167 Mdot
.66158 .06826 Mdot
.97486 .19362 Mdot
.32569 .21683 Mdot
.46429 .08566 Mdot
.54977 .05283 Mdot
.7087 .09822 Mdot
.09836 .24083 Mdot
.49941 .61778 Mdot
.49812 .61723 Mdot
.494 .61549 Mdot
.48087 .60992 Mdot
.43913 .59224 Mdot
.30829 .53717 Mdot
.95456 .39941 Mdot
.66806 .44097 Mdot
.58936 .56939 Mdot
.63776 .02991 Mdot
.86794 .14226 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50298 .00126 Mdot
.50949 .00402 Mdot
.53022 .01281 Mdot
.59601 .04066 Mdot
.79723 .12436 Mdot
.22675 .26546 Mdot
.42008 .11948 Mdot
.49851 .04847 Mdot
.57469 .04709 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50594 .00252 Mdot
.51892 .00802 Mdot
.56021 .02552 Mdot
.68966 .08001 Mdot
.0409 .21708 Mdot
.33146 .17958 Mdot
.41388 .05094 Mdot
.37334 .59298 Mdot
.16223 .48756 Mdot
.74778 .36189 Mdot
.49858 .61743 Mdot
.49548 .61612 Mdot
.48559 .61192 Mdot
.45412 .59858 Mdot
.35477 .55663 Mdot
.06656 .43992 Mdot
.6814 .37999 Mdot
.51314 .51404 Mdot
.36456 .52621 Mdot
.03647 .41526 Mdot
.65415 .38175 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50793 .00336 Mdot
.52527 .01072 Mdot
.58037 .03405 Mdot
.75096 .10543 Mdot
.16027 .25297 Mdot
.3678 .12826 Mdot
.39906 .01932 Mdot
.28886 .54993 Mdot
.94701 .40676 Mdot
.68318 .45498 Mdot
.49896 .61759 Mdot
.49668 .61662 Mdot
.48941 .61354 Mdot
.46627 .60373 Mdot
.39291 .57269 Mdot
.17075 .48074 Mdot
.73886 .35111 Mdot
.54511 .49829 Mdot
.41811 .53955 Mdot
.17364 .46694 Mdot
.71738 .33605 Mdot
.49906 .61764 Mdot
.49702 .61677 Mdot
.4905 .614 Mdot
.46973 .6052 Mdot
.40384 .57731 Mdot
.20233 .49349 Mdot
.77271 .35252 Mdot
.5794 .49856 Mdot
.50031 .56915 Mdot
.42169 .56944 Mdot
.23029 .49974 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50815 .00346 Mdot
.52596 .01101 Mdot
.58255 .03497 Mdot
.75747 .10811 Mdot
.17086 .25549 Mdot
.37443 .12581 Mdot
.40859 .02111 Mdot
.31306 .55899 Mdot
.99729 .42288 Mdot
.50074 .00031 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52401 .01018 Mdot
.57635 .03235 Mdot
.73889 .10045 Mdot
.13957 .24764 Mdot
.35672 .13421 Mdot
.38682 .01861 Mdot
.26111 .54034 Mdot
.89725 .39316 Mdot
.67703 .48193 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00349 Mdot
.52619 .0111 Mdot
.58326 .03527 Mdot
.75961 .10899 Mdot
.17425 .25626 Mdot
.3767 .12512 Mdot
.41214 .0219 Mdot
.32238 .56256 Mdot
.01815 .43001 Mdot
.68676 .41322 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.50842 .00357 Mdot
.52682 .01137 Mdot
.58525 .03611 Mdot
.76553 .11142 Mdot
.18341 .25826 Mdot
.38315 .12344 Mdot
.42294 .02459 Mdot
.3516 .57395 Mdot
.08855 .45546 Mdot
.49759 .61701 Mdot
.49234 .61478 Mdot
.47559 .60768 Mdot
.42237 .58514 Mdot
.25726 .51599 Mdot
.85368 .3686 Mdot
.63993 .48593 Mdot
.61008 .59958 Mdot
.73248 .07565 Mdot
.09217 .2223 Mdot
.3212 .14155 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51788 .00758 Mdot
.55691 .02412 Mdot
.67949 .07576 Mdot
.01776 .20906 Mdot
.32944 .19263 Mdot
.43153 .06309 Mdot
.43404 .00155 Mdot
.34042 .56017 Mdot
.04556 .4358 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50497 .00211 Mdot
.51584 .00672 Mdot
.55044 .02138 Mdot
.65945 .06737 Mdot
.96957 .19167 Mdot
.32506 .21971 Mdot
.46788 .08827 Mdot
.56286 .0587 Mdot
.74968 .11546 Mdot
.17524 .26301 Mdot
.49953 .61783 Mdot
.4985 .6174 Mdot
.49522 .616 Mdot
.48476 .61157 Mdot
.45147 .59746 Mdot
.3465 .55316 Mdot
.04534 .43191 Mdot
.67709 .39044 Mdot
.52296 .52278 Mdot
.40315 .54399 Mdot
.14687 .45964 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51466 .00622 Mdot
.54667 .01978 Mdot
.64768 .06243 Mdot
.93976 .18052 Mdot
.32006 .23504 Mdot
.48439 .10156 Mdot
.62533 .08711 Mdot
.93542 .19165 Mdot
.33975 .24989 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.52091 .00887 Mdot
.56653 .0282 Mdot
.70907 .08809 Mdot
.08249 .23079 Mdot
.33764 .15769 Mdot
.38935 .03196 Mdot
.28814 .55548 Mdot
.95501 .41215 Mdot
.68847 .4533 Mdot
.49991 .618 Mdot
.49972 .61791 Mdot
.49909 .61765 Mdot
.49711 .61681 Mdot
.49079 .61413 Mdot
.47065 .60559 Mdot
.40673 .57853 Mdot
.21079 .49693 Mdot
.78332 .35384 Mdot
.58937 .49817 Mdot
.52255 .57673 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50774 .00328 Mdot
.52465 .01045 Mdot
.5784 .03322 Mdot
.74504 .10299 Mdot
.1503 .25046 Mdot
.36215 .13094 Mdot
.39214 .01853 Mdot
.27245 .54406 Mdot
.9164 .39798 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48775 .61284 Mdot
.46098 .60149 Mdot
.37627 .56568 Mdot
.12409 .46218 Mdot
.70407 .35845 Mdot
.51292 .49989 Mdot
.34112 .51186 Mdot
.96866 .38784 Mdot
.64291 .41671 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50314 .00133 Mdot
.50999 .00424 Mdot
.53183 .0135 Mdot
.60111 .04281 Mdot
.81204 .13037 Mdot
.2438 .26684 Mdot
.43701 .11941 Mdot
.53817 .06252 Mdot
.69605 .09757 Mdot
.07907 .23672 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50704 .00299 Mdot
.52244 .00952 Mdot
.57139 .03025 Mdot
.72387 .09424 Mdot
.11186 .2398 Mdot
.34554 .14442 Mdot
.38223 .02268 Mdot
.25796 .54123 Mdot
.89525 .39387 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51705 .00723 Mdot
.55429 .02301 Mdot
.67138 .07237 Mdot
.99867 .20227 Mdot
.32795 .20351 Mdot
.44657 .07331 Mdot
.48655 .02471 Mdot
.50637 .01225 Mdot
.49984 .61797 Mdot
.49948 .61782 Mdot
.49835 .61734 Mdot
.49476 .61581 Mdot
.4833 .61095 Mdot
.44684 .5955 Mdot
.33212 .54713 Mdot
.00974 .41879 Mdot
.67276 .40977 Mdot
.54695 .54028 Mdot
.49054 .58317 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48933 .61351 Mdot
.46601 .60362 Mdot
.3921 .57236 Mdot
.16847 .47982 Mdot
.73675 .35121 Mdot
.54293 .49825 Mdot
.41272 .53756 Mdot
.15807 .46065 Mdot
.70341 .33704 Mdot
.49777 .61709 Mdot
.49291 .61503 Mdot
.4774 .60845 Mdot
.42811 .58757 Mdot
.27462 .52317 Mdot
.88524 .37739 Mdot
.65347 .47479 Mdot
.61785 .59602 Mdot
.74329 .07753 Mdot
.10725 .22494 Mdot
.32224 .13287 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50411 .00174 Mdot
.5131 .00556 Mdot
.54172 .01769 Mdot
.63222 .05593 Mdot
.899 .16488 Mdot
.30732 .25235 Mdot
.49221 .11427 Mdot
.66544 .10706 Mdot
.04449 .23426 Mdot
.35767 .19356 Mdot
.49863 .61745 Mdot
.49564 .61618 Mdot
.4861 .61214 Mdot
.45573 .59927 Mdot
.35982 .55875 Mdot
.07978 .44496 Mdot
.68502 .37406 Mdot
.50938 .50948 Mdot
.34779 .51817 Mdot
.99113 .39761 Mdot
.64777 .40583 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49072 .6141 Mdot
.47044 .6055 Mdot
.40606 .57825 Mdot
.20882 .49613 Mdot
.78079 .3535 Mdot
.58704 .49829 Mdot
.51745 .57502 Mdot
.47396 .59116 Mdot
.3916 .56713 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51466 .00622 Mdot
.54667 .01978 Mdot
.64768 .06243 Mdot
.93978 .18052 Mdot
.32006 .23503 Mdot
.48438 .10155 Mdot
.6253 .0871 Mdot
.93536 .19162 Mdot
.33973 .24992 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49594 .61631 Mdot
.48705 .61254 Mdot
.45877 .60055 Mdot
.36933 .56276 Mdot
.10518 .45478 Mdot
.6945 .36422 Mdot
.50817 .50288 Mdot
.33409 .51045 Mdot
.95384 .38302 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.50462 .00196 Mdot
.51471 .00624 Mdot
.54682 .01985 Mdot
.64817 .06264 Mdot
.94103 .181 Mdot
.32033 .23442 Mdot
.48384 .10105 Mdot
.62315 .0861 Mdot
.9293 .18921 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49338 .61523 Mdot
.4789 .60909 Mdot
.43286 .58958 Mdot
.28907 .52917 Mdot
.91371 .38605 Mdot
.66153 .46218 Mdot
.61215 .58751 Mdot
.71741 .06505 Mdot
.05642 .20952 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51513 .00642 Mdot
.54818 .02042 Mdot
.6524 .06441 Mdot
.95184 .18507 Mdot
.32243 .22904 Mdot
.47858 .09651 Mdot
.60269 .07671 Mdot
.87038 .16544 Mdot
.31171 .27275 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51419 .00602 Mdot
.54517 .01915 Mdot
.64301 .06047 Mdot
.92763 .17591 Mdot
.31711 .24071 Mdot
.48876 .10609 Mdot
.64357 .09568 Mdot
.98568 .21144 Mdot
.34925 .2247 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52397 .01017 Mdot
.57624 .03231 Mdot
.73856 .10032 Mdot
.13899 .24748 Mdot
.35644 .13439 Mdot
.38659 .01864 Mdot
.26067 .54021 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.5069 .00293 Mdot
.52197 .00932 Mdot
.56991 .02962 Mdot
.71936 .09237 Mdot
.10314 .23719 Mdot
.34281 .14813 Mdot
.38321 .02497 Mdot
.26372 .54419 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50815 .00345 Mdot
.52595 .011 Mdot
.58251 .03496 Mdot
.75737 .10807 Mdot
.1707 .25545 Mdot
.37433 .12585 Mdot
.40843 .02108 Mdot
.31263 .55883 Mdot
.99635 .42256 Mdot
.68554 .42595 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.4923 .61477 Mdot
.47548 .60764 Mdot
.42202 .58499 Mdot
.25621 .51556 Mdot
.85186 .36813 Mdot
.63899 .48647 Mdot
.6091 .59956 Mdot
.73033 .07493 Mdot
.08848 .22135 Mdot
.50044 .00019 Mdot
.50142 .0006 Mdot
.50451 .00191 Mdot
.51437 .00609 Mdot
.54576 .0194 Mdot
.64486 .06125 Mdot
.93247 .17775 Mdot
.31836 .23849 Mdot
.4872 .10435 Mdot
.63687 .0925 Mdot
.96747 .20432 Mdot
.34652 .23427 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50249 .00105 Mdot
.50792 .00336 Mdot
.52523 .0107 Mdot
.58024 .03399 Mdot
.75057 .10527 Mdot
.15962 .25281 Mdot
.36742 .12842 Mdot
.39855 .01924 Mdot
.28761 .54947 Mdot
.94457 .40602 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50632 .00268 Mdot
.52013 .00854 Mdot
.56405 .02715 Mdot
.70147 .08493 Mdot
.06662 .22567 Mdot
.33473 .1657 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50353 .0015 Mdot
.51123 .00476 Mdot
.53577 .01517 Mdot
.61353 .04805 Mdot
.84749 .1446 Mdot
.27678 .26532 Mdot
.47071 .11986 Mdot
.62096 .09286 Mdot
.93569 .19451 Mdot
.34428 .25252 Mdot
.5 .61803 Mdot
.49999 .61803 Mdot
.49996 .61802 Mdot
.49986 .61798 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48601 .6121 Mdot
.45547 .59915 Mdot
.35899 .55841 Mdot
.0776 .44413 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00327 Mdot
.52459 .01043 Mdot
.5782 .03313 Mdot
.74446 .10275 Mdot
.1493 .25021 Mdot
.36162 .13122 Mdot
.39156 .0185 Mdot
.27113 .5436 Mdot
.91407 .39736 Mdot
.67973 .47321 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50622 .00264 Mdot
.51982 .0084 Mdot
.56306 .02673 Mdot
.69845 .08367 Mdot
.06016 .22355 Mdot
.33376 .16909 Mdot
.40094 .04152 Mdot
.32892 .57353 Mdot
.04693 .44376 Mdot
.69556 .40087 Mdot
.49795 .61717 Mdot
.49348 .61527 Mdot
.47921 .60922 Mdot
.43386 .59 Mdot
.29213 .53044 Mdot
.91998 .38803 Mdot
.66287 .45913 Mdot
.6096 .58511 Mdot
.70803 .06084 Mdot
.03695 .20328 Mdot
.31094 .16933 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.42031 .58427 Mdot
.25107 .51344 Mdot
.8431 .3659 Mdot
.63417 .48891 Mdot
.6035 .59908 Mdot
.71735 .07037 Mdot
.06493 .21482 Mdot
.3178 .15628 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00114 Mdot
.5086 .00365 Mdot
.52739 .01161 Mdot
.58705 .03688 Mdot
.77089 .11362 Mdot
.1914 .25989 Mdot
.38918 .12224 Mdot
.43384 .0276 Mdot
.3821 .58606 Mdot
.16924 .48648 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .0021 Mdot
.51575 .00668 Mdot
.55015 .02126 Mdot
.65853 .06698 Mdot
.9673 .19083 Mdot
.32477 .22093 Mdot
.46938 .08937 Mdot
.56833 .06116 Mdot
.76666 .12257 Mdot
.20242 .26931 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.47699 .60828 Mdot
.42681 .58702 Mdot
.27066 .52153 Mdot
.87779 .37523 Mdot
.65074 .47771 Mdot
.61749 .59748 Mdot
.7449 .07874 Mdot
.11092 .22621 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00206 Mdot
.5155 .00657 Mdot
.54936 .02093 Mdot
.65608 .06596 Mdot
.96116 .18855 Mdot
.32392 .2242 Mdot
.47324 .09228 Mdot
.5826 .06759 Mdot
.81038 .14078 Mdot
.25992 .27783 Mdot
.49913 .61767 Mdot
.49724 .61686 Mdot
.49121 .61431 Mdot
.472 .60616 Mdot
.41101 .58034 Mdot
.22338 .50207 Mdot
.80035 .35659 Mdot
.6042 .49681 Mdot
.55343 .58666 Mdot
.5813 .01723 Mdot
.7259 .08937 Mdot
.49748 .61697 Mdot
.49197 .61463 Mdot
.47443 .60719 Mdot
.4187 .58359 Mdot
.24625 .51146 Mdot
.83514 .36395 Mdot
.62941 .49088 Mdot
.5971 .59806 Mdot
.70156 .06456 Mdot
.03378 .20532 Mdot
.31571 .17424 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52351 .00997 Mdot
.57476 .03168 Mdot
.73409 .09847 Mdot
.13095 .24527 Mdot
.35281 .13712 Mdot
.38405 .0193 Mdot
.25633 .5391 Mdot
.89008 .39168 Mdot
.67591 .48567 Mdot
.49845 .61737 Mdot
.49505 .61593 Mdot
.48422 .61134 Mdot
.44977 .59674 Mdot
.34121 .55094 Mdot
.03205 .42697 Mdot
.67514 .39745 Mdot
.53105 .52898 Mdot
.43323 .55758 Mdot
.23816 .49748 Mdot
.80503 .35034 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.5245 .01039 Mdot
.57791 .03301 Mdot
.74357 .10239 Mdot
.14777 .24981 Mdot
.36082 .13167 Mdot
.3907 .01847 Mdot
.26922 .54295 Mdot
.91075 .39648 Mdot
.67924 .47496 Mdot
.49862 .61745 Mdot
.49559 .61617 Mdot
.48596 .61208 Mdot
.4553 .59909 Mdot
.35848 .55819 Mdot
.07625 .44361 Mdot
.68398 .37559 Mdot
.51018 .51062 Mdot
.35166 .52006 Mdot
.00147 .4016 Mdot
.64908 .40024 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48265 .61068 Mdot
.44479 .59463 Mdot
.32576 .54447 Mdot
.99453 .41332 Mdot
.67151 .4184 Mdot
.55877 .54836 Mdot
.53219 .60161 Mdot
.55358 .01322 Mdot
.65384 .06196 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50853 .00362 Mdot
.52716 .01152 Mdot
.58635 .03658 Mdot
.7688 .11276 Mdot
.18831 .25928 Mdot
.38681 .12268 Mdot
.42946 .02636 Mdot
.36975 .58113 Mdot
.13575 .47341 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.4862 .61218 Mdot
.45606 .59941 Mdot
.36085 .55919 Mdot
.0825 .44601 Mdot
.68587 .3729 Mdot
.50885 .50863 Mdot
.34511 .51684 Mdot
.98401 .39486 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48667 .61238 Mdot
.45757 .60005 Mdot
.36557 .56117 Mdot
.09505 .45085 Mdot
.69028 .36788 Mdot
.50764 .50516 Mdot
.33646 .51224 Mdot
.96093 .38594 Mdot
.64341 .4218 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00227 Mdot
.51702 .00722 Mdot
.55418 .02296 Mdot
.67104 .07222 Mdot
.99784 .20198 Mdot
.32789 .20398 Mdot
.44722 .07375 Mdot
.48881 .02571 Mdot
.51364 .01534 Mdot
.55889 .02797 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50654 .00277 Mdot
.52082 .00883 Mdot
.56625 .02808 Mdot
.7082 .08773 Mdot
.0807 .23022 Mdot
.33727 .15857 Mdot
.39011 .03266 Mdot
.2909 .55672 Mdot
.96079 .41402 Mdot
.68891 .45 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.51442 .00611 Mdot
.5459 .01946 Mdot
.64529 .06143 Mdot
.93358 .17817 Mdot
.31863 .23798 Mdot
.48681 .10394 Mdot
.63522 .09173 Mdot
.96294 .20254 Mdot
.34574 .23659 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51315 .00558 Mdot
.54187 .01775 Mdot
.63267 .05612 Mdot
.90021 .16535 Mdot
.30782 .25192 Mdot
.49228 .114 Mdot
.66517 .10685 Mdot
.04367 .23393 Mdot
.35749 .19395 Mdot
.49794 .61716 Mdot
.49345 .61525 Mdot
.47912 .60918 Mdot
.43357 .58988 Mdot
.29123 .53007 Mdot
.91813 .38745 Mdot
.66249 .46004 Mdot
.61039 .58584 Mdot
.71092 .06213 Mdot
.04302 .20525 Mdot
.31137 .16585 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.4942 .61557 Mdot
.48151 .61019 Mdot
.44116 .59309 Mdot
.31453 .53978 Mdot
.96853 .40419 Mdot
.66943 .43318 Mdot
.57911 .56222 Mdot
.60264 .01454 Mdot
.76969 .10324 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50518 .00219 Mdot
.51649 .00699 Mdot
.55249 .02225 Mdot
.66581 .07004 Mdot
.98523 .19741 Mdot
.32677 .21108 Mdot
.45682 .08037 Mdot
.5229 .04084 Mdot
.62321 .06199 Mdot
.89041 .16514 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52 .00848 Mdot
.56363 .02697 Mdot
.70018 .08439 Mdot
.06386 .22477 Mdot
.3343 .16714 Mdot
.39872 .03981 Mdot
.32127 .57017 Mdot
.02863 .43717 Mdot
.69327 .41078 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52657 .01127 Mdot
.58447 .03578 Mdot
.76322 .11047 Mdot
.17987 .25751 Mdot
.3806 .12406 Mdot
.41855 .02346 Mdot
.33959 .56923 Mdot
.05873 .44446 Mdot
.69176 .39123 Mdot
.49927 .61772 Mdot
.49768 .61705 Mdot
.49259 .61489 Mdot
.47641 .60803 Mdot
.42496 .58624 Mdot
.26509 .51922 Mdot
.86755 .37234 Mdot
.64654 .48144 Mdot
.61556 .59889 Mdot
.7431 .07882 Mdot
.10914 .22623 Mdot
.49815 .61725 Mdot
.49411 .61553 Mdot
.48123 .61007 Mdot
.44025 .59271 Mdot
.31173 .53861 Mdot
.96221 .40202 Mdot
.66885 .43672 Mdot
.58384 .5655 Mdot
.61887 .02165 Mdot
.81608 .12188 Mdot
.23174 .25689 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47758 .60853 Mdot
.42867 .58781 Mdot
.27633 .52388 Mdot
.88851 .37835 Mdot
.65458 .47346 Mdot
.61775 .59527 Mdot
.74186 .07671 Mdot
.10439 .22406 Mdot
.32133 .13407 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50713 .00302 Mdot
.52272 .00963 Mdot
.57226 .03062 Mdot
.72651 .09533 Mdot
.1169 .24127 Mdot
.34729 .14238 Mdot
.38217 .02156 Mdot
.25601 .54006 Mdot
.89128 .39262 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .00159 Mdot
.51197 .00508 Mdot
.53813 .01617 Mdot
.62093 .05118 Mdot
.86818 .15281 Mdot
.29131 .26151 Mdot
.48371 .11891 Mdot
.65171 .10383 Mdot
.01435 .22412 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51668 .00707 Mdot
.5531 .02251 Mdot
.66771 .07083 Mdot
.98984 .19909 Mdot
.3272 .2085 Mdot
.45337 .07798 Mdot
.51059 .03536 Mdot
.58368 .04517 Mdot
.77659 .11922 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47648 .60806 Mdot
.4252 .58634 Mdot
.26581 .51953 Mdot
.86887 .37271 Mdot
.64711 .48098 Mdot
.61591 .59875 Mdot
.7436 .07892 Mdot
.10984 .22635 Mdot
.32409 .13241 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50323 .00137 Mdot
.51029 .00436 Mdot
.53278 .0139 Mdot
.60408 .04407 Mdot
.82061 .13382 Mdot
.25276 .26708 Mdot
.44621 .11956 Mdot
.56051 .07064 Mdot
.7634 .12539 Mdot
.20418 .27242 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49287 .61501 Mdot
.47728 .6084 Mdot
.42773 .58741 Mdot
.27346 .52269 Mdot
.88304 .37674 Mdot
.6527 .47567 Mdot
.61783 .59649 Mdot
.74401 .07798 Mdot
.10875 .22542 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51885 .00799 Mdot
.55998 .02542 Mdot
.68897 .07972 Mdot
.03936 .21655 Mdot
.33131 .18043 Mdot
.415 .05173 Mdot
.37717 .59465 Mdot
.17285 .49176 Mdot
.7573 .36121 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.50539 .00229 Mdot
.51719 .00729 Mdot
.55471 .02319 Mdot
.67268 .07291 Mdot
.00176 .20338 Mdot
.3282 .20175 Mdot
.44416 .07166 Mdot
.47805 .02095 Mdot
.47914 .00067 Mdot
.44901 .59942 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50308 .00131 Mdot
.50982 .00417 Mdot
.53129 .01327 Mdot
.5994 .04209 Mdot
.80709 .12836 Mdot
.23832 .26652 Mdot
.43146 .11937 Mdot
.52494 .05777 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50346 .00147 Mdot
.51101 .00467 Mdot
.53506 .01487 Mdot
.61129 .04711 Mdot
.84118 .14208 Mdot
.27168 .26607 Mdot
.46567 .11989 Mdot
.60855 .08831 Mdot
.90192 .18131 Mdot
.33327 .26659 Mdot
.49966 .61789 Mdot
.4989 .61757 Mdot
.49651 .61655 Mdot
.48888 .61332 Mdot
.46459 .60302 Mdot
.38762 .57046 Mdot
.15575 .47473 Mdot
.72579 .35231 Mdot
.53182 .49815 Mdot
.38525 .52745 Mdot
.08108 .43005 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51225 .00519 Mdot
.539 .01653 Mdot
.62366 .05232 Mdot
.8757 .15577 Mdot
.29581 .25964 Mdot
.487 .11816 Mdot
.65872 .10613 Mdot
.03098 .23007 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50333 .00141 Mdot
.51062 .0045 Mdot
.53381 .01434 Mdot
.60735 .04545 Mdot
.82998 .13759 Mdot
.26182 .2669 Mdot
.4556 .11976 Mdot
.58363 .07913 Mdot
.8314 .15313 Mdot
.28736 .2818 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00715 Mdot
.55365 .02274 Mdot
.66942 .07154 Mdot
.99396 .20058 Mdot
.32756 .20618 Mdot
.45022 .07581 Mdot
.49944 .03041 Mdot
.5478 .02989 Mdot
.6668 .07354 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00117 Mdot
.50876 .00372 Mdot
.52791 .01184 Mdot
.58872 .03758 Mdot
.77582 .11563 Mdot
.19851 .26124 Mdot
.39486 .12135 Mdot
.44472 .03082 Mdot
.41331 .59862 Mdot
.25821 .52218 Mdot
.50054 .00023 Mdot
.50171 .00073 Mdot
.50545 .00231 Mdot
.51736 .00736 Mdot
.55527 .02343 Mdot
.67442 .07364 Mdot
.00589 .20486 Mdot
.32853 .1994 Mdot
.4409 .06945 Mdot
.46666 .01592 Mdot
.44278 .60328 Mdot
.33492 .55137 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50483 .00205 Mdot
.51539 .00652 Mdot
.54898 .02077 Mdot
.6549 .06546 Mdot
.9582 .18744 Mdot
.32347 .22575 Mdot
.47501 .09366 Mdot
.58922 .07059 Mdot
.83036 .14903 Mdot
.4996 .61787 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48722 .61262 Mdot
.45931 .60078 Mdot
.37104 .56348 Mdot
.1098 .45658 Mdot
.69662 .36268 Mdot
.50887 .502 Mdot
.33442 .51022 Mdot
.95405 .38295 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50595 .00252 Mdot
.51894 .00803 Mdot
.56028 .02555 Mdot
.68989 .0801 Mdot
.0414 .21725 Mdot
.33151 .1793 Mdot
.41352 .05068 Mdot
.3721 .59243 Mdot
.15882 .48622 Mdot
.74493 .36223 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52403 .01019 Mdot
.57643 .03238 Mdot
.73912 .10055 Mdot
.13998 .24775 Mdot
.35692 .13407 Mdot
.38699 .01859 Mdot
.26143 .54044 Mdot
.89776 .39327 Mdot
.67712 .48167 Mdot
.50015 6e-05 Mdot
.50048 .00021 Mdot
.50154 .00066 Mdot
.50492 .00209 Mdot
.51568 .00665 Mdot
.54992 .02116 Mdot
.65782 .06668 Mdot
.96551 .19016 Mdot
.32453 .22189 Mdot
.47053 .09023 Mdot
.57257 .06307 Mdot
.77973 .12803 Mdot
.49771 .61706 Mdot
.4927 .61494 Mdot
.47673 .60817 Mdot
.42599 .58667 Mdot
.26818 .5205 Mdot
.87319 .37392 Mdot
.64892 .47943 Mdot
.61684 .5982 Mdot
.74469 .07902 Mdot
.11114 .22648 Mdot
.3241 .13162 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51105 .00469 Mdot
.53519 .01492 Mdot
.61169 .04728 Mdot
.84231 .14253 Mdot
.27262 .26595 Mdot
.4666 .11989 Mdot
.61086 .08916 Mdot
.90828 .18382 Mdot
.33579 .26421 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51979 .00839 Mdot
.56297 .02669 Mdot
.69818 .08356 Mdot
.05956 .22335 Mdot
.33368 .16941 Mdot
.4013 .04179 Mdot
.33018 .57408 Mdot
.05 .44487 Mdot
.69604 .39928 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00326 Mdot
.52446 .01037 Mdot
.57777 .03295 Mdot
.74316 .10222 Mdot
.14706 .24962 Mdot
.36045 .13188 Mdot
.39031 .01846 Mdot
.26837 .54267 Mdot
.90928 .39611 Mdot
.67902 .47572 Mdot
.49996 .61802 Mdot
.49989 .61799 Mdot
.49964 .61788 Mdot
.49885 .61754 Mdot
.49633 .61648 Mdot
.48829 .61307 Mdot
.46271 .60223 Mdot
.38172 .56797 Mdot
.13918 .46814 Mdot
.71348 .35494 Mdot
.52026 .49862 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.5066 .0028 Mdot
.52103 .00892 Mdot
.56692 .02836 Mdot
.71027 .08859 Mdot
.08494 .23156 Mdot
.33817 .1565 Mdot
.38837 .03102 Mdot
.28451 .55385 Mdot
.94751 .40976 Mdot
.68783 .45754 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50522 .00222 Mdot
.51664 .00706 Mdot
.55298 .02246 Mdot
.66731 .07066 Mdot
.98888 .19874 Mdot
.32711 .20904 Mdot
.45409 .07848 Mdot
.51316 .03651 Mdot
.59195 .04869 Mdot
.80111 .12927 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.4875 .61273 Mdot
.46019 .60116 Mdot
.3738 .56464 Mdot
.11733 .45953 Mdot
.70038 .36034 Mdot
.51065 .50078 Mdot
.33688 .51064 Mdot
.95908 .38454 Mdot
.64198 .42206 Mdot
.49804 .6172 Mdot
.49375 .61539 Mdot
.4801 .6096 Mdot
.43668 .5912 Mdot
.30077 .53404 Mdot
.93818 .39394 Mdot
.666 .44982 Mdot
.60007 .57729 Mdot
.67454 .04603 Mdot
.96142 .1773 Mdot
.3056 .21271 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47552 .60766 Mdot
.42216 .58505 Mdot
.25663 .51573 Mdot
.85258 .36832 Mdot
.63937 .48626 Mdot
.60949 .59957 Mdot
.7312 .07522 Mdot
.08999 .22174 Mdot
.32087 .14269 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52612 .01107 Mdot
.58304 .03518 Mdot
.75895 .10872 Mdot
.17322 .25603 Mdot
.376 .12533 Mdot
.41103 .02165 Mdot
.31945 .56143 Mdot
.0115 .42771 Mdot
.68632 .41706 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.5132 .0056 Mdot
.54204 .01782 Mdot
.6332 .05634 Mdot
.90164 .1659 Mdot
.30841 .2514 Mdot
.49234 .11367 Mdot
.66477 .10657 Mdot
.04253 .23346 Mdot
.35725 .19451 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49576 .61624 Mdot
.48649 .61231 Mdot
.45699 .5998 Mdot
.36374 .56041 Mdot
.09017 .44896 Mdot
.68847 .36977 Mdot
.50788 .50642 Mdot
.33909 .51372 Mdot
.96801 .38869 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.51809 .00767 Mdot
.55757 .0244 Mdot
.68153 .07661 Mdot
.02247 .21071 Mdot
.32982 .18995 Mdot
.42783 .06058 Mdot
.42126 .61398 Mdot
.30135 .54392 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48602 .61211 Mdot
.45548 .59916 Mdot
.35904 .55843 Mdot
.07774 .44418 Mdot
.68441 .37494 Mdot
.50982 .51013 Mdot
.34997 .51924 Mdot
.99694 .39985 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47592 .60782 Mdot
.42342 .58559 Mdot
.26042 .5173 Mdot
.8592 .37007 Mdot
.64269 .48422 Mdot
.61267 .59948 Mdot
.7379 .07739 Mdot
.10117 .22451 Mdot
.3227 .13691 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51776 .00753 Mdot
.55652 .02396 Mdot
.67829 .07526 Mdot
.01498 .20808 Mdot
.32923 .19422 Mdot
.43372 .06458 Mdot
.44165 .0049 Mdot
.36398 .57004 Mdot
.50073 .00031 Mdot
.50232 .00099 Mdot
.5074 .00314 Mdot
.52358 .01 Mdot
.575 .03178 Mdot
.73479 .09876 Mdot
.13223 .24563 Mdot
.35337 .13667 Mdot
.38438 .01917 Mdot
.25681 .53919 Mdot
.89074 .39179 Mdot
.67598 .48531 Mdot
.50015 6e-05 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50492 .00209 Mdot
.51567 .00664 Mdot
.54987 .02114 Mdot
.65767 .06662 Mdot
.96515 .19003 Mdot
.32448 .22208 Mdot
.47076 .0904 Mdot
.57342 .06345 Mdot
.78235 .12912 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47722 .60837 Mdot
.42754 .58733 Mdot
.27288 .52245 Mdot
.88195 .37643 Mdot
.6523 .4761 Mdot
.6178 .59671 Mdot
.74429 .07818 Mdot
.49832 .61732 Mdot
.49464 .61576 Mdot
.48292 .61079 Mdot
.44562 .59498 Mdot
.32832 .54554 Mdot
.00062 .41551 Mdot
.67199 .41493 Mdot
.55398 .5451 Mdot
.51539 .59419 Mdot
.49986 .60844 Mdot
.48413 .60831 Mdot
.49783 .61711 Mdot
.49309 .6151 Mdot
.47798 .60869 Mdot
.42993 .58834 Mdot
.28015 .52546 Mdot
.89591 .38056 Mdot
.65691 .47032 Mdot
.61695 .59334 Mdot
.73705 .07423 Mdot
.0951 .22128 Mdot
.31883 .13828 Mdot
.50023 .0001 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52405 .0102 Mdot
.57649 .03241 Mdot
.73931 .10063 Mdot
.14032 .24784 Mdot
.35708 .13396 Mdot
.38713 .01857 Mdot
.26171 .54052 Mdot
.8982 .39337 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50612 .0026 Mdot
.5195 .00827 Mdot
.56206 .0263 Mdot
.69537 .08239 Mdot
.05348 .22133 Mdot
.33287 .17268 Mdot
.40518 .04469 Mdot
.34351 .57992 Mdot
.08314 .45712 Mdot
.70366 .3835 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.47952 .60935 Mdot
.43484 .59042 Mdot
.29512 .53168 Mdot
.92619 .39003 Mdot
.66405 .45602 Mdot
.60667 .58257 Mdot
.69759 .05619 Mdot
.01442 .19581 Mdot
.30965 .18246 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47959 .60938 Mdot
.43504 .5905 Mdot
.29574 .53194 Mdot
.9275 .39045 Mdot
.66429 .45536 Mdot
.60601 .58202 Mdot
.69526 .05516 Mdot
.00925 .19406 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51443 .00612 Mdot
.54594 .01947 Mdot
.6454 .06147 Mdot
.93386 .17828 Mdot
.3187 .23784 Mdot
.48671 .10383 Mdot
.63479 .09152 Mdot
.96175 .20207 Mdot
.34553 .23719 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.52171 .00921 Mdot
.56907 .02927 Mdot
.71681 .09131 Mdot
.09811 .23566 Mdot
.34139 .15036 Mdot
.38423 .02648 Mdot
.26833 .5464 Mdot
.91527 .39983 Mdot
.68339 .47472 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50655 .00278 Mdot
.52087 .00885 Mdot
.56639 .02814 Mdot
.70864 .08792 Mdot
.08162 .23051 Mdot
.33746 .15812 Mdot
.38972 .0323 Mdot
.28947 .55608 Mdot
.9578 .41305 Mdot
.49992 .618 Mdot
.49976 .61793 Mdot
.49922 .61771 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.4203 .58427 Mdot
.25105 .51343 Mdot
.84307 .36589 Mdot
.63415 .48892 Mdot
.60347 .59907 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00325 Mdot
.52445 .01037 Mdot
.57776 .03294 Mdot
.74311 .1022 Mdot
.14698 .2496 Mdot
.3604 .1319 Mdot
.39027 .01846 Mdot
.26827 .54264 Mdot
.90911 .39606 Mdot
.679 .47581 Mdot
.50023 .0001 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52403 .01019 Mdot
.57643 .03238 Mdot
.7391 .10054 Mdot
.13996 .24774 Mdot
.3569 .13408 Mdot
.38698 .01859 Mdot
.26141 .54043 Mdot
.89773 .39327 Mdot
.49998 .61802 Mdot
.49993 .618 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47734 .60843 Mdot
.42792 .58749 Mdot
.27404 .52293 Mdot
.88415 .37707 Mdot
.65309 .47523 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49056 .61403 Mdot
.46993 .60529 Mdot
.40447 .57758 Mdot
.20417 .49424 Mdot
.77497 .35277 Mdot
.58156 .4985 Mdot
.50522 .57085 Mdot
.43671 .57569 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.52499 .0106 Mdot
.57948 .03367 Mdot
.74829 .10433 Mdot
.15582 .25187 Mdot
.36521 .12941 Mdot
.39574 .01886 Mdot
.28081 .54701 Mdot
.93161 .40222 Mdot
.68187 .46368 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50659 .0028 Mdot
.52101 .00891 Mdot
.56684 .02833 Mdot
.71002 .08849 Mdot
.08444 .2314 Mdot
.33806 .15674 Mdot
.38856 .03121 Mdot
.28523 .55417 Mdot
.94899 .41023 Mdot
.68796 .45671 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42796 .58751 Mdot
.27417 .52298 Mdot
.88439 .37714 Mdot
.65317 .47513 Mdot
.61785 .59621 Mdot
.74359 .07771 Mdot
.10787 .22514 Mdot
.32245 .13262 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51803 .00764 Mdot
.55738 .02432 Mdot
.68095 .07637 Mdot
.02114 .21025 Mdot
.32971 .19071 Mdot
.42887 .06128 Mdot
.42485 .61555 Mdot
.31226 .54845 Mdot
.97896 .41205 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50272 .00115 Mdot
.50866 .00367 Mdot
.52759 .0117 Mdot
.58768 .03714 Mdot
.77275 .11438 Mdot
.19412 .26042 Mdot
.39132 .12188 Mdot
.43787 .02877 Mdot
.39357 .59066 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50578 .00245 Mdot
.51842 .00781 Mdot
.55864 .02486 Mdot
.68484 .078 Mdot
.03005 .21335 Mdot
.33045 .18566 Mdot
.42197 .05657 Mdot
.40109 .60513 Mdot
.24121 .51922 Mdot
.84295 .3719 Mdot
.49985 .61797 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49505 .61593 Mdot
.48423 .61135 Mdot
.44979 .59675 Mdot
.34127 .55097 Mdot
.03222 .42703 Mdot
.67517 .39736 Mdot
.53094 .52889 Mdot
.43281 .55739 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50663 .00281 Mdot
.52111 .00895 Mdot
.56717 .02847 Mdot
.71103 .08891 Mdot
.0865 .23205 Mdot
.33851 .15575 Mdot
.38777 .03044 Mdot
.2823 .55285 Mdot
.943 .40833 Mdot
.68738 .46006 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00326 Mdot
.52447 .01037 Mdot
.57781 .03297 Mdot
.74326 .10226 Mdot
.14723 .24967 Mdot
.36054 .13183 Mdot
.39041 .01846 Mdot
.26857 .54274 Mdot
.90963 .3962 Mdot
.67908 .47554 Mdot
.49941 .61778 Mdot
.49812 .61724 Mdot
.494 .61549 Mdot
.48089 .60993 Mdot
.43918 .59226 Mdot
.30845 .53724 Mdot
.9549 .39953 Mdot
.6681 .44078 Mdot
.58911 .56922 Mdot
.63693 .02955 Mdot
.86571 .1414 Mdot
.4989 .61757 Mdot
.4965 .61655 Mdot
.48886 .61331 Mdot
.46453 .60299 Mdot
.38743 .57038 Mdot
.1552 .47451 Mdot
.72535 .35237 Mdot
.53138 .49815 Mdot
.38418 .52706 Mdot
.07817 .42891 Mdot
.65957 .35932 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51647 .00699 Mdot
.55244 .02223 Mdot
.66565 .06997 Mdot
.98484 .19727 Mdot
.32674 .2113 Mdot
.45712 .08058 Mdot
.52395 .0413 Mdot
.62656 .06342 Mdot
.89963 .16877 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49025 .6139 Mdot
.46895 .60487 Mdot
.40136 .57626 Mdot
.1951 .49056 Mdot
.76418 .35171 Mdot
.57104 .49867 Mdot
.48095 .56236 Mdot
.36235 .54473 Mdot
.06206 .43245 Mdot
.50004 2e-05 Mdot
.50011 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51185 .00502 Mdot
.53774 .016 Mdot
.6197 .05066 Mdot
.86477 .15146 Mdot
.28914 .26227 Mdot
.48196 .11917 Mdot
.64778 .10248 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48268 .61069 Mdot
.44485 .59466 Mdot
.32596 .54455 Mdot
.99501 .4135 Mdot
.67154 .41812 Mdot
.55838 .5481 Mdot
.53085 .60102 Mdot
.54929 .0114 Mdot
.64049 .05637 Mdot
.49963 .61788 Mdot
.49881 .61753 Mdot
.49621 .61643 Mdot
.48793 .61292 Mdot
.46157 .60174 Mdot
.37812 .56646 Mdot
.1292 .46419 Mdot
.70708 .35715 Mdot
.51505 .49936 Mdot
.34558 .51329 Mdot
.97915 .39157 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52529 .01073 Mdot
.58043 .03408 Mdot
.75115 .10551 Mdot
.16059 .25305 Mdot
.36799 .12818 Mdot
.39931 .01936 Mdot
.28947 .55015 Mdot
.50019 8e-05 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50612 .0026 Mdot
.51951 .00827 Mdot
.56209 .02631 Mdot
.69544 .08242 Mdot
.05365 .22138 Mdot
.33289 .17258 Mdot
.40506 .0446 Mdot
.34313 .57975 Mdot
.08217 .45676 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.5089 .00377 Mdot
.52835 .01202 Mdot
.59011 .03817 Mdot
.77994 .11732 Mdot
.20428 .26226 Mdot
.39968 .12076 Mdot
.45436 .03379 Mdot
.4415 .61009 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52365 .01003 Mdot
.57523 .03188 Mdot
.73549 .09905 Mdot
.1335 .24598 Mdot
.35393 .13623 Mdot
.38473 .01904 Mdot
.25737 .53932 Mdot
.89152 .39193 Mdot
.67609 .48489 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.515 .00636 Mdot
.54774 .02024 Mdot
.65104 .06384 Mdot
.94839 .18377 Mdot
.3218 .23078 Mdot
.48037 .098 Mdot
.60957 .07985 Mdot
.89045 .17359 Mdot
.50078 .00033 Mdot
.50249 .00105 Mdot
.50792 .00336 Mdot
.52524 .0107 Mdot
.58027 .03401 Mdot
.75067 .10531 Mdot
.1598 .25285 Mdot
.36752 .12838 Mdot
.39869 .01926 Mdot
.28794 .54959 Mdot
.94522 .40622 Mdot
.68305 .45601 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47635 .60801 Mdot
.42477 .58616 Mdot
.26452 .51899 Mdot
.86652 .37206 Mdot
.64608 .4818 Mdot
.61527 .59899 Mdot
.74264 .07872 Mdot
.10849 .22611 Mdot
.32392 .13314 Mdot
.5 .61803 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48366 .6111 Mdot
.44797 .59598 Mdot
.33562 .5486 Mdot
.01825 .42189 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .0027 Mdot
.52031 .00861 Mdot
.56464 .0274 Mdot
.70329 .08569 Mdot
.07046 .22692 Mdot
.33536 .16372 Mdot
.39505 .03689 Mdot
.30847 .56453 Mdot
.99909 .42683 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47757 .60852 Mdot
.42866 .5878 Mdot
.27627 .52385 Mdot
.8884 .37832 Mdot
.65454 .4735 Mdot
.61775 .5953 Mdot
.74191 .07674 Mdot
.1045 .22409 Mdot
.32136 .13403 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00342 Mdot
.52566 .01088 Mdot
.58158 .03456 Mdot
.75459 .10692 Mdot
.16623 .25441 Mdot
.37145 .12683 Mdot
.40414 .0202 Mdot
.30157 .55464 Mdot
.97269 .41478 Mdot
.68458 .43997 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00114 Mdot
.50859 .00364 Mdot
.52736 .0116 Mdot
.58698 .03684 Mdot
.77066 .11352 Mdot
.19107 .25983 Mdot
.38892 .12228 Mdot
.43336 .02746 Mdot
.38074 .58551 Mdot
.16549 .48501 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.47699 .60828 Mdot
.42682 .58702 Mdot
.2707 .52155 Mdot
.87786 .37525 Mdot
.65077 .47768 Mdot
.6175 .59747 Mdot
.7449 .07874 Mdot
.1109 .2262 Mdot
.32369 .13151 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48581 .61202 Mdot
.45483 .59888 Mdot
.35698 .55756 Mdot
.07235 .44212 Mdot
.68289 .37733 Mdot
.51125 .51196 Mdot
.35647 .52237 Mdot
.01441 .40663 Mdot
.65077 .39329 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50556 .00236 Mdot
.51771 .00751 Mdot
.55636 .02389 Mdot
.67781 .07506 Mdot
.01385 .20768 Mdot
.32914 .19486 Mdot
.43461 .06518 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51414 .006 Mdot
.54503 .01909 Mdot
.64258 .06029 Mdot
.92652 .17548 Mdot
.3168 .24121 Mdot
.48908 .10647 Mdot
.64499 .09636 Mdot
.98952 .21293 Mdot
.34976 .22264 Mdot
.49795 .61716 Mdot
.49347 .61526 Mdot
.47919 .60921 Mdot
.43379 .58997 Mdot
.29191 .53035 Mdot
.91953 .38789 Mdot
.66278 .45935 Mdot
.60979 .58529 Mdot
.70874 .06115 Mdot
.03844 .20377 Mdot
.31104 .16848 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51848 .00784 Mdot
.55881 .02493 Mdot
.68537 .07822 Mdot
.03124 .21376 Mdot
.33055 .18499 Mdot
.42106 .05594 Mdot
.39796 .60376 Mdot
.23208 .51551 Mdot
.82898 .3689 Mdot
.49852 .61741 Mdot
.4953 .61604 Mdot
.48502 .61168 Mdot
.45229 .59781 Mdot
.34908 .55424 Mdot
.05192 .43438 Mdot
.67825 .3871 Mdot
.51947 .5199 Mdot
.38982 .53791 Mdot
.10779 .44373 Mdot
.67615 .35127 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50764 .00324 Mdot
.52434 .01032 Mdot
.57739 .03279 Mdot
.74202 .10174 Mdot
.14507 .2491 Mdot
.35943 .13248 Mdot
.38929 .01845 Mdot
.26615 .54193 Mdot
.90551 .39515 Mdot
.67842 .47769 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.5049 .00208 Mdot
.51561 .00662 Mdot
.54968 .02106 Mdot
.65708 .06638 Mdot
.96368 .18948 Mdot
.32428 .22287 Mdot
.47169 .0911 Mdot
.57685 .06499 Mdot
.79285 .1335 Mdot
.23899 .27573 Mdot
.49908 .61764 Mdot
.49706 .61679 Mdot
.49064 .61407 Mdot
.4702 .6054 Mdot
.40531 .57793 Mdot
.20661 .49523 Mdot
.778 .35314 Mdot
.58443 .4984 Mdot
.51167 .57306 Mdot
.45638 .58386 Mdot
.33647 .54393 Mdot
.4976 .61702 Mdot
.49236 .6148 Mdot
.47568 .60772 Mdot
.42264 .58526 Mdot
.2581 .51634 Mdot
.85512 .36898 Mdot
.64067 .4855 Mdot
.61081 .59958 Mdot
.73406 .07617 Mdot
.09484 .22297 Mdot
.32163 .14017 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.5148 .00628 Mdot
.54712 .01998 Mdot
.6491 .06303 Mdot
.94343 .1819 Mdot
.32083 .23325 Mdot
.48277 .10008 Mdot
.6189 .08414 Mdot
.49866 .61747 Mdot
.49575 .61623 Mdot
.48645 .61229 Mdot
.45684 .59974 Mdot
.36328 .56021 Mdot
.08896 .44849 Mdot
.68804 .37025 Mdot
.50798 .50675 Mdot
.33989 .51415 Mdot
.97015 .38952 Mdot
.64492 .41703 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51119 .00474 Mdot
.53563 .01511 Mdot
.61309 .04787 Mdot
.84625 .1441 Mdot
.27581 .26548 Mdot
.46976 .11987 Mdot
.61862 .092 Mdot
.9294 .19207 Mdot
.34264 .25539 Mdot
.49996 .61802 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49541 .61609 Mdot
.48536 .61183 Mdot
.45339 .59828 Mdot
.3525 .55568 Mdot
.06071 .4377 Mdot
.68004 .38277 Mdot
.51541 .51629 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.5014 .0006 Mdot
.50447 .0019 Mdot
.51424 .00604 Mdot
.54535 .01923 Mdot
.64357 .0607 Mdot
.9291 .17647 Mdot
.3175 .24004 Mdot
.48831 .10557 Mdot
.64162 .09475 Mdot
.9804 .20938 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.50841 .00357 Mdot
.52678 .01136 Mdot
.58514 .03607 Mdot
.76521 .11129 Mdot
.18291 .25816 Mdot
.38279 .12353 Mdot
.42231 .02442 Mdot
.34986 .57326 Mdot
.08415 .45381 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51261 .00535 Mdot
.54015 .01702 Mdot
.62728 .05385 Mdot
.88563 .15967 Mdot
.30114 .2568 Mdot
.49014 .11681 Mdot
.66437 .10768 Mdot
.0436 .23438 Mdot
.35824 .19446 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49653 .61656 Mdot
.48896 .61335 Mdot
.46483 .60312 Mdot
.38836 .57078 Mdot
.15784 .47556 Mdot
.7275 .35207 Mdot
.53352 .49815 Mdot
.38944 .52899 Mdot
.09255 .43454 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47785 .60864 Mdot
.42955 .58818 Mdot
.27898 .52498 Mdot
.89363 .37987 Mdot
.65622 .4713 Mdot
.61728 .59397 Mdot
.73875 .07508 Mdot
.09837 .22225 Mdot
.31965 .13676 Mdot
.49757 .617 Mdot
.49227 .61475 Mdot
.47537 .60759 Mdot
.42166 .58484 Mdot
.25514 .51512 Mdot
.85001 .36765 Mdot
.63801 .48701 Mdot
.60804 .59951 Mdot
.72796 .07412 Mdot
.08433 .22025 Mdot
.32004 .14568 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50837 .00355 Mdot
.52666 .01131 Mdot
.58476 .03591 Mdot
.76407 .11082 Mdot
.18119 .25779 Mdot
.38154 .12382 Mdot
.42015 .02386 Mdot
.34395 .57094 Mdot
.06943 .44837 Mdot
.49976 .61793 Mdot
.49923 .61771 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60745 Mdot
.4206 .58439 Mdot
.25194 .5138 Mdot
.84458 .36627 Mdot
.63502 .48852 Mdot
.60454 .5992 Mdot
.71986 .07127 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48703 .61254 Mdot
.45871 .60053 Mdot
.36914 .56268 Mdot
.10466 .45458 Mdot
.69426 .36439 Mdot
.50811 .50298 Mdot
.33411 .5105 Mdot
.95395 .38308 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52504 .01062 Mdot
.57961 .03373 Mdot
.74869 .1045 Mdot
.1565 .25204 Mdot
.3656 .12923 Mdot
.39621 .01892 Mdot
.28195 .54742 Mdot
.93375 .40284 Mdot
.68208 .46249 Mdot
.49959 .61786 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.4869 .61248 Mdot
.45829 .60035 Mdot
.36782 .56212 Mdot
.1011 .45319 Mdot
.69272 .36565 Mdot
.50779 .50374 Mdot
.33454 .51096 Mdot
.95545 .38375 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52366 .01003 Mdot
.57524 .03188 Mdot
.73554 .09907 Mdot
.13358 .246 Mdot
.35396 .1362 Mdot
.38476 .01903 Mdot
.25741 .53933 Mdot
.89158 .39194 Mdot
.67609 .48486 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00113 Mdot
.50846 .00359 Mdot
.52693 .01142 Mdot
.58562 .03627 Mdot
.76663 .11187 Mdot
.18507 .25861 Mdot
.38437 .12317 Mdot
.42509 .02517 Mdot
.35755 .57629 Mdot
.10373 .46117 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51918 .00813 Mdot
.56105 .02587 Mdot
.69225 .08109 Mdot
.04664 .21903 Mdot
.33207 .1764 Mdot
.4098 .04804 Mdot
.35937 .58687 Mdot
.1244 .47281 Mdot
.72125 .36888 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51299 .00551 Mdot
.54137 .01754 Mdot
.63112 .05546 Mdot
.89603 .16373 Mdot
.30604 .2534 Mdot
.49197 .11491 Mdot
.66585 .10746 Mdot
.04586 .23486 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .00159 Mdot
.51198 .00508 Mdot
.53814 .01617 Mdot
.62097 .05119 Mdot
.86828 .15285 Mdot
.29138 .26149 Mdot
.48376 .1189 Mdot
.65182 .10387 Mdot
.01462 .22422 Mdot
.35552 .21069 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50338 .00144 Mdot
.51078 .00457 Mdot
.53435 .01456 Mdot
.60904 .04616 Mdot
.83478 .13952 Mdot
.26618 .26662 Mdot
.46008 .11984 Mdot
.59473 .08322 Mdot
.86322 .16594 Mdot
.31255 .2777 Mdot
.49773 .61707 Mdot
.49275 .61496 Mdot
.47691 .60824 Mdot
.42656 .58691 Mdot
.26991 .52122 Mdot
.8764 .37483 Mdot
.65021 .47824 Mdot
.61733 .59772 Mdot
.74494 .07886 Mdot
.11115 .22633 Mdot
.32387 .13146 Mdot
.4987 .61748 Mdot
.49585 .61627 Mdot
.48677 .61242 Mdot
.45786 .60017 Mdot
.36647 .56155 Mdot
.09747 .45178 Mdot
.69124 .36697 Mdot
.50764 .50457 Mdot
.33552 .51165 Mdot
.95829 .3849 Mdot
.64292 .42312 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50964 .00409 Mdot
.53069 .01301 Mdot
.5975 .04129 Mdot
.80157 .12612 Mdot
.23195 .26599 Mdot
.42513 .11939 Mdot
.51012 .05252 Mdot
.61026 .06189 Mdot
.86288 .15613 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48266 .61068 Mdot
.4448 .59464 Mdot
.32579 .54448 Mdot
.99462 .41336 Mdot
.67151 .41834 Mdot
.55869 .54831 Mdot
.53194 .6015 Mdot
.55276 .01287 Mdot
.65129 .06089 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51713 .00726 Mdot
.55453 .02311 Mdot
.67213 .07268 Mdot
.00046 .20292 Mdot
.3281 .20249 Mdot
.44517 .07236 Mdot
.48162 .02253 Mdot
.49055 .00552 Mdot
.48532 .6148 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50225 .00095 Mdot
.50715 .00303 Mdot
.52279 .00966 Mdot
.5725 .03072 Mdot
.72724 .09563 Mdot
.11828 .24167 Mdot
.34778 .14184 Mdot
.38221 .02128 Mdot
.25566 .53982 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48342 .611 Mdot
.44722 .59566 Mdot
.33329 .54762 Mdot
.01258 .41982 Mdot
.67302 .40818 Mdot
.54481 .53879 Mdot
.48292 .57979 Mdot
.39547 .56399 Mdot
.16227 .4739 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50152 .00065 Mdot
.50486 .00206 Mdot
.51547 .00656 Mdot
.54926 .02088 Mdot
.65576 .06582 Mdot
.96035 .18825 Mdot
.3238 .22462 Mdot
.47373 .09266 Mdot
.58443 .06842 Mdot
.81592 .14307 Mdot
.49823 .61728 Mdot
.49437 .61565 Mdot
.48206 .61043 Mdot
.44289 .59383 Mdot
.31987 .54201 Mdot
.98077 .40846 Mdot
.67044 .42624 Mdot
.56963 .55573 Mdot
.56997 .00021 Mdot
.67191 .063 Mdot
.98442 .19314 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50512 .00217 Mdot
.51631 .00691 Mdot
.55191 .022 Mdot
.664 .06928 Mdot
.98081 .1958 Mdot
.32634 .21355 Mdot
.46007 .08265 Mdot
.53453 .04602 Mdot
.6604 .07779 Mdot
.98814 .20256 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50425 .0018 Mdot
.51355 .00575 Mdot
.54316 .0183 Mdot
.63671 .05782 Mdot
.91103 .16954 Mdot
.31196 .24779 Mdot
.49202 .11128 Mdot
.66012 .10389 Mdot
.02987 .22852 Mdot
.35508 .20099 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50341 .00145 Mdot
.51087 .00461 Mdot
.53462 .01468 Mdot
.60989 .04652 Mdot
.83722 .1405 Mdot
.26832 .26643 Mdot
.46226 .11986 Mdot
.49803 .6172 Mdot
.49373 .61538 Mdot
.48003 .60956 Mdot
.43644 .5911 Mdot
.30003 .53373 Mdot
.93658 .39341 Mdot
.66576 .45066 Mdot
.60102 .57802 Mdot
.67783 .04747 Mdot
.96924 .1801 Mdot
.30651 .20844 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48127 .61009 Mdot
.44039 .59277 Mdot
.31216 .53878 Mdot
.96317 .40235 Mdot
.66894 .43619 Mdot
.58313 .565 Mdot
.61643 .02058 Mdot
.80922 .11915 Mdot
.2244 .2566 Mdot
.49895 .61759 Mdot
.49666 .61662 Mdot
.48935 .61352 Mdot
.46606 .60365 Mdot
.39227 .57242 Mdot
.16893 .48 Mdot
.73717 .35119 Mdot
.54336 .49826 Mdot
.4138 .53796 Mdot
.16117 .4619 Mdot
.70604 .33675 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47774 .6086 Mdot
.42919 .58803 Mdot
.27788 .52452 Mdot
.8915 .37924 Mdot
.65555 .47221 Mdot
.61752 .59453 Mdot
.74017 .0758 Mdot
.1011 .22307 Mdot
.32038 .13552 Mdot
.49819 .61727 Mdot
.49424 .61559 Mdot
.48165 .61025 Mdot
.44161 .59328 Mdot
.31592 .54036 Mdot
.97169 .40529 Mdot
.6697 .43139 Mdot
.5767 .56055 Mdot
.59433 .0109 Mdot
.74533 .09332 Mdot
.13496 .2408 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50378 .0016 Mdot
.51205 .00511 Mdot
.53837 .01627 Mdot
.62168 .05149 Mdot
.87025 .15362 Mdot
.29259 .26102 Mdot
.48469 .11873 Mdot
.65387 .10456 Mdot
.01955 .226 Mdot
.35598 .20792 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47564 .6077 Mdot
.42253 .58521 Mdot
.25774 .51619 Mdot
.85451 .36882 Mdot
.64036 .48568 Mdot
.6105 .59958 Mdot
.7334 .07595 Mdot
.09373 .2227 Mdot
.4996 .61786 Mdot
.49873 .6175 Mdot
.49595 .61632 Mdot
.4871 .61256 Mdot
.45892 .60062 Mdot
.36979 .56295 Mdot
.10641 .45526 Mdot
.69505 .3638 Mdot
.50833 .50263 Mdot
.33409 .51035 Mdot
.95368 .38293 Mdot
.49893 .61758 Mdot
.49659 .61659 Mdot
.48914 .61343 Mdot
.4654 .60337 Mdot
.39018 .57154 Mdot
.16299 .47762 Mdot
.73186 .35158 Mdot
.53792 .49817 Mdot
.40033 .533 Mdot
.12281 .44652 Mdot
.67882 .34363 Mdot
.49816 .61725 Mdot
.49413 .61555 Mdot
.4813 .61011 Mdot
.44049 .59281 Mdot
.31249 .53892 Mdot
.96391 .4026 Mdot
.66901 .43577 Mdot
.58259 .56462 Mdot
.61456 .01976 Mdot
.8039 .11702 Mdot
.21842 .25619 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52244 .00952 Mdot
.5714 .03026 Mdot
.7239 .09425 Mdot
.11192 .23981 Mdot
.34556 .1444 Mdot
.38223 .02266 Mdot
.25793 .54121 Mdot
.89519 .39385 Mdot
.50037 .00016 Mdot
.50117 .00049 Mdot
.50371 .00158 Mdot
.51183 .00502 Mdot
.53769 .01598 Mdot
.61956 .0506 Mdot
.86436 .1513 Mdot
.28887 .26236 Mdot
.48174 .1192 Mdot
.64727 .1023 Mdot
.0035 .22016 Mdot
.35448 .21692 Mdot
.49858 .61743 Mdot
.49547 .61611 Mdot
.48556 .61191 Mdot
.45402 .59854 Mdot
.35448 .55651 Mdot
.06582 .43963 Mdot
.68122 .38034 Mdot
.51341 .51432 Mdot
.36568 .52673 Mdot
.03956 .41648 Mdot
.65471 .38018 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00282 Mdot
.5212 .00899 Mdot
.56746 .02859 Mdot
.7119 .08927 Mdot
.08826 .2326 Mdot
.33891 .15491 Mdot
.38714 .0298 Mdot
.2799 .55176 Mdot
.93812 .40681 Mdot
.68685 .46274 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50756 .0032 Mdot
.52408 .01021 Mdot
.57657 .03244 Mdot
.73953 .10072 Mdot
.14072 .24794 Mdot
.35727 .13384 Mdot
.38729 .01855 Mdot
.26203 .54062 Mdot
.89872 .3935 Mdot
.67728 .48118 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52546 .01079 Mdot
.58095 .03429 Mdot
.75269 .10614 Mdot
.16312 .25366 Mdot
.36952 .12756 Mdot
.4014 .0197 Mdot
.29466 .55207 Mdot
.49952 .61783 Mdot
.49846 .61738 Mdot
.4951 .61595 Mdot
.48438 .61141 Mdot
.45027 .59695 Mdot
.34278 .5516 Mdot
.03598 .42842 Mdot
.67567 .39535 Mdot
.52853 .52709 Mdot
.42394 .5534 Mdot
.20956 .48554 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61476 Mdot
.47544 .60762 Mdot
.42189 .58494 Mdot
.25583 .5154 Mdot
.8512 .36796 Mdot
.63864 .48667 Mdot
.60873 .59955 Mdot
.72951 .07465 Mdot
.08705 .22097 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51399 .00593 Mdot
.54455 .01889 Mdot
.64106 .05965 Mdot
.92254 .17396 Mdot
.31567 .24297 Mdot
.49011 .10781 Mdot
.64972 .09865 Mdot
.00222 .21786 Mdot
.35139 .2158 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50763 .00324 Mdot
.52432 .01031 Mdot
.57733 .03277 Mdot
.74184 .10167 Mdot
.14476 .24902 Mdot
.35927 .13257 Mdot
.38913 .01846 Mdot
.26582 .54182 Mdot
.90496 .39501 Mdot
.67833 .47797 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61226 Mdot
.45661 .59964 Mdot
.36257 .55991 Mdot
.08705 .44776 Mdot
.68737 .37102 Mdot
.50818 .50729 Mdot
.34127 .51487 Mdot
.9738 .39093 Mdot
.64546 .41511 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00112 Mdot
.50845 .00358 Mdot
.52692 .01142 Mdot
.58559 .03626 Mdot
.76653 .11183 Mdot
.18493 .25858 Mdot
.38426 .1232 Mdot
.4249 .02511 Mdot
.35702 .57608 Mdot
.49742 .61694 Mdot
.49177 .61454 Mdot
.47377 .60691 Mdot
.41662 .58271 Mdot
.24004 .5089 Mdot
.82519 .36164 Mdot
.62292 .49303 Mdot
.58725 .59599 Mdot
.67601 .05485 Mdot
.97815 .18674 Mdot
.31297 .20693 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49145 .61441 Mdot
.47276 .60648 Mdot
.4134 .58135 Mdot
.23047 .50497 Mdot
.8106 .35854 Mdot
.61236 .49552 Mdot
.56902 .59124 Mdot
.62598 .03521 Mdot
.498 .61719 Mdot
.49362 .61533 Mdot
.47968 .60942 Mdot
.43535 .59063 Mdot
.29669 .53233 Mdot
.92949 .39109 Mdot
.66463 .45434 Mdot
.60498 .58117 Mdot
.69163 .05355 Mdot
.00113 .19128 Mdot
.30894 .19023 Mdot
.49948 .61781 Mdot
.49834 .61733 Mdot
.49472 .61579 Mdot
.48317 .6109 Mdot
.44642 .59532 Mdot
.3308 .54658 Mdot
.00656 .41764 Mdot
.67248 .41157 Mdot
.54938 .54195 Mdot
.49917 .587 Mdot
.44772 .58623 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00148 Mdot
.51109 .0047 Mdot
.53533 .01498 Mdot
.61212 .04746 Mdot
.84352 .14301 Mdot
.27361 .26581 Mdot
.46759 .11989 Mdot
.61329 .09005 Mdot
.91494 .18643 Mdot
.33819 .26158 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.49291 .61503 Mdot
.47741 .60846 Mdot
.42815 .58759 Mdot
.27474 .52322 Mdot
.88547 .37745 Mdot
.65355 .4747 Mdot
.61785 .59597 Mdot
.7432 .07747 Mdot
.10707 .22488 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50775 .00329 Mdot
.52469 .01047 Mdot
.57853 .03327 Mdot
.74543 .10315 Mdot
.15096 .25063 Mdot
.36251 .13075 Mdot
.39254 .01856 Mdot
.27336 .54437 Mdot
.91801 .39842 Mdot
.68028 .47111 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50293 .00124 Mdot
.50934 .00396 Mdot
.52974 .01261 Mdot
.59451 .04003 Mdot
.79284 .12258 Mdot
.22131 .26481 Mdot
.41492 .11966 Mdot
.4869 .04448 Mdot
.53924 .03235 Mdot
.64985 .06836 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47474 .60732 Mdot
.41968 .584 Mdot
.24918 .51266 Mdot
.83995 .36512 Mdot
.63233 .48972 Mdot
.60111 .59874 Mdot
.71157 .06826 Mdot
.05383 .21153 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00314 Mdot
.52362 .01002 Mdot
.57514 .03184 Mdot
.73522 .09894 Mdot
.13301 .24585 Mdot
.35371 .1364 Mdot
.38459 .01909 Mdot
.25714 .53927 Mdot
.8912 .39187 Mdot
.67604 .48506 Mdot
.50027 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.50889 .00377 Mdot
.52832 .01201 Mdot
.59001 .03813 Mdot
.77964 .1172 Mdot
.20387 .26219 Mdot
.39933 .1208 Mdot
.45364 .03357 Mdot
.4394 .60923 Mdot
.33645 .5544 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51389 .00589 Mdot
.54422 .01875 Mdot
.64004 .05922 Mdot
.91984 .17292 Mdot
.31486 .24414 Mdot
.4907 .10868 Mdot
.65261 .10006 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00156 Mdot
.51169 .00496 Mdot
.53724 .01579 Mdot
.61814 .05 Mdot
.86042 .14974 Mdot
.28625 .26317 Mdot
.4795 .11944 Mdot
.64209 .10049 Mdot
.99061 .2154 Mdot
.35321 .2241 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48513 .61173 Mdot
.45264 .59796 Mdot
.35016 .5547 Mdot
.05467 .43541 Mdot
.67878 .38572 Mdot
.51812 .51874 Mdot
.38459 .5355 Mdot
.09271 .43764 Mdot
.6695 .35648 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49666 .61662 Mdot
.48937 .61352 Mdot
.46613 .60367 Mdot
.39247 .57251 Mdot
.16952 .48024 Mdot
.73771 .35116 Mdot
.54392 .49827 Mdot
.41518 .53847 Mdot
.16516 .46351 Mdot
.50021 9e-05 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52177 .00923 Mdot
.56925 .02935 Mdot
.71736 .09154 Mdot
.0992 .23599 Mdot
.34169 .14987 Mdot
.38398 .02614 Mdot
.26725 .54589 Mdot
.91318 .39921 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51428 .00606 Mdot
.54548 .01928 Mdot
.64397 .06087 Mdot
.93013 .17686 Mdot
.31777 .23957 Mdot
.48799 .1052 Mdot
.6402 .09407 Mdot
.97655 .20788 Mdot
.34795 .22954 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00124 Mdot
.50929 .00394 Mdot
.52958 .01254 Mdot
.59398 .0398 Mdot
.79129 .12195 Mdot
.21935 .26455 Mdot
.41309 .11974 Mdot
.48284 .04311 Mdot
.52691 .02723 Mdot
.61114 .05206 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.4749 .60739 Mdot
.42019 .58422 Mdot
.25071 .51329 Mdot
.8425 .36575 Mdot
.63383 .48907 Mdot
.60306 .59902 Mdot
.7163 .06999 Mdot
.06295 .21424 Mdot
.31761 .15739 Mdot
.49881 .61753 Mdot
.49619 .61642 Mdot
.48787 .61289 Mdot
.46138 .60166 Mdot
.37753 .56621 Mdot
.12758 .46355 Mdot
.7061 .35755 Mdot
.51434 .49952 Mdot
.34405 .51279 Mdot
.97551 .39026 Mdot
.64356 .41288 Mdot
.4974 .61693 Mdot
.49172 .61452 Mdot
.47363 .60685 Mdot
.41616 .58252 Mdot
.23866 .50834 Mdot
.82304 .36117 Mdot
.62145 .49344 Mdot
.58486 .59542 Mdot
.66961 .05238 Mdot
.96328 .1815 Mdot
.31154 .21524 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50365 .00155 Mdot
.51163 .00493 Mdot
.53705 .01571 Mdot
.61754 .04974 Mdot
.85874 .14907 Mdot
.28509 .2635 Mdot
.47848 .11952 Mdot
.63969 .09963 Mdot
.98455 .21313 Mdot
.35255 .22744 Mdot
.50047 .0002 Mdot
.5015 .00063 Mdot
.50477 .00202 Mdot
.51519 .00644 Mdot
.54837 .0205 Mdot
.65298 .06465 Mdot
.95331 .18562 Mdot
.32268 .22828 Mdot
.47778 .09586 Mdot
.59966 .07532 Mdot
.86144 .16179 Mdot
.30579 .27462 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51189 .00504 Mdot
.53787 .01605 Mdot
.62011 .05083 Mdot
.86588 .1519 Mdot
.28986 .26203 Mdot
.48255 .11909 Mdot
.64911 .10294 Mdot
.00803 .22183 Mdot
.35491 .21438 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50832 .00353 Mdot
.52652 .01124 Mdot
.5843 .03571 Mdot
.76272 .11026 Mdot
.1791 .25734 Mdot
.38005 .12419 Mdot
.41763 .02323 Mdot
.3371 .56826 Mdot
.05269 .44226 Mdot
.69069 .3943 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48765 .6128 Mdot
.46067 .60136 Mdot
.37528 .56526 Mdot
.12138 .46112 Mdot
.70256 .35918 Mdot
.51193 .50022 Mdot
.33919 .51127 Mdot
.96424 .3863 Mdot
.64248 .41917 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50278 .00118 Mdot
.50884 .00375 Mdot
.52817 .01194 Mdot
.58952 .03792 Mdot
.77818 .1166 Mdot
.20184 .26184 Mdot
.39761 .121 Mdot
.45019 .03249 Mdot
.42925 .60509 Mdot
.30565 .54164 Mdot
.49906 .61764 Mdot
.49702 .61677 Mdot
.4905 .61401 Mdot
.46975 .60521 Mdot
.40391 .57734 Mdot
.20252 .49357 Mdot
.77295 .35254 Mdot
.57963 .49856 Mdot
.50084 .56934 Mdot
.4233 .57011 Mdot
.23511 .50173 Mdot
.49889 .61756 Mdot
.49647 .61654 Mdot
.48876 .61327 Mdot
.46421 .60286 Mdot
.38642 .56996 Mdot
.15237 .47338 Mdot
.72311 .35274 Mdot
.52918 .49818 Mdot
.37879 .52508 Mdot
.06364 .42326 Mdot
.65556 .36583 Mdot
.50066 .00028 Mdot
.50211 .00089 Mdot
.50672 .00285 Mdot
.5214 .00908 Mdot
.5681 .02886 Mdot
.71386 .09008 Mdot
.09222 .23384 Mdot
.33986 .15305 Mdot
.38583 .02841 Mdot
.27485 .54944 Mdot
.92804 .40369 Mdot
.68553 .46816 Mdot
.50033 .00014 Mdot
.50107 .00045 Mdot
.50339 .00144 Mdot
.51081 .00459 Mdot
.53444 .0146 Mdot
.60933 .04628 Mdot
.83561 .13985 Mdot
.26691 .26656 Mdot
.46083 .11985 Mdot
.59658 .0839 Mdot
.86846 .16803 Mdot
.31595 .27656 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00332 Mdot
.52496 .01058 Mdot
.57937 .03363 Mdot
.74797 .1042 Mdot
.15528 .25173 Mdot
.3649 .12955 Mdot
.39536 .01882 Mdot
.27991 .54668 Mdot
.92994 .40174 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .0099 Mdot
.57429 .03148 Mdot
.73267 .09788 Mdot
.12836 .24455 Mdot
.35172 .13804 Mdot
.38346 .01962 Mdot
.2556 .53901 Mdot
.88916 .39156 Mdot
.67586 .48621 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52444 .01036 Mdot
.57774 .03294 Mdot
.74305 .10217 Mdot
.14687 .24957 Mdot
.36035 .13194 Mdot
.39021 .01846 Mdot
.26815 .54259 Mdot
.90891 .39601 Mdot
.67896 .47592 Mdot
.49756 .617 Mdot
.49223 .61474 Mdot
.47526 .60754 Mdot
.42132 .5847 Mdot
.25411 .51469 Mdot
.84824 .3672 Mdot
.63705 .48751 Mdot
.60696 .59944 Mdot
.72551 .07327 Mdot
.07997 .21907 Mdot
.31946 .14801 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.4798 .60947 Mdot
.43572 .59079 Mdot
.29783 .53281 Mdot
.93191 .39188 Mdot
.66504 .4531 Mdot
.60367 .58011 Mdot
.68705 .05153 Mdot
.99074 .18769 Mdot
.30831 .19627 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.485 .61167 Mdot
.45224 .59779 Mdot
.34891 .55417 Mdot
.05148 .43421 Mdot
.67817 .38731 Mdot
.51969 .52009 Mdot
.39067 .53829 Mdot
.11025 .44473 Mdot
.67737 .3505 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51265 .00537 Mdot
.5403 .01709 Mdot
.62775 .05405 Mdot
.88689 .16016 Mdot
.30177 .25641 Mdot
.49044 .1166 Mdot
.66479 .10775 Mdot
.04446 .23465 Mdot
.35831 .19397 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50526 .00223 Mdot
.51676 .00711 Mdot
.55335 .02261 Mdot
.66846 .07115 Mdot
.99166 .19975 Mdot
.32736 .20748 Mdot
.45199 .07702 Mdot
.50568 .03318 Mdot
.56788 .03844 Mdot
.49996 .61802 Mdot
.49989 .61799 Mdot
.49963 .61788 Mdot
.49884 .61754 Mdot
.49629 .61646 Mdot
.48819 .61303 Mdot
.46239 .60209 Mdot
.38069 .56754 Mdot
.13632 .46701 Mdot
.71157 .35553 Mdot
.51863 .49879 Mdot
.49974 .61792 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49167 .6145 Mdot
.47345 .60678 Mdot
.4156 .58228 Mdot
.237 .50765 Mdot
.82047 .3606 Mdot
.61965 .49392 Mdot
.58186 .59468 Mdot
.66151 .04923 Mdot
.4977 .61706 Mdot
.49269 .61493 Mdot
.4767 .60816 Mdot
.4259 .58664 Mdot
.26792 .5204 Mdot
.87273 .37379 Mdot
.64873 .4796 Mdot
.61675 .59827 Mdot
.74461 .07902 Mdot
.11107 .22648 Mdot
.32412 .13167 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.5037 .00157 Mdot
.51177 .00499 Mdot
.53749 .0159 Mdot
.61893 .05033 Mdot
.86262 .15061 Mdot
.28773 .26273 Mdot
.48078 .11931 Mdot
.64506 .10153 Mdot
.99804 .21815 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.48509 .61171 Mdot
.45254 .59791 Mdot
.34984 .55456 Mdot
.05385 .43511 Mdot
.67862 .38613 Mdot
.51852 .51908 Mdot
.38612 .53621 Mdot
.09712 .43942 Mdot
.67131 .35487 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49074 .61411 Mdot
.47049 .60552 Mdot
.40624 .57832 Mdot
.20933 .49634 Mdot
.78145 .35359 Mdot
.58765 .49826 Mdot
.51878 .57547 Mdot
.47802 .59284 Mdot
.49919 .61769 Mdot
.49741 .61693 Mdot
.49174 .61453 Mdot
.47368 .60687 Mdot
.41631 .58258 Mdot
.23911 .50852 Mdot
.82374 .36132 Mdot
.62193 .49331 Mdot
.58565 .59561 Mdot
.67173 .0532 Mdot
.96824 .18326 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51517 .00643 Mdot
.5483 .02048 Mdot
.65279 .06457 Mdot
.95283 .18544 Mdot
.3226 .22853 Mdot
.47804 .09607 Mdot
.60066 .07578 Mdot
.86439 .163 Mdot
.3078 .27404 Mdot
.49999 .61803 Mdot
.49996 .61802 Mdot
.49987 .61798 Mdot
.49959 .61786 Mdot
.49869 .61748 Mdot
.49584 .61627 Mdot
.48673 .61241 Mdot
.45775 .60012 Mdot
.36612 .56141 Mdot
.09653 .45142 Mdot
.69086 .36732 Mdot
.49973 .61792 Mdot
.49913 .61767 Mdot
.49724 .61686 Mdot
.4912 .6143 Mdot
.47197 .60615 Mdot
.4109 .58029 Mdot
.22306 .50194 Mdot
.7999 .35651 Mdot
.60383 .49686 Mdot
.55269 .58643 Mdot
.57916 .01636 Mdot
.49778 .61709 Mdot
.49291 .61503 Mdot
.47742 .60846 Mdot
.42818 .5876 Mdot
.27482 .52325 Mdot
.88563 .3775 Mdot
.6536 .47464 Mdot
.61785 .59593 Mdot
.74314 .07744 Mdot
.10695 .22485 Mdot
.32214 .13299 Mdot
.498 .61718 Mdot
.49362 .61533 Mdot
.47966 .60941 Mdot
.43529 .59061 Mdot
.2965 .53226 Mdot
.92909 .39097 Mdot
.66456 .45455 Mdot
.60519 .58134 Mdot
.69235 .05387 Mdot
.00276 .19184 Mdot
.30903 .18928 Mdot
.4983 .61731 Mdot
.49457 .61573 Mdot
.4827 .6107 Mdot
.44493 .59469 Mdot
.32619 .54465 Mdot
.99555 .41369 Mdot
.67159 .41781 Mdot
.55796 .54781 Mdot
.52936 .60036 Mdot
.54456 .00939 Mdot
.62574 .05017 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.4421 .59349 Mdot
.31744 .54099 Mdot
.97515 .40649 Mdot
.66999 .42943 Mdot
.57402 .55872 Mdot
.58513 .00686 Mdot
.71792 .08207 Mdot
.0846 .22663 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48268 .61069 Mdot
.44487 .59467 Mdot
.32602 .54458 Mdot
.99514 .41354 Mdot
.67155 .41805 Mdot
.55828 .54803 Mdot
.53049 .60086 Mdot
.54816 .01092 Mdot
.63698 .05489 Mdot
.49956 .61785 Mdot
.49859 .61744 Mdot
.49552 .61613 Mdot
.48572 .61198 Mdot
.45452 .59875 Mdot
.35602 .55716 Mdot
.06982 .44116 Mdot
.68222 .37848 Mdot
.51203 .51285 Mdot
.35986 .52399 Mdot
.02362 .41022 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51554 .00659 Mdot
.54949 .02098 Mdot
.65647 .06612 Mdot
.96213 .18891 Mdot
.32406 .22369 Mdot
.47265 .09183 Mdot
.5804 .0666 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48511 .61172 Mdot
.45261 .59794 Mdot
.35005 .55465 Mdot
.05441 .43532 Mdot
.67873 .38585 Mdot
.51825 .51885 Mdot
.38508 .53573 Mdot
.09413 .43822 Mdot
.67007 .35595 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.4849 .61163 Mdot
.45193 .59766 Mdot
.34794 .55377 Mdot
.04902 .43329 Mdot
.67772 .38856 Mdot
.52097 .52115 Mdot
.39556 .54053 Mdot
.12451 .45052 Mdot
.68517 .3465 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47959 .60938 Mdot
.43506 .59051 Mdot
.29581 .53197 Mdot
.92765 .3905 Mdot
.66431 .45528 Mdot
.60594 .58196 Mdot
.695 .05504 Mdot
.00867 .19386 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48427 .61137 Mdot
.44993 .59681 Mdot
.34172 .55116 Mdot
.03333 .42744 Mdot
.67531 .39676 Mdot
.53021 .52836 Mdot
.43017 .5562 Mdot
.2287 .49352 Mdot
.49738 .61692 Mdot
.49167 .6145 Mdot
.47345 .60678 Mdot
.4156 .58228 Mdot
.237 .50765 Mdot
.82046 .3606 Mdot
.61964 .49392 Mdot
.58185 .59468 Mdot
.66149 .04922 Mdot
.9439 .17453 Mdot
.30872 .22548 Mdot
.49989 .61799 Mdot
.49966 .61789 Mdot
.49892 .61757 Mdot
.49654 .61657 Mdot
.48899 .61336 Mdot
.46493 .60317 Mdot
.3887 .57092 Mdot
.15879 .47594 Mdot
.72829 .35197 Mdot
.53431 .49815 Mdot
.39138 .5297 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.515 .00636 Mdot
.54777 .02025 Mdot
.65111 .06387 Mdot
.94857 .18384 Mdot
.32184 .23069 Mdot
.48028 .09793 Mdot
.60923 .07969 Mdot
.88946 .17319 Mdot
.32249 .26763 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50694 .00294 Mdot
.52209 .00937 Mdot
.57029 .02979 Mdot
.72053 .09285 Mdot
.10541 .23787 Mdot
.34349 .14714 Mdot
.38285 .02433 Mdot
.26193 .5433 Mdot
.90295 .39617 Mdot
.68069 .48067 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.5087 .00369 Mdot
.52772 .01175 Mdot
.5881 .03732 Mdot
.77399 .11488 Mdot
.1959 .26076 Mdot
.39274 .12165 Mdot
.4406 .02958 Mdot
.4014 .59381 Mdot
.49956 .61785 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48581 .61202 Mdot
.45481 .59888 Mdot
.35695 .55755 Mdot
.07225 .44208 Mdot
.68286 .37738 Mdot
.51128 .51199 Mdot
.3566 .52244 Mdot
.01476 .40677 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48464 .61152 Mdot
.4511 .5973 Mdot
.34535 .55268 Mdot
.04245 .43083 Mdot
.67663 .39194 Mdot
.52461 .52408 Mdot
.40937 .54681 Mdot
.16541 .46726 Mdot
.71565 .34007 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50324 .00138 Mdot
.51034 .00438 Mdot
.53292 .01396 Mdot
.60454 .04426 Mdot
.82194 .13436 Mdot
.25409 .26709 Mdot
.4476 .11959 Mdot
.5639 .07188 Mdot
.77351 .12954 Mdot
.21924 .27548 Mdot
.49793 .61716 Mdot
.4934 .61523 Mdot
.47897 .60912 Mdot
.4331 .58968 Mdot
.28979 .52947 Mdot
.91518 .38651 Mdot
.66186 .46148 Mdot
.61159 .58697 Mdot
.71533 .06411 Mdot
.05215 .20817 Mdot
.31214 .16068 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47714 .60834 Mdot
.4273 .58723 Mdot
.27215 .52215 Mdot
.88057 .37603 Mdot
.6518 .47664 Mdot
.61773 .59698 Mdot
.74458 .0784 Mdot
.11002 .22586 Mdot
.32327 .13179 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48769 .61281 Mdot
.46079 .60141 Mdot
.37568 .56543 Mdot
.12249 .46155 Mdot
.70317 .35888 Mdot
.51232 .50008 Mdot
.33994 .5115 Mdot
.96595 .38689 Mdot
.4984 .61736 Mdot
.49491 .61588 Mdot
.4838 .61116 Mdot
.44842 .59617 Mdot
.33702 .54918 Mdot
.02168 .42315 Mdot
.67393 .40311 Mdot
.53814 .53412 Mdot
.45903 .56914 Mdot
.31915 .53158 Mdot
.96271 .39774 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58507 .03604 Mdot
.765 .1112 Mdot
.1826 .25809 Mdot
.38256 .12358 Mdot
.42191 .02432 Mdot
.34878 .57283 Mdot
.08143 .4528 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52639 .01119 Mdot
.58388 .03554 Mdot
.76147 .10975 Mdot
.17716 .25691 Mdot
.37869 .12455 Mdot
.41537 .02267 Mdot
.33101 .5659 Mdot
.03819 .43706 Mdot
.68863 .402 Mdot
.499 .61761 Mdot
.4968 .61668 Mdot
.48981 .61371 Mdot
.46753 .60427 Mdot
.39689 .57437 Mdot
.18217 .48533 Mdot
.75008 .35099 Mdot
.55672 .49853 Mdot
.44665 .55 Mdot
.25803 .50146 Mdot
.83099 .35411 Mdot
.49748 .61697 Mdot
.49197 .61463 Mdot
.47443 .60719 Mdot
.41871 .5836 Mdot
.24629 .51147 Mdot
.8352 .36397 Mdot
.62944 .49087 Mdot
.59714 .59807 Mdot
.70168 .06461 Mdot
.03403 .2054 Mdot
.31572 .1741 Mdot
.49999 .61803 Mdot
.49998 .61802 Mdot
.49993 .618 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47554 .60766 Mdot
.42221 .58508 Mdot
.25679 .5158 Mdot
.85286 .36839 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51704 .00723 Mdot
.55424 .02299 Mdot
.67125 .07231 Mdot
.99835 .20216 Mdot
.32793 .20369 Mdot
.44682 .07348 Mdot
.48742 .02509 Mdot
.50917 .01344 Mdot
.54467 .02194 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50658 .00279 Mdot
.52096 .00889 Mdot
.56668 .02826 Mdot
.70951 .08828 Mdot
.0834 .23107 Mdot
.33783 .15725 Mdot
.38898 .03161 Mdot
.28677 .55487 Mdot
.95217 .41124 Mdot
.68824 .45492 Mdot
.49996 .61802 Mdot
.49986 .61798 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48601 .6121 Mdot
.45546 .59915 Mdot
.35896 .5584 Mdot
.07753 .4441 Mdot
.68435 .37503 Mdot
.50987 .5102 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60202 Mdot
.38022 .56734 Mdot
.13502 .46649 Mdot
.71072 .35581 Mdot
.51793 .49888 Mdot
.35196 .51546 Mdot
.9946 .39717 Mdot
.64534 .40218 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50547 .00232 Mdot
.51743 .00739 Mdot
.55549 .02352 Mdot
.6751 .07393 Mdot
.0075 .20543 Mdot
.32865 .19848 Mdot
.43963 .06859 Mdot
.46222 .01396 Mdot
.42868 .5973 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .00029 Mdot
.50221 .00094 Mdot
.50706 .00299 Mdot
.52248 .00953 Mdot
.57151 .0303 Mdot
.72423 .09439 Mdot
.11256 .24 Mdot
.34578 .14414 Mdot
.3822 .02251 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47784 .60864 Mdot
.4295 .58816 Mdot
.27882 .52491 Mdot
.89333 .37978 Mdot
.65612 .47144 Mdot
.61731 .59405 Mdot
.73897 .07519 Mdot
.09879 .22238 Mdot
.31975 .13657 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48803 .61296 Mdot
.46187 .60187 Mdot
.37907 .56686 Mdot
.13182 .46523 Mdot
.70869 .35652 Mdot
.51629 .49913 Mdot
.34828 .5142 Mdot
.98564 .39391 Mdot
.64451 .4072 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47989 .60951 Mdot
.43601 .59091 Mdot
.2987 .53317 Mdot
.93374 .39248 Mdot
.66533 .45214 Mdot
.60265 .5793 Mdot
.6835 .04996 Mdot
.98253 .18481 Mdot
.30772 .20098 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00165 Mdot
.51236 .00524 Mdot
.53936 .01669 Mdot
.62481 .05281 Mdot
.87887 .15702 Mdot
.29758 .25878 Mdot
.48815 .11778 Mdot
.66097 .10681 Mdot
.03614 .23186 Mdot
.35756 .19865 Mdot
.49827 .6173 Mdot
.49448 .61569 Mdot
.48241 .61057 Mdot
.444 .5943 Mdot
.32332 .54345 Mdot
.98879 .41128 Mdot
.67106 .42167 Mdot
.5633 .55143 Mdot
.54801 .60858 Mdot
.60364 .03438 Mdot
.80398 .12382 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .00159 Mdot
.51196 .00507 Mdot
.5381 .01616 Mdot
.62086 .05114 Mdot
.86797 .15272 Mdot
.29118 .26156 Mdot
.48361 .11893 Mdot
.65148 .10375 Mdot
.0138 .22392 Mdot
.35544 .21115 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50346 .00147 Mdot
.51101 .00467 Mdot
.53507 .01487 Mdot
.6113 .04711 Mdot
.8412 .14209 Mdot
.2717 .26606 Mdot
.46569 .11989 Mdot
.6086 .08832 Mdot
.90205 .18137 Mdot
.33333 .26654 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51068 .00453 Mdot
.53402 .01443 Mdot
.60802 .04573 Mdot
.83188 .13835 Mdot
.26357 .2668 Mdot
.4574 .11979 Mdot
.58808 .08077 Mdot
.49988 .61798 Mdot
.4996 .61787 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.48719 .6126 Mdot
.4592 .60074 Mdot
.3707 .56333 Mdot
.10887 .45622 Mdot
.69618 .36298 Mdot
.50871 .50217 Mdot
.33429 .51024 Mdot
.5002 8e-05 Mdot
.50062 .00026 Mdot
.50199 .00084 Mdot
.50633 .00268 Mdot
.52015 .00855 Mdot
.56413 .02718 Mdot
.70173 .08504 Mdot
.06717 .22585 Mdot
.33482 .16541 Mdot
.39683 .03833 Mdot
.31472 .56728 Mdot
.01333 .43177 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.5072 .00305 Mdot
.52294 .00973 Mdot
.57297 .03092 Mdot
.72865 .09622 Mdot
.12093 .24244 Mdot
.34877 .14081 Mdot
.38239 .02078 Mdot
.25521 .53943 Mdot
.88942 .39197 Mdot
.49786 .61713 Mdot
.49317 .61514 Mdot
.47825 .60881 Mdot
.4308 .58871 Mdot
.2828 .52657 Mdot
.90113 .38214 Mdot
.6584 .46802 Mdot
.61595 .5918 Mdot
.73244 .07199 Mdot
.0862 .21864 Mdot
.3169 .14258 Mdot
.49884 .61754 Mdot
.49632 .61647 Mdot
.48827 .61306 Mdot
.46265 .6022 Mdot
.38152 .56789 Mdot
.13863 .46792 Mdot
.71311 .35505 Mdot
.51994 .49865 Mdot
.35661 .51709 Mdot
.00614 .40143 Mdot
.64646 .39574 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00327 Mdot
.52459 .01043 Mdot
.5782 .03313 Mdot
.74445 .10275 Mdot
.14928 .2502 Mdot
.36161 .13123 Mdot
.39155 .0185 Mdot
.27111 .5436 Mdot
.91403 .39735 Mdot
.67973 .47323 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52382 .0101 Mdot
.57577 .03211 Mdot
.73714 .09973 Mdot
.13646 .24679 Mdot
.35526 .13523 Mdot
.38567 .01879 Mdot
.25896 .53972 Mdot
.8939 .39241 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.51511 .00641 Mdot
.54811 .02039 Mdot
.65217 .06432 Mdot
.95127 .18485 Mdot
.32233 .22932 Mdot
.47888 .09675 Mdot
.60385 .07723 Mdot
.87376 .16682 Mdot
.31379 .27196 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .6126 Mdot
.45916 .60072 Mdot
.37054 .56327 Mdot
.10846 .45606 Mdot
.69599 .36311 Mdot
.50864 .50224 Mdot
.33424 .51025 Mdot
.95377 .38289 Mdot
.64168 .42515 Mdot
.4998 .61795 Mdot
.49937 .61777 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.4797 .60943 Mdot
.43541 .59066 Mdot
.29686 .53241 Mdot
.92986 .39121 Mdot
.66469 .45415 Mdot
.60478 .58101 Mdot
.69093 .05324 Mdot
.50053 .00022 Mdot
.50169 .00071 Mdot
.50537 .00228 Mdot
.5171 .00725 Mdot
.55445 .02308 Mdot
.67188 .07258 Mdot
.99986 .2027 Mdot
.32805 .20283 Mdot
.44564 .07267 Mdot
.48326 .02325 Mdot
.49583 .00777 Mdot
.50215 .0039 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50654 .00277 Mdot
.52082 .00883 Mdot
.56624 .02807 Mdot
.70818 .08772 Mdot
.08066 .23021 Mdot
.33726 .15859 Mdot
.39012 .03267 Mdot
.29095 .55674 Mdot
.96091 .41406 Mdot
.68891 .44993 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51427 .00605 Mdot
.54545 .01927 Mdot
.64389 .06083 Mdot
.92992 .17678 Mdot
.31771 .23967 Mdot
.48805 .10528 Mdot
.64049 .09421 Mdot
.97734 .20818 Mdot
.34807 .22912 Mdot
.49834 .61733 Mdot
.49472 .6158 Mdot
.48319 .61091 Mdot
.44649 .59535 Mdot
.33102 .54667 Mdot
.00709 .41784 Mdot
.67253 .41126 Mdot
.54897 .54167 Mdot
.49771 .58635 Mdot
.44302 .58423 Mdot
.30466 .53253 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48497 .61166 Mdot
.45213 .59774 Mdot
.34858 .55403 Mdot
.05064 .4339 Mdot
.67802 .38774 Mdot
.52012 .52045 Mdot
.39232 .53905 Mdot
.11504 .44667 Mdot
.67984 .34906 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47916 .6092 Mdot
.43368 .58993 Mdot
.29157 .53021 Mdot
.91883 .38767 Mdot
.66263 .4597 Mdot
.6101 .58556 Mdot
.70984 .06165 Mdot
.04076 .20452 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.53112 .0132 Mdot
.59887 .04187 Mdot
.80555 .12774 Mdot
.23657 .26639 Mdot
.42971 .11937 Mdot
.52082 .0563 Mdot
.64306 .07555 Mdot
.95213 .19102 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .00291 Mdot
.52183 .00926 Mdot
.56944 .02943 Mdot
.71795 .09178 Mdot
.10036 .23634 Mdot
.34201 .14935 Mdot
.38373 .02578 Mdot
.26615 .54536 Mdot
.91106 .39858 Mdot
.68255 .4768 Mdot
.49787 .61713 Mdot
.49322 .61516 Mdot
.47841 .60888 Mdot
.43132 .58893 Mdot
.28437 .52721 Mdot
.90423 .3831 Mdot
.65923 .46662 Mdot
.61519 .59081 Mdot
.72923 .07048 Mdot
.07997 .21677 Mdot
.31574 .14572 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50244 .00103 Mdot
.50777 .00329 Mdot
.52474 .01049 Mdot
.57866 .03333 Mdot
.74584 .10332 Mdot
.15167 .25082 Mdot
.3629 .13055 Mdot
.39298 .01859 Mdot
.27437 .54473 Mdot
.91981 .39891 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50707 .003 Mdot
.52253 .00955 Mdot
.57168 .03037 Mdot
.72474 .0946 Mdot
.11354 .24029 Mdot
.34611 .14374 Mdot
.38217 .02229 Mdot
.49834 .61733 Mdot
.49473 .6158 Mdot
.4832 .61091 Mdot
.44651 .59536 Mdot
.3311 .5467 Mdot
.00728 .4179 Mdot
.67255 .41116 Mdot
.54883 .54157 Mdot
.49721 .58613 Mdot
.44142 .58355 Mdot
.29972 .53046 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49407 .61552 Mdot
.4811 .61002 Mdot
.43985 .59254 Mdot
.31051 .5381 Mdot
.95949 .40109 Mdot
.66858 .43824 Mdot
.58584 .5669 Mdot
.6257 .02464 Mdot
.83512 .12943 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60957 Mdot
.4365 .59112 Mdot
.30022 .53381 Mdot
.93699 .39355 Mdot
.66583 .45044 Mdot
.60077 .57783 Mdot
.67698 .0471 Mdot
.96724 .17939 Mdot
.30629 .20955 Mdot
.49757 .617 Mdot
.49224 .61475 Mdot
.47529 .60756 Mdot
.42143 .58475 Mdot
.25445 .51483 Mdot
.84883 .36735 Mdot
.63737 .48735 Mdot
.60733 .59946 Mdot
.72635 .07356 Mdot
.08147 .21948 Mdot
.31965 .14721 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51128 .00478 Mdot
.53591 .01523 Mdot
.61396 .04823 Mdot
.8487 .14508 Mdot
.27772 .26515 Mdot
.47162 .11984 Mdot
.62319 .09367 Mdot
.94162 .1968 Mdot
.50042 .00018 Mdot
.50133 .00057 Mdot
.50425 .0018 Mdot
.51354 .00574 Mdot
.5431 .01827 Mdot
.63653 .05774 Mdot
.91055 .16935 Mdot
.31179 .24798 Mdot
.49206 .11142 Mdot
.66044 .10406 Mdot
.03074 .22886 Mdot
.35522 .20054 Mdot
.49755 .61699 Mdot
.49219 .61472 Mdot
.47513 .60749 Mdot
.42092 .58453 Mdot
.25291 .5142 Mdot
.84621 .36668 Mdot
.63593 .48808 Mdot
.60565 .59932 Mdot
.72247 .0722 Mdot
.07446 .21754 Mdot
.31879 .151 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.51369 .0058 Mdot
.54358 .01848 Mdot
.63803 .05837 Mdot
.91452 .17088 Mdot
.31316 .24637 Mdot
.49161 .11029 Mdot
.65749 .10252 Mdot
.0229 .22584 Mdot
.35408 .20468 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51788 .00758 Mdot
.55692 .02413 Mdot
.67953 .07578 Mdot
.01786 .2091 Mdot
.32945 .19258 Mdot
.43145 .06304 Mdot
.43377 .00143 Mdot
.33958 .55982 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.47939 .60929 Mdot
.43442 .59024 Mdot
.29385 .53115 Mdot
.92354 .38917 Mdot
.66356 .45736 Mdot
.60797 .58367 Mdot
.70218 .05823 Mdot
.02443 .19916 Mdot
.31018 .1766 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48669 .61239 Mdot
.4576 .60006 Mdot
.36568 .56122 Mdot
.09536 .45096 Mdot
.6904 .36776 Mdot
.50764 .50508 Mdot
.33633 .51216 Mdot
.96056 .38579 Mdot
.64334 .42198 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .61119 Mdot
.44864 .59626 Mdot
.3377 .54947 Mdot
.02335 .42376 Mdot
.67411 .40219 Mdot
.49812 .61724 Mdot
.49402 .6155 Mdot
.48095 .60995 Mdot
.43936 .59233 Mdot
.309 .53747 Mdot
.95612 .39994 Mdot
.66823 .44011 Mdot
.58825 .56861 Mdot
.63398 .02826 Mdot
.85775 .1383 Mdot
.26761 .2533 Mdot
.49891 .61757 Mdot
.49653 .61656 Mdot
.48895 .61335 Mdot
.46481 .60311 Mdot
.38831 .57076 Mdot
.1577 .47551 Mdot
.72739 .35209 Mdot
.5334 .49815 Mdot
.38916 .52889 Mdot
.09177 .43424 Mdot
.66423 .3538 Mdot
.49926 .61772 Mdot
.49766 .61704 Mdot
.49253 .61487 Mdot
.47622 .60795 Mdot
.42435 .58598 Mdot
.26325 .51847 Mdot
.86424 .37143 Mdot
.64506 .48257 Mdot
.61456 .59919 Mdot
.74145 .07842 Mdot
.10673 .22575 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51224 .00519 Mdot
.53897 .01652 Mdot
.62358 .05229 Mdot
.87548 .15568 Mdot
.29568 .2597 Mdot
.48691 .11819 Mdot
.65855 .10607 Mdot
.03057 .22992 Mdot
.35702 .20176 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52442 .01035 Mdot
.57766 .0329 Mdot
.74283 .10208 Mdot
.14648 .24947 Mdot
.36015 .13205 Mdot
.39001 .01845 Mdot
.2677 .54244 Mdot
.90813 .39581 Mdot
.67884 .47632 Mdot
.49777 .61709 Mdot
.49288 .61501 Mdot
.47732 .60842 Mdot
.42785 .58746 Mdot
.27384 .52285 Mdot
.88376 .37695 Mdot
.65295 .47539 Mdot
.61785 .59634 Mdot
.7438 .07784 Mdot
.1083 .22527 Mdot
.3226 .13245 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50808 .00343 Mdot
.52574 .01091 Mdot
.58184 .03467 Mdot
.75537 .10725 Mdot
.1675 .25471 Mdot
.37226 .12655 Mdot
.40532 .02043 Mdot
.30458 .55578 Mdot
.97902 .41682 Mdot
.68484 .43622 Mdot
.49762 .61702 Mdot
.4924 .61481 Mdot
.4758 .60777 Mdot
.42304 .58543 Mdot
.25928 .51683 Mdot
.8572 .36953 Mdot
.64171 .48486 Mdot
.6118 .59955 Mdot
.73612 .07684 Mdot
.09827 .22382 Mdot
.3222 .1384 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47593 .60783 Mdot
.42345 .5856 Mdot
.26051 .51733 Mdot
.85935 .37011 Mdot
.64277 .48417 Mdot
.61274 .59948 Mdot
.73803 .07743 Mdot
.10137 .22456 Mdot
.32273 .13681 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .0034 Mdot
.52557 .01084 Mdot
.58131 .03445 Mdot
.75377 .10659 Mdot
.1649 .25409 Mdot
.37062 .12714 Mdot
.40294 .01998 Mdot
.29853 .55351 Mdot
.9664 .41277 Mdot
.6843 .44368 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.49131 .61435 Mdot
.47232 .6063 Mdot
.41203 .58077 Mdot
.2264 .50331 Mdot
.80466 .35738 Mdot
.60771 .49631 Mdot
.56026 .58871 Mdot
.60107 .02522 Mdot
.7835 .11275 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51796 .00761 Mdot
.55715 .02422 Mdot
.68024 .07607 Mdot
.01949 .20967 Mdot
.32958 .19165 Mdot
.43016 .06216 Mdot
.42933 .61752 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00822 Mdot
.56172 .02616 Mdot
.69434 .08196 Mdot
.05123 .22057 Mdot
.3326 .1739 Mdot
.40667 .04578 Mdot
.34863 .58216 Mdot
.09626 .46206 Mdot
.70814 .37816 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51542 .00654 Mdot
.54909 .02081 Mdot
.65524 .0656 Mdot
.95903 .18776 Mdot
.3236 .22532 Mdot
.47452 .09327 Mdot
.58738 .06975 Mdot
.82483 .14675 Mdot
.49848 .61739 Mdot
.49517 .61598 Mdot
.4846 .6115 Mdot
.45097 .59725 Mdot
.34495 .55251 Mdot
.04143 .43045 Mdot
.67647 .39248 Mdot
.52521 .52455 Mdot
.41161 .54782 Mdot
.17213 .47003 Mdot
.72193 .33979 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48044 .60974 Mdot
.43774 .59165 Mdot
.30401 .53539 Mdot
.94517 .39626 Mdot
.66696 .44609 Mdot
.49894 .61758 Mdot
.49661 .6166 Mdot
.48919 .61345 Mdot
.46557 .60344 Mdot
.39071 .57177 Mdot
.16448 .47822 Mdot
.73317 .35147 Mdot
.53926 .49819 Mdot
.40363 .53421 Mdot
.13213 .45024 Mdot
.68443 .34134 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51797 .00762 Mdot
.5572 .02425 Mdot
.6804 .07614 Mdot
.01986 .2098 Mdot
.32961 .19144 Mdot
.42987 .06197 Mdot
.42832 .61707 Mdot
.32285 .55285 Mdot
.00322 .42049 Mdot
.49831 .61732 Mdot
.4946 .61574 Mdot
.4828 .61074 Mdot
.44526 .59483 Mdot
.32721 .54508 Mdot
.99798 .41456 Mdot
.67178 .41643 Mdot
.55605 .54651 Mdot
.52266 .5974 Mdot
.52316 .0003 Mdot
.55826 .0217 Mdot
.5004 .00017 Mdot
.50126 .00053 Mdot
.50402 .0017 Mdot
.51279 .00542 Mdot
.54074 .01727 Mdot
.62913 .05463 Mdot
.89064 .16163 Mdot
.30359 .25522 Mdot
.49121 .11596 Mdot
.66565 .10781 Mdot
.04606 .23511 Mdot
.35835 .193 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00136 Mdot
.51025 .00434 Mdot
.53263 .01384 Mdot
.60363 .04388 Mdot
.8193 .1333 Mdot
.25144 .26707 Mdot
.44485 .11953 Mdot
.55717 .06942 Mdot
.75343 .12129 Mdot
.18836 .2688 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50374 .00159 Mdot
.51192 .00505 Mdot
.53795 .01609 Mdot
.62036 .05094 Mdot
.8666 .15218 Mdot
.29032 .26187 Mdot
.48292 .11903 Mdot
.64995 .10323 Mdot
.01006 .22257 Mdot
.3551 .21324 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50715 .00303 Mdot
.52278 .00966 Mdot
.57247 .03071 Mdot
.72714 .09559 Mdot
.11808 .24162 Mdot
.34771 .14192 Mdot
.3822 .02132 Mdot
.2557 .53985 Mdot
.89062 .3924 Mdot
.67699 .48601 Mdot
.49865 .61746 Mdot
.49569 .61621 Mdot
.48628 .61222 Mdot
.45631 .59951 Mdot
.36164 .55952 Mdot
.0846 .44681 Mdot
.68655 .37203 Mdot
.50851 .508 Mdot
.34324 .51589 Mdot
.97904 .39295 Mdot
.64619 .41232 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50263 .00112 Mdot
.50839 .00356 Mdot
.52672 .01133 Mdot
.58493 .03598 Mdot
.76458 .11103 Mdot
.18196 .25795 Mdot
.38209 .12369 Mdot
.4211 .02411 Mdot
.34656 .57196 Mdot
.49964 .61788 Mdot
.49884 .61754 Mdot
.4963 .61646 Mdot
.4882 .61303 Mdot
.46241 .6021 Mdot
.38077 .56758 Mdot
.13655 .4671 Mdot
.71173 .35548 Mdot
.51876 .49878 Mdot
.35387 .51613 Mdot
.99932 .39891 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53635 .01541 Mdot
.61533 .04881 Mdot
.85255 .14661 Mdot
.28064 .26457 Mdot
.47441 .11975 Mdot
.62995 .09613 Mdot
.95947 .20366 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52304 .00977 Mdot
.57327 .03105 Mdot
.72958 .0966 Mdot
.12266 .24294 Mdot
.34943 .14015 Mdot
.38256 .02047 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51554 .00659 Mdot
.54947 .02097 Mdot
.65641 .06609 Mdot
.96198 .18885 Mdot
.32404 .22377 Mdot
.47274 .0919 Mdot
.58075 .06675 Mdot
.80475 .13844 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.4755 .60765 Mdot
.4221 .58503 Mdot
.25645 .51566 Mdot
.85226 .36823 Mdot
.6392 .48635 Mdot
.60932 .59957 Mdot
.73083 .07509 Mdot
.08934 .22157 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50451 .00191 Mdot
.51435 .00609 Mdot
.5457 .01937 Mdot
.64466 .06116 Mdot
.93195 .17755 Mdot
.31823 .23873 Mdot
.48738 .10454 Mdot
.63762 .09285 Mdot
.96952 .20512 Mdot
.49983 .61796 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49441 .61567 Mdot
.4822 .61049 Mdot
.44335 .59402 Mdot
.32131 .54261 Mdot
.98411 .40963 Mdot
.6707 .42434 Mdot
.567 .55394 Mdot
.56086 .61424 Mdot
.50007 3e-05 Mdot
.50022 .0001 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52317 .00983 Mdot
.5737 .03123 Mdot
.73088 .09714 Mdot
.12507 .24362 Mdot
.35038 .13925 Mdot
.38288 .02009 Mdot
.25512 .53908 Mdot
.49935 .61776 Mdot
.49793 .61716 Mdot
.4934 .61524 Mdot
.47898 .60912 Mdot
.43313 .5897 Mdot
.2899 .52951 Mdot
.9154 .38658 Mdot
.66191 .46137 Mdot
.6115 .58688 Mdot
.715 .06397 Mdot
.05149 .20796 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48652 .61232 Mdot
.45709 .59984 Mdot
.36407 .56054 Mdot
.09105 .4493 Mdot
.68879 .36942 Mdot
.50781 .50618 Mdot
.33855 .51342 Mdot
.96655 .38813 Mdot
.64436 .41891 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52314 .00981 Mdot
.57361 .03119 Mdot
.73061 .09703 Mdot
.12457 .24348 Mdot
.35018 .13943 Mdot
.3828 .02016 Mdot
.25509 .5391 Mdot
.88877 .39163 Mdot
.67604 .48656 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.503 .00127 Mdot
.50955 .00405 Mdot
.53043 .0129 Mdot
.59668 .04094 Mdot
.7992 .12516 Mdot
.22914 .26571 Mdot
.42239 .11943 Mdot
.50377 .0503 Mdot
.59082 .0538 Mdot
.80682 .1335 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50478 .00203 Mdot
.51523 .00646 Mdot
.54849 .02056 Mdot
.65338 .06482 Mdot
.95434 .186 Mdot
.32285 .22775 Mdot
.47722 .0954 Mdot
.59752 .07435 Mdot
.85511 .1592 Mdot
.30124 .27572 Mdot
.49756 .617 Mdot
.49223 .61474 Mdot
.47526 .60754 Mdot
.42133 .5847 Mdot
.25414 .51471 Mdot
.8483 .36721 Mdot
.63708 .4875 Mdot
.607 .59944 Mdot
.72559 .07329 Mdot
.08012 .21911 Mdot
.31948 .14793 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48938 .61353 Mdot
.46618 .6037 Mdot
.39264 .57258 Mdot
.17001 .48044 Mdot
.73816 .35114 Mdot
.54439 .49828 Mdot
.41634 .5389 Mdot
.16851 .46487 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.4937 .61536 Mdot
.47992 .60952 Mdot
.43609 .59095 Mdot
.29896 .53328 Mdot
.9343 .39266 Mdot
.66542 .45186 Mdot
.60234 .57905 Mdot
.68241 .04949 Mdot
.98001 .18392 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50751 .00318 Mdot
.52392 .01014 Mdot
.57609 .03224 Mdot
.73809 .10012 Mdot
.13816 .24726 Mdot
.35605 .13466 Mdot
.38628 .01868 Mdot
.26008 .54004 Mdot
.89562 .39279 Mdot
.67675 .48276 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00255 Mdot
.51912 .00811 Mdot
.56086 .02579 Mdot
.69167 .08085 Mdot
.04535 .21859 Mdot
.33193 .17711 Mdot
.41071 .04869 Mdot
.36246 .58822 Mdot
.13265 .476 Mdot
.72611 .36678 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50331 .0014 Mdot
.51054 .00447 Mdot
.53358 .01424 Mdot
.60662 .04514 Mdot
.82789 .13675 Mdot
.25987 .26698 Mdot
.45358 .11972 Mdot
.57864 .07729 Mdot
.81691 .14726 Mdot
.27313 .28196 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53223 .01367 Mdot
.60236 .04334 Mdot
.81566 .13183 Mdot
.24767 .26699 Mdot
.44096 .11946 Mdot
.54772 .06598 Mdot
.72499 .10956 Mdot
.13806 .25529 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48534 .61182 Mdot
.45334 .59825 Mdot
.35233 .55561 Mdot
.06027 .43753 Mdot
.67995 .38298 Mdot
.5156 .51646 Mdot
.37462 .5309 Mdot
.06442 .42632 Mdot
.66021 .36822 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.523 .00975 Mdot
.57317 .03101 Mdot
.72928 .09648 Mdot
.1221 .24277 Mdot
.34921 .14036 Mdot
.3825 .02057 Mdot
.25511 .5393 Mdot
.88911 .39183 Mdot
.67631 .48652 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49234 .61478 Mdot
.47558 .60768 Mdot
.42235 .58513 Mdot
.25721 .51597 Mdot
.85358 .36858 Mdot
.63988 .48596 Mdot
.61002 .59958 Mdot
.73236 .07561 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48082 .6099 Mdot
.43896 .59216 Mdot
.30777 .53695 Mdot
.9534 .39902 Mdot
.66794 .44161 Mdot
.59017 .56997 Mdot
.64053 .03113 Mdot
.87534 .14512 Mdot
.2786 .24923 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50493 .00209 Mdot
.51572 .00666 Mdot
.55004 .02121 Mdot
.65818 .06684 Mdot
.96641 .1905 Mdot
.32465 .22141 Mdot
.46995 .0898 Mdot
.57044 .06211 Mdot
.77317 .12529 Mdot
.21211 .27128 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49276 .61496 Mdot
.47693 .60825 Mdot
.42661 .58694 Mdot
.27006 .52128 Mdot
.87668 .37491 Mdot
.65031 .47813 Mdot
.61736 .59767 Mdot
.74494 .07884 Mdot
.11112 .22631 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52355 .00998 Mdot
.57489 .03173 Mdot
.73448 .09863 Mdot
.13167 .24548 Mdot
.35312 .13686 Mdot
.38423 .01922 Mdot
.25659 .53915 Mdot
.89043 .39173 Mdot
.67594 .48547 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50832 .00353 Mdot
.52649 .01123 Mdot
.58423 .03568 Mdot
.76249 .11017 Mdot
.17875 .25726 Mdot
.3798 .12426 Mdot
.41721 .02312 Mdot
.33597 .56782 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48961 .61363 Mdot
.4669 .604 Mdot
.39489 .57353 Mdot
.17642 .48302 Mdot
.74429 .35096 Mdot
.55073 .49841 Mdot
.43198 .54464 Mdot
.21428 .48349 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50468 .00199 Mdot
.51492 .00633 Mdot
.54751 .02014 Mdot
.6503 .06353 Mdot
.94649 .18306 Mdot
.32144 .23174 Mdot
.48132 .09881 Mdot
.61324 .08153 Mdot
.90104 .17787 Mdot
.3279 .26382 Mdot
.49987 .61798 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49565 .61619 Mdot
.48615 .61216 Mdot
.45589 .59933 Mdot
.3603 .55896 Mdot
.08106 .44545 Mdot
.68542 .37351 Mdot
.50912 .50907 Mdot
.34649 .51752 Mdot
.49741 .61693 Mdot
.49173 .61453 Mdot
.47366 .60687 Mdot
.41627 .58256 Mdot
.239 .50847 Mdot
.82357 .36128 Mdot
.62181 .49334 Mdot
.58545 .59556 Mdot
.6712 .05299 Mdot
.96701 .18282 Mdot
.31195 .21319 Mdot
.4977 .61706 Mdot
.49268 .61493 Mdot
.47667 .60814 Mdot
.42579 .58659 Mdot
.26759 .52026 Mdot
.87212 .37362 Mdot
.64848 .47982 Mdot
.61664 .59835 Mdot
.7445 .07902 Mdot
.11095 .22648 Mdot
.32413 .13175 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.5055 .00233 Mdot
.51754 .00744 Mdot
.55582 .02366 Mdot
.67614 .07436 Mdot
.00993 .2063 Mdot
.32884 .19709 Mdot
.43771 .06728 Mdot
.45551 .011 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00091 Mdot
.50687 .00291 Mdot
.5219 .00929 Mdot
.56967 .02952 Mdot
.71863 .09206 Mdot
.10169 .23675 Mdot
.34239 .14876 Mdot
.38347 .02538 Mdot
.26494 .54478 Mdot
.49909 .61765 Mdot
.4971 .61681 Mdot
.49077 .61412 Mdot
.47061 .60557 Mdot
.40661 .57848 Mdot
.21043 .49679 Mdot
.78286 .35378 Mdot
.58895 .49819 Mdot
.52162 .57642 Mdot
.48661 .5964 Mdot
.43156 .58401 Mdot
.49883 .61754 Mdot
.49627 .61645 Mdot
.4881 .61299 Mdot
.46211 .60197 Mdot
.37982 .56718 Mdot
.13391 .46605 Mdot
.71001 .35605 Mdot
.51734 .49896 Mdot
.35064 .51501 Mdot
.99137 .39599 Mdot
.64504 .40399 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47958 .60937 Mdot
.43502 .59049 Mdot
.29568 .53191 Mdot
.92736 .3904 Mdot
.66426 .45543 Mdot
.49791 .61715 Mdot
.49335 .61522 Mdot
.47882 .60905 Mdot
.43262 .58948 Mdot
.28835 .52887 Mdot
.91224 .38558 Mdot
.6612 .46288 Mdot
.61269 .58805 Mdot
.71944 .06598 Mdot
.06054 .21081 Mdot
.313 .15603 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52374 .01007 Mdot
.57551 .032 Mdot
.73635 .0994 Mdot
.13505 .24641 Mdot
.35462 .1357 Mdot
.38521 .0189 Mdot
.25815 .53951 Mdot
.89267 .39216 Mdot
.67626 .48429 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49084 .61415 Mdot
.47083 .60567 Mdot
.40731 .57878 Mdot
.21249 .49763 Mdot
.78554 .35416 Mdot
.59139 .49804 Mdot
.52692 .57819 Mdot
.50262 .60302 Mdot
.48226 .60545 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.50231 .00098 Mdot
.50735 .00312 Mdot
.5234 .00992 Mdot
.57444 .03154 Mdot
.73312 .09807 Mdot
.12918 .24478 Mdot
.35206 .13775 Mdot
.38363 .01951 Mdot
.2558 .53903 Mdot
.88939 .39158 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49495 .61589 Mdot
.4839 .61121 Mdot
.44874 .5963 Mdot
.33801 .5496 Mdot
.02412 .42404 Mdot
.67419 .40177 Mdot
.53643 .53289 Mdot
.45282 .56636 Mdot
.29948 .52326 Mdot
.49872 .61749 Mdot
.49591 .6163 Mdot
.48696 .6125 Mdot
.45847 .60043 Mdot
.36839 .56236 Mdot
.10263 .45379 Mdot
.69338 .3651 Mdot
.50791 .50341 Mdot
.33429 .51073 Mdot
.95465 .3834 Mdot
.64212 .42488 Mdot
.49791 .61715 Mdot
.49336 .61522 Mdot
.47883 .60906 Mdot
.43265 .58949 Mdot
.28844 .52891 Mdot
.91242 .38564 Mdot
.66124 .4628 Mdot
.61262 .58799 Mdot
.71919 .06586 Mdot
.06003 .21065 Mdot
.31294 .15631 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00147 Mdot
.51101 .00467 Mdot
.53506 .01486 Mdot
.61127 .0471 Mdot
.84113 .14206 Mdot
.27164 .26607 Mdot
.46562 .11989 Mdot
.60844 .08827 Mdot
.90162 .18119 Mdot
.33315 .2667 Mdot
.50074 .00031 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52402 .01018 Mdot
.57638 .03236 Mdot
.73897 .10049 Mdot
.13972 .24768 Mdot
.35679 .13416 Mdot
.38688 .0186 Mdot
.26123 .54038 Mdot
.89744 .3932 Mdot
.67706 .48183 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47947 .60933 Mdot
.43468 .59035 Mdot
.29465 .53149 Mdot
.92521 .38971 Mdot
.66387 .45652 Mdot
.60716 .58298 Mdot
.69931 .05695 Mdot
.01819 .19708 Mdot
.30984 .18025 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48978 .6137 Mdot
.46745 .60423 Mdot
.39665 .57427 Mdot
.18148 .48506 Mdot
.74937 .35097 Mdot
.55599 .49852 Mdot
.44486 .54935 Mdot
.25267 .49925 Mdot
.82178 .35173 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47318 .60666 Mdot
.41475 .58192 Mdot
.23447 .50662 Mdot
.8166 .35977 Mdot
.61686 .49459 Mdot
.57707 .59344 Mdot
.64842 .0441 Mdot
.91151 .1626 Mdot
.49742 .61694 Mdot
.49178 .61455 Mdot
.47381 .60693 Mdot
.41672 .58275 Mdot
.24034 .50902 Mdot
.82566 .36175 Mdot
.62325 .49293 Mdot
.58777 .59611 Mdot
.67738 .05538 Mdot
.9813 .18783 Mdot
.3132 .20513 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50353 .0015 Mdot
.51124 .00477 Mdot
.53581 .01518 Mdot
.61365 .0481 Mdot
.84783 .14473 Mdot
.27704 .26527 Mdot
.47097 .11985 Mdot
.62158 .09309 Mdot
.93735 .19515 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50619 .00262 Mdot
.51971 .00836 Mdot
.56273 .02658 Mdot
.69741 .08324 Mdot
.05792 .2228 Mdot
.33345 .17029 Mdot
.40232 .04257 Mdot
.33371 .57563 Mdot
.05863 .44803 Mdot
.69758 .39489 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50333 .00141 Mdot
.51061 .0045 Mdot
.53379 .01432 Mdot
.60726 .04541 Mdot
.82973 .13749 Mdot
.26159 .26691 Mdot
.45536 .11975 Mdot
.58303 .07891 Mdot
.82968 .15244 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50584 .00248 Mdot
.51862 .00789 Mdot
.55926 .02512 Mdot
.68674 .07879 Mdot
.03434 .21483 Mdot
.33083 .18324 Mdot
.41872 .05432 Mdot
.38993 .60024 Mdot
.5001 4e-05 Mdot
.50032 .00013 Mdot
.501 .00043 Mdot
.5032 .00136 Mdot
.5102 .00433 Mdot
.53249 .01378 Mdot
.60318 .04369 Mdot
.81803 .13278 Mdot
.25013 .26705 Mdot
.4435 .11951 Mdot
.55388 .06822 Mdot
.74356 .11723 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50514 .00218 Mdot
.51638 .00694 Mdot
.55214 .0221 Mdot
.66471 .06957 Mdot
.98254 .19643 Mdot
.32651 .21258 Mdot
.45881 .08176 Mdot
.53 .044 Mdot
.64591 .07164 Mdot
.9513 .18874 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.4203 .58427 Mdot
.25106 .51343 Mdot
.84309 .36589 Mdot
.63416 .48891 Mdot
.60349 .59907 Mdot
.71733 .07036 Mdot
.06489 .21481 Mdot
.31779 .1563 Mdot
.50081 .00035 Mdot
.5026 .0011 Mdot
.50827 .00351 Mdot
.52634 .01117 Mdot
.58374 .03548 Mdot
.76104 .10958 Mdot
.1765 .25677 Mdot
.37823 .12468 Mdot
.41462 .02249 Mdot
.32899 .56511 Mdot
.03343 .43537 Mdot
.68809 .4046 Mdot
.4986 .61744 Mdot
.49553 .61614 Mdot
.48576 .612 Mdot
.45466 .59881 Mdot
.35646 .55735 Mdot
.07098 .4416 Mdot
.68252 .37795 Mdot
.51166 .51244 Mdot
.35828 .52324 Mdot
.01931 .40854 Mdot
.65145 .39069 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50512 .00217 Mdot
.51631 .00692 Mdot
.55192 .02201 Mdot
.66402 .06929 Mdot
.98087 .19582 Mdot
.32634 .21351 Mdot
.46002 .08262 Mdot
.53437 .04595 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50573 .00243 Mdot
.51827 .00775 Mdot
.55815 .02465 Mdot
.68332 .07736 Mdot
.02659 .21215 Mdot
.33015 .18762 Mdot
.42463 .05839 Mdot
.41024 .60914 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50655 .00278 Mdot
.52085 .00884 Mdot
.56635 .02812 Mdot
.70852 .08787 Mdot
.08136 .23043 Mdot
.33741 .15824 Mdot
.38982 .0324 Mdot
.28986 .55626 Mdot
.95862 .41331 Mdot
.68875 .45124 Mdot
.49889 .61756 Mdot
.49645 .61653 Mdot
.48868 .61323 Mdot
.46396 .60275 Mdot
.38562 .56962 Mdot
.15012 .47248 Mdot
.72137 .35305 Mdot
.5275 .49822 Mdot
.37468 .52358 Mdot
.0527 .41904 Mdot
.65311 .37107 Mdot
.49843 .61737 Mdot
.49501 .61592 Mdot
.4841 .61129 Mdot
.44937 .59657 Mdot
.33996 .55042 Mdot
.02895 .42582 Mdot
.67476 .39913 Mdot
.5331 .53049 Mdot
.44075 .56096 Mdot
.26157 .50729 Mdot
.84428 .36014 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50663 .00281 Mdot
.52112 .00896 Mdot
.5672 .02848 Mdot
.7111 .08894 Mdot
.08663 .23209 Mdot
.33854 .15569 Mdot
.38772 .03039 Mdot
.28211 .55276 Mdot
.9426 .40821 Mdot
.68734 .46027 Mdot
.49993 .618 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.4923 .61477 Mdot
.47546 .60763 Mdot
.42198 .58498 Mdot
.25608 .51551 Mdot
.85163 .36807 Mdot
.63887 .48654 Mdot
.60897 .59955 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47506 .60746 Mdot
.42069 .58443 Mdot
.25223 .51392 Mdot
.84505 .36639 Mdot
.63528 .48839 Mdot
.60487 .59924 Mdot
.72063 .07154 Mdot
.07107 .21658 Mdot
.31841 .15286 Mdot
.49789 .61714 Mdot
.49328 .61519 Mdot
.4786 .60896 Mdot
.43191 .58918 Mdot
.28617 .52796 Mdot
.90783 .38421 Mdot
.66015 .46496 Mdot
.61416 .58961 Mdot
.72509 .06856 Mdot
.07183 .2143 Mdot
.31445 .14995 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48345 .61101 Mdot
.4473 .5957 Mdot
.33355 .54773 Mdot
.01321 .42005 Mdot
.67308 .40782 Mdot
.54433 .53847 Mdot
.48124 .57904 Mdot
.39006 .56168 Mdot
.14677 .46767 Mdot
.50006 2e-05 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51918 .00813 Mdot
.56105 .02587 Mdot
.69226 .08109 Mdot
.04666 .21903 Mdot
.33207 .17639 Mdot
.40979 .04803 Mdot
.35933 .58685 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50698 .00296 Mdot
.52225 .00944 Mdot
.57078 .03 Mdot
.72203 .09347 Mdot
.10833 .23875 Mdot
.3444 .1459 Mdot
.3825 .02355 Mdot
.25994 .54228 Mdot
.8991 .39503 Mdot
.67968 .48242 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.51548 .00656 Mdot
.54929 .02089 Mdot
.65586 .06586 Mdot
.96059 .18834 Mdot
.32384 .2245 Mdot
.47359 .09255 Mdot
.58389 .06817 Mdot
.8143 .1424 Mdot
.26421 .27806 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51853 .00786 Mdot
.55898 .025 Mdot
.68588 .07843 Mdot
.03241 .21417 Mdot
.33066 .18433 Mdot
.42017 .05533 Mdot
.39491 .60242 Mdot
.22322 .51193 Mdot
.81618 .36646 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51442 .00611 Mdot
.54591 .01946 Mdot
.64531 .06143 Mdot
.93363 .17819 Mdot
.31865 .23795 Mdot
.48679 .10392 Mdot
.63515 .09169 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49206 .61467 Mdot
.47469 .6073 Mdot
.41953 .58394 Mdot
.24874 .51248 Mdot
.83923 .36494 Mdot
.6319 .4899 Mdot
.60054 .59865 Mdot
.71016 .06775 Mdot
.05107 .2107 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50704 .00299 Mdot
.52244 .00951 Mdot
.57137 .03024 Mdot
.7238 .09421 Mdot
.11175 .23976 Mdot
.34551 .14447 Mdot
.38224 .0227 Mdot
.25802 .54126 Mdot
.89536 .3939 Mdot
.6786 .48407 Mdot
.49887 .61756 Mdot
.4964 .61651 Mdot
.48853 .61317 Mdot
.46348 .60255 Mdot
.38414 .569 Mdot
.14595 .47083 Mdot
.71826 .3537 Mdot
.52456 .49832 Mdot
.36756 .521 Mdot
.03406 .41192 Mdot
.64985 .38058 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50824 .00349 Mdot
.52625 .01113 Mdot
.58346 .03536 Mdot
.76019 .10923 Mdot
.17516 .25647 Mdot
.37731 .12494 Mdot
.41313 .02213 Mdot
.32501 .56357 Mdot
.02419 .43211 Mdot
.68722 .40978 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00207 Mdot
.51552 .00658 Mdot
.54942 .02095 Mdot
.65626 .06603 Mdot
.9616 .18871 Mdot
.32399 .22397 Mdot
.47297 .09208 Mdot
.58161 .06714 Mdot
.80737 .13953 Mdot
.25652 .27759 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.47939 .6093 Mdot
.43443 .59025 Mdot
.29388 .53117 Mdot
.92361 .38919 Mdot
.66358 .45733 Mdot
.60794 .58365 Mdot
.70207 .05818 Mdot
.0242 .19908 Mdot
.31017 .17674 Mdot
.49871 .61749 Mdot
.4959 .61629 Mdot
.48693 .61249 Mdot
.45839 .60039 Mdot
.36814 .56226 Mdot
.10195 .45352 Mdot
.69309 .36534 Mdot
.50785 .50355 Mdot
.33439 .51083 Mdot
.95498 .38354 Mdot
.6422 .42473 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52657 .01127 Mdot
.58448 .03579 Mdot
.76323 .11048 Mdot
.1799 .25751 Mdot
.38061 .12405 Mdot
.41858 .02346 Mdot
.33967 .56927 Mdot
.05894 .44453 Mdot
.6918 .39113 Mdot
.5001 4e-05 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50309 .00131 Mdot
.50986 .00418 Mdot
.5314 .01331 Mdot
.59975 .04224 Mdot
.8081 .12877 Mdot
.23946 .26659 Mdot
.43261 .11937 Mdot
.52766 .05875 Mdot
.66399 .08426 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51419 .00602 Mdot
.54518 .01915 Mdot
.64304 .06048 Mdot
.92771 .17594 Mdot
.31713 .24067 Mdot
.48873 .10606 Mdot
.64346 .09562 Mdot
.98539 .21133 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.5037 .00157 Mdot
.5118 .005 Mdot
.53759 .01594 Mdot
.61922 .05046 Mdot
.86343 .15093 Mdot
.28827 .26256 Mdot
.48123 .11926 Mdot
.64611 .1019 Mdot
.00064 .21911 Mdot
.35421 .21852 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47906 .60915 Mdot
.43336 .58979 Mdot
.2906 .5298 Mdot
.91683 .38703 Mdot
.66222 .46067 Mdot
.61093 .58634 Mdot
.71289 .06301 Mdot
.04712 .20656 Mdot
.3117 .16352 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48774 .61284 Mdot
.46097 .60149 Mdot
.37622 .56566 Mdot
.12398 .46214 Mdot
.70401 .35848 Mdot
.51287 .49991 Mdot
.34103 .51183 Mdot
.96845 .38777 Mdot
.64289 .41682 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.4799 .60951 Mdot
.43603 .59092 Mdot
.29878 .53321 Mdot
.93392 .39254 Mdot
.66536 .45205 Mdot
.60255 .57922 Mdot
.68315 .04981 Mdot
.98172 .18453 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50545 .00231 Mdot
.51735 .00736 Mdot
.55522 .02341 Mdot
.67427 .07358 Mdot
.00553 .20473 Mdot
.3285 .1996 Mdot
.44119 .06964 Mdot
.46765 .01635 Mdot
.44591 .6046 Mdot
.34459 .55542 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50648 .00275 Mdot
.52065 .00875 Mdot
.5657 .02784 Mdot
.70651 .08703 Mdot
.07721 .2291 Mdot
.33658 .1603 Mdot
.39168 .03405 Mdot
.29655 .55924 Mdot
.97284 .41797 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48602 .61211 Mdot
.45548 .59916 Mdot
.35903 .55843 Mdot
.07772 .44417 Mdot
.6844 .37495 Mdot
.50983 .51014 Mdot
.34999 .51925 Mdot
.99701 .39988 Mdot
.64851 .40265 Mdot
.49886 .61755 Mdot
.49637 .61649 Mdot
.48843 .61313 Mdot
.46314 .60241 Mdot
.38305 .56854 Mdot
.14291 .46962 Mdot
.71607 .35423 Mdot
.52256 .49844 Mdot
.36277 .51928 Mdot
.02171 .40725 Mdot
.64819 .38719 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52305 .00977 Mdot
.57331 .03106 Mdot
.72969 .09665 Mdot
.12285 .24299 Mdot
.3495 .14008 Mdot
.38258 .02044 Mdot
.25507 .53923 Mdot
.88895 .39176 Mdot
.49783 .61711 Mdot
.49307 .6151 Mdot
.47793 .60867 Mdot
.42977 .58827 Mdot
.27967 .52526 Mdot
.89496 .38027 Mdot
.65662 .47073 Mdot
.61709 .5936 Mdot
.73778 .07459 Mdot
.0965 .2217 Mdot
.31918 .13762 Mdot
.49906 .61763 Mdot
.497 .61676 Mdot
.49043 .61398 Mdot
.46953 .60511 Mdot
.40319 .57704 Mdot
.20044 .49272 Mdot
.77043 .35228 Mdot
.5772 .49861 Mdot
.49526 .5674 Mdot
.40623 .56301 Mdot
.18454 .48102 Mdot
.49996 .61802 Mdot
.49988 .61798 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48746 .61272 Mdot
.46007 .6011 Mdot
.3734 .56447 Mdot
.11622 .45909 Mdot
.6998 .36067 Mdot
.51034 .50094 Mdot
.50048 .0002 Mdot
.50151 .00064 Mdot
.50482 .00205 Mdot
.51537 .00652 Mdot
.54894 .02074 Mdot
.65475 .0654 Mdot
.95781 .1873 Mdot
.32341 .22596 Mdot
.47524 .09383 Mdot
.59007 .07097 Mdot
.8329 .15008 Mdot
.2828 .27806 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53218 .01364 Mdot
.60219 .04327 Mdot
.81517 .13163 Mdot
.24715 .26698 Mdot
.44043 .11946 Mdot
.54644 .06551 Mdot
.72111 .10795 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52504 .01062 Mdot
.57963 .03374 Mdot
.74874 .10452 Mdot
.15658 .25206 Mdot
.36565 .12921 Mdot
.39627 .01893 Mdot
.2821 .54747 Mdot
.93403 .40291 Mdot
.68211 .46234 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51224 .00519 Mdot
.53899 .01653 Mdot
.62365 .05232 Mdot
.87567 .15576 Mdot
.29579 .25965 Mdot
.48699 .11817 Mdot
.6587 .10612 Mdot
.03091 .23004 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51728 .00733 Mdot
.55499 .02331 Mdot
.67357 .07328 Mdot
.00387 .20414 Mdot
.32837 .20055 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50358 .00152 Mdot
.51142 .00484 Mdot
.53637 .01542 Mdot
.61541 .04885 Mdot
.85279 .14671 Mdot
.28082 .26453 Mdot
.47458 .11975 Mdot
.63036 .09628 Mdot
.96054 .20406 Mdot
.49831 .61732 Mdot
.49462 .61575 Mdot
.48286 .61076 Mdot
.44543 .5949 Mdot
.32773 .54529 Mdot
.99921 .415 Mdot
.67188 .41573 Mdot
.55508 .54585 Mdot
.51928 .5959 Mdot
.51231 .61373 Mdot
.5238 .0071 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49294 .61504 Mdot
.47749 .60849 Mdot
.42841 .5877 Mdot
.27552 .52354 Mdot
.88696 .37789 Mdot
.65406 .47409 Mdot
.61782 .59563 Mdot
.74259 .07711 Mdot
.49868 .61747 Mdot
.49578 .61625 Mdot
.48657 .61234 Mdot
.45722 .5999 Mdot
.36448 .56072 Mdot
.09216 .44973 Mdot
.68919 .36899 Mdot
.50774 .50589 Mdot
.33791 .51307 Mdot
.96484 .38746 Mdot
.64408 .4198 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50368 .00156 Mdot
.51171 .00497 Mdot
.53729 .01581 Mdot
.6183 .05007 Mdot
.86087 .14992 Mdot
.28655 .26308 Mdot
.47977 .11941 Mdot
.64271 .10071 Mdot
.99217 .21598 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.52048 .00868 Mdot
.56517 .02762 Mdot
.70491 .08636 Mdot
.07387 .22803 Mdot
.33596 .16198 Mdot
.39329 .03544 Mdot
.3023 .56179 Mdot
.98534 .42214 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52 .00848 Mdot
.56363 .02697 Mdot
.70019 .0844 Mdot
.06388 .22477 Mdot
.3343 .16713 Mdot
.39871 .03981 Mdot
.32124 .57015 Mdot
.02855 .43714 Mdot
.69327 .41082 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50457 .00194 Mdot
.51455 .00617 Mdot
.54633 .01964 Mdot
.64661 .06198 Mdot
.93701 .17947 Mdot
.31944 .23636 Mdot
.48551 .10264 Mdot
.62988 .08923 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49795 .61717 Mdot
.49348 .61527 Mdot
.47922 .60922 Mdot
.43389 .59002 Mdot
.29221 .53047 Mdot
.92015 .38809 Mdot
.6629 .45904 Mdot
.60952 .58504 Mdot
.70775 .06071 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41914 .58378 Mdot
.24758 .512 Mdot
.83731 .36447 Mdot
.63074 .49037 Mdot
.59896 .59839 Mdot
.70625 .0663 Mdot
.0433 .20831 Mdot
.49996 .61802 Mdot
.49989 .61799 Mdot
.49964 .61788 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48832 .61308 Mdot
.46281 .60227 Mdot
.38203 .56811 Mdot
.14005 .46848 Mdot
.71408 .35477 Mdot
.52078 .49857 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50338 .00143 Mdot
.51075 .00456 Mdot
.53425 .01452 Mdot
.60872 .04603 Mdot
.83389 .13916 Mdot
.26539 .26668 Mdot
.45927 .11982 Mdot
.59271 .08247 Mdot
.8575 .16364 Mdot
.3086 .2788 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51814 .00769 Mdot
.55774 .02447 Mdot
.68205 .07683 Mdot
.02366 .21113 Mdot
.32991 .18927 Mdot
.4269 .05994 Mdot
.41805 .61256 Mdot
.29164 .53991 Mdot
.93461 .39738 Mdot
.49796 .61717 Mdot
.49351 .61528 Mdot
.47933 .60927 Mdot
.43424 .59016 Mdot
.29328 .53092 Mdot
.92237 .3888 Mdot
.66334 .45794 Mdot
.60852 .58415 Mdot
.70415 .0591 Mdot
.02867 .20057 Mdot
.31042 .17413 Mdot
.49848 .61739 Mdot
.49515 .61598 Mdot
.48455 .61148 Mdot
.4508 .59718 Mdot
.34441 .55228 Mdot
.04007 .42994 Mdot
.67626 .39319 Mdot
.52601 .52518 Mdot
.41461 .54919 Mdot
.18119 .47377 Mdot
.731 .3398 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47685 .60822 Mdot
.42638 .58684 Mdot
.26936 .52099 Mdot
.87537 .37454 Mdot
.6498 .47862 Mdot
.61719 .59788 Mdot
.74491 .07893 Mdot
.11123 .2264 Mdot
.32397 .13148 Mdot
.50042 .00018 Mdot
.50133 .00057 Mdot
.50425 .0018 Mdot
.51355 .00575 Mdot
.54315 .01829 Mdot
.63667 .0578 Mdot
.91092 .16949 Mdot
.31192 .24783 Mdot
.49203 .11131 Mdot
.66019 .10393 Mdot
.03008 .2286 Mdot
.35511 .20088 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50489 .00207 Mdot
.51556 .0066 Mdot
.54955 .02101 Mdot
.65668 .06621 Mdot
.96266 .18911 Mdot
.32414 .22341 Mdot
.47232 .09158 Mdot
.5792 .06605 Mdot
.80003 .13648 Mdot
.2479 .2768 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50364 .00154 Mdot
.5116 .00492 Mdot
.53695 .01566 Mdot
.61721 .04961 Mdot
.85784 .14871 Mdot
.28446 .26367 Mdot
.47792 .11957 Mdot
.63836 .09916 Mdot
.98116 .21187 Mdot
.35216 .22929 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48815 .61301 Mdot
.46226 .60203 Mdot
.38027 .56737 Mdot
.13517 .46655 Mdot
.71082 .35577 Mdot
.51801 .49887 Mdot
.35215 .51553 Mdot
.99506 .39734 Mdot
.64538 .40192 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48371 .61113 Mdot
.44814 .59605 Mdot
.33616 .54883 Mdot
.01959 .42238 Mdot
.67371 .40427 Mdot
.53965 .53518 Mdot
.46444 .57155 Mdot
.33634 .53886 Mdot
.00378 .4125 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.50539 .00229 Mdot
.51719 .00729 Mdot
.55471 .02319 Mdot
.67269 .07291 Mdot
.00178 .20339 Mdot
.3282 .20174 Mdot
.44414 .07165 Mdot
.47798 .02092 Mdot
.47892 .00058 Mdot
.44831 .59912 Mdot
.49814 .61724 Mdot
.49406 .61552 Mdot
.48109 .61002 Mdot
.43982 .59253 Mdot
.31041 .53806 Mdot
.95927 .40102 Mdot
.66856 .43836 Mdot
.58599 .56701 Mdot
.62623 .02487 Mdot
.83658 .13 Mdot
.2512 .25625 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51465 .00621 Mdot
.54664 .01977 Mdot
.6476 .0624 Mdot
.93956 .18044 Mdot
.32002 .23514 Mdot
.48447 .10164 Mdot
.62567 .08727 Mdot
.9364 .19204 Mdot
.34001 .24944 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52165 .00918 Mdot
.56886 .02918 Mdot
.71619 .09105 Mdot
.09687 .23528 Mdot
.34106 .15091 Mdot
.38453 .02687 Mdot
.26959 .547 Mdot
.91773 .40057 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50766 .00325 Mdot
.52442 .01035 Mdot
.57765 .0329 Mdot
.74279 .10206 Mdot
.14641 .24945 Mdot
.36011 .13207 Mdot
.38997 .01845 Mdot
.26762 .54242 Mdot
.908 .39578 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50998 .00423 Mdot
.53177 .01347 Mdot
.60091 .04273 Mdot
.81148 .13014 Mdot
.24319 .26681 Mdot
.43639 .1194 Mdot
.53668 .06199 Mdot
.69152 .09569 Mdot
.06914 .23339 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50451 .00191 Mdot
.51436 .00609 Mdot
.54571 .01938 Mdot
.6447 .06118 Mdot
.93204 .17759 Mdot
.31825 .23869 Mdot
.48735 .10451 Mdot
.63749 .09279 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47645 .60805 Mdot
.42511 .5863 Mdot
.26553 .51941 Mdot
.86835 .37256 Mdot
.64689 .48116 Mdot
.61578 .59881 Mdot
.74341 .07888 Mdot
.10958 .2263 Mdot
.32406 .13255 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41914 .58378 Mdot
.24758 .512 Mdot
.83732 .36448 Mdot
.63075 .49037 Mdot
.59897 .5984 Mdot
.70627 .06631 Mdot
.04334 .20832 Mdot
.3162 .16864 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50522 .00222 Mdot
.51665 .00706 Mdot
.55299 .02246 Mdot
.66735 .07068 Mdot
.98898 .19877 Mdot
.32712 .20899 Mdot
.45402 .07843 Mdot
.51291 .0364 Mdot
.59115 .04835 Mdot
.79875 .12831 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50836 .00355 Mdot
.52664 .0113 Mdot
.5847 .03588 Mdot
.76391 .11075 Mdot
.18093 .25774 Mdot
.38135 .12387 Mdot
.41984 .02378 Mdot
.3431 .57061 Mdot
.06731 .44759 Mdot
.69354 .38703 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51646 .00698 Mdot
.5524 .02221 Mdot
.66552 .06991 Mdot
.98453 .19716 Mdot
.32671 .21148 Mdot
.45735 .08074 Mdot
.52477 .04167 Mdot
.6292 .06454 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50289 .00123 Mdot
.50922 .00391 Mdot
.52936 .01245 Mdot
.5933 .03952 Mdot
.78931 .12114 Mdot
.21681 .26421 Mdot
.41075 .11986 Mdot
.47772 .04139 Mdot
.51137 .0208 Mdot
.56205 .03132 Mdot
.49905 .61763 Mdot
.49697 .61675 Mdot
.49034 .61394 Mdot
.46923 .60499 Mdot
.40224 .57663 Mdot
.19765 .49159 Mdot
.76714 .35196 Mdot
.57397 .49865 Mdot
.4878 .56478 Mdot
.38334 .55347 Mdot
.11914 .45475 Mdot
.49894 .61758 Mdot
.49662 .6166 Mdot
.48923 .61347 Mdot
.46569 .60349 Mdot
.39109 .57193 Mdot
.16557 .47865 Mdot
.73413 .35139 Mdot
.54024 .4982 Mdot
.40606 .53511 Mdot
.13901 .45299 Mdot
.68896 .33989 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.51369 .00581 Mdot
.5436 .01849 Mdot
.63811 .05841 Mdot
.91474 .17097 Mdot
.31323 .24628 Mdot
.49158 .11023 Mdot
.65732 .10243 Mdot
.02244 .22566 Mdot
.35401 .20492 Mdot
.5001 4e-05 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00137 Mdot
.51026 .00435 Mdot
.53267 .01385 Mdot
.60374 .04393 Mdot
.81964 .13343 Mdot
.25178 .26708 Mdot
.44521 .11954 Mdot
.55805 .06974 Mdot
.75605 .12237 Mdot
.49794 .61716 Mdot
.49345 .61526 Mdot
.47913 .60918 Mdot
.43359 .58989 Mdot
.29129 .53009 Mdot
.91826 .38749 Mdot
.66252 .45998 Mdot
.61034 .58579 Mdot
.71072 .06204 Mdot
.0426 .20511 Mdot
.31134 .16609 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48571 .61197 Mdot
.4545 .59874 Mdot
.35595 .55713 Mdot
.06966 .44109 Mdot
.68218 .37856 Mdot
.51208 .51291 Mdot
.36009 .5241 Mdot
.02424 .41047 Mdot
.65217 .38808 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47348 .60679 Mdot
.41569 .58232 Mdot
.23727 .50777 Mdot
.82089 .36069 Mdot
.61994 .49384 Mdot
.58235 .5948 Mdot
.66285 .04975 Mdot
.94719 .17573 Mdot
.30929 .22379 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51432 .00607 Mdot
.5456 .01933 Mdot
.64436 .06103 Mdot
.93115 .17725 Mdot
.31803 .2391 Mdot
.48765 .10483 Mdot
.63877 .0934 Mdot
.97265 .20635 Mdot
.34735 .23158 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.49419 .61557 Mdot
.4815 .61019 Mdot
.44112 .59308 Mdot
.31441 .53973 Mdot
.96827 .4041 Mdot
.6694 .43333 Mdot
.57931 .56235 Mdot
.60332 .01484 Mdot
.77167 .10404 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.5076 .00322 Mdot
.52423 .01027 Mdot
.57704 .03264 Mdot
.74097 .10131 Mdot
.14324 .24862 Mdot
.35851 .13304 Mdot
.38841 .01848 Mdot
.26429 .54133 Mdot
.90241 .39438 Mdot
.67791 .47928 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51643 .00697 Mdot
.55231 .02218 Mdot
.66526 .06981 Mdot
.9839 .19693 Mdot
.32664 .21183 Mdot
.45781 .08107 Mdot
.52644 .04241 Mdot
.63455 .06681 Mdot
.92129 .17721 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.5238 .01009 Mdot
.5757 .03207 Mdot
.7369 .09963 Mdot
.13603 .24668 Mdot
.35507 .13537 Mdot
.38553 .01883 Mdot
.25871 .53965 Mdot
.89351 .39233 Mdot
.67639 .48385 Mdot
.49866 .61747 Mdot
.49574 .61623 Mdot
.48644 .61228 Mdot
.45681 .59972 Mdot
.36318 .56017 Mdot
.08868 .44838 Mdot
.68794 .37036 Mdot
.50801 .50683 Mdot
.34008 .51425 Mdot
.97066 .38972 Mdot
.645 .41676 Mdot
.49832 .61732 Mdot
.49464 .61576 Mdot
.48291 .61079 Mdot
.44561 .59498 Mdot
.32829 .54553 Mdot
.00054 .41548 Mdot
.67198 .41497 Mdot
.55404 .54514 Mdot
.51561 .59428 Mdot
.50057 .60874 Mdot
.48638 .60927 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48297 .61081 Mdot
.4458 .59506 Mdot
.32887 .54577 Mdot
.00194 .41598 Mdot
.6721 .41418 Mdot
.55295 .5444 Mdot
.51178 .59259 Mdot
.48825 .60349 Mdot
.4471 .5926 Mdot
.49896 .61759 Mdot
.4967 .61663 Mdot
.48947 .61357 Mdot
.46646 .60381 Mdot
.39352 .57295 Mdot
.17251 .48144 Mdot
.74051 .35104 Mdot
.54682 .49833 Mdot
.42234 .5411 Mdot
.18594 .47193 Mdot
.72989 .33618 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50997 .00423 Mdot
.53175 .01346 Mdot
.60084 .0427 Mdot
.81128 .13006 Mdot
.24297 .2668 Mdot
.43616 .1194 Mdot
.53613 .06179 Mdot
.68985 .095 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50817 .00346 Mdot
.52601 .01103 Mdot
.5827 .03504 Mdot
.75795 .1083 Mdot
.17162 .25567 Mdot
.37493 .12565 Mdot
.40937 .02128 Mdot
.31508 .55976 Mdot
.00174 .42438 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47985 .60949 Mdot
.43589 .59086 Mdot
.29835 .53303 Mdot
.933 .39224 Mdot
.66521 .45253 Mdot
.60307 .57963 Mdot
.68494 .0506 Mdot
.98588 .18599 Mdot
.30797 .19906 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48824 .61305 Mdot
.46253 .60215 Mdot
.38114 .56773 Mdot
.13759 .46751 Mdot
.71241 .35526 Mdot
.51934 .49871 Mdot
.35521 .5166 Mdot
.00264 .40013 Mdot
.64611 .39768 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51315 .00558 Mdot
.54188 .01775 Mdot
.6327 .05613 Mdot
.9003 .16539 Mdot
.30786 .25188 Mdot
.49229 .11398 Mdot
.66515 .10683 Mdot
.04361 .2339 Mdot
.35747 .19398 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.52607 .01106 Mdot
.5829 .03512 Mdot
.75852 .10854 Mdot
.17253 .25587 Mdot
.37554 .12547 Mdot
.41031 .02149 Mdot
.31754 .5607 Mdot
.00723 .42625 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51375 .00583 Mdot
.54377 .01856 Mdot
.63863 .05863 Mdot
.91611 .1715 Mdot
.31368 .24571 Mdot
.49138 .10982 Mdot
.65614 .10183 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50569 .00241 Mdot
.51811 .00768 Mdot
.55765 .02444 Mdot
.6818 .07673 Mdot
.02309 .21093 Mdot
.32987 .1896 Mdot
.42735 .06025 Mdot
.41959 .61324 Mdot
.29629 .54183 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48772 .61282 Mdot
.46088 .60145 Mdot
.37595 .56554 Mdot
.12321 .46183 Mdot
.70357 .35869 Mdot
.51259 .5 Mdot
.34046 .51165 Mdot
.96713 .3873 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61476 Mdot
.47543 .60762 Mdot
.42188 .58493 Mdot
.25579 .51538 Mdot
.85112 .36794 Mdot
.6386 .48669 Mdot
.60868 .59954 Mdot
.72941 .07461 Mdot
.08687 .22093 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51433 .00608 Mdot
.54562 .01934 Mdot
.64442 .06106 Mdot
.93131 .17731 Mdot
.31807 .23903 Mdot
.4876 .10477 Mdot
.63854 .09329 Mdot
.97204 .20611 Mdot
.34726 .2319 Mdot
.49762 .61702 Mdot
.4924 .61481 Mdot
.4758 .60777 Mdot
.42304 .58543 Mdot
.25929 .51683 Mdot
.85721 .36954 Mdot
.64172 .48485 Mdot
.6118 .59955 Mdot
.73614 .07684 Mdot
.0983 .22383 Mdot
.32221 .13839 Mdot
.49905 .61763 Mdot
.49697 .61675 Mdot
.49035 .61394 Mdot
.46926 .605 Mdot
.40236 .57668 Mdot
.19801 .49174 Mdot
.76755 .352 Mdot
.57438 .49865 Mdot
.48875 .56511 Mdot
.38625 .55469 Mdot
.12729 .45799 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47991 .60952 Mdot
.43608 .59094 Mdot
.29893 .53327 Mdot
.93423 .39264 Mdot
.66541 .45189 Mdot
.60238 .57908 Mdot
.68254 .04954 Mdot
.9803 .18403 Mdot
.30754 .20225 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51418 .00601 Mdot
.54516 .01915 Mdot
.64298 .06046 Mdot
.92757 .17588 Mdot
.31709 .24074 Mdot
.48878 .10611 Mdot
.64364 .09571 Mdot
.98589 .21152 Mdot
.34927 .22459 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60203 Mdot
.38023 .56735 Mdot
.13505 .4665 Mdot
.71074 .3558 Mdot
.51794 .49888 Mdot
.352 .51548 Mdot
.9947 .39721 Mdot
.64535 .40212 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50716 .00304 Mdot
.52282 .00968 Mdot
.5726 .03076 Mdot
.72754 .09576 Mdot
.11883 .24183 Mdot
.34799 .14163 Mdot
.38224 .02117 Mdot
.25554 .53973 Mdot
.89025 .39227 Mdot
.67684 .48614 Mdot
.49826 .6173 Mdot
.49446 .61568 Mdot
.48235 .61055 Mdot
.44382 .59422 Mdot
.32277 .54322 Mdot
.98751 .41083 Mdot
.67096 .4224 Mdot
.56431 .55212 Mdot
.55152 .61013 Mdot
.61467 .03903 Mdot
.83534 .13638 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50766 .00325 Mdot
.52442 .01035 Mdot
.57764 .0329 Mdot
.74278 .10206 Mdot
.14639 .24945 Mdot
.3601 .13208 Mdot
.38996 .01845 Mdot
.2676 .54241 Mdot
.90797 .39577 Mdot
.67882 .47641 Mdot
.49911 .61766 Mdot
.49718 .61684 Mdot
.49101 .61422 Mdot
.47136 .60589 Mdot
.40898 .57948 Mdot
.2174 .49963 Mdot
.79208 .35517 Mdot
.59719 .49759 Mdot
.5392 .58219 Mdot
.53942 .00013 Mdot
.59816 .03631 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53097 .01313 Mdot
.59837 .04166 Mdot
.80412 .12716 Mdot
.23493 .26625 Mdot
.42807 .11937 Mdot
.51697 .05494 Mdot
.63126 .07064 Mdot
.92087 .17899 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.5261 .01107 Mdot
.58299 .03516 Mdot
.7588 .10865 Mdot
.17297 .25597 Mdot
.37583 .12538 Mdot
.41077 .02159 Mdot
.31877 .56117 Mdot
.00997 .42719 Mdot
.68623 .41795 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50464 .00197 Mdot
.51478 .00627 Mdot
.54706 .01995 Mdot
.64889 .06294 Mdot
.94288 .1817 Mdot
.32072 .23352 Mdot
.48302 .1003 Mdot
.61988 .08459 Mdot
.92004 .18551 Mdot
.33516 .25656 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47487 .60738 Mdot
.4201 .58418 Mdot
.25046 .51319 Mdot
.84208 .36564 Mdot
.63358 .48917 Mdot
.60275 .59898 Mdot
.71556 .06972 Mdot
.06152 .21382 Mdot
.31749 .15819 Mdot
.49802 .6172 Mdot
.4937 .61536 Mdot
.47993 .60952 Mdot
.43613 .59096 Mdot
.29906 .53332 Mdot
.93452 .39274 Mdot
.66545 .45174 Mdot
.60221 .57895 Mdot
.68196 .04929 Mdot
.97896 .18356 Mdot
.30743 .203 Mdot
.49914 .61767 Mdot
.49726 .61687 Mdot
.49127 .61433 Mdot
.4722 .60625 Mdot
.41164 .58061 Mdot
.22525 .50284 Mdot
.80301 .35707 Mdot
.60638 .49651 Mdot
.5577 .58795 Mdot
.59369 .02224 Mdot
.76223 .10417 Mdot
.50026 .00011 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52631 .01116 Mdot
.58364 .03543 Mdot
.76075 .10946 Mdot
.17604 .25666 Mdot
.37791 .12477 Mdot
.4141 .02236 Mdot
.32761 .56458 Mdot
.0302 .43423 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50418 .00177 Mdot
.5133 .00564 Mdot
.54236 .01796 Mdot
.63422 .05677 Mdot
.90437 .16696 Mdot
.30949 .25038 Mdot
.49236 .11302 Mdot
.66378 .10594 Mdot
.03976 .23236 Mdot
.35671 .19589 Mdot
.49935 .61776 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47911 .60918 Mdot
.43353 .58986 Mdot
.29112 .53002 Mdot
.9179 .38737 Mdot
.66244 .46015 Mdot
.61049 .58593 Mdot
.71128 .06229 Mdot
.04377 .20549 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50306 .0013 Mdot
.50976 .00414 Mdot
.53108 .01318 Mdot
.59872 .04181 Mdot
.80513 .12757 Mdot
.23609 .26635 Mdot
.42923 .11937 Mdot
.51968 .0559 Mdot
.63958 .0741 Mdot
.94302 .18754 Mdot
.49805 .61721 Mdot
.4938 .6154 Mdot
.48024 .60965 Mdot
.43711 .59138 Mdot
.30209 .53459 Mdot
.94101 .39487 Mdot
.6664 .44832 Mdot
.59834 .57597 Mdot
.66859 .04342 Mdot
.94702 .17208 Mdot
.30346 .22029 Mdot
.49812 .61724 Mdot
.49402 .6155 Mdot
.48095 .60996 Mdot
.43938 .59234 Mdot
.30905 .53749 Mdot
.95623 .39998 Mdot
.66824 .44005 Mdot
.58818 .56855 Mdot
.63372 .02814 Mdot
.85706 .13803 Mdot
.26712 .25344 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50752 .00319 Mdot
.52396 .01016 Mdot
.57621 .03229 Mdot
.73846 .10028 Mdot
.13882 .24743 Mdot
.35636 .13445 Mdot
.38653 .01864 Mdot
.26055 .54017 Mdot
.89636 .39295 Mdot
.67687 .48238 Mdot
.49909 .61765 Mdot
.49711 .61681 Mdot
.4908 .61413 Mdot
.47069 .60561 Mdot
.40688 .57859 Mdot
.21121 .49711 Mdot
.78387 .35392 Mdot
.58987 .49814 Mdot
.52364 .5771 Mdot
.49272 .59893 Mdot
.45089 .59218 Mdot
.49927 .61772 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47635 .60801 Mdot
.42478 .58616 Mdot
.26453 .519 Mdot
.86655 .37207 Mdot
.64609 .48179 Mdot
.61528 .59899 Mdot
.74266 .07872 Mdot
.10851 .22611 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.47849 .60891 Mdot
.43155 .58903 Mdot
.28508 .52751 Mdot
.90565 .38353 Mdot
.6596 .46597 Mdot
.6148 .59035 Mdot
.72765 .06975 Mdot
.07689 .21584 Mdot
.31523 .1473 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50695 .00295 Mdot
.52213 .00939 Mdot
.57041 .02984 Mdot
.7209 .09301 Mdot
.10614 .23809 Mdot
.34371 .14683 Mdot
.38275 .02413 Mdot
.2614 .54304 Mdot
.90193 .39587 Mdot
.49845 .61737 Mdot
.49505 .61593 Mdot
.48422 .61134 Mdot
.44976 .59674 Mdot
.3412 .55094 Mdot
.03203 .42696 Mdot
.67514 .39746 Mdot
.53106 .52899 Mdot
.43327 .5576 Mdot
.2383 .49754 Mdot
.80525 .35039 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00215 Mdot
.51612 .00684 Mdot
.55133 .02176 Mdot
.6622 .06852 Mdot
.97638 .19417 Mdot
.32586 .21599 Mdot
.46323 .0849 Mdot
.54593 .05111 Mdot
.69656 .0931 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00226 Mdot
.51701 .00721 Mdot
.55414 .02295 Mdot
.67092 .07217 Mdot
.99755 .20187 Mdot
.32786 .20414 Mdot
.44744 .0739 Mdot
.4896 .02606 Mdot
.51619 .01643 Mdot
.56701 .03141 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.51079 .00458 Mdot
.53437 .01457 Mdot
.6091 .04618 Mdot
.83495 .13959 Mdot
.26633 .26661 Mdot
.46023 .11984 Mdot
.5951 .08335 Mdot
.86428 .16636 Mdot
.31325 .27748 Mdot
.49756 .617 Mdot
.49222 .61473 Mdot
.4752 .60752 Mdot
.42115 .58463 Mdot
.2536 .51448 Mdot
.84739 .36698 Mdot
.63658 .48775 Mdot
.60642 .59939 Mdot
.72426 .07283 Mdot
.07771 .21845 Mdot
.31918 .14923 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52329 .00987 Mdot
.57407 .03139 Mdot
.732 .0976 Mdot
.12713 .24421 Mdot
.35121 .13849 Mdot
.38322 .01978 Mdot
.25536 .53901 Mdot
.88891 .39155 Mdot
.49993 .61801 Mdot
.49979 .61794 Mdot
.49933 .61775 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47833 .60885 Mdot
.43106 .58882 Mdot
.2836 .52689 Mdot
.90269 .38262 Mdot
.65883 .46732 Mdot
.61558 .59131 Mdot
.49748 .61696 Mdot
.49196 .61463 Mdot
.4744 .60718 Mdot
.41861 .58355 Mdot
.246 .51135 Mdot
.83473 .36385 Mdot
.62915 .49098 Mdot
.59672 .59799 Mdot
.70062 .06421 Mdot
.03184 .20471 Mdot
.31562 .17539 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47577 .60776 Mdot
.42293 .58538 Mdot
.25895 .51669 Mdot
.85661 .36938 Mdot
.64142 .48504 Mdot
.61153 .59956 Mdot
.73556 .07666 Mdot
.09735 .2236 Mdot
.32205 .13887 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50603 .00256 Mdot
.5192 .00814 Mdot
.5611 .02589 Mdot
.69241 .08115 Mdot
.04699 .21914 Mdot
.33211 .17621 Mdot
.40956 .04787 Mdot
.35855 .5865 Mdot
.12221 .47197 Mdot
.72004 .36948 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47758 .60853 Mdot
.42869 .58781 Mdot
.27636 .52389 Mdot
.88857 .37837 Mdot
.6546 .47343 Mdot
.61774 .59525 Mdot
.74182 .07669 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50664 .00281 Mdot
.52114 .00896 Mdot
.56726 .02851 Mdot
.7113 .08902 Mdot
.08705 .23223 Mdot
.33864 .15549 Mdot
.38757 .03024 Mdot
.28153 .5525 Mdot
.94143 .40784 Mdot
.68721 .46092 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00149 Mdot
.51116 .00473 Mdot
.53553 .01507 Mdot
.61277 .04774 Mdot
.84537 .14375 Mdot
.2751 .26559 Mdot
.46907 .11988 Mdot
.61693 .09138 Mdot
.92482 .19029 Mdot
.34133 .25742 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48427 .61136 Mdot
.44993 .59681 Mdot
.34171 .55115 Mdot
.03331 .42743 Mdot
.67531 .39678 Mdot
.53023 .52837 Mdot
.43021 .55622 Mdot
.22884 .49358 Mdot
.79084 .34734 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00148 Mdot
.51116 .00473 Mdot
.53553 .01507 Mdot
.61277 .04773 Mdot
.84534 .14374 Mdot
.27508 .26559 Mdot
.46905 .11988 Mdot
.61688 .09137 Mdot
.9247 .19024 Mdot
.3413 .25747 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .00139 Mdot
.51047 .00444 Mdot
.53336 .01415 Mdot
.60593 .04485 Mdot
.82591 .13596 Mdot
.25798 .26703 Mdot
.45162 .11968 Mdot
.57381 .07551 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47474 .60732 Mdot
.41967 .584 Mdot
.24915 .51265 Mdot
.8399 .36511 Mdot
.6323 .48973 Mdot
.60108 .59874 Mdot
.71148 .06823 Mdot
.05365 .21147 Mdot
.31686 .16268 Mdot
.49777 .61709 Mdot
.4929 .61502 Mdot
.47737 .60844 Mdot
.42801 .58753 Mdot
.27432 .52305 Mdot
.88468 .37722 Mdot
.65327 .47502 Mdot
.61785 .59614 Mdot
.74349 .07765 Mdot
.10767 .22507 Mdot
.32238 .1327 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51127 .00478 Mdot
.53591 .01522 Mdot
.61395 .04823 Mdot
.84868 .14507 Mdot
.2777 .26515 Mdot
.47161 .11984 Mdot
.62314 .09366 Mdot
.94151 .19676 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.5119 .00504 Mdot
.53788 .01606 Mdot
.62017 .05085 Mdot
.86605 .15197 Mdot
.28997 .26199 Mdot
.48264 .11908 Mdot
.64931 .10301 Mdot
.00852 .222 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50333 .00141 Mdot
.5106 .0045 Mdot
.53376 .01432 Mdot
.60719 .04538 Mdot
.82953 .13741 Mdot
.2614 .26692 Mdot
.45516 .11975 Mdot
.58255 .07873 Mdot
.82829 .15187 Mdot
.28445 .28193 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.5036 .00153 Mdot
.51146 .00486 Mdot
.5365 .01547 Mdot
.6158 .04901 Mdot
.85388 .14714 Mdot
.28162 .26436 Mdot
.47532 .11972 Mdot
.63216 .09693 Mdot
.96523 .20585 Mdot
.35004 .23782 Mdot
.49984 .61797 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49486 .61585 Mdot
.48363 .61109 Mdot
.44788 .59594 Mdot
.33534 .54848 Mdot
.01757 .42164 Mdot
.6735 .40539 Mdot
.54111 .53621 Mdot
.4697 .5739 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50736 .00312 Mdot
.52345 .00994 Mdot
.57459 .03161 Mdot
.73356 .09825 Mdot
.13 .24501 Mdot
.3524 .13746 Mdot
.38382 .01941 Mdot
.25603 .53906 Mdot
.88968 .39162 Mdot
.67587 .4859 Mdot
.49997 .61802 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49708 .61679 Mdot
.49068 .61408 Mdot
.47033 .60545 Mdot
.40572 .57811 Mdot
.20783 .49573 Mdot
.77953 .35333 Mdot
.58587 .49834 Mdot
.498 .61719 Mdot
.49364 .61534 Mdot
.47973 .60944 Mdot
.43551 .5907 Mdot
.29717 .53254 Mdot
.93051 .39143 Mdot
.6648 .45382 Mdot
.60444 .58072 Mdot
.68972 .05271 Mdot
.99681 .18979 Mdot
.30869 .19275 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00341 Mdot
.52564 .01087 Mdot
.58152 .03454 Mdot
.7544 .10685 Mdot
.16592 .25433 Mdot
.37125 .1269 Mdot
.40386 .02015 Mdot
.30085 .55438 Mdot
.9712 .4143 Mdot
.49862 .61745 Mdot
.4956 .61617 Mdot
.486 .6121 Mdot
.45541 .59913 Mdot
.3588 .55833 Mdot
.07711 .44394 Mdot
.68423 .37522 Mdot
.50997 .51034 Mdot
.35067 .51958 Mdot
.99882 .40058 Mdot
.64874 .40167 Mdot
.49979 .61794 Mdot
.49932 .61775 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.4781 .60875 Mdot
.43033 .58851 Mdot
.28136 .52597 Mdot
.89829 .38128 Mdot
.6576 .46928 Mdot
.61654 .59265 Mdot
.73507 .07326 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49075 .61411 Mdot
.47054 .60554 Mdot
.40639 .57839 Mdot
.20979 .49653 Mdot
.78203 .35367 Mdot
.58819 .49823 Mdot
.51997 .57587 Mdot
.49823 .61728 Mdot
.49437 .61564 Mdot
.48205 .61042 Mdot
.44287 .59382 Mdot
.31982 .54198 Mdot
.98064 .40841 Mdot
.67043 .42631 Mdot
.56973 .5558 Mdot
.57033 .00037 Mdot
.67301 .06346 Mdot
.98703 .19407 Mdot
.49852 .6174 Mdot
.49527 .61603 Mdot
.48493 .61164 Mdot
.45201 .59769 Mdot
.3482 .55387 Mdot
.04968 .43354 Mdot
.67784 .38823 Mdot
.52062 .52087 Mdot
.39424 .53993 Mdot
.12065 .44894 Mdot
.68292 .34751 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49541 .61609 Mdot
.48538 .61184 Mdot
.45346 .5983 Mdot
.35271 .55577 Mdot
.06124 .4379 Mdot
.68016 .38251 Mdot
.51519 .51608 Mdot
.37298 .53014 Mdot
.05983 .4245 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.52089 .00886 Mdot
.56648 .02817 Mdot
.7089 .08802 Mdot
.08214 .23068 Mdot
.33757 .15786 Mdot
.38949 .03209 Mdot
.28866 .55572 Mdot
.95611 .4125 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51093 .00463 Mdot
.5348 .01476 Mdot
.61046 .04676 Mdot
.83883 .14114 Mdot
.2697 .26629 Mdot
.46367 .11988 Mdot
.60361 .08649 Mdot
.88821 .17589 Mdot
.32705 .27122 Mdot
.49906 .61764 Mdot
.497 .61676 Mdot
.49045 .61399 Mdot
.46959 .60514 Mdot
.40339 .57712 Mdot
.20101 .49296 Mdot
.77112 .35235 Mdot
.57786 .49859 Mdot
.4968 .56793 Mdot
.41094 .56497 Mdot
.19834 .48664 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51092 .00463 Mdot
.53479 .01475 Mdot
.61043 .04675 Mdot
.83874 .1411 Mdot
.26962 .2663 Mdot
.46359 .11988 Mdot
.6034 .08641 Mdot
.88764 .17567 Mdot
.32676 .27139 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49562 .61618 Mdot
.48604 .61211 Mdot
.45554 .59919 Mdot
.35921 .5585 Mdot
.07819 .44435 Mdot
.68454 .37475 Mdot
.50972 .50999 Mdot
.34947 .51899 Mdot
.99562 .39934 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.5083 .00352 Mdot
.52643 .01121 Mdot
.58404 .0356 Mdot
.76192 .10994 Mdot
.17787 .25707 Mdot
.37918 .12442 Mdot
.41619 .02287 Mdot
.3332 .56675 Mdot
.04337 .43891 Mdot
.68928 .3992 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50505 .00214 Mdot
.51609 .00682 Mdot
.55122 .02171 Mdot
.66186 .06838 Mdot
.97556 .19387 Mdot
.32577 .21644 Mdot
.4638 .08531 Mdot
.548 .05204 Mdot
.7031 .09586 Mdot
.08665 .23704 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50299 .00127 Mdot
.50952 .00404 Mdot
.53033 .01286 Mdot
.59637 .04081 Mdot
.79828 .12479 Mdot
.22803 .2656 Mdot
.42131 .11946 Mdot
.50132 .04945 Mdot
.58331 .05067 Mdot
.78463 .12442 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47318 .60666 Mdot
.41475 .58192 Mdot
.23447 .50662 Mdot
.8166 .35977 Mdot
.61686 .49459 Mdot
.57707 .59345 Mdot
.64843 .0441 Mdot
.91153 .16261 Mdot
.49963 .61788 Mdot
.49882 .61753 Mdot
.49623 .61644 Mdot
.48799 .61294 Mdot
.46176 .60182 Mdot
.37873 .56671 Mdot
.13088 .46486 Mdot
.7081 .35674 Mdot
.51584 .49921 Mdot
.34728 .51386 Mdot
.98322 .39303 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48569 .61197 Mdot
.45443 .59871 Mdot
.35574 .55704 Mdot
.06911 .44088 Mdot
.68204 .37881 Mdot
.51226 .51311 Mdot
.36086 .52446 Mdot
.02633 .41129 Mdot
.65249 .38698 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .00341 Mdot
.52559 .01085 Mdot
.58136 .03447 Mdot
.75391 .10665 Mdot
.16513 .25415 Mdot
.37076 .12709 Mdot
.40315 .02002 Mdot
.29905 .5537 Mdot
.96747 .41311 Mdot
.68435 .44305 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52163 .00917 Mdot
.56883 .02917 Mdot
.71607 .091 Mdot
.09665 .23521 Mdot
.341 .15102 Mdot
.38459 .02694 Mdot
.26983 .54711 Mdot
.91819 .40071 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52451 .01039 Mdot
.57794 .03302 Mdot
.74367 .10243 Mdot
.14795 .24986 Mdot
.36091 .13162 Mdot
.3908 .01847 Mdot
.26943 .54303 Mdot
.91111 .39658 Mdot
.6793 .47477 Mdot
.49891 .61757 Mdot
.49652 .61656 Mdot
.4889 .61333 Mdot
.46465 .60305 Mdot
.38782 .57055 Mdot
.1563 .47495 Mdot
.72625 .35224 Mdot
.53227 .49815 Mdot
.38635 .52785 Mdot
.08409 .43123 Mdot
.66148 .35685 Mdot
.49992 .618 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47446 .60721 Mdot
.41881 .58364 Mdot
.24657 .51159 Mdot
.83566 .36408 Mdot
.62973 .49076 Mdot
.59755 .59815 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51267 .00537 Mdot
.54033 .0171 Mdot
.62786 .05409 Mdot
.88719 .16028 Mdot
.30192 .25632 Mdot
.49051 .11656 Mdot
.49899 .61761 Mdot
.4968 .61668 Mdot
.4898 .61371 Mdot
.4675 .60425 Mdot
.39679 .57433 Mdot
.1819 .48522 Mdot
.74979 .35098 Mdot
.55642 .49852 Mdot
.44593 .54974 Mdot
.25587 .50057 Mdot
.82725 .35313 Mdot
.49766 .61704 Mdot
.49254 .61487 Mdot
.47624 .60796 Mdot
.42443 .58602 Mdot
.26349 .51857 Mdot
.86467 .37155 Mdot
.64525 .48243 Mdot
.6147 .59915 Mdot
.7417 .07849 Mdot
.1071 .22583 Mdot
.32371 .13387 Mdot
.49751 .61698 Mdot
.49206 .61467 Mdot
.4747 .60731 Mdot
.41956 .58396 Mdot
.24884 .51252 Mdot
.83939 .36498 Mdot
.632 .48986 Mdot
.60067 .59867 Mdot
.71048 .06787 Mdot
.0517 .21088 Mdot
.31673 .1638 Mdot
.4975 .61697 Mdot
.49204 .61466 Mdot
.47464 .60728 Mdot
.41936 .58387 Mdot
.24822 .51227 Mdot
.83837 .36473 Mdot
.63138 .49011 Mdot
.59984 .59854 Mdot
.70844 .06711 Mdot
.04767 .20966 Mdot
.31646 .16613 Mdot
.49814 .61724 Mdot
.49406 .61552 Mdot
.48108 .61001 Mdot
.43978 .59251 Mdot
.31031 .53801 Mdot
.95903 .40093 Mdot
.66853 .4385 Mdot
.58617 .56713 Mdot
.62683 .02513 Mdot
.83823 .13065 Mdot
.25261 .2561 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51798 .00762 Mdot
.55722 .02425 Mdot
.68046 .07617 Mdot
.02001 .20985 Mdot
.32962 .19135 Mdot
.42976 .06189 Mdot
.42792 .6169 Mdot
.32163 .55234 Mdot
.00037 .41949 Mdot
.50018 8e-05 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50596 .00253 Mdot
.51897 .00805 Mdot
.56039 .02559 Mdot
.69022 .08024 Mdot
.04215 .2175 Mdot
.33159 .17888 Mdot
.41298 .0503 Mdot
.37025 .59163 Mdot
.15376 .48423 Mdot
.49948 .61781 Mdot
.49835 .61733 Mdot
.49474 .61581 Mdot
.48326 .61093 Mdot
.4467 .59544 Mdot
.33168 .54695 Mdot
.00867 .41841 Mdot
.67267 .41037 Mdot
.54776 .54084 Mdot
.49343 .58445 Mdot
.42923 .57836 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48987 .61374 Mdot
.46773 .60435 Mdot
.39752 .57464 Mdot
.18399 .48607 Mdot
.75197 .35103 Mdot
.55866 .49856 Mdot
.45138 .55173 Mdot
.27228 .50735 Mdot
.50003 1e-05 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.5087 .00369 Mdot
.52772 .01175 Mdot
.58812 .03733 Mdot
.77404 .11491 Mdot
.19597 .26077 Mdot
.3928 .12165 Mdot
.44071 .02961 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.5217 .0092 Mdot
.56903 .02925 Mdot
.7167 .09126 Mdot
.09789 .23559 Mdot
.34133 .15045 Mdot
.38428 .02654 Mdot
.26854 .5465 Mdot
.91569 .39996 Mdot
.68347 .47451 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00343 Mdot
.52579 .01094 Mdot
.582 .03474 Mdot
.75585 .10744 Mdot
.16827 .25489 Mdot
.37275 .12638 Mdot
.40604 .02058 Mdot
.30645 .55648 Mdot
.98297 .41812 Mdot
.68499 .43387 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49705 .61678 Mdot
.4906 .61405 Mdot
.47006 .60534 Mdot
.40488 .57775 Mdot
.20535 .49472 Mdot
.77643 .35294 Mdot
.58295 .49846 Mdot
.50835 .57193 Mdot
.44627 .57967 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51144 .00485 Mdot
.53642 .01544 Mdot
.61557 .04891 Mdot
.85322 .14688 Mdot
.28114 .26447 Mdot
.47487 .11974 Mdot
.63107 .09654 Mdot
.9624 .20477 Mdot
.3496 .23931 Mdot
.49857 .61743 Mdot
.49545 .61611 Mdot
.48551 .61189 Mdot
.45386 .59847 Mdot
.35397 .5563 Mdot
.06451 .43914 Mdot
.68091 .38095 Mdot
.5139 .51481 Mdot
.3677 .52768 Mdot
.04513 .41868 Mdot
.65577 .37739 Mdot
.50023 .0001 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52404 .01019 Mdot
.57645 .03239 Mdot
.73917 .10057 Mdot
.14007 .24777 Mdot
.35696 .13405 Mdot
.38702 .01858 Mdot
.2615 .54046 Mdot
.89787 .3933 Mdot
.49745 .61695 Mdot
.49189 .61459 Mdot
.47415 .60708 Mdot
.41782 .58322 Mdot
.24364 .51038 Mdot
.83091 .36295 Mdot
.62672 .49184 Mdot
.59316 .59729 Mdot
.69149 .06077 Mdot
.01261 .19846 Mdot
.31483 .18678 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49066 .61407 Mdot
.47025 .60542 Mdot
.40547 .578 Mdot
.20707 .49542 Mdot
.77858 .35321 Mdot
.58498 .49838 Mdot
.51288 .57347 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.48659 .61235 Mdot
.45729 .59993 Mdot
.36469 .56081 Mdot
.09271 .44994 Mdot
.6894 .36877 Mdot
.50772 .50575 Mdot
.3376 .5129 Mdot
.96402 .38715 Mdot
.64395 .42022 Mdot
.49745 .61695 Mdot
.49187 .61458 Mdot
.47409 .60705 Mdot
.41762 .58313 Mdot
.24303 .51013 Mdot
.82994 .36273 Mdot
.62609 .49205 Mdot
.59221 .59709 Mdot
.68903 .05984 Mdot
.00728 .19669 Mdot
.31461 .18994 Mdot
.49767 .61704 Mdot
.49256 .61488 Mdot
.47631 .60799 Mdot
.42465 .58611 Mdot
.26414 .51883 Mdot
.86584 .37187 Mdot
.64578 .48203 Mdot
.61507 .59905 Mdot
.74231 .07864 Mdot
.10801 .22601 Mdot
.32385 .13339 Mdot
.49838 .61735 Mdot
.49482 .61584 Mdot
.48351 .61104 Mdot
.44751 .59578 Mdot
.33418 .548 Mdot
.01475 .42061 Mdot
.67322 .40696 Mdot
.54319 .53767 Mdot
.47715 .57722 Mdot
.37696 .55611 Mdot
.11004 .45307 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.50441 .00187 Mdot
.51404 .00596 Mdot
.54472 .01896 Mdot
.6416 .05988 Mdot
.92395 .1745 Mdot
.31608 .24235 Mdot
.48976 .10734 Mdot
.64811 .09786 Mdot
.9979 .21619 Mdot
.35084 .21813 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00156 Mdot
.51174 .00498 Mdot
.53739 .01585 Mdot
.61862 .0502 Mdot
.86174 .15026 Mdot
.28714 .26291 Mdot
.48027 .11936 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00175 Mdot
.51318 .00559 Mdot
.54196 .01779 Mdot
.63296 .05624 Mdot
.90101 .16566 Mdot
.30815 .25163 Mdot
.49232 .11382 Mdot
.66496 .1067 Mdot
.04306 .23368 Mdot
.35736 .19424 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.4806 .60981 Mdot
.43828 .59187 Mdot
.30567 .53608 Mdot
.94878 .39747 Mdot
.6674 .44413 Mdot
.59333 .57225 Mdot
.65135 .03586 Mdot
.9037 .15596 Mdot
.29184 .23989 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51268 .00538 Mdot
.54037 .01712 Mdot
.62798 .05414 Mdot
.88752 .1604 Mdot
.30208 .25622 Mdot
.49058 .1165 Mdot
.66497 .10778 Mdot
.04483 .23476 Mdot
.35833 .19375 Mdot
.49991 .61799 Mdot
.49971 .61791 Mdot
.49906 .61764 Mdot
.49701 .61676 Mdot
.49046 .61399 Mdot
.46962 .60515 Mdot
.40347 .57716 Mdot
.20126 .49306 Mdot
.77142 .35238 Mdot
.57815 .49859 Mdot
.49745 .56816 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50543 .0023 Mdot
.5173 .00734 Mdot
.55507 .02334 Mdot
.67382 .07339 Mdot
.00447 .20435 Mdot
.32841 .20021 Mdot
.44203 .07022 Mdot
.47059 .01765 Mdot
.45528 .60857 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.48929 .61349 Mdot
.4659 .60357 Mdot
.39174 .5722 Mdot
.16742 .4794 Mdot
.7358 .35127 Mdot
.54195 .49823 Mdot
.4103 .53667 Mdot
.15112 .45785 Mdot
.69781 .33788 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60958 Mdot
.43653 .59113 Mdot
.30031 .53384 Mdot
.93718 .39361 Mdot
.66585 .45035 Mdot
.60067 .57775 Mdot
.67661 .04693 Mdot
.96634 .17907 Mdot
.30619 .21004 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47765 .60856 Mdot
.4289 .58791 Mdot
.27702 .52416 Mdot
.88983 .37874 Mdot
.65501 .47291 Mdot
.61766 .59495 Mdot
.74116 .07632 Mdot
.10302 .22364 Mdot
.32092 .13467 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48194 .61038 Mdot
.44253 .59367 Mdot
.31876 .54154 Mdot
.9782 .40756 Mdot
.67024 .4277 Mdot
.57165 .5571 Mdot
.57693 .00327 Mdot
.69318 .07184 Mdot
.0331 .21008 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.5151 .0064 Mdot
.54809 .02039 Mdot
.65211 .06429 Mdot
.95112 .1848 Mdot
.3223 .2294 Mdot
.47896 .09682 Mdot
.60416 .07738 Mdot
.87469 .16719 Mdot
.31435 .27173 Mdot
.49852 .61741 Mdot
.4953 .61604 Mdot
.48502 .61168 Mdot
.45231 .59782 Mdot
.34912 .55426 Mdot
.05203 .43442 Mdot
.67828 .38704 Mdot
.51941 .51985 Mdot
.3896 .5378 Mdot
.10715 .44347 Mdot
.67585 .35147 Mdot
.49788 .61714 Mdot
.49326 .61518 Mdot
.47852 .60893 Mdot
.43167 .58908 Mdot
.28544 .52766 Mdot
.90637 .38376 Mdot
.65978 .46564 Mdot
.61459 .59011 Mdot
.72682 .06936 Mdot
.07526 .21534 Mdot
.31497 .14815 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51156 .0049 Mdot
.53682 .01561 Mdot
.61681 .04944 Mdot
.8567 .14826 Mdot
.28366 .26387 Mdot
.4772 .11961 Mdot
.63664 .09854 Mdot
.97679 .21022 Mdot
.35163 .23166 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.477 .60828 Mdot
.42685 .58704 Mdot
.27079 .52158 Mdot
.87803 .3753 Mdot
.65084 .47762 Mdot
.61752 .59744 Mdot
.74489 .07872 Mdot
.11086 .22619 Mdot
.32367 .13152 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00348 Mdot
.52617 .0111 Mdot
.58322 .03525 Mdot
.75948 .10893 Mdot
.17405 .25622 Mdot
.37656 .12516 Mdot
.41192 .02185 Mdot
.32179 .56233 Mdot
.01682 .42955 Mdot
.68666 .41399 Mdot
.49977 .61794 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49249 .61485 Mdot
.47608 .60789 Mdot
.42393 .5858 Mdot
.26196 .51793 Mdot
.86193 .3708 Mdot
.64399 .48334 Mdot
.61375 .59935 Mdot
.73998 .07802 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51074 .00456 Mdot
.53421 .01451 Mdot
.60861 .04598 Mdot
.83357 .13903 Mdot
.2651 .2667 Mdot
.45897 .11982 Mdot
.59197 .0822 Mdot
.85539 .1628 Mdot
.30708 .27916 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54654 .01973 Mdot
.64729 .06227 Mdot
.93877 .18014 Mdot
.31984 .23552 Mdot
.4848 .10195 Mdot
.627 .08788 Mdot
.94011 .19352 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50406 .00172 Mdot
.51292 .00548 Mdot
.54116 .01745 Mdot
.63044 .05518 Mdot
.89419 .16301 Mdot
.30522 .25403 Mdot
.49175 .11528 Mdot
.66591 .10764 Mdot
.04626 .23507 Mdot
.35819 .19278 Mdot
.49969 .6179 Mdot
.49902 .61762 Mdot
.49689 .61671 Mdot
.49009 .61383 Mdot
.46843 .60465 Mdot
.39972 .57557 Mdot
.19034 .48863 Mdot
.7588 .35133 Mdot
.56564 .49865 Mdot
.46816 .55779 Mdot
.32325 .52847 Mdot
.50024 .0001 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50777 .00329 Mdot
.52475 .01049 Mdot
.57869 .03334 Mdot
.74593 .10336 Mdot
.15182 .25085 Mdot
.36298 .1305 Mdot
.39307 .0186 Mdot
.27458 .5448 Mdot
.92019 .39901 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.48219 .61048 Mdot
.44331 .59401 Mdot
.32119 .54256 Mdot
.98383 .40953 Mdot
.67068 .4245 Mdot
.56723 .5541 Mdot
.56164 .61458 Mdot
.64621 .05227 Mdot
.50079 .00033 Mdot
.50252 .00107 Mdot
.50802 .0034 Mdot
.52554 .01083 Mdot
.58122 .03441 Mdot
.7535 .10648 Mdot
.16445 .25398 Mdot
.37034 .12725 Mdot
.40255 .01991 Mdot
.29755 .55314 Mdot
.96439 .41213 Mdot
.6842 .44487 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52319 .00983 Mdot
.57377 .03126 Mdot
.73107 .09722 Mdot
.12542 .24372 Mdot
.35052 .13912 Mdot
.38293 .02003 Mdot
.25515 .53906 Mdot
.88876 .39159 Mdot
.67597 .48653 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52126 .00901 Mdot
.56763 .02866 Mdot
.71243 .08949 Mdot
.08933 .23294 Mdot
.33917 .1544 Mdot
.38676 .02942 Mdot
.27847 .55111 Mdot
.93526 .40592 Mdot
.6865 .46429 Mdot
.49873 .6175 Mdot
.49596 .61632 Mdot
.48714 .61258 Mdot
.45904 .60067 Mdot
.37019 .56312 Mdot
.10749 .45568 Mdot
.69554 .36343 Mdot
.50848 .50243 Mdot
.33415 .51029 Mdot
.95367 .38289 Mdot
.64171 .42523 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.4862 .61218 Mdot
.45606 .59941 Mdot
.36085 .55919 Mdot
.08251 .44601 Mdot
.68587 .3729 Mdot
.50885 .50863 Mdot
.3451 .51683 Mdot
.98399 .39485 Mdot
.64685 .40967 Mdot
.49975 .61793 Mdot
.4992 .6177 Mdot
.49747 .61696 Mdot
.49192 .61461 Mdot
.47428 .60713 Mdot
.41821 .58338 Mdot
.24478 .51085 Mdot
.83275 .36338 Mdot
.6279 .49143 Mdot
.59492 .59765 Mdot
.69601 .06248 Mdot
.49893 .61758 Mdot
.4966 .61659 Mdot
.48916 .61344 Mdot
.46547 .6034 Mdot
.39041 .57164 Mdot
.16363 .47788 Mdot
.73242 .35153 Mdot
.53849 .49818 Mdot
.40174 .53352 Mdot
.1268 .44811 Mdot
.68114 .34261 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52451 .01039 Mdot
.57795 .03303 Mdot
.74368 .10243 Mdot
.14796 .24986 Mdot
.36092 .13161 Mdot
.39081 .01847 Mdot
.26945 .54303 Mdot
.91115 .39659 Mdot
.6793 .47475 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47948 .60933 Mdot
.43471 .59036 Mdot
.29473 .53152 Mdot
.92539 .38977 Mdot
.66391 .45643 Mdot
.60707 .58291 Mdot
.699 .05682 Mdot
.01752 .19685 Mdot
.30981 .18065 Mdot
.49933 .61775 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47818 .60878 Mdot
.43057 .58861 Mdot
.28209 .52627 Mdot
.89972 .38171 Mdot
.65801 .46865 Mdot
.61625 .59223 Mdot
.73378 .07263 Mdot
.0888 .21941 Mdot
.49808 .61722 Mdot
.4939 .61545 Mdot
.48055 .60979 Mdot
.43811 .5918 Mdot
.30514 .53586 Mdot
.94764 .39708 Mdot
.66726 .44476 Mdot
.59409 .57281 Mdot
.65397 .03701 Mdot
.91042 .1585 Mdot
.29426 .23723 Mdot
.4983 .61731 Mdot
.49458 .61574 Mdot
.48274 .61072 Mdot
.44507 .59475 Mdot
.32662 .54483 Mdot
.99656 .41405 Mdot
.67167 .41724 Mdot
.55716 .54727 Mdot
.52658 .59913 Mdot
.53567 .00562 Mdot
.59781 .03841 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50663 .00281 Mdot
.52113 .00896 Mdot
.56721 .02848 Mdot
.71115 .08896 Mdot
.08675 .23213 Mdot
.33857 .15563 Mdot
.38768 .03035 Mdot
.28195 .55269 Mdot
.94227 .4081 Mdot
.68731 .46046 Mdot
.49881 .61753 Mdot
.49622 .61643 Mdot
.48796 .61293 Mdot
.46166 .60178 Mdot
.3784 .56658 Mdot
.12998 .4645 Mdot
.70755 .35696 Mdot
.51541 .49929 Mdot
.34636 .51355 Mdot
.981 .39223 Mdot
.64408 .4098 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48617 .61217 Mdot
.45595 .59936 Mdot
.36049 .55904 Mdot
.08155 .44564 Mdot
.68557 .3733 Mdot
.50903 .50892 Mdot
.34601 .51729 Mdot
.98641 .39578 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47908 .60916 Mdot
.43342 .58982 Mdot
.29079 .52988 Mdot
.91723 .38716 Mdot
.6623 .46048 Mdot
.61077 .58618 Mdot
.71229 .06275 Mdot
.04588 .20617 Mdot
.3116 .16422 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50678 .00288 Mdot
.52161 .00916 Mdot
.56876 .02914 Mdot
.71588 .09092 Mdot
.09627 .23509 Mdot
.3409 .15119 Mdot
.38468 .02706 Mdot
.27023 .5473 Mdot
.91898 .40095 Mdot
.68407 .47285 Mdot
.50053 .00022 Mdot
.50167 .00071 Mdot
.50533 .00226 Mdot
.51699 .0072 Mdot
.55407 .02292 Mdot
.6707 .07208 Mdot
.99705 .20169 Mdot
.32782 .20443 Mdot
.44783 .07417 Mdot
.491 .02667 Mdot
.52066 .01833 Mdot
.58122 .03743 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50364 .00154 Mdot
.51158 .00491 Mdot
.53689 .01564 Mdot
.61705 .04954 Mdot
.85738 .14853 Mdot
.28413 .26375 Mdot
.47762 .11959 Mdot
.63767 .09891 Mdot
.9794 .2112 Mdot
.35195 .23025 Mdot
.50004 2e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50368 .00156 Mdot
.51171 .00497 Mdot
.53731 .01582 Mdot
.61835 .05009 Mdot
.86101 .14997 Mdot
.28664 .26306 Mdot
.47985 .11941 Mdot
.6429 .10077 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48202 .61041 Mdot
.44279 .59378 Mdot
.31957 .54188 Mdot
.98005 .40821 Mdot
.67038 .42665 Mdot
.57019 .55611 Mdot
.57191 .00106 Mdot
.67786 .06548 Mdot
.99845 .19813 Mdot
.49935 .61776 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47906 .60916 Mdot
.43339 .5898 Mdot
.29069 .52984 Mdot
.91702 .38709 Mdot
.66226 .46058 Mdot
.61085 .58627 Mdot
.71261 .06289 Mdot
.04655 .20638 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47715 .60835 Mdot
.42732 .58724 Mdot
.27221 .52217 Mdot
.88069 .37606 Mdot
.65184 .47659 Mdot
.61773 .59695 Mdot
.74455 .07838 Mdot
.10997 .22584 Mdot
.32325 .13181 Mdot
.49804 .6172 Mdot
.49375 .61538 Mdot
.48008 .60959 Mdot
.4366 .59116 Mdot
.30052 .53393 Mdot
.93764 .39376 Mdot
.66592 .4501 Mdot
.60039 .57753 Mdot
.67565 .04652 Mdot
.96407 .17825 Mdot
.30593 .21128 Mdot
.49834 .61733 Mdot
.49471 .61579 Mdot
.48315 .61089 Mdot
.44635 .59529 Mdot
.33059 .54649 Mdot
.00605 .41746 Mdot
.67244 .41185 Mdot
.54977 .54222 Mdot
.50055 .58761 Mdot
.45214 .58812 Mdot
.33302 .54441 Mdot
.49969 .6179 Mdot
.49903 .61762 Mdot
.4969 .61672 Mdot
.49013 .61385 Mdot
.46857 .60471 Mdot
.40016 .57576 Mdot
.19163 .48915 Mdot
.76024 .35142 Mdot
.56709 .49866 Mdot
.47163 .55903 Mdot
.33383 .53287 Mdot
.49828 .61731 Mdot
.49453 .61571 Mdot
.48256 .61064 Mdot
.44448 .5945 Mdot
.3248 .54407 Mdot
.99228 .41252 Mdot
.67133 .41968 Mdot
.56054 .54956 Mdot
.53839 .60434 Mdot
.57327 .02155 Mdot
.7142 .0871 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.5196 .00831 Mdot
.56239 .02644 Mdot
.69637 .08281 Mdot
.05566 .22205 Mdot
.33315 .1715 Mdot
.40376 .04364 Mdot
.33865 .57779 Mdot
.07088 .45255 Mdot
.70028 .38899 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50741 .00314 Mdot
.52361 .01001 Mdot
.57509 .03182 Mdot
.73507 .09888 Mdot
.13274 .24577 Mdot
.35359 .13649 Mdot
.38452 .01911 Mdot
.25703 .53924 Mdot
.89103 .39184 Mdot
.67602 .48515 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.5261 .01107 Mdot
.58298 .03516 Mdot
.75878 .10865 Mdot
.17295 .25597 Mdot
.37582 .12538 Mdot
.41074 .02159 Mdot
.3187 .56115 Mdot
.00981 .42713 Mdot
.68622 .41804 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.5063 .00267 Mdot
.52006 .00851 Mdot
.56385 .02706 Mdot
.70085 .08467 Mdot
.06529 .22524 Mdot
.33452 .16639 Mdot
.3979 .03917 Mdot
.31841 .56891 Mdot
.0219 .43478 Mdot
.69265 .41455 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52176 .00923 Mdot
.56922 .02933 Mdot
.71727 .0915 Mdot
.09902 .23594 Mdot
.34164 .14995 Mdot
.38402 .02619 Mdot
.26742 .54597 Mdot
.91351 .39931 Mdot
.68305 .4756 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50548 .00232 Mdot
.51746 .0074 Mdot
.55559 .02356 Mdot
.6754 .07405 Mdot
.00821 .20568 Mdot
.32871 .19808 Mdot
.43907 .06821 Mdot
.46026 .01309 Mdot
.42245 .59467 Mdot
.27287 .52559 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50629 .00267 Mdot
.52003 .00849 Mdot
.56374 .02702 Mdot
.70053 .08454 Mdot
.06462 .22502 Mdot
.33442 .16674 Mdot
.39828 .03947 Mdot
.31975 .5695 Mdot
.02505 .4359 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50403 .00171 Mdot
.51285 .00545 Mdot
.54091 .01735 Mdot
.62968 .05486 Mdot
.89213 .16221 Mdot
.30428 .25472 Mdot
.49146 .11568 Mdot
.66582 .10776 Mdot
.0463 .23515 Mdot
.3583 .19283 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00164 Mdot
.51235 .00524 Mdot
.53933 .01667 Mdot
.62471 .05277 Mdot
.87858 .1569 Mdot
.29743 .25886 Mdot
.48806 .11782 Mdot
.66079 .10675 Mdot
.03572 .23172 Mdot
.35752 .19889 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.523 .00975 Mdot
.57317 .031 Mdot
.72925 .09647 Mdot
.12205 .24276 Mdot
.34919 .14038 Mdot
.38249 .02058 Mdot
.25511 .53931 Mdot
.88912 .39184 Mdot
.67632 .48652 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47343 .60677 Mdot
.41552 .58225 Mdot
.23676 .50756 Mdot
.8201 .36052 Mdot
.61938 .49398 Mdot
.58142 .59457 Mdot
.66031 .04876 Mdot
.94103 .17349 Mdot
.49907 .61764 Mdot
.49702 .61677 Mdot
.49052 .61401 Mdot
.46981 .60523 Mdot
.40408 .57741 Mdot
.20302 .49377 Mdot
.77356 .35261 Mdot
.58021 .49854 Mdot
.50216 .56979 Mdot
.42734 .5718 Mdot
.24729 .50676 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50661 .0028 Mdot
.52105 .00893 Mdot
.56698 .02839 Mdot
.71045 .08867 Mdot
.08531 .23168 Mdot
.33825 .15633 Mdot
.38822 .03089 Mdot
.28398 .55361 Mdot
.94642 .40941 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47472 .60732 Mdot
.41963 .58398 Mdot
.24904 .5126 Mdot
.83971 .36506 Mdot
.63219 .48978 Mdot
.60093 .59871 Mdot
.71111 .0681 Mdot
.05294 .21126 Mdot
.31681 .16308 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50427 .00181 Mdot
.51361 .00577 Mdot
.54334 .01837 Mdot
.63727 .05805 Mdot
.91251 .17011 Mdot
.31248 .24719 Mdot
.49187 .11087 Mdot
.65906 .10333 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51786 .00757 Mdot
.55685 .0241 Mdot
.6793 .07568 Mdot
.01732 .20891 Mdot
.32941 .19288 Mdot
.43187 .06333 Mdot
.43523 .00208 Mdot
.34411 .56172 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.47879 .60904 Mdot
.43251 .58943 Mdot
.288 .52872 Mdot
.91154 .38537 Mdot
.66104 .46322 Mdot
.61294 .5883 Mdot
.72037 .0664 Mdot
.06242 .2114 Mdot
.31322 .155 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50608 .00258 Mdot
.51936 .00821 Mdot
.56162 .02612 Mdot
.69402 .08183 Mdot
.05053 .22034 Mdot
.33251 .17427 Mdot
.40714 .04612 Mdot
.35023 .58286 Mdot
.10039 .46362 Mdot
.70975 .37661 Mdot
.49815 .61725 Mdot
.49411 .61554 Mdot
.48124 .61008 Mdot
.44031 .59273 Mdot
.31192 .53869 Mdot
.96264 .40217 Mdot
.66889 .43648 Mdot
.58352 .56528 Mdot
.61778 .02117 Mdot
.813 .12066 Mdot
.2285 .25679 Mdot
.50006 2e-05 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.5057 .00242 Mdot
.51816 .0077 Mdot
.55781 .02451 Mdot
.68229 .07693 Mdot
.02422 .21132 Mdot
.32996 .18896 Mdot
.42646 .05964 Mdot
.41654 .6119 Mdot
.50078 .00033 Mdot
.5025 .00106 Mdot
.50797 .00338 Mdot
.52537 .01076 Mdot
.58068 .03418 Mdot
.7519 .10582 Mdot
.16183 .25335 Mdot
.36874 .12787 Mdot
.40032 .01952 Mdot
.29197 .55107 Mdot
.95315 .40863 Mdot
.68359 .45144 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.503 .00127 Mdot
.50955 .00405 Mdot
.53042 .0129 Mdot
.59665 .04093 Mdot
.79911 .12513 Mdot
.22903 .2657 Mdot
.42228 .11944 Mdot
.50354 .05022 Mdot
.59009 .05349 Mdot
.80468 .13262 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50346 .00147 Mdot
.51101 .00467 Mdot
.53506 .01487 Mdot
.61129 .04711 Mdot
.84117 .14208 Mdot
.27168 .26607 Mdot
.46566 .11989 Mdot
.60853 .0883 Mdot
.90187 .1813 Mdot
.33326 .26661 Mdot
.49927 .61772 Mdot
.49767 .61704 Mdot
.49256 .61488 Mdot
.47631 .60799 Mdot
.42465 .58611 Mdot
.26415 .51884 Mdot
.86586 .37188 Mdot
.64579 .48202 Mdot
.61508 .59905 Mdot
.74233 .07864 Mdot
.10803 .22602 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47911 .60917 Mdot
.43352 .58986 Mdot
.29109 .53001 Mdot
.91785 .38735 Mdot
.66243 .46018 Mdot
.61051 .58595 Mdot
.71135 .06232 Mdot
.04393 .20554 Mdot
.31144 .16533 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51261 .00535 Mdot
.54015 .01702 Mdot
.62728 .05385 Mdot
.88562 .15966 Mdot
.30114 .25681 Mdot
.49014 .11681 Mdot
.66436 .10768 Mdot
.04359 .23437 Mdot
.35824 .19447 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51157 .00491 Mdot
.53685 .01563 Mdot
.61692 .04949 Mdot
.85703 .14839 Mdot
.28389 .26381 Mdot
.4774 .1196 Mdot
.63714 .09872 Mdot
.97805 .2107 Mdot
.35178 .23098 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49917 .61768 Mdot
.49734 .61691 Mdot
.49154 .61445 Mdot
.47304 .6066 Mdot
.41431 .58173 Mdot
.23315 .50607 Mdot
.8146 .35935 Mdot
.61538 .49491 Mdot
.57447 .59275 Mdot
.49843 .61737 Mdot
.49498 .61591 Mdot
.48401 .61126 Mdot
.44911 .59646 Mdot
.33915 .55008 Mdot
.02695 .42508 Mdot
.67452 .40022 Mdot
.53447 .53148 Mdot
.44571 .56318 Mdot
.27709 .51382 Mdot
.87319 .36841 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .0029 Mdot
.52181 .00925 Mdot
.56939 .0294 Mdot
.71777 .09171 Mdot
.10002 .23624 Mdot
.34192 .1495 Mdot
.3838 .02589 Mdot
.26647 .54552 Mdot
.91168 .39876 Mdot
.68268 .4765 Mdot
.49789 .61714 Mdot
.49329 .61519 Mdot
.47862 .60897 Mdot
.43197 .5892 Mdot
.28636 .52804 Mdot
.90822 .38433 Mdot
.66025 .46478 Mdot
.61404 .58948 Mdot
.72462 .06834 Mdot
.0709 .21401 Mdot
.31432 .15044 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51299 .00551 Mdot
.54136 .01753 Mdot
.63107 .05544 Mdot
.89589 .16367 Mdot
.30598 .25345 Mdot
.49195 .11494 Mdot
.66586 .10748 Mdot
.0459 .23488 Mdot
.35804 .19292 Mdot
.49984 .61796 Mdot
.49948 .61781 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48306 .61085 Mdot
.44608 .59518 Mdot
.32975 .54614 Mdot
.00405 .41674 Mdot
.67227 .41298 Mdot
.55132 .54328 Mdot
.50601 .59003 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.508 .00339 Mdot
.52547 .0108 Mdot
.58099 .03431 Mdot
.75282 .1062 Mdot
.16335 .25372 Mdot
.36966 .12751 Mdot
.40159 .01974 Mdot
.29514 .55224 Mdot
.95949 .41059 Mdot
.68395 .44775 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50428 .00181 Mdot
.51363 .00578 Mdot
.54339 .01839 Mdot
.63743 .05812 Mdot
.91294 .17027 Mdot
.31262 .24702 Mdot
.49182 .11075 Mdot
.65874 .10317 Mdot
.02622 .22711 Mdot
.35454 .20292 Mdot
.49959 .61786 Mdot
.49868 .61747 Mdot
.4958 .61625 Mdot
.48661 .61236 Mdot
.45736 .59996 Mdot
.36491 .5609 Mdot
.09329 .45017 Mdot
.68961 .36855 Mdot
.50769 .5056 Mdot
.3373 .51273 Mdot
.9632 .38683 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50577 .00245 Mdot
.51839 .0078 Mdot
.55853 .02481 Mdot
.68451 .07786 Mdot
.02929 .21309 Mdot
.33038 .18609 Mdot
.42255 .05696 Mdot
.40308 .606 Mdot
.24706 .52161 Mdot
.85235 .37409 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50756 .00321 Mdot
.52408 .01021 Mdot
.57659 .03245 Mdot
.73961 .10075 Mdot
.14086 .24798 Mdot
.35734 .13379 Mdot
.38735 .01855 Mdot
.26215 .54066 Mdot
.89891 .39354 Mdot
.67731 .48108 Mdot
.49858 .61743 Mdot
.49549 .61612 Mdot
.48562 .61193 Mdot
.4542 .59862 Mdot
.35504 .55675 Mdot
.06728 .44019 Mdot
.68158 .37966 Mdot
.51289 .51378 Mdot
.3635 .52571 Mdot
.03356 .41412 Mdot
.65365 .38324 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51686 .00715 Mdot
.55367 .02275 Mdot
.66946 .07156 Mdot
.99407 .20062 Mdot
.32757 .20612 Mdot
.45014 .07575 Mdot
.49914 .03028 Mdot
.54685 .02949 Mdot
.66382 .07229 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50406 .00172 Mdot
.51294 .00549 Mdot
.5412 .01747 Mdot
.63057 .05524 Mdot
.89456 .16315 Mdot
.30539 .25391 Mdot
.4918 .11521 Mdot
.66591 .10761 Mdot
.04621 .23503 Mdot
.35816 .1928 Mdot
.49784 .61712 Mdot
.49311 .61511 Mdot
.47806 .60873 Mdot
.43019 .58845 Mdot
.28094 .52579 Mdot
.89744 .38102 Mdot
.65736 .46965 Mdot
.61669 .5929 Mdot
.7358 .07361 Mdot
.09269 .22057 Mdot
.31827 .13942 Mdot
.4978 .6171 Mdot
.493 .61507 Mdot
.47771 .60858 Mdot
.42908 .58798 Mdot
.27757 .52439 Mdot
.8909 .37906 Mdot
.65536 .47246 Mdot
.61757 .59468 Mdot
.74054 .076 Mdot
.10182 .22328 Mdot
.32057 .1352 Mdot
.49886 .61755 Mdot
.49636 .61649 Mdot
.4884 .61312 Mdot
.46306 .60237 Mdot
.38281 .56844 Mdot
.14224 .46935 Mdot
.7156 .35435 Mdot
.52213 .49847 Mdot
.36176 .51892 Mdot
.01912 .40628 Mdot
.64787 .38859 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50447 .00189 Mdot
.51423 .00603 Mdot
.5453 .0192 Mdot
.64341 .06064 Mdot
.92869 .17631 Mdot
.31739 .24023 Mdot
.48844 .10572 Mdot
.64217 .09501 Mdot
.98189 .20996 Mdot
.34872 .22671 Mdot
.49952 .61783 Mdot
.49848 .61739 Mdot
.49517 .61599 Mdot
.48462 .61151 Mdot
.45102 .59727 Mdot
.34511 .55258 Mdot
.04183 .4306 Mdot
.67653 .39226 Mdot
.52497 .52436 Mdot
.41071 .54742 Mdot
.16944 .46892 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49336 .61522 Mdot
.47886 .60907 Mdot
.43274 .58953 Mdot
.2887 .52901 Mdot
.91295 .38581 Mdot
.66136 .46254 Mdot
.61243 .58779 Mdot
.71847 .06553 Mdot
.05857 .21019 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50706 .003 Mdot
.5225 .00954 Mdot
.57159 .03034 Mdot
.72447 .09448 Mdot
.11301 .24013 Mdot
.34593 .14395 Mdot
.38219 .02241 Mdot
.25742 .54093 Mdot
.89419 .39354 Mdot
.67823 .48457 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00113 Mdot
.50845 .00359 Mdot
.52693 .01142 Mdot
.58561 .03627 Mdot
.76661 .11186 Mdot
.18504 .2586 Mdot
.38435 .12318 Mdot
.42504 .02515 Mdot
.35742 .57624 Mdot
.1034 .46104 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50923 .00392 Mdot
.52941 .01247 Mdot
.59345 .03958 Mdot
.78973 .12131 Mdot
.21735 .26428 Mdot
.41125 .11983 Mdot
.4788 .04175 Mdot
.51466 .02216 Mdot
.57247 .03573 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50266 .00113 Mdot
.50846 .00359 Mdot
.52695 .01143 Mdot
.58568 .03629 Mdot
.7668 .11194 Mdot
.18533 .25866 Mdot
.38457 .12313 Mdot
.42543 .02526 Mdot
.3585 .57667 Mdot
.10619 .4621 Mdot
.49967 .61789 Mdot
.49896 .61759 Mdot
.49667 .61662 Mdot
.4894 .61354 Mdot
.46623 .60371 Mdot
.39277 .57264 Mdot
.17038 .48058 Mdot
.7385 .35112 Mdot
.54474 .49828 Mdot
.41721 .53922 Mdot
.17103 .46588 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.4929 .61502 Mdot
.47739 .60845 Mdot
.42809 .58756 Mdot
.27455 .52314 Mdot
.88511 .37735 Mdot
.65342 .47484 Mdot
.61785 .59605 Mdot
.74334 .07756 Mdot
.50044 .00018 Mdot
.50139 .00059 Mdot
.50442 .00188 Mdot
.51409 .00597 Mdot
.54486 .01902 Mdot
.64203 .06006 Mdot
.92508 .17493 Mdot
.3164 .24185 Mdot
.48947 .10696 Mdot
.64676 .09721 Mdot
.99429 .21479 Mdot
.35038 .22008 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53224 .01367 Mdot
.60238 .04335 Mdot
.81573 .13185 Mdot
.24773 .26699 Mdot
.44103 .11946 Mdot
.54788 .06604 Mdot
.72548 .10976 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50325 .00138 Mdot
.51035 .00439 Mdot
.53298 .01398 Mdot
.60471 .04433 Mdot
.82242 .13455 Mdot
.25457 .26708 Mdot
.44809 .1196 Mdot
.56511 .07232 Mdot
.7771 .13102 Mdot
.22437 .27643 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52611 .01107 Mdot
.583 .03516 Mdot
.75882 .10866 Mdot
.17301 .25598 Mdot
.37586 .12537 Mdot
.41081 .0216 Mdot
.31887 .56121 Mdot
.0102 .42727 Mdot
.68624 .41782 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.5048 .00203 Mdot
.51528 .00648 Mdot
.54865 .02062 Mdot
.65387 .06503 Mdot
.95558 .18647 Mdot
.32306 .22712 Mdot
.47652 .09485 Mdot
.59489 .07316 Mdot
.84732 .15601 Mdot
.29522 .27682 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.50509 .00216 Mdot
.51622 .00688 Mdot
.55163 .02189 Mdot
.66314 .06892 Mdot
.97871 .19503 Mdot
.32612 .21471 Mdot
.46158 .08372 Mdot
.53996 .04845 Mdot
.67767 .08511 Mdot
.02988 .21768 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48789 .6129 Mdot
.46143 .60168 Mdot
.37767 .56627 Mdot
.12795 .4637 Mdot
.70633 .35745 Mdot
.5145 .49948 Mdot
.34439 .5129 Mdot
.97633 .39056 Mdot
.64364 .41242 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48105 .61 Mdot
.43969 .59247 Mdot
.31003 .5379 Mdot
.95841 .40072 Mdot
.66847 .43884 Mdot
.58662 .56745 Mdot
.62837 .0258 Mdot
.84246 .13232 Mdot
.25612 .25566 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51786 .00757 Mdot
.55685 .0241 Mdot
.67932 .07569 Mdot
.01736 .20892 Mdot
.32941 .19286 Mdot
.43184 .0633 Mdot
.43511 .00202 Mdot
.34373 .56155 Mdot
.05382 .43886 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51253 .00532 Mdot
.53992 .01692 Mdot
.62654 .05354 Mdot
.88361 .15888 Mdot
.30011 .25741 Mdot
.48962 .11712 Mdot
.66356 .1075 Mdot
.04187 .23381 Mdot
.49977 .61794 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47662 .60812 Mdot
.42562 .58652 Mdot
.26709 .52005 Mdot
.87119 .37336 Mdot
.64809 .48015 Mdot
.61645 .59847 Mdot
.74429 .07901 Mdot
.49949 .61782 Mdot
.49836 .61734 Mdot
.49478 .61582 Mdot
.48337 .61098 Mdot
.44706 .5956 Mdot
.33281 .54742 Mdot
.01142 .4194 Mdot
.67291 .40883 Mdot
.54568 .5394 Mdot
.48603 .58117 Mdot
.40544 .56823 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50412 .00175 Mdot
.51314 .00557 Mdot
.54184 .01774 Mdot
.63259 .05609 Mdot
.9 .16527 Mdot
.30774 .25199 Mdot
.49227 .11405 Mdot
.66522 .10689 Mdot
.04382 .23399 Mdot
.35752 .19387 Mdot
.49996 .61802 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.4986 .61744 Mdot
.49554 .61614 Mdot
.48579 .61201 Mdot
.45475 .59885 Mdot
.35674 .55746 Mdot
.07172 .44188 Mdot
.68272 .37762 Mdot
.51144 .51218 Mdot
.49829 .61731 Mdot
.49455 .61572 Mdot
.48263 .61067 Mdot
.4447 .59459 Mdot
.32548 .54435 Mdot
.99387 .41309 Mdot
.67146 .41877 Mdot
.55929 .54871 Mdot
.534 .60241 Mdot
.55933 .01566 Mdot
.67162 .0694 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.52301 .00976 Mdot
.57318 .03101 Mdot
.7293 .09649 Mdot
.12214 .24279 Mdot
.34923 .14035 Mdot
.3825 .02056 Mdot
.2551 .5393 Mdot
.8891 .39183 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.4913 .61434 Mdot
.47229 .60628 Mdot
.41192 .58072 Mdot
.22606 .50317 Mdot
.80417 .35729 Mdot
.60731 .49637 Mdot
.55951 .58849 Mdot
.5989 .02435 Mdot
.77728 .11024 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.47953 .60935 Mdot
.43486 .59043 Mdot
.2952 .53172 Mdot
.92637 .39008 Mdot
.66409 .45593 Mdot
.60659 .5825 Mdot
.69728 .05605 Mdot
.01373 .19558 Mdot
.30961 .18286 Mdot
.4987 .61748 Mdot
.49585 .61628 Mdot
.48679 .61243 Mdot
.45793 .6002 Mdot
.36669 .56165 Mdot
.09806 .45201 Mdot
.69147 .36675 Mdot
.50766 .50443 Mdot
.33532 .51152 Mdot
.95774 .38468 Mdot
.64281 .42339 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50798 .00339 Mdot
.52543 .01078 Mdot
.58087 .03426 Mdot
.75244 .10604 Mdot
.16273 .25357 Mdot
.36928 .12766 Mdot
.40107 .01965 Mdot
.29383 .55176 Mdot
.95685 .40977 Mdot
.68381 .44928 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50274 .00116 Mdot
.50874 .0037 Mdot
.52783 .0118 Mdot
.58846 .03747 Mdot
.77504 .11531 Mdot
.1974 .26104 Mdot
.39396 .12148 Mdot
.44295 .03028 Mdot
.4082 .59656 Mdot
.24326 .51609 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49774 .61707 Mdot
.49279 .61497 Mdot
.47702 .60829 Mdot
.42689 .58705 Mdot
.27092 .52164 Mdot
.87827 .37536 Mdot
.65093 .47753 Mdot
.61754 .5974 Mdot
.74487 .07869 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50527 .00223 Mdot
.51678 .00712 Mdot
.55343 .02265 Mdot
.66872 .07125 Mdot
.99227 .19997 Mdot
.32742 .20713 Mdot
.45152 .0767 Mdot
.50401 .03244 Mdot
.56252 .03616 Mdot
.71243 .09265 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53216 .01364 Mdot
.60215 .04325 Mdot
.81506 .13158 Mdot
.24703 .26697 Mdot
.44031 .11945 Mdot
.54613 .0654 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50669 .00284 Mdot
.52131 .00904 Mdot
.56781 .02874 Mdot
.71298 .08972 Mdot
.09046 .23329 Mdot
.33943 .15388 Mdot
.38639 .02902 Mdot
.27703 .55045 Mdot
.93238 .40503 Mdot
.68613 .46584 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00283 Mdot
.52123 .009 Mdot
.56753 .02862 Mdot
.71212 .08936 Mdot
.08872 .23275 Mdot
.33902 .1547 Mdot
.38697 .02964 Mdot
.27929 .55148 Mdot
.9369 .40643 Mdot
.6867 .4634 Mdot
.49801 .61719 Mdot
.49365 .61534 Mdot
.47976 .60945 Mdot
.43561 .59074 Mdot
.29748 .53267 Mdot
.93117 .39164 Mdot
.66491 .45348 Mdot
.60408 .58044 Mdot
.68848 .05216 Mdot
.99399 .18882 Mdot
.30852 .19439 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50495 .0021 Mdot
.51577 .00669 Mdot
.5502 .02128 Mdot
.65868 .06705 Mdot
.96767 .19096 Mdot
.32482 .22073 Mdot
.46914 .08919 Mdot
.56745 .06076 Mdot
.49797 .61717 Mdot
.49352 .61529 Mdot
.47937 .60929 Mdot
.43435 .59021 Mdot
.29363 .53107 Mdot
.9231 .38903 Mdot
.66348 .45758 Mdot
.60818 .58385 Mdot
.70293 .05856 Mdot
.02604 .1997 Mdot
.31027 .17566 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47834 .60885 Mdot
.4311 .58883 Mdot
.28369 .52693 Mdot
.90289 .38268 Mdot
.65888 .46723 Mdot
.61553 .59124 Mdot
.73066 .07115 Mdot
.08276 .21761 Mdot
.31624 .1443 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51854 .00786 Mdot
.55901 .02501 Mdot
.68599 .07848 Mdot
.03266 .21425 Mdot
.33068 .18419 Mdot
.41999 .0552 Mdot
.39427 .60214 Mdot
.22136 .51117 Mdot
.81358 .36601 Mdot
.49939 .61778 Mdot
.49806 .61721 Mdot
.49383 .61542 Mdot
.48036 .60971 Mdot
.4375 .59154 Mdot
.30327 .53508 Mdot
.94356 .39572 Mdot
.66675 .44696 Mdot
.59674 .57477 Mdot
.66308 .041 Mdot
.93343 .16708 Mdot
.49883 .61754 Mdot
.49629 .61646 Mdot
.48817 .61302 Mdot
.46233 .60206 Mdot
.38052 .56747 Mdot
.13584 .46682 Mdot
.71126 .35563 Mdot
.51837 .49882 Mdot
.35298 .51581 Mdot
.9971 .39809 Mdot
.64557 .40078 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.51091 .00462 Mdot
.53473 .01473 Mdot
.61025 .04667 Mdot
.83822 .1409 Mdot
.26918 .26635 Mdot
.46314 .11987 Mdot
.60231 .08601 Mdot
.49943 .61779 Mdot
.49817 .61726 Mdot
.49418 .61557 Mdot
.48145 .61017 Mdot
.44097 .59302 Mdot
.31397 .53954 Mdot
.96726 .40375 Mdot
.66931 .4339 Mdot
.58008 .56288 Mdot
.60595 .01599 Mdot
.77927 .10712 Mdot
.5008 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.52572 .0109 Mdot
.58177 .03464 Mdot
.75516 .10716 Mdot
.16715 .25463 Mdot
.37203 .12662 Mdot
.40499 .02037 Mdot
.30375 .55546 Mdot
.97726 .41625 Mdot
.68476 .43726 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51726 .00732 Mdot
.55495 .02329 Mdot
.67345 .07323 Mdot
.00359 .20404 Mdot
.32835 .20071 Mdot
.44272 .07069 Mdot
.47301 .01872 Mdot
.49752 .61698 Mdot
.4921 .61469 Mdot
.47485 .60737 Mdot
.42002 .58415 Mdot
.25022 .51309 Mdot
.84169 .36555 Mdot
.63335 .48928 Mdot
.60245 .59894 Mdot
.71484 .06946 Mdot
.06015 .21342 Mdot
.31737 .15897 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.48488 .61162 Mdot
.45188 .59763 Mdot
.34777 .5537 Mdot
.04859 .43313 Mdot
.67765 .38878 Mdot
.52119 .52134 Mdot
.39643 .54093 Mdot
.12704 .45154 Mdot
.6867 .34588 Mdot
.4992 .61769 Mdot
.49744 .61695 Mdot
.49183 .61457 Mdot
.47398 .607 Mdot
.41728 .58299 Mdot
.242 .50971 Mdot
.82829 .36235 Mdot
.62501 .4924 Mdot
.59054 .59673 Mdot
.68468 .05818 Mdot
.99773 .19347 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48373 .61114 Mdot
.44821 .59608 Mdot
.33638 .54891 Mdot
.02011 .42257 Mdot
.67376 .40398 Mdot
.53927 .53492 Mdot
.46309 .57095 Mdot
.33205 .53704 Mdot
.99329 .40867 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52198 .00932 Mdot
.56994 .02964 Mdot
.71945 .0924 Mdot
.10331 .23724 Mdot
.34286 .14805 Mdot
.38318 .02492 Mdot
.26357 .54412 Mdot
.90611 .39711 Mdot
.68145 .47919 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50777 .0033 Mdot
.52476 .0105 Mdot
.57874 .03336 Mdot
.74608 .10342 Mdot
.15207 .25092 Mdot
.36312 .13043 Mdot
.39323 .01861 Mdot
.27494 .54492 Mdot
.92084 .39919 Mdot
.68064 .46959 Mdot
.49932 .61774 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47791 .60867 Mdot
.42971 .58825 Mdot
.27948 .52519 Mdot
.8946 .38017 Mdot
.65651 .47089 Mdot
.61715 .5937 Mdot
.73806 .07473 Mdot
.09702 .22186 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.51689 .00716 Mdot
.55377 .02279 Mdot
.66977 .07169 Mdot
.9948 .20088 Mdot
.32763 .2057 Mdot
.44957 .07536 Mdot
.49713 .02939 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61477 Mdot
.47545 .60763 Mdot
.42194 .58496 Mdot
.25597 .51546 Mdot
.85144 .36802 Mdot
.63877 .4866 Mdot
.60886 .59955 Mdot
.72981 .07475 Mdot
.49816 .61725 Mdot
.49413 .61555 Mdot
.48131 .61011 Mdot
.44053 .59283 Mdot
.3126 .53897 Mdot
.96416 .40269 Mdot
.66903 .43563 Mdot
.5824 .56449 Mdot
.61392 .01948 Mdot
.80209 .1163 Mdot
.21632 .25601 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50588 .00249 Mdot
.51874 .00795 Mdot
.55963 .02528 Mdot
.6879 .07927 Mdot
.03696 .21573 Mdot
.33108 .18177 Mdot
.41677 .05296 Mdot
.38323 .5973 Mdot
.18983 .49851 Mdot
.77456 .36138 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52235 .00948 Mdot
.5711 .03013 Mdot
.723 .09388 Mdot
.11019 .2393 Mdot
.34499 .14511 Mdot
.38234 .02308 Mdot
.25883 .5417 Mdot
.89696 .39439 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50963 .00408 Mdot
.53068 .01301 Mdot
.59745 .04127 Mdot
.80144 .12607 Mdot
.2318 .26598 Mdot
.42499 .1194 Mdot
.50978 .0524 Mdot
.60923 .06146 Mdot
.49753 .61698 Mdot
.49212 .61469 Mdot
.47489 .60738 Mdot
.42014 .5842 Mdot
.25057 .51323 Mdot
.84226 .36569 Mdot
.63369 .48913 Mdot
.60288 .599 Mdot
.71588 .06983 Mdot
.06214 .214 Mdot
.31754 .15785 Mdot
.49907 .61764 Mdot
.49702 .61677 Mdot
.49052 .61401 Mdot
.46979 .60523 Mdot
.40403 .57739 Mdot
.20288 .49372 Mdot
.77338 .35259 Mdot
.58005 .49855 Mdot
.50178 .56966 Mdot
.42619 .57132 Mdot
.24382 .50532 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50996 .00422 Mdot
.53172 .01345 Mdot
.60075 .04266 Mdot
.811 .12994 Mdot
.24266 .26678 Mdot
.43585 .1194 Mdot
.5354 .06152 Mdot
.4998 .61795 Mdot
.49938 .61777 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47985 .60949 Mdot
.43587 .59085 Mdot
.29828 .533 Mdot
.93285 .39219 Mdot
.66519 .45261 Mdot
.60315 .5797 Mdot
.68524 .05073 Mdot
.49833 .61732 Mdot
.49467 .61577 Mdot
.48301 .61083 Mdot
.44591 .59511 Mdot
.32922 .54592 Mdot
.00278 .41628 Mdot
.67217 .41371 Mdot
.5523 .54395 Mdot
.50949 .59157 Mdot
.48091 .60037 Mdot
.42375 .58271 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52335 .0099 Mdot
.57426 .03147 Mdot
.73257 .09784 Mdot
.12817 .2445 Mdot
.35164 .13811 Mdot
.38342 .01964 Mdot
.25556 .53901 Mdot
.88911 .39156 Mdot
.67586 .48624 Mdot
.49863 .61745 Mdot
.49565 .61619 Mdot
.48614 .61216 Mdot
.45587 .59932 Mdot
.36024 .55893 Mdot
.0809 .44539 Mdot
.68537 .37358 Mdot
.50915 .50913 Mdot
.34665 .5176 Mdot
.9881 .39644 Mdot
.64738 .40746 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50741 .00314 Mdot
.52361 .01001 Mdot
.57508 .03181 Mdot
.73504 .09886 Mdot
.13268 .24576 Mdot
.35357 .13651 Mdot
.3845 .01912 Mdot
.257 .53923 Mdot
.891 .39183 Mdot
.67601 .48517 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.5155 .00657 Mdot
.54933 .02091 Mdot
.656 .06592 Mdot
.96094 .18847 Mdot
.32389 .22431 Mdot
.47337 .09239 Mdot
.58311 .06782 Mdot
.81191 .14141 Mdot
.26161 .27793 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50763 .00323 Mdot
.52429 .0103 Mdot
.57726 .03273 Mdot
.74161 .10157 Mdot
.14436 .24891 Mdot
.35907 .1327 Mdot
.38894 .01846 Mdot
.2654 .54169 Mdot
.90426 .39483 Mdot
.67822 .47833 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50349 .00148 Mdot
.51111 .00471 Mdot
.53538 .015 Mdot
.61228 .04753 Mdot
.84397 .14319 Mdot
.27398 .26576 Mdot
.46796 .11989 Mdot
.61419 .09038 Mdot
.9174 .18739 Mdot
.33902 .26057 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50693 .00294 Mdot
.52209 .00937 Mdot
.57028 .02978 Mdot
.7205 .09284 Mdot
.10537 .23786 Mdot
.34348 .14716 Mdot
.38286 .02434 Mdot
.26197 .54332 Mdot
.90302 .39619 Mdot
.68071 .48064 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51256 .00533 Mdot
.54001 .01696 Mdot
.62684 .05366 Mdot
.88442 .15919 Mdot
.30053 .25717 Mdot
.48984 .117 Mdot
.6639 .10758 Mdot
.04262 .23406 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51846 .00783 Mdot
.55876 .02491 Mdot
.68522 .07815 Mdot
.03091 .21365 Mdot
.33052 .18517 Mdot
.42132 .05611 Mdot
.39883 .60414 Mdot
.23461 .51654 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00305 Mdot
.52288 .0097 Mdot
.57278 .03084 Mdot
.72808 .09598 Mdot
.11986 .24213 Mdot
.34836 .14123 Mdot
.3823 .02098 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47345 .60677 Mdot
.41558 .58227 Mdot
.23694 .50763 Mdot
.82038 .36058 Mdot
.61958 .49393 Mdot
.58175 .59465 Mdot
.66121 .04911 Mdot
.94322 .17429 Mdot
.3086 .22582 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50585 .00248 Mdot
.51863 .0079 Mdot
.55928 .02513 Mdot
.68682 .07882 Mdot
.03452 .21489 Mdot
.33085 .18314 Mdot
.41859 .05423 Mdot
.38946 .60003 Mdot
.20755 .5056 Mdot
.49863 .61745 Mdot
.49563 .61618 Mdot
.48606 .61212 Mdot
.45562 .59922 Mdot
.35947 .55861 Mdot
.07885 .44461 Mdot
.68474 .37446 Mdot
.50957 .50977 Mdot
.34876 .51864 Mdot
.99371 .3986 Mdot
.6481 .40443 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.52571 .0109 Mdot
.58174 .03463 Mdot
.75506 .10712 Mdot
.16699 .25459 Mdot
.37193 .12666 Mdot
.40484 .02034 Mdot
.30336 .55532 Mdot
.97645 .41599 Mdot
.68473 .43774 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00342 Mdot
.52566 .01088 Mdot
.58158 .03456 Mdot
.75457 .10692 Mdot
.1662 .2544 Mdot
.37143 .12684 Mdot
.40412 .0202 Mdot
.30151 .55462 Mdot
.49979 .61794 Mdot
.49933 .61775 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47833 .60885 Mdot
.43107 .58882 Mdot
.28361 .5269 Mdot
.90272 .38263 Mdot
.65883 .4673 Mdot
.61557 .5913 Mdot
.73083 .07123 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49399 .61549 Mdot
.48086 .60992 Mdot
.43909 .59222 Mdot
.30815 .53711 Mdot
.95425 .39931 Mdot
.66803 .44114 Mdot
.58957 .56955 Mdot
.6385 .03024 Mdot
.86993 .14303 Mdot
.49921 .6177 Mdot
.4975 .61697 Mdot
.49203 .61465 Mdot
.4746 .60727 Mdot
.41925 .58382 Mdot
.24789 .51213 Mdot
.83782 .3646 Mdot
.63105 .49025 Mdot
.59939 .59847 Mdot
.70731 .0667 Mdot
.04542 .20896 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00348 Mdot
.52617 .0111 Mdot
.5832 .03525 Mdot
.75942 .10891 Mdot
.17396 .2562 Mdot
.3765 .12518 Mdot
.41182 .02183 Mdot
.32154 .56224 Mdot
.01623 .42935 Mdot
.68662 .41432 Mdot
.49964 .61788 Mdot
.49884 .61754 Mdot
.49632 .61647 Mdot
.48826 .61306 Mdot
.46261 .60218 Mdot
.3814 .56784 Mdot
.1383 .46779 Mdot
.71289 .35512 Mdot
.51975 .49867 Mdot
.35616 .51693 Mdot
.005 .40101 Mdot
.49772 .61707 Mdot
.49272 .61495 Mdot
.47681 .6082 Mdot
.42624 .58678 Mdot
.26894 .52082 Mdot
.8746 .37432 Mdot
.64949 .47891 Mdot
.61707 .598 Mdot
.74485 .07897 Mdot
.11124 .22644 Mdot
.32402 .13151 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50556 .00236 Mdot
.51771 .00751 Mdot
.55638 .0239 Mdot
.67787 .07508 Mdot
.01399 .20773 Mdot
.32915 .19478 Mdot
.4345 .06511 Mdot
.44434 .00608 Mdot
.37237 .57356 Mdot
.12884 .46752 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51513 .00642 Mdot
.54818 .02042 Mdot
.65238 .0644 Mdot
.95181 .18506 Mdot
.32242 .22905 Mdot
.47859 .09652 Mdot
.60275 .07673 Mdot
.49868 .61748 Mdot
.49581 .61626 Mdot
.48664 .61237 Mdot
.45746 .6 Mdot
.36522 .56103 Mdot
.09413 .45049 Mdot
.68993 .36822 Mdot
.50766 .50538 Mdot
.33688 .51249 Mdot
.96207 .38639 Mdot
.64361 .42122 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48013 .60961 Mdot
.43676 .59123 Mdot
.30101 .53413 Mdot
.93868 .3941 Mdot
.66607 .44955 Mdot
.59977 .57706 Mdot
.67351 .04557 Mdot
.95893 .1764 Mdot
.30528 .21405 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51563 .00663 Mdot
.54977 .0211 Mdot
.65735 .06649 Mdot
.96433 .18973 Mdot
.32437 .22252 Mdot
.47128 .09079 Mdot
.57533 .06431 Mdot
.7882 .13156 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50455 .00193 Mdot
.5145 .00615 Mdot
.54616 .01957 Mdot
.6461 .06177 Mdot
.93568 .17897 Mdot
.31914 .23699 Mdot
.48603 .10315 Mdot
.632 .09021 Mdot
.95403 .19903 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.4778 .60862 Mdot
.42938 .58811 Mdot
.27846 .52476 Mdot
.89262 .37957 Mdot
.6559 .47174 Mdot
.6174 .59424 Mdot
.73945 .07543 Mdot
.49828 .6173 Mdot
.49451 .6157 Mdot
.4825 .61061 Mdot
.44429 .59442 Mdot
.32422 .54382 Mdot
.9909 .41203 Mdot
.67123 .42047 Mdot
.56164 .5503 Mdot
.5422 .60602 Mdot
.58534 .02666 Mdot
.75043 .10203 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50642 .00272 Mdot
.52047 .00868 Mdot
.56512 .0276 Mdot
.70475 .0863 Mdot
.07353 .22792 Mdot
.3359 .16215 Mdot
.39346 .03558 Mdot
.3029 .56206 Mdot
.98666 .42259 Mdot
.69041 .43494 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.50912 .00387 Mdot
.52906 .01232 Mdot
.59235 .03912 Mdot
.78653 .12001 Mdot
.21318 .26368 Mdot
.40745 .12007 Mdot
.4706 .03903 Mdot
.4899 .01193 Mdot
.49406 .00257 Mdot
.50064 .00027 Mdot
.50202 .00086 Mdot
.50645 .00273 Mdot
.52054 .00871 Mdot
.56534 .02769 Mdot
.70544 .08658 Mdot
.07497 .22838 Mdot
.33616 .16142 Mdot
.39275 .03497 Mdot
.30037 .56094 Mdot
.98111 .42072 Mdot
.69012 .43819 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51074 .00455 Mdot
.53421 .0145 Mdot
.60859 .04597 Mdot
.8335 .139 Mdot
.26504 .2667 Mdot
.45891 .11982 Mdot
.59182 .08214 Mdot
.85495 .16262 Mdot
.49932 .61775 Mdot
.49783 .61711 Mdot
.49309 .6151 Mdot
.47799 .6087 Mdot
.42998 .58836 Mdot
.28029 .52552 Mdot
.89618 .38064 Mdot
.65699 .4702 Mdot
.61691 .59326 Mdot
.73684 .07412 Mdot
.09468 .22116 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50283 .0012 Mdot
.50901 .00382 Mdot
.52871 .01218 Mdot
.59125 .03865 Mdot
.78329 .11869 Mdot
.20886 .26302 Mdot
.40363 .12037 Mdot
.46251 .03639 Mdot
.46566 .00195 Mdot
.41771 .5884 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48802 .61296 Mdot
.46186 .60186 Mdot
.37902 .56684 Mdot
.1317 .46518 Mdot
.70861 .35655 Mdot
.51623 .49914 Mdot
.34816 .51416 Mdot
.98533 .3938 Mdot
.64448 .40737 Mdot
.49908 .61764 Mdot
.49706 .61679 Mdot
.49064 .61406 Mdot
.47019 .60539 Mdot
.40527 .57791 Mdot
.20651 .49519 Mdot
.77787 .35312 Mdot
.58431 .49841 Mdot
.51139 .57297 Mdot
.45555 .58352 Mdot
.33388 .54284 Mdot
.49941 .61779 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48104 .60999 Mdot
.43965 .59245 Mdot
.30988 .53783 Mdot
.95808 .40061 Mdot
.66844 .43903 Mdot
.58685 .56761 Mdot
.62919 .02616 Mdot
.84471 .1332 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47982 .60948 Mdot
.43579 .59082 Mdot
.29802 .53289 Mdot
.93231 .39201 Mdot
.6651 .45289 Mdot
.60345 .57994 Mdot
.68629 .0512 Mdot
.98899 .18708 Mdot
.30819 .19728 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50528 .00224 Mdot
.51683 .00713 Mdot
.55356 .0227 Mdot
.66913 .07143 Mdot
.99327 .20033 Mdot
.3275 .20657 Mdot
.45075 .07617 Mdot
.50131 .03125 Mdot
.55383 .03246 Mdot
.68556 .08141 Mdot
.50072 .00031 Mdot
.5023 .00097 Mdot
.50732 .0031 Mdot
.52331 .00989 Mdot
.57415 .03142 Mdot
.73224 .0977 Mdot
.12758 .24433 Mdot
.35139 .13832 Mdot
.38331 .01972 Mdot
.25544 .53901 Mdot
.88899 .39155 Mdot
.67587 .48632 Mdot
.49757 .617 Mdot
.49226 .61475 Mdot
.47536 .60758 Mdot
.42163 .58483 Mdot
.25504 .51507 Mdot
.84983 .3676 Mdot
.63791 .48706 Mdot
.60793 .5995 Mdot
.72772 .07403 Mdot
.0839 .22013 Mdot
.31998 .1459 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48031 .60969 Mdot
.43736 .59148 Mdot
.30284 .5349 Mdot
.94262 .39541 Mdot
.66662 .44746 Mdot
.59734 .57521 Mdot
.66512 .04189 Mdot
.93848 .16895 Mdot
.30184 .22457 Mdot
.49939 .61778 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48038 .60972 Mdot
.43757 .59157 Mdot
.30349 .53517 Mdot
.94405 .39588 Mdot
.66681 .44669 Mdot
.59643 .57454 Mdot
.662 .04053 Mdot
.93074 .16609 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50623 .00264 Mdot
.51984 .00841 Mdot
.56313 .02676 Mdot
.69866 .08376 Mdot
.06062 .2237 Mdot
.33383 .16885 Mdot
.40066 .0413 Mdot
.32796 .57311 Mdot
.04462 .44291 Mdot
.69522 .40209 Mdot
.49845 .61738 Mdot
.49507 .61594 Mdot
.48431 .61138 Mdot
.45003 .59685 Mdot
.34204 .55129 Mdot
.03412 .42773 Mdot
.67542 .39634 Mdot
.52971 .52798 Mdot
.42829 .55536 Mdot
.22293 .49111 Mdot
.78227 .34569 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51749 .00742 Mdot
.55568 .0236 Mdot
.67571 .07418 Mdot
.00892 .20594 Mdot
.32876 .19767 Mdot
.43851 .06783 Mdot
.45829 .01223 Mdot
.41623 .59204 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48053 .60978 Mdot
.43805 .59178 Mdot
.30498 .53579 Mdot
.94729 .39696 Mdot
.66722 .44494 Mdot
.59432 .57298 Mdot
.65476 .03735 Mdot
.91245 .15926 Mdot
.29494 .23639 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.5041 .00174 Mdot
.51305 .00553 Mdot
.54155 .01761 Mdot
.63167 .0557 Mdot
.89752 .16431 Mdot
.30669 .25288 Mdot
.49211 .11459 Mdot
.66569 .10728 Mdot
.04528 .2346 Mdot
.35786 .19319 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50607 .00257 Mdot
.51933 .0082 Mdot
.56151 .02607 Mdot
.69368 .08168 Mdot
.04979 .22009 Mdot
.33243 .17468 Mdot
.40764 .04649 Mdot
.35196 .58362 Mdot
.10489 .46534 Mdot
.49747 .61696 Mdot
.49192 .61461 Mdot
.47428 .60713 Mdot
.41821 .58338 Mdot
.24479 .51085 Mdot
.83277 .36339 Mdot
.62791 .49143 Mdot
.59493 .59765 Mdot
.69606 .0625 Mdot
.02234 .20165 Mdot
.31522 .18101 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50295 .00125 Mdot
.50939 .00398 Mdot
.52991 .01268 Mdot
.59502 .04024 Mdot
.79434 .12319 Mdot
.22319 .26504 Mdot
.41669 .11959 Mdot
.49085 .04583 Mdot
.5513 .03736 Mdot
.68737 .0841 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00165 Mdot
.51237 .00524 Mdot
.53939 .0167 Mdot
.62488 .05284 Mdot
.87906 .15709 Mdot
.29769 .25872 Mdot
.48822 .11775 Mdot
.6611 .10684 Mdot
.03642 .23196 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51227 .0052 Mdot
.53907 .01656 Mdot
.62389 .05242 Mdot
.87634 .15602 Mdot
.29617 .25947 Mdot
.48724 .11809 Mdot
.65921 .10628 Mdot
.0321 .23046 Mdot
.35717 .20091 Mdot
.49919 .61769 Mdot
.49743 .61694 Mdot
.49182 .61456 Mdot
.47393 .60698 Mdot
.41712 .58292 Mdot
.24153 .50951 Mdot
.82755 .36218 Mdot
.62452 .49255 Mdot
.58978 .59656 Mdot
.68267 .05741 Mdot
.99325 .19195 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00207 Mdot
.51552 .00658 Mdot
.54941 .02094 Mdot
.65622 .06602 Mdot
.96151 .18868 Mdot
.32397 .22401 Mdot
.47303 .09212 Mdot
.58181 .06723 Mdot
.80798 .13978 Mdot
.25722 .27764 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47385 .60694 Mdot
.41685 .58281 Mdot
.24073 .50919 Mdot
.82628 .36189 Mdot
.62367 .49281 Mdot
.58844 .59626 Mdot
.67914 .05606 Mdot
.98531 .18922 Mdot
.31348 .20282 Mdot
.49926 .61772 Mdot
.49765 .61704 Mdot
.49251 .61486 Mdot
.47613 .60791 Mdot
.4241 .58587 Mdot
.26247 .51815 Mdot
.86285 .37105 Mdot
.64442 .48304 Mdot
.61409 .59929 Mdot
.7406 .07819 Mdot
.10544 .22548 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50947 .00402 Mdot
.53017 .01279 Mdot
.59585 .04059 Mdot
.79676 .12417 Mdot
.22618 .26539 Mdot
.41953 .1195 Mdot
.49726 .04804 Mdot
.57087 .0455 Mdot
.74731 .10905 Mdot
.50003 1e-05 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58507 .03604 Mdot
.765 .1112 Mdot
.1826 .25809 Mdot
.38255 .12358 Mdot
.4219 .02432 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00131 Mdot
.50987 .00419 Mdot
.53144 .01333 Mdot
.59987 .04229 Mdot
.80845 .12891 Mdot
.23985 .26662 Mdot
.433 .11937 Mdot
.52859 .05908 Mdot
.66684 .08544 Mdot
.01196 .2133 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50789 .00334 Mdot
.52513 .01065 Mdot
.5799 .03385 Mdot
.74954 .10484 Mdot
.15791 .25239 Mdot
.36641 .12886 Mdot
.39725 .01906 Mdot
.28444 .54831 Mdot
.93846 .40421 Mdot
.68251 .45985 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00127 Mdot
.50951 .00403 Mdot
.53029 .01284 Mdot
.59623 .04075 Mdot
.79787 .12462 Mdot
.22753 .26554 Mdot
.42083 .11947 Mdot
.50022 .04906 Mdot
.57993 .04927 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51067 .00452 Mdot
.53398 .01441 Mdot
.60789 .04567 Mdot
.83151 .13821 Mdot
.26323 .26682 Mdot
.45705 .11979 Mdot
.58722 .08045 Mdot
.84177 .15732 Mdot
.29645 .28101 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50415 .00176 Mdot
.51322 .00561 Mdot
.54211 .01785 Mdot
.63341 .05643 Mdot
.90222 .16613 Mdot
.30864 .25118 Mdot
.49235 .11354 Mdot
.66459 .10645 Mdot
.042 .23325 Mdot
.35714 .19477 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50725 .00308 Mdot
.52311 .0098 Mdot
.5735 .03114 Mdot
.73026 .09688 Mdot
.12392 .2433 Mdot
.34992 .13968 Mdot
.38271 .02027 Mdot
.25507 .53915 Mdot
.88881 .39168 Mdot
.6761 .48657 Mdot
.49961 .61787 Mdot
.49875 .6175 Mdot
.496 .61634 Mdot
.48727 .61263 Mdot
.45945 .60084 Mdot
.37145 .56365 Mdot
.11092 .45702 Mdot
.69716 .36231 Mdot
.50909 .5018 Mdot
.33464 .51022 Mdot
.95443 .38305 Mdot
.49903 .61762 Mdot
.49691 .61672 Mdot
.49016 .61386 Mdot
.46865 .60474 Mdot
.40044 .57587 Mdot
.19242 .48947 Mdot
.76113 .35148 Mdot
.56798 .49866 Mdot
.47374 .55979 Mdot
.34029 .53556 Mdot
.00551 .41113 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50629 .00267 Mdot
.52005 .0085 Mdot
.5638 .02704 Mdot
.7007 .08461 Mdot
.06496 .22513 Mdot
.33447 .16656 Mdot
.39808 .03932 Mdot
.31906 .56919 Mdot
.02343 .43532 Mdot
.69278 .41368 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51214 .00515 Mdot
.53865 .01639 Mdot
.62257 .05187 Mdot
.87271 .15459 Mdot
.29407 .26041 Mdot
.48579 .11849 Mdot
.65621 .10533 Mdot
.0251 .22799 Mdot
.3565 .20481 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.50539 .00229 Mdot
.51718 .00728 Mdot
.55469 .02318 Mdot
.67262 .07289 Mdot
.00162 .20333 Mdot
.32819 .20183 Mdot
.44427 .07174 Mdot
.47844 .02112 Mdot
.48038 .0012 Mdot
.45296 .60109 Mdot
.49832 .61732 Mdot
.49465 .61577 Mdot
.48296 .61081 Mdot
.44575 .59504 Mdot
.32874 .54572 Mdot
.00162 .41586 Mdot
.67207 .41436 Mdot
.5532 .54457 Mdot
.51265 .59298 Mdot
.49107 .60469 Mdot
.4561 .59642 Mdot
.49806 .61721 Mdot
.49383 .61542 Mdot
.48034 .6097 Mdot
.43742 .59151 Mdot
.30304 .53498 Mdot
.94306 .39555 Mdot
.66668 .44722 Mdot
.59706 .575 Mdot
.66416 .04147 Mdot
.93611 .16807 Mdot
.30134 .22572 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.4794 .6093 Mdot
.43446 .59026 Mdot
.29397 .5312 Mdot
.9238 .38925 Mdot
.66361 .45723 Mdot
.60785 .58357 Mdot
.70175 .05804 Mdot
.0235 .19885 Mdot
.31013 .17715 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51624 .00689 Mdot
.5517 .02191 Mdot
.66335 .069 Mdot
.97921 .19521 Mdot
.32617 .21443 Mdot
.46122 .08346 Mdot
.53867 .04787 Mdot
.67354 .08336 Mdot
.02013 .2142 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52444 .01036 Mdot
.57771 .03293 Mdot
.74297 .10214 Mdot
.14673 .24954 Mdot
.36028 .13198 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50994 .00422 Mdot
.53167 .01343 Mdot
.60059 .04259 Mdot
.81054 .12976 Mdot
.24216 .26676 Mdot
.43534 .11939 Mdot
.53417 .06108 Mdot
.68387 .09252 Mdot
.49939 .61778 Mdot
.49805 .61721 Mdot
.4938 .61541 Mdot
.48025 .60966 Mdot
.43716 .5914 Mdot
.30222 .53464 Mdot
.9413 .39497 Mdot
.66644 .44816 Mdot
.59816 .57584 Mdot
.66797 .04314 Mdot
.9455 .17152 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.4275 .58731 Mdot
.27278 .52241 Mdot
.88176 .37637 Mdot
.65223 .47618 Mdot
.61779 .59675 Mdot
.74434 .07821 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50357 .00152 Mdot
.51139 .00483 Mdot
.53626 .01538 Mdot
.61507 .0487 Mdot
.85183 .14633 Mdot
.2801 .26469 Mdot
.4739 .11977 Mdot
.62872 .09569 Mdot
.95625 .20243 Mdot
.34858 .24247 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50831 .00353 Mdot
.52649 .01123 Mdot
.5842 .03567 Mdot
.76242 .11014 Mdot
.17864 .25724 Mdot
.37972 .12428 Mdot
.41708 .02309 Mdot
.33562 .56769 Mdot
.4975 .61697 Mdot
.49204 .61466 Mdot
.47463 .60728 Mdot
.41933 .58385 Mdot
.24813 .51223 Mdot
.83821 .36469 Mdot
.63129 .49015 Mdot
.59972 .59852 Mdot
.70812 .067 Mdot
.04704 .20946 Mdot
.31642 .16649 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51495 .00634 Mdot
.54761 .02018 Mdot
.65061 .06366 Mdot
.94728 .18335 Mdot
.32159 .23134 Mdot
.48093 .09847 Mdot
.61172 .08084 Mdot
.89668 .17611 Mdot
.32596 .26531 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48389 .6112 Mdot
.44872 .59629 Mdot
.33794 .54957 Mdot
.02396 .42398 Mdot
.67417 .40186 Mdot
.53654 .53297 Mdot
.45322 .56654 Mdot
.30075 .5238 Mdot
.92158 .38369 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.51941 .00823 Mdot
.56176 .02617 Mdot
.69444 .082 Mdot
.05144 .22064 Mdot
.33262 .17378 Mdot
.40652 .04567 Mdot
.34814 .58195 Mdot
.09498 .46157 Mdot
.70766 .37866 Mdot
.49765 .61704 Mdot
.49252 .61486 Mdot
.47617 .60793 Mdot
.4242 .58592 Mdot
.26278 .51827 Mdot
.86339 .3712 Mdot
.64467 .48286 Mdot
.61428 .59925 Mdot
.74095 .07829 Mdot
.10596 .22559 Mdot
.32352 .13446 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.4853 .6118 Mdot
.45319 .59819 Mdot
.35189 .55542 Mdot
.05912 .43709 Mdot
.6797 .38354 Mdot
.51609 .51692 Mdot
.37659 .53182 Mdot
.06997 .42853 Mdot
.66174 .36574 Mdot
.49999 .61803 Mdot
.49997 .61802 Mdot
.49989 .61799 Mdot
.49965 .61788 Mdot
.49887 .61756 Mdot
.49642 .61651 Mdot
.48858 .61319 Mdot
.46362 .60261 Mdot
.38458 .56918 Mdot
.14718 .47132 Mdot
.71916 .3535 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.47952 .60935 Mdot
.43483 .59041 Mdot
.29509 .53167 Mdot
.92613 .39001 Mdot
.66404 .45606 Mdot
.60671 .5826 Mdot
.69771 .05624 Mdot
.01468 .1959 Mdot
.30966 .18231 Mdot
.498 .61719 Mdot
.49364 .61533 Mdot
.47972 .60944 Mdot
.43548 .59069 Mdot
.29709 .5325 Mdot
.93033 .39137 Mdot
.66477 .45391 Mdot
.60453 .5808 Mdot
.69005 .05286 Mdot
.99758 .19006 Mdot
.30873 .19231 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00212 Mdot
.51596 .00677 Mdot
.55082 .02154 Mdot
.66063 .06786 Mdot
.97251 .19275 Mdot
.32542 .21811 Mdot
.46591 .08683 Mdot
.55564 .05546 Mdot
.72716 .106 Mdot
.13495 .25203 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48306 .61085 Mdot
.44608 .59518 Mdot
.32977 .54615 Mdot
.00408 .41675 Mdot
.67227 .41297 Mdot
.55129 .54326 Mdot
.50593 .59 Mdot
.46946 .59549 Mdot
.38746 .56735 Mdot
.49863 .61745 Mdot
.49565 .61619 Mdot
.48613 .61215 Mdot
.45585 .59932 Mdot
.36019 .55891 Mdot
.08076 .44534 Mdot
.68532 .37364 Mdot
.50918 .50917 Mdot
.34679 .51768 Mdot
.98849 .39659 Mdot
.64743 .40725 Mdot
.49943 .61779 Mdot
.4982 .61727 Mdot
.49425 .6156 Mdot
.48169 .61027 Mdot
.44173 .59334 Mdot
.31632 .54052 Mdot
.97259 .4056 Mdot
.66978 .43088 Mdot
.576 .56008 Mdot
.59195 .00986 Mdot
.73828 .09044 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52545 .01079 Mdot
.58092 .03428 Mdot
.7526 .10611 Mdot
.16299 .25363 Mdot
.36944 .12759 Mdot
.40128 .01968 Mdot
.29437 .55196 Mdot
.95795 .41011 Mdot
.68387 .44865 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47344 .60677 Mdot
.41557 .58226 Mdot
.23689 .50761 Mdot
.8203 .36056 Mdot
.61953 .49395 Mdot
.58166 .59463 Mdot
.66097 .04902 Mdot
.94262 .17407 Mdot
.30849 .22612 Mdot
.49794 .61716 Mdot
.49345 .61526 Mdot
.47913 .60919 Mdot
.43361 .5899 Mdot
.29136 .53012 Mdot
.9184 .38753 Mdot
.66254 .45991 Mdot
.61028 .58573 Mdot
.71051 .06194 Mdot
.04215 .20497 Mdot
.31131 .16635 Mdot
.49884 .61754 Mdot
.49629 .61646 Mdot
.48818 .61302 Mdot
.46237 .60208 Mdot
.38064 .56752 Mdot
.13618 .46695 Mdot
.71148 .35556 Mdot
.51855 .4988 Mdot
.3534 .51596 Mdot
.99814 .39847 Mdot
.64567 .4002 Mdot
.49828 .6173 Mdot
.49452 .61571 Mdot
.48255 .61063 Mdot
.44444 .59448 Mdot
.32467 .54402 Mdot
.99198 .41242 Mdot
.67131 .41985 Mdot
.56078 .54972 Mdot
.53923 .60471 Mdot
.57592 .02268 Mdot
.72221 .09042 Mdot
.49999 .61803 Mdot
.49996 .61802 Mdot
.49987 .61798 Mdot
.49958 .61785 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.48629 .61222 Mdot
.45636 .59953 Mdot
.36177 .55958 Mdot
.08495 .44695 Mdot
.68667 .37188 Mdot
.50008 4e-05 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50854 .00362 Mdot
.5272 .01153 Mdot
.58647 .03663 Mdot
.76916 .11291 Mdot
.18885 .25938 Mdot
.38721 .1226 Mdot
.4302 .02657 Mdot
.37183 .58196 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50661 .0028 Mdot
.52105 .00893 Mdot
.56697 .02838 Mdot
.71042 .08865 Mdot
.08525 .23166 Mdot
.33824 .15635 Mdot
.38824 .03091 Mdot
.28406 .55364 Mdot
.94658 .40946 Mdot
.68774 .45806 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.5036 .00153 Mdot
.51146 .00486 Mdot
.53649 .01547 Mdot
.61579 .04901 Mdot
.85384 .14712 Mdot
.28159 .26436 Mdot
.47529 .11972 Mdot
.63209 .0969 Mdot
.96504 .20578 Mdot
.35001 .23792 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00202 Mdot
.51515 .00642 Mdot
.54823 .02045 Mdot
.65256 .06448 Mdot
.95225 .18522 Mdot
.3225 .22883 Mdot
.47836 .09633 Mdot
.60185 .07632 Mdot
.86791 .16443 Mdot
.31013 .2733 Mdot
.49738 .61692 Mdot
.49165 .61449 Mdot
.47341 .60676 Mdot
.41546 .58222 Mdot
.23658 .50748 Mdot
.81981 .36046 Mdot
.61918 .49404 Mdot
.58107 .59448 Mdot
.65938 .0484 Mdot
.93875 .17266 Mdot
.30775 .22805 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.5062 .00263 Mdot
.51976 .00838 Mdot
.56287 .02665 Mdot
.69786 .08343 Mdot
.05889 .22313 Mdot
.33358 .16977 Mdot
.40172 .04211 Mdot
.33162 .57471 Mdot
.0535 .44615 Mdot
.69663 .39748 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52317 .00983 Mdot
.5737 .03123 Mdot
.73088 .09714 Mdot
.12507 .24362 Mdot
.35037 .13925 Mdot
.38287 .02009 Mdot
.25512 .53908 Mdot
.88876 .39161 Mdot
.676 .48654 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54656 .01974 Mdot
.64736 .06229 Mdot
.93893 .1802 Mdot
.31988 .23544 Mdot
.48473 .10189 Mdot
.62673 .08776 Mdot
.93936 .19322 Mdot
.4981 .61723 Mdot
.49393 .61546 Mdot
.48066 .60984 Mdot
.43847 .59195 Mdot
.30625 .53632 Mdot
.95006 .3979 Mdot
.66756 .44343 Mdot
.59246 .57162 Mdot
.64838 .03456 Mdot
.896 .15304 Mdot
.28875 .24273 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50531 .00225 Mdot
.51693 .00718 Mdot
.55388 .02284 Mdot
.67013 .07184 Mdot
.99566 .20119 Mdot
.3277 .20521 Mdot
.44891 .07491 Mdot
.49478 .02835 Mdot
.53283 .02351 Mdot
.61976 .05373 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.53569 .01513 Mdot
.61327 .04794 Mdot
.84676 .14431 Mdot
.27621 .26541 Mdot
.47015 .11986 Mdot
.61959 .09236 Mdot
.932 .19308 Mdot
.34334 .25422 Mdot
.49784 .61712 Mdot
.49311 .61511 Mdot
.47803 .60872 Mdot
.43012 .58842 Mdot
.28073 .5257 Mdot
.89703 .3809 Mdot
.65724 .46983 Mdot
.61677 .59302 Mdot
.73614 .07378 Mdot
.09335 .22077 Mdot
.31842 .1391 Mdot
.49749 .61697 Mdot
.49199 .61464 Mdot
.47448 .60721 Mdot
.41887 .58366 Mdot
.24675 .51166 Mdot
.83595 .36415 Mdot
.62991 .49069 Mdot
.5978 .59819 Mdot
.70334 .06523 Mdot
.03742 .20647 Mdot
.31589 .1721 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50331 .0014 Mdot
.51054 .00447 Mdot
.53356 .01423 Mdot
.60655 .04511 Mdot
.8277 .13668 Mdot
.25969 .26698 Mdot
.45339 .11971 Mdot
.57818 .07712 Mdot
.81558 .14672 Mdot
.27173 .28192 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50688 .00292 Mdot
.52191 .00929 Mdot
.5697 .02954 Mdot
.71872 .0921 Mdot
.10188 .23681 Mdot
.34245 .14868 Mdot
.38343 .02533 Mdot
.26478 .5447 Mdot
.90843 .3978 Mdot
.68198 .47808 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52164 .00917 Mdot
.56884 .02917 Mdot
.7161 .09102 Mdot
.09671 .23523 Mdot
.34101 .15099 Mdot
.38457 .02692 Mdot
.26977 .54708 Mdot
.91807 .40067 Mdot
.68391 .47332 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51501 .00637 Mdot
.5478 .02026 Mdot
.65121 .06391 Mdot
.94881 .18393 Mdot
.32188 .23057 Mdot
.48016 .09782 Mdot
.60875 .07947 Mdot
.88807 .17263 Mdot
.32178 .26805 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48961 .61363 Mdot
.46692 .60401 Mdot
.39497 .57356 Mdot
.17665 .48311 Mdot
.74451 .35096 Mdot
.55096 .49841 Mdot
.43255 .54485 Mdot
.21597 .48418 Mdot
.7661 .34 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52312 .0098 Mdot
.57355 .03117 Mdot
.73042 .09695 Mdot
.12421 .24338 Mdot
.35004 .13957 Mdot
.38275 .02022 Mdot
.25508 .53913 Mdot
.88879 .39166 Mdot
.67607 .48657 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50676 .00287 Mdot
.52153 .00913 Mdot
.56851 .02903 Mdot
.7151 .0906 Mdot
.0947 .23461 Mdot
.34049 .1519 Mdot
.3851 .02757 Mdot
.27195 .5481 Mdot
.92234 .40196 Mdot
.68465 .47113 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50289 .00123 Mdot
.50921 .00391 Mdot
.52934 .01244 Mdot
.59324 .03949 Mdot
.78913 .12107 Mdot
.21658 .26418 Mdot
.41054 .11987 Mdot
.47726 .04123 Mdot
.50997 .02022 Mdot
.55764 .02946 Mdot
.49751 .61698 Mdot
.49208 .61467 Mdot
.47477 .60733 Mdot
.41976 .58404 Mdot
.24943 .51276 Mdot
.84037 .36522 Mdot
.63258 .48961 Mdot
.60144 .59879 Mdot
.71238 .06856 Mdot
.0554 .212 Mdot
.31699 .16167 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50437 .00185 Mdot
.51391 .0059 Mdot
.5443 .01878 Mdot
.64029 .05932 Mdot
.9205 .17318 Mdot
.31506 .24385 Mdot
.49056 .10847 Mdot
.65192 .09972 Mdot
.00809 .22013 Mdot
.35213 .21263 Mdot
.49951 .61783 Mdot
.49843 .61737 Mdot
.495 .61591 Mdot
.48407 .61128 Mdot
.44928 .59653 Mdot
.3397 .55031 Mdot
.0283 .42558 Mdot
.67468 .39948 Mdot
.53355 .53081 Mdot
.44236 .56168 Mdot
.26659 .5094 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47987 .6095 Mdot
.43593 .59088 Mdot
.29846 .53307 Mdot
.93324 .39232 Mdot
.66525 .45241 Mdot
.60294 .57952 Mdot
.68448 .0504 Mdot
.98482 .18562 Mdot
.30789 .19967 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48038 .60971 Mdot
.43756 .59157 Mdot
.30348 .53516 Mdot
.94401 .39587 Mdot
.6668 .44671 Mdot
.59646 .57456 Mdot
.6621 .04057 Mdot
.93097 .16617 Mdot
.30017 .22818 Mdot
.49761 .61702 Mdot
.4924 .61481 Mdot
.47579 .60777 Mdot
.42301 .58541 Mdot
.25919 .51679 Mdot
.85703 .36949 Mdot
.64163 .48491 Mdot
.61172 .59955 Mdot
.73596 .07679 Mdot
.09801 .22376 Mdot
.32216 .13853 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50652 .00276 Mdot
.52077 .00881 Mdot
.56608 .02801 Mdot
.7077 .08752 Mdot
.07966 .22989 Mdot
.33706 .15908 Mdot
.39056 .03307 Mdot
.29254 .55745 Mdot
.96426 .41515 Mdot
.49801 .61719 Mdot
.49366 .61534 Mdot
.47979 .60947 Mdot
.4357 .59078 Mdot
.29777 .53279 Mdot
.93178 .39184 Mdot
.66501 .45316 Mdot
.60374 .58017 Mdot
.6873 .05164 Mdot
.99129 .18788 Mdot
.30834 .19595 Mdot
.49875 .6175 Mdot
.49601 .61634 Mdot
.48729 .61264 Mdot
.45952 .60087 Mdot
.37168 .56375 Mdot
.11155 .45726 Mdot
.69746 .36211 Mdot
.50921 .50169 Mdot
.33478 .51023 Mdot
.9547 .38313 Mdot
.64165 .42456 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47928 .60925 Mdot
.43408 .5901 Mdot
.29281 .53072 Mdot
.92138 .38848 Mdot
.66315 .45844 Mdot
.60897 .58455 Mdot
.70577 .05983 Mdot
.03215 .20171 Mdot
.31063 .17211 Mdot
.49756 .617 Mdot
.49224 .61474 Mdot
.47526 .60755 Mdot
.42134 .58471 Mdot
.25417 .51472 Mdot
.84835 .36722 Mdot
.63711 .48748 Mdot
.60703 .59944 Mdot
.72567 .07332 Mdot
.08025 .21914 Mdot
.31949 .14786 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00343 Mdot
.52579 .01094 Mdot
.58201 .03474 Mdot
.75587 .10745 Mdot
.1683 .2549 Mdot
.37277 .12637 Mdot
.40607 .02058 Mdot
.30653 .55651 Mdot
.98316 .41818 Mdot
.685 .43376 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46985 .60525 Mdot
.40421 .57746 Mdot
.20339 .49393 Mdot
.77401 .35266 Mdot
.58065 .49853 Mdot
.50316 .57014 Mdot
.43039 .57306 Mdot
.49948 .61781 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44668 .59543 Mdot
.33163 .54693 Mdot
.00856 .41837 Mdot
.67266 .41043 Mdot
.54784 .5409 Mdot
.49372 .58459 Mdot
.43019 .57877 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.5075 .00318 Mdot
.52389 .01013 Mdot
.57599 .0322 Mdot
.73779 .1 Mdot
.13763 .24711 Mdot
.3558 .13484 Mdot
.38608 .01871 Mdot
.25971 .53993 Mdot
.89505 .39266 Mdot
.67665 .48305 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50774 .00328 Mdot
.52465 .01045 Mdot
.57838 .03321 Mdot
.74498 .10297 Mdot
.1502 .25044 Mdot
.3621 .13096 Mdot
.39209 .01853 Mdot
.27232 .54402 Mdot
.91617 .39792 Mdot
.68003 .47209 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54191 .01777 Mdot
.63279 .05617 Mdot
.90055 .16548 Mdot
.30796 .25179 Mdot
.4923 .11393 Mdot
.66508 .10679 Mdot
.04342 .23382 Mdot
.35743 .19407 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .61119 Mdot
.44865 .59627 Mdot
.33774 .54949 Mdot
.02347 .4238 Mdot
.67412 .40212 Mdot
.53688 .53321 Mdot
.4976 .61701 Mdot
.49234 .61478 Mdot
.47559 .60768 Mdot
.42238 .58515 Mdot
.2573 .51601 Mdot
.85373 .36862 Mdot
.63996 .48592 Mdot
.6101 .59958 Mdot
.73254 .07567 Mdot
.09228 .22233 Mdot
.32122 .1415 Mdot
.49832 .61732 Mdot
.49465 .61577 Mdot
.48297 .61081 Mdot
.44579 .59506 Mdot
.32886 .54577 Mdot
.0019 .41596 Mdot
.67209 .4142 Mdot
.55298 .54442 Mdot
.51188 .59263 Mdot
.4886 .60364 Mdot
.44822 .59308 Mdot
.49969 .6179 Mdot
.49902 .61762 Mdot
.49688 .61671 Mdot
.49005 .61382 Mdot
.46831 .6046 Mdot
.39935 .57541 Mdot
.18928 .48821 Mdot
.75765 .35127 Mdot
.56447 .49864 Mdot
.46536 .55678 Mdot
.31471 .52492 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50304 .00129 Mdot
.5097 .00411 Mdot
.53089 .0131 Mdot
.59812 .04155 Mdot
.8034 .12687 Mdot
.23409 .26618 Mdot
.42725 .11938 Mdot
.51503 .05425 Mdot
.62532 .06816 Mdot
.4981 .61723 Mdot
.49395 .61547 Mdot
.48072 .60986 Mdot
.43865 .59203 Mdot
.30683 .53656 Mdot
.95133 .39832 Mdot
.6677 .44274 Mdot
.5916 .571 Mdot
.64543 .03327 Mdot
.8883 .1501 Mdot
.28529 .24536 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50432 .00183 Mdot
.51378 .00584 Mdot
.54387 .0186 Mdot
.63892 .05875 Mdot
.9169 .1718 Mdot
.31394 .24538 Mdot
.49125 .10959 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49545 .6161 Mdot
.4855 .61188 Mdot
.45382 .59846 Mdot
.35383 .55624 Mdot
.06413 .43899 Mdot
.68082 .38113 Mdot
.51404 .51496 Mdot
.36829 .52796 Mdot
.04678 .41933 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50496 .0021 Mdot
.5158 .0067 Mdot
.5503 .02132 Mdot
.65899 .06718 Mdot
.96843 .19125 Mdot
.32492 .22032 Mdot
.46864 .08882 Mdot
.56562 .05994 Mdot
.75825 .11906 Mdot
.1893 .2664 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51239 .00525 Mdot
.53946 .01673 Mdot
.62512 .05294 Mdot
.87971 .15734 Mdot
.29804 .25854 Mdot
.48843 .11767 Mdot
.6615 .10696 Mdot
.03732 .23227 Mdot
.35768 .19799 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48055 .60979 Mdot
.43809 .5918 Mdot
.30511 .53584 Mdot
.94756 .39706 Mdot
.66726 .4448 Mdot
.59414 .57285 Mdot
.65414 .03708 Mdot
.91087 .15867 Mdot
.49886 .61755 Mdot
.49636 .61649 Mdot
.4884 .61312 Mdot
.46306 .60237 Mdot
.3828 .56843 Mdot
.1422 .46934 Mdot
.71557 .35436 Mdot
.52211 .49847 Mdot
.36169 .51889 Mdot
.01897 .40622 Mdot
.64786 .38868 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50419 .00178 Mdot
.51334 .00566 Mdot
.54249 .01801 Mdot
.63461 .05694 Mdot
.90543 .16737 Mdot
.3099 .24998 Mdot
.49235 .11276 Mdot
.66332 .10567 Mdot
.03848 .23186 Mdot
.35648 .19654 Mdot
.49795 .61717 Mdot
.49347 .61527 Mdot
.47921 .60922 Mdot
.43384 .58999 Mdot
.29205 .53041 Mdot
.91982 .38798 Mdot
.66284 .45921 Mdot
.60966 .58517 Mdot
.70828 .06095 Mdot
.03747 .20345 Mdot
.31097 .16903 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48743 .6127 Mdot
.45998 .60107 Mdot
.37313 .56436 Mdot
.11549 .45881 Mdot
.69943 .36089 Mdot
.51014 .50105 Mdot
.33606 .51045 Mdot
.95731 .38395 Mdot
.64183 .42306 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47445 .6072 Mdot
.41876 .58361 Mdot
.24642 .51152 Mdot
.83541 .36402 Mdot
.62957 .49082 Mdot
.59733 .59811 Mdot
.70215 .06478 Mdot
.035 .20571 Mdot
.31577 .17353 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00314 Mdot
.52355 .00999 Mdot
.57491 .03174 Mdot
.73454 .09866 Mdot
.13178 .24551 Mdot
.35317 .13683 Mdot
.38426 .01921 Mdot
.25663 .53916 Mdot
.89049 .39174 Mdot
.49776 .61708 Mdot
.49287 .61501 Mdot
.47728 .6084 Mdot
.42772 .58741 Mdot
.27343 .52268 Mdot
.88299 .37673 Mdot
.65267 .47569 Mdot
.61783 .5965 Mdot
.74403 .07799 Mdot
.10878 .22543 Mdot
.32278 .13226 Mdot
.49885 .61755 Mdot
.49633 .61648 Mdot
.4883 .61307 Mdot
.46275 .60224 Mdot
.38183 .56802 Mdot
.1395 .46826 Mdot
.7137 .35488 Mdot
.52045 .4986 Mdot
.3578 .51751 Mdot
.00911 .40253 Mdot
.64676 .39409 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54143 .01756 Mdot
.63129 .05554 Mdot
.89651 .16391 Mdot
.30625 .25323 Mdot
.49201 .11481 Mdot
.66581 .10741 Mdot
.04569 .23478 Mdot
.49862 .61745 Mdot
.4956 .61617 Mdot
.48598 .61209 Mdot
.45536 .59911 Mdot
.35867 .55827 Mdot
.07676 .4438 Mdot
.68412 .37537 Mdot
.51006 .51046 Mdot
.35108 .51978 Mdot
.99991 .401 Mdot
.64888 .40109 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60957 Mdot
.43651 .59113 Mdot
.30024 .53381 Mdot
.93703 .39356 Mdot
.66583 .45042 Mdot
.60075 .57781 Mdot
.6769 .04706 Mdot
.96705 .17932 Mdot
.30627 .20965 Mdot
.49905 .61763 Mdot
.49696 .61675 Mdot
.49032 .61393 Mdot
.46917 .60496 Mdot
.40207 .57656 Mdot
.19716 .4914 Mdot
.76656 .35191 Mdot
.5734 .49865 Mdot
.48648 .56431 Mdot
.37929 .55179 Mdot
.10791 .45031 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50552 .00234 Mdot
.51759 .00746 Mdot
.55599 .02373 Mdot
.67666 .07458 Mdot
.01115 .20673 Mdot
.32893 .1964 Mdot
.43675 .06663 Mdot
.45215 .00952 Mdot
.39687 .58387 Mdot
.1975 .49481 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51315 .00558 Mdot
.54187 .01775 Mdot
.63268 .05612 Mdot
.90024 .16536 Mdot
.30783 .25191 Mdot
.49228 .114 Mdot
.66516 .10684 Mdot
.04365 .23392 Mdot
.35748 .19396 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47779 .60862 Mdot
.42935 .5881 Mdot
.27838 .52473 Mdot
.89246 .37952 Mdot
.65585 .4718 Mdot
.61742 .59428 Mdot
.73956 .07549 Mdot
.09991 .22271 Mdot
.32005 .13605 Mdot
.4981 .61723 Mdot
.49394 .61546 Mdot
.48069 .60984 Mdot
.43853 .59198 Mdot
.30645 .5364 Mdot
.9505 .39804 Mdot
.66761 .4432 Mdot
.59216 .57141 Mdot
.64736 .03412 Mdot
.89335 .15203 Mdot
.28761 .24366 Mdot
.49941 .61779 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48103 .60999 Mdot
.43962 .59244 Mdot
.30981 .5378 Mdot
.95792 .40056 Mdot
.66842 .43911 Mdot
.58697 .56769 Mdot
.62957 .02633 Mdot
.84575 .13361 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48344 .61101 Mdot
.44728 .59568 Mdot
.33346 .54769 Mdot
.013 .41998 Mdot
.67306 .40794 Mdot
.54449 .53857 Mdot
.48179 .57928 Mdot
.39183 .56244 Mdot
.15184 .46971 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52373 .01006 Mdot
.57548 .03198 Mdot
.73625 .09936 Mdot
.13486 .24636 Mdot
.35454 .13577 Mdot
.38515 .01892 Mdot
.25805 .53948 Mdot
.89252 .39213 Mdot
.67624 .48436 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50693 .00294 Mdot
.52207 .00936 Mdot
.5702 .02975 Mdot
.72024 .09273 Mdot
.10486 .23771 Mdot
.34332 .14738 Mdot
.38293 .02448 Mdot
.26235 .54351 Mdot
.90375 .39641 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50793 .00336 Mdot
.52526 .01071 Mdot
.58033 .03403 Mdot
.75084 .10538 Mdot
.16007 .25292 Mdot
.36768 .12831 Mdot
.3989 .0193 Mdot
.28847 .54978 Mdot
.94625 .40653 Mdot
.68313 .45542 Mdot
.49944 .6178 Mdot
.49821 .61728 Mdot
.49431 .61562 Mdot
.48186 .61034 Mdot
.44227 .59356 Mdot
.31796 .54121 Mdot
.97636 .40691 Mdot
.67009 .42875 Mdot
.57308 .55808 Mdot
.58189 .00545 Mdot
.7082 .07806 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48468 .61154 Mdot
.45121 .59735 Mdot
.3457 .55283 Mdot
.04334 .43116 Mdot
.67677 .39148 Mdot
.5241 .52368 Mdot
.40743 .54593 Mdot
.1596 .46487 Mdot
.71053 .34049 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48636 .61225 Mdot
.45658 .59963 Mdot
.36247 .55987 Mdot
.08679 .44765 Mdot
.68728 .37113 Mdot
.50822 .50736 Mdot
.34147 .51498 Mdot
.97434 .39114 Mdot
.64554 .41482 Mdot
.50032 .00013 Mdot
.501 .00043 Mdot
.5032 .00136 Mdot
.5102 .00432 Mdot
.53248 .01377 Mdot
.60315 .04367 Mdot
.81793 .13274 Mdot
.25002 .26705 Mdot
.44339 .11951 Mdot
.55361 .06812 Mdot
.74275 .11689 Mdot
.17037 .26428 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50763 .00324 Mdot
.52431 .01031 Mdot
.57732 .03276 Mdot
.7418 .10165 Mdot
.1447 .249 Mdot
.35924 .13259 Mdot
.3891 .01846 Mdot
.26576 .5418 Mdot
.90485 .39498 Mdot
.49791 .61715 Mdot
.49335 .61521 Mdot
.47881 .60905 Mdot
.43257 .58946 Mdot
.28818 .5288 Mdot
.91189 .38548 Mdot
.66112 .46305 Mdot
.61281 .58818 Mdot
.7199 .06619 Mdot
.06147 .2111 Mdot
.31311 .15552 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .00341 Mdot
.52559 .01085 Mdot
.58138 .03448 Mdot
.75399 .10668 Mdot
.16525 .25418 Mdot
.37084 .12706 Mdot
.40326 .02004 Mdot
.29934 .55381 Mdot
.96807 .4133 Mdot
.68437 .4427 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50285 .00121 Mdot
.50909 .00385 Mdot
.52894 .01227 Mdot
.59196 .03895 Mdot
.78538 .11954 Mdot
.21166 .26345 Mdot
.4061 .12017 Mdot
.46771 .03808 Mdot
.48123 .00835 Mdot
.46665 .60902 Mdot
.4974 .61693 Mdot
.4917 .61452 Mdot
.47358 .60683 Mdot
.41599 .58244 Mdot
.23816 .50813 Mdot
.82226 .36099 Mdot
.6209 .49359 Mdot
.58396 .5952 Mdot
.6672 .05144 Mdot
.95758 .17946 Mdot
.31084 .21833 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47486 .60738 Mdot
.42007 .58417 Mdot
.25037 .51315 Mdot
.84193 .36561 Mdot
.6335 .48921 Mdot
.60264 .59896 Mdot
.71528 .06962 Mdot
.06101 .21367 Mdot
.31744 .15849 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50334 .00141 Mdot
.51063 .00451 Mdot
.53385 .01435 Mdot
.60746 .04549 Mdot
.83028 .13771 Mdot
.26211 .26688 Mdot
.45589 .11976 Mdot
.58434 .07939 Mdot
.83348 .15397 Mdot
.28925 .28168 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47834 .60885 Mdot
.43108 .58883 Mdot
.28363 .52691 Mdot
.90276 .38264 Mdot
.65884 .46729 Mdot
.61556 .59128 Mdot
.73079 .07121 Mdot
.08301 .21768 Mdot
.31629 .14417 Mdot
.50044 .00019 Mdot
.5014 .0006 Mdot
.50447 .0019 Mdot
.51426 .00605 Mdot
.54539 .01924 Mdot
.6437 .06076 Mdot
.92945 .1766 Mdot
.31759 .23988 Mdot
.4882 .10545 Mdot
.64114 .09452 Mdot
.97911 .20888 Mdot
.34832 .22819 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52148 .00911 Mdot
.56834 .02896 Mdot
.71459 .09039 Mdot
.09369 .2343 Mdot
.34023 .15237 Mdot
.38539 .02791 Mdot
.27311 .54864 Mdot
.9246 .40265 Mdot
.68501 .46996 Mdot
.49937 .61777 Mdot
.498 .61719 Mdot
.49364 .61534 Mdot
.47973 .60944 Mdot
.43549 .5907 Mdot
.29713 .53252 Mdot
.93042 .3914 Mdot
.66479 .45386 Mdot
.60448 .58076 Mdot
.68989 .05278 Mdot
.99719 .18993 Mdot
.49876 .61751 Mdot
.49605 .61636 Mdot
.48741 .6127 Mdot
.45991 .60104 Mdot
.3729 .56426 Mdot
.11487 .45856 Mdot
.69911 .36108 Mdot
.50998 .50115 Mdot
.33582 .51039 Mdot
.95679 .38378 Mdot
.64179 .42335 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47444 .6072 Mdot
.41874 .58361 Mdot
.24637 .51151 Mdot
.83534 .364 Mdot
.62953 .49084 Mdot
.59727 .59809 Mdot
.70199 .06472 Mdot
.03466 .2056 Mdot
.31575 .17373 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00227 Mdot
.51702 .00722 Mdot
.55419 .02297 Mdot
.67109 .07225 Mdot
.99798 .20203 Mdot
.3279 .2039 Mdot
.44711 .07368 Mdot
.48844 .02554 Mdot
.51244 .01484 Mdot
.5551 .02636 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.48628 .61222 Mdot
.45633 .59952 Mdot
.36168 .55954 Mdot
.0847 .44685 Mdot
.68658 .37198 Mdot
.5085 .50797 Mdot
.34315 .51584 Mdot
.97881 .39286 Mdot
.64616 .41245 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50629 .00267 Mdot
.52003 .00849 Mdot
.56374 .02702 Mdot
.70054 .08454 Mdot
.06462 .22502 Mdot
.33442 .16674 Mdot
.39828 .03947 Mdot
.31974 .56949 Mdot
.02503 .43589 Mdot
.69293 .41279 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50555 .00235 Mdot
.51767 .00749 Mdot
.55624 .02384 Mdot
.67744 .0749 Mdot
.01298 .20738 Mdot
.32907 .19536 Mdot
.4353 .06565 Mdot
.44713 .00731 Mdot
.3811 .57723 Mdot
.15286 .47697 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51996 .00846 Mdot
.56351 .02692 Mdot
.69981 .08424 Mdot
.06308 .22451 Mdot
.33418 .16755 Mdot
.39918 .04017 Mdot
.32287 .57087 Mdot
.03242 .43853 Mdot
.69367 .40868 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50603 .00256 Mdot
.5192 .00814 Mdot
.56111 .0259 Mdot
.69244 .08117 Mdot
.04705 .21917 Mdot
.33211 .17618 Mdot
.40952 .04784 Mdot
.35839 .58644 Mdot
.12179 .47181 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52143 .00909 Mdot
.56819 .0289 Mdot
.71414 .0902 Mdot
.09278 .23401 Mdot
.34 .15279 Mdot
.38566 .02822 Mdot
.27418 .54914 Mdot
.92672 .40329 Mdot
.68534 .46885 Mdot
.49967 .6179 Mdot
.49896 .61759 Mdot
.4967 .61663 Mdot
.48947 .61357 Mdot
.46647 .60382 Mdot
.39353 .57296 Mdot
.17255 .48146 Mdot
.74054 .35104 Mdot
.54685 .49833 Mdot
.42243 .54114 Mdot
.18621 .47204 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00115 Mdot
.50862 .00365 Mdot
.52744 .01164 Mdot
.58723 .03695 Mdot
.77142 .11383 Mdot
.19217 .26004 Mdot
.38978 .12213 Mdot
.43497 .02793 Mdot
.38531 .58734 Mdot
.17811 .48998 Mdot
.49931 .61774 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47768 .60857 Mdot
.42901 .58795 Mdot
.27733 .5243 Mdot
.89044 .37892 Mdot
.65521 .47265 Mdot
.61761 .5948 Mdot
.74081 .07614 Mdot
.10234 .22344 Mdot
.49848 .61739 Mdot
.49516 .61598 Mdot
.48457 .61149 Mdot
.45088 .59721 Mdot
.34466 .55239 Mdot
.0407 .43018 Mdot
.67636 .39286 Mdot
.52564 .52489 Mdot
.41321 .54855 Mdot
.17697 .47202 Mdot
.72668 .33974 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51573 .00667 Mdot
.55008 .02123 Mdot
.65833 .0669 Mdot
.96679 .19064 Mdot
.3247 .2212 Mdot
.46971 .08962 Mdot
.56954 .0617 Mdot
.77041 .12414 Mdot
.20804 .27047 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50314 .00133 Mdot
.51001 .00425 Mdot
.5319 .01352 Mdot
.60131 .0429 Mdot
.81262 .1306 Mdot
.24442 .26687 Mdot
.43764 .11942 Mdot
.5397 .06307 Mdot
.70069 .0995 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49406 .61552 Mdot
.48109 .61001 Mdot
.43981 .59252 Mdot
.3104 .53805 Mdot
.95923 .401 Mdot
.66855 .43839 Mdot
.58602 .56703 Mdot
.62634 .02492 Mdot
.83687 .13012 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50686 .00291 Mdot
.52186 .00927 Mdot
.56953 .02947 Mdot
.71823 .0919 Mdot
.10091 .23651 Mdot
.34217 .14911 Mdot
.38362 .02562 Mdot
.26564 .54512 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.51549 .00657 Mdot
.54933 .02091 Mdot
.65597 .06591 Mdot
.96088 .18844 Mdot
.32388 .22435 Mdot
.47341 .09242 Mdot
.58325 .06788 Mdot
.81234 .14159 Mdot
.26209 .27796 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50514 .00218 Mdot
.51638 .00695 Mdot
.55216 .02211 Mdot
.66477 .0696 Mdot
.98269 .19649 Mdot
.32653 .2125 Mdot
.4587 .08169 Mdot
.52961 .04383 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50317 .00135 Mdot
.51011 .00429 Mdot
.53219 .01365 Mdot
.60222 .04328 Mdot
.81527 .13167 Mdot
.24725 .26698 Mdot
.44054 .11946 Mdot
.54669 .0656 Mdot
.72187 .10827 Mdot
.13206 .25351 Mdot
.49972 .61791 Mdot
.49911 .61765 Mdot
.49715 .61683 Mdot
.49092 .61419 Mdot
.47109 .60578 Mdot
.40814 .57912 Mdot
.21491 .49861 Mdot
.78872 .35464 Mdot
.59424 .49784 Mdot
.53301 .58019 Mdot
.52094 .61057 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41915 .58378 Mdot
.2476 .51201 Mdot
.83734 .36448 Mdot
.63076 .49036 Mdot
.59899 .5984 Mdot
.70632 .06633 Mdot
.04345 .20836 Mdot
.31621 .16858 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50213 .00091 Mdot
.5068 .00288 Mdot
.52166 .00919 Mdot
.56892 .0292 Mdot
.71635 .09112 Mdot
.09719 .23537 Mdot
.34114 .15077 Mdot
.38445 .02677 Mdot
.26926 .54685 Mdot
.91709 .40038 Mdot
.499 .61761 Mdot
.4968 .61668 Mdot
.4898 .61371 Mdot
.46751 .60426 Mdot
.39683 .57435 Mdot
.18201 .48527 Mdot
.74991 .35098 Mdot
.55654 .49853 Mdot
.44621 .54985 Mdot
.25673 .50093 Mdot
.82873 .35351 Mdot
.49833 .61733 Mdot
.49469 .61578 Mdot
.48307 .61086 Mdot
.44612 .59519 Mdot
.32988 .54619 Mdot
.00434 .41684 Mdot
.6723 .41282 Mdot
.55109 .54312 Mdot
.50521 .58968 Mdot
.46713 .5945 Mdot
.38009 .56424 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47347 .60678 Mdot
.41564 .5823 Mdot
.23713 .50771 Mdot
.82067 .36064 Mdot
.61979 .49388 Mdot
.58209 .59474 Mdot
.66215 .04948 Mdot
.94549 .17511 Mdot
.309 .22466 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51644 .00697 Mdot
.55234 .02219 Mdot
.66535 .06984 Mdot
.9841 .197 Mdot
.32666 .21172 Mdot
.45766 .08096 Mdot
.5259 .04218 Mdot
.63283 .06608 Mdot
.91666 .17542 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47685 .60822 Mdot
.42636 .58683 Mdot
.26933 .52098 Mdot
.87531 .37452 Mdot
.64978 .47865 Mdot
.61718 .59789 Mdot
.7449 .07894 Mdot
.11124 .22641 Mdot
.32397 .13148 Mdot
.49899 .6176 Mdot
.49677 .61666 Mdot
.48971 .61367 Mdot
.46722 .60413 Mdot
.3959 .57396 Mdot
.17934 .48419 Mdot
.74719 .35095 Mdot
.55373 .49847 Mdot
.43934 .54734 Mdot
.23616 .49246 Mdot
.79515 .34547 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48246 .6106 Mdot
.44417 .59437 Mdot
.32383 .54366 Mdot
.99 .41171 Mdot
.67116 .42098 Mdot
.56235 .55079 Mdot
.54468 .60712 Mdot
.59316 .02996 Mdot
.77352 .11147 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52315 .00982 Mdot
.57363 .0312 Mdot
.73066 .09705 Mdot
.12467 .24351 Mdot
.35022 .1394 Mdot
.38282 .02015 Mdot
.2551 .5391 Mdot
.88877 .39163 Mdot
.67603 .48656 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47451 .60723 Mdot
.41895 .5837 Mdot
.24701 .51177 Mdot
.83638 .36425 Mdot
.63017 .49059 Mdot
.59817 .59826 Mdot
.70427 .06557 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48388 .6112 Mdot
.44868 .59628 Mdot
.33784 .54953 Mdot
.0237 .42389 Mdot
.67415 .402 Mdot
.53672 .5331 Mdot
.45388 .56684 Mdot
.30281 .52467 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.5039 .00165 Mdot
.51243 .00527 Mdot
.53959 .01678 Mdot
.62552 .05311 Mdot
.88081 .15778 Mdot
.29864 .25823 Mdot
.48879 .11752 Mdot
.66214 .10714 Mdot
.03877 .23277 Mdot
.35781 .19718 Mdot
.4988 .61753 Mdot
.49619 .61642 Mdot
.48787 .61289 Mdot
.46136 .60165 Mdot
.37747 .56619 Mdot
.12742 .46349 Mdot
.70601 .35759 Mdot
.51427 .49953 Mdot
.34391 .51274 Mdot
.97517 .39014 Mdot
.64353 .41307 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47783 .60863 Mdot
.42947 .58814 Mdot
.27873 .52487 Mdot
.89314 .37973 Mdot
.65607 .47151 Mdot
.61734 .5941 Mdot
.7391 .07525 Mdot
.09903 .22245 Mdot
.31982 .13646 Mdot
.49839 .61735 Mdot
.49488 .61586 Mdot
.4837 .61112 Mdot
.44812 .59604 Mdot
.33608 .54879 Mdot
.01939 .42231 Mdot
.67368 .40438 Mdot
.53979 .53528 Mdot
.46495 .57178 Mdot
.33797 .53955 Mdot
.0078 .41398 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .00991 Mdot
.57432 .03149 Mdot
.73273 .09791 Mdot
.12848 .24459 Mdot
.35177 .138 Mdot
.38349 .0196 Mdot
.25563 .53901 Mdot
.88919 .39156 Mdot
.67586 .48619 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51139 .00483 Mdot
.53629 .01539 Mdot
.61514 .04873 Mdot
.85203 .14641 Mdot
.28025 .26466 Mdot
.47404 .11977 Mdot
.62907 .09581 Mdot
.95717 .20277 Mdot
.34874 .24201 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50327 .00139 Mdot
.51043 .00442 Mdot
.53322 .01408 Mdot
.60548 .04466 Mdot
.82462 .13544 Mdot
.25674 .26706 Mdot
.45033 .11965 Mdot
.57063 .07435 Mdot
.79343 .1377 Mdot
.24612 .27978 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00348 Mdot
.52618 .0111 Mdot
.58323 .03526 Mdot
.7595 .10894 Mdot
.17408 .25623 Mdot
.37658 .12515 Mdot
.41196 .02186 Mdot
.3219 .56237 Mdot
.01705 .42963 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61007 Mdot
.44019 .59268 Mdot
.31155 .53853 Mdot
.96181 .40188 Mdot
.66881 .43695 Mdot
.58414 .5657 Mdot
.61987 .02209 Mdot
.81889 .123 Mdot
.23462 .25694 Mdot
.49834 .61733 Mdot
.4947 .61579 Mdot
.48311 .61087 Mdot
.44624 .59525 Mdot
.33026 .54635 Mdot
.00525 .41717 Mdot
.67237 .4123 Mdot
.55039 .54264 Mdot
.50272 .58858 Mdot
.45914 .5911 Mdot
.35495 .55364 Mdot
.4974 .61693 Mdot
.49173 .61453 Mdot
.47366 .60687 Mdot
.41626 .58256 Mdot
.23897 .50846 Mdot
.82352 .36127 Mdot
.62178 .49335 Mdot
.5854 .59555 Mdot
.67105 .05294 Mdot
.96666 .1827 Mdot
.31192 .21338 Mdot
.49846 .61738 Mdot
.4951 .61596 Mdot
.4844 .61142 Mdot
.45033 .59698 Mdot
.34295 .55167 Mdot
.03641 .42858 Mdot
.67573 .39512 Mdot
.52826 .52689 Mdot
.42294 .55295 Mdot
.2065 .48427 Mdot
.76019 .3422 Mdot
.49803 .6172 Mdot
.49371 .61537 Mdot
.47997 .60954 Mdot
.43626 .59102 Mdot
.29949 .5335 Mdot
.93542 .39303 Mdot
.66559 .45127 Mdot
.60169 .57854 Mdot
.68016 .0485 Mdot
.97475 .18207 Mdot
.30705 .20537 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00126 Mdot
.5095 .00403 Mdot
.53025 .01282 Mdot
.59609 .0407 Mdot
.79748 .12446 Mdot
.22705 .26549 Mdot
.42037 .11948 Mdot
.49917 .0487 Mdot
.57673 .04793 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.5033 .0014 Mdot
.51052 .00446 Mdot
.53352 .01421 Mdot
.60642 .04506 Mdot
.82733 .13653 Mdot
.25934 .267 Mdot
.45302 .11971 Mdot
.57727 .07679 Mdot
.81291 .14564 Mdot
.26888 .2818 Mdot
.4975 .61698 Mdot
.49205 .61466 Mdot
.47466 .60729 Mdot
.41943 .5839 Mdot
.24843 .51235 Mdot
.83871 .36481 Mdot
.63159 .49003 Mdot
.60012 .59859 Mdot
.70913 .06737 Mdot
.04904 .21008 Mdot
.31655 .16533 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47984 .60949 Mdot
.43585 .59085 Mdot
.29823 .53298 Mdot
.93275 .39215 Mdot
.66517 .45266 Mdot
.60321 .57974 Mdot
.68544 .05082 Mdot
.98703 .18639 Mdot
.30805 .1984 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50415 .00176 Mdot
.51321 .0056 Mdot
.54205 .01783 Mdot
.63325 .05636 Mdot
.90178 .16596 Mdot
.30846 .25134 Mdot
.49234 .11364 Mdot
.66473 .10654 Mdot
.0424 .23341 Mdot
.35722 .19457 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50701 .00297 Mdot
.52233 .00947 Mdot
.57103 .0301 Mdot
.72276 .09378 Mdot
.10974 .23917 Mdot
.34485 .1453 Mdot
.38237 .02319 Mdot
.25909 .54184 Mdot
.89746 .39453 Mdot
.50036 .00015 Mdot
.50114 .00049 Mdot
.50365 .00155 Mdot
.51162 .00493 Mdot
.537 .01569 Mdot
.61737 .04968 Mdot
.85828 .14889 Mdot
.28477 .26358 Mdot
.4782 .11954 Mdot
.63902 .09939 Mdot
.98285 .2125 Mdot
.35236 .22837 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52405 .0102 Mdot
.57647 .0324 Mdot
.73925 .1006 Mdot
.14022 .24781 Mdot
.35703 .134 Mdot
.38708 .01858 Mdot
.26162 .54049 Mdot
.89807 .39334 Mdot
.67717 .48151 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50525 .00223 Mdot
.51672 .00709 Mdot
.55323 .02256 Mdot
.66811 .071 Mdot
.99081 .19944 Mdot
.32729 .20795 Mdot
.45263 .07747 Mdot
.50796 .0342 Mdot
.57522 .04157 Mdot
.75116 .10874 Mdot
.49831 .61732 Mdot
.49462 .61575 Mdot
.48285 .61076 Mdot
.44541 .5949 Mdot
.32769 .54528 Mdot
.99913 .41497 Mdot
.67187 .41578 Mdot
.55515 .5459 Mdot
.51951 .59601 Mdot
.51306 .61405 Mdot
.52619 .00811 Mdot
.49902 .61762 Mdot
.49686 .6167 Mdot
.49001 .6138 Mdot
.46817 .60454 Mdot
.39891 .57523 Mdot
.18802 .48769 Mdot
.75627 .3512 Mdot
.56306 .49863 Mdot
.46199 .55557 Mdot
.30445 .52067 Mdot
.92202 .38168 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48495 .61165 Mdot
.45208 .59772 Mdot
.34842 .55397 Mdot
.05023 .43374 Mdot
.67794 .38795 Mdot
.52033 .52063 Mdot
.39314 .53942 Mdot
.11743 .44764 Mdot
.68113 .34838 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50697 .00295 Mdot
.52219 .00941 Mdot
.57059 .02991 Mdot
.72145 .09323 Mdot
.1072 .23841 Mdot
.34404 .14637 Mdot
.38262 .02384 Mdot
.26067 .54266 Mdot
.49787 .61713 Mdot
.49321 .61515 Mdot
.47836 .60886 Mdot
.43115 .58886 Mdot
.28386 .527 Mdot
.90322 .38279 Mdot
.65897 .46708 Mdot
.61545 .59114 Mdot
.7303 .07099 Mdot
.08207 .2174 Mdot
.31611 .14465 Mdot
.49799 .61718 Mdot
.49361 .61532 Mdot
.47964 .6094 Mdot
.43521 .59058 Mdot
.29626 .53216 Mdot
.92859 .3908 Mdot
.66448 .4548 Mdot
.60545 .58155 Mdot
.69328 .05428 Mdot
.00484 .19255 Mdot
.30914 .18807 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48825 .61305 Mdot
.46258 .60217 Mdot
.38129 .5678 Mdot
.138 .46767 Mdot
.71269 .35518 Mdot
.51958 .49869 Mdot
.35576 .51679 Mdot
.00401 .40064 Mdot
.64624 .39692 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50548 .00232 Mdot
.51746 .0074 Mdot
.55558 .02356 Mdot
.67538 .07404 Mdot
.00814 .20566 Mdot
.3287 .19812 Mdot
.43912 .06825 Mdot
.46045 .01318 Mdot
.42304 .59492 Mdot
.27466 .52633 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.4946 .61574 Mdot
.48278 .61073 Mdot
.44519 .5948 Mdot
.32701 .54499 Mdot
.99751 .41439 Mdot
.67174 .4167 Mdot
.55642 .54676 Mdot
.52397 .59798 Mdot
.52734 .00208 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.48059 .6098 Mdot
.43823 .59186 Mdot
.30554 .53602 Mdot
.94849 .39737 Mdot
.66737 .44429 Mdot
.59352 .57239 Mdot
.65201 .03615 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48038 .60971 Mdot
.43756 .59157 Mdot
.30345 .53515 Mdot
.94395 .39585 Mdot
.6668 .44674 Mdot
.59649 .57458 Mdot
.66222 .04062 Mdot
.93128 .16629 Mdot
.30025 .22803 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00326 Mdot
.52447 .01038 Mdot
.57782 .03297 Mdot
.7433 .10227 Mdot
.1473 .24969 Mdot
.36057 .13181 Mdot
.39044 .01846 Mdot
.26865 .54276 Mdot
.90976 .39623 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49427 .6156 Mdot
.48175 .6103 Mdot
.44191 .59341 Mdot
.31687 .54075 Mdot
.97386 .40604 Mdot
.66988 .43016 Mdot
.57502 .55941 Mdot
.58857 .00837 Mdot
.72822 .08631 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48702 .61253 Mdot
.45867 .60051 Mdot
.36903 .56263 Mdot
.10436 .45446 Mdot
.69413 .3645 Mdot
.50807 .50305 Mdot
.33413 .51053 Mdot
.95403 .38312 Mdot
.64193 .42515 Mdot
.49741 .61694 Mdot
.49176 .61454 Mdot
.47374 .6069 Mdot
.41652 .58267 Mdot
.23975 .50878 Mdot
.82474 .36154 Mdot
.62262 .49312 Mdot
.58676 .59587 Mdot
.6747 .05435 Mdot
.97514 .18568 Mdot
.31272 .20864 Mdot
.49784 .61712 Mdot
.49311 .61511 Mdot
.47804 .60872 Mdot
.43012 .58842 Mdot
.28073 .5257 Mdot
.89704 .3809 Mdot
.65724 .46983 Mdot
.61676 .59302 Mdot
.73614 .07378 Mdot
.09335 .22076 Mdot
.31842 .1391 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50327 .00139 Mdot
.51042 .00442 Mdot
.53318 .01407 Mdot
.60534 .0446 Mdot
.82424 .13528 Mdot
.25636 .26707 Mdot
.44994 .11964 Mdot
.56967 .074 Mdot
.7906 .13654 Mdot
.24254 .27931 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.4857 .61197 Mdot
.45446 .59873 Mdot
.35584 .55708 Mdot
.06937 .44098 Mdot
.6821 .37869 Mdot
.51218 .51301 Mdot
.3605 .52429 Mdot
.02535 .4109 Mdot
.65234 .3875 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52057 .00872 Mdot
.56544 .02773 Mdot
.70573 .0867 Mdot
.07557 .22858 Mdot
.33627 .16112 Mdot
.39246 .03473 Mdot
.29933 .56048 Mdot
.97885 .41996 Mdot
.69 .43952 Mdot
.49916 .61768 Mdot
.49733 .6169 Mdot
.49149 .61443 Mdot
.47291 .60655 Mdot
.41387 .58155 Mdot
.23186 .50555 Mdot
.81267 .35896 Mdot
.61394 .49521 Mdot
.57189 .59204 Mdot
.63403 .03841 Mdot
.8743 .14849 Mdot
.49771 .61706 Mdot
.4927 .61494 Mdot
.47674 .60817 Mdot
.42602 .58669 Mdot
.26829 .52055 Mdot
.87341 .37398 Mdot
.64901 .47935 Mdot
.61688 .59817 Mdot
.74472 .07901 Mdot
.11116 .22647 Mdot
.32409 .1316 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50761 .00323 Mdot
.52423 .01027 Mdot
.57706 .03265 Mdot
.74102 .10133 Mdot
.14333 .24864 Mdot
.35855 .13301 Mdot
.38845 .01848 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57374 .03125 Mdot
.731 .09719 Mdot
.12529 .24369 Mdot
.35046 .13916 Mdot
.38291 .02005 Mdot
.25514 .53907 Mdot
.88876 .3916 Mdot
.67598 .48653 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54655 .01973 Mdot
.64731 .06227 Mdot
.9388 .18015 Mdot
.31985 .2355 Mdot
.48479 .10194 Mdot
.62694 .08786 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50645 .00274 Mdot
.52055 .00872 Mdot
.5654 .02772 Mdot
.70562 .08666 Mdot
.07535 .22851 Mdot
.33623 .16123 Mdot
.39256 .03482 Mdot
.29971 .56065 Mdot
.97967 .42024 Mdot
.69004 .43903 Mdot
.49843 .61737 Mdot
.495 .61591 Mdot
.48407 .61128 Mdot
.4493 .59654 Mdot
.33974 .55033 Mdot
.02842 .42562 Mdot
.67469 .39942 Mdot
.53346 .53075 Mdot
.44207 .56155 Mdot
.26567 .50902 Mdot
.8517 .36219 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51157 .00491 Mdot
.53685 .01562 Mdot
.6169 .04947 Mdot
.85695 .14836 Mdot
.28383 .26383 Mdot
.47735 .1196 Mdot
.63702 .09868 Mdot
.97775 .21058 Mdot
.35175 .23114 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50814 .00345 Mdot
.52592 .01099 Mdot
.5824 .03491 Mdot
.75705 .10794 Mdot
.17019 .25534 Mdot
.37399 .12596 Mdot
.40792 .02097 Mdot
.3113 .55832 Mdot
.99345 .42159 Mdot
.68542 .42766 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00207 Mdot
.51553 .00659 Mdot
.54945 .02096 Mdot
.65634 .06607 Mdot
.96181 .18879 Mdot
.32402 .22386 Mdot
.47284 .09198 Mdot
.58114 .06693 Mdot
.80593 .13893 Mdot
.25486 .27746 Mdot
.49781 .61711 Mdot
.49302 .61507 Mdot
.47777 .60861 Mdot
.42928 .58807 Mdot
.27817 .52464 Mdot
.89206 .37941 Mdot
.65573 .47197 Mdot
.61746 .59438 Mdot
.73981 .07562 Mdot
.10041 .22286 Mdot
.32019 .13583 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48933 .61351 Mdot
.46601 .60362 Mdot
.39209 .57235 Mdot
.16844 .47981 Mdot
.73672 .35122 Mdot
.5429 .49825 Mdot
.41265 .53754 Mdot
.15785 .46056 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48179 .61031 Mdot
.44205 .59347 Mdot
.3173 .54093 Mdot
.97485 .40638 Mdot
.66996 .42961 Mdot
.57426 .55889 Mdot
.58595 .00722 Mdot
.72038 .08309 Mdot
.08943 .22808 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49427 .6156 Mdot
.48173 .61029 Mdot
.44186 .59339 Mdot
.31671 .54069 Mdot
.9735 .40591 Mdot
.66985 .43037 Mdot
.57531 .5596 Mdot
.58955 .0088 Mdot
.73114 .08751 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50199 .00084 Mdot
.50635 .00269 Mdot
.52022 .00858 Mdot
.56436 .02727 Mdot
.70241 .08532 Mdot
.0686 .22632 Mdot
.33505 .16467 Mdot
.39605 .0377 Mdot
.31196 .56607 Mdot
.00702 .42957 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48961 .61363 Mdot
.46689 .604 Mdot
.39488 .57353 Mdot
.17641 .48301 Mdot
.74428 .35096 Mdot
.55072 .49841 Mdot
.43195 .54463 Mdot
.2142 .48346 Mdot
.76373 .33963 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50249 .00105 Mdot
.50792 .00336 Mdot
.52523 .0107 Mdot
.58024 .03399 Mdot
.75056 .10526 Mdot
.15961 .25281 Mdot
.36741 .12843 Mdot
.39854 .01924 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50837 .00355 Mdot
.52666 .0113 Mdot
.58475 .0359 Mdot
.76404 .11081 Mdot
.18113 .25778 Mdot
.3815 .12383 Mdot
.42008 .02385 Mdot
.34376 .57087 Mdot
.06896 .44819 Mdot
.69392 .38625 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47661 .60812 Mdot
.4256 .58651 Mdot
.26702 .52002 Mdot
.87106 .37332 Mdot
.64804 .4802 Mdot
.61642 .59849 Mdot
.74426 .07901 Mdot
.11068 .22646 Mdot
.49894 .61758 Mdot
.49661 .6166 Mdot
.4892 .61345 Mdot
.4656 .60345 Mdot
.3908 .5718 Mdot
.16475 .47833 Mdot
.73341 .35145 Mdot
.5395 .49819 Mdot
.40423 .53443 Mdot
.13381 .45091 Mdot
.68551 .34096 Mdot
.49961 .61787 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.48751 .61274 Mdot
.46022 .60117 Mdot
.37388 .56467 Mdot
.11754 .45961 Mdot
.70049 .36028 Mdot
.51071 .50074 Mdot
.33698 .51067 Mdot
.9593 .38461 Mdot
.49897 .6176 Mdot
.49673 .61665 Mdot
.48958 .61361 Mdot
.46681 .60396 Mdot
.3946 .57341 Mdot
.17561 .48269 Mdot
.74349 .35097 Mdot
.54991 .49839 Mdot
.42996 .5439 Mdot
.20831 .48105 Mdot
.75607 .33854 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48029 .60968 Mdot
.43729 .59146 Mdot
.30263 .53481 Mdot
.94217 .39526 Mdot
.66656 .4477 Mdot
.59762 .57543 Mdot
.6661 .04232 Mdot
.94089 .16983 Mdot
.30233 .22338 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.4953 .61604 Mdot
.48503 .61168 Mdot
.45232 .59782 Mdot
.34917 .55428 Mdot
.05214 .43446 Mdot
.6783 .38698 Mdot
.51936 .51981 Mdot
.38939 .53771 Mdot
.10655 .44323 Mdot
.49782 .61711 Mdot
.49307 .61509 Mdot
.47792 .60867 Mdot
.42975 .58827 Mdot
.27961 .52524 Mdot
.89484 .38024 Mdot
.65659 .47078 Mdot
.61711 .59364 Mdot
.73787 .07464 Mdot
.09668 .22175 Mdot
.31922 .13754 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48617 .61217 Mdot
.45596 .59937 Mdot
.36054 .55906 Mdot
.0817 .4457 Mdot
.68562 .37324 Mdot
.509 .50888 Mdot
.34587 .51722 Mdot
.98604 .39564 Mdot
.64712 .40857 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51979 .00839 Mdot
.56297 .02669 Mdot
.69815 .08355 Mdot
.05951 .22333 Mdot
.33367 .16944 Mdot
.40134 .04182 Mdot
.33031 .57413 Mdot
.05029 .44498 Mdot
.49988 .61798 Mdot
.49962 .61787 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48763 .61279 Mdot
.46061 .60133 Mdot
.3751 .56519 Mdot
.12089 .46092 Mdot
.70228 .35932 Mdot
.51176 .50029 Mdot
.33887 .51118 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50314 .00133 Mdot
.51002 .00425 Mdot
.53191 .01353 Mdot
.60135 .04292 Mdot
.81276 .13065 Mdot
.24457 .26688 Mdot
.43779 .11942 Mdot
.54006 .0632 Mdot
.70178 .09995 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49228 .61476 Mdot
.47541 .60761 Mdot
.42181 .58491 Mdot
.25559 .5153 Mdot
.85078 .36785 Mdot
.63842 .48679 Mdot
.60849 .59953 Mdot
.72897 .07446 Mdot
.0861 .22072 Mdot
.49955 .61784 Mdot
.49858 .61743 Mdot
.49547 .61611 Mdot
.48556 .61191 Mdot
.45404 .59855 Mdot
.35452 .55653 Mdot
.06592 .43967 Mdot
.68125 .38029 Mdot
.51337 .51428 Mdot
.36553 .52666 Mdot
.03913 .41631 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51388 .00589 Mdot
.5442 .01874 Mdot
.63997 .05919 Mdot
.91965 .17285 Mdot
.3148 .24422 Mdot
.49074 .10874 Mdot
.6528 .10016 Mdot
.01043 .22103 Mdot
.35243 .21137 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.5124 .00526 Mdot
.53948 .01674 Mdot
.62517 .05296 Mdot
.87984 .1574 Mdot
.29811 .25851 Mdot
.48848 .11765 Mdot
.66158 .10698 Mdot
.0375 .23233 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.51089 .00462 Mdot
.5347 .01471 Mdot
.61014 .04663 Mdot
.83792 .14077 Mdot
.26892 .26637 Mdot
.46287 .11987 Mdot
.60164 .08576 Mdot
.88272 .17372 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49103 .61423 Mdot
.47144 .60592 Mdot
.40923 .57959 Mdot
.21812 .49992 Mdot
.79305 .35533 Mdot
.59803 .49751 Mdot
.54094 .58275 Mdot
.5446 .00226 Mdot
.61428 .04306 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49056 .61403 Mdot
.46994 .60529 Mdot
.40448 .57758 Mdot
.2042 .49425 Mdot
.77501 .35278 Mdot
.5816 .4985 Mdot
.50531 .57088 Mdot
.43697 .5758 Mdot
.27655 .51889 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49543 .6161 Mdot
.48544 .61186 Mdot
.45363 .59838 Mdot
.35325 .556 Mdot
.06264 .43842 Mdot
.68047 .38185 Mdot
.51463 .51553 Mdot
.37069 .52908 Mdot
.05344 .42196 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48249 .61061 Mdot
.44425 .5944 Mdot
.32409 .54377 Mdot
.99059 .41192 Mdot
.6712 .42064 Mdot
.56188 .55047 Mdot
.54305 .6064 Mdot
.58801 .02779 Mdot
.75837 .10528 Mdot
.50035 .00015 Mdot
.50112 .00047 Mdot
.50356 .00151 Mdot
.51135 .00481 Mdot
.53616 .01533 Mdot
.61474 .04856 Mdot
.8509 .14596 Mdot
.2794 .26483 Mdot
.47324 .1198 Mdot
.62711 .0951 Mdot
.95203 .20081 Mdot
.34782 .24461 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.47429 .60713 Mdot
.41826 .5834 Mdot
.24493 .51091 Mdot
.833 .36344 Mdot
.62806 .49138 Mdot
.59515 .59769 Mdot
.69661 .06271 Mdot
.02349 .20203 Mdot
.31527 .18033 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50669 .00284 Mdot
.52132 .00904 Mdot
.56782 .02874 Mdot
.71299 .08972 Mdot
.09047 .2333 Mdot
.33944 .15387 Mdot
.38638 .02901 Mdot
.27701 .55044 Mdot
.93233 .40501 Mdot
.68613 .46587 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48249 .61061 Mdot
.44427 .59441 Mdot
.32414 .54379 Mdot
.99071 .41197 Mdot
.67121 .42057 Mdot
.56178 .5504 Mdot
.54272 .60625 Mdot
.58698 .02735 Mdot
.7553 .10403 Mdot
.49921 .6177 Mdot
.4975 .61697 Mdot
.49203 .61465 Mdot
.4746 .60726 Mdot
.41924 .58382 Mdot
.24788 .51213 Mdot
.8378 .36459 Mdot
.63104 .49025 Mdot
.59938 .59846 Mdot
.70728 .06669 Mdot
.04537 .20895 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00156 Mdot
.51176 .00499 Mdot
.53744 .01587 Mdot
.61877 .05027 Mdot
.86218 .15043 Mdot
.28743 .26282 Mdot
.48052 .11934 Mdot
.64448 .10133 Mdot
.99658 .21761 Mdot
.35381 .22078 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49544 .6161 Mdot
.48548 .61188 Mdot
.45376 .59843 Mdot
.35367 .55617 Mdot
.06372 .43883 Mdot
.68072 .38133 Mdot
.5142 .51512 Mdot
.36895 .52827 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.51958 .0083 Mdot
.5623 .02641 Mdot
.69611 .0827 Mdot
.0551 .22187 Mdot
.33308 .1718 Mdot
.40412 .0439 Mdot
.33987 .57833 Mdot
.07396 .45369 Mdot
.70106 .38757 Mdot
.49853 .61741 Mdot
.49531 .61605 Mdot
.48507 .6117 Mdot
.45246 .59788 Mdot
.34959 .55446 Mdot
.05322 .43487 Mdot
.6785 .38645 Mdot
.51883 .51935 Mdot
.38733 .53676 Mdot
.10059 .44082 Mdot
.67281 .35365 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48979 .6137 Mdot
.46747 .60424 Mdot
.39671 .5743 Mdot
.18165 .48512 Mdot
.74954 .35098 Mdot
.55617 .49852 Mdot
.4453 .54951 Mdot
.25398 .4998 Mdot
.82401 .3523 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48084 .60991 Mdot
.43901 .59219 Mdot
.30793 .53702 Mdot
.95375 .39914 Mdot
.66798 .44141 Mdot
.58992 .56979 Mdot
.63969 .03076 Mdot
.87311 .14426 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52147 .00911 Mdot
.56832 .02895 Mdot
.71453 .09036 Mdot
.09356 .23426 Mdot
.3402 .15243 Mdot
.38543 .02795 Mdot
.27326 .54871 Mdot
.9249 .40274 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00074 Mdot
.50553 .00234 Mdot
.5176 .00746 Mdot
.55603 .02375 Mdot
.67678 .07463 Mdot
.01144 .20683 Mdot
.32895 .19624 Mdot
.43652 .06648 Mdot
.45137 .00918 Mdot
.3944 .58283 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50555 .00235 Mdot
.51767 .00749 Mdot
.55626 .02385 Mdot
.67748 .07492 Mdot
.01307 .20741 Mdot
.32908 .1953 Mdot
.43522 .0656 Mdot
.44686 .00719 Mdot
.38026 .57687 Mdot
.15053 .47605 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.5055 .00233 Mdot
.51751 .00742 Mdot
.55573 .02362 Mdot
.67585 .07424 Mdot
.00925 .20605 Mdot
.32879 .19749 Mdot
.43825 .06765 Mdot
.4574 .01183 Mdot
.4134 .59084 Mdot
.24581 .51446 Mdot
.4988 .61752 Mdot
.49617 .61641 Mdot
.48779 .61286 Mdot
.46112 .60155 Mdot
.37669 .56586 Mdot
.12527 .46264 Mdot
.70475 .35814 Mdot
.51338 .49976 Mdot
.34205 .51215 Mdot
.97082 .3886 Mdot
.64311 .4155 Mdot
.49836 .61734 Mdot
.49479 .61582 Mdot
.48339 .61099 Mdot
.44712 .59562 Mdot
.33298 .54749 Mdot
.01182 .41955 Mdot
.67295 .4086 Mdot
.54538 .53919 Mdot
.48496 .58069 Mdot
.402 .56677 Mdot
.18117 .48155 Mdot
.49775 .61708 Mdot
.49282 .61499 Mdot
.47713 .60834 Mdot
.42725 .58721 Mdot
.272 .52208 Mdot
.88029 .37595 Mdot
.65169 .47675 Mdot
.61771 .59703 Mdot
.74462 .07844 Mdot
.11014 .2259 Mdot
.32332 .13175 Mdot
.49871 .61749 Mdot
.4959 .6163 Mdot
.48695 .6125 Mdot
.45844 .60042 Mdot
.3683 .56233 Mdot
.10241 .4537 Mdot
.69328 .36518 Mdot
.50789 .50345 Mdot
.33432 .51076 Mdot
.95475 .38345 Mdot
.64214 .42483 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50346 .00147 Mdot
.51104 .00468 Mdot
.53516 .01491 Mdot
.61159 .04724 Mdot
.84203 .14242 Mdot
.27238 .26598 Mdot
.46637 .11989 Mdot
.61028 .08894 Mdot
.90669 .18319 Mdot
.33518 .26482 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50597 .00253 Mdot
.51902 .00807 Mdot
.56054 .02566 Mdot
.69068 .08043 Mdot
.04317 .21785 Mdot
.33169 .17832 Mdot
.41225 .04979 Mdot
.36776 .59053 Mdot
.14695 .48157 Mdot
.73573 .36388 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50415 .00176 Mdot
.51323 .00561 Mdot
.54214 .01786 Mdot
.63351 .05647 Mdot
.90247 .16623 Mdot
.30874 .25109 Mdot
.49235 .11348 Mdot
.66451 .10639 Mdot
.04176 .23316 Mdot
.35709 .19488 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51819 .00771 Mdot
.55789 .02454 Mdot
.68252 .07703 Mdot
.02475 .21151 Mdot
.33 .18866 Mdot
.42605 .05936 Mdot
.41513 .61128 Mdot
.28284 .53628 Mdot
.91689 .39186 Mdot
.50006 2e-05 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50601 .00255 Mdot
.51915 .00812 Mdot
.56094 .02583 Mdot
.69193 .08096 Mdot
.04594 .21879 Mdot
.33199 .17679 Mdot
.41029 .04839 Mdot
.36105 .5876 Mdot
.49813 .61724 Mdot
.49404 .61551 Mdot
.481 .60998 Mdot
.43954 .59241 Mdot
.30955 .5377 Mdot
.95734 .40036 Mdot
.66836 .43943 Mdot
.58738 .56799 Mdot
.63099 .02695 Mdot
.84964 .13513 Mdot
.26174 .2547 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51228 .00521 Mdot
.5391 .01658 Mdot
.62397 .05246 Mdot
.87657 .15611 Mdot
.2963 .25941 Mdot
.48733 .11806 Mdot
.65938 .10633 Mdot
.03249 .2306 Mdot
.35721 .20068 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52354 .00998 Mdot
.57486 .03172 Mdot
.73439 .09859 Mdot
.13149 .24543 Mdot
.35305 .13693 Mdot
.38418 .01924 Mdot
.25653 .53914 Mdot
.89034 .39172 Mdot
.67593 .48552 Mdot
.49928 .61773 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47684 .60821 Mdot
.42632 .58681 Mdot
.26919 .52092 Mdot
.87505 .37445 Mdot
.64967 .47874 Mdot
.61714 .59793 Mdot
.74489 .07895 Mdot
.11124 .22642 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51564 .00663 Mdot
.5498 .02111 Mdot
.65744 .06653 Mdot
.96456 .18981 Mdot
.3244 .2224 Mdot
.47113 .09068 Mdot
.5748 .06407 Mdot
.78657 .13088 Mdot
.2308 .27455 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47386 .60695 Mdot
.41688 .58282 Mdot
.24082 .50922 Mdot
.82642 .36192 Mdot
.62376 .49278 Mdot
.58858 .59629 Mdot
.67953 .05621 Mdot
.98619 .18952 Mdot
.31354 .20231 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48277 .61073 Mdot
.44514 .59478 Mdot
.32685 .54493 Mdot
.99712 .41425 Mdot
.67171 .41692 Mdot
.55672 .54697 Mdot
.52503 .59845 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.49411 .61553 Mdot
.48122 .61007 Mdot
.44023 .5927 Mdot
.31168 .53859 Mdot
.9621 .40198 Mdot
.66884 .43679 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51245 .00528 Mdot
.53963 .0168 Mdot
.62566 .05317 Mdot
.88119 .15793 Mdot
.29884 .25812 Mdot
.48891 .11747 Mdot
.66236 .1072 Mdot
.03924 .23293 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51073 .00455 Mdot
.53418 .01449 Mdot
.60851 .04594 Mdot
.83329 .13892 Mdot
.26485 .26672 Mdot
.45871 .11981 Mdot
.59134 .08197 Mdot
.85356 .16207 Mdot
.30574 .27946 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47765 .60856 Mdot
.42891 .58791 Mdot
.27703 .52417 Mdot
.88986 .37875 Mdot
.65502 .4729 Mdot
.61766 .59494 Mdot
.74114 .07632 Mdot
.10298 .22363 Mdot
.32091 .13469 Mdot
.50061 .00026 Mdot
.50195 .00082 Mdot
.5062 .00263 Mdot
.51974 .00837 Mdot
.56283 .02663 Mdot
.69773 .08338 Mdot
.05861 .22304 Mdot
.33355 .16992 Mdot
.40189 .04224 Mdot
.33222 .57497 Mdot
.05496 .44668 Mdot
.69689 .39674 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52505 .01062 Mdot
.57964 .03374 Mdot
.74878 .10453 Mdot
.15664 .25207 Mdot
.36568 .12919 Mdot
.39631 .01893 Mdot
.28219 .5475 Mdot
.93421 .40297 Mdot
.68212 .46224 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50619 .00263 Mdot
.51972 .00836 Mdot
.56277 .0266 Mdot
.69754 .08329 Mdot
.05819 .22289 Mdot
.33349 .17014 Mdot
.40215 .04244 Mdot
.33313 .57537 Mdot
.05719 .4475 Mdot
.6973 .39561 Mdot
.4987 .61748 Mdot
.49586 .61628 Mdot
.48681 .61244 Mdot
.45799 .60023 Mdot
.3669 .56173 Mdot
.09862 .45223 Mdot
.6917 .36654 Mdot
.50767 .5043 Mdot
.33515 .51141 Mdot
.95725 .38448 Mdot
.64271 .42364 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51684 .00714 Mdot
.55362 .02273 Mdot
.66932 .07151 Mdot
.99373 .2005 Mdot
.32754 .20631 Mdot
.4504 .07593 Mdot
.50005 .03069 Mdot
.54979 .03074 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51499 .00636 Mdot
.54774 .02024 Mdot
.65102 .06383 Mdot
.94833 .18375 Mdot
.32179 .23081 Mdot
.4804 .09803 Mdot
.60969 .07991 Mdot
.89081 .17374 Mdot
.32316 .26721 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.505 .00212 Mdot
.51593 .00676 Mdot
.55072 .0215 Mdot
.6603 .06773 Mdot
.97169 .19245 Mdot
.32532 .21856 Mdot
.46646 .08723 Mdot
.55766 .05636 Mdot
.73347 .10866 Mdot
.14672 .2554 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50833 .00353 Mdot
.52652 .01125 Mdot
.58432 .03572 Mdot
.76276 .11028 Mdot
.17916 .25735 Mdot
.38009 .12418 Mdot
.4177 .02324 Mdot
.3373 .56834 Mdot
.05318 .44244 Mdot
.69077 .39405 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50657 .00278 Mdot
.52091 .00887 Mdot
.56655 .0282 Mdot
.70911 .08811 Mdot
.08257 .23081 Mdot
.33766 .15765 Mdot
.38931 .03193 Mdot
.28801 .55542 Mdot
.95474 .41207 Mdot
.68845 .45346 Mdot
.5007 .0003 Mdot
.50223 .00095 Mdot
.50711 .00301 Mdot
.52264 .0096 Mdot
.57201 .03051 Mdot
.72574 .09501 Mdot
.11544 .24085 Mdot
.34677 .14297 Mdot
.38215 .02186 Mdot
.25646 .54036 Mdot
.89225 .39293 Mdot
.67759 .48537 Mdot
.49764 .61703 Mdot
.49248 .61484 Mdot
.47603 .60787 Mdot
.42378 .58574 Mdot
.26151 .51775 Mdot
.86114 .37059 Mdot
.64362 .4836 Mdot
.61345 .59939 Mdot
.73942 .07785 Mdot
.10359 .22507 Mdot
.32312 .13567 Mdot
.49819 .61727 Mdot
.49425 .61559 Mdot
.48167 .61026 Mdot
.44166 .59331 Mdot
.31609 .54043 Mdot
.97208 .40542 Mdot
.66973 .43117 Mdot
.57639 .56035 Mdot
.59329 .01044 Mdot
.74226 .09206 Mdot
.12967 .23943 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49236 .61479 Mdot
.47567 .60772 Mdot
.42261 .58525 Mdot
.258 .5163 Mdot
.85496 .36894 Mdot
.64059 .48555 Mdot
.61073 .59958 Mdot
.73388 .07611 Mdot
.09454 .2229 Mdot
.50046 .0002 Mdot
.50147 .00063 Mdot
.5047 .00199 Mdot
.51497 .00635 Mdot
.54766 .0202 Mdot
.65078 .06373 Mdot
.94773 .18352 Mdot
.32168 .23111 Mdot
.4807 .09828 Mdot
.61085 .08044 Mdot
.89416 .17509 Mdot
.32478 .26614 Mdot
.49906 .61763 Mdot
.49699 .61676 Mdot
.49042 .61397 Mdot
.46949 .6051 Mdot
.40308 .57699 Mdot
.20012 .4926 Mdot
.77005 .35224 Mdot
.57683 .49861 Mdot
.49442 .5671 Mdot
.40363 .56192 Mdot
.17696 .47794 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.4848 .61159 Mdot
.4516 .59752 Mdot
.34692 .55334 Mdot
.04641 .43231 Mdot
.67727 .38989 Mdot
.52237 .5223 Mdot
.40091 .54297 Mdot
.14022 .45692 Mdot
.69538 .34311 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.5263 .01115 Mdot
.5836 .03542 Mdot
.76063 .10941 Mdot
.17585 .25662 Mdot
.37779 .1248 Mdot
.41389 .02232 Mdot
.32705 .56436 Mdot
.0289 .43377 Mdot
.68764 .40712 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52599 .01102 Mdot
.58264 .03501 Mdot
.75775 .10822 Mdot
.17131 .25559 Mdot
.37473 .12572 Mdot
.40905 .02121 Mdot
.31424 .55944 Mdot
.99989 .42375 Mdot
.6857 .42386 Mdot
.49901 .61761 Mdot
.49683 .61669 Mdot
.4899 .61375 Mdot
.46784 .6044 Mdot
.39786 .57478 Mdot
.18497 .48646 Mdot
.753 .35106 Mdot
.55972 .49858 Mdot
.45393 .55265 Mdot
.28001 .51054 Mdot
.87158 .36561 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54192 .01777 Mdot
.63283 .05619 Mdot
.90065 .16552 Mdot
.308 .25176 Mdot
.4923 .1139 Mdot
.66506 .10677 Mdot
.04334 .23379 Mdot
.35742 .19411 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49941 .61778 Mdot
.49812 .61724 Mdot
.49402 .6155 Mdot
.48095 .60995 Mdot
.43936 .59233 Mdot
.309 .53747 Mdot
.95613 .39995 Mdot
.66823 .4401 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49542 .61609 Mdot
.48541 .61185 Mdot
.45356 .59835 Mdot
.35302 .5559 Mdot
.06205 .4382 Mdot
.68034 .38212 Mdot
.51486 .51576 Mdot
.37164 .52952 Mdot
.05608 .42301 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50584 .00248 Mdot
.5186 .00789 Mdot
.55921 .02509 Mdot
.68658 .07872 Mdot
.03399 .21471 Mdot
.3308 .18344 Mdot
.41899 .0545 Mdot
.39083 .60063 Mdot
.21147 .50718 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50278 .00118 Mdot
.50885 .00375 Mdot
.52818 .01195 Mdot
.58957 .03794 Mdot
.77832 .11666 Mdot
.20203 .26187 Mdot
.39778 .12098 Mdot
.45052 .03259 Mdot
.43022 .60549 Mdot
.30856 .54285 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50674 .00286 Mdot
.52147 .0091 Mdot
.56829 .02894 Mdot
.71445 .09033 Mdot
.0934 .23421 Mdot
.34016 .1525 Mdot
.38547 .02801 Mdot
.27345 .5488 Mdot
.92527 .40285 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49057 .61404 Mdot
.46997 .6053 Mdot
.40459 .57763 Mdot
.20451 .49438 Mdot
.77538 .35282 Mdot
.58196 .49849 Mdot
.5061 .57116 Mdot
.43941 .57681 Mdot
.5004 .00017 Mdot
.50126 .00053 Mdot
.50401 .0017 Mdot
.51278 .00542 Mdot
.5407 .01726 Mdot
.62902 .05458 Mdot
.89035 .16151 Mdot
.30345 .25531 Mdot
.49116 .11601 Mdot
.6656 .10781 Mdot
.04599 .23509 Mdot
.35835 .19305 Mdot
.49954 .61784 Mdot
.49855 .61742 Mdot
.49537 .61607 Mdot
.48525 .61178 Mdot
.45303 .59812 Mdot
.35137 .55521 Mdot
.05779 .43659 Mdot
.67942 .38419 Mdot
.51668 .51746 Mdot
.37892 .53289 Mdot
.07657 .43117 Mdot
.49752 .61698 Mdot
.49208 .61468 Mdot
.47479 .60734 Mdot
.41983 .58407 Mdot
.24963 .51284 Mdot
.84069 .3653 Mdot
.63277 .48953 Mdot
.60169 .59883 Mdot
.71299 .06878 Mdot
.05659 .21236 Mdot
.31708 .16099 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50274 .00116 Mdot
.50872 .0037 Mdot
.52776 .01177 Mdot
.58825 .03738 Mdot
.77442 .11506 Mdot
.19652 .26087 Mdot
.39324 .12158 Mdot
.44156 .02987 Mdot
.40419 .59493 Mdot
.23162 .51138 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52352 .00997 Mdot
.57479 .03169 Mdot
.73418 .09851 Mdot
.13112 .24532 Mdot
.35289 .13706 Mdot
.38409 .01928 Mdot
.25639 .53911 Mdot
.89016 .39169 Mdot
.67591 .48562 Mdot
.49956 .61785 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.4857 .61197 Mdot
.45446 .59873 Mdot
.35583 .55708 Mdot
.06934 .44097 Mdot
.6821 .3787 Mdot
.51218 .51302 Mdot
.36053 .52431 Mdot
.02544 .41093 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48054 .60978 Mdot
.43806 .59178 Mdot
.30499 .5358 Mdot
.94731 .39697 Mdot
.66722 .44493 Mdot
.59431 .57297 Mdot
.65471 .03733 Mdot
.91232 .15921 Mdot
.2949 .23644 Mdot
.50039 .00017 Mdot
.50126 .00053 Mdot
.504 .0017 Mdot
.51274 .0054 Mdot
.54059 .01721 Mdot
.62865 .05443 Mdot
.88935 .16112 Mdot
.30297 .25563 Mdot
.49097 .11619 Mdot
.66542 .10782 Mdot
.04567 .23501 Mdot
.35836 .19325 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.52082 .00883 Mdot
.56624 .02807 Mdot
.70817 .08772 Mdot
.08064 .2302 Mdot
.33726 .1586 Mdot
.39014 .03268 Mdot
.291 .55676 Mdot
.961 .41408 Mdot
.68892 .44988 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .61259 Mdot
.45915 .60072 Mdot
.37053 .56326 Mdot
.10842 .45604 Mdot
.69597 .36313 Mdot
.50863 .50225 Mdot
.33423 .51025 Mdot
.95376 .38289 Mdot
.64168 .42516 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51484 .00629 Mdot
.54725 .02003 Mdot
.64951 .0632 Mdot
.94446 .18229 Mdot
.32104 .23274 Mdot
.48229 .09965 Mdot
.61702 .08327 Mdot
.91188 .18224 Mdot
.33227 .25982 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52444 .01036 Mdot
.57772 .03293 Mdot
.74301 .10215 Mdot
.1468 .24956 Mdot
.36031 .13196 Mdot
.39018 .01846 Mdot
.26807 .54257 Mdot
.90876 .39597 Mdot
.67894 .476 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51188 .00504 Mdot
.53783 .01604 Mdot
.62 .05078 Mdot
.86558 .15178 Mdot
.28967 .2621 Mdot
.48239 .11911 Mdot
.64876 .10282 Mdot
.00717 .22151 Mdot
.49761 .61702 Mdot
.49237 .6148 Mdot
.47571 .60773 Mdot
.42275 .5853 Mdot
.25841 .51647 Mdot
.85568 .36913 Mdot
.64095 .48533 Mdot
.61108 .59957 Mdot
.73463 .07636 Mdot
.0958 .22322 Mdot
.32179 .13967 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02053 Mdot
.65314 .06472 Mdot
.95374 .18578 Mdot
.32275 .22806 Mdot
.47754 .09567 Mdot
.59876 .07492 Mdot
.8588 .16071 Mdot
.30393 .2751 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50788 .00334 Mdot
.52511 .01065 Mdot
.57985 .03383 Mdot
.7494 .10479 Mdot
.15768 .25233 Mdot
.36628 .12892 Mdot
.39708 .01903 Mdot
.28403 .54817 Mdot
.93768 .40398 Mdot
.68244 .46029 Mdot
.49873 .6175 Mdot
.49597 .61632 Mdot
.48716 .61259 Mdot
.4591 .6007 Mdot
.37038 .5632 Mdot
.108 .45588 Mdot
.69578 .36326 Mdot
.50856 .50233 Mdot
.33419 .51026 Mdot
.95371 .38289 Mdot
.64169 .4252 Mdot
.49894 .61758 Mdot
.49661 .6166 Mdot
.48921 .61346 Mdot
.46563 .60346 Mdot
.39091 .57185 Mdot
.16507 .47846 Mdot
.73369 .35143 Mdot
.53979 .4982 Mdot
.40494 .5347 Mdot
.13585 .45172 Mdot
.68683 .34053 Mdot
.49889 .61756 Mdot
.49646 .61653 Mdot
.48872 .61325 Mdot
.46409 .60281 Mdot
.38604 .5698 Mdot
.1513 .47296 Mdot
.72228 .35288 Mdot
.52838 .4982 Mdot
.37682 .52436 Mdot
.05838 .42123 Mdot
.65433 .36831 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50964 .00409 Mdot
.5307 .01302 Mdot
.59752 .0413 Mdot
.80163 .12615 Mdot
.23203 .266 Mdot
.42521 .11939 Mdot
.51029 .05258 Mdot
.6108 .06212 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52544 .01079 Mdot
.5809 .03427 Mdot
.75255 .10609 Mdot
.1629 .25361 Mdot
.36939 .12761 Mdot
.40121 .01967 Mdot
.2942 .55189 Mdot
.95759 .41 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50703 .00298 Mdot
.5224 .0095 Mdot
.57127 .0302 Mdot
.72349 .09408 Mdot
.11114 .23958 Mdot
.34531 .14472 Mdot
.38227 .02285 Mdot
.25832 .54143 Mdot
.89596 .39408 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50272 .00115 Mdot
.50866 .00367 Mdot
.52757 .01169 Mdot
.58764 .03712 Mdot
.77262 .11432 Mdot
.19392 .26038 Mdot
.39116 .1219 Mdot
.43758 .02869 Mdot
.39274 .59032 Mdot
.19891 .49824 Mdot
.49796 .61717 Mdot
.49351 .61528 Mdot
.47932 .60926 Mdot
.43419 .59014 Mdot
.29314 .53086 Mdot
.92207 .3887 Mdot
.66328 .4581 Mdot
.60866 .58427 Mdot
.70465 .05933 Mdot
.02974 .20092 Mdot
.31048 .17351 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50687 .00291 Mdot
.52187 .00927 Mdot
.56958 .02949 Mdot
.71837 .09195 Mdot
.10119 .23659 Mdot
.34225 .14898 Mdot
.38356 .02554 Mdot
.2654 .545 Mdot
.90961 .39815 Mdot
.68224 .47751 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48499 .61167 Mdot
.45222 .59778 Mdot
.34886 .55415 Mdot
.05136 .43417 Mdot
.67815 .38738 Mdot
.51976 .52014 Mdot
.39092 .53841 Mdot
.11097 .44502 Mdot
.67773 .35028 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.5072 .00306 Mdot
.52295 .00973 Mdot
.57301 .03094 Mdot
.72878 .09627 Mdot
.12116 .2425 Mdot
.34885 .14072 Mdot
.38241 .02074 Mdot
.25518 .53941 Mdot
.88935 .39194 Mdot
.49973 .61792 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.4913 .61434 Mdot
.47227 .60628 Mdot
.41187 .5807 Mdot
.22591 .50311 Mdot
.80396 .35725 Mdot
.60714 .4964 Mdot
.55918 .58839 Mdot
.59796 .02397 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50785 .00333 Mdot
.52502 .01061 Mdot
.57956 .03371 Mdot
.74853 .10443 Mdot
.15622 .25197 Mdot
.36544 .1293 Mdot
.39601 .0189 Mdot
.28148 .54725 Mdot
.93286 .40258 Mdot
.68199 .46299 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50507 .00215 Mdot
.51615 .00685 Mdot
.55142 .0218 Mdot
.66248 .06864 Mdot
.97707 .19443 Mdot
.32594 .21562 Mdot
.46274 .08455 Mdot
.54417 .05032 Mdot
.69101 .09075 Mdot
.06036 .22827 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50668 .00283 Mdot
.52127 .00902 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51119 .00475 Mdot
.53564 .01511 Mdot
.61312 .04788 Mdot
.84634 .14414 Mdot
.27587 .26547 Mdot
.46983 .11987 Mdot
.61879 .09206 Mdot
.92984 .19224 Mdot
.34276 .2552 Mdot
.49779 .6171 Mdot
.49295 .61504 Mdot
.47754 .60851 Mdot
.42855 .58776 Mdot
.27594 .52372 Mdot
.88776 .37813 Mdot
.65433 .47377 Mdot
.61778 .59545 Mdot
.74222 .07691 Mdot
.10511 .22428 Mdot
.32155 .13376 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50736 .00312 Mdot
.52345 .00994 Mdot
.5746 .03161 Mdot
.73358 .09826 Mdot
.13003 .24502 Mdot
.35242 .13744 Mdot
.38383 .01941 Mdot
.25604 .53906 Mdot
.50037 .00016 Mdot
.50117 .00049 Mdot
.50371 .00157 Mdot
.51183 .00502 Mdot
.53767 .01597 Mdot
.6195 .05057 Mdot
.86421 .15124 Mdot
.28877 .2624 Mdot
.48166 .11921 Mdot
.64708 .10224 Mdot
.00304 .22 Mdot
.35444 .21718 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00179 Mdot
.51342 .00569 Mdot
.54272 .01811 Mdot
.63535 .05724 Mdot
.90739 .16813 Mdot
.31064 .24922 Mdot
.49228 .11226 Mdot
.66234 .1051 Mdot
.03583 .23083 Mdot
.35603 .19789 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50483 .00205 Mdot
.51538 .00652 Mdot
.54897 .02076 Mdot
.65485 .06544 Mdot
.95806 .18739 Mdot
.32345 .22582 Mdot
.47509 .09372 Mdot
.49999 .61803 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49935 .61776 Mdot
.49793 .61716 Mdot
.49341 .61524 Mdot
.47901 .60913 Mdot
.43321 .58973 Mdot
.29013 .52961 Mdot
.91587 .38673 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52329 .00987 Mdot
.57407 .03138 Mdot
.73198 .0976 Mdot
.1271 .2442 Mdot
.3512 .1385 Mdot
.38322 .01979 Mdot
.25536 .53901 Mdot
.88891 .39155 Mdot
.67589 .48638 Mdot
.50046 .0002 Mdot
.50147 .00063 Mdot
.5047 .00199 Mdot
.51497 .00635 Mdot
.54766 .0202 Mdot
.65078 .06373 Mdot
.94773 .18352 Mdot
.32168 .23111 Mdot
.4807 .09828 Mdot
.61086 .08044 Mdot
.89417 .1751 Mdot
.32479 .26613 Mdot
.49868 .61748 Mdot
.49581 .61626 Mdot
.48665 .61237 Mdot
.45749 .60001 Mdot
.36532 .56107 Mdot
.09438 .45059 Mdot
.69003 .36813 Mdot
.50766 .50532 Mdot
.33677 .51242 Mdot
.96176 .38626 Mdot
.64356 .42138 Mdot
.49843 .61737 Mdot
.495 .61591 Mdot
.48406 .61127 Mdot
.44925 .59652 Mdot
.33959 .55026 Mdot
.02803 .42548 Mdot
.67464 .39963 Mdot
.53373 .53094 Mdot
.44302 .56198 Mdot
.26867 .51028 Mdot
.85723 .36375 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52515 .01067 Mdot
.57999 .03389 Mdot
.74981 .10496 Mdot
.15837 .2525 Mdot
.36668 .12874 Mdot
.39759 .0191 Mdot
.28527 .54861 Mdot
.94005 .40468 Mdot
.49855 .61742 Mdot
.49538 .61607 Mdot
.48528 .61179 Mdot
.45312 .59816 Mdot
.35166 .55533 Mdot
.05854 .43688 Mdot
.67958 .38382 Mdot
.51635 .51715 Mdot
.37759 .53228 Mdot
.0728 .42966 Mdot
.66258 .3645 Mdot
.50016 7e-05 Mdot
.50053 .00022 Mdot
.50167 .00071 Mdot
.50533 .00226 Mdot
.51699 .0072 Mdot
.55407 .02292 Mdot
.67071 .07209 Mdot
.99706 .2017 Mdot
.32782 .20442 Mdot
.44783 .07417 Mdot
.49097 .02666 Mdot
.52057 .01829 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51177 .00499 Mdot
.53748 .01589 Mdot
.61889 .05032 Mdot
.86251 .15056 Mdot
.28765 .26275 Mdot
.48071 .11932 Mdot
.64491 .10148 Mdot
.99767 .21802 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.5259 .01098 Mdot
.58236 .03489 Mdot
.75692 .10788 Mdot
.16999 .25529 Mdot
.37386 .126 Mdot
.40772 .02093 Mdot
.31079 .55813 Mdot
.99234 .42122 Mdot
.68537 .42832 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47929 .60925 Mdot
.43412 .59011 Mdot
.29292 .53077 Mdot
.92162 .38856 Mdot
.66319 .45832 Mdot
.60886 .58446 Mdot
.70539 .05965 Mdot
.03132 .20144 Mdot
.31058 .17259 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51013 .00429 Mdot
.53225 .01368 Mdot
.60243 .04337 Mdot
.81587 .13191 Mdot
.24788 .267 Mdot
.44118 .11947 Mdot
.54825 .06617 Mdot
.7266 .11022 Mdot
.1411 .25618 Mdot
.49921 .6177 Mdot
.4975 .61697 Mdot
.49203 .61465 Mdot
.47461 .60727 Mdot
.41928 .58384 Mdot
.24799 .51217 Mdot
.83799 .36464 Mdot
.63116 .4902 Mdot
.59954 .59849 Mdot
.70767 .06683 Mdot
.04615 .20919 Mdot
.49922 .6177 Mdot
.4975 .61697 Mdot
.49204 .61466 Mdot
.47463 .60728 Mdot
.41933 .58386 Mdot
.24814 .51223 Mdot
.83824 .3647 Mdot
.63131 .49014 Mdot
.59974 .59852 Mdot
.70818 .06702 Mdot
.04715 .2095 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.50869 .00369 Mdot
.52769 .01174 Mdot
.58802 .03729 Mdot
.77375 .11479 Mdot
.19556 .26069 Mdot
.39247 .12169 Mdot
.44008 .02942 Mdot
.39991 .59321 Mdot
.21931 .50642 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51177 .00499 Mdot
.53749 .01589 Mdot
.61892 .05033 Mdot
.8626 .1506 Mdot
.28771 .26273 Mdot
.48076 .11931 Mdot
.64503 .10152 Mdot
.99795 .21812 Mdot
.35395 .22002 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50812 .00344 Mdot
.52586 .01097 Mdot
.58223 .03484 Mdot
.75652 .10772 Mdot
.16934 .25514 Mdot
.37344 .12614 Mdot
.40708 .02079 Mdot
.30913 .5575 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.5187 .00793 Mdot
.55952 .02523 Mdot
.68755 .07913 Mdot
.03617 .21546 Mdot
.331 .18221 Mdot
.41735 .05337 Mdot
.38523 .59818 Mdot
.1955 .50077 Mdot
.78089 .36179 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50759 .00322 Mdot
.52417 .01025 Mdot
.57686 .03257 Mdot
.74041 .10108 Mdot
.14226 .24836 Mdot
.35802 .13335 Mdot
.38796 .0185 Mdot
.26337 .54104 Mdot
.9009 .39401 Mdot
.67765 .48006 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50757 .00321 Mdot
.52411 .01022 Mdot
.57667 .03249 Mdot
.73985 .10085 Mdot
.14127 .24809 Mdot
.35754 .13366 Mdot
.38752 .01853 Mdot
.2625 .54076 Mdot
.89947 .39367 Mdot
.4974 .61693 Mdot
.4917 .61452 Mdot
.47357 .60683 Mdot
.41599 .58244 Mdot
.23815 .50813 Mdot
.82224 .36099 Mdot
.62089 .49359 Mdot
.58394 .5952 Mdot
.66715 .05142 Mdot
.95746 .17942 Mdot
.31083 .21839 Mdot
.49805 .61721 Mdot
.49379 .6154 Mdot
.48021 .60964 Mdot
.43701 .59134 Mdot
.30178 .53446 Mdot
.94035 .39465 Mdot
.66631 .44867 Mdot
.59875 .57628 Mdot
.67 .04403 Mdot
.95045 .17333 Mdot
.30403 .21853 Mdot
.49843 .61737 Mdot
.495 .61592 Mdot
.48409 .61129 Mdot
.44934 .59656 Mdot
.33986 .55038 Mdot
.02872 .42573 Mdot
.67473 .39926 Mdot
.53326 .5306 Mdot
.44133 .56122 Mdot
.26338 .50805 Mdot
.84753 .36103 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48043 .60973 Mdot
.43771 .59163 Mdot
.30392 .53535 Mdot
.94496 .39619 Mdot
.66693 .4462 Mdot
.59584 .5741 Mdot
.65999 .03964 Mdot
.92569 .16421 Mdot
.29885 .23063 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50306 .0013 Mdot
.50975 .00413 Mdot
.53105 .01316 Mdot
.59862 .04176 Mdot
.80483 .12745 Mdot
.23575 .26632 Mdot
.42889 .11937 Mdot
.49838 .61735 Mdot
.49485 .61585 Mdot
.48358 .61107 Mdot
.44774 .59588 Mdot
.33491 .5483 Mdot
.01653 .42126 Mdot
.6734 .40596 Mdot
.54187 .53675 Mdot
.47243 .57512 Mdot
.36184 .54968 Mdot
.06907 .43709 Mdot
.49958 .61786 Mdot
.49868 .61747 Mdot
.49578 .61625 Mdot
.48657 .61234 Mdot
.45722 .5999 Mdot
.36449 .56072 Mdot
.09216 .44973 Mdot
.68919 .36899 Mdot
.50774 .50589 Mdot
.33791 .51307 Mdot
.96483 .38746 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50642 .00272 Mdot
.52044 .00867 Mdot
.56504 .02756 Mdot
.70451 .0862 Mdot
.07303 .22776 Mdot
.33581 .16241 Mdot
.39372 .03579 Mdot
.30379 .56246 Mdot
.98865 .42326 Mdot
.69051 .43378 Mdot
.49897 .6176 Mdot
.49673 .61665 Mdot
.48958 .61361 Mdot
.4668 .60396 Mdot
.39458 .5734 Mdot
.17553 .48266 Mdot
.74341 .35097 Mdot
.54983 .49839 Mdot
.42976 .54383 Mdot
.20772 .48081 Mdot
.75532 .33844 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50751 .00318 Mdot
.52391 .01014 Mdot
.57606 .03223 Mdot
.738 .10009 Mdot
.138 .24721 Mdot
.35598 .13472 Mdot
.38622 .01869 Mdot
.25996 .54 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48384 .61118 Mdot
.44855 .59622 Mdot
.33743 .54936 Mdot
.02269 .42352 Mdot
.67403 .40255 Mdot
.53743 .53361 Mdot
.45644 .56798 Mdot
.31093 .5281 Mdot
.94396 .39124 Mdot
.49886 .61755 Mdot
.49637 .6165 Mdot
.48844 .61313 Mdot
.46319 .60243 Mdot
.38322 .56861 Mdot
.14337 .4698 Mdot
.7164 .35415 Mdot
.52285 .49842 Mdot
.36348 .51953 Mdot
.02352 .40793 Mdot
.64841 .38621 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51255 .00532 Mdot
.53997 .01694 Mdot
.62671 .05361 Mdot
.88406 .15905 Mdot
.30034 .25728 Mdot
.48974 .11705 Mdot
.66375 .10755 Mdot
.04229 .23395 Mdot
.35814 .1952 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50312 .00132 Mdot
.50993 .00421 Mdot
.53162 .01341 Mdot
.60042 .04252 Mdot
.81005 .12956 Mdot
.24162 .26673 Mdot
.43479 .11939 Mdot
.53287 .06061 Mdot
.67989 .09086 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47788 .60865 Mdot
.42963 .58821 Mdot
.27923 .52508 Mdot
.89411 .38002 Mdot
.65637 .4711 Mdot
.61721 .59384 Mdot
.73841 .07491 Mdot
.09772 .22206 Mdot
.31948 .13706 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50498 .00211 Mdot
.51588 .00673 Mdot
.55056 .02143 Mdot
.65981 .06752 Mdot
.97048 .192 Mdot
.32517 .21922 Mdot
.46728 .08783 Mdot
.56065 .0577 Mdot
.7428 .11258 Mdot
.49939 .61778 Mdot
.49807 .61722 Mdot
.49385 .61543 Mdot
.48041 .60973 Mdot
.43766 .59161 Mdot
.30376 .53528 Mdot
.94463 .39608 Mdot
.66689 .44638 Mdot
.59605 .57426 Mdot
.66071 .03996 Mdot
.92751 .16489 Mdot
.49846 .61738 Mdot
.49511 .61596 Mdot
.48441 .61142 Mdot
.45037 .597 Mdot
.34308 .55173 Mdot
.03674 .42871 Mdot
.67578 .39494 Mdot
.52805 .52673 Mdot
.42218 .5526 Mdot
.20417 .4833 Mdot
.75726 .34183 Mdot
.49959 .61786 Mdot
.4987 .61748 Mdot
.49585 .61627 Mdot
.48678 .61243 Mdot
.45792 .60019 Mdot
.36666 .56163 Mdot
.09797 .45198 Mdot
.69144 .36678 Mdot
.50765 .50445 Mdot
.33535 .51154 Mdot
.95782 .38471 Mdot
.50061 .00026 Mdot
.50196 .00083 Mdot
.50624 .00265 Mdot
.51988 .00843 Mdot
.56326 .02681 Mdot
.69906 .08393 Mdot
.06146 .22398 Mdot
.33395 .1684 Mdot
.40015 .04091 Mdot
.3262 .57233 Mdot
.04035 .44137 Mdot
.69463 .40436 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51797 .00762 Mdot
.5572 .02424 Mdot
.68039 .07614 Mdot
.01984 .20979 Mdot
.32961 .19145 Mdot
.42989 .06198 Mdot
.42839 .6171 Mdot
.32305 .55293 Mdot
.00368 .42065 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47571 .60774 Mdot
.42276 .58531 Mdot
.25846 .51649 Mdot
.85575 .36915 Mdot
.64099 .4853 Mdot
.61112 .59957 Mdot
.73471 .07638 Mdot
.09593 .22325 Mdot
.49984 .61797 Mdot
.49948 .61781 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44669 .59544 Mdot
.33164 .54693 Mdot
.00859 .41838 Mdot
.67266 .41042 Mdot
.54782 .54088 Mdot
.49365 .58455 Mdot
.49859 .61743 Mdot
.49549 .61612 Mdot
.48565 .61195 Mdot
.4543 .59866 Mdot
.35533 .55687 Mdot
.06802 .44047 Mdot
.68176 .37931 Mdot
.51263 .5135 Mdot
.36241 .5252 Mdot
.03058 .41295 Mdot
.65316 .38477 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51773 .00752 Mdot
.55644 .02392 Mdot
.67806 .07516 Mdot
.01443 .20789 Mdot
.32919 .19453 Mdot
.43416 .06488 Mdot
.44315 .00556 Mdot
.36868 .57201 Mdot
.11883 .46362 Mdot
.49857 .61743 Mdot
.49545 .6161 Mdot
.4855 .61189 Mdot
.45384 .59847 Mdot
.35391 .55627 Mdot
.06435 .43907 Mdot
.68087 .38103 Mdot
.51396 .51488 Mdot
.36795 .5278 Mdot
.04584 .41895 Mdot
.65591 .37705 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.4876 .61277 Mdot
.4605 .60129 Mdot
.37476 .56504 Mdot
.11995 .46056 Mdot
.70178 .35959 Mdot
.51145 .50041 Mdot
.3383 .51102 Mdot
.96222 .3856 Mdot
.64228 .4203 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47856 .60894 Mdot
.43177 .58912 Mdot
.28576 .52779 Mdot
.90701 .38396 Mdot
.65995 .46534 Mdot
.6144 .58989 Mdot
.72607 .06901 Mdot
.07377 .21489 Mdot
.31474 .14893 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49076 .61412 Mdot
.47058 .60556 Mdot
.40652 .57844 Mdot
.21016 .49668 Mdot
.78251 .35373 Mdot
.58863 .49821 Mdot
.52092 .57619 Mdot
.48451 .59553 Mdot
.42489 .58119 Mdot
.49756 .617 Mdot
.49223 .61474 Mdot
.47525 .60754 Mdot
.42131 .58469 Mdot
.25408 .51468 Mdot
.84819 .36718 Mdot
.63703 .48753 Mdot
.60693 .59944 Mdot
.72544 .07324 Mdot
.07985 .21903 Mdot
.31944 .14808 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51848 .00784 Mdot
.55882 .02493 Mdot
.68538 .07822 Mdot
.03128 .21377 Mdot
.33056 .18496 Mdot
.42103 .05592 Mdot
.39786 .60371 Mdot
.23178 .51539 Mdot
.82853 .36881 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48478 .61158 Mdot
.45154 .59749 Mdot
.34674 .55326 Mdot
.04596 .43214 Mdot
.6772 .39013 Mdot
.52262 .5225 Mdot
.40186 .5434 Mdot
.14305 .45808 Mdot
.69741 .34261 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47452 .60723 Mdot
.419 .58372 Mdot
.24714 .51182 Mdot
.83659 .3643 Mdot
.6303 .49054 Mdot
.59835 .59829 Mdot
.70472 .06574 Mdot
.04023 .20735 Mdot
.31603 .17046 Mdot
.49996 .61802 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.49861 .61744 Mdot
.49557 .61615 Mdot
.48587 .61204 Mdot
.45502 .59896 Mdot
.35758 .55781 Mdot
.0739 .44271 Mdot
.68331 .37664 Mdot
.5108 .51142 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50797 .00338 Mdot
.5254 .01077 Mdot
.58077 .03422 Mdot
.75217 .10593 Mdot
.16228 .25346 Mdot
.369 .12777 Mdot
.40069 .01958 Mdot
.29288 .55141 Mdot
.95496 .40919 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.523 .00975 Mdot
.57317 .031 Mdot
.72926 .09647 Mdot
.12207 .24277 Mdot
.3492 .14038 Mdot
.38249 .02058 Mdot
.25511 .53931 Mdot
.88911 .39184 Mdot
.67632 .48652 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48864 .61322 Mdot
.46381 .60269 Mdot
.38517 .56943 Mdot
.14886 .47198 Mdot
.72041 .35324 Mdot
.52659 .49824 Mdot
.37246 .52278 Mdot
.04685 .4168 Mdot
.65198 .37399 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52311 .0098 Mdot
.57352 .03115 Mdot
.73032 .09691 Mdot
.12404 .24333 Mdot
.34997 .13963 Mdot
.38273 .02025 Mdot
.25507 .53914 Mdot
.8888 .39167 Mdot
.67609 .48657 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51092 .00463 Mdot
.53479 .01475 Mdot
.61044 .04675 Mdot
.83876 .14111 Mdot
.26964 .2663 Mdot
.46361 .11988 Mdot
.60346 .08643 Mdot
.88779 .17573 Mdot
.49915 .61767 Mdot
.49729 .61688 Mdot
.49135 .61437 Mdot
.47245 .60635 Mdot
.41244 .58094 Mdot
.22762 .50381 Mdot
.80642 .35772 Mdot
.60911 .49609 Mdot
.56294 .5895 Mdot
.60875 .02831 Mdot
.80529 .12147 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00286 Mdot
.52145 .0091 Mdot
.56825 .02892 Mdot
.71433 .09028 Mdot
.09316 .23413 Mdot
.3401 .15261 Mdot
.38554 .02809 Mdot
.27373 .54893 Mdot
.92582 .40302 Mdot
.6852 .46932 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50378 .0016 Mdot
.51204 .0051 Mdot
.53833 .01625 Mdot
.62158 .05145 Mdot
.86997 .15351 Mdot
.29242 .26109 Mdot
.48456 .11875 Mdot
.65359 .10446 Mdot
.01888 .22576 Mdot
.35591 .2083 Mdot
.49812 .61724 Mdot
.49401 .61549 Mdot
.48091 .60994 Mdot
.43924 .59228 Mdot
.30864 .53732 Mdot
.95533 .39968 Mdot
.66815 .44054 Mdot
.58881 .569 Mdot
.63589 .02909 Mdot
.86292 .14031 Mdot
.27107 .25225 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49407 .61552 Mdot
.48111 .61003 Mdot
.43989 .59256 Mdot
.31063 .53815 Mdot
.95976 .40118 Mdot
.66861 .43809 Mdot
.58564 .56676 Mdot
.62501 .02434 Mdot
.49772 .61707 Mdot
.49272 .61495 Mdot
.47682 .6082 Mdot
.42627 .58679 Mdot
.26902 .52085 Mdot
.87475 .37436 Mdot
.64955 .47885 Mdot
.6171 .59798 Mdot
.74487 .07897 Mdot
.11124 .22643 Mdot
.32401 .1315 Mdot
.49931 .61774 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47767 .60857 Mdot
.42898 .58794 Mdot
.27726 .52426 Mdot
.89029 .37888 Mdot
.65516 .47272 Mdot
.61762 .59483 Mdot
.74089 .07618 Mdot
.10251 .22349 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50923 .00391 Mdot
.52939 .01246 Mdot
.59339 .03955 Mdot
.78956 .12124 Mdot
.21713 .26425 Mdot
.41104 .11984 Mdot
.47835 .0416 Mdot
.51329 .02159 Mdot
.56814 .0339 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48583 .61202 Mdot
.45487 .5989 Mdot
.35711 .55762 Mdot
.07268 .44224 Mdot
.68298 .37719 Mdot
.51115 .51184 Mdot
.35604 .52217 Mdot
.01326 .40618 Mdot
.65061 .39391 Mdot
.4986 .61744 Mdot
.49553 .61614 Mdot
.48575 .61199 Mdot
.45463 .5988 Mdot
.35637 .5573 Mdot
.07073 .4415 Mdot
.68246 .37807 Mdot
.51174 .51253 Mdot
.35862 .5234 Mdot
.02023 .4089 Mdot
.65158 .39019 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48082 .6099 Mdot
.43897 .59217 Mdot
.30779 .53696 Mdot
.95344 .39904 Mdot
.66794 .44158 Mdot
.59014 .56995 Mdot
.64043 .03108 Mdot
.87508 .14502 Mdot
.27845 .2493 Mdot
.4995 .61782 Mdot
.49842 .61736 Mdot
.49496 .6159 Mdot
.48395 .61123 Mdot
.44889 .59637 Mdot
.33849 .5498 Mdot
.02532 .42448 Mdot
.67433 .40111 Mdot
.53559 .53229 Mdot
.44979 .56501 Mdot
.28993 .51923 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.4806 .60981 Mdot
.43828 .59187 Mdot
.30567 .53608 Mdot
.94878 .39747 Mdot
.6674 .44413 Mdot
.59333 .57225 Mdot
.65135 .03586 Mdot
.90371 .15596 Mdot
.29185 .23988 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.5068 .00288 Mdot
.52165 .00918 Mdot
.56889 .02919 Mdot
.71625 .09108 Mdot
.097 .23532 Mdot
.34109 .15086 Mdot
.3845 .02682 Mdot
.26946 .54694 Mdot
.91747 .40049 Mdot
.6838 .47362 Mdot
.49792 .61715 Mdot
.49338 .61523 Mdot
.4789 .60909 Mdot
.43288 .58959 Mdot
.28912 .52919 Mdot
.91381 .38608 Mdot
.66156 .46213 Mdot
.61211 .58747 Mdot
.71727 .06499 Mdot
.05612 .20942 Mdot
.31253 .15847 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50315 .00134 Mdot
.51003 .00425 Mdot
.53195 .01355 Mdot
.60148 .04297 Mdot
.81313 .13081 Mdot
.24497 .26689 Mdot
.43821 .11942 Mdot
.54105 .06356 Mdot
.7048 .1012 Mdot
.5007 .00029 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.52249 .00954 Mdot
.57154 .03032 Mdot
.72432 .09443 Mdot
.11274 .24005 Mdot
.34584 .14406 Mdot
.3822 .02247 Mdot
.25754 .541 Mdot
.89443 .39362 Mdot
.67831 .48447 Mdot
.50063 .00027 Mdot
.50202 .00085 Mdot
.50642 .00272 Mdot
.52046 .00868 Mdot
.56512 .0276 Mdot
.70474 .08629 Mdot
.07351 .22791 Mdot
.33589 .16216 Mdot
.39347 .03559 Mdot
.30293 .56208 Mdot
.98674 .42262 Mdot
.69041 .4349 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50601 .00255 Mdot
.51914 .00811 Mdot
.5609 .02581 Mdot
.6918 .0809 Mdot
.04565 .21869 Mdot
.33196 .17695 Mdot
.4105 .04854 Mdot
.36174 .5879 Mdot
.13072 .47525 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50686 .00291 Mdot
.52184 .00926 Mdot
.56948 .02944 Mdot
.71807 .09183 Mdot
.1006 .23642 Mdot
.34208 .14924 Mdot
.38368 .02571 Mdot
.26593 .54526 Mdot
.91063 .39845 Mdot
.68246 .47701 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50821 .00348 Mdot
.52615 .01109 Mdot
.58314 .03522 Mdot
.75924 .10884 Mdot
.17367 .25613 Mdot
.3763 .12523 Mdot
.41152 .02176 Mdot
.32073 .56193 Mdot
.01441 .42872 Mdot
.6865 .41538 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51644 .00697 Mdot
.55233 .02218 Mdot
.66532 .06983 Mdot
.98403 .19698 Mdot
.32666 .21175 Mdot
.45771 .081 Mdot
.52608 .04225 Mdot
.6334 .06633 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.503 .00127 Mdot
.50956 .00405 Mdot
.53045 .01291 Mdot
.59673 .04096 Mdot
.79933 .12522 Mdot
.22929 .26573 Mdot
.42253 .11943 Mdot
.50411 .05042 Mdot
.59186 .05423 Mdot
.80988 .13474 Mdot
.49919 .61769 Mdot
.49741 .61694 Mdot
.49175 .61453 Mdot
.47371 .60688 Mdot
.4164 .58262 Mdot
.23939 .50864 Mdot
.82418 .36142 Mdot
.62224 .49322 Mdot
.58614 .59573 Mdot
.67304 .05371 Mdot
.97131 .18434 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.52591 .01099 Mdot
.58238 .0349 Mdot
.75697 .1079 Mdot
.17007 .25531 Mdot
.37391 .12598 Mdot
.4078 .02094 Mdot
.31099 .5582 Mdot
.99276 .42136 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.51037 .0044 Mdot
.53304 .01401 Mdot
.60491 .04442 Mdot
.82298 .13478 Mdot
.25513 .26708 Mdot
.44866 .11961 Mdot
.56653 .07284 Mdot
.7813 .13274 Mdot
.2302 .27744 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50759 .00322 Mdot
.52419 .01026 Mdot
.57692 .03259 Mdot
.74059 .10116 Mdot
.14258 .24844 Mdot
.35818 .13325 Mdot
.3881 .01849 Mdot
.26367 .54113 Mdot
.90139 .39413 Mdot
.67774 .47981 Mdot
.49844 .61737 Mdot
.49503 .61593 Mdot
.48417 .61132 Mdot
.4496 .59667 Mdot
.34069 .55073 Mdot
.03078 .4265 Mdot
.67498 .39814 Mdot
.53188 .52959 Mdot
.4363 .55896 Mdot
.24768 .50146 Mdot
.82036 .35393 Mdot
.49836 .61734 Mdot
.49477 .61581 Mdot
.48333 .61096 Mdot
.44692 .59553 Mdot
.33237 .54724 Mdot
.01034 .41901 Mdot
.67282 .40943 Mdot
.54649 .53996 Mdot
.48892 .58245 Mdot
.41475 .57219 Mdot
.21872 .49688 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52195 .00931 Mdot
.56982 .02959 Mdot
.71908 .09225 Mdot
.10259 .23702 Mdot
.34265 .14836 Mdot
.3833 .02512 Mdot
.26417 .54441 Mdot
.90725 .39745 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51443 .00612 Mdot
.54595 .01948 Mdot
.64543 .06148 Mdot
.93394 .17831 Mdot
.31872 .23781 Mdot
.48668 .1038 Mdot
.63468 .09147 Mdot
.96144 .20195 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50513 .00218 Mdot
.51636 .00694 Mdot
.55207 .02207 Mdot
.66451 .06949 Mdot
.98205 .19625 Mdot
.32646 .21286 Mdot
.45917 .08202 Mdot
.53129 .04457 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50759 .00322 Mdot
.52417 .01025 Mdot
.57685 .03256 Mdot
.74039 .10107 Mdot
.14223 .24835 Mdot
.35801 .13336 Mdot
.38795 .0185 Mdot
.26335 .54103 Mdot
.90086 .394 Mdot
.67765 .48008 Mdot
.49946 .6178 Mdot
.49826 .6173 Mdot
.49447 .61569 Mdot
.48238 .61056 Mdot
.44392 .59426 Mdot
.32306 .54334 Mdot
.98819 .41107 Mdot
.67102 .42201 Mdot
.56377 .55175 Mdot
.54966 .60931 Mdot
.60882 .03656 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49057 .61403 Mdot
.46996 .6053 Mdot
.40456 .57761 Mdot
.20443 .49434 Mdot
.77528 .35281 Mdot
.58186 .49849 Mdot
.50589 .57108 Mdot
.43876 .57655 Mdot
.49803 .6172 Mdot
.49372 .61537 Mdot
.47998 .60955 Mdot
.4363 .59104 Mdot
.29961 .53355 Mdot
.93569 .39312 Mdot
.66563 .45113 Mdot
.60154 .57842 Mdot
.67963 .04826 Mdot
.9735 .18162 Mdot
.30694 .20607 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.5169 .00716 Mdot
.55379 .0228 Mdot
.66983 .07172 Mdot
.99495 .20094 Mdot
.32764 .20562 Mdot
.44946 .07529 Mdot
.49673 .02922 Mdot
.5391 .02618 Mdot
.63953 .06207 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.49948 .61782 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.4833 .61095 Mdot
.44685 .5955 Mdot
.33214 .54714 Mdot
.00979 .41881 Mdot
.67277 .40974 Mdot
.54691 .54025 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49147 .61442 Mdot
.47283 .60651 Mdot
.41363 .58145 Mdot
.23114 .50525 Mdot
.81159 .35874 Mdot
.61312 .49537 Mdot
.57041 .59163 Mdot
.62989 .03676 Mdot
.86328 .14424 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00148 Mdot
.51116 .00473 Mdot
.53553 .01506 Mdot
.61276 .04773 Mdot
.84533 .14374 Mdot
.27507 .2656 Mdot
.46904 .11988 Mdot
.61685 .09135 Mdot
.92461 .19021 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50661 .0028 Mdot
.52107 .00894 Mdot
.56704 .02841 Mdot
.71063 .08874 Mdot
.08569 .2318 Mdot
.33833 .15614 Mdot
.38808 .03074 Mdot
.28343 .55336 Mdot
.9453 .40906 Mdot
.68761 .45877 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50569 .00241 Mdot
.51812 .00768 Mdot
.55766 .02444 Mdot
.68181 .07673 Mdot
.02312 .21094 Mdot
.32987 .18958 Mdot
.42732 .06023 Mdot
.4195 .6132 Mdot
.29601 .54171 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00161 Mdot
.51213 .00514 Mdot
.53864 .01638 Mdot
.62253 .05185 Mdot
.8726 .15455 Mdot
.294 .26044 Mdot
.48574 .1185 Mdot
.65611 .1053 Mdot
.02487 .22791 Mdot
.35647 .20494 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50833 .00353 Mdot
.52653 .01125 Mdot
.58433 .03572 Mdot
.76279 .1103 Mdot
.17921 .25736 Mdot
.38013 .12417 Mdot
.41777 .02326 Mdot
.33747 .56841 Mdot
.05359 .44259 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50678 .00287 Mdot
.52159 .00915 Mdot
.56867 .0291 Mdot
.71561 .09081 Mdot
.09572 .23492 Mdot
.34075 .15144 Mdot
.38483 .02724 Mdot
.27083 .54758 Mdot
.92014 .4013 Mdot
.68428 .47226 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47386 .60695 Mdot
.4169 .58283 Mdot
.24088 .50925 Mdot
.82651 .36194 Mdot
.62382 .49276 Mdot
.58868 .59632 Mdot
.67979 .05631 Mdot
.98678 .18973 Mdot
.31357 .20197 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47591 .60782 Mdot
.42338 .58557 Mdot
.26032 .51725 Mdot
.85902 .37002 Mdot
.6426 .48428 Mdot
.6126 .59949 Mdot
.73775 .07735 Mdot
.10092 .22445 Mdot
.32266 .13704 Mdot
.49901 .61761 Mdot
.49683 .61669 Mdot
.48991 .61376 Mdot
.46787 .60441 Mdot
.39796 .57483 Mdot
.18526 .48658 Mdot
.75331 .35107 Mdot
.56004 .49859 Mdot
.45472 .55294 Mdot
.28237 .51152 Mdot
.87622 .36702 Mdot
.4987 .61748 Mdot
.49585 .61628 Mdot
.48679 .61243 Mdot
.45792 .60019 Mdot
.36667 .56164 Mdot
.09801 .45199 Mdot
.69145 .36677 Mdot
.50766 .50444 Mdot
.33534 .51153 Mdot
.95779 .3847 Mdot
.64282 .42337 Mdot
.49903 .61762 Mdot
.49691 .61672 Mdot
.49015 .61386 Mdot
.46864 .60474 Mdot
.40038 .57585 Mdot
.19226 .48941 Mdot
.76095 .35147 Mdot
.56781 .49866 Mdot
.47332 .55964 Mdot
.33901 .53502 Mdot
.00233 .40996 Mdot
.49787 .61713 Mdot
.49322 .61516 Mdot
.47839 .60887 Mdot
.43124 .58889 Mdot
.28412 .52711 Mdot
.90374 .38294 Mdot
.6591 .46684 Mdot
.61532 .59097 Mdot
.72976 .07073 Mdot
.081 .21708 Mdot
.31592 .14519 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47908 .60916 Mdot
.43343 .58982 Mdot
.29081 .52989 Mdot
.91726 .38717 Mdot
.66231 .46046 Mdot
.61075 .58617 Mdot
.71225 .06272 Mdot
.04578 .20614 Mdot
.31159 .16428 Mdot
.49771 .61706 Mdot
.49272 .61495 Mdot
.47679 .60819 Mdot
.42619 .58676 Mdot
.26879 .52076 Mdot
.87433 .37424 Mdot
.64938 .47901 Mdot
.61703 .59804 Mdot
.74483 .07898 Mdot
.11123 .22645 Mdot
.32404 .13152 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50312 .00132 Mdot
.50993 .00421 Mdot
.53164 .01342 Mdot
.6005 .04256 Mdot
.81028 .12965 Mdot
.24187 .26674 Mdot
.43505 .11939 Mdot
.53347 .06083 Mdot
.68174 .09164 Mdot
.04713 .22582 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50531 .00225 Mdot
.51693 .00718 Mdot
.55389 .02284 Mdot
.67016 .07186 Mdot
.99574 .20122 Mdot
.32771 .20517 Mdot
.44885 .07487 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51317 .00558 Mdot
.54193 .01777 Mdot
.63285 .05619 Mdot
.9007 .16554 Mdot
.30802 .25174 Mdot
.4923 .11389 Mdot
.66504 .10676 Mdot
.04331 .23378 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47929 .60925 Mdot
.43411 .59011 Mdot
.29291 .53076 Mdot
.92159 .38855 Mdot
.66319 .45833 Mdot
.60888 .58447 Mdot
.70544 .05968 Mdot
.03143 .20148 Mdot
.31059 .17253 Mdot
.4989 .61757 Mdot
.49648 .61654 Mdot
.4888 .61328 Mdot
.46431 .6029 Mdot
.38675 .5701 Mdot
.15329 .47375 Mdot
.72383 .35261 Mdot
.52989 .49817 Mdot
.38051 .52571 Mdot
.06827 .42506 Mdot
.65674 .36369 Mdot
.49772 .61707 Mdot
.49272 .61495 Mdot
.47682 .6082 Mdot
.42626 .58679 Mdot
.26902 .52085 Mdot
.87474 .37436 Mdot
.64955 .47886 Mdot
.6171 .59798 Mdot
.74487 .07897 Mdot
.11124 .22643 Mdot
.32401 .1315 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47445 .6072 Mdot
.41875 .58361 Mdot
.2464 .51152 Mdot
.83537 .36401 Mdot
.62955 .49083 Mdot
.5973 .5981 Mdot
.70207 .06475 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48906 .6134 Mdot
.46516 .60326 Mdot
.38943 .57123 Mdot
.16087 .47677 Mdot
.73004 .35177 Mdot
.53607 .49815 Mdot
.39575 .53131 Mdot
.10999 .44143 Mdot
.67207 .34739 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50502 .00213 Mdot
.51598 .00678 Mdot
.55087 .02156 Mdot
.66078 .06793 Mdot
.97288 .19289 Mdot
.32546 .21791 Mdot
.46565 .08664 Mdot
.55471 .05504 Mdot
.72424 .10477 Mdot
.12938 .25039 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50377 .0016 Mdot
.51201 .00509 Mdot
.53826 .01622 Mdot
.62134 .05135 Mdot
.8693 .15325 Mdot
.29201 .26125 Mdot
.48425 .11881 Mdot
.6529 .10423 Mdot
.01722 .22516 Mdot
.35576 .20923 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50648 .00275 Mdot
.52065 .00876 Mdot
.5657 .02784 Mdot
.70652 .08703 Mdot
.07722 .22911 Mdot
.33658 .16029 Mdot
.39167 .03405 Mdot
.29653 .55923 Mdot
.97279 .41795 Mdot
.68966 .44305 Mdot
.49947 .61781 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48298 .61082 Mdot
.44582 .59507 Mdot
.32894 .5458 Mdot
.0021 .41603 Mdot
.67211 .41409 Mdot
.55283 .54432 Mdot
.51135 .5924 Mdot
.48688 .60291 Mdot
.49839 .61735 Mdot
.49486 .61585 Mdot
.48363 .61109 Mdot
.44787 .59594 Mdot
.33532 .54847 Mdot
.01754 .42163 Mdot
.6735 .40541 Mdot
.54114 .53623 Mdot
.4698 .57394 Mdot
.35342 .54611 Mdot
.04697 .42864 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50833 .00353 Mdot
.52654 .01126 Mdot
.58439 .03575 Mdot
.76296 .11036 Mdot
.17947 .25742 Mdot
.38031 .12413 Mdot
.41808 .02334 Mdot
.33831 .56873 Mdot
.05562 .44332 Mdot
.69119 .39281 Mdot
.49859 .61743 Mdot
.4955 .61612 Mdot
.48565 .61195 Mdot
.45432 .59867 Mdot
.35541 .5569 Mdot
.06824 .44055 Mdot
.68182 .37921 Mdot
.51255 .51342 Mdot
.3621 .52505 Mdot
.02973 .41262 Mdot
.65302 .38521 Mdot
.49997 .61802 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49917 .61768 Mdot
.49734 .61691 Mdot
.49153 .61444 Mdot
.47302 .60659 Mdot
.41423 .5817 Mdot
.23293 .50598 Mdot
.81427 .35929 Mdot
.61514 .49496 Mdot
.49834 .61733 Mdot
.4947 .61578 Mdot
.4831 .61087 Mdot
.4462 .59523 Mdot
.33013 .5463 Mdot
.00496 .41707 Mdot
.67235 .41247 Mdot
.55061 .5428 Mdot
.50351 .58893 Mdot
.46168 .59218 Mdot
.36293 .557 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52397 .01016 Mdot
.57624 .0323 Mdot
.73854 .10031 Mdot
.13896 .24747 Mdot
.35643 .1344 Mdot
.38658 .01864 Mdot
.26065 .5402 Mdot
.89652 .39299 Mdot
.6769 .4823 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50703 .00298 Mdot
.52241 .0095 Mdot
.57128 .0302 Mdot
.72353 .0941 Mdot
.11122 .23961 Mdot
.34533 .14469 Mdot
.38227 .02283 Mdot
.25828 .5414 Mdot
.89588 .39406 Mdot
.67876 .48384 Mdot
.49865 .61746 Mdot
.49569 .61621 Mdot
.48628 .61222 Mdot
.45632 .59952 Mdot
.36167 .55954 Mdot
.08468 .44684 Mdot
.68658 .37199 Mdot
.5085 .50798 Mdot
.34317 .51585 Mdot
.97886 .39288 Mdot
.64617 .41242 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51961 .00832 Mdot
.56241 .02645 Mdot
.69645 .08284 Mdot
.05583 .22211 Mdot
.33317 .17141 Mdot
.40365 .04356 Mdot
.33826 .57762 Mdot
.06992 .45219 Mdot
.70004 .38943 Mdot
.50059 .00025 Mdot
.50186 .00079 Mdot
.50594 .00252 Mdot
.51892 .00802 Mdot
.56022 .02552 Mdot
.6897 .08003 Mdot
.04099 .21711 Mdot
.33147 .17953 Mdot
.41382 .0509 Mdot
.37313 .59288 Mdot
.16165 .48734 Mdot
.74729 .36194 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50523 .00222 Mdot
.51667 .00707 Mdot
.55305 .02249 Mdot
.66755 .07076 Mdot
.98946 .19895 Mdot
.32717 .20872 Mdot
.45366 .07818 Mdot
.51162 .03582 Mdot
.58699 .04658 Mdot
.78644 .12327 Mdot
.49831 .61732 Mdot
.49461 .61575 Mdot
.48282 .61075 Mdot
.44533 .59486 Mdot
.32742 .54517 Mdot
.99848 .41474 Mdot
.67182 .41614 Mdot
.55566 .54624 Mdot
.52129 .59679 Mdot
.51875 .61647 Mdot
.54428 .01578 Mdot
.49833 .61732 Mdot
.49467 .61577 Mdot
.48301 .61083 Mdot
.44592 .59511 Mdot
.32927 .54594 Mdot
.0029 .41632 Mdot
.67218 .41364 Mdot
.55221 .54389 Mdot
.50915 .59142 Mdot
.47981 .5999 Mdot
.42028 .58124 Mdot
.49919 .61769 Mdot
.4974 .61693 Mdot
.49173 .61453 Mdot
.47366 .60686 Mdot
.41625 .58255 Mdot
.23894 .50845 Mdot
.82346 .36126 Mdot
.62174 .49336 Mdot
.58534 .59554 Mdot
.67089 .05288 Mdot
.9663 .18257 Mdot
.49861 .61744 Mdot
.49556 .61615 Mdot
.48587 .61204 Mdot
.45499 .59895 Mdot
.35751 .55778 Mdot
.07372 .44264 Mdot
.68326 .37672 Mdot
.51086 .51148 Mdot
.35472 .52154 Mdot
.00969 .40479 Mdot
.65013 .39582 Mdot
.49772 .61707 Mdot
.49274 .61495 Mdot
.47687 .60822 Mdot
.42642 .58685 Mdot
.26949 .52104 Mdot
.87561 .3746 Mdot
.64989 .47853 Mdot
.61722 .59784 Mdot
.74492 .07892 Mdot
.11122 .22639 Mdot
.32394 .13147 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.52088 .00885 Mdot
.56644 .02816 Mdot
.7088 .08798 Mdot
.08194 .23061 Mdot
.33753 .15796 Mdot
.38958 .03217 Mdot
.28897 .55585 Mdot
.95674 .41271 Mdot
.68861 .45232 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48825 .61305 Mdot
.46257 .60216 Mdot
.38126 .56778 Mdot
.13792 .46764 Mdot
.71263 .35519 Mdot
.51953 .49869 Mdot
.35566 .51675 Mdot
.00375 .40054 Mdot
.64622 .39707 Mdot
.50047 .0002 Mdot
.50148 .00063 Mdot
.50472 .002 Mdot
.51505 .00638 Mdot
.54792 .02031 Mdot
.65159 .06407 Mdot
.94979 .1843 Mdot
.32206 .23008 Mdot
.47966 .0974 Mdot
.60682 .07859 Mdot
.88245 .17035 Mdot
.31881 .26968 Mdot
.50045 .00019 Mdot
.50143 .0006 Mdot
.50454 .00193 Mdot
.51447 .00614 Mdot
.54607 .01953 Mdot
.64582 .06165 Mdot
.93495 .17869 Mdot
.31896 .23733 Mdot
.48631 .10342 Mdot
.63314 .09075 Mdot
.95718 .20027 Mdot
.34468 .23949 Mdot
.49786 .61712 Mdot
.49317 .61514 Mdot
.47824 .60881 Mdot
.43077 .5887 Mdot
.28269 .52652 Mdot
.90091 .38208 Mdot
.65834 .46812 Mdot
.616 .59186 Mdot
.73265 .07209 Mdot
.08662 .21876 Mdot
.31698 .14237 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50925 .00392 Mdot
.52946 .01249 Mdot
.59361 .03965 Mdot
.79021 .12151 Mdot
.21797 .26437 Mdot
.41181 .1198 Mdot
.48004 .04217 Mdot
.51842 .02372 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50661 .0028 Mdot
.52107 .00893 Mdot
.56703 .02841 Mdot
.7106 .08873 Mdot
.08563 .23178 Mdot
.33832 .15617 Mdot
.3881 .03077 Mdot
.28352 .5534 Mdot
.94549 .40912 Mdot
.68763 .45867 Mdot
.49932 .61775 Mdot
.49785 .61712 Mdot
.49314 .61513 Mdot
.47816 .60877 Mdot
.43051 .58859 Mdot
.28191 .52619 Mdot
.89936 .3816 Mdot
.65791 .46881 Mdot
.61633 .59234 Mdot
.73411 .0728 Mdot
.08945 .21961 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50668 .00283 Mdot
.52128 .00902 Mdot
.5677 .02869 Mdot
.71262 .08957 Mdot
.08973 .23307 Mdot
.33926 .15422 Mdot
.38663 .02927 Mdot
.27796 .55087 Mdot
.93423 .4056 Mdot
.68637 .46485 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50963 .00408 Mdot
.53067 .01301 Mdot
.59744 .04126 Mdot
.80141 .12606 Mdot
.23176 .26597 Mdot
.42495 .1194 Mdot
.50968 .05237 Mdot
.60894 .06134 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00116 Mdot
.50875 .00371 Mdot
.52787 .01182 Mdot
.58857 .03752 Mdot
.77538 .11545 Mdot
.19789 .26113 Mdot
.39435 .12142 Mdot
.44373 .03052 Mdot
.41045 .59747 Mdot
.24983 .51876 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.5063 .00267 Mdot
.52007 .00851 Mdot
.56387 .02707 Mdot
.70093 .08471 Mdot
.06546 .22529 Mdot
.33455 .1663 Mdot
.3978 .03909 Mdot
.31807 .56876 Mdot
.02111 .4345 Mdot
.69258 .41499 Mdot
.50036 .00015 Mdot
.50113 .00048 Mdot
.50361 .00153 Mdot
.51151 .00488 Mdot
.53666 .01554 Mdot
.61632 .04923 Mdot
.85535 .14772 Mdot
.28269 .26411 Mdot
.47631 .11967 Mdot
.63453 .09778 Mdot
.97135 .20817 Mdot
.35092 .23459 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50572 .00242 Mdot
.51821 .00772 Mdot
.55796 .02457 Mdot
.68274 .07712 Mdot
.02525 .21168 Mdot
.33004 .18837 Mdot
.42566 .0591 Mdot
.41379 .6107 Mdot
.27883 .53463 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54142 .01756 Mdot
.63126 .05553 Mdot
.89643 .16388 Mdot
.30621 .25326 Mdot
.49201 .11483 Mdot
.66581 .10742 Mdot
.04573 .2348 Mdot
.35799 .19299 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50712 .00302 Mdot
.52269 .00962 Mdot
.57217 .03058 Mdot
.72624 .09522 Mdot
.11638 .24112 Mdot
.3471 .14259 Mdot
.38216 .02167 Mdot
.25616 .54016 Mdot
.89161 .39273 Mdot
.50057 .00024 Mdot
.50183 .00078 Mdot
.50583 .00247 Mdot
.51857 .00787 Mdot
.55909 .02504 Mdot
.68622 .07857 Mdot
.03317 .21443 Mdot
.33072 .1839 Mdot
.4196 .05493 Mdot
.39295 .60156 Mdot
.21756 .50964 Mdot
.80837 .36515 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .00179 Mdot
.51346 .00571 Mdot
.54287 .01817 Mdot
.6358 .05743 Mdot
.90859 .1686 Mdot
.31108 .24875 Mdot
.49221 .11194 Mdot
.66166 .10473 Mdot
.03401 .23012 Mdot
.35573 .19883 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.52301 .00976 Mdot
.57318 .03101 Mdot
.7293 .09649 Mdot
.12213 .24278 Mdot
.34922 .14035 Mdot
.3825 .02057 Mdot
.2551 .5393 Mdot
.8891 .39183 Mdot
.67631 .48652 Mdot
.49977 .61793 Mdot
.49926 .61772 Mdot
.49763 .61703 Mdot
.49245 .61483 Mdot
.47594 .60783 Mdot
.42348 .58561 Mdot
.26061 .51738 Mdot
.85954 .37016 Mdot
.64286 .48411 Mdot
.61282 .59947 Mdot
.73818 .07748 Mdot
.50027 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.50889 .00377 Mdot
.52831 .012 Mdot
.58996 .03811 Mdot
.77949 .11714 Mdot
.20367 .26215 Mdot
.39915 .12082 Mdot
.45329 .03346 Mdot
.43837 .60881 Mdot
.3333 .5531 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48427 .61136 Mdot
.44992 .59681 Mdot
.34169 .55114 Mdot
.03326 .42741 Mdot
.6753 .39681 Mdot
.53026 .5284 Mdot
.43035 .55628 Mdot
.22925 .49375 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .00139 Mdot
.51048 .00444 Mdot
.53337 .01415 Mdot
.60594 .04485 Mdot
.82594 .13597 Mdot
.25801 .26703 Mdot
.45165 .11968 Mdot
.57388 .07554 Mdot
.803 .1416 Mdot
.25774 .28104 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48119 .61006 Mdot
.44015 .59267 Mdot
.31143 .53848 Mdot
.96154 .40179 Mdot
.66878 .4371 Mdot
.58434 .56584 Mdot
.62056 .02239 Mdot
.82082 .12377 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.5046 .00195 Mdot
.51467 .00622 Mdot
.54671 .0198 Mdot
.64781 .06248 Mdot
.94009 .18064 Mdot
.32013 .23488 Mdot
.48425 .10143 Mdot
.62477 .08685 Mdot
.93385 .19102 Mdot
.33933 .2506 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48015 .60962 Mdot
.43683 .59126 Mdot
.30122 .53422 Mdot
.93914 .39426 Mdot
.66614 .44931 Mdot
.59949 .57684 Mdot
.67254 .04515 Mdot
.9566 .17556 Mdot
.30496 .2153 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50693 .00294 Mdot
.52209 .00937 Mdot
.57027 .02978 Mdot
.72048 .09283 Mdot
.10532 .23785 Mdot
.34346 .14718 Mdot
.38286 .02435 Mdot
.262 .54334 Mdot
.90308 .39621 Mdot
.68072 .48061 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.5063 .00267 Mdot
.52006 .00851 Mdot
.56383 .02705 Mdot
.7008 .08465 Mdot
.06519 .2252 Mdot
.3345 .16645 Mdot
.39796 .03922 Mdot
.31862 .569 Mdot
.02239 .43496 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.5311 .01319 Mdot
.5988 .04184 Mdot
.80537 .12766 Mdot
.23636 .26637 Mdot
.4295 .11937 Mdot
.52032 .05613 Mdot
.64155 .07492 Mdot
.94819 .18951 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51247 .00529 Mdot
.5397 .01683 Mdot
.62588 .05326 Mdot
.8818 .15816 Mdot
.29916 .25795 Mdot
.48909 .11738 Mdot
.66268 .10728 Mdot
.03996 .23317 Mdot
.49747 .61696 Mdot
.49195 .61462 Mdot
.47436 .60716 Mdot
.41847 .58349 Mdot
.24556 .51117 Mdot
.83402 .36369 Mdot
.62871 .49114 Mdot
.59609 .59787 Mdot
.699 .0636 Mdot
.02849 .20364 Mdot
.31547 .17736 Mdot
.49867 .61747 Mdot
.49576 .61624 Mdot
.48648 .6123 Mdot
.45696 .59979 Mdot
.36366 .56037 Mdot
.08997 .44888 Mdot
.6884 .36985 Mdot
.50789 .50648 Mdot
.33922 .51379 Mdot
.96835 .38882 Mdot
.64464 .41797 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51515 .00643 Mdot
.54825 .02045 Mdot
.65261 .0645 Mdot
.95238 .18527 Mdot
.32252 .22876 Mdot
.47829 .09627 Mdot
.60159 .0762 Mdot
.86712 .16411 Mdot
.30961 .27348 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47423 .60711 Mdot
.41805 .58332 Mdot
.24432 .51066 Mdot
.83201 .36321 Mdot
.62743 .4916 Mdot
.59422 .59751 Mdot
.69422 .0618 Mdot
.01844 .20038 Mdot
.31506 .18332 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49227 .61476 Mdot
.47539 .6076 Mdot
.42173 .58487 Mdot
.25535 .5152 Mdot
.85037 .36774 Mdot
.6382 .48691 Mdot
.60825 .59952 Mdot
.72843 .07428 Mdot
.08516 .22047 Mdot
.49932 .61774 Mdot
.49783 .61711 Mdot
.49308 .6151 Mdot
.47795 .60868 Mdot
.42985 .58831 Mdot
.2799 .52536 Mdot
.89543 .38041 Mdot
.65676 .47053 Mdot
.61703 .59347 Mdot
.73743 .07441 Mdot
.09583 .2215 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47698 .60827 Mdot
.42677 .587 Mdot
.27054 .52148 Mdot
.87757 .37516 Mdot
.65066 .4778 Mdot
.61747 .59752 Mdot
.74491 .07876 Mdot
.11097 .22623 Mdot
.32373 .1315 Mdot
.49952 .61783 Mdot
.49849 .61739 Mdot
.49517 .61599 Mdot
.48463 .61152 Mdot
.45106 .59729 Mdot
.34522 .55262 Mdot
.04212 .43071 Mdot
.67657 .39211 Mdot
.5248 .52423 Mdot
.41009 .54713 Mdot
.16756 .46814 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50594 .00252 Mdot
.51891 .00802 Mdot
.56018 .02551 Mdot
.6896 .07998 Mdot
.04076 .21703 Mdot
.33145 .17966 Mdot
.41399 .05101 Mdot
.3737 .59314 Mdot
.16323 .48796 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51263 .00535 Mdot
.54021 .01705 Mdot
.62746 .05392 Mdot
.8861 .15985 Mdot
.30138 .25666 Mdot
.49026 .11673 Mdot
.66453 .10771 Mdot
.04394 .23449 Mdot
.35827 .19427 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.48508 .61171 Mdot
.45248 .59789 Mdot
.34967 .55449 Mdot
.05343 .43495 Mdot
.67854 .38634 Mdot
.51872 .51926 Mdot
.38692 .53658 Mdot
.09941 .44034 Mdot
.67229 .35406 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50263 .00112 Mdot
.50838 .00355 Mdot
.5267 .01132 Mdot
.58488 .03596 Mdot
.76443 .11097 Mdot
.18173 .25791 Mdot
.38193 .12373 Mdot
.42082 .02404 Mdot
.34577 .57166 Mdot
.07394 .45003 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50301 .00128 Mdot
.50959 .00407 Mdot
.53056 .01296 Mdot
.59709 .04112 Mdot
.80039 .12565 Mdot
.23055 .26586 Mdot
.42377 .11941 Mdot
.50695 .05141 Mdot
.60057 .05786 Mdot
.83519 .14501 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48833 .61308 Mdot
.46282 .60227 Mdot
.38206 .56812 Mdot
.14015 .46852 Mdot
.71415 .35475 Mdot
.52084 .49857 Mdot
.35872 .51783 Mdot
.01143 .4034 Mdot
.64701 .39281 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.50911 .00386 Mdot
.52901 .0123 Mdot
.59218 .03904 Mdot
.78601 .1198 Mdot
.21249 .26358 Mdot
.40684 .12011 Mdot
.46929 .0386 Mdot
.48598 .01031 Mdot
.49868 .61748 Mdot
.49581 .61626 Mdot
.48665 .61237 Mdot
.45749 .60001 Mdot
.36532 .56107 Mdot
.09439 .45059 Mdot
.69003 .36813 Mdot
.50766 .50532 Mdot
.33676 .51242 Mdot
.96174 .38626 Mdot
.64356 .42138 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50809 .00343 Mdot
.52578 .01093 Mdot
.58198 .03473 Mdot
.75577 .10741 Mdot
.16814 .25486 Mdot
.37267 .1264 Mdot
.40593 .02055 Mdot
.30615 .55637 Mdot
.98234 .41791 Mdot
.68497 .43425 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.5209 .00886 Mdot
.56649 .02818 Mdot
.70894 .08804 Mdot
.08221 .2307 Mdot
.33758 .15783 Mdot
.38946 .03206 Mdot
.28855 .55567 Mdot
.95588 .41243 Mdot
.68854 .45281 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51486 .0063 Mdot
.5473 .02005 Mdot
.64966 .06326 Mdot
.94485 .18244 Mdot
.32112 .23255 Mdot
.4821 .09949 Mdot
.61629 .08293 Mdot
.90981 .1814 Mdot
.33148 .26061 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47984 .60948 Mdot
.43584 .59084 Mdot
.29818 .53296 Mdot
.93264 .39212 Mdot
.66515 .45272 Mdot
.60327 .57979 Mdot
.68564 .05091 Mdot
.9875 .18656 Mdot
.30809 .19813 Mdot
.49774 .61707 Mdot
.49279 .61498 Mdot
.47703 .60829 Mdot
.42693 .58707 Mdot
.27105 .52169 Mdot
.87851 .37543 Mdot
.65102 .47744 Mdot
.61756 .59736 Mdot
.74485 .07867 Mdot
.11074 .22613 Mdot
.3236 .13156 Mdot
.49881 .61753 Mdot
.49621 .61643 Mdot
.48793 .61292 Mdot
.46157 .60174 Mdot
.37813 .56646 Mdot
.12923 .4642 Mdot
.70709 .35714 Mdot
.51507 .49936 Mdot
.34561 .5133 Mdot
.97921 .39159 Mdot
.64391 .41081 Mdot
.49787 .61713 Mdot
.49323 .61516 Mdot
.47843 .60889 Mdot
.43136 .58895 Mdot
.2845 .52727 Mdot
.90449 .38318 Mdot
.6593 .4665 Mdot
.61512 .59073 Mdot
.72894 .07035 Mdot
.07941 .2166 Mdot
.31565 .146 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50825 .0035 Mdot
.52629 .01115 Mdot
.58357 .0354 Mdot
.76052 .10936 Mdot
.17569 .25659 Mdot
.37767 .12483 Mdot
.41371 .02227 Mdot
.32656 .56417 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47601 .60786 Mdot
.42369 .5857 Mdot
.26126 .51764 Mdot
.86069 .37047 Mdot
.6434 .48374 Mdot
.61328 .59942 Mdot
.73908 .07775 Mdot
.10306 .22495 Mdot
.32303 .13595 Mdot
.49752 .61698 Mdot
.49208 .61468 Mdot
.47479 .60734 Mdot
.41982 .58406 Mdot
.24962 .51284 Mdot
.84068 .3653 Mdot
.63276 .48953 Mdot
.60168 .59883 Mdot
.71296 .06877 Mdot
.05653 .21234 Mdot
.31708 .16103 Mdot
.49901 .61761 Mdot
.49684 .61669 Mdot
.48994 .61377 Mdot
.46795 .60444 Mdot
.39821 .57493 Mdot
.18598 .48687 Mdot
.75407 .3511 Mdot
.56082 .4986 Mdot
.45659 .55362 Mdot
.28806 .51388 Mdot
.88759 .37053 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50541 .0023 Mdot
.51725 .00731 Mdot
.5549 .02327 Mdot
.67328 .07316 Mdot
.00319 .2039 Mdot
.32831 .20094 Mdot
.44303 .0709 Mdot
.47409 .0192 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.5104 .00441 Mdot
.53312 .01404 Mdot
.60517 .04453 Mdot
.82373 .13508 Mdot
.25586 .26707 Mdot
.44943 .11963 Mdot
.5684 .07353 Mdot
.78684 .135 Mdot
.23765 .27861 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50837 .00355 Mdot
.52667 .01131 Mdot
.58477 .03591 Mdot
.76412 .11084 Mdot
.18125 .2578 Mdot
.38158 .12381 Mdot
.42023 .02388 Mdot
.34416 .57102 Mdot
.06994 .44856 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.4863 .61222 Mdot
.45636 .59953 Mdot
.36178 .55958 Mdot
.08498 .44696 Mdot
.68668 .37187 Mdot
.50846 .50789 Mdot
.34292 .51573 Mdot
.9782 .39262 Mdot
.64608 .41277 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47986 .60949 Mdot
.4359 .59087 Mdot
.29839 .53304 Mdot
.93308 .39226 Mdot
.66522 .45249 Mdot
.60302 .57959 Mdot
.68479 .05053 Mdot
.98553 .18587 Mdot
.30794 .19927 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.4778 .60862 Mdot
.42937 .5881 Mdot
.27843 .52475 Mdot
.89257 .37955 Mdot
.65589 .47176 Mdot
.6174 .59425 Mdot
.73949 .07545 Mdot
.09978 .22267 Mdot
.32002 .13612 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50704 .00298 Mdot
.52241 .0095 Mdot
.57129 .03021 Mdot
.72358 .09412 Mdot
.11131 .23963 Mdot
.34536 .14465 Mdot
.38226 .02281 Mdot
.25823 .54138 Mdot
.89579 .39403 Mdot
.67873 .48388 Mdot
.49749 .61697 Mdot
.49201 .61465 Mdot
.47456 .60724 Mdot
.41909 .58376 Mdot
.24743 .51194 Mdot
.83707 .36441 Mdot
.63059 .49043 Mdot
.59876 .59836 Mdot
.70574 .06612 Mdot
.04228 .20799 Mdot
.31614 .16926 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48115 .61004 Mdot
.44 .5926 Mdot
.31096 .53828 Mdot
.96049 .40143 Mdot
.66868 .43769 Mdot
.58511 .56639 Mdot
.62321 .02355 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48365 .6111 Mdot
.44795 .59597 Mdot
.33556 .54857 Mdot
.01812 .42184 Mdot
.67355 .40508 Mdot
.54071 .53593 Mdot
.46828 .57327 Mdot
.34858 .54405 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52363 .01002 Mdot
.57517 .03185 Mdot
.73531 .09897 Mdot
.13317 .24589 Mdot
.35378 .13635 Mdot
.38464 .01907 Mdot
.25721 .53928 Mdot
.8913 .39189 Mdot
.49984 .61797 Mdot
.49949 .61782 Mdot
.49836 .61734 Mdot
.49478 .61582 Mdot
.48336 .61098 Mdot
.44704 .59558 Mdot
.33273 .54739 Mdot
.01123 .41933 Mdot
.6729 .40893 Mdot
.54582 .5395 Mdot
.48654 .5814 Mdot
.4985 .6174 Mdot
.49524 .61601 Mdot
.48482 .6116 Mdot
.45168 .59755 Mdot
.34718 .55344 Mdot
.04707 .43256 Mdot
.67738 .38956 Mdot
.52201 .52201 Mdot
.39954 .54235 Mdot
.1362 .45528 Mdot
.6926 .34387 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48646 .61229 Mdot
.45687 .59975 Mdot
.36339 .56026 Mdot
.08923 .4486 Mdot
.68813 .37014 Mdot
.50796 .50668 Mdot
.33971 .51405 Mdot
.96965 .38933 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.51319 .00559 Mdot
.542 .01781 Mdot
.63307 .05629 Mdot
.9013 .16578 Mdot
.30827 .25152 Mdot
.49233 .11375 Mdot
.66487 .10664 Mdot
.04281 .23358 Mdot
.3573 .19437 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50319 .00135 Mdot
.51017 .00431 Mdot
.5324 .01374 Mdot
.6029 .04357 Mdot
.81722 .13245 Mdot
.24929 .26704 Mdot
.44263 .11949 Mdot
.55177 .06745 Mdot
.73721 .11461 Mdot
.16062 .26168 Mdot
.49786 .61713 Mdot
.4932 .61515 Mdot
.47832 .60884 Mdot
.43104 .58881 Mdot
.28351 .52686 Mdot
.90253 .38257 Mdot
.65878 .46739 Mdot
.61562 .59136 Mdot
.73102 .07133 Mdot
.08347 .21782 Mdot
.31637 .14394 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49205 .61466 Mdot
.47469 .6073 Mdot
.41951 .58393 Mdot
.24869 .51246 Mdot
.83914 .36492 Mdot
.63185 .48992 Mdot
.60047 .59864 Mdot
.70999 .06769 Mdot
.05073 .21059 Mdot
.49986 .61797 Mdot
.49956 .61785 Mdot
.49859 .61743 Mdot
.4955 .61612 Mdot
.48565 .61195 Mdot
.45431 .59867 Mdot
.35538 .55689 Mdot
.06816 .44052 Mdot
.6818 .37925 Mdot
.51258 .51345 Mdot
.36222 .52511 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50508 .00215 Mdot
.51619 .00686 Mdot
.55154 .02185 Mdot
.66285 .0688 Mdot
.97799 .19477 Mdot
.32604 .2151 Mdot
.46209 .08408 Mdot
.5418 .04927 Mdot
.68349 .08757 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50765 .00324 Mdot
.52436 .01033 Mdot
.57747 .03282 Mdot
.74224 .10184 Mdot
.14546 .2492 Mdot
.35962 .13236 Mdot
.38948 .01845 Mdot
.26657 .54207 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48938 .61353 Mdot
.46618 .60369 Mdot
.39263 .57258 Mdot
.16996 .48042 Mdot
.73812 .35114 Mdot
.54434 .49827 Mdot
.41623 .53885 Mdot
.16817 .46473 Mdot
.71225 .33626 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49088 .61417 Mdot
.47094 .60571 Mdot
.40766 .57892 Mdot
.21351 .49804 Mdot
.78688 .35436 Mdot
.59259 .49796 Mdot
.5295 .57904 Mdot
.51041 .60623 Mdot
.49886 .61755 Mdot
.49638 .6165 Mdot
.48848 .61315 Mdot
.4633 .60247 Mdot
.38355 .56875 Mdot
.1443 .47017 Mdot
.71706 .35399 Mdot
.52346 .49838 Mdot
.36491 .52005 Mdot
.0272 .40932 Mdot
.64889 .38422 Mdot
.49744 .61695 Mdot
.49185 .61458 Mdot
.47404 .60703 Mdot
.41745 .58306 Mdot
.24252 .50992 Mdot
.82913 .36254 Mdot
.62556 .49222 Mdot
.5914 .59692 Mdot
.68691 .05903 Mdot
.00265 .19514 Mdot
.31441 .19268 Mdot
.50017 7e-05 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50565 .0024 Mdot
.518 .00763 Mdot
.55731 .02429 Mdot
.68072 .07628 Mdot
.02061 .21006 Mdot
.32967 .19101 Mdot
.42928 .06156 Mdot
.42627 .61617 Mdot
.31658 .55024 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51543 .00654 Mdot
.54914 .02083 Mdot
.65538 .06566 Mdot
.9594 .18789 Mdot
.32366 .22513 Mdot
.4743 .0931 Mdot
.58656 .06938 Mdot
.82237 .14573 Mdot
.27264 .27829 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.47552 .60765 Mdot
.42214 .58504 Mdot
.25656 .5157 Mdot
.85246 .36829 Mdot
.6393 .4863 Mdot
.60943 .59957 Mdot
.73106 .07517 Mdot
.08974 .22168 Mdot
.32083 .14282 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50654 .00277 Mdot
.52084 .00884 Mdot
.56632 .02811 Mdot
.70842 .08782 Mdot
.08115 .23036 Mdot
.33736 .15835 Mdot
.38991 .03248 Mdot
.29019 .5564 Mdot
.95931 .41354 Mdot
.6888 .45085 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50379 .00161 Mdot
.51206 .00512 Mdot
.53842 .01629 Mdot
.62184 .05156 Mdot
.87068 .15379 Mdot
.29285 .26092 Mdot
.48489 .11869 Mdot
.6543 .1047 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50618 .00262 Mdot
.51969 .00835 Mdot
.56265 .02655 Mdot
.69718 .08314 Mdot
.05741 .22263 Mdot
.33338 .17056 Mdot
.40265 .04281 Mdot
.33482 .57611 Mdot
.06137 .44903 Mdot
.69813 .39354 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.4743 .60714 Mdot
.41828 .58341 Mdot
.24499 .51094 Mdot
.83308 .36346 Mdot
.62812 .49136 Mdot
.59523 .59771 Mdot
.69681 .06278 Mdot
.02392 .20216 Mdot
.31528 .18007 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49603 .61635 Mdot
.48736 .61268 Mdot
.45976 .60097 Mdot
.37244 .56407 Mdot
.11361 .45807 Mdot
.69847 .36147 Mdot
.50967 .50135 Mdot
.33537 .51031 Mdot
.95586 .38348 Mdot
.498 .61718 Mdot
.49361 .61533 Mdot
.47965 .60941 Mdot
.43526 .5906 Mdot
.2964 .53222 Mdot
.92889 .3909 Mdot
.66453 .45465 Mdot
.6053 .58143 Mdot
.69273 .05404 Mdot
.00361 .19213 Mdot
.30907 .18879 Mdot
.49858 .61743 Mdot
.49548 .61612 Mdot
.4856 .61193 Mdot
.45415 .5986 Mdot
.35489 .55668 Mdot
.06688 .44003 Mdot
.68148 .37984 Mdot
.51303 .51392 Mdot
.36409 .52599 Mdot
.03519 .41476 Mdot
.65393 .3824 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52639 .01119 Mdot
.5839 .03554 Mdot
.76151 .10977 Mdot
.17723 .25693 Mdot
.37874 .12454 Mdot
.41545 .02269 Mdot
.33122 .56598 Mdot
.49848 .61739 Mdot
.49515 .61598 Mdot
.48454 .61148 Mdot
.45079 .59717 Mdot
.34438 .55227 Mdot
.04 .42992 Mdot
.67625 .39323 Mdot
.52606 .52521 Mdot
.41478 .54926 Mdot
.18171 .47398 Mdot
.73154 .33982 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50332 .00141 Mdot
.51057 .00448 Mdot
.53367 .01428 Mdot
.60689 .04526 Mdot
.82868 .13707 Mdot
.26061 .26695 Mdot
.45434 .11973 Mdot
.58052 .07798 Mdot
.8224 .14949 Mdot
.27873 .28203 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49067 .61408 Mdot
.47029 .60544 Mdot
.40559 .57805 Mdot
.20745 .49557 Mdot
.77905 .35327 Mdot
.58542 .49836 Mdot
.51386 .57381 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50599 .00254 Mdot
.51909 .0081 Mdot
.56077 .02576 Mdot
.69139 .08073 Mdot
.04475 .21839 Mdot
.33186 .17745 Mdot
.41113 .04899 Mdot
.36392 .58885 Mdot
.13656 .47752 Mdot
.72858 .36589 Mdot
.49799 .61718 Mdot
.49358 .61531 Mdot
.47955 .60936 Mdot
.43494 .59046 Mdot
.29543 .53181 Mdot
.92685 .39024 Mdot
.66417 .45569 Mdot
.60634 .58229 Mdot
.69642 .05567 Mdot
.01183 .19493 Mdot
.30951 .18398 Mdot
.4992 .61769 Mdot
.49744 .61695 Mdot
.49185 .61458 Mdot
.47403 .60702 Mdot
.41744 .58306 Mdot
.24248 .5099 Mdot
.82905 .36252 Mdot
.62551 .49224 Mdot
.59132 .5969 Mdot
.68672 .05896 Mdot
.00222 .19499 Mdot
.49742 .61694 Mdot
.49178 .61455 Mdot
.47383 .60694 Mdot
.4168 .58279 Mdot
.24058 .50912 Mdot
.82604 .36184 Mdot
.6235 .49286 Mdot
.58818 .5962 Mdot
.67845 .05579 Mdot
.98374 .18868 Mdot
.31338 .20372 Mdot
.49875 .61751 Mdot
.49603 .61635 Mdot
.48735 .61267 Mdot
.4597 .60095 Mdot
.37226 .56399 Mdot
.11312 .45788 Mdot
.69823 .36162 Mdot
.50956 .50143 Mdot
.33521 .51028 Mdot
.95554 .38339 Mdot
.6417 .42406 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51217 .00516 Mdot
.53876 .01644 Mdot
.62293 .05202 Mdot
.8737 .15498 Mdot
.29465 .26016 Mdot
.4862 .11839 Mdot
.65708 .10561 Mdot
.02716 .22872 Mdot
.49762 .61702 Mdot
.4924 .61481 Mdot
.4758 .60777 Mdot
.42304 .58543 Mdot
.25929 .51683 Mdot
.85722 .36954 Mdot
.64172 .48485 Mdot
.61181 .59955 Mdot
.73614 .07684 Mdot
.09831 .22383 Mdot
.32221 .13838 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00142 Mdot
.5107 .00454 Mdot
.53407 .01445 Mdot
.60817 .0458 Mdot
.83232 .13853 Mdot
.26398 .26678 Mdot
.45781 .1198 Mdot
.58911 .08115 Mdot
.84721 .15951 Mdot
.50079 .00033 Mdot
.50252 .00107 Mdot
.50802 .0034 Mdot
.52553 .01083 Mdot
.58119 .0344 Mdot
.75342 .10644 Mdot
.16433 .25395 Mdot
.37026 .12728 Mdot
.40244 .01989 Mdot
.29726 .55303 Mdot
.96381 .41195 Mdot
.68417 .44521 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50994 .00421 Mdot
.53166 .01342 Mdot
.60056 .04258 Mdot
.81045 .12972 Mdot
.24206 .26675 Mdot
.43524 .11939 Mdot
.53393 .06099 Mdot
.68313 .09221 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49682 .61668 Mdot
.48985 .61373 Mdot
.46768 .60433 Mdot
.39737 .57458 Mdot
.18356 .48589 Mdot
.75152 .35102 Mdot
.5582 .49856 Mdot
.45025 .55132 Mdot
.26887 .50594 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50458 .00194 Mdot
.51459 .00619 Mdot
.54646 .0197 Mdot
.64703 .06216 Mdot
.9381 .17989 Mdot
.31969 .23584 Mdot
.48508 .10221 Mdot
.62811 .0884 Mdot
.94323 .19475 Mdot
.34171 .24627 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .0099 Mdot
.57429 .03148 Mdot
.73265 .09787 Mdot
.12832 .24454 Mdot
.3517 .13806 Mdot
.38345 .01962 Mdot
.25559 .53901 Mdot
.88915 .39156 Mdot
.67586 .48621 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50894 .00379 Mdot
.52849 .01208 Mdot
.59053 .03835 Mdot
.78117 .11782 Mdot
.20598 .26255 Mdot
.40113 .12061 Mdot
.45733 .03473 Mdot
.45029 .61368 Mdot
.36989 .56834 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.507 .00297 Mdot
.52229 .00945 Mdot
.57092 .03005 Mdot
.72244 .09364 Mdot
.10912 .23898 Mdot
.34465 .14557 Mdot
.38243 .02335 Mdot
.25945 .54203 Mdot
.89817 .39475 Mdot
.67942 .48284 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50677 .00287 Mdot
.52157 .00915 Mdot
.56862 .02908 Mdot
.71546 .09075 Mdot
.09542 .23483 Mdot
.34067 .15158 Mdot
.38491 .02734 Mdot
.27116 .54773 Mdot
.92078 .40149 Mdot
.68439 .47193 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50703 .00298 Mdot
.52239 .0095 Mdot
.57124 .03019 Mdot
.72341 .09405 Mdot
.111 .23954 Mdot
.34526 .14478 Mdot
.38228 .02288 Mdot
.2584 .54147 Mdot
.89611 .39413 Mdot
.67883 .48374 Mdot
.49864 .61746 Mdot
.49568 .6162 Mdot
.48624 .6122 Mdot
.45619 .59946 Mdot
.36124 .55935 Mdot
.08354 .4464 Mdot
.6862 .37247 Mdot
.50868 .50832 Mdot
.34417 .51636 Mdot
.9815 .39389 Mdot
.64652 .41101 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00213 Mdot
.51598 .00677 Mdot
.55086 .02156 Mdot
.66074 .06791 Mdot
.97278 .19285 Mdot
.32545 .21797 Mdot
.46572 .08669 Mdot
.55498 .05516 Mdot
.72507 .10512 Mdot
.13097 .25086 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.5093 .00394 Mdot
.52963 .01256 Mdot
.59415 .03987 Mdot
.7918 .12215 Mdot
.22 .26464 Mdot
.41369 .11971 Mdot
.48417 .04356 Mdot
.53094 .02891 Mdot
.62385 .05742 Mdot
.49932 .61775 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47811 .60875 Mdot
.43036 .58852 Mdot
.28145 .526 Mdot
.89845 .38133 Mdot
.65765 .46921 Mdot
.61651 .59261 Mdot
.73493 .07319 Mdot
.09101 .22007 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60745 Mdot
.42061 .5844 Mdot
.25198 .51382 Mdot
.84464 .36628 Mdot
.63505 .4885 Mdot
.60459 .59921 Mdot
.71996 .0713 Mdot
.06982 .21623 Mdot
.31828 .15355 Mdot
.49791 .61715 Mdot
.49333 .6152 Mdot
.47874 .60902 Mdot
.43235 .58937 Mdot
.28753 .52853 Mdot
.91057 .38506 Mdot
.66081 .46367 Mdot
.61327 .58865 Mdot
.72165 .06698 Mdot
.06498 .21219 Mdot
.31353 .15361 Mdot
.49838 .61735 Mdot
.49484 .61584 Mdot
.48355 .61106 Mdot
.44764 .59584 Mdot
.33461 .54817 Mdot
.01578 .42099 Mdot
.67332 .40638 Mdot
.54242 .53713 Mdot
.47441 .576 Mdot
.36816 .55237 Mdot
.08601 .44366 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50712 .00302 Mdot
.52269 .00962 Mdot
.57217 .03058 Mdot
.72624 .09522 Mdot
.11638 .24112 Mdot
.3471 .14259 Mdot
.38216 .02167 Mdot
.50068 .00029 Mdot
.50218 .00093 Mdot
.50695 .00295 Mdot
.52214 .00939 Mdot
.57045 .02985 Mdot
.721 .09305 Mdot
.10634 .23815 Mdot
.34377 .14674 Mdot
.38273 .02407 Mdot
.26126 .54296 Mdot
.90166 .39579 Mdot
.68036 .48126 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .0018 Mdot
.51356 .00575 Mdot
.54317 .0183 Mdot
.63674 .05783 Mdot
.9111 .16957 Mdot
.31198 .24776 Mdot
.49201 .11126 Mdot
.66007 .10386 Mdot
.02974 .22847 Mdot
.35506 .20106 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48306 .61085 Mdot
.44607 .59517 Mdot
.32973 .54613 Mdot
.00399 .41672 Mdot
.67227 .41301 Mdot
.55136 .54331 Mdot
.50616 .5901 Mdot
.47019 .5958 Mdot
.38976 .56833 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48669 .61239 Mdot
.45761 .60006 Mdot
.36569 .56122 Mdot
.09538 .45097 Mdot
.69041 .36775 Mdot
.50764 .50507 Mdot
.33632 .51215 Mdot
.96053 .38578 Mdot
.64334 .422 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47343 .60677 Mdot
.41552 .58225 Mdot
.23676 .50756 Mdot
.8201 .36052 Mdot
.61938 .49398 Mdot
.58142 .59457 Mdot
.66031 .04876 Mdot
.94103 .17349 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00148 Mdot
.51109 .0047 Mdot
.53532 .01498 Mdot
.6121 .04745 Mdot
.84346 .14299 Mdot
.27356 .26582 Mdot
.46754 .11989 Mdot
.61317 .09 Mdot
.91461 .1863 Mdot
.33808 .26172 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52029 .0086 Mdot
.56456 .02736 Mdot
.70305 .08559 Mdot
.06995 .22676 Mdot
.33527 .16398 Mdot
.39532 .03711 Mdot
.30942 .56494 Mdot
.00122 .42756 Mdot
.4988 .61753 Mdot
.49618 .61641 Mdot
.48782 .61287 Mdot
.4612 .60158 Mdot
.37696 .56597 Mdot
.126 .46293 Mdot
.70517 .35795 Mdot
.51367 .49968 Mdot
.34266 .51234 Mdot
.97224 .3891 Mdot
.64325 .41471 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02052 Mdot
.65313 .06472 Mdot
.95371 .18577 Mdot
.32275 .22808 Mdot
.47756 .09568 Mdot
.59883 .07495 Mdot
.859 .16079 Mdot
.30407 .27507 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.48761 .61278 Mdot
.46053 .6013 Mdot
.37485 .56508 Mdot
.12021 .46065 Mdot
.70191 .35951 Mdot
.51154 .50038 Mdot
.33845 .51106 Mdot
.96256 .38572 Mdot
.64231 .42011 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50579 .00246 Mdot
.51844 .00782 Mdot
.5587 .02488 Mdot
.68503 .07808 Mdot
.03048 .2135 Mdot
.33049 .18541 Mdot
.42164 .05634 Mdot
.39995 .60463 Mdot
.23788 .51787 Mdot
.83777 .37075 Mdot
.49913 .61766 Mdot
.49721 .61685 Mdot
.49113 .61427 Mdot
.47173 .60605 Mdot
.41017 .57998 Mdot
.22089 .50106 Mdot
.79687 .35597 Mdot
.6013 .49717 Mdot
.54762 .58486 Mdot
.56431 .01032 Mdot
.67487 .06833 Mdot
.49799 .61718 Mdot
.4936 .61532 Mdot
.4796 .60938 Mdot
.43508 .59052 Mdot
.29586 .53199 Mdot
.92775 .39053 Mdot
.66433 .45523 Mdot
.60589 .58191 Mdot
.69481 .05496 Mdot
.00827 .19372 Mdot
.30932 .18606 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47445 .6072 Mdot
.41875 .58361 Mdot
.2464 .51152 Mdot
.83538 .36401 Mdot
.62956 .49083 Mdot
.59731 .5981 Mdot
.70209 .06476 Mdot
.03487 .20567 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52354 .00998 Mdot
.57487 .03172 Mdot
.7344 .0986 Mdot
.13152 .24543 Mdot
.35306 .13692 Mdot
.38419 .01924 Mdot
.25654 .53914 Mdot
.89035 .39172 Mdot
.67593 .48552 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48534 .61182 Mdot
.45331 .59824 Mdot
.35226 .55558 Mdot
.06008 .43746 Mdot
.6799 .38307 Mdot
.51568 .51654 Mdot
.37495 .53105 Mdot
.06534 .42669 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00267 Mdot
.52002 .00849 Mdot
.56371 .027 Mdot
.70044 .0845 Mdot
.06442 .22495 Mdot
.33439 .16685 Mdot
.3984 .03956 Mdot
.32015 .56967 Mdot
.02599 .43623 Mdot
.69302 .41224 Mdot
.50008 4e-05 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50267 .00113 Mdot
.50851 .00361 Mdot
.52711 .0115 Mdot
.58618 .03651 Mdot
.7683 .11255 Mdot
.18757 .25913 Mdot
.38624 .12279 Mdot
.42845 .02608 Mdot
.36689 .57999 Mdot
.49878 .61751 Mdot
.4961 .61638 Mdot
.48757 .61276 Mdot
.46042 .60125 Mdot
.3745 .56494 Mdot
.11925 .46028 Mdot
.7014 .35979 Mdot
.51123 .5005 Mdot
.33789 .51091 Mdot
.96131 .38529 Mdot
.64219 .42081 Mdot
.4976 .61701 Mdot
.49234 .61479 Mdot
.4756 .60769 Mdot
.42242 .58516 Mdot
.25741 .51605 Mdot
.85393 .36867 Mdot
.64006 .48586 Mdot
.6102 .59958 Mdot
.73276 .07574 Mdot
.09264 .22242 Mdot
.32128 .1413 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50575 .00244 Mdot
.51832 .00777 Mdot
.55832 .02472 Mdot
.68385 .07758 Mdot
.02779 .21257 Mdot
.33026 .18693 Mdot
.4237 .05775 Mdot
.40703 .60773 Mdot
.2587 .52636 Mdot
.872 .37904 Mdot
.49973 .61792 Mdot
.49914 .61767 Mdot
.49727 .61687 Mdot
.49129 .61434 Mdot
.47226 .60627 Mdot
.41182 .58068 Mdot
.22576 .50305 Mdot
.80374 .35721 Mdot
.60697 .49642 Mdot
.55885 .58829 Mdot
.597 .02358 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42796 .58751 Mdot
.27415 .52298 Mdot
.88436 .37713 Mdot
.65316 .47515 Mdot
.61785 .59621 Mdot
.7436 .07772 Mdot
.1079 .22514 Mdot
.32246 .13261 Mdot
.50005 2e-05 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50157 .00066 Mdot
.50499 .00212 Mdot
.51591 .00675 Mdot
.55066 .02147 Mdot
.66011 .06765 Mdot
.97122 .19228 Mdot
.32527 .21881 Mdot
.46678 .08746 Mdot
.55882 .05688 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50717 .00304 Mdot
.52284 .00969 Mdot
.57266 .03079 Mdot
.72773 .09584 Mdot
.1192 .24194 Mdot
.34812 .14148 Mdot
.38226 .0211 Mdot
.25547 .53967 Mdot
.89008 .39221 Mdot
.67678 .4862 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.51038 .0044 Mdot
.53306 .01402 Mdot
.60496 .04444 Mdot
.82314 .13484 Mdot
.25529 .26708 Mdot
.44883 .11962 Mdot
.56693 .07299 Mdot
.78251 .13323 Mdot
.23185 .27771 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50658 .00279 Mdot
.52096 .00889 Mdot
.56668 .02826 Mdot
.70953 .08829 Mdot
.08344 .23109 Mdot
.33784 .15723 Mdot
.38896 .03159 Mdot
.28671 .55484 Mdot
.95205 .4112 Mdot
.68823 .45499 Mdot
.49884 .61754 Mdot
.4963 .61646 Mdot
.48821 .61304 Mdot
.46246 .60212 Mdot
.38091 .56763 Mdot
.13694 .46725 Mdot
.71198 .3554 Mdot
.51898 .49875 Mdot
.35437 .5163 Mdot
.00054 .39936 Mdot
.6459 .39885 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.5144 .00611 Mdot
.54585 .01944 Mdot
.64512 .06136 Mdot
.93315 .17801 Mdot
.31853 .23818 Mdot
.48696 .1041 Mdot
.63587 .09203 Mdot
.96471 .20323 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50815 .00345 Mdot
.52595 .011 Mdot
.58251 .03496 Mdot
.75738 .10807 Mdot
.17071 .25546 Mdot
.37434 .12584 Mdot
.40844 .02108 Mdot
.31267 .55884 Mdot
.99643 .42259 Mdot
.68555 .4259 Mdot
.49881 .61753 Mdot
.49621 .61643 Mdot
.48792 .61291 Mdot
.46154 .60173 Mdot
.37802 .56642 Mdot
.12892 .46408 Mdot
.70691 .35721 Mdot
.51493 .49938 Mdot
.34531 .5132 Mdot
.97851 .39134 Mdot
.64384 .4112 Mdot
.49741 .61694 Mdot
.49175 .61454 Mdot
.47373 .6069 Mdot
.41649 .58265 Mdot
.23964 .50874 Mdot
.82456 .3615 Mdot
.6225 .49315 Mdot
.58657 .59583 Mdot
.67418 .05415 Mdot
.97393 .18526 Mdot
.31262 .20932 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50502 .00213 Mdot
.51598 .00678 Mdot
.55087 .02157 Mdot
.66079 .06793 Mdot
.9729 .1929 Mdot
.32547 .2179 Mdot
.46564 .08663 Mdot
.55466 .05502 Mdot
.72408 .10471 Mdot
.12907 .2503 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00155 Mdot
.51168 .00495 Mdot
.53721 .01578 Mdot
.61804 .04996 Mdot
.86013 .14962 Mdot
.28605 .26323 Mdot
.47933 .11945 Mdot
.64168 .10034 Mdot
.98958 .21501 Mdot
.3531 .22467 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48772 .61283 Mdot
.46089 .60145 Mdot
.376 .56556 Mdot
.12335 .46189 Mdot
.70365 .35865 Mdot
.51264 .49998 Mdot
.34056 .51168 Mdot
.96736 .38739 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00123 Mdot
.50927 .00393 Mdot
.52952 .01252 Mdot
.59381 .03973 Mdot
.7908 .12175 Mdot
.21872 .26447 Mdot
.41251 .11977 Mdot
.48157 .04268 Mdot
.52304 .02563 Mdot
.59896 .04692 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53095 .01312 Mdot
.59832 .04164 Mdot
.80396 .12709 Mdot
.23474 .26624 Mdot
.42789 .11937 Mdot
.51654 .05479 Mdot
.62994 .07009 Mdot
.91731 .1776 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49304 .61508 Mdot
.47781 .60863 Mdot
.42942 .58813 Mdot
.2786 .52482 Mdot
.89289 .37965 Mdot
.65599 .47162 Mdot
.61737 .59417 Mdot
.73927 .07534 Mdot
.09936 .22255 Mdot
.49993 .618 Mdot
.49977 .61794 Mdot
.49927 .61773 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47648 .60806 Mdot
.4252 .58634 Mdot
.2658 .51952 Mdot
.86884 .3727 Mdot
.6471 .48099 Mdot
.6159 .59875 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.4872 .61261 Mdot
.45925 .60076 Mdot
.37082 .56339 Mdot
.10922 .45635 Mdot
.69635 .36286 Mdot
.50877 .5021 Mdot
.33433 .51023 Mdot
.9539 .38292 Mdot
.64166 .42505 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50514 .00218 Mdot
.51636 .00694 Mdot
.55208 .02208 Mdot
.66455 .06951 Mdot
.98215 .19629 Mdot
.32647 .2128 Mdot
.45909 .08196 Mdot
.53102 .04446 Mdot
.6492 .07304 Mdot
.9598 .19196 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51703 .00722 Mdot
.55422 .02298 Mdot
.67117 .07228 Mdot
.99816 .20209 Mdot
.32791 .2038 Mdot
.44697 .07358 Mdot
.48794 .02532 Mdot
.51085 .01416 Mdot
.55002 .02421 Mdot
.49853 .61741 Mdot
.4953 .61604 Mdot
.48503 .61169 Mdot
.45235 .59783 Mdot
.34925 .55432 Mdot
.05236 .43454 Mdot
.67834 .38688 Mdot
.51925 .51971 Mdot
.38897 .53752 Mdot
.10534 .44274 Mdot
.67498 .35206 Mdot
.49852 .6174 Mdot
.49527 .61603 Mdot
.48493 .61165 Mdot
.45203 .5977 Mdot
.34826 .5539 Mdot
.04982 .43359 Mdot
.67787 .38815 Mdot
.52054 .5208 Mdot
.39395 .5398 Mdot
.11981 .4486 Mdot
.68245 .34773 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50775 .00329 Mdot
.5247 .01047 Mdot
.57855 .03328 Mdot
.7455 .10318 Mdot
.15109 .25067 Mdot
.36259 .13071 Mdot
.39263 .01857 Mdot
.27355 .54444 Mdot
.91835 .39851 Mdot
.68032 .47093 Mdot
.49932 .61775 Mdot
.49783 .61712 Mdot
.4931 .61511 Mdot
.47801 .60871 Mdot
.43005 .58839 Mdot
.28052 .52562 Mdot
.89662 .38077 Mdot
.65712 .47001 Mdot
.61684 .59314 Mdot
.73648 .07395 Mdot
.094 .22096 Mdot
.49813 .61724 Mdot
.49404 .61551 Mdot
.48102 .60998 Mdot
.43959 .59243 Mdot
.30969 .53776 Mdot
.95766 .40047 Mdot
.66839 .43926 Mdot
.58715 .56783 Mdot
.63021 .02661 Mdot
.84751 .1343 Mdot
.26012 .25501 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50315 .00134 Mdot
.51003 .00426 Mdot
.53196 .01355 Mdot
.60151 .04298 Mdot
.8132 .13083 Mdot
.24505 .2669 Mdot
.43828 .11942 Mdot
.54123 .06363 Mdot
.70533 .10142 Mdot
.09883 .2432 Mdot
.49756 .617 Mdot
.49221 .61473 Mdot
.47519 .60752 Mdot
.42112 .58461 Mdot
.25351 .51444 Mdot
.84722 .36693 Mdot
.63649 .4878 Mdot
.60631 .59938 Mdot
.72401 .07274 Mdot
.07726 .21832 Mdot
.31912 .14948 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50295 .00125 Mdot
.50939 .00398 Mdot
.52991 .01268 Mdot
.59502 .04024 Mdot
.79434 .12319 Mdot
.22319 .26504 Mdot
.41668 .11959 Mdot
.49083 .04583 Mdot
.55125 .03734 Mdot
.6872 .08403 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48672 .6124 Mdot
.45772 .60011 Mdot
.36605 .56138 Mdot
.09636 .45135 Mdot
.69079 .36738 Mdot
.50763 .50483 Mdot
.33592 .51191 Mdot
.95943 .38535 Mdot
.64314 .42255 Mdot
.49952 .61783 Mdot
.49848 .61739 Mdot
.49515 .61598 Mdot
.48456 .61149 Mdot
.45084 .5972 Mdot
.34456 .55235 Mdot
.04045 .43008 Mdot
.67632 .39299 Mdot
.52579 .525 Mdot
.41378 .54881 Mdot
.17868 .47273 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49734 .61691 Mdot
.49152 .61444 Mdot
.473 .60659 Mdot
.41417 .58167 Mdot
.23273 .5059 Mdot
.81397 .35923 Mdot
.61492 .49501 Mdot
.57364 .59253 Mdot
.63894 .04035 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53217 .01364 Mdot
.60217 .04326 Mdot
.8151 .1316 Mdot
.24708 .26697 Mdot
.44036 .11945 Mdot
.54625 .06545 Mdot
.72056 .10773 Mdot
.12952 .25275 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52547 .0108 Mdot
.58097 .0343 Mdot
.75276 .10617 Mdot
.16325 .2537 Mdot
.3696 .12753 Mdot
.40151 .01972 Mdot
.29494 .55217 Mdot
.95909 .41047 Mdot
.68393 .44798 Mdot
.49948 .61782 Mdot
.49835 .61734 Mdot
.49476 .61581 Mdot
.4833 .61095 Mdot
.44684 .5955 Mdot
.33212 .54713 Mdot
.00975 .4188 Mdot
.67276 .40976 Mdot
.54694 .54027 Mdot
.49052 .58316 Mdot
.41989 .57438 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .0034 Mdot
.52557 .01084 Mdot
.58131 .03445 Mdot
.75377 .10659 Mdot
.1649 .25409 Mdot
.37062 .12714 Mdot
.40294 .01998 Mdot
.29853 .55351 Mdot
.9664 .41277 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50787 .00334 Mdot
.52508 .01064 Mdot
.57976 .03379 Mdot
.74912 .10467 Mdot
.15721 .25221 Mdot
.36601 .12904 Mdot
.39673 .01899 Mdot
.28319 .54786 Mdot
.93609 .40351 Mdot
.6823 .46118 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50266 .00113 Mdot
.50846 .00359 Mdot
.52695 .01143 Mdot
.58567 .03629 Mdot
.76679 .11194 Mdot
.18531 .25866 Mdot
.38455 .12314 Mdot
.42541 .02525 Mdot
.35844 .57664 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51216 .00516 Mdot
.53872 .01642 Mdot
.6228 .05196 Mdot
.87332 .15484 Mdot
.29443 .26026 Mdot
.48605 .11843 Mdot
.65676 .10551 Mdot
.02639 .22845 Mdot
.35662 .20409 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00332 Mdot
.52497 .01059 Mdot
.57942 .03365 Mdot
.74811 .10426 Mdot
.15551 .25179 Mdot
.36503 .12949 Mdot
.39552 .01884 Mdot
.28029 .54682 Mdot
.93064 .40194 Mdot
.68177 .46422 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51714 .00727 Mdot
.55457 .02313 Mdot
.67226 .07274 Mdot
.00077 .20303 Mdot
.32812 .20231 Mdot
.44493 .07219 Mdot
.48076 .02215 Mdot
.4878 .00435 Mdot
.49771 .61706 Mdot
.49269 .61493 Mdot
.47672 .60816 Mdot
.42594 .58665 Mdot
.26805 .52045 Mdot
.87296 .37385 Mdot
.64883 .47951 Mdot
.6168 .59824 Mdot
.74465 .07902 Mdot
.1111 .22648 Mdot
.32411 .13165 Mdot
.49983 .61796 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49455 .61572 Mdot
.48262 .61067 Mdot
.44469 .59459 Mdot
.32544 .54433 Mdot
.99378 .41306 Mdot
.67145 .41882 Mdot
.55936 .54876 Mdot
.53426 .60252 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48195 .61038 Mdot
.44255 .59368 Mdot
.31883 .54157 Mdot
.97836 .40761 Mdot
.67025 .42761 Mdot
.57152 .55702 Mdot
.57651 .00308 Mdot
.69188 .0713 Mdot
.03024 .20912 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51502 .00637 Mdot
.54781 .02027 Mdot
.65124 .06392 Mdot
.9489 .18396 Mdot
.3219 .23053 Mdot
.48011 .09778 Mdot
.60858 .0794 Mdot
.88757 .17243 Mdot
.32152 .2682 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50576 .00244 Mdot
.51835 .00778 Mdot
.5584 .02475 Mdot
.68409 .07768 Mdot
.02834 .21276 Mdot
.3303 .18662 Mdot
.42328 .05747 Mdot
.40559 .6071 Mdot
.25445 .52462 Mdot
.86467 .37714 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48669 .61239 Mdot
.45761 .60006 Mdot
.36568 .56122 Mdot
.09536 .45097 Mdot
.6904 .36776 Mdot
.50764 .50508 Mdot
.33633 .51216 Mdot
.96056 .38579 Mdot
.64334 .42199 Mdot
.49842 .61736 Mdot
.49495 .61589 Mdot
.48391 .61121 Mdot
.44879 .59632 Mdot
.33815 .54966 Mdot
.02448 .42418 Mdot
.67423 .40157 Mdot
.53617 .53271 Mdot
.45189 .56595 Mdot
.29654 .52202 Mdot
.9126 .38074 Mdot
.49953 .61784 Mdot
.49851 .6174 Mdot
.49525 .61602 Mdot
.48486 .61162 Mdot
.45181 .59761 Mdot
.34757 .55361 Mdot
.04807 .43293 Mdot
.67756 .38905 Mdot
.52147 .52157 Mdot
.3975 .54141 Mdot
.13017 .45282 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51067 .00452 Mdot
.53397 .0144 Mdot
.60784 .04565 Mdot
.83137 .13815 Mdot
.26311 .26683 Mdot
.45692 .11978 Mdot
.58691 .08034 Mdot
.84088 .15696 Mdot
.2957 .2811 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50332 .00141 Mdot
.51058 .00449 Mdot
.5337 .01429 Mdot
.60699 .0453 Mdot
.82895 .13718 Mdot
.26087 .26694 Mdot
.45461 .11974 Mdot
.58118 .07823 Mdot
.82431 .15026 Mdot
.49823 .61728 Mdot
.49437 .61565 Mdot
.48205 .61042 Mdot
.44288 .59382 Mdot
.31985 .542 Mdot
.98072 .40844 Mdot
.67044 .42627 Mdot
.56967 .55576 Mdot
.57012 .00027 Mdot
.67236 .06319 Mdot
.9855 .19353 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51253 .00531 Mdot
.5399 .01692 Mdot
.6265 .05352 Mdot
.88348 .15883 Mdot
.30004 .25745 Mdot
.48958 .11714 Mdot
.6635 .10749 Mdot
.04175 .23377 Mdot
.35809 .19551 Mdot
.49973 .61792 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.49131 .61435 Mdot
.47232 .6063 Mdot
.41202 .58077 Mdot
.22636 .50329 Mdot
.8046 .35737 Mdot
.60766 .49632 Mdot
.56018 .58869 Mdot
.60082 .02512 Mdot
.49818 .61726 Mdot
.49419 .61557 Mdot
.4815 .61019 Mdot
.44112 .59308 Mdot
.31442 .53973 Mdot
.96827 .4041 Mdot
.6694 .43332 Mdot
.57931 .56235 Mdot
.60331 .01484 Mdot
.77164 .10403 Mdot
.17649 .25021 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50357 .00151 Mdot
.51138 .00483 Mdot
.53625 .01537 Mdot
.61502 .04868 Mdot
.8517 .14627 Mdot
.28 .26471 Mdot
.47381 .11978 Mdot
.6285 .0956 Mdot
.95566 .2022 Mdot
.34848 .24277 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47576 .60776 Mdot
.42292 .58538 Mdot
.25894 .51668 Mdot
.85659 .36937 Mdot
.64141 .48504 Mdot
.61152 .59956 Mdot
.73554 .07665 Mdot
.09732 .22359 Mdot
.32204 .13889 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49847 .61739 Mdot
.49513 .61597 Mdot
.48448 .61145 Mdot
.4506 .59709 Mdot
.34379 .55202 Mdot
.03852 .42937 Mdot
.67603 .394 Mdot
.52695 .5259 Mdot
.41811 .55076 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00178 Mdot
.51341 .00569 Mdot
.5427 .0181 Mdot
.63526 .05721 Mdot
.90716 .16804 Mdot
.31056 .24931 Mdot
.49229 .11232 Mdot
.66246 .10517 Mdot
.03616 .23096 Mdot
.35608 .19772 Mdot
.4977 .61706 Mdot
.49268 .61493 Mdot
.47669 .60815 Mdot
.42585 .58662 Mdot
.26778 .52034 Mdot
.87247 .37371 Mdot
.64863 .47969 Mdot
.6167 .59831 Mdot
.74457 .07902 Mdot
.11102 .22648 Mdot
.32413 .13171 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42794 .5875 Mdot
.2741 .52295 Mdot
.88425 .3771 Mdot
.65312 .47519 Mdot
.61785 .59623 Mdot
.74364 .07774 Mdot
.10797 .22517 Mdot
.32248 .13258 Mdot
.5007 .00029 Mdot
.50221 .00094 Mdot
.50706 .00299 Mdot
.52248 .00953 Mdot
.57152 .03031 Mdot
.72425 .0944 Mdot
.1126 .24001 Mdot
.34579 .14412 Mdot
.3822 .0225 Mdot
.25761 .54103 Mdot
.89455 .39365 Mdot
.67835 .48441 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47459 .60726 Mdot
.41919 .5838 Mdot
.24772 .51206 Mdot
.83754 .36453 Mdot
.63088 .49031 Mdot
.59916 .59843 Mdot
.70673 .06648 Mdot
.04426 .20861 Mdot
.31626 .1681 Mdot
.49787 .61713 Mdot
.49321 .61516 Mdot
.47838 .60887 Mdot
.43121 .58888 Mdot
.28404 .52708 Mdot
.90358 .38289 Mdot
.65906 .46692 Mdot
.61536 .59102 Mdot
.72993 .07081 Mdot
.08134 .21718 Mdot
.31598 .14502 Mdot
.49987 .61798 Mdot
.49957 .61785 Mdot
.49863 .61745 Mdot
.49564 .61618 Mdot
.48611 .61214 Mdot
.45576 .59928 Mdot
.3599 .55879 Mdot
.08 .44505 Mdot
.68509 .37397 Mdot
.50933 .50941 Mdot
.34756 .51805 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00254 Mdot
.5191 .0081 Mdot
.56079 .02576 Mdot
.69145 .08076 Mdot
.04488 .21843 Mdot
.33188 .17737 Mdot
.41104 .04892 Mdot
.36359 .58871 Mdot
.13569 .47718 Mdot
.72802 .36609 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00126 Mdot
.50944 .004 Mdot
.53005 .01274 Mdot
.59548 .04044 Mdot
.7957 .12374 Mdot
.22488 .26525 Mdot
.41829 .11953 Mdot
.49445 .04707 Mdot
.56229 .04193 Mdot
.50071 .0003 Mdot
.50228 .00096 Mdot
.50725 .00307 Mdot
.52309 .00979 Mdot
.57345 .03112 Mdot
.73012 .09683 Mdot
.12366 .24322 Mdot
.34982 .13977 Mdot
.38268 .02031 Mdot
.25506 .53916 Mdot
.88884 .39169 Mdot
.67613 .48657 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50323 .00137 Mdot
.51028 .00436 Mdot
.53275 .01389 Mdot
.60401 .04404 Mdot
.82041 .13374 Mdot
.25256 .26708 Mdot
.44601 .11956 Mdot
.56002 .07046 Mdot
.76193 .12479 Mdot
.20191 .27192 Mdot
.49745 .61695 Mdot
.49187 .61458 Mdot
.47409 .60705 Mdot
.41762 .58313 Mdot
.24302 .51012 Mdot
.82991 .36272 Mdot
.62607 .49206 Mdot
.59218 .59709 Mdot
.68896 .05981 Mdot
.00712 .19664 Mdot
.31461 .19004 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48961 .61363 Mdot
.4669 .604 Mdot
.39488 .57353 Mdot
.17641 .48301 Mdot
.74428 .35096 Mdot
.55072 .49841 Mdot
.43196 .54464 Mdot
.21422 .48346 Mdot
.76375 .33963 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51251 .00531 Mdot
.53985 .0169 Mdot
.62635 .05346 Mdot
.88308 .15867 Mdot
.29984 .25757 Mdot
.48947 .1172 Mdot
.66332 .10744 Mdot
.04135 .23364 Mdot
.35806 .19573 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48837 .6131 Mdot
.46295 .60232 Mdot
.38245 .56828 Mdot
.14123 .46895 Mdot
.71489 .35454 Mdot
.5215 .49851 Mdot
.36027 .51838 Mdot
.01534 .40486 Mdot
.64744 .39066 Mdot
.49902 .61762 Mdot
.49689 .61671 Mdot
.49009 .61383 Mdot
.46843 .60465 Mdot
.39972 .57557 Mdot
.19034 .48863 Mdot
.75881 .35133 Mdot
.56564 .49865 Mdot
.46818 .5578 Mdot
.32329 .52849 Mdot
.96454 .39632 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50407 .00172 Mdot
.51295 .00549 Mdot
.54125 .01749 Mdot
.63074 .0553 Mdot
.895 .16332 Mdot
.30559 .25376 Mdot
.49185 .11512 Mdot
.6659 .10757 Mdot
.04612 .23499 Mdot
.35812 .19283 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50379 .00161 Mdot
.51209 .00512 Mdot
.53849 .01632 Mdot
.62207 .05165 Mdot
.87131 .15404 Mdot
.29323 .26076 Mdot
.48517 .11863 Mdot
.65491 .1049 Mdot
.02203 .22689 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50798 .00338 Mdot
.52543 .01078 Mdot
.58085 .03425 Mdot
.75238 .10602 Mdot
.16263 .25355 Mdot
.36922 .12768 Mdot
.40098 .01963 Mdot
.29362 .55168 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50612 .00259 Mdot
.51948 .00826 Mdot
.562 .02628 Mdot
.69518 .08231 Mdot
.05307 .22119 Mdot
.33282 .1729 Mdot
.40545 .04488 Mdot
.34444 .58033 Mdot
.08551 .45801 Mdot
.7044 .38249 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51525 .00647 Mdot
.54856 .02059 Mdot
.65358 .06491 Mdot
.95485 .18619 Mdot
.32294 .22749 Mdot
.47693 .09517 Mdot
.59644 .07386 Mdot
.85192 .1579 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50599 .00254 Mdot
.51908 .00809 Mdot
.56072 .02573 Mdot
.69124 .08067 Mdot
.04441 .21827 Mdot
.33182 .17763 Mdot
.41137 .04916 Mdot
.36474 .58922 Mdot
.13878 .47838 Mdot
.73005 .36542 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.5078 .00331 Mdot
.52485 .01054 Mdot
.57903 .03348 Mdot
.74693 .10377 Mdot
.15352 .25129 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49434 .61564 Mdot
.48198 .61039 Mdot
.44264 .59372 Mdot
.31911 .54169 Mdot
.97901 .40784 Mdot
.6703 .42724 Mdot
.57101 .55667 Mdot
.57474 .0023 Mdot
.6865 .06907 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51805 .00765 Mdot
.55744 .02435 Mdot
.68113 .07645 Mdot
.02156 .21039 Mdot
.32974 .19047 Mdot
.42854 .06106 Mdot
.42372 .61505 Mdot
.30881 .54702 Mdot
.97129 .40943 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51572 .00667 Mdot
.55006 .02122 Mdot
.65826 .06687 Mdot
.96662 .19058 Mdot
.32468 .22129 Mdot
.46982 .0897 Mdot
.56994 .06188 Mdot
.77164 .12465 Mdot
.20986 .27084 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48746 .61272 Mdot
.46006 .6011 Mdot
.37337 .56446 Mdot
.11615 .45907 Mdot
.69977 .36069 Mdot
.51032 .50095 Mdot
.33634 .51051 Mdot
.95791 .38415 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49853 .61741 Mdot
.49531 .61604 Mdot
.48505 .6117 Mdot
.45241 .59786 Mdot
.34944 .5544 Mdot
.05284 .43473 Mdot
.67843 .38663 Mdot
.51901 .51951 Mdot
.38805 .53709 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50527 .00224 Mdot
.5168 .00712 Mdot
.55347 .02267 Mdot
.66885 .07131 Mdot
.9926 .20009 Mdot
.32744 .20695 Mdot
.45127 .07653 Mdot
.50313 .03205 Mdot
.55968 .03495 Mdot
.70367 .08899 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51068 .00453 Mdot
.53402 .01442 Mdot
.608 .04572 Mdot
.83183 .13834 Mdot
.26353 .2668 Mdot
.45736 .11979 Mdot
.58798 .08073 Mdot
.84395 .1582 Mdot
.29826 .28077 Mdot
.50075 .00032 Mdot
.50237 .00101 Mdot
.50756 .00321 Mdot
.5241 .01022 Mdot
.57664 .03247 Mdot
.73974 .1008 Mdot
.14108 .24804 Mdot
.35745 .13372 Mdot
.38745 .01854 Mdot
.26234 .54071 Mdot
.89922 .39361 Mdot
.67737 .48092 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.51942 .00823 Mdot
.56179 .02619 Mdot
.69453 .08204 Mdot
.05165 .22071 Mdot
.33265 .17367 Mdot
.40639 .04557 Mdot
.34767 .58174 Mdot
.09377 .46112 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .61259 Mdot
.45914 .60071 Mdot
.37048 .56324 Mdot
.1083 .456 Mdot
.69592 .36317 Mdot
.50861 .50227 Mdot
.33422 .51025 Mdot
.95374 .38289 Mdot
.64168 .42517 Mdot
.50044 .00019 Mdot
.5014 .0006 Mdot
.50447 .0019 Mdot
.51425 .00604 Mdot
.54539 .01924 Mdot
.64368 .06075 Mdot
.92939 .17658 Mdot
.31757 .23991 Mdot
.48822 .10547 Mdot
.64122 .09456 Mdot
.97932 .20896 Mdot
.34835 .22808 Mdot
.49873 .6175 Mdot
.49597 .61632 Mdot
.48715 .61258 Mdot
.45907 .60068 Mdot
.37029 .56316 Mdot
.10777 .45579 Mdot
.69567 .36334 Mdot
.50853 .50237 Mdot
.33417 .51027 Mdot
.95369 .38289 Mdot
.6417 .42521 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00227 Mdot
.51702 .00722 Mdot
.55417 .02296 Mdot
.67102 .07222 Mdot
.99781 .20197 Mdot
.32788 .204 Mdot
.44724 .07377 Mdot
.4889 .02575 Mdot
.51393 .01547 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50761 .00323 Mdot
.52423 .01027 Mdot
.57705 .03265 Mdot
.74098 .10132 Mdot
.14326 .24862 Mdot
.35852 .13303 Mdot
.38842 .01848 Mdot
.26432 .54134 Mdot
.90245 .39439 Mdot
.67792 .47927 Mdot
.49754 .61699 Mdot
.49218 .61472 Mdot
.47508 .60747 Mdot
.42074 .58445 Mdot
.25237 .51398 Mdot
.84529 .36645 Mdot
.63542 .48832 Mdot
.60504 .59926 Mdot
.72103 .07168 Mdot
.0718 .21679 Mdot
.31849 .15246 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52545 .01079 Mdot
.58091 .03428 Mdot
.75259 .1061 Mdot
.16296 .25363 Mdot
.36942 .1276 Mdot
.40127 .01968 Mdot
.29432 .55194 Mdot
.95785 .41008 Mdot
.68386 .4487 Mdot
.49888 .61756 Mdot
.49642 .61651 Mdot
.48859 .61319 Mdot
.46365 .60262 Mdot
.38465 .56921 Mdot
.14738 .47139 Mdot
.71931 .35347 Mdot
.52554 .49828 Mdot
.36993 .52186 Mdot
.04022 .41426 Mdot
.65082 .37737 Mdot
.49848 .61739 Mdot
.49517 .61599 Mdot
.48461 .61151 Mdot
.451 .59726 Mdot
.34504 .55255 Mdot
.04165 .43053 Mdot
.6765 .39236 Mdot
.52508 .52445 Mdot
.41111 .5476 Mdot
.17063 .46941 Mdot
.7205 .33983 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47916 .6092 Mdot
.43368 .58993 Mdot
.29158 .53021 Mdot
.91884 .38767 Mdot
.66264 .45969 Mdot
.61009 .58556 Mdot
.70982 .06164 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .613 Mdot
.46223 .60202 Mdot
.38019 .56733 Mdot
.13494 .46646 Mdot
.71067 .35582 Mdot
.51789 .49888 Mdot
.35187 .51543 Mdot
.99439 .3971 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48652 .61232 Mdot
.45709 .59984 Mdot
.36406 .56054 Mdot
.09103 .44929 Mdot
.68878 .36943 Mdot
.50781 .50619 Mdot
.33856 .51343 Mdot
.9666 .38815 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.50649 .00275 Mdot
.52067 .00877 Mdot
.56578 .02788 Mdot
.70678 .08714 Mdot
.07775 .22928 Mdot
.33668 .16003 Mdot
.39143 .03383 Mdot
.29565 .55884 Mdot
.97089 .41732 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50554 .00235 Mdot
.51763 .00748 Mdot
.55613 .02379 Mdot
.67709 .07476 Mdot
.01217 .20709 Mdot
.32901 .19582 Mdot
.43594 .06608 Mdot
.44934 .00828 Mdot
.38804 .58014 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00304 Mdot
.52287 .0097 Mdot
.57274 .03082 Mdot
.72796 .09593 Mdot
.11963 .24207 Mdot
.34828 .14131 Mdot
.38229 .02102 Mdot
.25539 .53961 Mdot
.88989 .39215 Mdot
.6767 .48627 Mdot
.49751 .61698 Mdot
.49208 .61467 Mdot
.47476 .60733 Mdot
.41975 .58403 Mdot
.2494 .51275 Mdot
.84032 .36521 Mdot
.63255 .48963 Mdot
.6014 .59878 Mdot
.71228 .06852 Mdot
.05521 .21194 Mdot
.31698 .16178 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.51511 .00641 Mdot
.54811 .02039 Mdot
.65217 .06432 Mdot
.95128 .18486 Mdot
.32233 .22932 Mdot
.47888 .09675 Mdot
.60384 .07723 Mdot
.87373 .1668 Mdot
.31378 .27196 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51648 .00699 Mdot
.55246 .02224 Mdot
.6657 .06999 Mdot
.98496 .19732 Mdot
.32675 .21124 Mdot
.45703 .08052 Mdot
.52362 .04116 Mdot
.62552 .06298 Mdot
.89678 .16765 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51428 .00606 Mdot
.54547 .01928 Mdot
.64394 .06086 Mdot
.93008 .17684 Mdot
.31775 .2396 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50924 .00392 Mdot
.52942 .01248 Mdot
.5935 .0396 Mdot
.78988 .12137 Mdot
.21755 .26431 Mdot
.41142 .11982 Mdot
.47919 .04188 Mdot
.51582 .02264 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00332 Mdot
.52498 .01059 Mdot
.57942 .03365 Mdot
.74813 .10426 Mdot
.15554 .2518 Mdot
.36505 .12948 Mdot
.39554 .01884 Mdot
.28034 .54684 Mdot
.93073 .40197 Mdot
.68178 .46417 Mdot
.49794 .61716 Mdot
.49345 .61526 Mdot
.47913 .60918 Mdot
.4336 .58989 Mdot
.29133 .53011 Mdot
.91833 .38751 Mdot
.66253 .45994 Mdot
.61031 .58576 Mdot
.71062 .062 Mdot
.04239 .20505 Mdot
.31133 .16621 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50271 .00115 Mdot
.50862 .00366 Mdot
.52747 .01165 Mdot
.58731 .03699 Mdot
.77166 .11393 Mdot
.19253 .26011 Mdot
.39006 .12208 Mdot
.4355 .02808 Mdot
.38681 .58794 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00312 Mdot
.52347 .00995 Mdot
.57465 .03163 Mdot
.73375 .09833 Mdot
.13033 .2451 Mdot
.35255 .13734 Mdot
.3839 .01937 Mdot
.25613 .53907 Mdot
.88981 .39163 Mdot
.67588 .48582 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00148 Mdot
.51114 .00473 Mdot
.53549 .01505 Mdot
.61264 .04768 Mdot
.845 .1436 Mdot
.27481 .26564 Mdot
.46878 .11988 Mdot
.61621 .09112 Mdot
.92287 .18953 Mdot
.34075 .25826 Mdot
.49917 .61768 Mdot
.49735 .61691 Mdot
.49154 .61445 Mdot
.47306 .60661 Mdot
.41436 .58175 Mdot
.2333 .50614 Mdot
.81483 .3594 Mdot
.61555 .49488 Mdot
.57477 .59283 Mdot
.64208 .04159 Mdot
.89529 .1565 Mdot
.49891 .61757 Mdot
.49651 .61656 Mdot
.48889 .61332 Mdot
.46461 .60303 Mdot
.3877 .5705 Mdot
.15596 .47481 Mdot
.72596 .35228 Mdot
.53198 .49815 Mdot
.38566 .5276 Mdot
.08221 .43049 Mdot
.66085 .35762 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49146 .61441 Mdot
.47281 .6065 Mdot
.41356 .58142 Mdot
.23094 .50517 Mdot
.81129 .35868 Mdot
.61289 .49542 Mdot
.56999 .59152 Mdot
.62871 .03629 Mdot
.86013 .14302 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .00181 Mdot
.51358 .00576 Mdot
.54325 .01834 Mdot
.637 .05794 Mdot
.91178 .16983 Mdot
.31222 .24749 Mdot
.49195 .11107 Mdot
.65959 .10361 Mdot
.02848 .22798 Mdot
.35487 .20172 Mdot
.499 .61761 Mdot
.4968 .61668 Mdot
.4898 .61371 Mdot
.46752 .60426 Mdot
.39686 .57436 Mdot
.18208 .4853 Mdot
.74999 .35098 Mdot
.55662 .49853 Mdot
.44641 .54992 Mdot
.25732 .50117 Mdot
.82975 .35378 Mdot
.49903 .61762 Mdot
.49689 .61672 Mdot
.49011 .61384 Mdot
.46849 .60467 Mdot
.39991 .57565 Mdot
.1909 .48886 Mdot
.75943 .35137 Mdot
.56627 .49866 Mdot
.46967 .55833 Mdot
.32785 .53039 Mdot
.9753 .40014 Mdot
.49766 .61704 Mdot
.49253 .61487 Mdot
.47621 .60795 Mdot
.42435 .58598 Mdot
.26322 .51846 Mdot
.86419 .37142 Mdot
.64504 .48259 Mdot
.61455 .59919 Mdot
.74143 .07842 Mdot
.10669 .22575 Mdot
.32364 .13408 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.50231 .00098 Mdot
.50735 .00312 Mdot
.5234 .00992 Mdot
.57444 .03154 Mdot
.73312 .09807 Mdot
.12918 .24478 Mdot
.35206 .13775 Mdot
.38363 .01951 Mdot
.2558 .53903 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00247 Mdot
.51852 .00785 Mdot
.55896 .02499 Mdot
.68581 .0784 Mdot
.03225 .21411 Mdot
.33064 .18442 Mdot
.4203 .05541 Mdot
.39534 .60261 Mdot
.22447 .51243 Mdot
.81794 .36678 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.5205 .00869 Mdot
.56522 .02764 Mdot
.70505 .08642 Mdot
.07415 .22812 Mdot
.33601 .16184 Mdot
.39315 .03532 Mdot
.3018 .56157 Mdot
.98424 .42177 Mdot
.69028 .43636 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50223 .00095 Mdot
.50711 .00301 Mdot
.52264 .0096 Mdot
.57203 .03052 Mdot
.72582 .09504 Mdot
.11559 .24089 Mdot
.34682 .14291 Mdot
.38215 .02183 Mdot
.25641 .54033 Mdot
.89214 .3929 Mdot
.5007 .00029 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.52248 .00953 Mdot
.57152 .03031 Mdot
.72426 .0944 Mdot
.11261 .24002 Mdot
.3458 .14411 Mdot
.3822 .0225 Mdot
.2576 .54103 Mdot
.89454 .39365 Mdot
.67835 .48442 Mdot
.49865 .61746 Mdot
.49571 .61621 Mdot
.48632 .61223 Mdot
.45644 .59957 Mdot
.36204 .55969 Mdot
.08567 .44722 Mdot
.6869 .37159 Mdot
.50836 .50769 Mdot
.34235 .51544 Mdot
.97669 .39204 Mdot
.64587 .41357 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50763 .00323 Mdot
.52429 .0103 Mdot
.57726 .03273 Mdot
.7416 .10157 Mdot
.14435 .24891 Mdot
.35906 .1327 Mdot
.38893 .01846 Mdot
.2654 .54169 Mdot
.90425 .39483 Mdot
.67822 .47834 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.5181 .00768 Mdot
.55761 .02442 Mdot
.68166 .07667 Mdot
.02278 .21082 Mdot
.32984 .18978 Mdot
.42759 .06041 Mdot
.42044 .61361 Mdot
.29884 .54289 Mdot
.4981 .61723 Mdot
.49394 .61547 Mdot
.48071 .60985 Mdot
.4386 .59201 Mdot
.30667 .5365 Mdot
.95098 .39821 Mdot
.66766 .44293 Mdot
.59183 .57117 Mdot
.64624 .03363 Mdot
.89042 .15091 Mdot
.28629 .24466 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49651 .61655 Mdot
.48888 .61332 Mdot
.4646 .60302 Mdot
.38765 .57048 Mdot
.15582 .47476 Mdot
.72585 .3523 Mdot
.53188 .49815 Mdot
.38539 .5275 Mdot
.08148 .4302 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47451 .60723 Mdot
.41895 .5837 Mdot
.24701 .51177 Mdot
.83637 .36425 Mdot
.63017 .49059 Mdot
.59817 .59826 Mdot
.70426 .06557 Mdot
.49765 .61704 Mdot
.4925 .61485 Mdot
.47612 .60791 Mdot
.42404 .58585 Mdot
.2623 .51807 Mdot
.86255 .37097 Mdot
.64428 .48314 Mdot
.61398 .59931 Mdot
.7404 .07813 Mdot
.10513 .22541 Mdot
.32338 .13489 Mdot
.49827 .6173 Mdot
.49447 .61569 Mdot
.48239 .61057 Mdot
.44396 .59428 Mdot
.3232 .5434 Mdot
.98851 .41118 Mdot
.67104 .42183 Mdot
.56353 .55159 Mdot
.5488 .60893 Mdot
.60611 .03542 Mdot
.81107 .12667 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49071 .6141 Mdot
.47042 .60549 Mdot
.40602 .57823 Mdot
.20869 .49608 Mdot
.78063 .35348 Mdot
.58689 .4983 Mdot
.51711 .57491 Mdot
.47294 .59073 Mdot
.38836 .56577 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00286 Mdot
.52145 .00909 Mdot
.56824 .02892 Mdot
.71428 .09026 Mdot
.09307 .2341 Mdot
.34007 .15266 Mdot
.38557 .02812 Mdot
.27384 .54898 Mdot
.92604 .40309 Mdot
.68523 .46921 Mdot
.49796 .61717 Mdot
.49351 .61528 Mdot
.47931 .60926 Mdot
.43417 .59013 Mdot
.29307 .53083 Mdot
.92193 .38866 Mdot
.66325 .45816 Mdot
.60872 .58433 Mdot
.70487 .05943 Mdot
.03022 .20108 Mdot
.31051 .17323 Mdot
.49979 .61795 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47887 .60907 Mdot
.43276 .58954 Mdot
.28877 .52904 Mdot
.9131 .38586 Mdot
.6614 .46247 Mdot
.61238 .58774 Mdot
.71826 .06544 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50811 .00344 Mdot
.52584 .01095 Mdot
.58214 .0348 Mdot
.75627 .10762 Mdot
.16894 .25505 Mdot
.37318 .12623 Mdot
.40669 .02071 Mdot
.30813 .55712 Mdot
.98658 .4193 Mdot
.68514 .43173 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51877 .00796 Mdot
.55975 .02532 Mdot
.68826 .07942 Mdot
.03776 .216 Mdot
.33115 .18133 Mdot
.41618 .05255 Mdot
.38122 .59642 Mdot
.18416 .49625 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51451 .00615 Mdot
.54621 .01959 Mdot
.64625 .06183 Mdot
.93608 .17912 Mdot
.31923 .2368 Mdot
.48588 .103 Mdot
.63137 .08992 Mdot
.9523 .19835 Mdot
.34371 .2419 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00467 Mdot
.53505 .01486 Mdot
.61124 .04709 Mdot
.84104 .14202 Mdot
.27156 .26608 Mdot
.46554 .11989 Mdot
.60825 .08819 Mdot
.90109 .18098 Mdot
.33293 .26689 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50937 .00397 Mdot
.52984 .01265 Mdot
.59482 .04016 Mdot
.79376 .12295 Mdot
.22246 .26495 Mdot
.416 .11961 Mdot
.4893 .0453 Mdot
.54657 .03539 Mdot
.67269 .07795 Mdot
.49893 .61758 Mdot
.49658 .61659 Mdot
.48912 .61342 Mdot
.46534 .60334 Mdot
.38998 .57146 Mdot
.16242 .47739 Mdot
.73137 .35163 Mdot
.53742 .49817 Mdot
.39908 .53254 Mdot
.11932 .44513 Mdot
.67687 .34459 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50365 .00155 Mdot
.51164 .00493 Mdot
.53706 .01571 Mdot
.61756 .04975 Mdot
.85879 .14909 Mdot
.28512 .26349 Mdot
.47851 .11952 Mdot
.63977 .09966 Mdot
.98474 .21321 Mdot
.35257 .22733 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48203 .61041 Mdot
.44281 .59379 Mdot
.31963 .5419 Mdot
.98019 .40825 Mdot
.6704 .42657 Mdot
.57008 .55604 Mdot
.57153 .0009 Mdot
.67671 .065 Mdot
.99575 .19718 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.5055 .00233 Mdot
.51751 .00743 Mdot
.55574 .02363 Mdot
.67588 .07425 Mdot
.00933 .20608 Mdot
.32879 .19744 Mdot
.43818 .06761 Mdot
.45716 .01173 Mdot
.41266 .59053 Mdot
.24363 .51357 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48499 .61167 Mdot
.4522 .59777 Mdot
.34879 .55412 Mdot
.05119 .4341 Mdot
.67812 .38747 Mdot
.51984 .52021 Mdot
.39125 .53856 Mdot
.11195 .44541 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47786 .60865 Mdot
.42957 .58819 Mdot
.27905 .52501 Mdot
.89376 .37991 Mdot
.65626 .47125 Mdot
.61726 .59393 Mdot
.73866 .07503 Mdot
.0982 .2222 Mdot
.3196 .13684 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.48621 .61219 Mdot
.4561 .59942 Mdot
.36097 .55924 Mdot
.08283 .44613 Mdot
.68597 .37277 Mdot
.5088 .50853 Mdot
.34481 .51668 Mdot
.98321 .39455 Mdot
.64675 .41009 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.51441 .00611 Mdot
.54588 .01945 Mdot
.64523 .0614 Mdot
.93342 .17811 Mdot
.31859 .23805 Mdot
.48687 .104 Mdot
.63546 .09184 Mdot
.96359 .20279 Mdot
.49977 .61794 Mdot
.49927 .61772 Mdot
.49766 .61704 Mdot
.49255 .61487 Mdot
.47626 .60797 Mdot
.42449 .58604 Mdot
.26365 .51863 Mdot
.86495 .37163 Mdot
.64538 .48233 Mdot
.61479 .59913 Mdot
.74185 .07853 Mdot
.49989 .61799 Mdot
.49964 .61788 Mdot
.49885 .61754 Mdot
.49632 .61647 Mdot
.48828 .61306 Mdot
.46268 .60221 Mdot
.38161 .56793 Mdot
.13888 .46802 Mdot
.71328 .355 Mdot
.52009 .49863 Mdot
.35695 .51721 Mdot
.49792 .61715 Mdot
.49336 .61522 Mdot
.47884 .60906 Mdot
.43268 .5895 Mdot
.28852 .52894 Mdot
.91258 .38569 Mdot
.66128 .46272 Mdot
.61256 .58793 Mdot
.71897 .06576 Mdot
.05958 .21051 Mdot
.31289 .15656 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48134 .61012 Mdot
.44062 .59287 Mdot
.31289 .53909 Mdot
.96483 .40292 Mdot
.66909 .43526 Mdot
.5819 .56415 Mdot
.6122 .01873 Mdot
.79721 .11434 Mdot
.21053 .25544 Mdot
.49739 .61693 Mdot
.49168 .61451 Mdot
.47351 .6068 Mdot
.41578 .58236 Mdot
.23754 .50787 Mdot
.82129 .36078 Mdot
.62023 .49377 Mdot
.58283 .59492 Mdot
.66415 .05026 Mdot
.9503 .17685 Mdot
.3098 .22218 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48746 .61272 Mdot
.46006 .6011 Mdot
.37338 .56446 Mdot
.11617 .45907 Mdot
.69978 .36069 Mdot
.51032 .50095 Mdot
.33635 .51051 Mdot
.95792 .38415 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50725 .00308 Mdot
.52311 .0098 Mdot
.57351 .03115 Mdot
.7303 .0969 Mdot
.12399 .24331 Mdot
.34995 .13965 Mdot
.38272 .02026 Mdot
.25507 .53914 Mdot
.88881 .39167 Mdot
.67609 .48657 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50543 .0023 Mdot
.5173 .00733 Mdot
.55506 .02334 Mdot
.67376 .07337 Mdot
.00434 .20431 Mdot
.3284 .20028 Mdot
.44213 .07028 Mdot
.47094 .01781 Mdot
.4564 .60905 Mdot
.37729 .56914 Mdot
.4979 .61715 Mdot
.49332 .6152 Mdot
.47872 .60901 Mdot
.43231 .58935 Mdot
.28738 .52847 Mdot
.91029 .38497 Mdot
.66074 .46381 Mdot
.61337 .58875 Mdot
.72202 .06715 Mdot
.06572 .21242 Mdot
.31362 .15321 Mdot
.49902 .61762 Mdot
.49689 .61671 Mdot
.49009 .61383 Mdot
.46842 .60465 Mdot
.39971 .57556 Mdot
.19031 .48862 Mdot
.75878 .35133 Mdot
.56561 .49865 Mdot
.4681 .55777 Mdot
.32304 .52839 Mdot
.96397 .39611 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49853 .61741 Mdot
.49531 .61604 Mdot
.48505 .61169 Mdot
.45239 .59785 Mdot
.34938 .55437 Mdot
.0527 .43467 Mdot
.6784 .38671 Mdot
.51908 .51957 Mdot
.38832 .53722 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51812 .00769 Mdot
.55769 .02445 Mdot
.6819 .07677 Mdot
.02332 .21101 Mdot
.32989 .18947 Mdot
.42717 .06012 Mdot
.41897 .61297 Mdot
.2944 .54105 Mdot
.94034 .39921 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.4984 .61735 Mdot
.4949 .61587 Mdot
.48375 .61114 Mdot
.44826 .5961 Mdot
.33651 .54897 Mdot
.02045 .42269 Mdot
.67379 .40379 Mdot
.53903 .53474 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50714 .00303 Mdot
.52275 .00965 Mdot
.57238 .03067 Mdot
.72687 .09548 Mdot
.11758 .24147 Mdot
.34753 .14212 Mdot
.38219 .02142 Mdot
.25582 .53994 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51419 .00602 Mdot
.54519 .01916 Mdot
.64305 .06048 Mdot
.92775 .17595 Mdot
.31714 .24066 Mdot
.48872 .10604 Mdot
.6434 .0956 Mdot
.98525 .21127 Mdot
.34919 .22493 Mdot
.49824 .61729 Mdot
.49438 .61565 Mdot
.48209 .61044 Mdot
.44299 .59387 Mdot
.3202 .54214 Mdot
.98152 .40872 Mdot
.6705 .42581 Mdot
.56904 .55533 Mdot
.56793 .61735 Mdot
.66566 .0604 Mdot
.96937 .18771 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48371 .61113 Mdot
.44815 .59605 Mdot
.33618 .54883 Mdot
.01962 .42239 Mdot
.67371 .40425 Mdot
.53962 .53516 Mdot
.46436 .57152 Mdot
.33609 .53876 Mdot
.00316 .41227 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51727 .00733 Mdot
.55499 .02331 Mdot
.67355 .07328 Mdot
.00383 .20412 Mdot
.32836 .20058 Mdot
.44253 .07056 Mdot
.47235 .01843 Mdot
.4609 .61096 Mdot
.39138 .57507 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.5175 .00742 Mdot
.5557 .02361 Mdot
.67577 .0742 Mdot
.00906 .20599 Mdot
.32877 .19759 Mdot
.4384 .06775 Mdot
.45791 .01206 Mdot
.41501 .59152 Mdot
.49914 .61767 Mdot
.49725 .61687 Mdot
.49124 .61432 Mdot
.47211 .60621 Mdot
.41135 .58048 Mdot
.22439 .50249 Mdot
.80178 .35685 Mdot
.60538 .49665 Mdot
.55575 .58736 Mdot
.58805 .01996 Mdot
.7458 .09749 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.51509 .0064 Mdot
.54805 .02037 Mdot
.65199 .06424 Mdot
.95082 .18468 Mdot
.32225 .22956 Mdot
.47912 .09695 Mdot
.60477 .07765 Mdot
.87646 .16791 Mdot
.3154 .27128 Mdot
.50039 .00017 Mdot
.50126 .00053 Mdot
.504 .0017 Mdot
.51275 .00541 Mdot
.5406 .01721 Mdot
.62868 .05444 Mdot
.88944 .16116 Mdot
.30302 .2556 Mdot
.49098 .11617 Mdot
.66544 .10782 Mdot
.04571 .23502 Mdot
.35836 .19323 Mdot
.49927 .61773 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47646 .60805 Mdot
.42513 .58631 Mdot
.26559 .51943 Mdot
.86846 .3726 Mdot
.64693 .48112 Mdot
.61581 .5988 Mdot
.74346 .07889 Mdot
.10964 .22631 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.5042 .00178 Mdot
.51339 .00568 Mdot
.54264 .01808 Mdot
.63508 .05713 Mdot
.90668 .16786 Mdot
.31037 .2495 Mdot
.49231 .11244 Mdot
.66271 .10532 Mdot
.03684 .23122 Mdot
.3562 .19738 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49076 .61412 Mdot
.47058 .60556 Mdot
.40651 .57844 Mdot
.21012 .49666 Mdot
.78246 .35372 Mdot
.58858 .49821 Mdot
.52082 .57616 Mdot
.4842 .5954 Mdot
.42391 .58078 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48723 .61262 Mdot
.45935 .6008 Mdot
.37114 .56352 Mdot
.11009 .45669 Mdot
.69676 .36258 Mdot
.50892 .50195 Mdot
.33447 .51022 Mdot
.95413 .38297 Mdot
.64165 .42491 Mdot
.49873 .6175 Mdot
.49595 .61632 Mdot
.4871 .61257 Mdot
.45893 .60062 Mdot
.36984 .56297 Mdot
.10655 .45531 Mdot
.69511 .36375 Mdot
.50835 .50261 Mdot
.3341 .51034 Mdot
.95368 .38292 Mdot
.64176 .42526 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51714 .00727 Mdot
.55455 .02312 Mdot
.67219 .07271 Mdot
.00059 .20297 Mdot
.32811 .20242 Mdot
.44507 .07229 Mdot
.48126 .02237 Mdot
.4894 .00503 Mdot
.49907 .61764 Mdot
.49705 .61678 Mdot
.49059 .61404 Mdot
.47003 .60533 Mdot
.40477 .5777 Mdot
.20505 .4946 Mdot
.77605 .3529 Mdot
.58259 .49847 Mdot
.50754 .57165 Mdot
.4438 .57864 Mdot
.2975 .52761 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.5056 .00237 Mdot
.51784 .00756 Mdot
.55678 .02407 Mdot
.67909 .07559 Mdot
.01683 .20873 Mdot
.32937 .19316 Mdot
.43226 .06359 Mdot
.43658 .00267 Mdot
.34826 .56345 Mdot
.06527 .44314 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49066 .61407 Mdot
.47024 .60542 Mdot
.40546 .57799 Mdot
.20705 .49541 Mdot
.77855 .35321 Mdot
.58495 .49838 Mdot
.51282 .57345 Mdot
.45988 .58532 Mdot
.34741 .54852 Mdot
.50046 .00019 Mdot
.50145 .00062 Mdot
.50463 .00196 Mdot
.51475 .00625 Mdot
.54696 .01991 Mdot
.6486 .06282 Mdot
.94213 .18141 Mdot
.32057 .23388 Mdot
.48335 .10061 Mdot
.62121 .0852 Mdot
.92382 .18702 Mdot
.33638 .25498 Mdot
.49854 .61742 Mdot
.49535 .61606 Mdot
.4852 .61176 Mdot
.45288 .59806 Mdot
.35091 .55501 Mdot
.0566 .43614 Mdot
.67917 .38477 Mdot
.51722 .51794 Mdot
.38105 .53388 Mdot
.0826 .43358 Mdot
.66574 .3604 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00467 Mdot
.53505 .01486 Mdot
.61124 .04709 Mdot
.84104 .14202 Mdot
.27156 .26608 Mdot
.46555 .11989 Mdot
.60825 .0882 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.5059 .0025 Mdot
.5188 .00797 Mdot
.55983 .02536 Mdot
.6885 .07953 Mdot
.03831 .21619 Mdot
.3312 .18102 Mdot
.41577 .05227 Mdot
.37981 .59581 Mdot
.18022 .49468 Mdot
.76448 .36109 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52329 .00988 Mdot
.57408 .03139 Mdot
.73202 .09761 Mdot
.12716 .24421 Mdot
.35122 .13848 Mdot
.38323 .01978 Mdot
.25537 .53901 Mdot
.88891 .39155 Mdot
.67588 .48637 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00165 Mdot
.51237 .00525 Mdot
.5394 .0167 Mdot
.62492 .05286 Mdot
.87917 .15713 Mdot
.29775 .2587 Mdot
.48826 .11774 Mdot
.66116 .10686 Mdot
.03657 .23201 Mdot
.3576 .19841 Mdot
.50079 .00033 Mdot
.50251 .00107 Mdot
.50801 .0034 Mdot
.52551 .01082 Mdot
.5811 .03436 Mdot
.75315 .10633 Mdot
.16389 .25385 Mdot
.36999 .12738 Mdot
.40206 .01982 Mdot
.29631 .55268 Mdot
.96186 .41133 Mdot
.68408 .44635 Mdot
.49783 .61711 Mdot
.49308 .6151 Mdot
.47794 .60868 Mdot
.42983 .5883 Mdot
.27984 .52533 Mdot
.8953 .38038 Mdot
.65673 .47059 Mdot
.61705 .59351 Mdot
.73753 .07446 Mdot
.09601 .22156 Mdot
.31906 .13785 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51454 .00616 Mdot
.54628 .01962 Mdot
.64648 .06192 Mdot
.93666 .17934 Mdot
.31936 .23652 Mdot
.48565 .10277 Mdot
.63044 .08949 Mdot
.94972 .19732 Mdot
.34317 .24316 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50199 .00084 Mdot
.50634 .00269 Mdot
.52021 .00857 Mdot
.56432 .02726 Mdot
.7023 .08528 Mdot
.06837 .22625 Mdot
.33501 .16479 Mdot
.39617 .0378 Mdot
.3124 .56626 Mdot
.49818 .61726 Mdot
.49421 .61558 Mdot
.48157 .61022 Mdot
.44134 .59317 Mdot
.31509 .54001 Mdot
.96979 .40463 Mdot
.66954 .43247 Mdot
.57815 .56155 Mdot
.59933 .01309 Mdot
.76002 .09931 Mdot
.15897 .24656 Mdot
.49991 .618 Mdot
.49972 .61792 Mdot
.49912 .61766 Mdot
.49718 .61684 Mdot
.49103 .61423 Mdot
.47142 .60591 Mdot
.40916 .57956 Mdot
.21793 .49984 Mdot
.79279 .35529 Mdot
.59781 .49753 Mdot
.54048 .5826 Mdot
.49967 .61789 Mdot
.49894 .61758 Mdot
.49662 .6166 Mdot
.48924 .61347 Mdot
.46573 .60351 Mdot
.39122 .57198 Mdot
.16596 .47881 Mdot
.73448 .35136 Mdot
.54059 .49821 Mdot
.40694 .53543 Mdot
.14152 .454 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .00181 Mdot
.51357 .00575 Mdot
.5432 .01832 Mdot
.63685 .05788 Mdot
.9114 .16968 Mdot
.31209 .24764 Mdot
.49198 .11118 Mdot
.65986 .10375 Mdot
.0292 .22826 Mdot
.35498 .20134 Mdot
.49956 .61785 Mdot
.49858 .61743 Mdot
.49549 .61612 Mdot
.48562 .61194 Mdot
.45422 .59863 Mdot
.35509 .55677 Mdot
.0674 .44023 Mdot
.68161 .3796 Mdot
.51284 .51373 Mdot
.36332 .52562 Mdot
.03306 .41392 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47984 .60948 Mdot
.43584 .59084 Mdot
.2982 .53297 Mdot
.93269 .39214 Mdot
.66516 .45269 Mdot
.60324 .57977 Mdot
.68555 .05087 Mdot
.98728 .18648 Mdot
.30807 .19826 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.5099 .0042 Mdot
.53154 .01337 Mdot
.60018 .04242 Mdot
.80935 .12928 Mdot
.24085 .26668 Mdot
.43401 .11938 Mdot
.531 .05994 Mdot
.6742 .0885 Mdot
.02957 .21963 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48769 .61281 Mdot
.4608 .60141 Mdot
.3757 .56544 Mdot
.12252 .46156 Mdot
.70319 .35887 Mdot
.51233 .50008 Mdot
.33996 .5115 Mdot
.966 .38691 Mdot
.49819 .61726 Mdot
.49422 .61558 Mdot
.48159 .61023 Mdot
.44139 .59319 Mdot
.31526 .54008 Mdot
.97018 .40477 Mdot
.66957 .43225 Mdot
.57785 .56135 Mdot
.59831 .01264 Mdot
.75702 .09809 Mdot
.15424 .24549 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00823 Mdot
.56174 .02617 Mdot
.69438 .08198 Mdot
.05132 .2206 Mdot
.33261 .17384 Mdot
.40661 .04573 Mdot
.34842 .58207 Mdot
.0957 .46185 Mdot
.70793 .37838 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47786 .60864 Mdot
.42956 .58818 Mdot
.27901 .52499 Mdot
.89369 .37989 Mdot
.65624 .47128 Mdot
.61727 .59395 Mdot
.73871 .07506 Mdot
.09829 .22223 Mdot
.31963 .13679 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47888 .60908 Mdot
.4328 .58956 Mdot
.28889 .52909 Mdot
.91334 .38593 Mdot
.66145 .46236 Mdot
.61229 .58765 Mdot
.71792 .06529 Mdot
.05745 .20984 Mdot
.31267 .15773 Mdot
.49906 .61763 Mdot
.49699 .61676 Mdot
.49041 .61397 Mdot
.46947 .60509 Mdot
.403 .57695 Mdot
.19987 .49249 Mdot
.76975 .35221 Mdot
.57653 .49862 Mdot
.49373 .56686 Mdot
.40153 .56105 Mdot
.17086 .47547 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50661 .0028 Mdot
.52106 .00893 Mdot
.567 .02839 Mdot
.71049 .08868 Mdot
.0854 .23171 Mdot
.33827 .15628 Mdot
.38819 .03085 Mdot
.28384 .55355 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48977 .6137 Mdot
.46743 .60422 Mdot
.39656 .57424 Mdot
.18123 .48495 Mdot
.74911 .35097 Mdot
.55572 .49851 Mdot
.4442 .54911 Mdot
.25069 .49844 Mdot
.81845 .35089 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50639 .00271 Mdot
.52034 .00863 Mdot
.56473 .02743 Mdot
.70357 .0858 Mdot
.07105 .22711 Mdot
.33546 .16342 Mdot
.39474 .03664 Mdot
.30738 .56405 Mdot
.99665 .42599 Mdot
.69094 .4291 Mdot
.50049 .00021 Mdot
.50158 .00067 Mdot
.50502 .00213 Mdot
.516 .00678 Mdot
.55093 .02159 Mdot
.66096 .068 Mdot
.97333 .19305 Mdot
.32552 .21766 Mdot
.46534 .08642 Mdot
.5536 .05454 Mdot
.72073 .10329 Mdot
.12257 .24835 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50994 .00422 Mdot
.53167 .01343 Mdot
.60059 .04259 Mdot
.81055 .12976 Mdot
.24217 .26676 Mdot
.43535 .11939 Mdot
.53419 .06109 Mdot
.68394 .09255 Mdot
.05214 .22756 Mdot
.49933 .61775 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47817 .60878 Mdot
.43056 .58861 Mdot
.28207 .52626 Mdot
.89967 .3817 Mdot
.658 .46867 Mdot
.61626 .59224 Mdot
.73382 .07266 Mdot
.08888 .21944 Mdot
.49816 .61725 Mdot
.49413 .61555 Mdot
.48131 .61011 Mdot
.44051 .59282 Mdot
.31253 .53894 Mdot
.964 .40263 Mdot
.66902 .43572 Mdot
.58252 .56457 Mdot
.61432 .01966 Mdot
.80323 .11676 Mdot
.21765 .25612 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51716 .00727 Mdot
.55461 .02315 Mdot
.67238 .07279 Mdot
.00104 .20313 Mdot
.32814 .20216 Mdot
.44472 .07204 Mdot
.48002 .02182 Mdot
.48542 .00334 Mdot
.46899 .60788 Mdot
.50016 7e-05 Mdot
.50053 .00022 Mdot
.50167 .00071 Mdot
.50533 .00226 Mdot
.51699 .00721 Mdot
.5541 .02293 Mdot
.67079 .07212 Mdot
.99726 .20177 Mdot
.32784 .20431 Mdot
.44767 .07406 Mdot
.49041 .02641 Mdot
.51877 .01753 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50528 .00224 Mdot
.51683 .00714 Mdot
.55356 .0227 Mdot
.66914 .07143 Mdot
.99329 .20034 Mdot
.3275 .20656 Mdot
.45074 .07616 Mdot
.50126 .03122 Mdot
.55366 .03239 Mdot
.50018 8e-05 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50598 .00254 Mdot
.51906 .00808 Mdot
.56066 .02571 Mdot
.69106 .08059 Mdot
.044 .21813 Mdot
.33178 .17786 Mdot
.41166 .04937 Mdot
.36573 .58965 Mdot
.14146 .47942 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.5028 .00119 Mdot
.50892 .00378 Mdot
.52842 .01205 Mdot
.59031 .03825 Mdot
.78051 .11755 Mdot
.20507 .26239 Mdot
.40035 .12069 Mdot
.45573 .03423 Mdot
.44556 .61175 Mdot
.35531 .56226 Mdot
.49799 .61718 Mdot
.49358 .61531 Mdot
.47955 .60936 Mdot
.43493 .59046 Mdot
.29541 .5318 Mdot
.92681 .39022 Mdot
.66416 .45571 Mdot
.60637 .58231 Mdot
.6965 .05571 Mdot
.01201 .19499 Mdot
.30952 .18387 Mdot
.49823 .61728 Mdot
.49435 .61564 Mdot
.48199 .6104 Mdot
.44268 .59374 Mdot
.31923 .54174 Mdot
.97928 .40793 Mdot
.67032 .42709 Mdot
.5708 .55653 Mdot
.57402 .00199 Mdot
.6843 .06816 Mdot
.01326 .20331 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50599 .00254 Mdot
.51908 .00809 Mdot
.56073 .02574 Mdot
.69127 .08068 Mdot
.04448 .21829 Mdot
.33183 .17759 Mdot
.41132 .04913 Mdot
.36457 .58914 Mdot
.13831 .4782 Mdot
.72973 .36552 Mdot
.4987 .61748 Mdot
.49585 .61627 Mdot
.48677 .61242 Mdot
.45785 .60017 Mdot
.36646 .56155 Mdot
.09745 .45178 Mdot
.69123 .36697 Mdot
.50764 .50457 Mdot
.33552 .51166 Mdot
.95831 .3849 Mdot
.64292 .42311 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52638 .01118 Mdot
.58386 .03552 Mdot
.76138 .10972 Mdot
.17703 .25688 Mdot
.3786 .12458 Mdot
.41522 .02263 Mdot
.3306 .56574 Mdot
.03722 .43671 Mdot
.68851 .40252 Mdot
.49988 .61798 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49604 .61635 Mdot
.48737 .61268 Mdot
.45979 .60099 Mdot
.37253 .56411 Mdot
.11388 .45817 Mdot
.69861 .36138 Mdot
.50974 .5013 Mdot
.33546 .51032 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60202 Mdot
.38021 .56734 Mdot
.135 .46649 Mdot
.71071 .35581 Mdot
.51792 .49888 Mdot
.35195 .51546 Mdot
.99457 .39716 Mdot
.49788 .61714 Mdot
.49326 .61517 Mdot
.47851 .60892 Mdot
.43164 .58907 Mdot
.28536 .52762 Mdot
.90621 .38371 Mdot
.65974 .46571 Mdot
.61464 .59016 Mdot
.72701 .06945 Mdot
.07563 .21546 Mdot
.31502 .14795 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48031 .60969 Mdot
.43735 .59148 Mdot
.30282 .53489 Mdot
.94259 .3954 Mdot
.66662 .44747 Mdot
.59736 .57523 Mdot
.6652 .04193 Mdot
.93867 .16902 Mdot
.30188 .22448 Mdot
.49943 .61779 Mdot
.49819 .61727 Mdot
.49423 .61559 Mdot
.48163 .61024 Mdot
.44152 .59325 Mdot
.31566 .54025 Mdot
.9711 .40508 Mdot
.66965 .43173 Mdot
.57715 .56087 Mdot
.59591 .01159 Mdot
.74997 .09521 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49073 .6141 Mdot
.47048 .60552 Mdot
.4062 .57831 Mdot
.20923 .4963 Mdot
.78131 .35357 Mdot
.58752 .49827 Mdot
.5185 .57538 Mdot
.47717 .59249 Mdot
.40172 .5714 Mdot
.50046 .00019 Mdot
.50145 .00062 Mdot
.50463 .00197 Mdot
.51477 .00626 Mdot
.54701 .01993 Mdot
.64876 .06288 Mdot
.94256 .18157 Mdot
.32066 .23368 Mdot
.48316 .10044 Mdot
.62047 .08486 Mdot
.9217 .18617 Mdot
.3357 .25587 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51563 .00663 Mdot
.54976 .02109 Mdot
.65731 .06647 Mdot
.96424 .18969 Mdot
.32436 .22257 Mdot
.47134 .09084 Mdot
.57555 .06441 Mdot
.78887 .13184 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47779 .60862 Mdot
.42936 .5881 Mdot
.2784 .52474 Mdot
.8925 .37954 Mdot
.65587 .47178 Mdot
.61741 .59427 Mdot
.73953 .07547 Mdot
.09986 .2227 Mdot
.32004 .13608 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49706 .61679 Mdot
.49062 .61406 Mdot
.47012 .60536 Mdot
.40506 .57782 Mdot
.20587 .49493 Mdot
.77708 .35302 Mdot
.58357 .49844 Mdot
.50972 .5724 Mdot
.45046 .58141 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50798 .00339 Mdot
.52543 .01078 Mdot
.58087 .03426 Mdot
.75245 .10604 Mdot
.16273 .25357 Mdot
.36928 .12765 Mdot
.40107 .01965 Mdot
.29384 .55176 Mdot
.95688 .40978 Mdot
.68381 .44927 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52163 .00917 Mdot
.56881 .02916 Mdot
.71602 .09098 Mdot
.09655 .23518 Mdot
.34097 .15106 Mdot
.38461 .02697 Mdot
.26994 .54716 Mdot
.9184 .40077 Mdot
.68397 .47315 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50355 .00151 Mdot
.51131 .0048 Mdot
.53602 .01527 Mdot
.61431 .04838 Mdot
.8497 .14548 Mdot
.27849 .26501 Mdot
.47236 .11982 Mdot
.62499 .09433 Mdot
.94642 .19865 Mdot
.34671 .24739 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48908 .6134 Mdot
.46523 .60329 Mdot
.38962 .57131 Mdot
.16141 .47699 Mdot
.7305 .35172 Mdot
.53654 .49816 Mdot
.3969 .53173 Mdot
.11321 .4427 Mdot
.67367 .34638 Mdot
.49819 .61727 Mdot
.49423 .61559 Mdot
.48161 .61024 Mdot
.44148 .59323 Mdot
.31553 .54019 Mdot
.97079 .40498 Mdot
.66962 .4319 Mdot
.57739 .56103 Mdot
.59671 .01194 Mdot
.75233 .09618 Mdot
.14665 .24371 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48963 .61364 Mdot
.46696 .60403 Mdot
.3951 .57362 Mdot
.17705 .48327 Mdot
.7449 .35095 Mdot
.55136 .49842 Mdot
.43354 .54522 Mdot
.21891 .48538 Mdot
.77009 .34065 Mdot
.49797 .61717 Mdot
.49352 .61529 Mdot
.47936 .60928 Mdot
.43433 .59021 Mdot
.29358 .53104 Mdot
.92299 .38899 Mdot
.66346 .45764 Mdot
.60823 .5839 Mdot
.70312 .05864 Mdot
.02645 .19983 Mdot
.31029 .17542 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.53111 .01319 Mdot
.59883 .04185 Mdot
.80545 .1277 Mdot
.23645 .26638 Mdot
.42959 .11937 Mdot
.52053 .0562 Mdot
.64218 .07518 Mdot
.94985 .19015 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47929 .60925 Mdot
.43411 .59011 Mdot
.2929 .53076 Mdot
.92158 .38854 Mdot
.66319 .45834 Mdot
.60888 .58447 Mdot
.49837 .61734 Mdot
.49479 .61583 Mdot
.48341 .611 Mdot
.44719 .59565 Mdot
.3332 .54759 Mdot
.01237 .41975 Mdot
.673 .40829 Mdot
.54497 .53891 Mdot
.48349 .58004 Mdot
.39729 .56476 Mdot
.16751 .47602 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52404 .01019 Mdot
.57644 .03239 Mdot
.73916 .10056 Mdot
.14006 .24777 Mdot
.35695 .13405 Mdot
.38702 .01858 Mdot
.2615 .54046 Mdot
.89786 .3933 Mdot
.67713 .48162 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50545 .00231 Mdot
.51735 .00736 Mdot
.55523 .02341 Mdot
.67431 .0736 Mdot
.00564 .20477 Mdot
.32851 .19954 Mdot
.4411 .06959 Mdot
.46736 .01623 Mdot
.44499 .60421 Mdot
.34175 .55423 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48593 .61207 Mdot
.45519 .59904 Mdot
.35812 .55804 Mdot
.07531 .44325 Mdot
.68371 .37601 Mdot
.51043 .51094 Mdot
.35277 .5206 Mdot
.00445 .40276 Mdot
.64945 .39864 Mdot
.49839 .61735 Mdot
.49488 .61586 Mdot
.4837 .61112 Mdot
.4481 .59604 Mdot
.33603 .54877 Mdot
.01927 .42226 Mdot
.67367 .40444 Mdot
.53987 .53534 Mdot
.46526 .57192 Mdot
.33894 .53997 Mdot
.01022 .41487 Mdot
.49986 .61798 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49559 .61616 Mdot
.48594 .61207 Mdot
.45524 .59906 Mdot
.35827 .55811 Mdot
.07571 .4434 Mdot
.68382 .37583 Mdot
.51032 .5108 Mdot
.35229 .52036 Mdot
.49945 .6178 Mdot
.49824 .61729 Mdot
.49441 .61566 Mdot
.48218 .61048 Mdot
.44327 .59399 Mdot
.32107 .54251 Mdot
.98354 .40943 Mdot
.67066 .42466 Mdot
.56745 .55425 Mdot
.56242 .61492 Mdot
.64862 .05328 Mdot
.4981 .61723 Mdot
.49396 .61547 Mdot
.48075 .60987 Mdot
.43873 .59207 Mdot
.30706 .53666 Mdot
.95184 .39849 Mdot
.66776 .44246 Mdot
.59125 .57075 Mdot
.64423 .03275 Mdot
.88514 .14889 Mdot
.28377 .24636 Mdot
.49771 .61706 Mdot
.49269 .61494 Mdot
.47672 .60816 Mdot
.42595 .58666 Mdot
.26808 .52046 Mdot
.87302 .37387 Mdot
.64885 .47949 Mdot
.61681 .59823 Mdot
.74466 .07902 Mdot
.11111 .22648 Mdot
.32411 .13164 Mdot
.4978 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42911 .58799 Mdot
.27765 .52443 Mdot
.89106 .37911 Mdot
.65541 .47239 Mdot
.61756 .59464 Mdot
.74044 .07595 Mdot
.10162 .22322 Mdot
.32052 .13529 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.47701 .60828 Mdot
.42687 .58704 Mdot
.27084 .52161 Mdot
.87813 .37532 Mdot
.65088 .47758 Mdot
.61753 .59742 Mdot
.74488 .07871 Mdot
.11084 .22618 Mdot
.32366 .13153 Mdot
.49928 .61773 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47658 .6081 Mdot
.42551 .58647 Mdot
.26673 .5199 Mdot
.87053 .37317 Mdot
.64782 .48039 Mdot
.6163 .59856 Mdot
.74412 .079 Mdot
.11051 .22644 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49848 .61739 Mdot
.49516 .61598 Mdot
.48458 .61149 Mdot
.4509 .59722 Mdot
.34474 .55242 Mdot
.04091 .43026 Mdot
.67639 .39275 Mdot
.52551 .52479 Mdot
.41275 .54834 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.52659 .01127 Mdot
.58452 .0358 Mdot
.76336 .11053 Mdot
.18009 .25755 Mdot
.38075 .12402 Mdot
.41881 .02352 Mdot
.3403 .56951 Mdot
.06045 .44508 Mdot
.6921 .39038 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50662 .00281 Mdot
.52108 .00894 Mdot
.56708 .02843 Mdot
.71075 .08879 Mdot
.08593 .23187 Mdot
.33839 .15602 Mdot
.38798 .03065 Mdot
.28309 .5532 Mdot
.9446 .40884 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.4805 .60977 Mdot
.43795 .59174 Mdot
.30467 .53566 Mdot
.9466 .39674 Mdot
.66714 .44531 Mdot
.59477 .57331 Mdot
.6563 .03803 Mdot
.91638 .16074 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.5357 .01514 Mdot
.6133 .04796 Mdot
.84687 .14435 Mdot
.27629 .2654 Mdot
.47023 .11986 Mdot
.61979 .09243 Mdot
.93254 .19329 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48861 .6132 Mdot
.46373 .60266 Mdot
.38491 .56932 Mdot
.14812 .47169 Mdot
.71986 .35335 Mdot
.52607 .49826 Mdot
.37119 .52232 Mdot
.04353 .41552 Mdot
.65138 .37567 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49087 .61416 Mdot
.47091 .6057 Mdot
.40756 .57888 Mdot
.21322 .49793 Mdot
.7865 .3543 Mdot
.59225 .49798 Mdot
.52877 .5788 Mdot
.5082 .60532 Mdot
.49992 .61292 Mdot
.49858 .61743 Mdot
.49548 .61612 Mdot
.4856 .61193 Mdot
.45415 .5986 Mdot
.35487 .55668 Mdot
.06684 .44002 Mdot
.68147 .37986 Mdot
.51304 .51394 Mdot
.36415 .52602 Mdot
.03535 .41482 Mdot
.65396 .38232 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48722 .61262 Mdot
.45931 .60078 Mdot
.37102 .56347 Mdot
.10975 .45656 Mdot
.6966 .36269 Mdot
.50886 .50201 Mdot
.33441 .51022 Mdot
.95404 .38295 Mdot
.64165 .42497 Mdot
.49828 .61731 Mdot
.49453 .61572 Mdot
.48258 .61065 Mdot
.44456 .59453 Mdot
.32505 .54417 Mdot
.99286 .41273 Mdot
.67138 .41934 Mdot
.56008 .54925 Mdot
.53678 .60363 Mdot
.56817 .0194 Mdot
.69871 .08068 Mdot
.50024 .0001 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50777 .00329 Mdot
.52475 .01049 Mdot
.5787 .03334 Mdot
.74595 .10337 Mdot
.15185 .25086 Mdot
.363 .1305 Mdot
.39309 .0186 Mdot
.27462 .54481 Mdot
.92027 .39903 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50405 .00172 Mdot
.51291 .00547 Mdot
.54111 .01743 Mdot
.63028 .05511 Mdot
.89377 .16285 Mdot
.30504 .25417 Mdot
.4917 .11536 Mdot
.66591 .10767 Mdot
.0463 .23509 Mdot
.35822 .19277 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47715 .60834 Mdot
.4273 .58723 Mdot
.27217 .52215 Mdot
.88061 .37604 Mdot
.65181 .47663 Mdot
.61773 .59697 Mdot
.74457 .07839 Mdot
.11001 .22585 Mdot
.32326 .1318 Mdot
.49854 .61742 Mdot
.49536 .61607 Mdot
.48521 .61176 Mdot
.45291 .59807 Mdot
.35101 .55506 Mdot
.05687 .43624 Mdot
.67923 .38464 Mdot
.5171 .51783 Mdot
.38057 .53365 Mdot
.08123 .43303 Mdot
.66527 .36096 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50536 .00227 Mdot
.51708 .00724 Mdot
.55438 .02305 Mdot
.67167 .07249 Mdot
.99936 .20252 Mdot
.32801 .20312 Mdot
.44604 .07295 Mdot
.48466 .02387 Mdot
.50031 .00967 Mdot
.51643 .00996 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51015 .0043 Mdot
.53232 .0137 Mdot
.60263 .04346 Mdot
.81644 .13214 Mdot
.24848 .26702 Mdot
.4418 .11948 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.52011 .00853 Mdot
.564 .02712 Mdot
.70132 .08487 Mdot
.06629 .22556 Mdot
.33468 .16587 Mdot
.39733 .03872 Mdot
.31644 .56804 Mdot
.01731 .43316 Mdot
.69227 .41715 Mdot
.50041 .00017 Mdot
.50131 .00055 Mdot
.50416 .00177 Mdot
.51326 .00562 Mdot
.54224 .01791 Mdot
.63383 .05661 Mdot
.90333 .16656 Mdot
.30908 .25077 Mdot
.49236 .11327 Mdot
.6642 .1062 Mdot
.0409 .23282 Mdot
.35693 .19531 Mdot
.49961 .61787 Mdot
.49875 .6175 Mdot
.49601 .61634 Mdot
.48729 .61264 Mdot
.45951 .60087 Mdot
.37166 .56374 Mdot
.11149 .45724 Mdot
.69743 .36213 Mdot
.5092 .5017 Mdot
.33477 .51023 Mdot
.95467 .38312 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.4929 .61502 Mdot
.47738 .60844 Mdot
.42804 .58754 Mdot
.2744 .52308 Mdot
.88484 .37727 Mdot
.65333 .47495 Mdot
.61785 .59611 Mdot
.74344 .07762 Mdot
.10755 .22504 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50525 .00223 Mdot
.51673 .00709 Mdot
.55325 .02257 Mdot
.66816 .07102 Mdot
.99093 .19948 Mdot
.3273 .20789 Mdot
.45254 .0774 Mdot
.50764 .03406 Mdot
.57421 .04114 Mdot
.7481 .10747 Mdot
.50027 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.50888 .00377 Mdot
.52829 .012 Mdot
.58992 .03809 Mdot
.77937 .11709 Mdot
.2035 .26212 Mdot
.39901 .12083 Mdot
.453 .03337 Mdot
.43751 .60846 Mdot
.33067 .55201 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49234 .61478 Mdot
.47558 .60768 Mdot
.42235 .58514 Mdot
.25722 .51598 Mdot
.8536 .36858 Mdot
.6399 .48596 Mdot
.61004 .59958 Mdot
.7324 .07562 Mdot
.09203 .22226 Mdot
.4974 .61693 Mdot
.49171 .61452 Mdot
.47359 .60683 Mdot
.41603 .58246 Mdot
.23828 .50818 Mdot
.82244 .36103 Mdot
.62103 .49356 Mdot
.58417 .59525 Mdot
.66777 .05167 Mdot
.95894 .17995 Mdot
.31102 .2176 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47317 .60666 Mdot
.41472 .58191 Mdot
.23438 .50658 Mdot
.81645 .35974 Mdot
.61675 .49461 Mdot
.57688 .5934 Mdot
.64791 .0439 Mdot
.91021 .16211 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50896 .0038 Mdot
.52854 .0121 Mdot
.5907 .03842 Mdot
.78167 .11802 Mdot
.20666 .26266 Mdot
.40171 .12055 Mdot
.45853 .03512 Mdot
.45385 .61514 Mdot
.3809 .57295 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51239 .00525 Mdot
.53945 .01672 Mdot
.62507 .05292 Mdot
.87957 .15729 Mdot
.29797 .25858 Mdot
.48839 .11769 Mdot
.66142 .10694 Mdot
.03714 .23221 Mdot
.35766 .19809 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.5203 .00861 Mdot
.56459 .02737 Mdot
.70312 .08562 Mdot
.0701 .22681 Mdot
.3353 .1639 Mdot
.39524 .03705 Mdot
.30914 .56482 Mdot
.00061 .42735 Mdot
.50046 .00019 Mdot
.50145 .00062 Mdot
.50462 .00196 Mdot
.51473 .00625 Mdot
.54689 .01988 Mdot
.64839 .06273 Mdot
.94159 .18121 Mdot
.32045 .23415 Mdot
.4836 .10083 Mdot
.62217 .08565 Mdot
.92654 .18811 Mdot
.33722 .25382 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47986 .6095 Mdot
.43592 .59088 Mdot
.29844 .53307 Mdot
.9332 .3923 Mdot
.66524 .45243 Mdot
.60296 .57954 Mdot
.68455 .05043 Mdot
.98498 .18568 Mdot
.49949 .61782 Mdot
.49838 .61735 Mdot
.49485 .61585 Mdot
.48359 .61108 Mdot
.44777 .59589 Mdot
.33499 .54833 Mdot
.01671 .42133 Mdot
.67341 .40586 Mdot
.54174 .53665 Mdot
.47196 .57491 Mdot
.36033 .54904 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61007 Mdot
.4402 .59269 Mdot
.3116 .53855 Mdot
.96192 .40192 Mdot
.66882 .43689 Mdot
.58406 .56565 Mdot
.6196 .02197 Mdot
.81812 .12269 Mdot
.50003 1e-05 Mdot
.50008 4e-05 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50267 .00113 Mdot
.50851 .00361 Mdot
.52711 .0115 Mdot
.58618 .03651 Mdot
.7683 .11255 Mdot
.18757 .25913 Mdot
.38624 .12279 Mdot
.42844 .02608 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48443 .61143 Mdot
.45043 .59702 Mdot
.34326 .5518 Mdot
.03719 .42887 Mdot
.67584 .39471 Mdot
.52777 .52652 Mdot
.42116 .55214 Mdot
.20106 .48201 Mdot
.75343 .34138 Mdot
.50043 .00018 Mdot
.50135 .00057 Mdot
.50432 .00183 Mdot
.51375 .00583 Mdot
.54378 .01856 Mdot
.63866 .05864 Mdot
.91621 .17153 Mdot
.31371 .24567 Mdot
.49136 .10979 Mdot
.65606 .10179 Mdot
.0191 .22437 Mdot
.35356 .20671 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52505 .01062 Mdot
.57965 .03375 Mdot
.7488 .10454 Mdot
.15667 .25208 Mdot
.3657 .12918 Mdot
.39634 .01894 Mdot
.28226 .54753 Mdot
.93433 .403 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46983 .60524 Mdot
.40414 .57744 Mdot
.2032 .49384 Mdot
.77377 .35263 Mdot
.58042 .49854 Mdot
.50262 .56996 Mdot
.42877 .57239 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50812 .00345 Mdot
.52588 .01097 Mdot
.58229 .03486 Mdot
.7567 .10779 Mdot
.16964 .25521 Mdot
.37363 .12608 Mdot
.40737 .02085 Mdot
.30989 .55778 Mdot
.99037 .42056 Mdot
.68529 .42949 Mdot
.50072 .00031 Mdot
.5023 .00097 Mdot
.50732 .00311 Mdot
.52333 .00989 Mdot
.57421 .03144 Mdot
.73241 .09777 Mdot
.12789 .24442 Mdot
.35152 .13821 Mdot
.38337 .01968 Mdot
.2555 .53901 Mdot
.88905 .39155 Mdot
.67587 .48628 Mdot
.49812 .61724 Mdot
.494 .61549 Mdot
.48088 .60993 Mdot
.43916 .59225 Mdot
.30837 .53721 Mdot
.95474 .39947 Mdot
.66808 .44087 Mdot
.58923 .5693 Mdot
.63732 .02972 Mdot
.86677 .14181 Mdot
.27353 .25139 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53634 .01541 Mdot
.61532 .04881 Mdot
.85252 .1466 Mdot
.28062 .26458 Mdot
.47439 .11976 Mdot
.6299 .09611 Mdot
.95933 .2036 Mdot
.49862 .61745 Mdot
.49559 .61616 Mdot
.48595 .61208 Mdot
.45527 .59907 Mdot
.35838 .55815 Mdot
.07601 .44352 Mdot
.68391 .3757 Mdot
.51025 .51071 Mdot
.35194 .5202 Mdot
.00223 .4019 Mdot
.64917 .39983 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00282 Mdot
.52122 .009 Mdot
.56752 .02861 Mdot
.71208 .08935 Mdot
.08864 .23272 Mdot
.339 .15473 Mdot
.387 .02967 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51465 .00621 Mdot
.54664 .01977 Mdot
.64761 .0624 Mdot
.93958 .18045 Mdot
.32002 .23513 Mdot
.48446 .10163 Mdot
.62564 .08725 Mdot
.9363 .192 Mdot
.33998 .24949 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51352 .00573 Mdot
.54306 .01825 Mdot
.6364 .05769 Mdot
.91019 .16921 Mdot
.31166 .24812 Mdot
.4921 .11151 Mdot
.66068 .10419 Mdot
.03137 .2291 Mdot
.35531 .20021 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50374 .00159 Mdot
.51191 .00505 Mdot
.53794 .01609 Mdot
.62035 .05093 Mdot
.86657 .15217 Mdot
.2903 .26188 Mdot
.4829 .11904 Mdot
.64992 .10322 Mdot
.00999 .22254 Mdot
.49819 .61727 Mdot
.49424 .61559 Mdot
.48165 .61025 Mdot
.44161 .59328 Mdot
.31592 .54035 Mdot
.97168 .40529 Mdot
.6697 .4314 Mdot
.5767 .56056 Mdot
.59436 .01091 Mdot
.7454 .09335 Mdot
.13507 .24083 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.5144 .00611 Mdot
.54585 .01944 Mdot
.64511 .06135 Mdot
.93312 .178 Mdot
.31852 .23819 Mdot
.48697 .10411 Mdot
.63591 .09205 Mdot
.96481 .20327 Mdot
.34607 .23563 Mdot
.49953 .61784 Mdot
.49852 .61741 Mdot
.49527 .61603 Mdot
.48495 .61165 Mdot
.45207 .59772 Mdot
.34838 .55395 Mdot
.05014 .43371 Mdot
.67793 .38799 Mdot
.52038 .52067 Mdot
.39332 .53951 Mdot
.11795 .44785 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52145 .00909 Mdot
.56823 .02892 Mdot
.71426 .09025 Mdot
.09302 .23409 Mdot
.34006 .15268 Mdot
.38558 .02813 Mdot
.27389 .549 Mdot
.92615 .40312 Mdot
.68525 .46915 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48705 .61254 Mdot
.45875 .60054 Mdot
.36926 .56273 Mdot
.10497 .4547 Mdot
.6944 .36429 Mdot
.50814 .50292 Mdot
.3341 .51047 Mdot
.95388 .38305 Mdot
.49816 .61726 Mdot
.49415 .61555 Mdot
.48136 .61013 Mdot
.44068 .59289 Mdot
.31305 .53916 Mdot
.96519 .40304 Mdot
.66913 .43506 Mdot
.58163 .56396 Mdot
.61128 .01833 Mdot
.79459 .11329 Mdot
.20732 .25508 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50722 .00306 Mdot
.52299 .00975 Mdot
.57311 .03098 Mdot
.72909 .0964 Mdot
.12175 .24267 Mdot
.34908 .1405 Mdot
.38246 .02063 Mdot
.25513 .53934 Mdot
.88919 .39187 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51117 .00474 Mdot
.53558 .01509 Mdot
.61292 .0478 Mdot
.84578 .14392 Mdot
.27543 .26554 Mdot
.46939 .11987 Mdot
.61773 .09167 Mdot
.49748 .61697 Mdot
.49197 .61463 Mdot
.47442 .60719 Mdot
.41867 .58358 Mdot
.24615 .51141 Mdot
.83497 .36391 Mdot
.6293 .49092 Mdot
.59694 .59803 Mdot
.70117 .06442 Mdot
.03298 .20507 Mdot
.31567 .17471 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50437 .00185 Mdot
.51392 .0059 Mdot
.54434 .0188 Mdot
.6404 .05937 Mdot
.9208 .1733 Mdot
.31515 .24372 Mdot
.4905 .10837 Mdot
.65161 .09957 Mdot
.00726 .2198 Mdot
.35203 .21308 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.47971 .60943 Mdot
.43544 .59067 Mdot
.29695 .53245 Mdot
.93005 .39128 Mdot
.66473 .45406 Mdot
.60468 .58092 Mdot
.69058 .05309 Mdot
.99877 .19047 Mdot
.3088 .19161 Mdot
.49902 .61762 Mdot
.49686 .6167 Mdot
.49 .61379 Mdot
.46816 .60453 Mdot
.39887 .57521 Mdot
.1879 .48764 Mdot
.75614 .35119 Mdot
.56293 .49863 Mdot
.46167 .55545 Mdot
.30348 .52026 Mdot
.9199 .38097 Mdot
.49875 .6175 Mdot
.49602 .61635 Mdot
.48733 .61266 Mdot
.45967 .60093 Mdot
.37214 .56394 Mdot
.1128 .45775 Mdot
.69807 .36172 Mdot
.50949 .50148 Mdot
.33512 .51027 Mdot
.95535 .38333 Mdot
.64168 .42418 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.4794 .6093 Mdot
.43444 .59025 Mdot
.2939 .53117 Mdot
.92365 .38921 Mdot
.66358 .45731 Mdot
.60792 .58363 Mdot
.702 .05815 Mdot
.02405 .19903 Mdot
.31016 .17683 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50293 .00124 Mdot
.50935 .00396 Mdot
.52978 .01263 Mdot
.59463 .04008 Mdot
.79319 .12272 Mdot
.22176 .26487 Mdot
.41534 .11964 Mdot
.48782 .0448 Mdot
.54206 .03352 Mdot
.65866 .07206 Mdot
.49909 .61765 Mdot
.49711 .61681 Mdot
.49079 .61413 Mdot
.47065 .60559 Mdot
.40674 .57853 Mdot
.21081 .49694 Mdot
.78335 .35385 Mdot
.58939 .49817 Mdot
.5226 .57675 Mdot
.48958 .59763 Mdot
.44093 .58797 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49067 .61408 Mdot
.47028 .60543 Mdot
.40556 .57803 Mdot
.20734 .49553 Mdot
.77891 .35325 Mdot
.58529 .49837 Mdot
.51357 .57371 Mdot
.46219 .58628 Mdot
.35463 .55156 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52518 .01068 Mdot
.58006 .03392 Mdot
.75003 .10505 Mdot
.15873 .25259 Mdot
.36689 .12865 Mdot
.39787 .01914 Mdot
.28594 .54886 Mdot
.94134 .40506 Mdot
.68275 .45822 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.4791 .60917 Mdot
.43351 .58985 Mdot
.29105 .52999 Mdot
.91775 .38732 Mdot
.66241 .46022 Mdot
.61055 .58598 Mdot
.7115 .06239 Mdot
.04424 .20564 Mdot
.31147 .16516 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47817 .60878 Mdot
.43054 .5886 Mdot
.282 .52623 Mdot
.89954 .38166 Mdot
.65796 .46873 Mdot
.61629 .59228 Mdot
.73395 .07272 Mdot
.08912 .21951 Mdot
.31749 .14114 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51668 .00707 Mdot
.5531 .02251 Mdot
.6677 .07082 Mdot
.98981 .19908 Mdot
.3272 .20852 Mdot
.45339 .07799 Mdot
.51068 .0354 Mdot
.58396 .04529 Mdot
.77742 .11956 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48386 .61119 Mdot
.44863 .59626 Mdot
.33767 .54946 Mdot
.0233 .42374 Mdot
.6741 .40222 Mdot
.537 .5333 Mdot
.45491 .5673 Mdot
.30608 .52605 Mdot
.93319 .38757 Mdot
.49924 .61771 Mdot
.49757 .617 Mdot
.49225 .61475 Mdot
.4753 .60756 Mdot
.42145 .58475 Mdot
.2545 .51485 Mdot
.84891 .36737 Mdot
.63742 .48732 Mdot
.60738 .59947 Mdot
.72646 .0736 Mdot
.08167 .21953 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00148 Mdot
.5111 .00471 Mdot
.53535 .01499 Mdot
.6122 .0475 Mdot
.84376 .14311 Mdot
.2738 .26578 Mdot
.46778 .11989 Mdot
.61377 .09022 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50836 .00355 Mdot
.52663 .01129 Mdot
.58467 .03587 Mdot
.76379 .11071 Mdot
.18076 .2577 Mdot
.38123 .1239 Mdot
.41962 .02373 Mdot
.34252 .57038 Mdot
.06589 .44707 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49613 .61639 Mdot
.48768 .61281 Mdot
.46076 .6014 Mdot
.37559 .56539 Mdot
.12222 .46145 Mdot
.70302 .35895 Mdot
.51223 .50012 Mdot
.33975 .51144 Mdot
.96552 .38674 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57518 .03185 Mdot
.73534 .09898 Mdot
.13321 .2459 Mdot
.3538 .13633 Mdot
.38465 .01907 Mdot
.25723 .53929 Mdot
.89133 .39189 Mdot
.67606 .48499 Mdot
.5002 8e-05 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.52011 .00853 Mdot
.56401 .02713 Mdot
.70134 .08488 Mdot
.06633 .22558 Mdot
.33468 .16585 Mdot
.39731 .0387 Mdot
.31635 .568 Mdot
.01712 .4331 Mdot
.4986 .61744 Mdot
.49553 .61614 Mdot
.48576 .61199 Mdot
.45465 .59881 Mdot
.35644 .55734 Mdot
.07093 .44158 Mdot
.68251 .37798 Mdot
.51168 .51245 Mdot
.35835 .52327 Mdot
.01949 .40861 Mdot
.65147 .39059 Mdot
.49883 .61754 Mdot
.49627 .61645 Mdot
.48811 .61299 Mdot
.46212 .60197 Mdot
.37984 .56719 Mdot
.13398 .46608 Mdot
.71005 .35603 Mdot
.51738 .49896 Mdot
.35072 .51503 Mdot
.99157 .39606 Mdot
.64505 .40388 Mdot
.49899 .61761 Mdot
.49678 .61667 Mdot
.48976 .61369 Mdot
.46737 .6042 Mdot
.39639 .57416 Mdot
.18073 .48475 Mdot
.7486 .35096 Mdot
.55519 .4985 Mdot
.44291 .54864 Mdot
.24683 .49685 Mdot
.81206 .34933 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47855 .60894 Mdot
.43175 .58911 Mdot
.28567 .52776 Mdot
.90684 .3839 Mdot
.6599 .46542 Mdot
.61446 .58995 Mdot
.72627 .06911 Mdot
.07417 .21501 Mdot
.3148 .14871 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48467 .61154 Mdot
.45121 .59735 Mdot
.34569 .55282 Mdot
.0433 .43115 Mdot
.67676 .3915 Mdot
.52412 .52369 Mdot
.40751 .54597 Mdot
.15984 .46497 Mdot
.71073 .34047 Mdot
.50003 1e-05 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00115 Mdot
.50862 .00365 Mdot
.52745 .01164 Mdot
.58726 .03696 Mdot
.7715 .11386 Mdot
.19229 .26007 Mdot
.38988 .12211 Mdot
.43514 .02798 Mdot
.49836 .61734 Mdot
.49478 .61582 Mdot
.48338 .61099 Mdot
.44709 .59561 Mdot
.3329 .54746 Mdot
.01163 .41948 Mdot
.67293 .40871 Mdot
.54552 .53929 Mdot
.48547 .58092 Mdot
.40366 .56747 Mdot
.186 .48351 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02053 Mdot
.65316 .06473 Mdot
.95377 .18579 Mdot
.32276 .22805 Mdot
.47753 .09565 Mdot
.5987 .07489 Mdot
.85862 .16064 Mdot
.3038 .27513 Mdot
.50074 .00031 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.524 .01018 Mdot
.57634 .03235 Mdot
.73886 .10044 Mdot
.13953 .24762 Mdot
.3567 .13422 Mdot
.38681 .01861 Mdot
.26108 .54033 Mdot
.8972 .39314 Mdot
.67702 .48196 Mdot
.49949 .61782 Mdot
.49836 .61734 Mdot
.49479 .61582 Mdot
.48339 .61099 Mdot
.44713 .59562 Mdot
.333 .5475 Mdot
.01188 .41957 Mdot
.67296 .40857 Mdot
.54533 .53916 Mdot
.48479 .58062 Mdot
.40147 .56654 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50709 .00301 Mdot
.52258 .00957 Mdot
.57182 .03043 Mdot
.72518 .09478 Mdot
.11437 .24053 Mdot
.3464 .1434 Mdot
.38215 .0221 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.42751 .58732 Mdot
.2728 .52242 Mdot
.8818 .37638 Mdot
.65225 .47616 Mdot
.61779 .59674 Mdot
.74433 .0782 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52125 .00901 Mdot
.56762 .02866 Mdot
.7124 .08948 Mdot
.08928 .23292 Mdot
.33915 .15443 Mdot
.38678 .02944 Mdot
.27854 .55114 Mdot
.93541 .40596 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49627 .61645 Mdot
.48813 .613 Mdot
.46219 .602 Mdot
.38007 .56728 Mdot
.13459 .46632 Mdot
.71045 .3559 Mdot
.5177 .49891 Mdot
.35145 .51529 Mdot
.99336 .39672 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48385 .61118 Mdot
.44858 .59624 Mdot
.3375 .54939 Mdot
.02288 .42359 Mdot
.67405 .40245 Mdot
.5373 .53351 Mdot
.45597 .56777 Mdot
.30945 .52748 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49292 .61503 Mdot
.47745 .60847 Mdot
.42827 .58764 Mdot
.2751 .52337 Mdot
.88616 .37766 Mdot
.65379 .47442 Mdot
.61784 .59582 Mdot
.74293 .07731 Mdot
.10652 .22471 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50523 .00222 Mdot
.51666 .00706 Mdot
.55303 .02248 Mdot
.66748 .07074 Mdot
.9893 .19889 Mdot
.32715 .20881 Mdot
.45378 .07826 Mdot
.51205 .03601 Mdot
.58839 .04718 Mdot
.79059 .12497 Mdot
.4986 .61744 Mdot
.49552 .61614 Mdot
.48574 .61199 Mdot
.4546 .59879 Mdot
.35628 .55727 Mdot
.07052 .44142 Mdot
.6824 .37817 Mdot
.51181 .5126 Mdot
.35891 .52354 Mdot
.02102 .40921 Mdot
.65169 .38978 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47602 .60787 Mdot
.42373 .58572 Mdot
.26137 .51769 Mdot
.86088 .37052 Mdot
.64349 .48368 Mdot
.61335 .59941 Mdot
.73923 .07779 Mdot
.10328 .225 Mdot
.32306 .13583 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00246 Mdot
.5185 .00784 Mdot
.55887 .02495 Mdot
.68554 .07829 Mdot
.03163 .2139 Mdot
.33059 .18477 Mdot
.42077 .05573 Mdot
.39695 .60331 Mdot
.22913 .51432 Mdot
.82463 .36804 Mdot
.49819 .61727 Mdot
.49423 .61559 Mdot
.48163 .61025 Mdot
.44154 .59325 Mdot
.31571 .54027 Mdot
.9712 .40512 Mdot
.66966 .43167 Mdot
.57707 .56081 Mdot
.59562 .01146 Mdot
.74913 .09487 Mdot
.14136 .24241 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.50511 .00217 Mdot
.51628 .0069 Mdot
.55182 .02197 Mdot
.66372 .06916 Mdot
.98012 .19555 Mdot
.32626 .21393 Mdot
.46056 .083 Mdot
.53632 .04682 Mdot
.66607 .08019 Mdot
.00213 .20769 Mdot
.49794 .61716 Mdot
.49342 .61524 Mdot
.47905 .60915 Mdot
.43333 .58978 Mdot
.29051 .52977 Mdot
.91665 .38697 Mdot
.66218 .46076 Mdot
.611 .58641 Mdot
.71316 .06314 Mdot
.04769 .20675 Mdot
.31175 .1632 Mdot
.49857 .61743 Mdot
.49545 .61611 Mdot
.48552 .61189 Mdot
.45388 .59848 Mdot
.35403 .55632 Mdot
.06465 .43919 Mdot
.68094 .38089 Mdot
.51384 .51476 Mdot
.36748 .52758 Mdot
.04453 .41844 Mdot
.65565 .37769 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50707 .003 Mdot
.52254 .00956 Mdot
.5717 .03038 Mdot
.7248 .09462 Mdot
.11364 .24032 Mdot
.34614 .1437 Mdot
.38217 .02226 Mdot
.25715 .54077 Mdot
.89364 .39337 Mdot
.67806 .4848 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51526 .00647 Mdot
.5486 .0206 Mdot
.6537 .06496 Mdot
.95516 .18631 Mdot
.32299 .22733 Mdot
.47676 .09503 Mdot
.59578 .07356 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00212 Mdot
.51596 .00677 Mdot
.5508 .02153 Mdot
.66055 .06783 Mdot
.97231 .19268 Mdot
.3254 .21822 Mdot
.46604 .08692 Mdot
.55613 .05568 Mdot
.72867 .10664 Mdot
.1378 .25286 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43732 .59147 Mdot
.30273 .53485 Mdot
.94239 .39533 Mdot
.66659 .44758 Mdot
.59748 .57532 Mdot
.66563 .04212 Mdot
.93974 .16941 Mdot
.3021 .22395 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.5112 .00475 Mdot
.53567 .01512 Mdot
.61319 .04791 Mdot
.84653 .14421 Mdot
.27603 .26544 Mdot
.46997 .11987 Mdot
.61915 .0922 Mdot
.93083 .19262 Mdot
.34302 .25475 Mdot
.49744 .61695 Mdot
.49184 .61457 Mdot
.47399 .60701 Mdot
.41731 .583 Mdot
.24209 .50974 Mdot
.82843 .36238 Mdot
.6251 .49237 Mdot
.59069 .59677 Mdot
.68507 .05833 Mdot
.99859 .19377 Mdot
.31422 .19507 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.50591 .00251 Mdot
.51883 .00798 Mdot
.55991 .02539 Mdot
.68877 .07964 Mdot
.0389 .21639 Mdot
.33126 .18069 Mdot
.41534 .05196 Mdot
.37834 .59516 Mdot
.1761 .49304 Mdot
.49919 .61769 Mdot
.49741 .61694 Mdot
.49176 .61454 Mdot
.47375 .60691 Mdot
.41656 .58268 Mdot
.23985 .50882 Mdot
.82489 .36158 Mdot
.62272 .49309 Mdot
.58693 .59591 Mdot
.67514 .05452 Mdot
.97615 .18604 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50435 .00184 Mdot
.51386 .00588 Mdot
.54413 .01871 Mdot
.63974 .05909 Mdot
.91906 .17263 Mdot
.31462 .24447 Mdot
.49086 .10892 Mdot
.65339 .10045 Mdot
.01199 .22163 Mdot
.35263 .21052 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.51869 .00793 Mdot
.5595 .02522 Mdot
.68749 .0791 Mdot
.03603 .21541 Mdot
.33099 .18229 Mdot
.41746 .05344 Mdot
.38559 .59834 Mdot
.19651 .50117 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47854 .60894 Mdot
.43174 .58911 Mdot
.28565 .52775 Mdot
.9068 .38389 Mdot
.65989 .46544 Mdot
.61447 .58996 Mdot
.72632 .06913 Mdot
.07427 .21505 Mdot
.31481 .14866 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.50649 .00275 Mdot
.52067 .00877 Mdot
.56578 .02788 Mdot
.70676 .08713 Mdot
.07772 .22927 Mdot
.33668 .16004 Mdot
.39144 .03384 Mdot
.2957 .55886 Mdot
.971 .41736 Mdot
.68956 .4441 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48052 .60977 Mdot
.43801 .59176 Mdot
.30484 .53573 Mdot
.94698 .39686 Mdot
.66718 .44511 Mdot
.59453 .57313 Mdot
.65546 .03766 Mdot
.91425 .15994 Mdot
.29552 .23564 Mdot
.49832 .61732 Mdot
.49464 .61576 Mdot
.48293 .61079 Mdot
.44565 .595 Mdot
.32843 .54559 Mdot
.00088 .4156 Mdot
.67201 .41478 Mdot
.55378 .54496 Mdot
.5147 .59388 Mdot
.49763 .60748 Mdot
.477 .60528 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50323 .00137 Mdot
.51028 .00436 Mdot
.53275 .01388 Mdot
.60398 .04403 Mdot
.82034 .13371 Mdot
.25248 .26708 Mdot
.44593 .11956 Mdot
.55982 .07039 Mdot
.76134 .12455 Mdot
.20099 .27172 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00467 Mdot
.53504 .01486 Mdot
.61123 .04708 Mdot
.841 .14201 Mdot
.27153 .26608 Mdot
.46552 .11989 Mdot
.60818 .08817 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46983 .60524 Mdot
.40414 .57744 Mdot
.2032 .49385 Mdot
.77378 .35264 Mdot
.58043 .49854 Mdot
.50265 .56996 Mdot
.42885 .57242 Mdot
.25183 .50863 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50749 .00317 Mdot
.52385 .01011 Mdot
.57585 .03214 Mdot
.73737 .09982 Mdot
.13687 .2469 Mdot
.35545 .13509 Mdot
.38581 .01876 Mdot
.25922 .53979 Mdot
.89429 .3925 Mdot
.67652 .48345 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.5076 .00322 Mdot
.5242 .01026 Mdot
.57697 .03261 Mdot
.74074 .10122 Mdot
.14284 .24851 Mdot
.35831 .13317 Mdot
.38822 .01849 Mdot
.26392 .54121 Mdot
.90179 .39423 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00123 Mdot
.50926 .00392 Mdot
.52948 .0125 Mdot
.59368 .03968 Mdot
.79042 .12159 Mdot
.21823 .2644 Mdot
.41205 .11979 Mdot
.48057 .04234 Mdot
.52001 .02437 Mdot
.58938 .04287 Mdot
.49825 .61729 Mdot
.49442 .61567 Mdot
.48223 .6105 Mdot
.44344 .59406 Mdot
.32158 .54272 Mdot
.98473 .40985 Mdot
.67075 .42399 Mdot
.56651 .55361 Mdot
.55917 .6135 Mdot
.63856 .04906 Mdot
.9005 .16189 Mdot
.49812 .61724 Mdot
.49401 .61549 Mdot
.48091 .60994 Mdot
.43924 .59228 Mdot
.30863 .53731 Mdot
.95529 .39966 Mdot
.66814 .44057 Mdot
.58884 .56902 Mdot
.63598 .02913 Mdot
.86317 .14041 Mdot
.27124 .2522 Mdot
.50006 2e-05 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00255 Mdot
.51913 .00811 Mdot
.56087 .0258 Mdot
.69171 .08086 Mdot
.04546 .21862 Mdot
.33194 .17706 Mdot
.41063 .04864 Mdot
.36221 .58811 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49067 .61408 Mdot
.47028 .60543 Mdot
.40558 .57805 Mdot
.20741 .49556 Mdot
.77901 .35327 Mdot
.58538 .49837 Mdot
.51377 .57378 Mdot
.4628 .58653 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48636 .61225 Mdot
.45656 .59962 Mdot
.3624 .55984 Mdot
.0866 .44758 Mdot
.68722 .3712 Mdot
.50824 .50742 Mdot
.34161 .51505 Mdot
.97472 .39128 Mdot
.64559 .41462 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50607 .00257 Mdot
.51934 .0082 Mdot
.56155 .02609 Mdot
.69381 .08174 Mdot
.05008 .22018 Mdot
.33246 .17452 Mdot
.40745 .04634 Mdot
.35129 .58333 Mdot
.10314 .46467 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50395 .00168 Mdot
.5126 .00534 Mdot
.54011 .01701 Mdot
.62716 .0538 Mdot
.8853 .15954 Mdot
.30098 .2569 Mdot
.49006 .11686 Mdot
.66425 .10765 Mdot
.04334 .23429 Mdot
.35823 .19461 Mdot
.49902 .61762 Mdot
.49689 .61672 Mdot
.4901 .61384 Mdot
.46847 .60467 Mdot
.39986 .57563 Mdot
.19075 .4888 Mdot
.75926 .35136 Mdot
.5661 .49865 Mdot
.46927 .55819 Mdot
.32663 .52988 Mdot
.97239 .3991 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51854 .00786 Mdot
.55902 .02501 Mdot
.686 .07848 Mdot
.03267 .21425 Mdot
.33068 .18418 Mdot
.41998 .05519 Mdot
.39425 .60213 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51726 .00732 Mdot
.55493 .02328 Mdot
.67337 .0732 Mdot
.0034 .20397 Mdot
.32833 .20082 Mdot
.44286 .07078 Mdot
.47352 .01895 Mdot
.46464 .61254 Mdot
.49803 .6172 Mdot
.49373 .61537 Mdot
.48002 .60956 Mdot
.43642 .59109 Mdot
.29997 .5337 Mdot
.93646 .39337 Mdot
.66575 .45073 Mdot
.60109 .57807 Mdot
.67808 .04758 Mdot
.96983 .18031 Mdot
.30657 .20811 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.52501 .0106 Mdot
.57951 .03369 Mdot
.7484 .10437 Mdot
.156 .25191 Mdot
.36531 .12936 Mdot
.39586 .01888 Mdot
.2811 .54711 Mdot
.93216 .40237 Mdot
.68192 .46338 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51464 .00621 Mdot
.5466 .01976 Mdot
.64748 .06234 Mdot
.93924 .18032 Mdot
.31995 .23529 Mdot
.48461 .10177 Mdot
.62621 .08752 Mdot
.9379 .19264 Mdot
.3404 .24876 Mdot
.50081 .00034 Mdot
.50258 .0011 Mdot
.50823 .00349 Mdot
.52621 .01111 Mdot
.58334 .0353 Mdot
.75983 .10908 Mdot
.1746 .25634 Mdot
.37693 .12505 Mdot
.41251 .02199 Mdot
.32338 .56294 Mdot
.02043 .4308 Mdot
.68692 .41192 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.47481 .60735 Mdot
.41991 .5841 Mdot
.24987 .51294 Mdot
.8411 .3654 Mdot
.63301 .48943 Mdot
.602 .59887 Mdot
.71374 .06906 Mdot
.05805 .21279 Mdot
.3172 .16016 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47767 .60857 Mdot
.42896 .58793 Mdot
.2772 .52424 Mdot
.89019 .37885 Mdot
.65513 .47276 Mdot
.61763 .59486 Mdot
.74095 .07622 Mdot
.10262 .22352 Mdot
.3208 .13484 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52373 .01006 Mdot
.57548 .03198 Mdot
.73625 .09936 Mdot
.13487 .24636 Mdot
.35454 .13576 Mdot
.38515 .01892 Mdot
.25805 .53948 Mdot
.89252 .39213 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50522 .00221 Mdot
.51662 .00705 Mdot
.55291 .02243 Mdot
.66712 .07058 Mdot
.98842 .19857 Mdot
.32707 .2093 Mdot
.45444 .07872 Mdot
.51441 .03706 Mdot
.59597 .0504 Mdot
.8129 .13408 Mdot
.49913 .61767 Mdot
.49724 .61686 Mdot
.4912 .6143 Mdot
.47195 .60614 Mdot
.41086 .58028 Mdot
.22293 .50189 Mdot
.79972 .35647 Mdot
.60368 .49688 Mdot
.5524 .58634 Mdot
.57831 .01601 Mdot
.71699 .08571 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50325 .00138 Mdot
.51036 .00439 Mdot
.53299 .01399 Mdot
.60476 .04436 Mdot
.82258 .13462 Mdot
.25473 .26708 Mdot
.44825 .1196 Mdot
.56551 .07247 Mdot
.77827 .13149 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49025 .6139 Mdot
.46895 .60487 Mdot
.40138 .57627 Mdot
.19517 .49059 Mdot
.76425 .35171 Mdot
.57111 .49867 Mdot
.48112 .56242 Mdot
.36286 .54495 Mdot
.06344 .43298 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.5061 .00259 Mdot
.51944 .00824 Mdot
.56186 .02622 Mdot
.69474 .08213 Mdot
.05211 .22087 Mdot
.3327 .17341 Mdot
.40608 .04535 Mdot
.3466 .58128 Mdot
.09104 .46009 Mdot
.70624 .38022 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00137 Mdot
.51027 .00435 Mdot
.5327 .01386 Mdot
.60384 .04397 Mdot
.81992 .13355 Mdot
.25207 .26708 Mdot
.4455 .11955 Mdot
.55877 .07 Mdot
.75819 .12325 Mdot
.19604 .2706 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.50649 .00275 Mdot
.52066 .00876 Mdot
.56574 .02786 Mdot
.70666 .08709 Mdot
.07752 .2292 Mdot
.33664 .16014 Mdot
.39153 .03393 Mdot
.29604 .55901 Mdot
.97172 .4176 Mdot
.6896 .44367 Mdot
.49816 .61726 Mdot
.49415 .61555 Mdot
.48136 .61013 Mdot
.44067 .59289 Mdot
.31302 .53914 Mdot
.96511 .40302 Mdot
.66912 .4351 Mdot
.58169 .564 Mdot
.61147 .01841 Mdot
.79513 .11351 Mdot
.20799 .25516 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51186 .00503 Mdot
.53778 .01602 Mdot
.61985 .05072 Mdot
.86517 .15162 Mdot
.2894 .26219 Mdot
.48217 .11914 Mdot
.64826 .10265 Mdot
.00594 .22106 Mdot
.35471 .21555 Mdot
.4982 .61727 Mdot
.49426 .6156 Mdot
.48172 .61028 Mdot
.4418 .59337 Mdot
.31653 .54061 Mdot
.97307 .40577 Mdot
.66982 .43061 Mdot
.57563 .55983 Mdot
.59068 .0093 Mdot
.7345 .08889 Mdot
.11592 .23573 Mdot
.4997 .61791 Mdot
.49903 .61762 Mdot
.49692 .61673 Mdot
.4902 .61388 Mdot
.46878 .6048 Mdot
.40083 .57604 Mdot
.19357 .48994 Mdot
.76243 .35157 Mdot
.56929 .49867 Mdot
.47684 .56089 Mdot
.34976 .5395 Mdot
.50067 .00028 Mdot
.50213 .00091 Mdot
.5068 .00288 Mdot
.52167 .00919 Mdot
.56893 .02921 Mdot
.71638 .09113 Mdot
.09726 .23539 Mdot
.34116 .15074 Mdot
.38443 .02674 Mdot
.2692 .54681 Mdot
.91696 .40034 Mdot
.68371 .47388 Mdot
.49794 .61716 Mdot
.49345 .61526 Mdot
.47913 .60918 Mdot
.43358 .58989 Mdot
.29129 .53009 Mdot
.91824 .38748 Mdot
.66251 .45998 Mdot
.61034 .58579 Mdot
.71075 .06205 Mdot
.04266 .20513 Mdot
.31135 .16605 Mdot
.49958 .61786 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.48657 .61234 Mdot
.45725 .59991 Mdot
.36457 .56075 Mdot
.09238 .44981 Mdot
.68928 .3689 Mdot
.50773 .50583 Mdot
.33778 .513 Mdot
.9645 .38733 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48016 .60962 Mdot
.43685 .59127 Mdot
.30129 .53425 Mdot
.93928 .3943 Mdot
.66616 .44924 Mdot
.59941 .57678 Mdot
.67226 .04503 Mdot
.95593 .17532 Mdot
.30486 .21565 Mdot
.49933 .61775 Mdot
.49786 .61713 Mdot
.49317 .61514 Mdot
.47825 .60881 Mdot
.4308 .58871 Mdot
.28279 .52656 Mdot
.9011 .38214 Mdot
.65839 .46803 Mdot
.61595 .5918 Mdot
.73246 .072 Mdot
.08624 .21865 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51218 .00516 Mdot
.53879 .01644 Mdot
.623 .05205 Mdot
.8739 .15506 Mdot
.29477 .26011 Mdot
.48628 .11836 Mdot
.49893 .61758 Mdot
.49658 .61658 Mdot
.4891 .61341 Mdot
.46528 .60331 Mdot
.3898 .57138 Mdot
.16191 .47719 Mdot
.73093 .35168 Mdot
.53697 .49816 Mdot
.39798 .53213 Mdot
.11623 .4439 Mdot
.67522 .34548 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.44212 .5935 Mdot
.31749 .54101 Mdot
.97529 .40654 Mdot
.67 .42936 Mdot
.57392 .55865 Mdot
.58476 .0067 Mdot
.71683 .08162 Mdot
.08246 .22597 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.5052 .00221 Mdot
.51658 .00703 Mdot
.55278 .02237 Mdot
.66672 .07042 Mdot
.98744 .19822 Mdot
.32698 .20985 Mdot
.45518 .07923 Mdot
.51702 .03822 Mdot
.60434 .05397 Mdot
.50003 1e-05 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.50841 .00357 Mdot
.52678 .01136 Mdot
.58515 .03607 Mdot
.76523 .1113 Mdot
.18295 .25817 Mdot
.38281 .12352 Mdot
.42235 .02444 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48762 .61279 Mdot
.46058 .60132 Mdot
.37503 .56516 Mdot
.12069 .46084 Mdot
.70217 .35938 Mdot
.5117 .50031 Mdot
.33875 .51114 Mdot
.96322 .38595 Mdot
.64238 .41974 Mdot
.49778 .61709 Mdot
.49293 .61504 Mdot
.47748 .60849 Mdot
.42836 .58768 Mdot
.27538 .52349 Mdot
.8867 .37781 Mdot
.65397 .4742 Mdot
.61782 .59569 Mdot
.7427 .07718 Mdot
.10607 .22457 Mdot
.32185 .13336 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52442 .01035 Mdot
.57766 .0329 Mdot
.74282 .10207 Mdot
.14647 .24947 Mdot
.36014 .13206 Mdot
.39 .01845 Mdot
.26769 .54244 Mdot
.90811 .3958 Mdot
.67884 .47634 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50341 .00145 Mdot
.51087 .00461 Mdot
.53463 .01468 Mdot
.60994 .04654 Mdot
.83734 .14054 Mdot
.26842 .26642 Mdot
.46237 .11987 Mdot
.60039 .0853 Mdot
.87922 .17232 Mdot
.32232 .27385 Mdot
.50071 .0003 Mdot
.50228 .00096 Mdot
.50725 .00307 Mdot
.52309 .00979 Mdot
.57346 .03113 Mdot
.73013 .09683 Mdot
.12368 .24323 Mdot
.34983 .13976 Mdot
.38268 .0203 Mdot
.25506 .53916 Mdot
.88884 .39169 Mdot
.67612 .48657 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50285 .00121 Mdot
.50909 .00385 Mdot
.52894 .01227 Mdot
.59197 .03895 Mdot
.7854 .11955 Mdot
.21169 .26346 Mdot
.40612 .12017 Mdot
.46776 .0381 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.5075 .00318 Mdot
.5239 .01013 Mdot
.576 .0322 Mdot
.73783 .10002 Mdot
.1377 .24713 Mdot
.35584 .13482 Mdot
.38611 .01871 Mdot
.25976 .53995 Mdot
.89513 .39268 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.5181 .00768 Mdot
.55762 .02442 Mdot
.68169 .07668 Mdot
.02284 .21084 Mdot
.32985 .18974 Mdot
.42754 .06038 Mdot
.42027 .61354 Mdot
.29834 .54268 Mdot
.9486 .40188 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48616 .61217 Mdot
.45594 .59935 Mdot
.36045 .55902 Mdot
.08146 .44561 Mdot
.68554 .37334 Mdot
.50904 .50895 Mdot
.3461 .51733 Mdot
.98665 .39588 Mdot
.6472 .40824 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52198 .00932 Mdot
.56992 .02963 Mdot
.71941 .09239 Mdot
.10324 .23722 Mdot
.34284 .14808 Mdot
.38319 .02494 Mdot
.26363 .54414 Mdot
.90622 .39714 Mdot
.49995 .61801 Mdot
.49984 .61796 Mdot
.49948 .61781 Mdot
.49833 .61733 Mdot
.49469 .61578 Mdot
.48309 .61086 Mdot
.44617 .59522 Mdot
.33003 .54626 Mdot
.00472 .41698 Mdot
.67233 .4126 Mdot
.5508 .54292 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47957 .60937 Mdot
.435 .59049 Mdot
.29563 .53189 Mdot
.92726 .39037 Mdot
.66424 .45548 Mdot
.60614 .58212 Mdot
.69569 .05535 Mdot
.01022 .19439 Mdot
.30943 .18492 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47778 .60861 Mdot
.42932 .58808 Mdot
.27828 .52469 Mdot
.89228 .37947 Mdot
.6558 .47188 Mdot
.61744 .59433 Mdot
.73968 .07555 Mdot
.10014 .22278 Mdot
.32012 .13595 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.48331 .61096 Mdot
.44686 .59551 Mdot
.33218 .54716 Mdot
.0099 .41885 Mdot
.67278 .40968 Mdot
.54683 .54019 Mdot
.49011 .58298 Mdot
.41858 .57382 Mdot
.23018 .5016 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51427 .00605 Mdot
.54543 .01926 Mdot
.64381 .0608 Mdot
.92973 .17671 Mdot
.31766 .23976 Mdot
.48812 .10535 Mdot
.64076 .09434 Mdot
.97808 .20847 Mdot
.49742 .61694 Mdot
.49177 .61454 Mdot
.47378 .60692 Mdot
.41665 .58272 Mdot
.24013 .50894 Mdot
.82534 .36168 Mdot
.62303 .493 Mdot
.58742 .59603 Mdot
.67644 .05502 Mdot
.97914 .18708 Mdot
.31304 .20637 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50272 .00115 Mdot
.50866 .00367 Mdot
.52759 .0117 Mdot
.5877 .03715 Mdot
.77279 .11439 Mdot
.19417 .26043 Mdot
.39136 .12187 Mdot
.43795 .02879 Mdot
.39381 .59075 Mdot
.20194 .49945 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47649 .60806 Mdot
.42522 .58635 Mdot
.26586 .51954 Mdot
.86894 .37273 Mdot
.64714 .48095 Mdot
.61593 .59874 Mdot
.74363 .07892 Mdot
.10987 .22635 Mdot
.32409 .13239 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48464 .61152 Mdot
.45109 .5973 Mdot
.34532 .55267 Mdot
.04238 .4308 Mdot
.67661 .39198 Mdot
.52465 .52412 Mdot
.40952 .54688 Mdot
.16586 .46745 Mdot
.71606 .34004 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.50729 .00309 Mdot
.52323 .00985 Mdot
.57389 .03131 Mdot
.73146 .09738 Mdot
.12614 .24392 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47736 .60843 Mdot
.42798 .58752 Mdot
.27422 .52301 Mdot
.88449 .37717 Mdot
.65321 .47509 Mdot
.61785 .59618 Mdot
.74356 .07769 Mdot
.1078 .22511 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.5067 .00284 Mdot
.52134 .00905 Mdot
.56789 .02877 Mdot
.71322 .08982 Mdot
.09093 .23344 Mdot
.33955 .15365 Mdot
.38623 .02885 Mdot
.27644 .55017 Mdot
.93119 .40466 Mdot
.68597 .46648 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.5061 .00259 Mdot
.51944 .00824 Mdot
.56186 .02622 Mdot
.69474 .08213 Mdot
.05212 .22087 Mdot
.33271 .17341 Mdot
.40607 .04534 Mdot
.34659 .58127 Mdot
.09101 .46008 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.52591 .01098 Mdot
.58237 .0349 Mdot
.75694 .10789 Mdot
.17002 .2553 Mdot
.37388 .12599 Mdot
.40775 .02093 Mdot
.31086 .55815 Mdot
.99247 .42126 Mdot
.68538 .42824 Mdot
.49789 .61714 Mdot
.49328 .61519 Mdot
.4786 .60896 Mdot
.43193 .58919 Mdot
.28622 .52798 Mdot
.90794 .38424 Mdot
.66018 .46491 Mdot
.61412 .58957 Mdot
.72495 .0685 Mdot
.07156 .21422 Mdot
.31441 .15009 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.5054 .00229 Mdot
.51719 .00729 Mdot
.55473 .0232 Mdot
.67276 .07294 Mdot
.00194 .20345 Mdot
.32822 .20165 Mdot
.44401 .07156 Mdot
.47754 .02072 Mdot
.47749 .618 Mdot
.4438 .59721 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.52659 .01127 Mdot
.58452 .03581 Mdot
.76337 .11053 Mdot
.18011 .25756 Mdot
.38077 .12401 Mdot
.41884 .02353 Mdot
.34037 .56954 Mdot
.06064 .44515 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48837 .6131 Mdot
.46295 .60233 Mdot
.38247 .56829 Mdot
.1413 .46898 Mdot
.71494 .35453 Mdot
.52154 .49851 Mdot
.36036 .51842 Mdot
.01558 .40495 Mdot
.64747 .39052 Mdot
.49824 .61729 Mdot
.4944 .61566 Mdot
.48217 .61048 Mdot
.44326 .59398 Mdot
.32103 .54249 Mdot
.98346 .4094 Mdot
.67065 .42471 Mdot
.56751 .55429 Mdot
.56264 .61502 Mdot
.64931 .05356 Mdot
.9285 .17255 Mdot
.49898 .6176 Mdot
.49675 .61665 Mdot
.48963 .61364 Mdot
.46697 .60403 Mdot
.39513 .57363 Mdot
.17713 .4833 Mdot
.74498 .35095 Mdot
.55145 .49842 Mdot
.43375 .54529 Mdot
.21951 .48563 Mdot
.77091 .34078 Mdot
.49746 .61696 Mdot
.49189 .6146 Mdot
.47418 .60709 Mdot
.41791 .58326 Mdot
.24389 .51048 Mdot
.83131 .36305 Mdot
.62698 .49175 Mdot
.59355 .59737 Mdot
.6925 .06115 Mdot
.01477 .19917 Mdot
.31492 .1855 Mdot
.4997 .61791 Mdot
.49904 .61763 Mdot
.49693 .61673 Mdot
.49023 .61389 Mdot
.46887 .60483 Mdot
.40112 .57616 Mdot
.19439 .49027 Mdot
.76336 .35164 Mdot
.57023 .49867 Mdot
.47904 .56168 Mdot
.3565 .5423 Mdot
.5007 .0003 Mdot
.50223 .00095 Mdot
.50712 .00302 Mdot
.52268 .00962 Mdot
.57214 .03057 Mdot
.72614 .09518 Mdot
.1162 .24107 Mdot
.34703 .14267 Mdot
.38215 .0217 Mdot
.25622 .5402 Mdot
.89173 .39277 Mdot
.67741 .48558 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50295 .00125 Mdot
.5094 .00399 Mdot
.52994 .0127 Mdot
.59514 .04029 Mdot
.79468 .12333 Mdot
.22362 .2651 Mdot
.41709 .11957 Mdot
.49175 .04614 Mdot
.55404 .0385 Mdot
.69583 .08763 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51388 .00589 Mdot
.54421 .01874 Mdot
.64 .0592 Mdot
.91975 .17289 Mdot
.31483 .24418 Mdot
.49072 .1087 Mdot
.6527 .10011 Mdot
.49908 .61765 Mdot
.49708 .6168 Mdot
.49069 .61409 Mdot
.47035 .60546 Mdot
.4058 .57814 Mdot
.20805 .49582 Mdot
.77981 .35337 Mdot
.58613 .49833 Mdot
.51543 .57434 Mdot
.46783 .58862 Mdot
.3723 .55899 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51823 .00773 Mdot
.55803 .0246 Mdot
.68296 .07721 Mdot
.02574 .21185 Mdot
.33008 .18809 Mdot
.42528 .05884 Mdot
.41248 .61012 Mdot
.27492 .53302 Mdot
.90154 .38728 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49817 .61726 Mdot
.49416 .61556 Mdot
.4814 .61015 Mdot
.44079 .59294 Mdot
.31342 .53931 Mdot
.96601 .40333 Mdot
.6692 .43459 Mdot
.58101 .56353 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00314 Mdot
.52355 .00999 Mdot
.57492 .03174 Mdot
.73456 .09866 Mdot
.13181 .24551 Mdot
.35318 .13682 Mdot
.38427 .01921 Mdot
.25665 .53916 Mdot
.8905 .39174 Mdot
.67595 .48543 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49024 .6139 Mdot
.46893 .60486 Mdot
.4013 .57624 Mdot
.19493 .49049 Mdot
.76398 .35169 Mdot
.57083 .49867 Mdot
.48047 .56219 Mdot
.36089 .54413 Mdot
.05822 .43097 Mdot
.49832 .61732 Mdot
.49463 .61576 Mdot
.4829 .61078 Mdot
.44558 .59497 Mdot
.32821 .54549 Mdot
.00036 .41541 Mdot
.67197 .41508 Mdot
.55419 .54524 Mdot
.51613 .59451 Mdot
.50223 .60944 Mdot
.49166 .6115 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49627 .61645 Mdot
.48812 .613 Mdot
.46217 .60199 Mdot
.37999 .56725 Mdot
.13439 .46624 Mdot
.71032 .35594 Mdot
.5176 .49892 Mdot
.35121 .5152 Mdot
.99276 .3965 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51225 .0052 Mdot
.53902 .01654 Mdot
.62374 .05236 Mdot
.87591 .15585 Mdot
.29593 .25958 Mdot
.48708 .11814 Mdot
.65889 .10618 Mdot
.03136 .2302 Mdot
.3571 .20132 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51684 .00714 Mdot
.55361 .02273 Mdot
.66929 .07149 Mdot
.99366 .20047 Mdot
.32754 .20635 Mdot
.45045 .07597 Mdot
.50024 .03077 Mdot
.55039 .03099 Mdot
.67485 .07693 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51668 .00707 Mdot
.55309 .02251 Mdot
.66768 .07082 Mdot
.98976 .19906 Mdot
.32719 .20854 Mdot
.45343 .07802 Mdot
.5108 .03546 Mdot
.58435 .04546 Mdot
.77857 .12004 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51623 .00688 Mdot
.55168 .02191 Mdot
.66329 .06898 Mdot
.97907 .19516 Mdot
.32615 .21451 Mdot
.46132 .08354 Mdot
.53903 .04803 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47949 .60934 Mdot
.43472 .59037 Mdot
.29477 .53154 Mdot
.92546 .38979 Mdot
.66392 .45639 Mdot
.60704 .58288 Mdot
.69888 .05676 Mdot
.01724 .19676 Mdot
.30979 .18081 Mdot
.50054 .00023 Mdot
.50173 .00074 Mdot
.50552 .00234 Mdot
.5176 .00746 Mdot
.55602 .02375 Mdot
.67675 .07461 Mdot
.01136 .2068 Mdot
.32895 .19628 Mdot
.43658 .06652 Mdot
.45158 .00927 Mdot
.39507 .58311 Mdot
.19232 .49273 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53634 .01541 Mdot
.61529 .0488 Mdot
.85246 .14657 Mdot
.28057 .26459 Mdot
.47434 .11976 Mdot
.62979 .09607 Mdot
.95905 .20349 Mdot
.34906 .24104 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00147 Mdot
.51107 .0047 Mdot
.53527 .01495 Mdot
.61193 .04738 Mdot
.84299 .1428 Mdot
.27318 .26587 Mdot
.46716 .11989 Mdot
.61223 .08966 Mdot
.91203 .18529 Mdot
.33717 .26275 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42914 .58801 Mdot
.27773 .52446 Mdot
.89121 .37915 Mdot
.65546 .47233 Mdot
.61754 .5946 Mdot
.74035 .0759 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50817 .00346 Mdot
.52602 .01103 Mdot
.58273 .03505 Mdot
.75802 .10833 Mdot
.17173 .25569 Mdot
.37501 .12563 Mdot
.40948 .02131 Mdot
.31538 .55988 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52605 .01105 Mdot
.58283 .03509 Mdot
.75831 .10846 Mdot
.17221 .2558 Mdot
.37532 .12553 Mdot
.40997 .02141 Mdot
.31666 .56037 Mdot
.49949 .61782 Mdot
.49836 .61734 Mdot
.49477 .61582 Mdot
.48335 .61097 Mdot
.44699 .59556 Mdot
.33259 .54733 Mdot
.01087 .4192 Mdot
.67286 .40913 Mdot
.54609 .53968 Mdot
.4875 .58182 Mdot
.41016 .57024 Mdot
.4997 .61791 Mdot
.49905 .61763 Mdot
.49696 .61675 Mdot
.49032 .61393 Mdot
.46915 .60496 Mdot
.40201 .57654 Mdot
.197 .49133 Mdot
.76637 .35189 Mdot
.57321 .49866 Mdot
.48603 .56415 Mdot
.37792 .55122 Mdot
.49793 .61716 Mdot
.4934 .61523 Mdot
.47896 .60911 Mdot
.43307 .58967 Mdot
.28972 .52944 Mdot
.91503 .38646 Mdot
.66183 .46155 Mdot
.61165 .58702 Mdot
.71554 .06421 Mdot
.05259 .20831 Mdot
.31218 .16044 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50655 .00278 Mdot
.52088 .00885 Mdot
.56644 .02816 Mdot
.70879 .08798 Mdot
.08192 .23061 Mdot
.33752 .15797 Mdot
.38959 .03218 Mdot
.289 .55587 Mdot
.95682 .41273 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50378 .0016 Mdot
.51204 .00511 Mdot
.53835 .01626 Mdot
.62163 .05147 Mdot
.87009 .15356 Mdot
.29249 .26106 Mdot
.48462 .11874 Mdot
.65372 .10451 Mdot
.01918 .22587 Mdot
.35594 .20813 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52226 .00944 Mdot
.57081 .03001 Mdot
.7221 .09351 Mdot
.10847 .23879 Mdot
.34444 .14584 Mdot
.38249 .02351 Mdot
.25985 .54224 Mdot
.89893 .39498 Mdot
.67963 .4825 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51494 .00633 Mdot
.54756 .02016 Mdot
.65047 .0636 Mdot
.94694 .18322 Mdot
.32153 .23151 Mdot
.4811 .09862 Mdot
.61238 .08114 Mdot
.89857 .17688 Mdot
.32681 .26467 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.5047 .002 Mdot
.51499 .00636 Mdot
.54772 .02023 Mdot
.65098 .06381 Mdot
.94823 .18371 Mdot
.32177 .23086 Mdot
.48045 .09807 Mdot
.60988 .07999 Mdot
.89135 .17396 Mdot
.32342 .26704 Mdot
.49862 .61745 Mdot
.49559 .61616 Mdot
.48595 .61208 Mdot
.45526 .59907 Mdot
.35834 .55813 Mdot
.07588 .44347 Mdot
.68387 .37576 Mdot
.51028 .51075 Mdot
.35209 .52027 Mdot
.00262 .40205 Mdot
.64922 .39962 Mdot
.50078 .00033 Mdot
.5025 .00106 Mdot
.50796 .00338 Mdot
.52537 .01076 Mdot
.58066 .03417 Mdot
.75183 .10579 Mdot
.16172 .25332 Mdot
.36867 .1279 Mdot
.40023 .0195 Mdot
.29174 .55099 Mdot
.95269 .40849 Mdot
.68356 .4517 Mdot
.49981 .61795 Mdot
.49938 .61777 Mdot
.49802 .6172 Mdot
.49371 .61537 Mdot
.47995 .60953 Mdot
.43621 .591 Mdot
.29932 .53343 Mdot
.93507 .39291 Mdot
.66554 .45145 Mdot
.6019 .5787 Mdot
.68087 .04881 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51726 .00732 Mdot
.55494 .02329 Mdot
.67342 .07322 Mdot
.00351 .20401 Mdot
.32834 .20075 Mdot
.44278 .07073 Mdot
.47321 .01881 Mdot
.46366 .61213 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50513 .00218 Mdot
.51634 .00693 Mdot
.55203 .02206 Mdot
.66439 .06944 Mdot
.98176 .19615 Mdot
.32643 .21302 Mdot
.45938 .08216 Mdot
.53204 .04491 Mdot
.65244 .07441 Mdot
.9681 .19509 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48645 .61229 Mdot
.45685 .59974 Mdot
.36333 .56023 Mdot
.08907 .44854 Mdot
.68808 .3702 Mdot
.50797 .50672 Mdot
.33981 .51411 Mdot
.96993 .38944 Mdot
.64489 .41714 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.52501 .0106 Mdot
.57953 .03369 Mdot
.74844 .10439 Mdot
.15606 .25193 Mdot
.36535 .12934 Mdot
.39591 .01888 Mdot
.28122 .54715 Mdot
.93237 .40244 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51541 .00653 Mdot
.54905 .02079 Mdot
.65512 .06555 Mdot
.95873 .18764 Mdot
.32356 .22548 Mdot
.4747 .09341 Mdot
.58805 .07005 Mdot
.82683 .14758 Mdot
.27706 .27826 Mdot
.49883 .61754 Mdot
.49626 .61645 Mdot
.48808 .61298 Mdot
.46203 .60194 Mdot
.37957 .56707 Mdot
.13321 .46578 Mdot
.70957 .3562 Mdot
.51699 .49901 Mdot
.34984 .51473 Mdot
.98941 .39528 Mdot
.64486 .40508 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43731 .59146 Mdot
.30269 .53484 Mdot
.94231 .39531 Mdot
.66658 .44762 Mdot
.59753 .57536 Mdot
.66579 .04219 Mdot
.94013 .16955 Mdot
.30217 .22376 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50531 .00225 Mdot
.51692 .00717 Mdot
.55386 .02283 Mdot
.67004 .07181 Mdot
.99546 .20112 Mdot
.32769 .20533 Mdot
.44906 .07501 Mdot
.49533 .02859 Mdot
.53459 .02426 Mdot
.62532 .05607 Mdot
.49777 .61709 Mdot
.49288 .61502 Mdot
.47733 .60842 Mdot
.4279 .58748 Mdot
.27396 .5229 Mdot
.884 .37702 Mdot
.65304 .47529 Mdot
.61785 .59629 Mdot
.74372 .07779 Mdot
.10814 .22522 Mdot
.32254 .13251 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00156 Mdot
.5117 .00496 Mdot
.53727 .0158 Mdot
.61824 .05004 Mdot
.8607 .14985 Mdot
.28643 .26312 Mdot
.47966 .11942 Mdot
.64247 .10062 Mdot
.99157 .21575 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50288 .00122 Mdot
.50916 .00388 Mdot
.52918 .01237 Mdot
.59273 .03928 Mdot
.78764 .12046 Mdot
.21464 .2639 Mdot
.40877 .11998 Mdot
.47343 .03996 Mdot
.49842 .01545 Mdot
.52105 .01398 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48769 .61281 Mdot
.46079 .60141 Mdot
.37566 .56542 Mdot
.12243 .46153 Mdot
.70314 .3589 Mdot
.5123 .50009 Mdot
.3399 .51148 Mdot
.96585 .38686 Mdot
.64263 .41828 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51454 .00616 Mdot
.54628 .01962 Mdot
.64647 .06192 Mdot
.93665 .17934 Mdot
.31936 .23653 Mdot
.48566 .10278 Mdot
.63046 .0895 Mdot
.49825 .61729 Mdot
.49442 .61567 Mdot
.48223 .6105 Mdot
.44345 .59406 Mdot
.3216 .54273 Mdot
.98478 .40987 Mdot
.67075 .42396 Mdot
.56648 .55359 Mdot
.55904 .61344 Mdot
.63814 .04889 Mdot
.89938 .16146 Mdot
.49857 .61743 Mdot
.49546 .61611 Mdot
.48553 .6119 Mdot
.45394 .59851 Mdot
.3542 .5564 Mdot
.0651 .43936 Mdot
.68105 .38068 Mdot
.51367 .51459 Mdot
.36679 .52725 Mdot
.04261 .41768 Mdot
.65528 .37865 Mdot
.49823 .61728 Mdot
.49437 .61565 Mdot
.48206 .61043 Mdot
.44289 .59383 Mdot
.31988 .54201 Mdot
.98078 .40846 Mdot
.67044 .42623 Mdot
.56962 .55573 Mdot
.56995 .0002 Mdot
.67184 .06297 Mdot
.98426 .19308 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50676 .00287 Mdot
.52154 .00914 Mdot
.56854 .02905 Mdot
.7152 .09064 Mdot
.09491 .23467 Mdot
.34054 .15181 Mdot
.38505 .0275 Mdot
.27172 .548 Mdot
.92189 .40182 Mdot
.68457 .47137 Mdot
.49969 .6179 Mdot
.49901 .61762 Mdot
.49686 .6167 Mdot
.48999 .61379 Mdot
.46811 .60451 Mdot
.39873 .57515 Mdot
.18747 .48747 Mdot
.75567 .35117 Mdot
.56246 .49862 Mdot
.46054 .55505 Mdot
.30004 .51884 Mdot
.49901 .61761 Mdot
.49684 .61669 Mdot
.48994 .61377 Mdot
.46796 .60445 Mdot
.39823 .57494 Mdot
.18604 .48689 Mdot
.75414 .3511 Mdot
.56089 .4986 Mdot
.45676 .55368 Mdot
.28856 .51408 Mdot
.88861 .37085 Mdot
.49939 .61777 Mdot
.49805 .61721 Mdot
.49379 .6154 Mdot
.4802 .60964 Mdot
.437 .59133 Mdot
.30174 .53444 Mdot
.94025 .39462 Mdot
.6663 .44872 Mdot
.59882 .57633 Mdot
.67022 .04413 Mdot
.95098 .17352 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47989 .60951 Mdot
.43601 .59091 Mdot
.2987 .53317 Mdot
.93374 .39248 Mdot
.66533 .45215 Mdot
.60265 .5793 Mdot
.6835 .04997 Mdot
.98255 .18482 Mdot
.30772 .20096 Mdot
.49845 .61738 Mdot
.49505 .61594 Mdot
.48424 .61135 Mdot
.44983 .59677 Mdot
.34141 .55102 Mdot
.03255 .42715 Mdot
.67521 .39719 Mdot
.53072 .52874 Mdot
.43204 .55704 Mdot
.23447 .49593 Mdot
.79932 .34909 Mdot
.49914 .61767 Mdot
.49725 .61687 Mdot
.49124 .61432 Mdot
.47208 .6062 Mdot
.41127 .58045 Mdot
.22416 .50239 Mdot
.80146 .35679 Mdot
.60511 .49669 Mdot
.55523 .5872 Mdot
.58653 .01935 Mdot
.74134 .09567 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50704 .00299 Mdot
.52243 .00951 Mdot
.57134 .03023 Mdot
.72372 .09417 Mdot
.11158 .23971 Mdot
.34545 .14454 Mdot
.38225 .02274 Mdot
.2581 .5413 Mdot
.89552 .39395 Mdot
.67865 .484 Mdot
.50004 1e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51155 .0049 Mdot
.5368 .0156 Mdot
.61675 .04941 Mdot
.85653 .1482 Mdot
.28354 .2639 Mdot
.47709 .11962 Mdot
.63638 .09845 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48268 .61069 Mdot
.44487 .59467 Mdot
.32601 .54458 Mdot
.99514 .41354 Mdot
.67155 .41805 Mdot
.55829 .54803 Mdot
.53051 .60087 Mdot
.54823 .01095 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47812 .60876 Mdot
.43039 .58854 Mdot
.28155 .52605 Mdot
.89865 .38139 Mdot
.65771 .46912 Mdot
.61647 .59255 Mdot
.73475 .0731 Mdot
.09066 .21997 Mdot
.31782 .14039 Mdot
.49881 .61753 Mdot
.49621 .61642 Mdot
.48791 .61291 Mdot
.4615 .60171 Mdot
.37789 .56636 Mdot
.12856 .46394 Mdot
.70669 .3573 Mdot
.51477 .49942 Mdot
.34497 .51309 Mdot
.97769 .39104 Mdot
.64377 .41166 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.5124 .00526 Mdot
.53949 .01674 Mdot
.6252 .05297 Mdot
.87993 .15743 Mdot
.29816 .25848 Mdot
.48851 .11764 Mdot
.66163 .107 Mdot
.03762 .23238 Mdot
.3577 .19782 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47982 .60948 Mdot
.43578 .59082 Mdot
.29802 .53289 Mdot
.9323 .39201 Mdot
.6651 .45289 Mdot
.60346 .57994 Mdot
.68631 .0512 Mdot
.98902 .18709 Mdot
.30819 .19726 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52448 .01038 Mdot
.57786 .03299 Mdot
.74344 .10233 Mdot
.14754 .24975 Mdot
.3607 .13174 Mdot
.39057 .01846 Mdot
.26894 .54286 Mdot
.91026 .39636 Mdot
.67917 .47522 Mdot
.49977 .61794 Mdot
.49927 .61772 Mdot
.49766 .61704 Mdot
.49254 .61487 Mdot
.47624 .60796 Mdot
.42444 .58602 Mdot
.26349 .51857 Mdot
.86468 .37155 Mdot
.64526 .48242 Mdot
.61471 .59915 Mdot
.7417 .07849 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58507 .03604 Mdot
.765 .1112 Mdot
.1826 .25809 Mdot
.38256 .12358 Mdot
.42191 .02432 Mdot
.34877 .57283 Mdot
.08141 .4528 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50896 .0038 Mdot
.52855 .01211 Mdot
.59073 .03843 Mdot
.78176 .11806 Mdot
.20678 .26268 Mdot
.40182 .12054 Mdot
.45875 .03519 Mdot
.4545 .61541 Mdot
.49888 .61756 Mdot
.49644 .61652 Mdot
.48866 .61322 Mdot
.46388 .60272 Mdot
.38538 .56952 Mdot
.14943 .47221 Mdot
.72085 .35315 Mdot
.527 .49823 Mdot
.37346 .52314 Mdot
.04949 .41781 Mdot
.65247 .37267 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.4833 .61095 Mdot
.44685 .59551 Mdot
.33215 .54715 Mdot
.00983 .41883 Mdot
.67277 .40972 Mdot
.54688 .54023 Mdot
.49031 .58307 Mdot
.4192 .57409 Mdot
.23204 .50236 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43732 .59147 Mdot
.30271 .53485 Mdot
.94235 .39532 Mdot
.66659 .4476 Mdot
.5975 .57534 Mdot
.6657 .04215 Mdot
.93992 .16947 Mdot
.30213 .22386 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.48061 .60981 Mdot
.43829 .59188 Mdot
.30571 .53609 Mdot
.94886 .39749 Mdot
.66741 .44409 Mdot
.59327 .57221 Mdot
.65116 .03578 Mdot
.90319 .15577 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47646 .60805 Mdot
.42513 .58631 Mdot
.26559 .51943 Mdot
.86847 .3726 Mdot
.64694 .48112 Mdot
.61581 .59879 Mdot
.74346 .07889 Mdot
.10964 .22631 Mdot
.32407 .13252 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47458 .60726 Mdot
.41919 .5838 Mdot
.24771 .51205 Mdot
.83752 .36452 Mdot
.63087 .49032 Mdot
.59914 .59842 Mdot
.70669 .06647 Mdot
.04419 .20858 Mdot
.31625 .16815 Mdot
.49856 .61743 Mdot
.49542 .61609 Mdot
.48542 .61185 Mdot
.45359 .59836 Mdot
.35312 .55594 Mdot
.06229 .43829 Mdot
.6804 .38201 Mdot
.51477 .51567 Mdot
.37126 .52934 Mdot
.05502 .42259 Mdot
.65788 .37259 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52372 .01006 Mdot
.57544 .03197 Mdot
.73614 .09932 Mdot
.13467 .2463 Mdot
.35445 .13583 Mdot
.38509 .01894 Mdot
.25795 .53946 Mdot
.89237 .3921 Mdot
.67621 .48444 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.51319 .00559 Mdot
.54199 .0178 Mdot
.63305 .05628 Mdot
.90124 .16575 Mdot
.30824 .25154 Mdot
.49232 .11377 Mdot
.66489 .10665 Mdot
.04287 .2336 Mdot
.35732 .19434 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50746 .00316 Mdot
.52377 .01008 Mdot
.57561 .03204 Mdot
.73665 .09953 Mdot
.13559 .24655 Mdot
.35486 .13552 Mdot
.38538 .01886 Mdot
.25845 .53959 Mdot
.89312 .39225 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47887 .60907 Mdot
.43277 .58954 Mdot
.28879 .52905 Mdot
.91314 .38587 Mdot
.66141 .46245 Mdot
.61236 .58772 Mdot
.7182 .06541 Mdot
.05803 .21002 Mdot
.31273 .15741 Mdot
.5004 .00017 Mdot
.50126 .00054 Mdot
.50402 .00171 Mdot
.51281 .00543 Mdot
.54081 .0173 Mdot
.62934 .05472 Mdot
.89123 .16186 Mdot
.30387 .25502 Mdot
.49131 .11585 Mdot
.66573 .1078 Mdot
.04618 .23514 Mdot
.35833 .19292 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48497 .61166 Mdot
.45213 .59774 Mdot
.34858 .55403 Mdot
.05063 .4339 Mdot
.67802 .38774 Mdot
.52012 .52045 Mdot
.39234 .53906 Mdot
.1151 .44669 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00156 Mdot
.5117 .00496 Mdot
.53727 .0158 Mdot
.61823 .05004 Mdot
.86067 .14984 Mdot
.28641 .26312 Mdot
.47965 .11942 Mdot
.64243 .10061 Mdot
.99147 .21572 Mdot
.3533 .22362 Mdot
.50014 6e-05 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.5044 .00186 Mdot
.51401 .00594 Mdot
.54461 .01891 Mdot
.64126 .05973 Mdot
.92304 .17415 Mdot
.31582 .24275 Mdot
.48999 .10764 Mdot
.64916 .09837 Mdot
.00071 .21727 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47318 .60666 Mdot
.41475 .58192 Mdot
.23448 .50662 Mdot
.8166 .35977 Mdot
.61686 .49459 Mdot
.57708 .59345 Mdot
.64846 .04411 Mdot
.9116 .16263 Mdot
.49906 .61764 Mdot
.49702 .61677 Mdot
.49049 .614 Mdot
.46972 .6052 Mdot
.40381 .5773 Mdot
.20223 .49345 Mdot
.7726 .3525 Mdot
.57929 .49856 Mdot
.50007 .56907 Mdot
.42094 .56913 Mdot
.22803 .49881 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49084 .61415 Mdot
.47081 .60566 Mdot
.40725 .57875 Mdot
.21231 .49755 Mdot
.7853 .35413 Mdot
.59117 .49806 Mdot
.52644 .57803 Mdot
.50119 .60243 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00248 Mdot
.51867 .00791 Mdot
.55941 .02518 Mdot
.6872 .07898 Mdot
.03538 .21519 Mdot
.33093 .18266 Mdot
.41795 .05378 Mdot
.38726 .59907 Mdot
.20126 .50308 Mdot
.78764 .3624 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.4851 .61171 Mdot
.45255 .59792 Mdot
.34987 .55458 Mdot
.05394 .43514 Mdot
.67864 .38609 Mdot
.51848 .51905 Mdot
.38597 .53614 Mdot
.09667 .43924 Mdot
.67112 .35503 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49267 .61493 Mdot
.47667 .60814 Mdot
.42578 .58658 Mdot
.26755 .52024 Mdot
.87204 .3736 Mdot
.64845 .47985 Mdot
.61662 .59836 Mdot
.74448 .07902 Mdot
.11094 .22648 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52613 .01108 Mdot
.58307 .03519 Mdot
.75904 .10875 Mdot
.17336 .25606 Mdot
.37609 .1253 Mdot
.41118 .02168 Mdot
.31984 .56158 Mdot
.01239 .42802 Mdot
.68637 .41655 Mdot
.49838 .61735 Mdot
.49485 .61585 Mdot
.4836 .61108 Mdot
.44779 .5959 Mdot
.33505 .54836 Mdot
.01686 .42138 Mdot
.67343 .40578 Mdot
.54163 .53658 Mdot
.47157 .57473 Mdot
.35909 .54852 Mdot
.06179 .43429 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50895 .0038 Mdot
.52851 .01209 Mdot
.59062 .03838 Mdot
.78142 .11792 Mdot
.20632 .2626 Mdot
.40142 .12058 Mdot
.45792 .03492 Mdot
.45204 .6144 Mdot
.37531 .57061 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42795 .5875 Mdot
.27414 .52297 Mdot
.88433 .37712 Mdot
.65315 .47516 Mdot
.61785 .59622 Mdot
.74361 .07772 Mdot
.10791 .22515 Mdot
.32246 .1326 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50507 .00215 Mdot
.51616 .00685 Mdot
.55145 .02181 Mdot
.66257 .06868 Mdot
.97729 .19451 Mdot
.32596 .21549 Mdot
.46259 .08444 Mdot
.5436 .05007 Mdot
.68921 .08999 Mdot
.05634 .2269 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47663 .60813 Mdot
.42567 .58654 Mdot
.26723 .52011 Mdot
.87146 .37343 Mdot
.64821 .48006 Mdot
.6165 .59844 Mdot
.74436 .07902 Mdot
.11079 .22647 Mdot
.32414 .13186 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48837 .6131 Mdot
.46296 .60233 Mdot
.38249 .5683 Mdot
.14133 .46899 Mdot
.71496 .35452 Mdot
.52156 .49851 Mdot
.36041 .51844 Mdot
.0157 .40499 Mdot
.64748 .39046 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47423 .60711 Mdot
.41805 .58332 Mdot
.24432 .51066 Mdot
.83201 .36321 Mdot
.62743 .4916 Mdot
.59422 .59751 Mdot
.69423 .06181 Mdot
.01847 .20039 Mdot
.31506 .18331 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50468 .00198 Mdot
.51491 .00632 Mdot
.54748 .02013 Mdot
.65021 .06349 Mdot
.94627 .18297 Mdot
.3214 .23184 Mdot
.48142 .0989 Mdot
.61364 .08172 Mdot
.9022 .17834 Mdot
.3284 .26341 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51787 .00758 Mdot
.55689 .02411 Mdot
.67943 .07574 Mdot
.01763 .20902 Mdot
.32943 .19271 Mdot
.43163 .06316 Mdot
.43439 .00171 Mdot
.3415 .56062 Mdot
.04825 .4368 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.49131 .61435 Mdot
.47233 .6063 Mdot
.41205 .58078 Mdot
.22646 .50333 Mdot
.80475 .3574 Mdot
.60778 .4963 Mdot
.5604 .58875 Mdot
.60148 .02538 Mdot
.78466 .11321 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.4877 .61282 Mdot
.46084 .60143 Mdot
.37584 .5655 Mdot
.12292 .46172 Mdot
.70341 .35876 Mdot
.51248 .50003 Mdot
.34025 .51159 Mdot
.96665 .38714 Mdot
.64271 .41783 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.48078 .60989 Mdot
.43884 .59211 Mdot
.3074 .5368 Mdot
.9526 .39875 Mdot
.66785 .44205 Mdot
.59073 .57037 Mdot
.64244 .03196 Mdot
.88041 .14707 Mdot
.28136 .2478 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50387 .00164 Mdot
.51234 .00523 Mdot
.53929 .01666 Mdot
.62459 .05272 Mdot
.87827 .15678 Mdot
.29725 .25894 Mdot
.48795 .11786 Mdot
.66058 .10669 Mdot
.03525 .23156 Mdot
.35747 .19915 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51646 .00698 Mdot
.55241 .02222 Mdot
.66557 .06994 Mdot
.98466 .1972 Mdot
.32672 .21141 Mdot
.45725 .08067 Mdot
.52443 .04152 Mdot
.62811 .06408 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50599 .00254 Mdot
.51909 .0081 Mdot
.56076 .02575 Mdot
.69136 .08072 Mdot
.04467 .21836 Mdot
.33185 .17749 Mdot
.41119 .04903 Mdot
.36411 .58894 Mdot
.13707 .47772 Mdot
.72892 .36578 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48645 .61229 Mdot
.45686 .59974 Mdot
.36333 .56023 Mdot
.0891 .44854 Mdot
.68808 .3702 Mdot
.50797 .50672 Mdot
.3398 .5141 Mdot
.9699 .38942 Mdot
.49816 .61725 Mdot
.49412 .61554 Mdot
.48127 .61009 Mdot
.4404 .59277 Mdot
.31221 .53881 Mdot
.96329 .40239 Mdot
.66895 .43612 Mdot
.58304 .56494 Mdot
.61613 .02045 Mdot
.80837 .11881 Mdot
.22346 .25654 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.48692 .61249 Mdot
.45834 .60037 Mdot
.36798 .56219 Mdot
.10154 .45336 Mdot
.69291 .36549 Mdot
.50782 .50364 Mdot
.33446 .51089 Mdot
.9552 .38364 Mdot
.64226 .42463 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.51958 .0083 Mdot
.5623 .02641 Mdot
.69612 .0827 Mdot
.05512 .22187 Mdot
.33308 .17179 Mdot
.40411 .0439 Mdot
.33985 .57832 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52529 .01072 Mdot
.58041 .03407 Mdot
.75108 .10548 Mdot
.16047 .25302 Mdot
.36792 .12821 Mdot
.39922 .01934 Mdot
.28925 .55007 Mdot
.94777 .40699 Mdot
.68324 .45454 Mdot
.49894 .61759 Mdot
.49663 .61661 Mdot
.48927 .61349 Mdot
.46584 .60355 Mdot
.39156 .57213 Mdot
.16691 .4792 Mdot
.73533 .3513 Mdot
.54148 .49822 Mdot
.40913 .53624 Mdot
.14776 .4565 Mdot
.69525 .33837 Mdot
.49755 .617 Mdot
.4922 .61473 Mdot
.47516 .6075 Mdot
.421 .58456 Mdot
.25315 .5143 Mdot
.84661 .36678 Mdot
.63616 .48797 Mdot
.60592 .59935 Mdot
.7231 .07242 Mdot
.0756 .21786 Mdot
.31892 .15038 Mdot
.49828 .61731 Mdot
.49453 .61572 Mdot
.48259 .61065 Mdot
.44457 .59454 Mdot
.32508 .54418 Mdot
.99293 .41275 Mdot
.67138 .41931 Mdot
.56003 .54922 Mdot
.53661 .60356 Mdot
.56761 .01916 Mdot
.69701 .07997 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50811 .00344 Mdot
.52582 .01095 Mdot
.5821 .03478 Mdot
.75615 .10757 Mdot
.16875 .255 Mdot
.37305 .12627 Mdot
.4065 .02067 Mdot
.30763 .55693 Mdot
.98552 .41895 Mdot
.68509 .43236 Mdot
.49793 .61716 Mdot
.49341 .61524 Mdot
.47901 .60913 Mdot
.43322 .58973 Mdot
.29017 .52962 Mdot
.91595 .38675 Mdot
.66203 .4611 Mdot
.61129 .58667 Mdot
.7142 .0636 Mdot
.04983 .20743 Mdot
.31193 .16199 Mdot
.4993 .61774 Mdot
.49776 .61709 Mdot
.49287 .61501 Mdot
.47729 .6084 Mdot
.42775 .58742 Mdot
.27353 .52272 Mdot
.88317 .37678 Mdot
.65274 .47562 Mdot
.61784 .59646 Mdot
.74397 .07796 Mdot
.10867 .2254 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47857 .60895 Mdot
.43182 .58914 Mdot
.2859 .52785 Mdot
.9073 .38404 Mdot
.66002 .46521 Mdot
.61432 .58979 Mdot
.72573 .06886 Mdot
.0731 .21469 Mdot
.31464 .14928 Mdot
.49833 .61732 Mdot
.49466 .61577 Mdot
.483 .61082 Mdot
.44588 .59509 Mdot
.32914 .54588 Mdot
.00257 .41621 Mdot
.67215 .41382 Mdot
.55246 .54406 Mdot
.51005 .59182 Mdot
.48269 .60113 Mdot
.42943 .58511 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47572 .60774 Mdot
.42277 .58531 Mdot
.25847 .51649 Mdot
.85577 .36915 Mdot
.641 .4853 Mdot
.61113 .59957 Mdot
.73473 .07639 Mdot
.09596 .22326 Mdot
.32182 .13959 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47784 .60864 Mdot
.42949 .58815 Mdot
.2788 .5249 Mdot
.89328 .37977 Mdot
.65611 .47145 Mdot
.61732 .59406 Mdot
.739 .0752 Mdot
.09884 .2224 Mdot
.31977 .13654 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47768 .60857 Mdot
.429 .58795 Mdot
.2773 .52428 Mdot
.89038 .3789 Mdot
.65519 .47268 Mdot
.61762 .59481 Mdot
.74084 .07616 Mdot
.1024 .22346 Mdot
.32074 .13494 Mdot
.49948 .61781 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48329 .61095 Mdot
.44679 .59548 Mdot
.33197 .54707 Mdot
.00938 .41866 Mdot
.67273 .40998 Mdot
.54723 .54047 Mdot
.49153 .58361 Mdot
.42314 .57576 Mdot
.49847 .61739 Mdot
.49514 .61597 Mdot
.48451 .61146 Mdot
.45067 .59712 Mdot
.34403 .55212 Mdot
.03911 .42959 Mdot
.67612 .39369 Mdot
.52659 .52562 Mdot
.41677 .55016 Mdot
.18771 .47647 Mdot
.73797 .34008 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.51319 .00559 Mdot
.54199 .0178 Mdot
.63306 .05628 Mdot
.90127 .16576 Mdot
.30826 .25153 Mdot
.49232 .11376 Mdot
.66488 .10665 Mdot
.04284 .23359 Mdot
.35731 .19435 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50522 .00221 Mdot
.51664 .00706 Mdot
.55297 .02245 Mdot
.6673 .07066 Mdot
.98886 .19873 Mdot
.32711 .20905 Mdot
.45411 .07849 Mdot
.51323 .03654 Mdot
.59218 .04879 Mdot
.80178 .12954 Mdot
.49875 .6175 Mdot
.49602 .61634 Mdot
.4873 .61265 Mdot
.45957 .60089 Mdot
.37184 .56381 Mdot
.11198 .45743 Mdot
.69767 .36198 Mdot
.50931 .50162 Mdot
.33489 .51024 Mdot
.95491 .38319 Mdot
.64166 .42444 Mdot
.49989 .61799 Mdot
.49963 .61788 Mdot
.49884 .61754 Mdot
.49629 .61646 Mdot
.48818 .61302 Mdot
.46236 .60208 Mdot
.3806 .56751 Mdot
.13609 .46691 Mdot
.71142 .35558 Mdot
.51851 .49881 Mdot
.35329 .51592 Mdot
.49816 .61725 Mdot
.49415 .61555 Mdot
.48135 .61013 Mdot
.44065 .59288 Mdot
.31297 .53913 Mdot
.96501 .40298 Mdot
.66911 .43516 Mdot
.58177 .56405 Mdot
.61174 .01853 Mdot
.79591 .11382 Mdot
.20894 .25527 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.5076 .00322 Mdot
.52421 .01027 Mdot
.57701 .03263 Mdot
.74086 .10126 Mdot
.14304 .24857 Mdot
.35841 .1331 Mdot
.38831 .01848 Mdot
.26411 .54127 Mdot
.9021 .3943 Mdot
.67786 .47944 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51822 .00773 Mdot
.558 .02459 Mdot
.68288 .07718 Mdot
.02556 .21179 Mdot
.33007 .1882 Mdot
.42543 .05893 Mdot
.41297 .61033 Mdot
.27637 .53361 Mdot
.90431 .38809 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49089 .61417 Mdot
.47099 .60574 Mdot
.40783 .57899 Mdot
.214 .49824 Mdot
.78753 .35446 Mdot
.59318 .49792 Mdot
.53074 .57945 Mdot
.51414 .60777 Mdot
.51872 .00283 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50662 .00281 Mdot
.5211 .00895 Mdot
.56713 .02845 Mdot
.71091 .08886 Mdot
.08625 .23197 Mdot
.33846 .15587 Mdot
.38786 .03054 Mdot
.28264 .553 Mdot
.9437 .40855 Mdot
.68745 .45967 Mdot
.49957 .61785 Mdot
.49863 .61745 Mdot
.49562 .61618 Mdot
.48605 .61212 Mdot
.45556 .5992 Mdot
.35929 .55854 Mdot
.07841 .44443 Mdot
.68461 .37465 Mdot
.50967 .50992 Mdot
.34924 .51888 Mdot
.995 .3991 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.5196 .00831 Mdot
.56237 .02644 Mdot
.69633 .08279 Mdot
.05557 .22203 Mdot
.33314 .17154 Mdot
.40381 .04368 Mdot
.33883 .57787 Mdot
.07134 .45272 Mdot
.70039 .38877 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47495 .60741 Mdot
.42036 .58429 Mdot
.25123 .5135 Mdot
.84337 .36596 Mdot
.63433 .48884 Mdot
.60369 .5991 Mdot
.71782 .07053 Mdot
.06581 .21507 Mdot
.31788 .15579 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50605 .00257 Mdot
.51928 .00817 Mdot
.56135 .026 Mdot
.6932 .08148 Mdot
.04873 .21973 Mdot
.3323 .17526 Mdot
.40836 .04701 Mdot
.35444 .58471 Mdot
.11136 .46781 Mdot
.71454 .37279 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61225 Mdot
.45659 .59963 Mdot
.36249 .55988 Mdot
.08686 .44768 Mdot
.68731 .3711 Mdot
.50821 .50734 Mdot
.34141 .51495 Mdot
.97419 .39108 Mdot
.64551 .4149 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50642 .00272 Mdot
.52044 .00867 Mdot
.56504 .02757 Mdot
.70452 .0862 Mdot
.07304 .22776 Mdot
.33581 .1624 Mdot
.39371 .03579 Mdot
.30377 .56245 Mdot
.98859 .42324 Mdot
.69051 .43381 Mdot
.5007 .0003 Mdot
.50223 .00094 Mdot
.5071 .00301 Mdot
.52261 .00959 Mdot
.57192 .03047 Mdot
.72546 .0949 Mdot
.11491 .24069 Mdot
.34658 .14318 Mdot
.38215 .02198 Mdot
.25665 .54047 Mdot
.89263 .39306 Mdot
.67772 .48521 Mdot
.49997 .61802 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49918 .61768 Mdot
.49737 .61692 Mdot
.49163 .61449 Mdot
.47334 .60673 Mdot
.41525 .58213 Mdot
.23597 .50723 Mdot
.81887 .36026 Mdot
.61851 .4942 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48113 .61003 Mdot
.43995 .59258 Mdot
.31081 .53822 Mdot
.96015 .40132 Mdot
.66864 .43787 Mdot
.58535 .56656 Mdot
.62404 .02391 Mdot
.83052 .12761 Mdot
.24582 .25667 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50338 .00143 Mdot
.51078 .00457 Mdot
.53432 .01455 Mdot
.60896 .04613 Mdot
.83456 .13943 Mdot
.26598 .26663 Mdot
.45988 .11983 Mdot
.59423 .08303 Mdot
.8618 .16537 Mdot
.31159 .27798 Mdot
.50063 .00027 Mdot
.50199 .00085 Mdot
.50635 .00269 Mdot
.52023 .00858 Mdot
.56437 .02728 Mdot
.70245 .08534 Mdot
.06868 .22635 Mdot
.33506 .16463 Mdot
.396 .03766 Mdot
.31181 .566 Mdot
.00667 .42945 Mdot
.69153 .42326 Mdot
.49953 .61784 Mdot
.49851 .6174 Mdot
.49524 .61602 Mdot
.48483 .6116 Mdot
.45172 .59757 Mdot
.34727 .55349 Mdot
.04732 .43265 Mdot
.67743 .38943 Mdot
.52187 .5219 Mdot
.39903 .54211 Mdot
.13468 .45466 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47679 .60819 Mdot
.42617 .58675 Mdot
.26872 .52073 Mdot
.87419 .3742 Mdot
.64933 .47906 Mdot
.61701 .59806 Mdot
.74482 .07899 Mdot
.11123 .22645 Mdot
.32405 .13153 Mdot
.49895 .61759 Mdot
.49666 .61662 Mdot
.48935 .61352 Mdot
.46609 .60366 Mdot
.39236 .57246 Mdot
.16918 .48011 Mdot
.7374 .35118 Mdot
.54361 .49826 Mdot
.4144 .53818 Mdot
.1629 .4626 Mdot
.70753 .3366 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .00121 Mdot
.50906 .00384 Mdot
.52885 .01223 Mdot
.59167 .03883 Mdot
.78451 .11918 Mdot
.21049 .26327 Mdot
.40506 .12025 Mdot
.46552 .03737 Mdot
.47468 .00566 Mdot
.44601 .60031 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50274 .00116 Mdot
.50872 .0037 Mdot
.52778 .01178 Mdot
.5883 .0374 Mdot
.77458 .11513 Mdot
.19675 .26091 Mdot
.39342 .12155 Mdot
.44192 .02997 Mdot
.4052 .59534 Mdot
.23456 .51257 Mdot
.4987 .61748 Mdot
.49586 .61628 Mdot
.48681 .61244 Mdot
.458 .60023 Mdot
.36693 .56175 Mdot
.0987 .45226 Mdot
.69173 .36651 Mdot
.50767 .50428 Mdot
.33512 .51139 Mdot
.95718 .38445 Mdot
.64269 .42367 Mdot
.49757 .61701 Mdot
.49227 .61476 Mdot
.47539 .6076 Mdot
.42172 .58487 Mdot
.25532 .51519 Mdot
.85033 .36773 Mdot
.63818 .48692 Mdot
.60822 .59952 Mdot
.72838 .07426 Mdot
.08507 .22045 Mdot
.32014 .14528 Mdot
.49838 .61735 Mdot
.49484 .61584 Mdot
.48355 .61106 Mdot
.44764 .59584 Mdot
.33459 .54817 Mdot
.01575 .42098 Mdot
.67332 .4064 Mdot
.54245 .53715 Mdot
.4745 .57604 Mdot
.36847 .5525 Mdot
.08686 .44399 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50712 .00302 Mdot
.52269 .00962 Mdot
.57217 .03058 Mdot
.72623 .09522 Mdot
.11637 .24112 Mdot
.3471 .14259 Mdot
.38216 .02167 Mdot
.49894 .61759 Mdot
.49663 .6166 Mdot
.48926 .61348 Mdot
.4658 .60353 Mdot
.39144 .57207 Mdot
.16657 .47906 Mdot
.73502 .35133 Mdot
.54116 .49822 Mdot
.40834 .53595 Mdot
.14549 .45559 Mdot
.69356 .33873 Mdot
.49841 .61736 Mdot
.49492 .61588 Mdot
.48383 .61118 Mdot
.44851 .59621 Mdot
.3373 .5493 Mdot
.02237 .4234 Mdot
.674 .40273 Mdot
.53765 .53377 Mdot
.45727 .56835 Mdot
.31354 .52921 Mdot
.94987 .39327 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50607 .00257 Mdot
.51932 .00819 Mdot
.5615 .02606 Mdot
.69364 .08167 Mdot
.04969 .22006 Mdot
.33242 .17473 Mdot
.4077 .04653 Mdot
.35218 .58372 Mdot
.10546 .46555 Mdot
.71187 .37478 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51997 .00847 Mdot
.56354 .02693 Mdot
.69992 .08429 Mdot
.06332 .22459 Mdot
.33422 .16743 Mdot
.39904 .04006 Mdot
.32239 .57066 Mdot
.03126 .43811 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .0027 Mdot
.52031 .00861 Mdot
.56463 .02739 Mdot
.70324 .08567 Mdot
.07035 .22689 Mdot
.33534 .16377 Mdot
.39511 .03694 Mdot
.30868 .56462 Mdot
.99955 .42699 Mdot
.6911 .4274 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49089 .61417 Mdot
.47099 .60573 Mdot
.40781 .57899 Mdot
.21394 .49822 Mdot
.78744 .35444 Mdot
.5931 .49792 Mdot
.53058 .57939 Mdot
.51364 .60757 Mdot
.51714 .00216 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50556 .00236 Mdot
.51771 .00751 Mdot
.55636 .02389 Mdot
.67778 .07505 Mdot
.01379 .20766 Mdot
.32914 .1949 Mdot
.43466 .06522 Mdot
.4449 .00633 Mdot
.37415 .5743 Mdot
.13367 .46941 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50429 .00182 Mdot
.51366 .00579 Mdot
.54348 .01843 Mdot
.63773 .05825 Mdot
.91373 .17058 Mdot
.31289 .24669 Mdot
.49172 .11052 Mdot
.65813 .10285 Mdot
.02458 .22648 Mdot
.35431 .20378 Mdot
.50022 .0001 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57373 .03124 Mdot
.73097 .09718 Mdot
.12523 .24367 Mdot
.35044 .13919 Mdot
.3829 .02006 Mdot
.25513 .53907 Mdot
.88876 .3916 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49082 .61414 Mdot
.47075 .60563 Mdot
.40704 .57866 Mdot
.21169 .4973 Mdot
.78449 .35401 Mdot
.59044 .4981 Mdot
.52486 .5775 Mdot
.49641 .60045 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52176 .00923 Mdot
.56923 .02934 Mdot
.71731 .09152 Mdot
.0991 .23596 Mdot
.34166 .14991 Mdot
.384 .02617 Mdot
.26734 .54593 Mdot
.91336 .39926 Mdot
.68302 .47567 Mdot
.49874 .6175 Mdot
.496 .61634 Mdot
.48725 .61263 Mdot
.45939 .60082 Mdot
.37126 .56357 Mdot
.11042 .45682 Mdot
.69691 .36248 Mdot
.50899 .50189 Mdot
.33454 .51022 Mdot
.95424 .383 Mdot
.64164 .42484 Mdot
.49995 .61801 Mdot
.49984 .61796 Mdot
.49948 .61781 Mdot
.49834 .61733 Mdot
.4947 .61579 Mdot
.48312 .61088 Mdot
.44627 .59526 Mdot
.33035 .54639 Mdot
.00549 .41726 Mdot
.67239 .41217 Mdot
.55021 .54252 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54143 .01756 Mdot
.63129 .05554 Mdot
.89649 .1639 Mdot
.30624 .25324 Mdot
.49201 .11481 Mdot
.66581 .10741 Mdot
.0457 .23479 Mdot
.35798 .193 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47487 .60738 Mdot
.42009 .58418 Mdot
.25042 .51317 Mdot
.84202 .36563 Mdot
.63354 .48919 Mdot
.6027 .59897 Mdot
.71543 .06967 Mdot
.06129 .21375 Mdot
.31747 .15833 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00249 Mdot
.51867 .00792 Mdot
.55943 .02519 Mdot
.68728 .07901 Mdot
.03556 .21525 Mdot
.33094 .18256 Mdot
.41781 .05369 Mdot
.38679 .59887 Mdot
.19993 .50255 Mdot
.78605 .36224 Mdot
.49961 .61787 Mdot
.49875 .6175 Mdot
.49603 .61635 Mdot
.48734 .61266 Mdot
.45967 .60094 Mdot
.37217 .56395 Mdot
.11288 .45778 Mdot
.69811 .3617 Mdot
.5095 .50147 Mdot
.33514 .51027 Mdot
.9554 .38334 Mdot
.4997 .61791 Mdot
.49905 .61763 Mdot
.49699 .61676 Mdot
.4904 .61396 Mdot
.46942 .60507 Mdot
.40284 .57689 Mdot
.1994 .4923 Mdot
.7692 .35215 Mdot
.57599 .49863 Mdot
.49249 .56643 Mdot
.39772 .55947 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49248 .61484 Mdot
.47604 .60787 Mdot
.4238 .58575 Mdot
.26157 .51777 Mdot
.86124 .37062 Mdot
.64366 .48357 Mdot
.61349 .59939 Mdot
.73949 .07787 Mdot
.1037 .2251 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48329 .61095 Mdot
.44679 .59548 Mdot
.33197 .54707 Mdot
.00938 .41866 Mdot
.67273 .40997 Mdot
.54722 .54047 Mdot
.49151 .5836 Mdot
.42307 .57574 Mdot
.24369 .50717 Mdot
.49828 .6173 Mdot
.49452 .61571 Mdot
.48255 .61063 Mdot
.44444 .59448 Mdot
.32469 .54402 Mdot
.99201 .41243 Mdot
.67131 .41983 Mdot
.56076 .54971 Mdot
.53915 .60468 Mdot
.57566 .02257 Mdot
.72144 .0901 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .61119 Mdot
.44864 .59626 Mdot
.33769 .54947 Mdot
.02335 .42376 Mdot
.67411 .40219 Mdot
.53696 .53327 Mdot
.45477 .56723 Mdot
.30563 .52586 Mdot
.49825 .61729 Mdot
.49443 .61567 Mdot
.48226 .61051 Mdot
.44353 .5941 Mdot
.32187 .54284 Mdot
.98542 .41009 Mdot
.6708 .42359 Mdot
.56597 .55324 Mdot
.55728 .61266 Mdot
.63267 .04659 Mdot
.8848 .15583 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50925 .00392 Mdot
.52947 .0125 Mdot
.59365 .03966 Mdot
.79032 .12155 Mdot
.21811 .26439 Mdot
.41194 .11979 Mdot
.48033 .04226 Mdot
.51928 .02407 Mdot
.58707 .0419 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51995 .00846 Mdot
.56348 .0269 Mdot
.69973 .08421 Mdot
.06291 .22446 Mdot
.33416 .16764 Mdot
.39928 .04025 Mdot
.32321 .57102 Mdot
.03323 .43881 Mdot
.69376 .40823 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48444 .61144 Mdot
.45047 .59704 Mdot
.3434 .55186 Mdot
.03753 .429 Mdot
.67589 .39453 Mdot
.52756 .52636 Mdot
.42037 .55179 Mdot
.19866 .48101 Mdot
.75053 .34107 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.4896 .61362 Mdot
.46688 .60399 Mdot
.39484 .57351 Mdot
.1763 .48297 Mdot
.74416 .35096 Mdot
.5506 .49841 Mdot
.43167 .54453 Mdot
.21335 .48311 Mdot
.76261 .33946 Mdot
.49767 .61704 Mdot
.49257 .61488 Mdot
.47632 .60799 Mdot
.42468 .58612 Mdot
.26424 .51887 Mdot
.86601 .37192 Mdot
.64586 .48197 Mdot
.61512 .59904 Mdot
.7424 .07866 Mdot
.10814 .22604 Mdot
.32387 .13333 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.5263 .01115 Mdot
.58363 .03543 Mdot
.76069 .10943 Mdot
.17595 .25665 Mdot
.37786 .12478 Mdot
.41401 .02234 Mdot
.32735 .56448 Mdot
.02962 .43402 Mdot
.68771 .40672 Mdot
.50063 .00027 Mdot
.50199 .00084 Mdot
.50635 .00269 Mdot
.52022 .00857 Mdot
.56433 .02726 Mdot
.70234 .08529 Mdot
.06845 .22627 Mdot
.33502 .16475 Mdot
.39613 .03776 Mdot
.31225 .5662 Mdot
.00768 .4298 Mdot
.69159 .42268 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49856 .61743 Mdot
.49543 .61609 Mdot
.48543 .61186 Mdot
.45361 .59837 Mdot
.35318 .55597 Mdot
.06245 .43835 Mdot
.68043 .38193 Mdot
.5147 .51561 Mdot
.37099 .52922 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48933 .61351 Mdot
.46601 .60362 Mdot
.39209 .57235 Mdot
.16843 .47981 Mdot
.73671 .35122 Mdot
.5429 .49825 Mdot
.41264 .53753 Mdot
.15784 .46056 Mdot
.70322 .33706 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49236 .6148 Mdot
.47567 .60772 Mdot
.42263 .58525 Mdot
.25806 .51632 Mdot
.85506 .36897 Mdot
.64064 .48552 Mdot
.61078 .59958 Mdot
.73399 .07615 Mdot
.09473 .22295 Mdot
.49965 .61788 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48863 .61321 Mdot
.4638 .60269 Mdot
.38514 .56942 Mdot
.14876 .47194 Mdot
.72034 .35326 Mdot
.52652 .49825 Mdot
.37229 .52272 Mdot
.0464 .41662 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51105 .00469 Mdot
.5352 .01492 Mdot
.61172 .04729 Mdot
.8424 .14257 Mdot
.27269 .26594 Mdot
.46668 .11989 Mdot
.61104 .08922 Mdot
.90878 .18401 Mdot
.49758 .61701 Mdot
.49228 .61476 Mdot
.47542 .60761 Mdot
.42182 .58491 Mdot
.25562 .51532 Mdot
.85084 .36786 Mdot
.63845 .48677 Mdot
.60852 .59954 Mdot
.72905 .07449 Mdot
.08625 .22076 Mdot
.32031 .14466 Mdot
.5006 .00026 Mdot
.50193 .00082 Mdot
.50614 .0026 Mdot
.51955 .00829 Mdot
.56222 .02637 Mdot
.69586 .0826 Mdot
.05456 .22169 Mdot
.33301 .17209 Mdot
.40447 .04416 Mdot
.34108 .57886 Mdot
.077 .45482 Mdot
.70187 .38619 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.51009 .00428 Mdot
.53214 .01363 Mdot
.60209 .04323 Mdot
.81487 .13151 Mdot
.24683 .26697 Mdot
.44011 .11945 Mdot
.54565 .06523 Mdot
.71874 .10697 Mdot
.12596 .25168 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51964 .00833 Mdot
.56249 .02649 Mdot
.6967 .08294 Mdot
.05637 .22229 Mdot
.33324 .17112 Mdot
.4033 .0433 Mdot
.33708 .57711 Mdot
.49837 .61734 Mdot
.49479 .61583 Mdot
.48341 .611 Mdot
.44718 .59564 Mdot
.33317 .54757 Mdot
.01229 .41972 Mdot
.67299 .40834 Mdot
.54503 .53895 Mdot
.4837 .58013 Mdot
.39797 .56505 Mdot
.16947 .47681 Mdot
.49969 .6179 Mdot
.49901 .61762 Mdot
.49686 .6167 Mdot
.48999 .61379 Mdot
.46813 .60452 Mdot
.39878 .57517 Mdot
.18764 .48754 Mdot
.75586 .35118 Mdot
.56264 .49862 Mdot
.46099 .55521 Mdot
.30139 .5194 Mdot
.49866 .61747 Mdot
.49574 .61623 Mdot
.48644 .61228 Mdot
.45681 .59972 Mdot
.3632 .56018 Mdot
.08873 .4484 Mdot
.68796 .37034 Mdot
.508 .50682 Mdot
.34005 .51423 Mdot
.97056 .38968 Mdot
.64498 .41681 Mdot
.4983 .61731 Mdot
.4946 .61574 Mdot
.48279 .61074 Mdot
.44521 .59481 Mdot
.32707 .54502 Mdot
.99763 .41443 Mdot
.67175 .41663 Mdot
.55632 .5467 Mdot
.52363 .59783 Mdot
.52625 .00162 Mdot
.56805 .02584 Mdot
.49738 .61692 Mdot
.49167 .6145 Mdot
.47346 .60678 Mdot
.41562 .58229 Mdot
.23706 .50768 Mdot
.82056 .36062 Mdot
.61971 .4939 Mdot
.58196 .59471 Mdot
.66179 .04934 Mdot
.94462 .1748 Mdot
.30885 .22511 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48765 .6128 Mdot
.46066 .60135 Mdot
.37525 .56525 Mdot
.12131 .46109 Mdot
.70251 .35921 Mdot
.51191 .50023 Mdot
.33914 .51126 Mdot
.96412 .38626 Mdot
.64246 .41924 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.5057 .00242 Mdot
.51817 .0077 Mdot
.55783 .02451 Mdot
.68233 .07695 Mdot
.02431 .21136 Mdot
.32997 .1889 Mdot
.42639 .05959 Mdot
.4163 .6118 Mdot
.28637 .53773 Mdot
.92392 .39402 Mdot
.49742 .61694 Mdot
.4918 .61455 Mdot
.47386 .60695 Mdot
.41691 .58283 Mdot
.24089 .50925 Mdot
.82654 .36195 Mdot
.62384 .49276 Mdot
.58871 .59632 Mdot
.67986 .05634 Mdot
.98694 .18978 Mdot
.31359 .20188 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49087 .61416 Mdot
.47092 .6057 Mdot
.40758 .57889 Mdot
.21327 .49794 Mdot
.78656 .35431 Mdot
.59231 .49798 Mdot
.52889 .57884 Mdot
.50857 .60547 Mdot
.50109 .61341 Mdot
.49944 .6178 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48204 .61042 Mdot
.44284 .59381 Mdot
.31973 .54195 Mdot
.98043 .40834 Mdot
.67041 .42643 Mdot
.5699 .55591 Mdot
.57089 .00061 Mdot
.67474 .06418 Mdot
.50022 9e-05 Mdot
.5007 .00029 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.52249 .00954 Mdot
.57154 .03031 Mdot
.72431 .09442 Mdot
.11271 .24005 Mdot
.34583 .14407 Mdot
.3822 .02248 Mdot
.25756 .541 Mdot
.89445 .39362 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51093 .00463 Mdot
.5348 .01475 Mdot
.61045 .04676 Mdot
.83881 .14113 Mdot
.26968 .2663 Mdot
.46365 .11988 Mdot
.60356 .08647 Mdot
.88808 .17584 Mdot
.32698 .27126 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48789 .6129 Mdot
.46142 .60168 Mdot
.37764 .56626 Mdot
.12789 .46368 Mdot
.70629 .35747 Mdot
.51447 .49949 Mdot
.34433 .51288 Mdot
.97618 .3905 Mdot
.64363 .4125 Mdot
.49948 .61781 Mdot
.49834 .61733 Mdot
.49472 .6158 Mdot
.48319 .61091 Mdot
.44648 .59535 Mdot
.33101 .54667 Mdot
.00707 .41783 Mdot
.67253 .41128 Mdot
.54899 .54168 Mdot
.49778 .58638 Mdot
.44324 .58432 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51351 .00573 Mdot
.54301 .01824 Mdot
.63626 .05763 Mdot
.90983 .16907 Mdot
.31153 .24827 Mdot
.49212 .11161 Mdot
.66091 .10431 Mdot
.03199 .22934 Mdot
.35541 .19988 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48569 .61197 Mdot
.45445 .59872 Mdot
.35579 .55706 Mdot
.06924 .44093 Mdot
.68207 .37875 Mdot
.51222 .51306 Mdot
.36068 .52438 Mdot
.02584 .41109 Mdot
.65241 .38725 Mdot
.50078 .00033 Mdot
.50249 .00105 Mdot
.50792 .00336 Mdot
.52522 .01069 Mdot
.5802 .03398 Mdot
.75045 .10522 Mdot
.15943 .25276 Mdot
.3673 .12847 Mdot
.3984 .01922 Mdot
.28724 .54933 Mdot
.94385 .40581 Mdot
.68295 .45679 Mdot
.49761 .61702 Mdot
.49237 .6148 Mdot
.4757 .60773 Mdot
.4227 .58528 Mdot
.25827 .51641 Mdot
.85543 .36907 Mdot
.64083 .4854 Mdot
.61096 .59958 Mdot
.73438 .07628 Mdot
.09538 .22311 Mdot
.32172 .13989 Mdot
.49905 .61763 Mdot
.49699 .61676 Mdot
.49041 .61397 Mdot
.46944 .60508 Mdot
.40293 .57693 Mdot
.19967 .49241 Mdot
.76951 .35218 Mdot
.5763 .49862 Mdot
.4932 .56668 Mdot
.39991 .56038 Mdot
.1662 .47359 Mdot
.50027 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.50889 .00377 Mdot
.52833 .01201 Mdot
.59002 .03813 Mdot
.77967 .11721 Mdot
.20391 .2622 Mdot
.39936 .12079 Mdot
.45372 .03359 Mdot
.43962 .60932 Mdot
.33712 .55468 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52314 .00981 Mdot
.57361 .03119 Mdot
.73059 .09702 Mdot
.12452 .24347 Mdot
.35016 .13945 Mdot
.38279 .02017 Mdot
.25509 .53911 Mdot
.88877 .39164 Mdot
.67604 .48656 Mdot
.49831 .61732 Mdot
.4946 .61575 Mdot
.48281 .61074 Mdot
.44527 .59484 Mdot
.32725 .54509 Mdot
.99807 .41459 Mdot
.67179 .41638 Mdot
.55598 .54646 Mdot
.52242 .59729 Mdot
.52237 .61801 Mdot
.55578 .02065 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50698 .00296 Mdot
.52225 .00943 Mdot
.57078 .02999 Mdot
.72201 .09346 Mdot
.10828 .23873 Mdot
.34438 .14592 Mdot
.3825 .02356 Mdot
.25997 .5423 Mdot
.89916 .39504 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48029 .60968 Mdot
.43728 .59145 Mdot
.30261 .5348 Mdot
.94212 .39524 Mdot
.66655 .44772 Mdot
.59765 .57545 Mdot
.6662 .04237 Mdot
.94116 .16993 Mdot
.30238 .22325 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.5041 .00174 Mdot
.51307 .00554 Mdot
.54161 .01764 Mdot
.63187 .05578 Mdot
.89807 .16452 Mdot
.30692 .25268 Mdot
.49215 .11448 Mdot
.66561 .1072 Mdot
.04501 .23448 Mdot
.3578 .19331 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51261 .00535 Mdot
.54017 .01703 Mdot
.62735 .05388 Mdot
.88581 .15974 Mdot
.30124 .25674 Mdot
.49019 .11678 Mdot
.66443 .10769 Mdot
.04373 .23442 Mdot
.35826 .19438 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.4805 .60976 Mdot
.43793 .59173 Mdot
.30461 .53564 Mdot
.94647 .39669 Mdot
.66712 .44539 Mdot
.59486 .57338 Mdot
.65661 .03817 Mdot
.91717 .16103 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50759 .00322 Mdot
.52417 .01025 Mdot
.57686 .03257 Mdot
.74041 .10108 Mdot
.14226 .24836 Mdot
.35802 .13335 Mdot
.38796 .0185 Mdot
.26337 .54104 Mdot
.9009 .39401 Mdot
.67765 .48006 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50406 .00172 Mdot
.51295 .00549 Mdot
.54123 .01748 Mdot
.63066 .05527 Mdot
.8948 .16325 Mdot
.3055 .25383 Mdot
.49183 .11516 Mdot
.66591 .10759 Mdot
.04616 .23501 Mdot
.35814 .19281 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48275 .61072 Mdot
.44509 .59476 Mdot
.32668 .54485 Mdot
.99671 .4141 Mdot
.67168 .41715 Mdot
.55705 .54719 Mdot
.52616 .59895 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50757 .00321 Mdot
.52413 .01023 Mdot
.57673 .03251 Mdot
.74002 .10092 Mdot
.14157 .24817 Mdot
.35768 .13357 Mdot
.38765 .01852 Mdot
.26276 .54084 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57519 .03186 Mdot
.73536 .09899 Mdot
.13326 .24592 Mdot
.35382 .13631 Mdot
.38467 .01906 Mdot
.25726 .53929 Mdot
.89136 .3919 Mdot
.67606 .48497 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49541 .61609 Mdot
.48537 .61183 Mdot
.45342 .59829 Mdot
.3526 .55572 Mdot
.06096 .43779 Mdot
.6801 .38265 Mdot
.51531 .51619 Mdot
.37346 .53037 Mdot
.06118 .42503 Mdot
.49776 .61708 Mdot
.49287 .61501 Mdot
.47727 .6084 Mdot
.4277 .5874 Mdot
.27337 .52265 Mdot
.88289 .3767 Mdot
.65264 .47573 Mdot
.61783 .59652 Mdot
.74405 .07801 Mdot
.10884 .22545 Mdot
.3228 .13223 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52198 .00932 Mdot
.56994 .02964 Mdot
.71946 .09241 Mdot
.10333 .23724 Mdot
.34287 .14804 Mdot
.38317 .02491 Mdot
.26356 .54411 Mdot
.90608 .3971 Mdot
.68144 .4792 Mdot
.49863 .61745 Mdot
.49562 .61618 Mdot
.48605 .61212 Mdot
.45557 .5992 Mdot
.35932 .55855 Mdot
.07848 .44447 Mdot
.68463 .37462 Mdot
.50966 .50989 Mdot
.34915 .51884 Mdot
.99477 .39901 Mdot
.64823 .40386 Mdot
.49811 .61723 Mdot
.49399 .61549 Mdot
.48086 .60992 Mdot
.43908 .59221 Mdot
.30812 .5371 Mdot
.95418 .39929 Mdot
.66802 .44118 Mdot
.58962 .56958 Mdot
.63866 .03031 Mdot
.87035 .14319 Mdot
.27571 .25053 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50289 .00123 Mdot
.50921 .00391 Mdot
.52935 .01244 Mdot
.59326 .0395 Mdot
.78919 .12109 Mdot
.21666 .26419 Mdot
.41061 .11987 Mdot
.47741 .04129 Mdot
.51044 .02041 Mdot
.55911 .03008 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.44211 .5935 Mdot
.31746 .541 Mdot
.97522 .40651 Mdot
.67 .4294 Mdot
.57397 .55869 Mdot
.58495 .00679 Mdot
.71739 .08185 Mdot
.08356 .22631 Mdot
.49741 .61693 Mdot
.49174 .61453 Mdot
.47369 .60688 Mdot
.41636 .5826 Mdot
.23926 .50858 Mdot
.82397 .36137 Mdot
.62209 .49326 Mdot
.58591 .59567 Mdot
.67243 .05347 Mdot
.96988 .18383 Mdot
.31224 .21159 Mdot
.49826 .61729 Mdot
.49444 .61568 Mdot
.4823 .61053 Mdot
.44366 .59415 Mdot
.32225 .543 Mdot
.9863 .4104 Mdot
.67087 .42309 Mdot
.56527 .55277 Mdot
.55485 .61159 Mdot
.62508 .04341 Mdot
.86422 .14779 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50685 .00291 Mdot
.52184 .00926 Mdot
.56947 .02944 Mdot
.71802 .09181 Mdot
.10051 .23639 Mdot
.34205 .14928 Mdot
.3837 .02574 Mdot
.26601 .5453 Mdot
.9108 .3985 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .00241 Mdot
.51807 .00766 Mdot
.55751 .02438 Mdot
.68136 .07654 Mdot
.02209 .21058 Mdot
.32979 .19017 Mdot
.42813 .06078 Mdot
.42229 .61443 Mdot
.30446 .54521 Mdot
.96174 .40622 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49146 .61441 Mdot
.47281 .6065 Mdot
.41355 .58141 Mdot
.23092 .50516 Mdot
.81126 .35867 Mdot
.61287 .49542 Mdot
.56994 .5915 Mdot
.62858 .03624 Mdot
.85979 .14289 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48582 .61202 Mdot
.45486 .5989 Mdot
.35709 .55761 Mdot
.07261 .44222 Mdot
.68296 .37722 Mdot
.51117 .51186 Mdot
.35613 .52221 Mdot
.01349 .40627 Mdot
.65064 .39378 Mdot
.49974 .61792 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49165 .61449 Mdot
.4734 .60676 Mdot
.41545 .58221 Mdot
.23654 .50746 Mdot
.81975 .36045 Mdot
.61914 .49405 Mdot
.581 .59446 Mdot
.65918 .04832 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48442 .61143 Mdot
.4504 .59701 Mdot
.34316 .55176 Mdot
.03694 .42878 Mdot
.67581 .39484 Mdot
.52793 .52664 Mdot
.42172 .5524 Mdot
.20277 .48272 Mdot
.75552 .34162 Mdot
.49847 .61739 Mdot
.49514 .61597 Mdot
.48451 .61146 Mdot
.45067 .59712 Mdot
.34402 .55212 Mdot
.03909 .42958 Mdot
.67612 .3937 Mdot
.5266 .52563 Mdot
.41681 .55018 Mdot
.18785 .47652 Mdot
.73812 .34009 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48134 .61012 Mdot
.4406 .59286 Mdot
.31281 .53906 Mdot
.96465 .40286 Mdot
.66908 .43536 Mdot
.58203 .56424 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51143 .00485 Mdot
.53641 .01544 Mdot
.61554 .0489 Mdot
.85314 .14685 Mdot
.28108 .26448 Mdot
.47482 .11974 Mdot
.63094 .09649 Mdot
.96205 .20464 Mdot
.34955 .23949 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51721 .0073 Mdot
.55478 .02322 Mdot
.6729 .073 Mdot
.00228 .20357 Mdot
.32824 .20145 Mdot
.44374 .07138 Mdot
.4766 .02031 Mdot
.4745 .61673 Mdot
.4343 .59319 Mdot
.49872 .61749 Mdot
.49592 .6163 Mdot
.487 .61252 Mdot
.45861 .60049 Mdot
.36884 .56255 Mdot
.10385 .45426 Mdot
.69391 .36467 Mdot
.50802 .50315 Mdot
.33416 .51058 Mdot
.95418 .38319 Mdot
.64198 .42508 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50413 .00175 Mdot
.51314 .00557 Mdot
.54186 .01775 Mdot
.63264 .05611 Mdot
.90013 .16532 Mdot
.30779 .25195 Mdot
.49228 .11402 Mdot
.66519 .10686 Mdot
.04373 .23395 Mdot
.3575 .19392 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48646 .61229 Mdot
.4569 .59976 Mdot
.36347 .56029 Mdot
.08945 .44868 Mdot
.68821 .37006 Mdot
.50794 .50662 Mdot
.33956 .51397 Mdot
.96927 .38918 Mdot
.64479 .41749 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48816 .61301 Mdot
.4623 .60205 Mdot
.38043 .56743 Mdot
.1356 .46672 Mdot
.7111 .35568 Mdot
.51824 .49884 Mdot
.35268 .51571 Mdot
.99636 .39782 Mdot
.6455 .40119 Mdot
.49902 .61762 Mdot
.49687 .61671 Mdot
.49003 .61381 Mdot
.46824 .60457 Mdot
.39913 .57532 Mdot
.18865 .48795 Mdot
.75696 .35123 Mdot
.56376 .49863 Mdot
.46368 .55618 Mdot
.30959 .5228 Mdot
.9333 .38547 Mdot
.49912 .61766 Mdot
.4972 .61685 Mdot
.49107 .61425 Mdot
.47155 .60597 Mdot
.40958 .57973 Mdot
.21915 .50034 Mdot
.79446 .35556 Mdot
.59925 .49739 Mdot
.54344 .58355 Mdot
.552 .00529 Mdot
.63719 .05265 Mdot
.49828 .6173 Mdot
.49452 .61571 Mdot
.48253 .61063 Mdot
.44438 .59446 Mdot
.3245 .54394 Mdot
.99157 .41227 Mdot
.67128 .42008 Mdot
.5611 .54994 Mdot
.54034 .6052 Mdot
.57943 .02416 Mdot
.73279 .09478 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.4275 .58731 Mdot
.27276 .5224 Mdot
.88173 .37636 Mdot
.65222 .47619 Mdot
.61779 .59675 Mdot
.74434 .07822 Mdot
.10948 .22567 Mdot
.49777 .61709 Mdot
.49288 .61501 Mdot
.47732 .60842 Mdot
.42784 .58746 Mdot
.2738 .52283 Mdot
.88369 .37693 Mdot
.65293 .47541 Mdot
.61785 .59635 Mdot
.74382 .07786 Mdot
.10834 .22529 Mdot
.32262 .13243 Mdot
.49838 .61735 Mdot
.49484 .61584 Mdot
.48355 .61106 Mdot
.44762 .59583 Mdot
.33453 .54814 Mdot
.01559 .42092 Mdot
.6733 .40649 Mdot
.54257 .53723 Mdot
.47493 .57623 Mdot
.36983 .55308 Mdot
.09053 .44542 Mdot
.5 .61803 Mdot
.49999 .61803 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48045 .60974 Mdot
.43777 .59166 Mdot
.30411 .53543 Mdot
.49846 .61738 Mdot
.49509 .61595 Mdot
.48437 .61141 Mdot
.45023 .59694 Mdot
.34266 .55155 Mdot
.03567 .42831 Mdot
.67563 .39551 Mdot
.52872 .52724 Mdot
.42466 .55372 Mdot
.21177 .48646 Mdot
.767 .34315 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47696 .60826 Mdot
.42672 .58698 Mdot
.27039 .52142 Mdot
.87729 .37508 Mdot
.65055 .4779 Mdot
.61744 .59757 Mdot
.74492 .07879 Mdot
.11102 .22626 Mdot
.32377 .13148 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47458 .60726 Mdot
.41918 .58379 Mdot
.24769 .51205 Mdot
.83749 .36452 Mdot
.63085 .49032 Mdot
.59912 .59842 Mdot
.70664 .06645 Mdot
.04408 .20855 Mdot
.31625 .16821 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51979 .00839 Mdot
.56299 .0267 Mdot
.69822 .08358 Mdot
.05966 .22338 Mdot
.33369 .16936 Mdot
.40124 .04175 Mdot
.32998 .57399 Mdot
.04949 .44469 Mdot
.69596 .39954 Mdot
.49931 .61774 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47759 .60853 Mdot
.42871 .58782 Mdot
.27642 .52392 Mdot
.88869 .3784 Mdot
.65464 .47338 Mdot
.61774 .59523 Mdot
.74176 .07665 Mdot
.10421 .224 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51216 .00516 Mdot
.53874 .01642 Mdot
.62284 .05198 Mdot
.87346 .15489 Mdot
.29451 .26022 Mdot
.4861 .11841 Mdot
.65687 .10554 Mdot
.02666 .22854 Mdot
.35664 .20394 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51542 .00654 Mdot
.5491 .02082 Mdot
.65528 .06562 Mdot
.95914 .1878 Mdot
.32362 .22526 Mdot
.47445 .09322 Mdot
.58713 .06964 Mdot
.82407 .14644 Mdot
.27435 .27829 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48645 .61229 Mdot
.45686 .59974 Mdot
.36334 .56024 Mdot
.08912 .44855 Mdot
.68809 .37019 Mdot
.50797 .50671 Mdot
.33978 .51409 Mdot
.96986 .38941 Mdot
.49821 .61728 Mdot
.49431 .61562 Mdot
.48188 .61035 Mdot
.44232 .59359 Mdot
.31813 .54128 Mdot
.97676 .40705 Mdot
.67012 .42852 Mdot
.57277 .55787 Mdot
.58082 .00498 Mdot
.70497 .07672 Mdot
.05835 .2184 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50315 .00134 Mdot
.51005 .00426 Mdot
.532 .01357 Mdot
.60164 .04304 Mdot
.81359 .13099 Mdot
.24547 .26691 Mdot
.43871 .11943 Mdot
.54227 .064 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48933 .61351 Mdot
.46602 .60363 Mdot
.39214 .57237 Mdot
.16856 .47986 Mdot
.73683 .35121 Mdot
.54302 .49825 Mdot
.41294 .53764 Mdot
.1587 .4609 Mdot
.70394 .33698 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.51098 .00466 Mdot
.53498 .01483 Mdot
.61103 .047 Mdot
.84043 .14178 Mdot
.27106 .26614 Mdot
.46504 .11989 Mdot
.607 .08773 Mdot
.89763 .17962 Mdot
.33145 .26811 Mdot
.49915 .61767 Mdot
.49728 .61688 Mdot
.49134 .61436 Mdot
.47241 .60633 Mdot
.41229 .58088 Mdot
.22716 .50362 Mdot
.80576 .35759 Mdot
.60859 .49617 Mdot
.56194 .58921 Mdot
.60589 .02716 Mdot
.79722 .11825 Mdot
.49875 .6175 Mdot
.49602 .61635 Mdot
.48732 .61266 Mdot
.45961 .60091 Mdot
.37198 .56387 Mdot
.11236 .45758 Mdot
.69786 .36186 Mdot
.50939 .50155 Mdot
.33499 .51025 Mdot
.9551 .38325 Mdot
.64167 .42432 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.5091 .00386 Mdot
.52899 .01229 Mdot
.59212 .03902 Mdot
.78584 .11972 Mdot
.21226 .26355 Mdot
.40663 .12013 Mdot
.46885 .03845 Mdot
.48465 .00976 Mdot
.49979 .61794 Mdot
.49933 .61775 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47818 .60878 Mdot
.43059 .58862 Mdot
.28215 .52629 Mdot
.89982 .38175 Mdot
.65804 .4686 Mdot
.61623 .5922 Mdot
.73368 .07259 Mdot
.49769 .61705 Mdot
.49263 .61491 Mdot
.47651 .60807 Mdot
.42528 .58637 Mdot
.26605 .51962 Mdot
.8693 .37283 Mdot
.64729 .48083 Mdot
.61601 .5987 Mdot
.74375 .07894 Mdot
.11003 .22638 Mdot
.3241 .1323 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50752 .00319 Mdot
.52395 .01016 Mdot
.57618 .03228 Mdot
.73837 .10024 Mdot
.13865 .24739 Mdot
.35628 .1345 Mdot
.38647 .01865 Mdot
.26043 .54014 Mdot
.89617 .39291 Mdot
.67684 .48248 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48512 .61172 Mdot
.45262 .59795 Mdot
.35011 .55468 Mdot
.05455 .43537 Mdot
.67876 .38578 Mdot
.51818 .51879 Mdot
.38482 .53561 Mdot
.09337 .43791 Mdot
.66976 .35623 Mdot
.49888 .61756 Mdot
.49644 .61652 Mdot
.48866 .61322 Mdot
.46387 .60271 Mdot
.38535 .56951 Mdot
.14934 .47218 Mdot
.72078 .35317 Mdot
.52694 .49823 Mdot
.37331 .52309 Mdot
.0491 .41766 Mdot
.6524 .37286 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50324 .00137 Mdot
.51033 .00438 Mdot
.5329 .01395 Mdot
.60446 .04423 Mdot
.8217 .13426 Mdot
.25385 .26709 Mdot
.44734 .11958 Mdot
.56328 .07165 Mdot
.77166 .12879 Mdot
.21656 .27497 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51997 .00847 Mdot
.56356 .02694 Mdot
.69997 .08431 Mdot
.06341 .22462 Mdot
.33423 .16738 Mdot
.39899 .04002 Mdot
.32219 .57057 Mdot
.0308 .43795 Mdot
.6935 .40957 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.47491 .6074 Mdot
.42022 .58423 Mdot
.25081 .51333 Mdot
.84267 .36579 Mdot
.63392 .48902 Mdot
.60318 .59903 Mdot
.7166 .07009 Mdot
.0635 .2144 Mdot
.31766 .15708 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.50482 .00204 Mdot
.51534 .00651 Mdot
.54885 .02071 Mdot
.65447 .06528 Mdot
.95711 .18704 Mdot
.3233 .22632 Mdot
.47565 .09415 Mdot
.5916 .07166 Mdot
.8375 .15197 Mdot
.28695 .27778 Mdot
.49993 .618 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49774 .61708 Mdot
.49281 .61499 Mdot
.47711 .60833 Mdot
.42718 .58718 Mdot
.2718 .522 Mdot
.87991 .37584 Mdot
.65155 .4769 Mdot
.61768 .5971 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50513 .00218 Mdot
.51635 .00693 Mdot
.55204 .02206 Mdot
.66442 .06945 Mdot
.98184 .19618 Mdot
.32644 .21297 Mdot
.45932 .08212 Mdot
.53184 .04482 Mdot
.65179 .07413 Mdot
.96644 .19447 Mdot
.49741 .61693 Mdot
.49173 .61453 Mdot
.47367 .60687 Mdot
.41628 .58257 Mdot
.23901 .50848 Mdot
.82358 .36129 Mdot
.62182 .49334 Mdot
.58547 .59557 Mdot
.67125 .05302 Mdot
.96714 .18287 Mdot
.31197 .21312 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50697 .00296 Mdot
.52221 .00942 Mdot
.57066 .02994 Mdot
.72166 .09332 Mdot
.10761 .23853 Mdot
.34417 .1462 Mdot
.38258 .02374 Mdot
.2604 .54252 Mdot
.89999 .39529 Mdot
.67992 .48202 Mdot
.498 .61718 Mdot
.49362 .61533 Mdot
.47966 .60941 Mdot
.43528 .5906 Mdot
.29647 .53225 Mdot
.92903 .39095 Mdot
.66455 .45458 Mdot
.60522 .58136 Mdot
.69247 .05392 Mdot
.00302 .19193 Mdot
.30904 .18913 Mdot
.49779 .61709 Mdot
.49294 .61504 Mdot
.47752 .6085 Mdot
.42849 .58773 Mdot
.27576 .52364 Mdot
.88742 .37803 Mdot
.65421 .47391 Mdot
.6178 .59553 Mdot
.74238 .077 Mdot
.10543 .22437 Mdot
.32164 .13363 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.48491 .61163 Mdot
.45194 .59766 Mdot
.34797 .55378 Mdot
.0491 .43332 Mdot
.67774 .38852 Mdot
.52092 .52112 Mdot
.3954 .54046 Mdot
.12402 .45032 Mdot
.68488 .34663 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47928 .60925 Mdot
.43408 .5901 Mdot
.29279 .53071 Mdot
.92134 .38847 Mdot
.66314 .45845 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52445 .01037 Mdot
.57774 .03294 Mdot
.74307 .10218 Mdot
.1469 .24958 Mdot
.36036 .13193 Mdot
.39023 .01846 Mdot
.26818 .5426 Mdot
.90895 .39602 Mdot
.67897 .4759 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00043 Mdot
.5032 .00136 Mdot
.51018 .00432 Mdot
.53243 .01375 Mdot
.60298 .0436 Mdot
.81745 .13255 Mdot
.24953 .26704 Mdot
.44288 .1195 Mdot
.55239 .06768 Mdot
.73906 .11537 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50698 .00296 Mdot
.52224 .00943 Mdot
.57074 .02998 Mdot
.7219 .09342 Mdot
.10809 .23867 Mdot
.34432 .146 Mdot
.38253 .02361 Mdot
.26009 .54236 Mdot
.8994 .39512 Mdot
.67976 .48229 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.51548 .00657 Mdot
.5493 .0209 Mdot
.65588 .06587 Mdot
.96065 .18836 Mdot
.32385 .22447 Mdot
.47355 .09252 Mdot
.58377 .06812 Mdot
.81393 .14224 Mdot
.26381 .27805 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52053 .0087 Mdot
.56532 .02768 Mdot
.70536 .08655 Mdot
.0748 .22833 Mdot
.33613 .16151 Mdot
.39283 .03505 Mdot
.30067 .56107 Mdot
.98177 .42094 Mdot
.49894 .61758 Mdot
.49661 .6166 Mdot
.48921 .61346 Mdot
.46563 .60346 Mdot
.3909 .57185 Mdot
.16503 .47844 Mdot
.73365 .35143 Mdot
.53975 .4982 Mdot
.40486 .53466 Mdot
.1356 .45162 Mdot
.68667 .34058 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.49272 .61494 Mdot
.47679 .60819 Mdot
.42619 .58676 Mdot
.26879 .52076 Mdot
.87433 .37424 Mdot
.64938 .47901 Mdot
.61703 .59804 Mdot
.74483 .07898 Mdot
.11123 .22645 Mdot
.49911 .61766 Mdot
.49716 .61683 Mdot
.49097 .6142 Mdot
.47122 .60583 Mdot
.40854 .5793 Mdot
.21611 .4991 Mdot
.79033 .35489 Mdot
.59566 .49772 Mdot
.536 .58116 Mdot
.52989 .61426 Mdot
.56835 .02377 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50327 .00139 Mdot
.51042 .00442 Mdot
.53318 .01407 Mdot
.60536 .04461 Mdot
.82428 .1353 Mdot
.25641 .26707 Mdot
.44999 .11964 Mdot
.56979 .07404 Mdot
.79094 .13668 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47426 .60712 Mdot
.41817 .58336 Mdot
.24466 .5108 Mdot
.83255 .36334 Mdot
.62778 .49148 Mdot
.59473 .59761 Mdot
.69555 .06231 Mdot
.02126 .2013 Mdot
.49812 .61724 Mdot
.49401 .6155 Mdot
.48093 .60995 Mdot
.43931 .59231 Mdot
.30883 .5374 Mdot
.95575 .39982 Mdot
.66819 .44031 Mdot
.58852 .56879 Mdot
.63487 .02865 Mdot
.86018 .13925 Mdot
.26926 .25283 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47565 .60771 Mdot
.42255 .58522 Mdot
.2578 .51621 Mdot
.85461 .36885 Mdot
.64041 .48565 Mdot
.61055 .59958 Mdot
.7335 .07599 Mdot
.09391 .22274 Mdot
.32148 .14065 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51961 .00831 Mdot
.5624 .02645 Mdot
.69641 .08282 Mdot
.05576 .22209 Mdot
.33316 .17145 Mdot
.4037 .04359 Mdot
.33843 .5777 Mdot
.07035 .45235 Mdot
.70014 .38924 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48593 .61207 Mdot
.4552 .59904 Mdot
.35815 .55806 Mdot
.0754 .44329 Mdot
.68373 .37597 Mdot
.5104 .51091 Mdot
.35266 .52054 Mdot
.49797 .61717 Mdot
.49352 .61529 Mdot
.47935 .60928 Mdot
.43431 .59019 Mdot
.29349 .53101 Mdot
.92281 .38894 Mdot
.66342 .45773 Mdot
.60831 .58397 Mdot
.70341 .05878 Mdot
.0271 .20005 Mdot
.31033 .17505 Mdot
.49872 .61749 Mdot
.49591 .6163 Mdot
.48697 .61251 Mdot
.4585 .60044 Mdot
.36848 .5624 Mdot
.10289 .45389 Mdot
.69349 .36501 Mdot
.50793 .50335 Mdot
.33426 .5107 Mdot
.95454 .38335 Mdot
.64209 .42493 Mdot
.49937 .61777 Mdot
.49801 .61719 Mdot
.49365 .61534 Mdot
.47977 .60946 Mdot
.43562 .59075 Mdot
.29752 .53268 Mdot
.93125 .39167 Mdot
.66493 .45344 Mdot
.60403 .5804 Mdot
.68831 .05209 Mdot
.99362 .18869 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.5028 .00119 Mdot
.50893 .00379 Mdot
.52846 .01207 Mdot
.59044 .03831 Mdot
.7809 .11771 Mdot
.20561 .26248 Mdot
.40081 .12064 Mdot
.45667 .03452 Mdot
.44834 .61289 Mdot
.36388 .56583 Mdot
.49793 .61716 Mdot
.49342 .61524 Mdot
.47903 .60914 Mdot
.43326 .58975 Mdot
.29031 .52968 Mdot
.91623 .38684 Mdot
.66209 .46096 Mdot
.61117 .58657 Mdot
.71378 .06342 Mdot
.04897 .20716 Mdot
.31186 .16248 Mdot
.49915 .61768 Mdot
.49731 .61689 Mdot
.49142 .6144 Mdot
.47267 .60645 Mdot
.41313 .58124 Mdot
.22966 .50464 Mdot
.8094 .3583 Mdot
.61144 .49569 Mdot
.56732 .59076 Mdot
.62119 .03329 Mdot
.83978 .1351 Mdot
.49875 .6175 Mdot
.49602 .61635 Mdot
.48732 .61266 Mdot
.45963 .60092 Mdot
.37202 .56389 Mdot
.11248 .45763 Mdot
.69792 .36182 Mdot
.50941 .50153 Mdot
.33503 .51026 Mdot
.95517 .38327 Mdot
.64167 .42428 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51513 .00642 Mdot
.54817 .02042 Mdot
.65237 .0644 Mdot
.95176 .18504 Mdot
.32241 .22907 Mdot
.47862 .09654 Mdot
.60285 .07678 Mdot
.87084 .16563 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50652 .00277 Mdot
.52079 .00881 Mdot
.56614 .02803 Mdot
.70786 .08759 Mdot
.07999 .22999 Mdot
.33713 .15892 Mdot
.39042 .03294 Mdot
.29202 .55722 Mdot
.96315 .41479 Mdot
.68907 .44864 Mdot
.50057 .00024 Mdot
.5018 .00076 Mdot
.50574 .00243 Mdot
.51829 .00776 Mdot
.55821 .02467 Mdot
.68352 .07744 Mdot
.02703 .2123 Mdot
.33019 .18737 Mdot
.42429 .05816 Mdot
.40906 .60862 Mdot
.26473 .52883 Mdot
.88269 .38192 Mdot
.49897 .6176 Mdot
.49672 .61664 Mdot
.48954 .6136 Mdot
.46669 .60391 Mdot
.39424 .57326 Mdot
.17456 .48227 Mdot
.74247 .35099 Mdot
.54885 .49837 Mdot
.42736 .54295 Mdot
.20064 .47792 Mdot
.74658 .33741 Mdot
.49753 .61698 Mdot
.49212 .61469 Mdot
.47489 .60739 Mdot
.42015 .5842 Mdot
.2506 .51325 Mdot
.84232 .3657 Mdot
.63372 .48911 Mdot
.60292 .599 Mdot
.71597 .06987 Mdot
.06231 .21405 Mdot
.31756 .15775 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50791 .00336 Mdot
.52521 .01069 Mdot
.58017 .03396 Mdot
.75035 .10518 Mdot
.15927 .25272 Mdot
.36721 .12851 Mdot
.39827 .0192 Mdot
.28693 .54922 Mdot
.94326 .40563 Mdot
.6829 .45713 Mdot
.49765 .61704 Mdot
.49251 .61486 Mdot
.47614 .60792 Mdot
.42412 .58588 Mdot
.26253 .51817 Mdot
.86296 .37108 Mdot
.64447 .483 Mdot
.61413 .59928 Mdot
.74067 .07821 Mdot
.10554 .2255 Mdot
.32345 .13467 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.53111 .01319 Mdot
.59882 .04185 Mdot
.80542 .12769 Mdot
.23643 .26638 Mdot
.42957 .11937 Mdot
.52047 .05618 Mdot
.642 .07511 Mdot
.94938 .18997 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50387 .00164 Mdot
.51234 .00523 Mdot
.53931 .01667 Mdot
.62465 .05274 Mdot
.87842 .15684 Mdot
.29734 .2589 Mdot
.488 .11784 Mdot
.66068 .10672 Mdot
.03547 .23163 Mdot
.3575 .19902 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50183 .00078 Mdot
.50583 .00247 Mdot
.51858 .00788 Mdot
.55912 .02506 Mdot
.68633 .07862 Mdot
.03343 .21452 Mdot
.33075 .18375 Mdot
.41941 .05479 Mdot
.39228 .60127 Mdot
.21563 .50886 Mdot
.50037 .00016 Mdot
.50117 .00049 Mdot
.50372 .00158 Mdot
.51184 .00502 Mdot
.53771 .01599 Mdot
.61962 .05062 Mdot
.86453 .15136 Mdot
.28898 .26233 Mdot
.48183 .11919 Mdot
.64748 .10238 Mdot
.00402 .22036 Mdot
.35453 .21663 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47983 .60948 Mdot
.43582 .59083 Mdot
.29812 .53293 Mdot
.93253 .39208 Mdot
.66514 .45278 Mdot
.60333 .57984 Mdot
.68587 .05101 Mdot
.98801 .18674 Mdot
.30812 .19784 Mdot
.49938 .61777 Mdot
.49804 .6172 Mdot
.49375 .61539 Mdot
.4801 .6096 Mdot
.43669 .5912 Mdot
.30079 .53404 Mdot
.93821 .39395 Mdot
.66601 .4498 Mdot
.60005 .57727 Mdot
.67449 .046 Mdot
.96128 .17725 Mdot
.49983 .61796 Mdot
.49945 .6178 Mdot
.49823 .61729 Mdot
.49438 .61565 Mdot
.48208 .61044 Mdot
.44297 .59386 Mdot
.32014 .54212 Mdot
.98139 .40867 Mdot
.67049 .42589 Mdot
.56914 .5554 Mdot
.56828 .6175 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50299 .00127 Mdot
.50953 .00404 Mdot
.53036 .01287 Mdot
.59645 .04085 Mdot
.79852 .12488 Mdot
.22831 .26563 Mdot
.42158 .11945 Mdot
.50194 .04966 Mdot
.5852 .05146 Mdot
.79024 .12672 Mdot
.49871 .61749 Mdot
.49588 .61629 Mdot
.48689 .61247 Mdot
.45824 .60033 Mdot
.36768 .56206 Mdot
.10072 .45305 Mdot
.69257 .36578 Mdot
.50777 .50382 Mdot
.33462 .51102 Mdot
.95569 .38384 Mdot
.64237 .42439 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .0029 Mdot
.52181 .00925 Mdot
.56938 .0294 Mdot
.71775 .0917 Mdot
.09997 .23622 Mdot
.3419 .14952 Mdot
.38381 .0259 Mdot
.26652 .54554 Mdot
.91177 .39879 Mdot
.68269 .47646 Mdot
.49923 .61771 Mdot
.49756 .617 Mdot
.49221 .61473 Mdot
.4752 .60752 Mdot
.42113 .58462 Mdot
.25354 .51446 Mdot
.84727 .36695 Mdot
.63652 .48778 Mdot
.60635 .59939 Mdot
.72409 .07277 Mdot
.07741 .21836 Mdot
.4996 .61786 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.48692 .61249 Mdot
.45835 .60038 Mdot
.36801 .5622 Mdot
.10161 .45339 Mdot
.69294 .36546 Mdot
.50783 .50363 Mdot
.33445 .51088 Mdot
.95516 .38362 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50625 .00265 Mdot
.5199 .00844 Mdot
.56334 .02684 Mdot
.69929 .08402 Mdot
.06197 .22414 Mdot
.33402 .16814 Mdot
.39984 .04068 Mdot
.32515 .57187 Mdot
.03785 .44047 Mdot
.69431 .40571 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.48621 .61219 Mdot
.45608 .59941 Mdot
.36091 .55921 Mdot
.08266 .44607 Mdot
.68592 .37283 Mdot
.50883 .50858 Mdot
.34496 .51676 Mdot
.98361 .39471 Mdot
.6468 .40988 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48652 .61232 Mdot
.45708 .59984 Mdot
.36405 .56053 Mdot
.091 .44928 Mdot
.68877 .36944 Mdot
.50781 .5062 Mdot
.33858 .51344 Mdot
.96665 .38817 Mdot
.64438 .41886 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47781 .60862 Mdot
.4294 .58812 Mdot
.27854 .52479 Mdot
.89277 .37961 Mdot
.65595 .47167 Mdot
.61738 .5942 Mdot
.73935 .07538 Mdot
.09952 .2226 Mdot
.31995 .13623 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51884 .00799 Mdot
.55997 .02542 Mdot
.68895 .07971 Mdot
.03931 .21653 Mdot
.3313 .18046 Mdot
.41504 .05175 Mdot
.37731 .59472 Mdot
.17324 .49191 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.52589 .01098 Mdot
.58231 .03487 Mdot
.75678 .10783 Mdot
.16976 .25524 Mdot
.37371 .12605 Mdot
.4075 .02088 Mdot
.31021 .5579 Mdot
.99106 .42079 Mdot
.49925 .61772 Mdot
.49762 .61702 Mdot
.4924 .61481 Mdot
.4758 .60777 Mdot
.42304 .58543 Mdot
.25928 .51683 Mdot
.8572 .36953 Mdot
.64171 .48485 Mdot
.6118 .59955 Mdot
.73613 .07684 Mdot
.09828 .22382 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48618 .61218 Mdot
.456 .59938 Mdot
.36067 .55911 Mdot
.08203 .44583 Mdot
.68572 .3731 Mdot
.50894 .50877 Mdot
.34555 .51706 Mdot
.98518 .39531 Mdot
.64701 .40903 Mdot
.49899 .6176 Mdot
.49677 .61666 Mdot
.4897 .61367 Mdot
.46721 .60413 Mdot
.39587 .57394 Mdot
.17924 .48415 Mdot
.74709 .35095 Mdot
.55363 .49847 Mdot
.4391 .54725 Mdot
.23544 .49217 Mdot
.79405 .34524 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50657 .00279 Mdot
.52094 .00888 Mdot
.56664 .02824 Mdot
.70939 .08823 Mdot
.08315 .231 Mdot
.33778 .15737 Mdot
.38908 .0317 Mdot
.28713 .55503 Mdot
.95293 .41148 Mdot
.49939 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48043 .60974 Mdot
.43772 .59164 Mdot
.30396 .53536 Mdot
.94505 .39622 Mdot
.66694 .44615 Mdot
.59579 .57406 Mdot
.65979 .03956 Mdot
.9252 .16403 Mdot
.49836 .61734 Mdot
.49478 .61582 Mdot
.48338 .61099 Mdot
.44709 .5956 Mdot
.33287 .54745 Mdot
.01157 .41946 Mdot
.67293 .40874 Mdot
.54556 .53932 Mdot
.48562 .58099 Mdot
.40413 .56767 Mdot
.18738 .48407 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50661 .0028 Mdot
.52105 .00892 Mdot
.56696 .02838 Mdot
.71038 .08864 Mdot
.08517 .23163 Mdot
.33822 .15639 Mdot
.38827 .03094 Mdot
.28417 .55369 Mdot
.94682 .40954 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.5209 .00886 Mdot
.56649 .02818 Mdot
.70893 .08804 Mdot
.08221 .2307 Mdot
.33758 .15783 Mdot
.38947 .03207 Mdot
.28856 .55567 Mdot
.95589 .41243 Mdot
.68854 .45281 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.50461 .00196 Mdot
.51469 .00623 Mdot
.54679 .01983 Mdot
.64805 .06259 Mdot
.94072 .18088 Mdot
.32027 .23457 Mdot
.48397 .10118 Mdot
.62368 .08634 Mdot
.9308 .18981 Mdot
.33848 .25196 Mdot
.49982 .61796 Mdot
.49944 .6178 Mdot
.4982 .61727 Mdot
.49428 .61561 Mdot
.48178 .61031 Mdot
.442 .59345 Mdot
.31712 .54086 Mdot
.97443 .40624 Mdot
.66993 .42984 Mdot
.57458 .5591 Mdot
.58705 .00771 Mdot
.5 0 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.5357 .01514 Mdot
.6133 .04796 Mdot
.84685 .14434 Mdot
.27628 .2654 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.50482 .00204 Mdot
.51536 .00651 Mdot
.5489 .02073 Mdot
.65463 .06535 Mdot
.9575 .18718 Mdot
.32337 .22612 Mdot
.47542 .09397 Mdot
.49899 .61761 Mdot
.4968 .61668 Mdot
.48979 .6137 Mdot
.46748 .60425 Mdot
.39674 .57431 Mdot
.18174 .48516 Mdot
.74964 .35098 Mdot
.55626 .49852 Mdot
.44553 .5496 Mdot
.25467 .50008 Mdot
.82519 .3526 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.50482 .00204 Mdot
.51534 .00651 Mdot
.54885 .02071 Mdot
.65447 .06528 Mdot
.9571 .18704 Mdot
.3233 .22632 Mdot
.47565 .09415 Mdot
.59161 .07167 Mdot
.83752 .15198 Mdot
.28696 .27777 Mdot
.49868 .61747 Mdot
.49578 .61624 Mdot
.48655 .61233 Mdot
.45718 .59988 Mdot
.36435 .56066 Mdot
.09181 .44959 Mdot
.68906 .36912 Mdot
.50776 .50598 Mdot
.3381 .51318 Mdot
.96536 .38767 Mdot
.64417 .41953 Mdot
.50016 7e-05 Mdot
.50053 .00022 Mdot
.50167 .00071 Mdot
.50533 .00226 Mdot
.51699 .00721 Mdot
.55409 .02293 Mdot
.67079 .07212 Mdot
.99724 .20176 Mdot
.32784 .20432 Mdot
.44768 .07407 Mdot
.49046 .02644 Mdot
.51893 .0176 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50761 .00323 Mdot
.52424 .01028 Mdot
.57709 .03267 Mdot
.74112 .10137 Mdot
.14351 .24869 Mdot
.35864 .13296 Mdot
.38853 .01847 Mdot
.26455 .54141 Mdot
.90284 .39448 Mdot
.67798 .47906 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.477 .60828 Mdot
.42683 .58703 Mdot
.27073 .52156 Mdot
.87792 .37526 Mdot
.65079 .47766 Mdot
.61751 .59746 Mdot
.74489 .07873 Mdot
.11089 .2262 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.49332 .6152 Mdot
.47871 .609 Mdot
.43225 .58932 Mdot
.28721 .52839 Mdot
.90993 .38486 Mdot
.66066 .46397 Mdot
.61348 .58888 Mdot
.72247 .06736 Mdot
.06663 .2127 Mdot
.49926 .61772 Mdot
.49763 .61703 Mdot
.49246 .61484 Mdot
.47597 .60785 Mdot
.42359 .58566 Mdot
.26094 .51751 Mdot
.86012 .37031 Mdot
.64313 .48393 Mdot
.61305 .59944 Mdot
.73864 .07762 Mdot
.10236 .22479 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51105 .00469 Mdot
.53521 .01493 Mdot
.61174 .0473 Mdot
.84245 .14259 Mdot
.27273 .26593 Mdot
.46672 .11989 Mdot
.61114 .08926 Mdot
.90906 .18412 Mdot
.33608 .26392 Mdot
.49885 .61755 Mdot
.49633 .61648 Mdot
.48831 .61307 Mdot
.46276 .60224 Mdot
.38185 .56803 Mdot
.13954 .46828 Mdot
.71373 .35487 Mdot
.52048 .4986 Mdot
.35786 .51753 Mdot
.00928 .4026 Mdot
.64678 .394 Mdot
.50044 .00018 Mdot
.50139 .00059 Mdot
.50442 .00187 Mdot
.51407 .00597 Mdot
.5448 .01899 Mdot
.64184 .05998 Mdot
.92458 .17474 Mdot
.31626 .24207 Mdot
.4896 .10713 Mdot
.64736 .0975 Mdot
.99589 .21541 Mdot
.35059 .21921 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00466 Mdot
.53503 .01485 Mdot
.61119 .04707 Mdot
.8409 .14197 Mdot
.27145 .26609 Mdot
.46543 .11989 Mdot
.60796 .08809 Mdot
.9003 .18068 Mdot
.3326 .26717 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47446 .6072 Mdot
.41878 .58363 Mdot
.2465 .51156 Mdot
.83555 .36405 Mdot
.62966 .49079 Mdot
.59745 .59813 Mdot
.70246 .0649 Mdot
.03564 .20591 Mdot
.49758 .61701 Mdot
.4923 .61477 Mdot
.47546 .60763 Mdot
.42195 .58497 Mdot
.25601 .51548 Mdot
.8515 .36804 Mdot
.6388 .48658 Mdot
.6089 .59955 Mdot
.72989 .07478 Mdot
.08771 .22115 Mdot
.32053 .14388 Mdot
.49977 .61794 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47662 .60812 Mdot
.42564 .58652 Mdot
.26712 .52007 Mdot
.87125 .37337 Mdot
.64812 .48013 Mdot
.61646 .59847 Mdot
.74431 .07902 Mdot
.49781 .6171 Mdot
.49302 .61507 Mdot
.47776 .6086 Mdot
.42925 .58805 Mdot
.27807 .5246 Mdot
.89187 .37935 Mdot
.65567 .47205 Mdot
.61748 .59443 Mdot
.73994 .07568 Mdot
.10066 .22293 Mdot
.32025 .13572 Mdot
.50077 .00033 Mdot
.50244 .00104 Mdot
.50778 .0033 Mdot
.52479 .01051 Mdot
.57883 .0334 Mdot
.74634 .10353 Mdot
.15252 .25103 Mdot
.36336 .13031 Mdot
.39352 .01864 Mdot
.2756 .54516 Mdot
.92204 .39952 Mdot
.68079 .46894 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50588 .00249 Mdot
.51874 .00795 Mdot
.55965 .02528 Mdot
.68797 .0793 Mdot
.03711 .21578 Mdot
.33109 .18169 Mdot
.41666 .05289 Mdot
.38286 .59714 Mdot
.18878 .49809 Mdot
.77342 .36132 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51776 .00753 Mdot
.55652 .02396 Mdot
.6783 .07526 Mdot
.015 .20809 Mdot
.32923 .1942 Mdot
.4337 .06457 Mdot
.44157 .00487 Mdot
.36376 .56994 Mdot
.10565 .45851 Mdot
.49838 .61735 Mdot
.49483 .61584 Mdot
.48353 .61105 Mdot
.44756 .59581 Mdot
.33435 .54807 Mdot
.01517 .42077 Mdot
.67326 .40673 Mdot
.54288 .53745 Mdot
.47603 .57672 Mdot
.37336 .55458 Mdot
.10016 .44919 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48343 .61101 Mdot
.44725 .59568 Mdot
.3334 .54767 Mdot
.01284 .41992 Mdot
.67304 .40803 Mdot
.54461 .53866 Mdot
.48222 .57947 Mdot
.3932 .56302 Mdot
.15574 .47128 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49387 .61544 Mdot
.48048 .60976 Mdot
.43787 .5917 Mdot
.30442 .53556 Mdot
.94606 .39655 Mdot
.66707 .44561 Mdot
.59513 .57357 Mdot
.65754 .03857 Mdot
.91951 .16191 Mdot
.49911 .61766 Mdot
.49717 .61683 Mdot
.49098 .61421 Mdot
.47127 .60585 Mdot
.40871 .57937 Mdot
.2166 .4993 Mdot
.79099 .35499 Mdot
.59624 .49767 Mdot
.53722 .58155 Mdot
.53351 .61574 Mdot
.57969 .02854 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53096 .01313 Mdot
.59836 .04165 Mdot
.80408 .12714 Mdot
.23488 .26625 Mdot
.42803 .11937 Mdot
.51685 .0549 Mdot
.63091 .07049 Mdot
.91994 .17863 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52031 .00861 Mdot
.56461 .02738 Mdot
.7032 .08565 Mdot
.07027 .22686 Mdot
.33533 .16381 Mdot
.39515 .03697 Mdot
.30882 .56468 Mdot
.99987 .42709 Mdot
.69112 .42722 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.5052 .0022 Mdot
.51656 .00702 Mdot
.55272 .02235 Mdot
.66652 .07033 Mdot
.98697 .19805 Mdot
.32694 .21011 Mdot
.45553 .07947 Mdot
.51828 .03878 Mdot
.6084 .0557 Mdot
.49781 .6171 Mdot
.49302 .61507 Mdot
.47776 .6086 Mdot
.42926 .58806 Mdot
.2781 .52461 Mdot
.89192 .37936 Mdot
.65569 .47203 Mdot
.61747 .59442 Mdot
.7399 .07567 Mdot
.10058 .22291 Mdot
.32023 .13575 Mdot
.4978 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42913 .588 Mdot
.2777 .52445 Mdot
.89115 .37913 Mdot
.65544 .47236 Mdot
.61755 .59462 Mdot
.74039 .07592 Mdot
.10152 .22319 Mdot
.32049 .13533 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50713 .00303 Mdot
.52273 .00964 Mdot
.5723 .03064 Mdot
.72662 .09538 Mdot
.11711 .24133 Mdot
.34736 .1423 Mdot
.38217 .02151 Mdot
.25595 .54002 Mdot
.89116 .39258 Mdot
.6772 .4858 Mdot
.4986 .61744 Mdot
.49553 .61614 Mdot
.48575 .61199 Mdot
.45463 .5988 Mdot
.35637 .55731 Mdot
.07074 .4415 Mdot
.68246 .37807 Mdot
.51174 .51252 Mdot
.35861 .52339 Mdot
.02021 .40889 Mdot
.65158 .39021 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50349 .00148 Mdot
.51111 .00471 Mdot
.53539 .01501 Mdot
.61233 .04755 Mdot
.84411 .14325 Mdot
.27409 .26574 Mdot
.46806 .11988 Mdot
.61446 .09048 Mdot
.91812 .18767 Mdot
.33926 .26027 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50374 .00159 Mdot
.51193 .00506 Mdot
.53799 .01611 Mdot
.6205 .05099 Mdot
.86697 .15233 Mdot
.29055 .26179 Mdot
.48311 .11901 Mdot
.65037 .10337 Mdot
.0111 .22294 Mdot
.35519 .21266 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48501 .61168 Mdot
.45227 .5978 Mdot
.349 .55421 Mdot
.05172 .4343 Mdot
.67822 .3872 Mdot
.51957 .51999 Mdot
.39021 .53808 Mdot
.10891 .44418 Mdot
.6767 .35091 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50757 .00321 Mdot
.52411 .01022 Mdot
.57668 .03249 Mdot
.73987 .10086 Mdot
.1413 .2481 Mdot
.35755 .13365 Mdot
.38754 .01853 Mdot
.26253 .54077 Mdot
.89952 .39368 Mdot
.67742 .48077 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50744 .00316 Mdot
.52371 .01005 Mdot
.5754 .03195 Mdot
.73602 .09927 Mdot
.13446 .24624 Mdot
.35435 .1359 Mdot
.38502 .01895 Mdot
.25784 .53943 Mdot
.89221 .39206 Mdot
.67619 .48453 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47427 .60712 Mdot
.41818 .58337 Mdot
.24469 .51081 Mdot
.8326 .36335 Mdot
.62781 .49147 Mdot
.59477 .59762 Mdot
.69565 .06234 Mdot
.02147 .20137 Mdot
.31518 .18152 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50618 .00262 Mdot
.51969 .00835 Mdot
.56267 .02656 Mdot
.69724 .08317 Mdot
.05754 .22268 Mdot
.3334 .17049 Mdot
.40256 .04274 Mdot
.33452 .57598 Mdot
.06063 .44876 Mdot
.69798 .3939 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52199 .00932 Mdot
.56995 .02964 Mdot
.7195 .09243 Mdot
.10342 .23727 Mdot
.34289 .14801 Mdot
.38316 .02489 Mdot
.26349 .54407 Mdot
.90594 .39706 Mdot
.68141 .47927 Mdot
.49994 .61801 Mdot
.49979 .61795 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47886 .60907 Mdot
.43275 .58953 Mdot
.28874 .52903 Mdot
.91303 .38583 Mdot
.66138 .46251 Mdot
.6124 .58776 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52317 .00982 Mdot
.5737 .03123 Mdot
.73086 .09713 Mdot
.12503 .24361 Mdot
.35036 .13926 Mdot
.38287 .02009 Mdot
.25512 .53908 Mdot
.88876 .39161 Mdot
.676 .48654 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50677 .00287 Mdot
.52157 .00915 Mdot
.56862 .02908 Mdot
.71544 .09074 Mdot
.09538 .23482 Mdot
.34066 .15159 Mdot
.38492 .02735 Mdot
.2712 .54775 Mdot
.92087 .40152 Mdot
.6844 .47189 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47658 .6081 Mdot
.42551 .58647 Mdot
.26674 .51991 Mdot
.87057 .37318 Mdot
.64783 .48038 Mdot
.61631 .59855 Mdot
.74413 .079 Mdot
.11053 .22644 Mdot
.32414 .13202 Mdot
.50026 .00011 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.5263 .01115 Mdot
.58361 .03542 Mdot
.76065 .10942 Mdot
.17589 .25663 Mdot
.37781 .1248 Mdot
.41394 .02233 Mdot
.32717 .56441 Mdot
.02919 .43387 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50407 .00173 Mdot
.51298 .0055 Mdot
.54132 .01752 Mdot
.63096 .0554 Mdot
.89561 .16356 Mdot
.30586 .25354 Mdot
.49192 .11499 Mdot
.66587 .10751 Mdot
.04598 .23492 Mdot
.35807 .19288 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.5036 .00153 Mdot
.51147 .00486 Mdot
.53653 .01549 Mdot
.61592 .04906 Mdot
.85421 .14727 Mdot
.28186 .2643 Mdot
.47555 .1197 Mdot
.63271 .09713 Mdot
.96665 .20639 Mdot
.35025 .23708 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50937 .00398 Mdot
.52986 .01266 Mdot
.59487 .04018 Mdot
.79392 .12302 Mdot
.22266 .26498 Mdot
.41619 .11961 Mdot
.48973 .04545 Mdot
.54787 .03593 Mdot
.67674 .07964 Mdot
.49907 .61764 Mdot
.49705 .61678 Mdot
.49061 .61405 Mdot
.47008 .60535 Mdot
.40492 .57777 Mdot
.20549 .49478 Mdot
.77659 .35296 Mdot
.58311 .49845 Mdot
.5087 .57205 Mdot
.44734 .58011 Mdot
.30841 .53217 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47659 .60811 Mdot
.42554 .58648 Mdot
.26684 .51995 Mdot
.87073 .37323 Mdot
.6479 .48032 Mdot
.61635 .59853 Mdot
.74418 .079 Mdot
.11058 .22645 Mdot
.32414 .13199 Mdot
.50055 .00023 Mdot
.50176 .00074 Mdot
.5056 .00237 Mdot
.51783 .00756 Mdot
.55676 .02406 Mdot
.67902 .07557 Mdot
.01667 .20868 Mdot
.32936 .19325 Mdot
.43238 .06367 Mdot
.437 .00285 Mdot
.34956 .56399 Mdot
.06859 .44439 Mdot
.49778 .61709 Mdot
.49294 .61504 Mdot
.47751 .6085 Mdot
.42846 .58772 Mdot
.27567 .52361 Mdot
.88725 .37798 Mdot
.65416 .47398 Mdot
.61781 .59557 Mdot
.74246 .07704 Mdot
.10558 .22442 Mdot
.32169 .13357 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48618 .61217 Mdot
.45598 .59937 Mdot
.36061 .55909 Mdot
.08187 .44576 Mdot
.68567 .37317 Mdot
.50897 .50883 Mdot
.34571 .51713 Mdot
.9856 .39547 Mdot
.64706 .40881 Mdot
.50079 .00033 Mdot
.50252 .00107 Mdot
.50802 .0034 Mdot
.52553 .01083 Mdot
.58119 .0344 Mdot
.7534 .10644 Mdot
.1643 .25395 Mdot
.37025 .12728 Mdot
.40242 .01988 Mdot
.29721 .55301 Mdot
.9637 .41191 Mdot
.68417 .44527 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52177 .00923 Mdot
.56925 .02935 Mdot
.71737 .09154 Mdot
.09921 .23599 Mdot
.34169 .14986 Mdot
.38398 .02613 Mdot
.26724 .54588 Mdot
.91316 .3992 Mdot
.68298 .47577 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50578 .00245 Mdot
.51842 .00781 Mdot
.55864 .02485 Mdot
.68484 .078 Mdot
.03004 .21335 Mdot
.33045 .18566 Mdot
.42197 .05657 Mdot
.4011 .60513 Mdot
.24123 .51923 Mdot
.84299 .37191 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50552 .00234 Mdot
.51759 .00746 Mdot
.55599 .02373 Mdot
.67665 .07457 Mdot
.01113 .20672 Mdot
.32893 .19641 Mdot
.43676 .06664 Mdot
.45222 .00955 Mdot
.49871 .61749 Mdot
.4959 .6163 Mdot
.48694 .6125 Mdot
.45841 .6004 Mdot
.36821 .56229 Mdot
.10215 .4536 Mdot
.69317 .36527 Mdot
.50787 .50351 Mdot
.33436 .5108 Mdot
.95488 .3835 Mdot
.64218 .42477 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.51009 .00428 Mdot
.53215 .01363 Mdot
.6021 .04323 Mdot
.81491 .13152 Mdot
.24687 .26697 Mdot
.44014 .11945 Mdot
.54573 .06526 Mdot
.71898 .10707 Mdot
.12644 .25183 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50659 .00279 Mdot
.52098 .0089 Mdot
.56675 .02829 Mdot
.70973 .08837 Mdot
.08385 .23122 Mdot
.33793 .15703 Mdot
.3888 .03144 Mdot
.2861 .55457 Mdot
.95079 .4108 Mdot
.68812 .4557 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51494 .00634 Mdot
.54757 .02017 Mdot
.65051 .06362 Mdot
.94702 .18326 Mdot
.32155 .23147 Mdot
.48105 .09858 Mdot
.61221 .08106 Mdot
.89809 .17668 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48601 .6121 Mdot
.45546 .59915 Mdot
.35895 .55839 Mdot
.07751 .44409 Mdot
.68434 .37504 Mdot
.50988 .51021 Mdot
.35023 .51936 Mdot
.99763 .40012 Mdot
.64859 .40231 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50536 .00227 Mdot
.51707 .00724 Mdot
.55432 .02303 Mdot
.6715 .07242 Mdot
.99894 .20237 Mdot
.32798 .20335 Mdot
.44636 .07316 Mdot
.48579 .02437 Mdot
.50394 .01122 Mdot
.528 .01487 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00341 Mdot
.52565 .01088 Mdot
.58157 .03456 Mdot
.75454 .10691 Mdot
.16616 .25439 Mdot
.3714 .12685 Mdot
.40407 .02019 Mdot
.3014 .55458 Mdot
.97235 .41467 Mdot
.68456 .44017 Mdot
.4979 .61714 Mdot
.49331 .6152 Mdot
.47868 .60899 Mdot
.43216 .58928 Mdot
.28693 .52828 Mdot
.90937 .38469 Mdot
.66053 .46424 Mdot
.61367 .58908 Mdot
.72319 .06768 Mdot
.06805 .21314 Mdot
.31392 .15196 Mdot
.49897 .6176 Mdot
.49671 .61664 Mdot
.48951 .61358 Mdot
.46658 .60386 Mdot
.39388 .57311 Mdot
.17355 .48186 Mdot
.7415 .35101 Mdot
.54784 .49835 Mdot
.42488 .54204 Mdot
.19336 .47495 Mdot
.73807 .33665 Mdot
.50069 .00029 Mdot
.50218 .00093 Mdot
.50696 .00295 Mdot
.52216 .0094 Mdot
.5705 .02988 Mdot
.72118 .09312 Mdot
.10668 .23825 Mdot
.34388 .1466 Mdot
.38268 .02398 Mdot
.26103 .54285 Mdot
.90121 .39566 Mdot
.68024 .48147 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50703 .00298 Mdot
.52241 .0095 Mdot
.57129 .03021 Mdot
.72355 .0941 Mdot
.11126 .23962 Mdot
.34534 .14467 Mdot
.38227 .02282 Mdot
.25826 .54139 Mdot
.89585 .39405 Mdot
.67875 .48386 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49072 .6141 Mdot
.47044 .6055 Mdot
.40608 .57825 Mdot
.20886 .49615 Mdot
.78085 .35351 Mdot
.5871 .49829 Mdot
.51756 .57506 Mdot
.47432 .59131 Mdot
.5001 4e-05 Mdot
.50032 .00013 Mdot
.501 .00043 Mdot
.5032 .00136 Mdot
.51019 .00432 Mdot
.53246 .01376 Mdot
.60308 .04365 Mdot
.81774 .13266 Mdot
.24983 .26705 Mdot
.44319 .1195 Mdot
.55312 .06794 Mdot
.74127 .11628 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48403 .61126 Mdot
.44914 .59648 Mdot
.33927 .55013 Mdot
.02724 .42519 Mdot
.67455 .40006 Mdot
.53426 .53133 Mdot
.44498 .56285 Mdot
.27478 .51285 Mdot
.86875 .36709 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61225 Mdot
.45659 .59963 Mdot
.36252 .55989 Mdot
.08692 .44771 Mdot
.68733 .37107 Mdot
.5082 .50733 Mdot
.34137 .51492 Mdot
.97407 .39103 Mdot
.6455 .41497 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.47982 .60947 Mdot
.43577 .59081 Mdot
.29798 .53287 Mdot
.93221 .39198 Mdot
.66508 .45294 Mdot
.60351 .57998 Mdot
.68647 .05128 Mdot
.98941 .18722 Mdot
.30822 .19704 Mdot
.49999 .61803 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48115 .61004 Mdot
.44 .5926 Mdot
.31097 .53829 Mdot
.96052 .40144 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47726 .60839 Mdot
.42766 .58738 Mdot
.27324 .5226 Mdot
.88263 .37662 Mdot
.65255 .47583 Mdot
.61782 .59657 Mdot
.74412 .07806 Mdot
.10899 .2255 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.48219 .61048 Mdot
.44332 .59401 Mdot
.32122 .54257 Mdot
.98389 .40955 Mdot
.67068 .42446 Mdot
.56717 .55406 Mdot
.56145 .6145 Mdot
.64564 .05203 Mdot
.91905 .16898 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.5203 .00861 Mdot
.56461 .02738 Mdot
.70318 .08564 Mdot
.07022 .22685 Mdot
.33532 .16384 Mdot
.39517 .03699 Mdot
.30891 .56472 Mdot
9e-05 .42717 Mdot
.69113 .42709 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.5109 .00462 Mdot
.53471 .01472 Mdot
.61019 .04664 Mdot
.83805 .14083 Mdot
.26903 .26636 Mdot
.46299 .11987 Mdot
.60193 .08587 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47726 .60839 Mdot
.42767 .58738 Mdot
.27328 .52261 Mdot
.8827 .37664 Mdot
.65257 .47581 Mdot
.61782 .59656 Mdot
.7441 .07805 Mdot
.49906 .61763 Mdot
.497 .61676 Mdot
.49044 .61398 Mdot
.46953 .60512 Mdot
.40321 .57704 Mdot
.20049 .49275 Mdot
.7705 .35228 Mdot
.57726 .49861 Mdot
.49541 .56745 Mdot
.40667 .56319 Mdot
.18583 .48155 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.4919 .6146 Mdot
.47421 .6071 Mdot
.418 .58329 Mdot
.24415 .51059 Mdot
.83173 .36315 Mdot
.62725 .49166 Mdot
.59396 .59746 Mdot
.69355 .06155 Mdot
.01702 .19991 Mdot
.49877 .61751 Mdot
.49607 .61637 Mdot
.48747 .61272 Mdot
.46008 .60111 Mdot
.37345 .56449 Mdot
.11636 .45915 Mdot
.69988 .36063 Mdot
.51038 .50092 Mdot
.33643 .51053 Mdot
.95811 .38421 Mdot
.6419 .42261 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51433 .00608 Mdot
.54564 .01935 Mdot
.64448 .06109 Mdot
.93148 .17738 Mdot
.31811 .23895 Mdot
.48754 .10471 Mdot
.6383 .09317 Mdot
.97137 .20585 Mdot
.34715 .23225 Mdot
.49962 .61787 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48765 .6128 Mdot
.46066 .60136 Mdot
.37527 .56526 Mdot
.12137 .46111 Mdot
.70255 .35919 Mdot
.51193 .50022 Mdot
.33918 .51127 Mdot
.96421 .38629 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51388 .00589 Mdot
.5442 .01874 Mdot
.63998 .05919 Mdot
.91969 .17287 Mdot
.31482 .2442 Mdot
.49073 .10872 Mdot
.65275 .10013 Mdot
.01031 .22098 Mdot
.35241 .21143 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.47479 .60734 Mdot
.41984 .58407 Mdot
.24966 .51286 Mdot
.84075 .36531 Mdot
.63281 .48952 Mdot
.60174 .59883 Mdot
.7131 .06883 Mdot
.05681 .21242 Mdot
.3171 .16087 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50751 .00319 Mdot
.52393 .01015 Mdot
.57612 .03225 Mdot
.73818 .10016 Mdot
.13832 .2473 Mdot
.35613 .13461 Mdot
.38634 .01867 Mdot
.26019 .54007 Mdot
.89579 .39283 Mdot
.67678 .48268 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49087 .61416 Mdot
.47091 .6057 Mdot
.40757 .57889 Mdot
.21325 .49794 Mdot
.78653 .35431 Mdot
.59228 .49798 Mdot
.52883 .57882 Mdot
.50839 .6054 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50854 .00362 Mdot
.5272 .01153 Mdot
.58647 .03663 Mdot
.76915 .1129 Mdot
.18884 .25938 Mdot
.38721 .1226 Mdot
.4302 .02657 Mdot
.3718 .58195 Mdot
.14125 .47554 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50375 .00159 Mdot
.51195 .00507 Mdot
.53805 .01613 Mdot
.62069 .05107 Mdot
.86749 .15253 Mdot
.29088 .26167 Mdot
.48337 .11896 Mdot
.65096 .10357 Mdot
.01252 .22346 Mdot
.35532 .21186 Mdot
.49755 .61699 Mdot
.49219 .61472 Mdot
.47511 .60748 Mdot
.42084 .5845 Mdot
.25268 .5141 Mdot
.84581 .36658 Mdot
.63571 .48818 Mdot
.60539 .59929 Mdot
.72185 .07198 Mdot
.07332 .21722 Mdot
.31866 .15162 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50443 .00188 Mdot
.51412 .00599 Mdot
.54497 .01906 Mdot
.64236 .0602 Mdot
.92595 .17526 Mdot
.31665 .24147 Mdot
.48924 .10667 Mdot
.6457 .0967 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48478 .61158 Mdot
.45155 .5975 Mdot
.34677 .55328 Mdot
.04605 .43218 Mdot
.67721 .39008 Mdot
.52257 .52246 Mdot
.40167 .54332 Mdot
.14249 .45785 Mdot
.697 .34271 Mdot
.49823 .61729 Mdot
.49438 .61565 Mdot
.48208 .61044 Mdot
.44297 .59386 Mdot
.32012 .54211 Mdot
.98135 .40866 Mdot
.67049 .42591 Mdot
.56918 .55542 Mdot
.5684 .61755 Mdot
.6671 .061 Mdot
.97287 .18898 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51775 .00752 Mdot
.55649 .02394 Mdot
.67819 .07521 Mdot
.01473 .20799 Mdot
.32921 .19436 Mdot
.43392 .06471 Mdot
.44233 .0052 Mdot
.36612 .57093 Mdot
.11195 .46095 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48835 .6131 Mdot
.46291 .60231 Mdot
.38233 .56823 Mdot
.1409 .46882 Mdot
.71466 .35461 Mdot
.5213 .49853 Mdot
.35979 .51821 Mdot
.01412 .4044 Mdot
.6473 .39133 Mdot
.49786 .61713 Mdot
.49319 .61515 Mdot
.4783 .60883 Mdot
.43097 .58878 Mdot
.28332 .52678 Mdot
.90215 .38246 Mdot
.65868 .46756 Mdot
.61571 .59148 Mdot
.73141 .07151 Mdot
.08422 .21805 Mdot
.31651 .14356 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50276 .00117 Mdot
.50881 .00373 Mdot
.52805 .01189 Mdot
.58916 .03777 Mdot
.77712 .11617 Mdot
.20036 .26157 Mdot
.39638 .12115 Mdot
.44773 .03173 Mdot
.42207 .60217 Mdot
.28412 .53278 Mdot
.49982 .61796 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49432 .61563 Mdot
.4819 .61036 Mdot
.4424 .59362 Mdot
.31838 .54138 Mdot
.97733 .40725 Mdot
.67017 .4282 Mdot
.57233 .55757 Mdot
.57928 .0043 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47949 .60934 Mdot
.43475 .59038 Mdot
.29486 .53158 Mdot
.92566 .38985 Mdot
.66396 .45629 Mdot
.60694 .5828 Mdot
.69853 .05661 Mdot
.01649 .19651 Mdot
.30975 .18125 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48467 .61153 Mdot
.45118 .59734 Mdot
.3456 .55278 Mdot
.04308 .43106 Mdot
.67672 .39162 Mdot
.52425 .5238 Mdot
.408 .54619 Mdot
.16133 .46558 Mdot
.71202 .34035 Mdot
.49813 .61724 Mdot
.49406 .61551 Mdot
.48107 .61001 Mdot
.43974 .59249 Mdot
.31017 .53796 Mdot
.95873 .40083 Mdot
.6685 .43866 Mdot
.58639 .56728 Mdot
.62758 .02546 Mdot
.84029 .13147 Mdot
.25434 .2559 Mdot
.49742 .61694 Mdot
.49177 .61455 Mdot
.47379 .60692 Mdot
.41668 .58274 Mdot
.24023 .50898 Mdot
.82549 .36171 Mdot
.62313 .49297 Mdot
.58758 .59606 Mdot
.67687 .05519 Mdot
.98014 .18743 Mdot
.31312 .20579 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51573 .00667 Mdot
.55007 .02122 Mdot
.65827 .06687 Mdot
.96664 .19058 Mdot
.32468 .22128 Mdot
.4698 .08969 Mdot
.5699 .06186 Mdot
.7715 .1246 Mdot
.20966 .2708 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.5061 .00259 Mdot
.51943 .00824 Mdot
.56183 .0262 Mdot
.69465 .08209 Mdot
.05192 .2208 Mdot
.33268 .17352 Mdot
.40621 .04544 Mdot
.34705 .58147 Mdot
.09218 .46052 Mdot
.70665 .37976 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50636 .0027 Mdot
.52027 .00859 Mdot
.56449 .02733 Mdot
.70281 .08549 Mdot
.06946 .2266 Mdot
.33519 .16423 Mdot
.39558 .03732 Mdot
.31034 .56535 Mdot
.00332 .42829 Mdot
.69132 .42521 Mdot
.49863 .61745 Mdot
.49564 .61619 Mdot
.48612 .61215 Mdot
.45581 .5993 Mdot
.36006 .55886 Mdot
.08043 .44521 Mdot
.68522 .37378 Mdot
.50924 .50927 Mdot
.34712 .51783 Mdot
.98934 .39692 Mdot
.64754 .40679 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49293 .61504 Mdot
.47749 .60849 Mdot
.4284 .58769 Mdot
.27548 .52353 Mdot
.88689 .37787 Mdot
.65404 .47412 Mdot
.61782 .59565 Mdot
.74262 .07713 Mdot
.1059 .22452 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47888 .60908 Mdot
.4328 .58956 Mdot
.2889 .5291 Mdot
.91337 .38594 Mdot
.66146 .46235 Mdot
.61228 .58764 Mdot
.71789 .06527 Mdot
.05739 .20982 Mdot
.31266 .15776 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.5059 .0025 Mdot
.51881 .00798 Mdot
.55987 .02538 Mdot
.68864 .07958 Mdot
.03861 .21629 Mdot
.33123 .18085 Mdot
.41556 .05211 Mdot
.37907 .59549 Mdot
.17816 .49386 Mdot
.76242 .36109 Mdot
.4989 .61757 Mdot
.4965 .61655 Mdot
.48885 .61331 Mdot
.4645 .60298 Mdot
.38734 .57034 Mdot
.15494 .47441 Mdot
.72515 .3524 Mdot
.53118 .49815 Mdot
.38368 .52687 Mdot
.07682 .42839 Mdot
.65915 .3599 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52247 .00953 Mdot
.57147 .03028 Mdot
.7241 .09433 Mdot
.11232 .23993 Mdot
.3457 .14424 Mdot
.38221 .02257 Mdot
.25774 .54111 Mdot
.89482 .39374 Mdot
.67843 .4843 Mdot
.49971 .61791 Mdot
.49906 .61764 Mdot
.49701 .61677 Mdot
.49047 .61399 Mdot
.46963 .60516 Mdot
.40352 .57717 Mdot
.20139 .49311 Mdot
.77158 .35239 Mdot
.57831 .49859 Mdot
.49781 .56829 Mdot
.41403 .56626 Mdot
.49805 .61721 Mdot
.49378 .6154 Mdot
.4802 .60964 Mdot
.43699 .59133 Mdot
.30171 .53443 Mdot
.94019 .3946 Mdot
.66629 .44875 Mdot
.59885 .57635 Mdot
.67034 .04418 Mdot
.95127 .17362 Mdot
.30416 .2181 Mdot
.49873 .61749 Mdot
.49595 .61631 Mdot
.48708 .61256 Mdot
.45886 .60059 Mdot
.36962 .56288 Mdot
.10596 .45508 Mdot
.69485 .36395 Mdot
.50827 .50272 Mdot
.33409 .51038 Mdot
.95372 .38296 Mdot
.6418 .42526 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.48219 .61048 Mdot
.4433 .594 Mdot
.32117 .54255 Mdot
.98377 .40951 Mdot
.67067 .42453 Mdot
.56727 .55413 Mdot
.5618 .61465 Mdot
.64671 .05248 Mdot
.49858 .61743 Mdot
.49547 .61611 Mdot
.48556 .61191 Mdot
.45401 .59854 Mdot
.35443 .55649 Mdot
.0657 .43959 Mdot
.68119 .38039 Mdot
.51345 .51436 Mdot
.36586 .52682 Mdot
.04005 .41667 Mdot
.6548 .37994 Mdot
.50077 .00032 Mdot
.50244 .00104 Mdot
.50778 .0033 Mdot
.52478 .01051 Mdot
.5788 .03339 Mdot
.74626 .1035 Mdot
.15239 .251 Mdot
.36329 .13034 Mdot
.39343 .01863 Mdot
.27541 .54509 Mdot
.92168 .39942 Mdot
.68075 .46913 Mdot
.49961 .61787 Mdot
.49875 .6175 Mdot
.496 .61634 Mdot
.48727 .61263 Mdot
.45945 .60084 Mdot
.37145 .56365 Mdot
.11094 .45702 Mdot
.69716 .36231 Mdot
.50909 .5018 Mdot
.33464 .51022 Mdot
.95443 .38305 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.47939 .60929 Mdot
.43442 .59024 Mdot
.29383 .53115 Mdot
.92351 .38916 Mdot
.66356 .45738 Mdot
.60798 .58369 Mdot
.70224 .05825 Mdot
.02456 .1992 Mdot
.31019 .17653 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.48059 .6098 Mdot
.43822 .59185 Mdot
.3055 .53601 Mdot
.94841 .39734 Mdot
.66736 .44433 Mdot
.59357 .57243 Mdot
.6522 .03623 Mdot
.90588 .15678 Mdot
.29266 .23904 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.48931 .6135 Mdot
.46595 .6036 Mdot
.39191 .57227 Mdot
.16791 .4796 Mdot
.73624 .35124 Mdot
.54241 .49824 Mdot
.41143 .53709 Mdot
.15436 .45915 Mdot
.70038 .33746 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00325 Mdot
.52445 .01037 Mdot
.57776 .03295 Mdot
.74311 .1022 Mdot
.14698 .2496 Mdot
.36041 .1319 Mdot
.39027 .01846 Mdot
.26828 .54264 Mdot
.90912 .39606 Mdot
.679 .47581 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52656 .01126 Mdot
.58443 .03577 Mdot
.76309 .11042 Mdot
.17967 .25746 Mdot
.38045 .12409 Mdot
.41831 .0234 Mdot
.33894 .56898 Mdot
.05715 .44388 Mdot
.69147 .39203 Mdot
.5007 .0003 Mdot
.50223 .00094 Mdot
.50709 .00301 Mdot
.52259 .00958 Mdot
.57185 .03045 Mdot
.72526 .09482 Mdot
.11453 .24058 Mdot
.34645 .14333 Mdot
.38215 .02206 Mdot
.25679 .54056 Mdot
.89292 .39315 Mdot
.67782 .48509 Mdot
.49819 .61726 Mdot
.49422 .61558 Mdot
.48158 .61022 Mdot
.44137 .59318 Mdot
.31519 .54005 Mdot
.97002 .40471 Mdot
.66956 .43234 Mdot
.57798 .56144 Mdot
.59875 .01284 Mdot
.75832 .09862 Mdot
.1563 .24596 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52399 .01017 Mdot
.57631 .03233 Mdot
.73875 .10039 Mdot
.13933 .24757 Mdot
.3566 .13428 Mdot
.38673 .01862 Mdot
.26093 .54029 Mdot
.89696 .39309 Mdot
.67698 .48208 Mdot
.49844 .61737 Mdot
.49503 .61593 Mdot
.48417 .61132 Mdot
.4496 .59667 Mdot
.34068 .55072 Mdot
.03074 .42648 Mdot
.67498 .39816 Mdot
.53191 .52961 Mdot
.43638 .559 Mdot
.24796 .50158 Mdot
.82082 .35405 Mdot
.49768 .61705 Mdot
.49262 .61491 Mdot
.47649 .60807 Mdot
.42524 .58636 Mdot
.26592 .51957 Mdot
.86906 .37276 Mdot
.64719 .48091 Mdot
.61596 .59873 Mdot
.74367 .07893 Mdot
.10993 .22636 Mdot
.3241 .13236 Mdot
.49882 .61753 Mdot
.49623 .61643 Mdot
.48798 .61294 Mdot
.46171 .6018 Mdot
.37857 .56665 Mdot
.13044 .46468 Mdot
.70783 .35685 Mdot
.51563 .49924 Mdot
.34683 .51371 Mdot
.98213 .39264 Mdot
.64418 .40917 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.53569 .01513 Mdot
.61326 .04794 Mdot
.84674 .1443 Mdot
.27619 .26542 Mdot
.47014 .11986 Mdot
.61956 .09234 Mdot
.93191 .19305 Mdot
.34331 .25426 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50562 .00238 Mdot
.5179 .00759 Mdot
.55698 .02415 Mdot
.67971 .07585 Mdot
.01826 .20924 Mdot
.32948 .19235 Mdot
.43113 .06282 Mdot
.43268 .00096 Mdot
.33623 .55842 Mdot
.03524 .43201 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50762 .00323 Mdot
.52428 .01029 Mdot
.57721 .03271 Mdot
.74147 .10152 Mdot
.14412 .24885 Mdot
.35894 .13277 Mdot
.38882 .01846 Mdot
.26516 .54161 Mdot
.90385 .39473 Mdot
.67815 .47854 Mdot
.49959 .61786 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48672 .6124 Mdot
.45772 .60011 Mdot
.36604 .56137 Mdot
.09631 .45134 Mdot
.69078 .3674 Mdot
.50763 .50485 Mdot
.33594 .51192 Mdot
.95948 .38537 Mdot
.49957 .61785 Mdot
.49865 .61746 Mdot
.49568 .6162 Mdot
.48625 .6122 Mdot
.45621 .59947 Mdot
.36131 .55938 Mdot
.08373 .44648 Mdot
.68626 .37239 Mdot
.50865 .50826 Mdot
.344 .51627 Mdot
.98106 .39372 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50694 .00294 Mdot
.5221 .00937 Mdot
.5703 .02979 Mdot
.72056 .09287 Mdot
.10549 .2379 Mdot
.34351 .14711 Mdot
.38284 .02431 Mdot
.26188 .54328 Mdot
.90285 .39614 Mdot
.68066 .48072 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.51958 .0083 Mdot
.56232 .02641 Mdot
.69617 .08272 Mdot
.05522 .22191 Mdot
.33309 .17174 Mdot
.40404 .04385 Mdot
.49891 .61757 Mdot
.49654 .61657 Mdot
.48897 .61336 Mdot
.46486 .60314 Mdot
.38847 .57082 Mdot
.15815 .47569 Mdot
.72776 .35204 Mdot
.53377 .49815 Mdot
.39007 .52922 Mdot
.09428 .43523 Mdot
.6652 .35284 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48193 .61037 Mdot
.4425 .59366 Mdot
.31868 .54151 Mdot
.97801 .40749 Mdot
.67022 .42781 Mdot
.57179 .5572 Mdot
.57745 .00349 Mdot
.69473 .07249 Mdot
.0365 .21123 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.51039 .00441 Mdot
.5331 .01404 Mdot
.60511 .0445 Mdot
.82357 .13501 Mdot
.2557 .26708 Mdot
.44926 .11963 Mdot
.56799 .07338 Mdot
.49886 .61755 Mdot
.49635 .61649 Mdot
.48838 .61311 Mdot
.463 .60235 Mdot
.38261 .56835 Mdot
.14166 .46912 Mdot
.71519 .35446 Mdot
.52177 .49849 Mdot
.3609 .51861 Mdot
.01694 .40546 Mdot
.64762 .38978 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49085 .61415 Mdot
.47086 .60568 Mdot
.40739 .57881 Mdot
.21271 .49771 Mdot
.78582 .3542 Mdot
.59164 .49803 Mdot
.52746 .57837 Mdot
.50425 .60369 Mdot
.48742 .60763 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50395 .00168 Mdot
.5126 .00534 Mdot
.54012 .01701 Mdot
.62719 .05381 Mdot
.88538 .15957 Mdot
.30102 .25688 Mdot
.49008 .11685 Mdot
.66428 .10766 Mdot
.0434 .23431 Mdot
.35823 .19457 Mdot
.4995 .61782 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48397 .61124 Mdot
.44897 .5964 Mdot
.33872 .5499 Mdot
.02588 .42469 Mdot
.67439 .4008 Mdot
.5352 .53201 Mdot
.44839 .56438 Mdot
.28551 .51737 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48113 .61003 Mdot
.43994 .59258 Mdot
.31078 .53821 Mdot
.96009 .40129 Mdot
.66864 .43791 Mdot
.5854 .56659 Mdot
.6242 .02398 Mdot
.83097 .12779 Mdot
.24623 .25665 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47488 .60738 Mdot
.42011 .58419 Mdot
.25048 .5132 Mdot
.84211 .36565 Mdot
.6336 .48917 Mdot
.60277 .59898 Mdot
.71561 .06974 Mdot
.06162 .21385 Mdot
.3175 .15814 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.51481 .00628 Mdot
.54716 .01999 Mdot
.64923 .06308 Mdot
.94374 .18202 Mdot
.3209 .2331 Mdot
.48262 .09995 Mdot
.61833 .08387 Mdot
.91562 .18374 Mdot
.33364 .25835 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49507 .61595 Mdot
.48431 .61138 Mdot
.45004 .59686 Mdot
.34206 .5513 Mdot
.03419 .42776 Mdot
.67543 .39631 Mdot
.52966 .52795 Mdot
.42814 .55529 Mdot
.22246 .49091 Mdot
.49854 .61742 Mdot
.49536 .61606 Mdot
.48521 .61176 Mdot
.4529 .59807 Mdot
.35096 .55503 Mdot
.05673 .43619 Mdot
.6792 .38471 Mdot
.51716 .51789 Mdot
.38081 .53377 Mdot
.08193 .43332 Mdot
.66551 .36067 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51996 .00846 Mdot
.56352 .02692 Mdot
.69985 .08426 Mdot
.06317 .22454 Mdot
.3342 .16751 Mdot
.39913 .04013 Mdot
.32269 .57079 Mdot
.03198 .43837 Mdot
.69362 .40892 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51748 .00741 Mdot
.55565 .02359 Mdot
.67561 .07414 Mdot
.00869 .20586 Mdot
.32874 .1978 Mdot
.43869 .06795 Mdot
.45893 .01251 Mdot
.41825 .59289 Mdot
.26027 .52039 Mdot
.49845 .61738 Mdot
.49505 .61594 Mdot
.48424 .61135 Mdot
.44982 .59676 Mdot
.34138 .55101 Mdot
.03249 .42713 Mdot
.6752 .39722 Mdot
.53076 .52877 Mdot
.43218 .55711 Mdot
.23492 .49612 Mdot
.8 .34924 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48205 .61042 Mdot
.44286 .59381 Mdot
.31978 .54197 Mdot
.98055 .40838 Mdot
.67042 .42637 Mdot
.56981 .55585 Mdot
.57058 .00048 Mdot
.67377 .06378 Mdot
.98884 .19472 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00225 Mdot
.51694 .00718 Mdot
.55393 .02286 Mdot
.67027 .0719 Mdot
.996 .20132 Mdot
.32773 .20502 Mdot
.44864 .07473 Mdot
.49385 .02794 Mdot
.52982 .02223 Mdot
.49799 .61718 Mdot
.4936 .61532 Mdot
.47961 .60939 Mdot
.43513 .59054 Mdot
.296 .53205 Mdot
.92805 .39063 Mdot
.66438 .45508 Mdot
.60573 .58179 Mdot
.69427 .05472 Mdot
.00706 .19331 Mdot
.30926 .18677 Mdot
.49931 .61774 Mdot
.4978 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42911 .58799 Mdot
.27765 .52443 Mdot
.89106 .37911 Mdot
.65541 .47239 Mdot
.61756 .59464 Mdot
.74044 .07595 Mdot
.10162 .22322 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48443 .61143 Mdot
.45044 .59702 Mdot
.3433 .55182 Mdot
.03728 .42891 Mdot
.67585 .39466 Mdot
.52772 .52648 Mdot
.42094 .55204 Mdot
.20039 .48173 Mdot
.75261 .34129 Mdot
.49831 .61732 Mdot
.49461 .61575 Mdot
.48282 .61075 Mdot
.4453 .59485 Mdot
.32735 .54513 Mdot
.99831 .41468 Mdot
.6718 .41624 Mdot
.55579 .54633 Mdot
.52177 .597 Mdot
.52029 .61712 Mdot
.54915 .01784 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50333 .00141 Mdot
.5106 .00449 Mdot
.53375 .01431 Mdot
.60714 .04536 Mdot
.82937 .13735 Mdot
.26126 .26692 Mdot
.45501 .11975 Mdot
.58218 .07859 Mdot
.82721 .15144 Mdot
.28342 .28196 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49757 .617 Mdot
.49226 .61475 Mdot
.47536 .60759 Mdot
.42164 .58483 Mdot
.25506 .51509 Mdot
.84988 .36762 Mdot
.63794 .48705 Mdot
.60796 .59951 Mdot
.72779 .07406 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .0014 Mdot
.5105 .00445 Mdot
.53343 .01417 Mdot
.60614 .04494 Mdot
.82651 .1362 Mdot
.25855 .26702 Mdot
.45221 .11969 Mdot
.57527 .07605 Mdot
.80706 .14326 Mdot
.26241 .28142 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52052 .0087 Mdot
.56528 .02767 Mdot
.70524 .0865 Mdot
.07456 .22825 Mdot
.33608 .16163 Mdot
.39295 .03515 Mdot
.30109 .56126 Mdot
.98268 .42125 Mdot
.6902 .43727 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50199 .00085 Mdot
.50635 .00269 Mdot
.52023 .00858 Mdot
.56438 .02728 Mdot
.70248 .08535 Mdot
.06875 .22637 Mdot
.33507 .1646 Mdot
.39597 .03763 Mdot
.31169 .56595 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.50729 .00309 Mdot
.52321 .00984 Mdot
.57384 .03129 Mdot
.73129 .09731 Mdot
.12582 .24384 Mdot
.35068 .13897 Mdot
.38299 .01997 Mdot
.25519 .53905 Mdot
.88877 .39158 Mdot
.67595 .4865 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49545 .6161 Mdot
.48549 .61188 Mdot
.4538 .59845 Mdot
.35377 .55621 Mdot
.06399 .43894 Mdot
.68079 .3812 Mdot
.5141 .51501 Mdot
.36853 .52807 Mdot
.04742 .41958 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.503 .00127 Mdot
.50956 .00405 Mdot
.53043 .0129 Mdot
.59669 .04095 Mdot
.79922 .12517 Mdot
.22916 .26572 Mdot
.42241 .11943 Mdot
.50382 .05032 Mdot
.59097 .05386 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51606 .00681 Mdot
.55114 .02168 Mdot
.6616 .06827 Mdot
.9749 .19363 Mdot
.3257 .2168 Mdot
.46426 .08563 Mdot
.54966 .05278 Mdot
.70833 .09807 Mdot
.09761 .24059 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50503 .00213 Mdot
.51604 .0068 Mdot
.55106 .02164 Mdot
.66136 .06817 Mdot
.9743 .19341 Mdot
.32563 .21713 Mdot
.46467 .08593 Mdot
.55116 .05345 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48765 .6128 Mdot
.46067 .60136 Mdot
.3753 .56527 Mdot
.12143 .46114 Mdot
.70258 .35917 Mdot
.51195 .50022 Mdot
.33922 .51128 Mdot
.9643 .38632 Mdot
.64248 .41914 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.5148 .00628 Mdot
.54714 .01998 Mdot
.64915 .06305 Mdot
.94355 .18195 Mdot
.32086 .23319 Mdot
.48271 .10003 Mdot
.61869 .08404 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47459 .60726 Mdot
.41919 .5838 Mdot
.24772 .51206 Mdot
.83754 .36453 Mdot
.63088 .49031 Mdot
.59916 .59843 Mdot
.70674 .06649 Mdot
.04428 .20861 Mdot
.31626 .16809 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47984 .60948 Mdot
.43584 .59084 Mdot
.2982 .53297 Mdot
.93269 .39214 Mdot
.66516 .45269 Mdot
.60324 .57977 Mdot
.68555 .05087 Mdot
.98728 .18648 Mdot
.30807 .19826 Mdot
.49761 .61702 Mdot
.4924 .61481 Mdot
.47578 .60776 Mdot
.42297 .5854 Mdot
.25908 .51674 Mdot
.85685 .36944 Mdot
.64154 .48496 Mdot
.61164 .59955 Mdot
.73579 .07673 Mdot
.09773 .22369 Mdot
.32211 .13868 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52601 .01103 Mdot
.58268 .03503 Mdot
.75788 .10828 Mdot
.17151 .25564 Mdot
.37486 .12568 Mdot
.40925 .02126 Mdot
.31478 .55965 Mdot
.00107 .42415 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48377 .61115 Mdot
.44832 .59613 Mdot
.3367 .54905 Mdot
.02091 .42286 Mdot
.67384 .40353 Mdot
.53869 .53451 Mdot
.46102 .57003 Mdot
.32544 .53425 Mdot
.97746 .40297 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52226 .00944 Mdot
.57083 .03001 Mdot
.72216 .09353 Mdot
.10857 .23882 Mdot
.34447 .14579 Mdot
.38248 .02349 Mdot
.25978 .54221 Mdot
.89881 .39494 Mdot
.6796 .48255 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.5064 .00272 Mdot
.5204 .00865 Mdot
.5649 .02751 Mdot
.70409 .08602 Mdot
.07215 .22747 Mdot
.33565 .16285 Mdot
.39417 .03616 Mdot
.30537 .56316 Mdot
.99216 .42445 Mdot
.6907 .43172 Mdot
.49765 .61704 Mdot
.49252 .61486 Mdot
.47618 .60793 Mdot
.42424 .58594 Mdot
.26292 .51833 Mdot
.86364 .37127 Mdot
.64478 .48277 Mdot
.61436 .59923 Mdot
.7411 .07833 Mdot
.10619 .22564 Mdot
.32356 .13434 Mdot
.49778 .61709 Mdot
.49293 .61504 Mdot
.47749 .60849 Mdot
.42839 .58769 Mdot
.27547 .52352 Mdot
.88686 .37786 Mdot
.65403 .47414 Mdot
.61782 .59566 Mdot
.74263 .07714 Mdot
.10593 .22453 Mdot
.3218 .13342 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52632 .01116 Mdot
.58367 .03544 Mdot
.76082 .10948 Mdot
.17615 .25669 Mdot
.37799 .12475 Mdot
.41422 .02239 Mdot
.32793 .5647 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.5093 .00394 Mdot
.52962 .01256 Mdot
.59411 .03986 Mdot
.79168 .12211 Mdot
.21985 .26462 Mdot
.41355 .11972 Mdot
.48387 .04346 Mdot
.53003 .02853 Mdot
.62095 .0562 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50629 .00267 Mdot
.52003 .00849 Mdot
.56373 .02701 Mdot
.7005 .08453 Mdot
.06455 .22499 Mdot
.33441 .16678 Mdot
.39832 .0395 Mdot
.31989 .56956 Mdot
.02538 .43602 Mdot
.69296 .41258 Mdot
.49937 .61776 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47948 .60933 Mdot
.43471 .59037 Mdot
.29474 .53153 Mdot
.9254 .38977 Mdot
.66391 .45642 Mdot
.60707 .5829 Mdot
.69898 .05681 Mdot
.01747 .19683 Mdot
.49787 .61713 Mdot
.49321 .61515 Mdot
.47835 .60886 Mdot
.43114 .58885 Mdot
.28381 .52698 Mdot
.90313 .38276 Mdot
.65894 .46712 Mdot
.61547 .59117 Mdot
.73041 .07103 Mdot
.08227 .21746 Mdot
.31615 .14455 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52547 .0108 Mdot
.58098 .03431 Mdot
.75278 .10618 Mdot
.16328 .2537 Mdot
.36962 .12752 Mdot
.40153 .01973 Mdot
.295 .55219 Mdot
.95921 .4105 Mdot
.68394 .44791 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00348 Mdot
.52618 .0111 Mdot
.58322 .03526 Mdot
.75949 .10894 Mdot
.17406 .25622 Mdot
.37657 .12515 Mdot
.41193 .02186 Mdot
.32183 .56235 Mdot
.01691 .42958 Mdot
.68667 .41393 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51823 .00773 Mdot
.55804 .0246 Mdot
.68297 .07722 Mdot
.02578 .21187 Mdot
.33009 .18807 Mdot
.42525 .05881 Mdot
.41237 .61007 Mdot
.27458 .53288 Mdot
.9009 .38709 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.4818 .61032 Mdot
.44209 .59349 Mdot
.31741 .54098 Mdot
.97509 .40647 Mdot
.66998 .42947 Mdot
.57407 .55876 Mdot
.5853 .00694 Mdot
.71845 .08229 Mdot
.08566 .22695 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00142 Mdot
.5107 .00454 Mdot
.53407 .01445 Mdot
.60816 .04579 Mdot
.8323 .13852 Mdot
.26395 .26678 Mdot
.45779 .1198 Mdot
.58905 .08113 Mdot
.84704 .15944 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49651 .61656 Mdot
.48889 .61332 Mdot
.46462 .60303 Mdot
.38771 .5705 Mdot
.15599 .47483 Mdot
.72599 .35228 Mdot
.53201 .49815 Mdot
.38573 .52763 Mdot
.0824 .43056 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.47551 .60765 Mdot
.42211 .58503 Mdot
.25649 .51567 Mdot
.85233 .36825 Mdot
.63924 .48634 Mdot
.60936 .59957 Mdot
.7309 .07512 Mdot
.08947 .2216 Mdot
.32079 .14296 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52196 .00931 Mdot
.56985 .0296 Mdot
.7192 .0923 Mdot
.10282 .23709 Mdot
.34272 .14827 Mdot
.38326 .02506 Mdot
.26398 .54431 Mdot
.90689 .39734 Mdot
.49892 .61758 Mdot
.49656 .61658 Mdot
.48904 .61339 Mdot
.46509 .60323 Mdot
.38919 .57113 Mdot
.16018 .4765 Mdot
.72946 .35183 Mdot
.53549 .49815 Mdot
.3943 .53078 Mdot
.10597 .43983 Mdot
.67017 .3487 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50682 .00289 Mdot
.52172 .00921 Mdot
.5691 .02928 Mdot
.71692 .09135 Mdot
.09832 .23572 Mdot
.34145 .15026 Mdot
.38418 .02641 Mdot
.26811 .5463 Mdot
.91485 .39971 Mdot
.68331 .47493 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47426 .60712 Mdot
.41815 .58336 Mdot
.24462 .51078 Mdot
.83249 .36332 Mdot
.62774 .49149 Mdot
.59467 .5976 Mdot
.6954 .06225 Mdot
.02093 .20119 Mdot
.31516 .18184 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51252 .00531 Mdot
.53988 .01691 Mdot
.62643 .05349 Mdot
.88329 .15875 Mdot
.29995 .25751 Mdot
.48953 .11717 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.48659 .61235 Mdot
.45731 .59994 Mdot
.36476 .56083 Mdot
.09289 .45001 Mdot
.68946 .3687 Mdot
.50771 .5057 Mdot
.33751 .51285 Mdot
.96376 .38705 Mdot
.6439 .42035 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.48689 .61248 Mdot
.45826 .60034 Mdot
.36772 .56208 Mdot
.10084 .45309 Mdot
.69262 .36574 Mdot
.50778 .5038 Mdot
.33459 .511 Mdot
.95561 .38381 Mdot
.64235 .42443 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50539 .00228 Mdot
.51716 .00728 Mdot
.55461 .02315 Mdot
.67239 .07279 Mdot
.00107 .20314 Mdot
.32815 .20214 Mdot
.44469 .07203 Mdot
.47994 .02178 Mdot
.48517 .00323 Mdot
.46818 .60753 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51526 .00647 Mdot
.54858 .02059 Mdot
.65364 .06493 Mdot
.95501 .18625 Mdot
.32296 .22741 Mdot
.47684 .0951 Mdot
.59611 .07371 Mdot
.85093 .15749 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47726 .60839 Mdot
.42768 .58739 Mdot
.2733 .52262 Mdot
.88275 .37666 Mdot
.65259 .47579 Mdot
.61782 .59655 Mdot
.74409 .07804 Mdot
.10893 .22548 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48405 .61127 Mdot
.44921 .5965 Mdot
.33947 .55021 Mdot
.02774 .42537 Mdot
.67461 .39979 Mdot
.53393 .53109 Mdot
.44375 .5623 Mdot
.27093 .51123 Mdot
.86145 .36496 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.513 .00551 Mdot
.54141 .01755 Mdot
.63122 .05551 Mdot
.89631 .16383 Mdot
.30616 .2533 Mdot
.49199 .11485 Mdot
.66582 .10743 Mdot
.04577 .23482 Mdot
.358 .19297 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47553 .60766 Mdot
.42219 .58506 Mdot
.25671 .51577 Mdot
.85272 .36835 Mdot
.63944 .48622 Mdot
.60957 .59957 Mdot
.73137 .07528 Mdot
.09028 .22181 Mdot
.32091 .14254 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50321 .00136 Mdot
.51023 .00434 Mdot
.53259 .01382 Mdot
.60351 .04383 Mdot
.81896 .13316 Mdot
.25109 .26707 Mdot
.44448 .11953 Mdot
.55629 .0691 Mdot
.75078 .1202 Mdot
.184 .26774 Mdot
.49908 .61764 Mdot
.49708 .61679 Mdot
.49068 .61408 Mdot
.47032 .60545 Mdot
.40571 .5781 Mdot
.20779 .49571 Mdot
.77949 .35333 Mdot
.58583 .49835 Mdot
.51477 .57411 Mdot
.46583 .58779 Mdot
.36602 .55635 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47698 .60827 Mdot
.42678 .58701 Mdot
.27058 .5215 Mdot
.87765 .37519 Mdot
.65069 .47777 Mdot
.61748 .59751 Mdot
.74491 .07876 Mdot
.11095 .22623 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52384 .01011 Mdot
.57582 .03213 Mdot
.73729 .09979 Mdot
.13673 .24687 Mdot
.35539 .13514 Mdot
.38577 .01877 Mdot
.25913 .53977 Mdot
.89416 .39247 Mdot
.6765 .48352 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51143 .00485 Mdot
.5364 .01543 Mdot
.61551 .04889 Mdot
.85306 .14681 Mdot
.28101 .26449 Mdot
.47476 .11974 Mdot
.6308 .09644 Mdot
.96168 .2045 Mdot
.34949 .23968 Mdot
.49913 .61767 Mdot
.49723 .61686 Mdot
.49117 .61429 Mdot
.47188 .60611 Mdot
.41062 .58018 Mdot
.22223 .5016 Mdot
.79874 .3563 Mdot
.60287 .49698 Mdot
.55077 .58584 Mdot
.57356 .01408 Mdot
.70278 .07987 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51226 .0052 Mdot
.53905 .01655 Mdot
.62381 .05239 Mdot
.87612 .15594 Mdot
.29605 .25953 Mdot
.48716 .11812 Mdot
.65905 .10623 Mdot
.50048 .0002 Mdot
.50151 .00064 Mdot
.50482 .00205 Mdot
.51537 .00652 Mdot
.54894 .02075 Mdot
.65476 .0654 Mdot
.95784 .18731 Mdot
.32342 .22594 Mdot
.47522 .09382 Mdot
.59 .07094 Mdot
.8327 .15 Mdot
.28262 .27807 Mdot
.49817 .61726 Mdot
.49416 .61556 Mdot
.48141 .61015 Mdot
.44082 .59295 Mdot
.31349 .53934 Mdot
.96618 .40338 Mdot
.66922 .4345 Mdot
.58089 .56344 Mdot
.60873 .01721 Mdot
.78727 .11034 Mdot
.19802 .25386 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50669 .00284 Mdot
.52132 .00904 Mdot
.56785 .02875 Mdot
.71308 .08976 Mdot
.09066 .23336 Mdot
.33948 .15378 Mdot
.38632 .02895 Mdot
.27677 .55033 Mdot
.93186 .40487 Mdot
.68606 .46612 Mdot
.4999 .61799 Mdot
.4997 .61791 Mdot
.49904 .61762 Mdot
.49693 .61673 Mdot
.49021 .61388 Mdot
.46881 .60481 Mdot
.40093 .57608 Mdot
.19386 .49006 Mdot
.76276 .3516 Mdot
.56962 .49867 Mdot
.4776 .56117 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.44211 .5935 Mdot
.31748 .54101 Mdot
.97525 .40653 Mdot
.67 .42938 Mdot
.57395 .55867 Mdot
.58486 .00675 Mdot
.71713 .08174 Mdot
.08305 .22615 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50597 .00253 Mdot
.51903 .00807 Mdot
.56057 .02567 Mdot
.69079 .08048 Mdot
.04341 .21793 Mdot
.33172 .17818 Mdot
.41208 .04966 Mdot
.36716 .59027 Mdot
.14533 .48093 Mdot
.73456 .36416 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50825 .0035 Mdot
.52627 .01114 Mdot
.58351 .03538 Mdot
.76035 .10929 Mdot
.17542 .25653 Mdot
.37749 .12489 Mdot
.41341 .0222 Mdot
.32577 .56387 Mdot
.02594 .43273 Mdot
.68737 .40879 Mdot
.49981 .61796 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49399 .61548 Mdot
.48085 .60991 Mdot
.43904 .5922 Mdot
.30802 .53706 Mdot
.95395 .39921 Mdot
.668 .44131 Mdot
.58979 .5697 Mdot
.63922 .03055 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50809 .00343 Mdot
.52578 .01093 Mdot
.58196 .03472 Mdot
.75573 .1074 Mdot
.16808 .25484 Mdot
.37263 .12642 Mdot
.40587 .02054 Mdot
.30599 .55631 Mdot
.98201 .4178 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50577 .00245 Mdot
.51839 .0078 Mdot
.55852 .02481 Mdot
.68448 .07785 Mdot
.02923 .21307 Mdot
.33038 .18612 Mdot
.4226 .05699 Mdot
.40323 .60607 Mdot
.24749 .52178 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50399 .00169 Mdot
.51271 .00539 Mdot
.54048 .01716 Mdot
.62832 .05429 Mdot
.88846 .16077 Mdot
.30254 .25592 Mdot
.49079 .11634 Mdot
.66522 .10781 Mdot
.04531 .23491 Mdot
.35835 .19347 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50762 .00323 Mdot
.52429 .0103 Mdot
.57724 .03273 Mdot
.74156 .10156 Mdot
.14428 .24889 Mdot
.35903 .13272 Mdot
.3889 .01846 Mdot
.26533 .54166 Mdot
.90413 .3948 Mdot
.4977 .61706 Mdot
.49267 .61492 Mdot
.47664 .60813 Mdot
.42569 .58655 Mdot
.26729 .52014 Mdot
.87156 .37346 Mdot
.64825 .48002 Mdot
.61652 .59843 Mdot
.74438 .07902 Mdot
.11082 .22647 Mdot
.32414 .13184 Mdot
.49864 .61746 Mdot
.49568 .6162 Mdot
.48624 .6122 Mdot
.45619 .59946 Mdot
.36124 .55935 Mdot
.08352 .4464 Mdot
.6862 .37247 Mdot
.50868 .50832 Mdot
.34418 .51636 Mdot
.98153 .39391 Mdot
.64653 .41099 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52029 .0086 Mdot
.56455 .02736 Mdot
.70301 .08557 Mdot
.06986 .22673 Mdot
.33526 .16402 Mdot
.39536 .03715 Mdot
.30958 .56502 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50668 .00283 Mdot
.52129 .00903 Mdot
.56773 .0287 Mdot
.71273 .08961 Mdot
.08994 .23313 Mdot
.33931 .15412 Mdot
.38656 .0292 Mdot
.27769 .55075 Mdot
.93369 .40543 Mdot
.6863 .46514 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47444 .6072 Mdot
.41874 .58361 Mdot
.24637 .5115 Mdot
.83533 .364 Mdot
.62952 .49084 Mdot
.59726 .59809 Mdot
.70197 .06471 Mdot
.03462 .20559 Mdot
.31575 .17375 Mdot
.50008 4e-05 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00113 Mdot
.50852 .00361 Mdot
.52715 .01151 Mdot
.58631 .03656 Mdot
.76868 .11271 Mdot
.18814 .25924 Mdot
.38667 .1227 Mdot
.42922 .0263 Mdot
.36908 .58086 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48465 .61152 Mdot
.45112 .59731 Mdot
.34541 .55271 Mdot
.04261 .43089 Mdot
.67665 .39186 Mdot
.52452 .52401 Mdot
.40902 .54665 Mdot
.16436 .46683 Mdot
.71471 .34013 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51875 .00795 Mdot
.55967 .02529 Mdot
.68803 .07933 Mdot
.03725 .21583 Mdot
.3311 .18161 Mdot
.41656 .05281 Mdot
.3825 .59699 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47727 .60839 Mdot
.42768 .58739 Mdot
.27332 .52263 Mdot
.88278 .37667 Mdot
.6526 .47577 Mdot
.61783 .59654 Mdot
.74408 .07803 Mdot
.10891 .22547 Mdot
.32282 .13221 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50562 .00238 Mdot
.51791 .0076 Mdot
.55701 .02417 Mdot
.67982 .0759 Mdot
.01852 .20933 Mdot
.3295 .1922 Mdot
.43092 .06268 Mdot
.43195 .00064 Mdot
.334 .55749 Mdot
.02979 .43003 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50632 .00268 Mdot
.52014 .00854 Mdot
.56409 .02716 Mdot
.7016 .08499 Mdot
.06689 .22576 Mdot
.33477 .16556 Mdot
.39699 .03846 Mdot
.31527 .56753 Mdot
.01461 .43222 Mdot
.69207 .41869 Mdot
.49744 .61695 Mdot
.49183 .61457 Mdot
.47398 .607 Mdot
.41726 .58298 Mdot
.24194 .50968 Mdot
.8282 .36233 Mdot
.62495 .49242 Mdot
.59045 .59671 Mdot
.68445 .05809 Mdot
.99722 .1933 Mdot
.31416 .19588 Mdot
.49887 .61756 Mdot
.49641 .61651 Mdot
.48856 .61318 Mdot
.46356 .60259 Mdot
.38439 .5691 Mdot
.14666 .47111 Mdot
.71878 .35359 Mdot
.52505 .4983 Mdot
.36873 .52142 Mdot
.03708 .41307 Mdot
.65032 .379 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50309 .00131 Mdot
.50984 .00417 Mdot
.53135 .01329 Mdot
.59956 .04216 Mdot
.80758 .12856 Mdot
.23887 .26655 Mdot
.43201 .11937 Mdot
.52625 .05824 Mdot
.65969 .08247 Mdot
.99445 .20689 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.508 .00339 Mdot
.52548 .0108 Mdot
.58102 .03432 Mdot
.7529 .10623 Mdot
.16348 .25375 Mdot
.36974 .12748 Mdot
.40171 .01976 Mdot
.29542 .55235 Mdot
.96007 .41077 Mdot
.68398 .4474 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.50511 .00217 Mdot
.51628 .0069 Mdot
.55183 .02197 Mdot
.66377 .06918 Mdot
.98024 .19559 Mdot
.32628 .21386 Mdot
.46048 .08294 Mdot
.536 .04668 Mdot
.49804 .6172 Mdot
.49375 .61538 Mdot
.48008 .60959 Mdot
.43662 .59117 Mdot
.30057 .53395 Mdot
.93774 .39379 Mdot
.66594 .45005 Mdot
.60033 .57749 Mdot
.67545 .04643 Mdot
.96359 .17808 Mdot
.30587 .21154 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51747 .00741 Mdot
.55562 .02358 Mdot
.67552 .0741 Mdot
.00847 .20578 Mdot
.32873 .19793 Mdot
.43886 .06807 Mdot
.45953 .01277 Mdot
.42014 .59369 Mdot
.26594 .52273 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50812 .00344 Mdot
.52588 .01097 Mdot
.58227 .03485 Mdot
.75665 .10777 Mdot
.16956 .25519 Mdot
.37358 .12609 Mdot
.4073 .02084 Mdot
.30969 .55771 Mdot
.98994 .42042 Mdot
.68527 .42974 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47683 .60821 Mdot
.42629 .5868 Mdot
.26909 .52088 Mdot
.87488 .3744 Mdot
.6496 .47881 Mdot
.61712 .59796 Mdot
.74488 .07896 Mdot
.11124 .22643 Mdot
.324 .13149 Mdot
.49987 .61798 Mdot
.49958 .61786 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48636 .61225 Mdot
.45656 .59962 Mdot
.36242 .55985 Mdot
.08667 .44761 Mdot
.68724 .37118 Mdot
.50823 .5074 Mdot
.34156 .51502 Mdot
.49853 .61741 Mdot
.4953 .61604 Mdot
.48504 .61169 Mdot
.45235 .59784 Mdot
.34927 .55432 Mdot
.0524 .43456 Mdot
.67834 .38685 Mdot
.51923 .5197 Mdot
.38889 .53748 Mdot
.1051 .44264 Mdot
.67487 .35214 Mdot
.49867 .61747 Mdot
.49576 .61624 Mdot
.4865 .61231 Mdot
.45701 .59981 Mdot
.36382 .56044 Mdot
.0904 .44905 Mdot
.68855 .36968 Mdot
.50786 .50636 Mdot
.33895 .51364 Mdot
.96763 .38855 Mdot
.64453 .41835 Mdot
.49959 .61786 Mdot
.4987 .61748 Mdot
.49587 .61628 Mdot
.48683 .61245 Mdot
.45807 .60026 Mdot
.36712 .56183 Mdot
.09923 .45247 Mdot
.69195 .36632 Mdot
.50769 .50416 Mdot
.33497 .51129 Mdot
.95675 .38428 Mdot
.49954 .61784 Mdot
.49854 .61742 Mdot
.49535 .61606 Mdot
.48519 .61176 Mdot
.45286 .59805 Mdot
.35084 .55498 Mdot
.05643 .43608 Mdot
.67914 .38485 Mdot
.5173 .51801 Mdot
.38135 .53402 Mdot
.08347 .43393 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52546 .0108 Mdot
.58095 .0343 Mdot
.75271 .10615 Mdot
.16316 .25367 Mdot
.36954 .12755 Mdot
.40143 .01971 Mdot
.29474 .55209 Mdot
.95868 .41034 Mdot
.68391 .44822 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51117 .00474 Mdot
.53558 .01508 Mdot
.6129 .04779 Mdot
.84573 .1439 Mdot
.27539 .26555 Mdot
.46935 .11987 Mdot
.61762 .09164 Mdot
.92671 .19102 Mdot
.34188 .25659 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51264 .00536 Mdot
.54026 .01707 Mdot
.62763 .054 Mdot
.88656 .16003 Mdot
.30161 .25651 Mdot
.49037 .11666 Mdot
.66469 .10773 Mdot
.49943 .61779 Mdot
.49819 .61727 Mdot
.49425 .61559 Mdot
.48167 .61026 Mdot
.44165 .5933 Mdot
.31606 .54041 Mdot
.97201 .4054 Mdot
.66973 .43121 Mdot
.57645 .56039 Mdot
.59349 .01053 Mdot
.74284 .0923 Mdot
.49962 .61787 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48764 .61279 Mdot
.46063 .60134 Mdot
.37517 .56522 Mdot
.12109 .461 Mdot
.70239 .35927 Mdot
.51183 .50026 Mdot
.339 .51122 Mdot
.9638 .38615 Mdot
.49999 .61803 Mdot
.49995 .61801 Mdot
.49986 .61797 Mdot
.49954 .61784 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.4851 .61172 Mdot
.45257 .59793 Mdot
.34995 .55461 Mdot
.05415 .43522 Mdot
.67868 .38598 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52606 .01105 Mdot
.58286 .0351 Mdot
.75841 .1085 Mdot
.17236 .25584 Mdot
.37542 .1255 Mdot
.41013 .02145 Mdot
.31708 .56053 Mdot
.0062 .4259 Mdot
.68602 .42015 Mdot
.49905 .61763 Mdot
.49696 .61674 Mdot
.49031 .61393 Mdot
.46915 .60495 Mdot
.40199 .57653 Mdot
.19695 .49131 Mdot
.76631 .35189 Mdot
.57315 .49866 Mdot
.4859 .56411 Mdot
.37753 .55106 Mdot
.10307 .4484 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51553 .00659 Mdot
.54945 .02096 Mdot
.65635 .06607 Mdot
.96185 .1888 Mdot
.32402 .22384 Mdot
.47282 .09196 Mdot
.58106 .06689 Mdot
.80569 .13883 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .00271 Mdot
.52033 .00862 Mdot
.56469 .02742 Mdot
.70343 .08575 Mdot
.07075 .22702 Mdot
.33541 .16357 Mdot
.39489 .03676 Mdot
.30793 .56429 Mdot
.99787 .42641 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50798 .00338 Mdot
.52542 .01078 Mdot
.58084 .03425 Mdot
.75236 .10601 Mdot
.16259 .25354 Mdot
.3692 .12769 Mdot
.40095 .01963 Mdot
.29354 .55165 Mdot
.95628 .40959 Mdot
.68378 .44962 Mdot
.49755 .61699 Mdot
.49218 .61472 Mdot
.47509 .60747 Mdot
.42079 .58447 Mdot
.25251 .51403 Mdot
.84553 .36651 Mdot
.63555 .48826 Mdot
.6052 .59927 Mdot
.72141 .07182 Mdot
.0725 .21699 Mdot
.31857 .15208 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.5217 .0092 Mdot
.56904 .02926 Mdot
.71672 .09127 Mdot
.09793 .2356 Mdot
.34134 .15044 Mdot
.38427 .02653 Mdot
.26851 .54649 Mdot
.91563 .39994 Mdot
.68346 .47455 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50237 .00101 Mdot
.50757 .00321 Mdot
.5241 .01022 Mdot
.57665 .03248 Mdot
.73977 .10082 Mdot
.14113 .24806 Mdot
.35747 .1337 Mdot
.38747 .01854 Mdot
.26238 .54073 Mdot
.89929 .39363 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49715 .61683 Mdot
.49093 .61419 Mdot
.47112 .60579 Mdot
.40824 .57917 Mdot
.21521 .49873 Mdot
.78913 .3547 Mdot
.5946 .49781 Mdot
.53376 .58044 Mdot
.5232 .6115 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.5068 .00288 Mdot
.52167 .00919 Mdot
.56895 .02922 Mdot
.71644 .09116 Mdot
.09738 .23543 Mdot
.34119 .15068 Mdot
.3844 .0267 Mdot
.26906 .54675 Mdot
.9167 .40026 Mdot
.68366 .47401 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47756 .60852 Mdot
.42862 .58779 Mdot
.27616 .52381 Mdot
.88819 .37826 Mdot
.65447 .47359 Mdot
.61776 .59535 Mdot
.74201 .07679 Mdot
.1047 .22415 Mdot
.32142 .13394 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.52661 .01128 Mdot
.58459 .03583 Mdot
.76357 .11061 Mdot
.18041 .25762 Mdot
.38098 .12396 Mdot
.4192 .02362 Mdot
.34136 .56992 Mdot
.06304 .44603 Mdot
.49938 .61777 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.47981 .60947 Mdot
.43577 .59081 Mdot
.29796 .53287 Mdot
.93219 .39197 Mdot
.66508 .45295 Mdot
.60352 .57999 Mdot
.68652 .0513 Mdot
.98952 .18726 Mdot
.49964 .61788 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48837 .6131 Mdot
.46296 .60233 Mdot
.38249 .5683 Mdot
.14133 .46899 Mdot
.71496 .35452 Mdot
.52157 .49851 Mdot
.36042 .51844 Mdot
.01572 .405 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51919 .00814 Mdot
.56107 .02589 Mdot
.69234 .08112 Mdot
.04683 .21909 Mdot
.33209 .1763 Mdot
.40967 .04795 Mdot
.35892 .58667 Mdot
.1232 .47235 Mdot
.72059 .36921 Mdot
.49953 .61783 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48466 .61153 Mdot
.45115 .59733 Mdot
.34552 .55275 Mdot
.04287 .43099 Mdot
.67669 .39173 Mdot
.52437 .52389 Mdot
.40846 .5464 Mdot
.16268 .46614 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00326 Mdot
.52446 .01037 Mdot
.57779 .03296 Mdot
.74322 .10224 Mdot
.14717 .24965 Mdot
.3605 .13185 Mdot
.39037 .01846 Mdot
.26849 .54271 Mdot
.90949 .39616 Mdot
.67905 .47561 Mdot
.49747 .61696 Mdot
.49194 .61462 Mdot
.47433 .60715 Mdot
.41839 .58346 Mdot
.24532 .51107 Mdot
.83363 .36359 Mdot
.62846 .49123 Mdot
.59573 .59781 Mdot
.69809 .06326 Mdot
.0266 .20303 Mdot
.31539 .17848 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.5064 .00271 Mdot
.52039 .00865 Mdot
.5649 .0275 Mdot
.70407 .08601 Mdot
.0721 .22746 Mdot
.33564 .16288 Mdot
.39419 .03618 Mdot
.30546 .5632 Mdot
.99235 .42452 Mdot
.69071 .43161 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51068 .00453 Mdot
.53402 .01443 Mdot
.60802 .04573 Mdot
.83188 .13835 Mdot
.26357 .2668 Mdot
.4574 .11979 Mdot
.58808 .08077 Mdot
.84424 .15832 Mdot
.29849 .28074 Mdot
.49966 .61789 Mdot
.49892 .61758 Mdot
.49655 .61657 Mdot
.48901 .61337 Mdot
.46501 .6032 Mdot
.38893 .57102 Mdot
.15945 .47621 Mdot
.72885 .3519 Mdot
.53487 .49815 Mdot
.39277 .53021 Mdot
.10172 .43816 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50675 .00286 Mdot
.52151 .00912 Mdot
.56842 .029 Mdot
.71485 .09049 Mdot
.0942 .23445 Mdot
.34036 .15213 Mdot
.38524 .02774 Mdot
.27252 .54837 Mdot
.92345 .4023 Mdot
.49976 .61793 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47572 .60774 Mdot
.4228 .58532 Mdot
.25856 .51653 Mdot
.85593 .36919 Mdot
.64108 .48525 Mdot
.6112 .59957 Mdot
.73488 .07644 Mdot
.49844 .61737 Mdot
.49503 .61593 Mdot
.48416 .61132 Mdot
.44957 .59666 Mdot
.34059 .55068 Mdot
.03052 .4264 Mdot
.67495 .39828 Mdot
.53205 .52972 Mdot
.43692 .55924 Mdot
.24961 .50227 Mdot
.82358 .35473 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49715 .61683 Mdot
.49093 .61419 Mdot
.47111 .60578 Mdot
.40819 .57915 Mdot
.21507 .49868 Mdot
.78894 .35467 Mdot
.59444 .49782 Mdot
.53342 .58032 Mdot
.52216 .61108 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48977 .6137 Mdot
.46741 .60422 Mdot
.39651 .57421 Mdot
.18108 .48489 Mdot
.74895 .35097 Mdot
.55556 .49851 Mdot
.44381 .54897 Mdot
.24952 .49796 Mdot
.8165 .35041 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00823 Mdot
.56174 .02617 Mdot
.69438 .08198 Mdot
.05133 .2206 Mdot
.33261 .17384 Mdot
.4066 .04573 Mdot
.3484 .58207 Mdot
.09567 .46184 Mdot
.70792 .37839 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51417 .00601 Mdot
.54511 .01912 Mdot
.6428 .06038 Mdot
.9271 .1757 Mdot
.31696 .24095 Mdot
.48891 .10627 Mdot
.64425 .096 Mdot
.98752 .21215 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49839 .61735 Mdot
.49488 .61586 Mdot
.4837 .61112 Mdot
.44812 .59604 Mdot
.33609 .54879 Mdot
.0194 .42231 Mdot
.67369 .40437 Mdot
.53978 .53528 Mdot
.46493 .57177 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48801 .61295 Mdot
.46183 .60185 Mdot
.37893 .5668 Mdot
.13143 .46507 Mdot
.70845 .35661 Mdot
.5161 .49916 Mdot
.34787 .51406 Mdot
.98464 .39354 Mdot
.64441 .40776 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50765 .00324 Mdot
.52436 .01033 Mdot
.57748 .03283 Mdot
.74229 .10186 Mdot
.14555 .24923 Mdot
.35967 .13233 Mdot
.38953 .01845 Mdot
.26666 .5421 Mdot
.90637 .39536 Mdot
.67856 .47724 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52355 .00998 Mdot
.57489 .03173 Mdot
.73447 .09863 Mdot
.13165 .24547 Mdot
.35312 .13687 Mdot
.38423 .01923 Mdot
.25659 .53915 Mdot
.89042 .39173 Mdot
.67594 .48548 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47458 .60725 Mdot
.41916 .58378 Mdot
.24762 .51202 Mdot
.83739 .36449 Mdot
.63079 .49035 Mdot
.59903 .59841 Mdot
.70641 .06637 Mdot
.04363 .20841 Mdot
.31622 .16847 Mdot
.49931 .61774 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42914 .588 Mdot
.27773 .52446 Mdot
.8912 .37915 Mdot
.65546 .47234 Mdot
.61755 .5946 Mdot
.74036 .0759 Mdot
.10146 .22317 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50632 .00268 Mdot
.52014 .00854 Mdot
.56408 .02716 Mdot
.70157 .08497 Mdot
.06683 .22574 Mdot
.33476 .16559 Mdot
.39702 .03848 Mdot
.31537 .56757 Mdot
.01485 .4323 Mdot
.69208 .41855 Mdot
.49887 .61755 Mdot
.4964 .61651 Mdot
.48853 .61317 Mdot
.46346 .60254 Mdot
.38408 .56897 Mdot
.14578 .47076 Mdot
.71813 .35373 Mdot
.52444 .49833 Mdot
.36728 .5209 Mdot
.03332 .41163 Mdot
.64974 .38097 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00321 Mdot
.52413 .01023 Mdot
.57675 .03252 Mdot
.7401 .10095 Mdot
.14171 .24821 Mdot
.35775 .13352 Mdot
.38772 .01852 Mdot
.26288 .54088 Mdot
.9001 .39382 Mdot
.50072 .00031 Mdot
.5023 .00097 Mdot
.50732 .0031 Mdot
.52332 .00989 Mdot
.57418 .03143 Mdot
.73234 .09774 Mdot
.12775 .24438 Mdot
.35147 .13826 Mdot
.38334 .0197 Mdot
.25548 .53901 Mdot
.88902 .39155 Mdot
.67587 .4863 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.47428 .60713 Mdot
.41824 .58339 Mdot
.24486 .51088 Mdot
.83288 .36342 Mdot
.62799 .4914 Mdot
.59504 .59767 Mdot
.69634 .0626 Mdot
.02292 .20184 Mdot
.31524 .18066 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52001 .00849 Mdot
.56368 .02699 Mdot
.70033 .08446 Mdot
.06419 .22487 Mdot
.33435 .16697 Mdot
.39853 .03967 Mdot
.32062 .56988 Mdot
.0271 .43663 Mdot
.69312 .41163 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50978 .00415 Mdot
.53115 .01321 Mdot
.59894 .0419 Mdot
.80577 .12783 Mdot
.23683 .26641 Mdot
.42996 .11937 Mdot
.52141 .05651 Mdot
.64486 .0763 Mdot
.95683 .19281 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50701 .00297 Mdot
.52233 .00947 Mdot
.57103 .0301 Mdot
.72276 .09378 Mdot
.10975 .23917 Mdot
.34485 .1453 Mdot
.38237 .02319 Mdot
.25908 .54184 Mdot
.89745 .39453 Mdot
.67922 .48316 Mdot
.49808 .61722 Mdot
.4939 .61545 Mdot
.48055 .60979 Mdot
.43811 .5918 Mdot
.30516 .53587 Mdot
.94767 .39709 Mdot
.66727 .44474 Mdot
.59406 .57279 Mdot
.65388 .03697 Mdot
.91021 .15842 Mdot
.29419 .23731 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48266 .61068 Mdot
.44481 .59464 Mdot
.32583 .5445 Mdot
.99469 .41338 Mdot
.67152 .4183 Mdot
.55864 .54827 Mdot
.53173 .60141 Mdot
.55211 .01259 Mdot
.64926 .06004 Mdot
.49868 .61747 Mdot
.49578 .61624 Mdot
.48656 .61233 Mdot
.4572 .59989 Mdot
.36441 .56069 Mdot
.09196 .44965 Mdot
.68912 .36906 Mdot
.50775 .50595 Mdot
.33802 .51313 Mdot
.96514 .38758 Mdot
.64413 .41964 Mdot
.49891 .61757 Mdot
.49652 .61656 Mdot
.48891 .61333 Mdot
.46468 .60306 Mdot
.3879 .57058 Mdot
.15655 .47505 Mdot
.72644 .35222 Mdot
.53246 .49815 Mdot
.38683 .52803 Mdot
.0854 .43174 Mdot
.66193 .35631 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50961 .00408 Mdot
.53062 .01298 Mdot
.59726 .04119 Mdot
.80088 .12584 Mdot
.23114 .26591 Mdot
.42434 .1194 Mdot
.50827 .05187 Mdot
.60459 .05953 Mdot
.84674 .14966 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52517 .01067 Mdot
.58003 .0339 Mdot
.74993 .10501 Mdot
.15857 .25255 Mdot
.36679 .12869 Mdot
.39774 .01912 Mdot
.28563 .54875 Mdot
.94075 .40488 Mdot
.6827 .45856 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50505 .00214 Mdot
.51607 .00682 Mdot
.55117 .02169 Mdot
.66171 .06832 Mdot
.97517 .19373 Mdot
.32573 .21665 Mdot
.46407 .0855 Mdot
.54897 .05247 Mdot
.70618 .09716 Mdot
.09312 .23915 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00344 Mdot
.52581 .01094 Mdot
.58205 .03476 Mdot
.75599 .1075 Mdot
.1685 .25494 Mdot
.37289 .12632 Mdot
.40626 .02062 Mdot
.30702 .5567 Mdot
.98419 .41852 Mdot
.68504 .43315 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.51688 .00716 Mdot
.55373 .02277 Mdot
.66964 .07164 Mdot
.9945 .20077 Mdot
.32761 .20587 Mdot
.44981 .07552 Mdot
.49796 .02976 Mdot
.54305 .02787 Mdot
.65192 .06729 Mdot
.49941 .61779 Mdot
.49813 .61724 Mdot
.49406 .61551 Mdot
.48106 .61 Mdot
.43973 .59249 Mdot
.31015 .53795 Mdot
.95869 .40082 Mdot
.6685 .43869 Mdot
.58642 .56731 Mdot
.62768 .0255 Mdot
.84058 .13158 Mdot
.49911 .61766 Mdot
.49718 .61684 Mdot
.49101 .61422 Mdot
.47137 .60589 Mdot
.409 .57949 Mdot
.21746 .49965 Mdot
.79215 .35518 Mdot
.59725 .49758 Mdot
.53933 .58223 Mdot
.5398 .00029 Mdot
.59936 .03681 Mdot
.50034 .00015 Mdot
.5011 .00046 Mdot
.50349 .00148 Mdot
.51113 .00472 Mdot
.53544 .01503 Mdot
.61249 .04762 Mdot
.84456 .14343 Mdot
.27446 .26569 Mdot
.46843 .11988 Mdot
.61536 .09081 Mdot
.92057 .18863 Mdot
.34004 .25925 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51918 .00813 Mdot
.56103 .02587 Mdot
.69221 .08107 Mdot
.04655 .21899 Mdot
.33206 .17645 Mdot
.40987 .04809 Mdot
.35959 .58696 Mdot
.12499 .47304 Mdot
.72158 .36872 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49718 .61684 Mdot
.491 .61422 Mdot
.47133 .60588 Mdot
.40889 .57944 Mdot
.21713 .49952 Mdot
.79171 .35511 Mdot
.59687 .49762 Mdot
.53854 .58198 Mdot
.53744 .61736 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48977 .6137 Mdot
.46742 .60422 Mdot
.39654 .57423 Mdot
.18117 .48493 Mdot
.74904 .35097 Mdot
.55565 .49851 Mdot
.44403 .54905 Mdot
.25019 .49823 Mdot
.81762 .35069 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49145 .61441 Mdot
.47277 .60649 Mdot
.41345 .58137 Mdot
.23061 .50503 Mdot
.81081 .35858 Mdot
.61252 .49549 Mdot
.56931 .59133 Mdot
.6268 .03553 Mdot
.855 .14103 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.5257 .0109 Mdot
.58172 .03462 Mdot
.75501 .1071 Mdot
.16692 .25457 Mdot
.37188 .12668 Mdot
.40477 .02033 Mdot
.30319 .55525 Mdot
.97608 .41587 Mdot
.68472 .43796 Mdot
.49822 .61728 Mdot
.49434 .61564 Mdot
.48198 .61039 Mdot
.44264 .59372 Mdot
.31912 .54169 Mdot
.97903 .40785 Mdot
.6703 .42723 Mdot
.571 .55666 Mdot
.57469 .00228 Mdot
.68636 .06901 Mdot
.01792 .20492 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50278 .00118 Mdot
.50886 .00376 Mdot
.52823 .01197 Mdot
.58974 .03801 Mdot
.77882 .11686 Mdot
.20274 .26199 Mdot
.39837 .12091 Mdot
.4517 .03296 Mdot
.4337 .60691 Mdot
.31909 .5472 Mdot
.49949 .61782 Mdot
.49837 .61734 Mdot
.49479 .61583 Mdot
.48342 .611 Mdot
.44721 .59566 Mdot
.33325 .54761 Mdot
.01249 .41979 Mdot
.67301 .40823 Mdot
.54488 .53884 Mdot
.48316 .57989 Mdot
.39625 .56432 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50777 .0033 Mdot
.52476 .0105 Mdot
.57872 .03335 Mdot
.74602 .10339 Mdot
.15197 .25089 Mdot
.36306 .13046 Mdot
.39317 .01861 Mdot
.27479 .54487 Mdot
.92057 .39911 Mdot
.68061 .46973 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48863 .61321 Mdot
.4638 .60269 Mdot
.38514 .56942 Mdot
.14876 .47194 Mdot
.72034 .35326 Mdot
.52652 .49825 Mdot
.3723 .52272 Mdot
.04643 .41663 Mdot
.6519 .3742 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50808 .00343 Mdot
.52575 .01092 Mdot
.58187 .03468 Mdot
.75545 .10728 Mdot
.16762 .25474 Mdot
.37233 .12652 Mdot
.40543 .02046 Mdot
.30487 .55589 Mdot
.97963 .41703 Mdot
.68486 .43585 Mdot
.49991 .618 Mdot
.49973 .61792 Mdot
.49913 .61767 Mdot
.49724 .61686 Mdot
.4912 .6143 Mdot
.47198 .60615 Mdot
.41095 .58031 Mdot
.22319 .502 Mdot
.80008 .35654 Mdot
.60399 .49684 Mdot
.553 .58652 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50551 .00233 Mdot
.51754 .00744 Mdot
.55583 .02366 Mdot
.67615 .07436 Mdot
.00995 .2063 Mdot
.32884 .19708 Mdot
.43769 .06728 Mdot
.45546 .01098 Mdot
.40728 .58826 Mdot
.22774 .50708 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47931 .60926 Mdot
.43416 .59013 Mdot
.29304 .53082 Mdot
.92186 .38863 Mdot
.66324 .4582 Mdot
.60875 .58436 Mdot
.70499 .05948 Mdot
.03048 .20116 Mdot
.31053 .17308 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51253 .00531 Mdot
.53989 .01691 Mdot
.62646 .05351 Mdot
.88339 .15879 Mdot
.3 .25748 Mdot
.48956 .11715 Mdot
.66346 .10748 Mdot
.04166 .23374 Mdot
.35808 .19556 Mdot
.49838 .61735 Mdot
.49484 .61585 Mdot
.48356 .61106 Mdot
.44765 .59584 Mdot
.33463 .54818 Mdot
.01583 .42101 Mdot
.67333 .40636 Mdot
.54239 .53711 Mdot
.47428 .57594 Mdot
.36777 .5522 Mdot
.08495 .44324 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48126 .61009 Mdot
.44036 .59276 Mdot
.31208 .53875 Mdot
.96299 .40229 Mdot
.66892 .43629 Mdot
.58327 .5651 Mdot
.6169 .02078 Mdot
.81052 .11967 Mdot
.22583 .25667 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.4808 .60989 Mdot
.43891 .59214 Mdot
.30761 .53689 Mdot
.95305 .3989 Mdot
.6679 .4418 Mdot
.59041 .57014 Mdot
.64136 .03149 Mdot
.87755 .14597 Mdot
.27982 .24862 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52312 .0098 Mdot
.57353 .03116 Mdot
.73036 .09693 Mdot
.12411 .24335 Mdot
.35 .1396 Mdot
.38274 .02024 Mdot
.25507 .53913 Mdot
.8888 .39166 Mdot
.67608 .48657 Mdot
.49846 .61738 Mdot
.49511 .61596 Mdot
.48441 .61142 Mdot
.45038 .597 Mdot
.3431 .55173 Mdot
.03679 .42872 Mdot
.67578 .39492 Mdot
.52802 .52671 Mdot
.42208 .55256 Mdot
.20387 .48317 Mdot
.75688 .34178 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49105 .61424 Mdot
.47149 .60595 Mdot
.40939 .57966 Mdot
.21861 .50012 Mdot
.79372 .35544 Mdot
.59861 .49745 Mdot
.54214 .58313 Mdot
.54813 .0037 Mdot
.62522 .04765 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00179 Mdot
.51341 .00569 Mdot
.54272 .01811 Mdot
.63533 .05724 Mdot
.90733 .16811 Mdot
.31062 .24924 Mdot
.49228 .11227 Mdot
.66237 .10512 Mdot
.03591 .23086 Mdot
.35604 .19785 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50544 .00231 Mdot
.51734 .00735 Mdot
.55518 .02339 Mdot
.67415 .07353 Mdot
.00526 .20463 Mdot
.32848 .19976 Mdot
.4414 .06979 Mdot
.46841 .01669 Mdot
.44833 .60563 Mdot
.5 .61803 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49985 .61797 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48427 .61136 Mdot
.44993 .59681 Mdot
.34171 .55115 Mdot
.0333 .42743 Mdot
.49986 .61797 Mdot
.49954 .61784 Mdot
.49854 .61741 Mdot
.49535 .61606 Mdot
.48517 .61175 Mdot
.45278 .59802 Mdot
.3506 .55488 Mdot
.05581 .43584 Mdot
.67901 .38516 Mdot
.51758 .51827 Mdot
.38248 .53454 Mdot
.49897 .6176 Mdot
.49673 .61665 Mdot
.48957 .61361 Mdot
.46678 .60395 Mdot
.39453 .57338 Mdot
.17539 .4826 Mdot
.74328 .35097 Mdot
.54968 .49839 Mdot
.42941 .5437 Mdot
.2067 .48039 Mdot
.75403 .33827 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.489 .61337 Mdot
.46497 .60318 Mdot
.38882 .57097 Mdot
.15913 .47608 Mdot
.72858 .35194 Mdot
.5346 .49815 Mdot
.3921 .52997 Mdot
.09988 .43743 Mdot
.66748 .35079 Mdot
.49821 .61727 Mdot
.4943 .61562 Mdot
.48183 .61033 Mdot
.44217 .59352 Mdot
.31767 .54109 Mdot
.9757 .40668 Mdot
.67003 .42912 Mdot
.5736 .55843 Mdot
.58367 .00622 Mdot
.71353 .08026 Mdot
.07589 .22395 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48384 .61118 Mdot
.44855 .59623 Mdot
.33743 .54936 Mdot
.02271 .42352 Mdot
.67404 .40254 Mdot
.53742 .5336 Mdot
.49812 .61724 Mdot
.49401 .61549 Mdot
.48093 .60995 Mdot
.43929 .5923 Mdot
.3088 .53738 Mdot
.95567 .39979 Mdot
.66818 .44036 Mdot
.58857 .56883 Mdot
.63506 .02873 Mdot
.86069 .13945 Mdot
.2696 .25272 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.52168 .00919 Mdot
.56899 .02923 Mdot
.71656 .0912 Mdot
.09761 .2355 Mdot
.34126 .15058 Mdot
.38435 .02663 Mdot
.26883 .54664 Mdot
.91625 .40013 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.5137 .00581 Mdot
.54364 .0185 Mdot
.63821 .05845 Mdot
.91502 .17107 Mdot
.31332 .24617 Mdot
.49154 .11015 Mdot
.65709 .10231 Mdot
.02182 .22542 Mdot
.35393 .20525 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50449 .0019 Mdot
.51431 .00607 Mdot
.54557 .01932 Mdot
.64425 .06099 Mdot
.93086 .17714 Mdot
.31796 .23924 Mdot
.48775 .10494 Mdot
.63918 .09359 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50595 .00252 Mdot
.51896 .00804 Mdot
.56033 .02557 Mdot
.69005 .08017 Mdot
.04175 .21737 Mdot
.33155 .1791 Mdot
.41327 .0505 Mdot
.37123 .59205 Mdot
.15643 .48528 Mdot
.74298 .36251 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00327 Mdot
.5246 .01043 Mdot
.57823 .03314 Mdot
.74452 .10278 Mdot
.14941 .25024 Mdot
.36168 .13119 Mdot
.39162 .01851 Mdot
.27128 .54366 Mdot
.91433 .39743 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.4879 .6129 Mdot
.46147 .6017 Mdot
.37782 .56633 Mdot
.12837 .46387 Mdot
.70658 .35735 Mdot
.51468 .49944 Mdot
.34478 .51303 Mdot
.97725 .39088 Mdot
.64373 .41191 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50331 .0014 Mdot
.51054 .00447 Mdot
.53357 .01423 Mdot
.60657 .04512 Mdot
.82776 .1367 Mdot
.25975 .26698 Mdot
.45345 .11971 Mdot
.57832 .07717 Mdot
.81597 .14688 Mdot
.27215 .28193 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51298 .00551 Mdot
.54135 .01753 Mdot
.63104 .05543 Mdot
.89582 .16364 Mdot
.30595 .25347 Mdot
.49194 .11495 Mdot
.66586 .10749 Mdot
.04592 .23489 Mdot
.35805 .19291 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50686 .00291 Mdot
.52186 .00927 Mdot
.56955 .02947 Mdot
.71827 .09192 Mdot
.10101 .23654 Mdot
.34219 .14906 Mdot
.3836 .02559 Mdot
.26556 .54508 Mdot
.90992 .39824 Mdot
.68231 .47736 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47768 .60857 Mdot
.429 .58795 Mdot
.27733 .52429 Mdot
.89043 .37892 Mdot
.65521 .47266 Mdot
.61761 .5948 Mdot
.74082 .07614 Mdot
.10235 .22344 Mdot
.32073 .13496 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50832 .00353 Mdot
.5265 .01124 Mdot
.58426 .03569 Mdot
.76257 .1102 Mdot
.17887 .25729 Mdot
.37989 .12424 Mdot
.41736 .02316 Mdot
.33637 .56798 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50551 .00234 Mdot
.51757 .00745 Mdot
.55591 .0237 Mdot
.67642 .07447 Mdot
.01059 .20653 Mdot
.32889 .19672 Mdot
.43719 .06693 Mdot
.4537 .01021 Mdot
.40175 .58592 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50798 .00338 Mdot
.52541 .01077 Mdot
.58079 .03423 Mdot
.75222 .10595 Mdot
.16235 .25348 Mdot
.36905 .12775 Mdot
.40075 .01959 Mdot
.29304 .55147 Mdot
.95528 .40929 Mdot
.68372 .4502 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50626 .00265 Mdot
.51993 .00845 Mdot
.56343 .02688 Mdot
.69958 .08415 Mdot
.06259 .22435 Mdot
.33411 .16781 Mdot
.39947 .0404 Mdot
.32387 .57131 Mdot
.0348 .43938 Mdot
.69394 .40737 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.48489 .61163 Mdot
.4519 .59764 Mdot
.34786 .55373 Mdot
.04881 .43321 Mdot
.67769 .38867 Mdot
.52108 .52124 Mdot
.39599 .54072 Mdot
.12575 .45102 Mdot
.68591 .3462 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51877 .00796 Mdot
.55973 .02531 Mdot
.68819 .07939 Mdot
.0376 .21595 Mdot
.33114 .18142 Mdot
.4163 .05263 Mdot
.38161 .5966 Mdot
.18528 .49669 Mdot
.76968 .36118 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.4933 .61519 Mdot
.47866 .60899 Mdot
.43211 .58926 Mdot
.28679 .52822 Mdot
.90908 .3846 Mdot
.66046 .46437 Mdot
.61376 .58918 Mdot
.72355 .06785 Mdot
.06877 .21336 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.49331 .6152 Mdot
.4787 .609 Mdot
.43224 .58932 Mdot
.28718 .52838 Mdot
.90988 .38485 Mdot
.66065 .464 Mdot
.6135 .5889 Mdot
.72254 .06739 Mdot
.06677 .21275 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50409 .00173 Mdot
.51302 .00552 Mdot
.54147 .01758 Mdot
.63142 .05559 Mdot
.89684 .16404 Mdot
.3064 .25312 Mdot
.49205 .11474 Mdot
.66577 .10737 Mdot
.04557 .23473 Mdot
.35794 .19306 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50806 .00342 Mdot
.52566 .01088 Mdot
.58159 .03457 Mdot
.75461 .10693 Mdot
.16626 .25442 Mdot
.37147 .12683 Mdot
.40417 .02021 Mdot
.30165 .55468 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47763 .60855 Mdot
.42885 .58789 Mdot
.27687 .5241 Mdot
.88955 .37866 Mdot
.65492 .47303 Mdot
.61768 .59502 Mdot
.74131 .07641 Mdot
.10332 .22373 Mdot
.32101 .13454 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.48482 .6116 Mdot
.45166 .59754 Mdot
.34709 .55341 Mdot
.04686 .43248 Mdot
.67735 .38966 Mdot
.52213 .5221 Mdot
.39998 .54255 Mdot
.1375 .45581 Mdot
.69348 .34362 Mdot
.4987 .61748 Mdot
.49587 .61628 Mdot
.48685 .61246 Mdot
.45814 .60029 Mdot
.36735 .56192 Mdot
.09983 .4527 Mdot
.69219 .3661 Mdot
.50772 .50402 Mdot
.33482 .51118 Mdot
.9563 .38409 Mdot
.64251 .4241 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .61119 Mdot
.44864 .59626 Mdot
.33769 .54947 Mdot
.02334 .42375 Mdot
.67411 .4022 Mdot
.53697 .53328 Mdot
.4548 .56725 Mdot
.30573 .5259 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41913 .58377 Mdot
.24754 .51198 Mdot
.83724 .36446 Mdot
.6307 .49039 Mdot
.59891 .59838 Mdot
.70611 .06625 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49292 .61503 Mdot
.47746 .60848 Mdot
.4283 .58765 Mdot
.27519 .52341 Mdot
.88634 .37771 Mdot
.65385 .47435 Mdot
.61783 .59578 Mdot
.74286 .07727 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.51211 .00514 Mdot
.53857 .01635 Mdot
.62233 .05177 Mdot
.87204 .15433 Mdot
.29367 .26058 Mdot
.4855 .11856 Mdot
.6556 .10513 Mdot
.02367 .22748 Mdot
.35636 .20561 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00112 Mdot
.50843 .00358 Mdot
.52686 .01139 Mdot
.58539 .03617 Mdot
.76596 .1116 Mdot
.18406 .2584 Mdot
.38362 .12334 Mdot
.42377 .02481 Mdot
.35389 .57485 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51644 .00697 Mdot
.55234 .02219 Mdot
.66533 .06983 Mdot
.98407 .19699 Mdot
.32666 .21174 Mdot
.45769 .08098 Mdot
.52599 .04221 Mdot
.63311 .0662 Mdot
.91742 .17571 Mdot
.49835 .61733 Mdot
.49473 .6158 Mdot
.48321 .61091 Mdot
.44655 .59538 Mdot
.33121 .54675 Mdot
.00755 .418 Mdot
.67257 .411 Mdot
.54862 .54143 Mdot
.49646 .5858 Mdot
.43901 .58252 Mdot
.29229 .52736 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.47491 .60739 Mdot
.42021 .58423 Mdot
.25079 .51332 Mdot
.84264 .36578 Mdot
.6339 .48903 Mdot
.60316 .59903 Mdot
.71654 .07007 Mdot
.0634 .21437 Mdot
.31765 .15714 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50513 .00217 Mdot
.51633 .00692 Mdot
.55199 .02204 Mdot
.66424 .06938 Mdot
.98141 .19602 Mdot
.3264 .21321 Mdot
.45963 .08234 Mdot
.53297 .04532 Mdot
.6554 .07567 Mdot
.97561 .1979 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52124 .00901 Mdot
.56759 .02864 Mdot
.7123 .08943 Mdot
.08907 .23286 Mdot
.3391 .15453 Mdot
.38685 .02951 Mdot
.27882 .55127 Mdot
.93596 .40614 Mdot
.68659 .46391 Mdot
.49792 .61715 Mdot
.49336 .61522 Mdot
.47886 .60907 Mdot
.43275 .58953 Mdot
.28873 .52903 Mdot
.91301 .38583 Mdot
.66138 .46252 Mdot
.61241 .58777 Mdot
.71838 .0655 Mdot
.0584 .21014 Mdot
.31277 .15721 Mdot
.4999 .61799 Mdot
.49967 .6179 Mdot
.49896 .61759 Mdot
.49669 .61663 Mdot
.48946 .61357 Mdot
.46644 .60381 Mdot
.39346 .57293 Mdot
.17234 .48137 Mdot
.74035 .35105 Mdot
.54665 .49832 Mdot
.42192 .54095 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48415 .61131 Mdot
.44954 .59664 Mdot
.34049 .55064 Mdot
.03028 .42631 Mdot
.67492 .39841 Mdot
.53222 .52984 Mdot
.43751 .5595 Mdot
.25147 .50305 Mdot
.82671 .35551 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.5225 .00954 Mdot
.57157 .03033 Mdot
.72442 .09447 Mdot
.11292 .24011 Mdot
.3459 .14399 Mdot
.38219 .02243 Mdot
.25746 .54095 Mdot
.89426 .39357 Mdot
.67826 .48454 Mdot
.49858 .61743 Mdot
.49548 .61612 Mdot
.48559 .61193 Mdot
.45413 .59859 Mdot
.35481 .55665 Mdot
.06667 .43996 Mdot
.68143 .37994 Mdot
.5131 .514 Mdot
.3644 .52613 Mdot
.03604 .41509 Mdot
.65408 .38197 Mdot
.49876 .61751 Mdot
.49605 .61636 Mdot
.4874 .61269 Mdot
.45988 .60102 Mdot
.3728 .56422 Mdot
.11461 .45846 Mdot
.69898 .36116 Mdot
.50992 .50119 Mdot
.33572 .51037 Mdot
.95658 .38372 Mdot
.64177 .42347 Mdot
.49922 .6177 Mdot
.4975 .61698 Mdot
.49205 .61466 Mdot
.47467 .6073 Mdot
.41947 .58392 Mdot
.24856 .5124 Mdot
.83892 .36487 Mdot
.63172 .48997 Mdot
.60029 .59861 Mdot
.70955 .06752 Mdot
.04987 .21033 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50806 .00342 Mdot
.52569 .01089 Mdot
.58168 .03461 Mdot
.75489 .10705 Mdot
.16672 .25452 Mdot
.37176 .12672 Mdot
.40459 .02029 Mdot
.30273 .55508 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50595 .00252 Mdot
.51895 .00803 Mdot
.56029 .02556 Mdot
.68994 .08012 Mdot
.04152 .21729 Mdot
.33152 .17923 Mdot
.41344 .05063 Mdot
.37182 .59231 Mdot
.15804 .48591 Mdot
.74429 .36232 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50333 .00141 Mdot
.51062 .00451 Mdot
.53384 .01435 Mdot
.60744 .04548 Mdot
.83022 .13769 Mdot
.26205 .26688 Mdot
.45583 .11976 Mdot
.5842 .07934 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50508 .00215 Mdot
.51619 .00687 Mdot
.55154 .02185 Mdot
.66285 .0688 Mdot
.978 .19477 Mdot
.32604 .2151 Mdot
.46208 .08408 Mdot
.54178 .04926 Mdot
.68343 .08755 Mdot
.04323 .22237 Mdot
.49983 .61796 Mdot
.49944 .6178 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48204 .61042 Mdot
.44283 .5938 Mdot
.31969 .54193 Mdot
.98035 .40831 Mdot
.67041 .42648 Mdot
.56996 .55595 Mdot
.5711 .00071 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50746 .00316 Mdot
.52377 .01008 Mdot
.57561 .03204 Mdot
.73665 .09953 Mdot
.13558 .24655 Mdot
.35486 .13552 Mdot
.38538 .01886 Mdot
.25845 .53958 Mdot
.89312 .39225 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.48752 .61274 Mdot
.46027 .60119 Mdot
.37404 .56474 Mdot
.11799 .45978 Mdot
.70072 .36015 Mdot
.51084 .50068 Mdot
.33721 .51072 Mdot
.9598 .38478 Mdot
.64205 .42166 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48275 .61072 Mdot
.44509 .59476 Mdot
.32669 .54486 Mdot
.99675 .41412 Mdot
.67168 .41713 Mdot
.55702 .54717 Mdot
.52607 .59891 Mdot
.53405 .00493 Mdot
.49745 .61695 Mdot
.49186 .61458 Mdot
.47407 .60704 Mdot
.41756 .58311 Mdot
.24286 .51006 Mdot
.82966 .36266 Mdot
.62591 .49211 Mdot
.59193 .59703 Mdot
.68832 .05957 Mdot
.00572 .19617 Mdot
.31455 .19086 Mdot
.49833 .61732 Mdot
.49467 .61577 Mdot
.48302 .61083 Mdot
.44593 .59512 Mdot
.3293 .54595 Mdot
.00297 .41635 Mdot
.67218 .41359 Mdot
.55215 .54385 Mdot
.50895 .59134 Mdot
.47918 .59963 Mdot
.41828 .58039 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50663 .00281 Mdot
.52112 .00896 Mdot
.5672 .02848 Mdot
.7111 .08894 Mdot
.08664 .2321 Mdot
.33854 .15569 Mdot
.38772 .03039 Mdot
.28211 .55276 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50584 .00248 Mdot
.51861 .00789 Mdot
.55922 .0251 Mdot
.68662 .07874 Mdot
.03408 .21474 Mdot
.33081 .18339 Mdot
.41892 .05446 Mdot
.3906 .60053 Mdot
.21081 .50692 Mdot
.79949 .36382 Mdot
.49845 .61738 Mdot
.49507 .61594 Mdot
.4843 .61137 Mdot
.45 .59684 Mdot
.34194 .55125 Mdot
.03389 .42765 Mdot
.67539 .39647 Mdot
.52986 .52809 Mdot
.42885 .55561 Mdot
.22463 .49182 Mdot
.78471 .34615 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50831 .00352 Mdot
.52647 .01122 Mdot
.58415 .03565 Mdot
.76226 .11008 Mdot
.1784 .25719 Mdot
.37955 .12432 Mdot
.4168 .02302 Mdot
.33486 .56739 Mdot
.04733 .44033 Mdot
.68984 .3971 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50515 .00218 Mdot
.51641 .00696 Mdot
.55223 .02214 Mdot
.665 .0697 Mdot
.98327 .1967 Mdot
.32658 .21218 Mdot
.45828 .08139 Mdot
.4976 .61702 Mdot
.49234 .61479 Mdot
.47561 .60769 Mdot
.42244 .58517 Mdot
.25748 .51608 Mdot
.85405 .3687 Mdot
.64013 .48582 Mdot
.61027 .59958 Mdot
.7329 .07579 Mdot
.09289 .22248 Mdot
.32132 .14118 Mdot
.49899 .6176 Mdot
.49677 .61667 Mdot
.48972 .61367 Mdot
.46725 .60415 Mdot
.39601 .574 Mdot
.17964 .48431 Mdot
.7475 .35095 Mdot
.55405 .49848 Mdot
.44013 .54763 Mdot
.23851 .49343 Mdot
.79878 .34627 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50657 .00279 Mdot
.52094 .00888 Mdot
.56664 .02824 Mdot
.7094 .08823 Mdot
.08316 .231 Mdot
.33778 .15737 Mdot
.38907 .0317 Mdot
.28712 .55502 Mdot
.9529 .41148 Mdot
.6883 .4545 Mdot
.49753 .61698 Mdot
.49211 .61469 Mdot
.47488 .60738 Mdot
.42012 .58419 Mdot
.25052 .51321 Mdot
.84219 .36567 Mdot
.63364 .48915 Mdot
.60283 .59899 Mdot
.71574 .06978 Mdot
.06188 .21392 Mdot
.31752 .15799 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51813 .00769 Mdot
.5577 .02445 Mdot
.68192 .07678 Mdot
.02338 .21103 Mdot
.32989 .18944 Mdot
.42712 .06009 Mdot
.41882 .6129 Mdot
.29395 .54086 Mdot
.9394 .39891 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.48052 .60977 Mdot
.438 .59176 Mdot
.30483 .53573 Mdot
.94694 .39685 Mdot
.66718 .44513 Mdot
.59455 .57315 Mdot
.65554 .0377 Mdot
.91445 .16001 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.50868 .00368 Mdot
.52766 .01173 Mdot
.58793 .03725 Mdot
.77348 .11468 Mdot
.19517 .26062 Mdot
.39216 .12174 Mdot
.43947 .02924 Mdot
.39817 .59251 Mdot
.21433 .50442 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51414 .006 Mdot
.54504 .01909 Mdot
.64259 .06029 Mdot
.92654 .17549 Mdot
.31681 .2412 Mdot
.48907 .10647 Mdot
.64496 .09634 Mdot
.98945 .21291 Mdot
.34975 .22268 Mdot
.49994 .61801 Mdot
.49981 .61796 Mdot
.49941 .61778 Mdot
.49812 .61724 Mdot
.49401 .61549 Mdot
.48091 .60994 Mdot
.43924 .59228 Mdot
.30864 .53732 Mdot
.95533 .39968 Mdot
.66815 .44054 Mdot
.58881 .569 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51802 .00764 Mdot
.55736 .02431 Mdot
.68089 .07634 Mdot
.02099 .2102 Mdot
.3297 .19079 Mdot
.42899 .06136 Mdot
.42525 .61572 Mdot
.31346 .54895 Mdot
.98167 .41298 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50515 .00218 Mdot
.51641 .00696 Mdot
.55223 .02214 Mdot
.66499 .06969 Mdot
.98322 .19668 Mdot
.32658 .21221 Mdot
.45831 .08141 Mdot
.52821 .0432 Mdot
.64021 .06922 Mdot
.93637 .18303 Mdot
.49866 .61747 Mdot
.49574 .61623 Mdot
.48643 .61228 Mdot
.45679 .59971 Mdot
.36312 .56014 Mdot
.08853 .44833 Mdot
.68788 .37042 Mdot
.50802 .50687 Mdot
.34019 .51431 Mdot
.97094 .38983 Mdot
.64504 .41661 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00132 Mdot
.50989 .00419 Mdot
.5315 .01335 Mdot
.60004 .04236 Mdot
.80895 .12912 Mdot
.24041 .26665 Mdot
.43356 .11938 Mdot
.52994 .05956 Mdot
.67095 .08715 Mdot
.02185 .21687 Mdot
.49932 .61775 Mdot
.49784 .61712 Mdot
.49312 .61512 Mdot
.47809 .60874 Mdot
.43031 .5885 Mdot
.28129 .52593 Mdot
.89813 .38123 Mdot
.65756 .46935 Mdot
.61657 .5927 Mdot
.73521 .07332 Mdot
.09155 .22023 Mdot
.49825 .61729 Mdot
.49444 .61567 Mdot
.48228 .61052 Mdot
.44358 .59412 Mdot
.32203 .54291 Mdot
.98578 .41022 Mdot
.67083 .42339 Mdot
.56569 .55305 Mdot
.5563 .61223 Mdot
.6296 .0453 Mdot
.87652 .1526 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .0034 Mdot
.52557 .01084 Mdot
.5813 .03444 Mdot
.75375 .10658 Mdot
.16486 .25408 Mdot
.37059 .12715 Mdot
.40291 .01997 Mdot
.29844 .55347 Mdot
.96623 .41271 Mdot
.68429 .44379 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48863 .61321 Mdot
.4638 .60269 Mdot
.38513 .56942 Mdot
.14874 .47194 Mdot
.72033 .35326 Mdot
.52651 .49825 Mdot
.37227 .52271 Mdot
.04634 .4166 Mdot
.65188 .37425 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47575 .60775 Mdot
.42287 .58535 Mdot
.25878 .51662 Mdot
.85631 .3693 Mdot
.64127 .48513 Mdot
.61139 .59956 Mdot
.73527 .07656 Mdot
.09687 .22348 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50814 .00345 Mdot
.52592 .01099 Mdot
.58242 .03492 Mdot
.75711 .10796 Mdot
.17028 .25536 Mdot
.37405 .12594 Mdot
.40801 .02099 Mdot
.31155 .55841 Mdot
.99397 .42176 Mdot
.68544 .42735 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48988 .61374 Mdot
.46777 .60437 Mdot
.39765 .57469 Mdot
.18436 .48622 Mdot
.75236 .35104 Mdot
.55906 .49857 Mdot
.45234 .55208 Mdot
.27519 .50855 Mdot
.49967 .6179 Mdot
.49896 .61759 Mdot
.49669 .61663 Mdot
.48947 .61357 Mdot
.46646 .60381 Mdot
.39351 .57295 Mdot
.17248 .48143 Mdot
.74048 .35104 Mdot
.54678 .49832 Mdot
.42226 .54107 Mdot
.1857 .47183 Mdot
.49817 .61726 Mdot
.49417 .61556 Mdot
.48142 .61016 Mdot
.44088 .59298 Mdot
.31368 .53942 Mdot
.9666 .40353 Mdot
.66926 .43426 Mdot
.58057 .56322 Mdot
.60764 .01673 Mdot
.78413 .10908 Mdot
.19389 .25325 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52612 .01107 Mdot
.58304 .03518 Mdot
.75894 .10871 Mdot
.17319 .25602 Mdot
.37598 .12533 Mdot
.411 .02164 Mdot
.31938 .56141 Mdot
.01134 .42766 Mdot
.68631 .41715 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50721 .00306 Mdot
.52298 .00975 Mdot
.5731 .03098 Mdot
.72907 .09639 Mdot
.1217 .24266 Mdot
.34906 .14052 Mdot
.38246 .02064 Mdot
.25513 .53934 Mdot
.8892 .39188 Mdot
.67637 .48649 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49442 .61567 Mdot
.48222 .61049 Mdot
.44339 .59404 Mdot
.32144 .54266 Mdot
.98441 .40974 Mdot
.67072 .42417 Mdot
.56676 .55378 Mdot
.56004 .61388 Mdot
.64125 .05019 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50577 .00245 Mdot
.51837 .00779 Mdot
.55847 .02478 Mdot
.68433 .07778 Mdot
.02888 .21294 Mdot
.33035 .18632 Mdot
.42287 .05718 Mdot
.40417 .60648 Mdot
.25024 .5229 Mdot
.85758 .37536 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.47851 .60892 Mdot
.43163 .58906 Mdot
.28532 .52761 Mdot
.90612 .38368 Mdot
.65972 .46575 Mdot
.61466 .59019 Mdot
.72711 .06949 Mdot
.07581 .21551 Mdot
.31505 .14786 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52144 .00909 Mdot
.56821 .0289 Mdot
.71418 .09022 Mdot
.09287 .23404 Mdot
.34002 .15275 Mdot
.38563 .02819 Mdot
.27407 .54909 Mdot
.92651 .40323 Mdot
.68531 .46896 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00125 Mdot
.50943 .004 Mdot
.53003 .01273 Mdot
.5954 .0404 Mdot
.79545 .12364 Mdot
.22456 .26521 Mdot
.41799 .11954 Mdot
.49377 .04684 Mdot
.56022 .04107 Mdot
.49979 .61794 Mdot
.49932 .61774 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47787 .60865 Mdot
.4296 .5882 Mdot
.27914 .52504 Mdot
.89393 .37996 Mdot
.65631 .47118 Mdot
.61724 .59389 Mdot
.73855 .07497 Mdot
.49965 .61789 Mdot
.4989 .61757 Mdot
.49649 .61655 Mdot
.48882 .61329 Mdot
.4644 .60294 Mdot
.38702 .57021 Mdot
.15406 .47405 Mdot
.72444 .35251 Mdot
.53048 .49816 Mdot
.38197 .52625 Mdot
.07221 .42659 Mdot
.49809 .61722 Mdot
.49392 .61546 Mdot
.48063 .60982 Mdot
.43835 .59191 Mdot
.3059 .53617 Mdot
.94929 .39764 Mdot
.66746 .44385 Mdot
.59298 .572 Mdot
.65017 .03534 Mdot
.90063 .1548 Mdot
.29066 .24105 Mdot
.49772 .61707 Mdot
.49274 .61496 Mdot
.47688 .60823 Mdot
.42647 .58688 Mdot
.26964 .52111 Mdot
.8759 .37469 Mdot
.65001 .47842 Mdot
.61726 .5978 Mdot
.74493 .0789 Mdot
.1112 .22637 Mdot
.32392 .13147 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50647 .00274 Mdot
.5206 .00873 Mdot
.56554 .02778 Mdot
.70605 .08684 Mdot
.07624 .22879 Mdot
.3364 .16078 Mdot
.39214 .03445 Mdot
.29818 .55997 Mdot
.97635 .41913 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50675 .00286 Mdot
.52152 .00912 Mdot
.56846 .02901 Mdot
.71495 .09054 Mdot
.09442 .23452 Mdot
.34042 .15204 Mdot
.38518 .02767 Mdot
.27228 .54826 Mdot
.92298 .40215 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50655 .00278 Mdot
.52086 .00885 Mdot
.56639 .02813 Mdot
.70862 .08791 Mdot
.08157 .2305 Mdot
.33745 .15814 Mdot
.38973 .03231 Mdot
.28953 .55611 Mdot
.95793 .41309 Mdot
.6887 .45164 Mdot
.49938 .61777 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.4798 .60947 Mdot
.43573 .5908 Mdot
.29787 .53283 Mdot
.93198 .3919 Mdot
.66505 .45306 Mdot
.60364 .58008 Mdot
.68692 .05147 Mdot
.99044 .18758 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48667 .61238 Mdot
.45757 .60004 Mdot
.36556 .56117 Mdot
.09502 .45084 Mdot
.69027 .36789 Mdot
.50764 .50516 Mdot
.33648 .51225 Mdot
.96096 .38595 Mdot
.64342 .42178 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47778 .60861 Mdot
.42932 .58808 Mdot
.27828 .52469 Mdot
.89226 .37946 Mdot
.65579 .47189 Mdot
.61744 .59433 Mdot
.73969 .07555 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52196 .00931 Mdot
.56986 .0296 Mdot
.71921 .09231 Mdot
.10285 .2371 Mdot
.34273 .14825 Mdot
.38325 .02505 Mdot
.26395 .5443 Mdot
.90683 .39732 Mdot
.68162 .47884 Mdot
.49787 .61713 Mdot
.49321 .61515 Mdot
.47836 .60886 Mdot
.43116 .58886 Mdot
.28387 .52701 Mdot
.90324 .38279 Mdot
.65897 .46707 Mdot
.61544 .59113 Mdot
.73028 .07098 Mdot
.08203 .21739 Mdot
.31611 .14467 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50658 .00279 Mdot
.52095 .00888 Mdot
.56667 .02825 Mdot
.70949 .08827 Mdot
.08334 .23106 Mdot
.33782 .15728 Mdot
.389 .03163 Mdot
.28685 .5549 Mdot
.95233 .41129 Mdot
.68826 .45482 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49855 .61742 Mdot
.49538 .61608 Mdot
.48529 .6118 Mdot
.45316 .59818 Mdot
.35179 .55538 Mdot
.05887 .437 Mdot
.67964 .38366 Mdot
.51621 .51702 Mdot
.37703 .53202 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49847 .61738 Mdot
.49512 .61597 Mdot
.48446 .61144 Mdot
.45051 .59706 Mdot
.34353 .55192 Mdot
.03787 .42913 Mdot
.67594 .39435 Mdot
.52735 .5262 Mdot
.41959 .55143 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50833 .00353 Mdot
.52654 .01125 Mdot
.58438 .03575 Mdot
.76294 .11036 Mdot
.17945 .25741 Mdot
.38029 .12413 Mdot
.41804 .02333 Mdot
.33821 .5687 Mdot
.05539 .44324 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54096 .01737 Mdot
.62983 .05492 Mdot
.89256 .16237 Mdot
.30448 .25458 Mdot
.49152 .1156 Mdot
.66586 .10774 Mdot
.04633 .23514 Mdot
.35828 .1928 Mdot
.49991 .618 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49083 .61415 Mdot
.47081 .60566 Mdot
.40723 .57874 Mdot
.21226 .49753 Mdot
.78523 .35412 Mdot
.59111 .49806 Mdot
.52631 .57799 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50686 .00291 Mdot
.52184 .00926 Mdot
.56949 .02945 Mdot
.71809 .09184 Mdot
.10064 .23643 Mdot
.34209 .14923 Mdot
.38367 .0257 Mdot
.26589 .54524 Mdot
.49874 .6175 Mdot
.496 .61634 Mdot
.48725 .61263 Mdot
.45938 .60081 Mdot
.37125 .56357 Mdot
.11039 .45681 Mdot
.6969 .36248 Mdot
.50898 .50189 Mdot
.33453 .51022 Mdot
.95423 .383 Mdot
.64164 .42484 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50664 .00282 Mdot
.52116 .00897 Mdot
.56731 .02853 Mdot
.71146 .08909 Mdot
.08737 .23232 Mdot
.33871 .15534 Mdot
.38745 .03013 Mdot
.2811 .5523 Mdot
.94056 .40757 Mdot
.68712 .4614 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49392 .61546 Mdot
.48063 .60982 Mdot
.43837 .59191 Mdot
.30594 .53619 Mdot
.94939 .39767 Mdot
.66748 .4438 Mdot
.59292 .57195 Mdot
.64995 .03525 Mdot
.90008 .15459 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52351 .00997 Mdot
.57478 .03169 Mdot
.73413 .09849 Mdot
.13103 .2453 Mdot
.35285 .13709 Mdot
.38407 .01929 Mdot
.25636 .53911 Mdot
.89012 .39168 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50344 .00146 Mdot
.51096 .00465 Mdot
.53489 .01479 Mdot
.61075 .04688 Mdot
.83965 .14147 Mdot
.2704 .26622 Mdot
.46437 .11988 Mdot
.60534 .08713 Mdot
.89304 .17781 Mdot
.32937 .26967 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48939 .61354 Mdot
.46621 .60371 Mdot
.39273 .57262 Mdot
.17025 .48053 Mdot
.73839 .35113 Mdot
.54462 .49828 Mdot
.41692 .53911 Mdot
.17017 .46554 Mdot
.50075 .00032 Mdot
.50237 .00101 Mdot
.50756 .00321 Mdot
.52409 .01022 Mdot
.57663 .03247 Mdot
.73971 .10079 Mdot
.14103 .24803 Mdot
.35742 .13374 Mdot
.38743 .01854 Mdot
.2623 .5407 Mdot
.89915 .3936 Mdot
.67736 .48096 Mdot
.5 0 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.50868 .00368 Mdot
.52766 .01173 Mdot
.58791 .03724 Mdot
.77344 .11466 Mdot
.19511 .26061 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00099 Mdot
.50741 .00314 Mdot
.5236 .01 Mdot
.57505 .0318 Mdot
.73494 .09882 Mdot
.1325 .24571 Mdot
.35349 .13658 Mdot
.38445 .01914 Mdot
.25692 .53922 Mdot
.89089 .39181 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.5053 .00225 Mdot
.51687 .00715 Mdot
.55371 .02277 Mdot
.66959 .07162 Mdot
.99438 .20073 Mdot
.3276 .20594 Mdot
.4499 .07559 Mdot
.49828 .0299 Mdot
.54409 .02831 Mdot
.6552 .06867 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49067 .61408 Mdot
.4703 .60544 Mdot
.40562 .57806 Mdot
.20753 .49561 Mdot
.77916 .35328 Mdot
.58552 .49836 Mdot
.51408 .57388 Mdot
.46372 .58691 Mdot
.35942 .55357 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51875 .00795 Mdot
.55969 .0253 Mdot
.68806 .07934 Mdot
.03732 .21585 Mdot
.33111 .18157 Mdot
.4165 .05278 Mdot
.38232 .59691 Mdot
.18728 .49749 Mdot
.49873 .61749 Mdot
.49594 .61631 Mdot
.48708 .61255 Mdot
.45885 .60059 Mdot
.36958 .56286 Mdot
.10585 .45504 Mdot
.69479 .36399 Mdot
.50825 .50275 Mdot
.33409 .51039 Mdot
.95374 .38297 Mdot
.64181 .42525 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50353 .0015 Mdot
.51125 .00477 Mdot
.53583 .01519 Mdot
.6137 .04813 Mdot
.84797 .14479 Mdot
.27716 .26525 Mdot
.47108 .11985 Mdot
.62185 .09318 Mdot
.93806 .19543 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50613 .0026 Mdot
.51953 .00828 Mdot
.56215 .02634 Mdot
.69566 .08251 Mdot
.05411 .22154 Mdot
.33295 .17234 Mdot
.40476 .04438 Mdot
.3421 .5793 Mdot
.07956 .45578 Mdot
.70259 .38505 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50332 .00141 Mdot
.51059 .00449 Mdot
.53374 .01431 Mdot
.60712 .04535 Mdot
.82932 .13733 Mdot
.26121 .26692 Mdot
.45496 .11975 Mdot
.58205 .07855 Mdot
.82685 .15129 Mdot
.28308 .28197 Mdot
.49823 .61728 Mdot
.49437 .61564 Mdot
.48205 .61042 Mdot
.44287 .59382 Mdot
.31983 .54199 Mdot
.98066 .40842 Mdot
.67043 .4263 Mdot
.56972 .55579 Mdot
.57026 .00034 Mdot
.67282 .06338 Mdot
.98658 .19392 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50924 .00392 Mdot
.52945 .01248 Mdot
.59356 .03963 Mdot
.79008 .12145 Mdot
.2178 .26434 Mdot
.41165 .11981 Mdot
.47969 .04205 Mdot
.51736 .02328 Mdot
.58101 .03934 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49431 .61562 Mdot
.48188 .61035 Mdot
.44233 .59359 Mdot
.31816 .54129 Mdot
.97682 .40707 Mdot
.67013 .42849 Mdot
.57273 .55784 Mdot
.58066 .0049 Mdot
.70448 .07652 Mdot
.49857 .61743 Mdot
.49544 .6161 Mdot
.48546 .61187 Mdot
.45369 .5984 Mdot
.35344 .55608 Mdot
.06314 .43861 Mdot
.68059 .38161 Mdot
.51443 .51534 Mdot
.36988 .5287 Mdot
.05119 .42107 Mdot
.65703 .37443 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51252 .00531 Mdot
.53987 .0169 Mdot
.62639 .05347 Mdot
.88319 .15871 Mdot
.29989 .25754 Mdot
.4895 .11718 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52305 .00977 Mdot
.57331 .03106 Mdot
.72968 .09664 Mdot
.12284 .24299 Mdot
.3495 .14008 Mdot
.38258 .02044 Mdot
.25507 .53923 Mdot
.88896 .39176 Mdot
.67622 .48655 Mdot
.50068 .00029 Mdot
.50216 .00091 Mdot
.50687 .00291 Mdot
.52188 .00928 Mdot
.56961 .0295 Mdot
.71847 .092 Mdot
.10139 .23666 Mdot
.3423 .14889 Mdot
.38352 .02548 Mdot
.26521 .54491 Mdot
.90926 .39804 Mdot
.68216 .47768 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50997 .00423 Mdot
.53176 .01347 Mdot
.60089 .04272 Mdot
.81141 .13011 Mdot
.24311 .26681 Mdot
.43631 .1194 Mdot
.53649 .06192 Mdot
.69093 .09545 Mdot
.06785 .23295 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48647 .6123 Mdot
.45693 .59977 Mdot
.36356 .56033 Mdot
.08968 .44877 Mdot
.68829 .36996 Mdot
.50792 .50655 Mdot
.33941 .51389 Mdot
.96885 .38902 Mdot
.64472 .41771 Mdot
.49756 .617 Mdot
.49222 .61474 Mdot
.47523 .60753 Mdot
.42122 .58465 Mdot
.2538 .51457 Mdot
.84772 .36706 Mdot
.63677 .48766 Mdot
.60664 .59941 Mdot
.72475 .073 Mdot
.07861 .21869 Mdot
.31929 .14875 Mdot
.50004 2e-05 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50413 .00175 Mdot
.51314 .00557 Mdot
.54186 .01774 Mdot
.63263 .0561 Mdot
.90011 .16531 Mdot
.30778 .25195 Mdot
.49228 .11403 Mdot
.66519 .10687 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47593 .60783 Mdot
.42344 .5856 Mdot
.26049 .51733 Mdot
.85933 .3701 Mdot
.64275 .48418 Mdot
.61273 .59948 Mdot
.73801 .07743 Mdot
.10134 .22455 Mdot
.32273 .13682 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50697 .00295 Mdot
.52219 .00941 Mdot
.57059 .02991 Mdot
.72145 .09323 Mdot
.10721 .23841 Mdot
.34404 .14637 Mdot
.38262 .02384 Mdot
.26067 .54266 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50522 .00221 Mdot
.51663 .00705 Mdot
.55294 .02244 Mdot
.6672 .07062 Mdot
.98862 .19864 Mdot
.32709 .20919 Mdot
.45429 .07862 Mdot
.51388 .03683 Mdot
.59425 .04967 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50387 .00164 Mdot
.51232 .00522 Mdot
.53922 .01663 Mdot
.62437 .05262 Mdot
.87765 .15654 Mdot
.29691 .25911 Mdot
.48773 .11793 Mdot
.66016 .10657 Mdot
.03428 .23122 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52546 .01079 Mdot
.58095 .0343 Mdot
.7527 .10615 Mdot
.16315 .25367 Mdot
.36954 .12756 Mdot
.40142 .01971 Mdot
.29471 .55208 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52145 .00909 Mdot
.56823 .02891 Mdot
.71426 .09025 Mdot
.09302 .23409 Mdot
.34006 .15268 Mdot
.38559 .02814 Mdot
.27389 .549 Mdot
.92616 .40312 Mdot
.68525 .46915 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51501 .00637 Mdot
.54781 .02027 Mdot
.65123 .06392 Mdot
.94887 .18395 Mdot
.32189 .23054 Mdot
.48013 .09779 Mdot
.60863 .07942 Mdot
.88773 .17249 Mdot
.32161 .26815 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48652 .61232 Mdot
.45708 .59984 Mdot
.36404 .56053 Mdot
.09099 .44927 Mdot
.68876 .36945 Mdot
.50782 .5062 Mdot
.33859 .51345 Mdot
.96666 .38817 Mdot
.64438 .41885 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52329 .00987 Mdot
.57407 .03139 Mdot
.73199 .0976 Mdot
.12712 .2442 Mdot
.35121 .13849 Mdot
.38322 .01979 Mdot
.25536 .53901 Mdot
.88891 .39155 Mdot
.67589 .48638 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.5077 .00327 Mdot
.52454 .0104 Mdot
.57803 .03306 Mdot
.74394 .10254 Mdot
.1484 .24997 Mdot
.36115 .13148 Mdot
.39105 .01848 Mdot
.26999 .54322 Mdot
.91208 .39683 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.48482 .6116 Mdot
.45166 .59754 Mdot
.34709 .55341 Mdot
.04686 .43248 Mdot
.67735 .38966 Mdot
.52212 .5221 Mdot
.39997 .54254 Mdot
.13746 .45579 Mdot
.69345 .34362 Mdot
.49938 .61777 Mdot
.49801 .61719 Mdot
.49366 .61534 Mdot
.4798 .60947 Mdot
.43571 .59079 Mdot
.29779 .53279 Mdot
.93182 .39185 Mdot
.66502 .45314 Mdot
.60372 .58015 Mdot
.68723 .05161 Mdot
.99115 .18783 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48603 .61211 Mdot
.45551 .59917 Mdot
.35913 .55847 Mdot
.07798 .44427 Mdot
.68448 .37484 Mdot
.50977 .51006 Mdot
.3497 .51911 Mdot
.99624 .39958 Mdot
.64841 .40307 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48968 .61366 Mdot
.46712 .60409 Mdot
.39561 .57383 Mdot
.17849 .48385 Mdot
.74633 .35095 Mdot
.55285 .49845 Mdot
.43719 .54655 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50714 .00303 Mdot
.52274 .00964 Mdot
.57234 .03065 Mdot
.72674 .09543 Mdot
.11734 .2414 Mdot
.34744 .14221 Mdot
.38218 .02147 Mdot
.25589 .53998 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52601 .01103 Mdot
.58269 .03503 Mdot
.75791 .10829 Mdot
.17157 .25565 Mdot
.3749 .12567 Mdot
.40931 .02127 Mdot
.31493 .5597 Mdot
.00141 .42427 Mdot
.68578 .42296 Mdot
.49743 .61694 Mdot
.49181 .61456 Mdot
.47391 .60697 Mdot
.41705 .58289 Mdot
.24131 .50942 Mdot
.8272 .3621 Mdot
.62428 .49262 Mdot
.58941 .59648 Mdot
.68172 .05705 Mdot
.99112 .19122 Mdot
.31383 .19945 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50793 .00336 Mdot
.52526 .01071 Mdot
.58032 .03403 Mdot
.75082 .10537 Mdot
.16005 .25292 Mdot
.36767 .12832 Mdot
.39888 .01929 Mdot
.28842 .54976 Mdot
.94615 .4065 Mdot
.68312 .45548 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00249 Mdot
.51867 .00792 Mdot
.55942 .02518 Mdot
.68724 .079 Mdot
.03547 .21522 Mdot
.33094 .18261 Mdot
.41788 .05373 Mdot
.38703 .59897 Mdot
.20059 .50281 Mdot
.49778 .61709 Mdot
.49293 .61503 Mdot
.47746 .60848 Mdot
.42831 .58766 Mdot
.27522 .52342 Mdot
.88639 .37772 Mdot
.65387 .47433 Mdot
.61783 .59576 Mdot
.74284 .07726 Mdot
.10633 .22465 Mdot
.32193 .13325 Mdot
.49907 .61764 Mdot
.49705 .61678 Mdot
.4906 .61405 Mdot
.47006 .60534 Mdot
.40487 .57774 Mdot
.20533 .49471 Mdot
.7764 .35294 Mdot
.58292 .49846 Mdot
.50828 .5719 Mdot
.44605 .57958 Mdot
.30445 .53052 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.50381 .00161 Mdot
.51212 .00514 Mdot
.53861 .01637 Mdot
.62244 .05181 Mdot
.87234 .15445 Mdot
.29385 .26051 Mdot
.48563 .11853 Mdot
.65588 .10522 Mdot
.02432 .22771 Mdot
.35642 .20525 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51265 .00536 Mdot
.54028 .01708 Mdot
.62769 .05402 Mdot
.88672 .1601 Mdot
.30169 .25646 Mdot
.49041 .11663 Mdot
.66474 .10774 Mdot
.04436 .23462 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50283 .0012 Mdot
.50903 .00383 Mdot
.52877 .0122 Mdot
.59142 .03872 Mdot
.78379 .11889 Mdot
.20954 .26312 Mdot
.40422 .12032 Mdot
.46375 .03679 Mdot
.46938 .00348 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48801 .61295 Mdot
.46181 .60184 Mdot
.37887 .56677 Mdot
.13127 .46501 Mdot
.70834 .35665 Mdot
.51602 .49917 Mdot
.34769 .514 Mdot
.98421 .39339 Mdot
.64437 .408 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48327 .61094 Mdot
.44674 .59546 Mdot
.3318 .547 Mdot
.00898 .41852 Mdot
.67269 .4102 Mdot
.54753 .54068 Mdot
.4926 .58409 Mdot
.42657 .57723 Mdot
.25425 .51154 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50798 .00338 Mdot
.52541 .01078 Mdot
.58081 .03424 Mdot
.75228 .10597 Mdot
.16246 .2535 Mdot
.36911 .12772 Mdot
.40084 .01961 Mdot
.29326 .55155 Mdot
.95571 .40942 Mdot
.68374 .44995 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00341 Mdot
.52563 .01087 Mdot
.5815 .03453 Mdot
.75435 .10683 Mdot
.16585 .25432 Mdot
.37121 .12692 Mdot
.40379 .02014 Mdot
.30069 .55431 Mdot
.97086 .41419 Mdot
.6845 .44105 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51217 .00516 Mdot
.53875 .01643 Mdot
.62288 .052 Mdot
.87357 .15493 Mdot
.29457 .2602 Mdot
.48615 .1184 Mdot
.65697 .10557 Mdot
.0269 .22862 Mdot
.35667 .20381 Mdot
.49887 .61755 Mdot
.49639 .6165 Mdot
.48849 .61315 Mdot
.46334 .60249 Mdot
.38368 .5688 Mdot
.14467 .47032 Mdot
.71733 .35392 Mdot
.5237 .49837 Mdot
.3655 .52026 Mdot
.02872 .40989 Mdot
.64909 .38341 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48374 .61114 Mdot
.44822 .59609 Mdot
.33641 .54893 Mdot
.02018 .4226 Mdot
.67377 .40394 Mdot
.53922 .53488 Mdot
.4629 .57087 Mdot
.33144 .53679 Mdot
.99182 .40814 Mdot
.50038 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51245 .00528 Mdot
.53964 .01681 Mdot
.62567 .05317 Mdot
.88123 .15794 Mdot
.29886 .25811 Mdot
.48892 .11746 Mdot
.66238 .1072 Mdot
.03929 .23294 Mdot
.35786 .19689 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51555 .00659 Mdot
.54949 .02098 Mdot
.65649 .06613 Mdot
.96217 .18893 Mdot
.32407 .22366 Mdot
.47262 .09181 Mdot
.58031 .06655 Mdot
.80341 .13788 Mdot
.25193 .2772 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50746 .00316 Mdot
.52375 .01007 Mdot
.57553 .03201 Mdot
.73642 .09943 Mdot
.13516 .24644 Mdot
.35467 .13566 Mdot
.38524 .01889 Mdot
.25821 .53952 Mdot
.89276 .39217 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .00341 Mdot
.52558 .01085 Mdot
.58134 .03446 Mdot
.75388 .10663 Mdot
.16508 .25413 Mdot
.37073 .1271 Mdot
.4031 .02001 Mdot
.29894 .55366 Mdot
.96724 .41303 Mdot
.68434 .44319 Mdot
.49922 .6177 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.4749 .60739 Mdot
.42018 .58422 Mdot
.25068 .51328 Mdot
.84246 .36574 Mdot
.6338 .48908 Mdot
.60303 .59901 Mdot
.71622 .06996 Mdot
.06279 .21419 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50285 .00121 Mdot
.50908 .00385 Mdot
.52891 .01226 Mdot
.59187 .03891 Mdot
.78511 .11943 Mdot
.2113 .2634 Mdot
.40578 .12019 Mdot
.46704 .03786 Mdot
.47922 .00752 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.4818 .61032 Mdot
.44209 .59349 Mdot
.3174 .54097 Mdot
.97508 .40646 Mdot
.66998 .42948 Mdot
.57408 .55876 Mdot
.58533 .00695 Mdot
.71854 .08232 Mdot
.08582 .227 Mdot
.49967 .6179 Mdot
.49896 .61759 Mdot
.49668 .61663 Mdot
.48942 .61355 Mdot
.4663 .60374 Mdot
.39299 .57273 Mdot
.171 .48084 Mdot
.73909 .3511 Mdot
.54535 .49829 Mdot
.41871 .53977 Mdot
.17538 .46765 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47698 .60827 Mdot
.42679 .58701 Mdot
.2706 .52151 Mdot
.87768 .37519 Mdot
.6507 .47776 Mdot
.61748 .5975 Mdot
.74491 .07875 Mdot
.11094 .22622 Mdot
.50007 3e-05 Mdot
.50022 .0001 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50725 .00308 Mdot
.5231 .0098 Mdot
.57348 .03114 Mdot
.7302 .09686 Mdot
.12381 .24326 Mdot
.34988 .13972 Mdot
.3827 .02028 Mdot
.25507 .53915 Mdot
.49835 .61733 Mdot
.49473 .6158 Mdot
.48321 .61091 Mdot
.44654 .59538 Mdot
.3312 .54675 Mdot
.00752 .41799 Mdot
.67257 .41102 Mdot
.54864 .54144 Mdot
.49655 .58584 Mdot
.43927 .58264 Mdot
.2931 .5277 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51749 .00741 Mdot
.55566 .02359 Mdot
.67563 .07415 Mdot
.00875 .20588 Mdot
.32875 .19777 Mdot
.43864 .06792 Mdot
.45877 .01244 Mdot
.41774 .59268 Mdot
.25875 .51977 Mdot
.49888 .61756 Mdot
.49644 .61652 Mdot
.48865 .61322 Mdot
.46384 .6027 Mdot
.38525 .56946 Mdot
.14907 .47207 Mdot
.72057 .35321 Mdot
.52674 .49824 Mdot
.37283 .52291 Mdot
.04784 .41717 Mdot
.65216 .37349 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48501 .61168 Mdot
.45227 .5978 Mdot
.34899 .55421 Mdot
.0517 .43429 Mdot
.67821 .38721 Mdot
.51958 .52 Mdot
.39026 .53811 Mdot
.10905 .44424 Mdot
.67677 .35087 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49775 .61708 Mdot
.49284 .615 Mdot
.47719 .60836 Mdot
.42743 .58728 Mdot
.27256 .52232 Mdot
.88135 .37625 Mdot
.65208 .47634 Mdot
.61777 .59683 Mdot
.74443 .07828 Mdot
.4987 .61748 Mdot
.49587 .61628 Mdot
.48685 .61246 Mdot
.45812 .60028 Mdot
.3673 .5619 Mdot
.0997 .45265 Mdot
.69214 .36615 Mdot
.50771 .50405 Mdot
.33485 .5112 Mdot
.95639 .38413 Mdot
.64253 .42406 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50392 .00166 Mdot
.51248 .00529 Mdot
.53974 .01685 Mdot
.626 .05331 Mdot
.88212 .15829 Mdot
.29933 .25785 Mdot
.48919 .11734 Mdot
.66285 .10732 Mdot
.04033 .2333 Mdot
.35796 .19631 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52366 .01003 Mdot
.57527 .03189 Mdot
.73561 .0991 Mdot
.13371 .24604 Mdot
.35402 .13616 Mdot
.3848 .01902 Mdot
.25747 .53934 Mdot
.89167 .39196 Mdot
.67611 .48481 Mdot
.4988 .61752 Mdot
.49618 .61641 Mdot
.48782 .61287 Mdot
.4612 .60158 Mdot
.37695 .56597 Mdot
.12597 .46292 Mdot
.70516 .35796 Mdot
.51366 .49968 Mdot
.34263 .51233 Mdot
.97218 .38908 Mdot
.64324 .41474 Mdot
.49883 .61754 Mdot
.49626 .61645 Mdot
.4881 .61299 Mdot
.4621 .60196 Mdot
.37978 .56716 Mdot
.1338 .46601 Mdot
.70994 .35607 Mdot
.51729 .49897 Mdot
.35051 .51496 Mdot
.99106 .39588 Mdot
.64501 .40416 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51351 .00573 Mdot
.54302 .01824 Mdot
.63628 .05764 Mdot
.90988 .16909 Mdot
.31155 .24825 Mdot
.49212 .1116 Mdot
.66088 .1043 Mdot
.0319 .22931 Mdot
.35539 .19993 Mdot
.49851 .6174 Mdot
.49524 .61602 Mdot
.48483 .6116 Mdot
.45171 .59756 Mdot
.34726 .55348 Mdot
.04727 .43263 Mdot
.67742 .38945 Mdot
.5219 .52192 Mdot
.39912 .54215 Mdot
.13496 .45477 Mdot
.69176 .34412 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52599 .01102 Mdot
.58263 .03501 Mdot
.75774 .10822 Mdot
.17129 .25559 Mdot
.37471 .12572 Mdot
.40903 .02121 Mdot
.31419 .55942 Mdot
.99978 .42372 Mdot
.6857 .42392 Mdot
.4978 .6171 Mdot
.493 .61507 Mdot
.4777 .60858 Mdot
.42905 .58797 Mdot
.27748 .52436 Mdot
.89072 .379 Mdot
.6553 .47254 Mdot
.61759 .59473 Mdot
.74064 .07605 Mdot
.10202 .22334 Mdot
.32063 .13511 Mdot
.49748 .61696 Mdot
.49196 .61463 Mdot
.4744 .60718 Mdot
.4186 .58355 Mdot
.24596 .51133 Mdot
.83466 .36384 Mdot
.62911 .491 Mdot
.59666 .59798 Mdot
.70046 .06415 Mdot
.03152 .20461 Mdot
.31561 .17558 Mdot
.4996 .61787 Mdot
.49873 .6175 Mdot
.49595 .61632 Mdot
.48711 .61257 Mdot
.45896 .60063 Mdot
.36992 .56301 Mdot
.10677 .4554 Mdot
.69521 .36368 Mdot
.50838 .50256 Mdot
.33411 .51033 Mdot
.95367 .38291 Mdot
.4992 .61769 Mdot
.49745 .61695 Mdot
.49187 .61459 Mdot
.47411 .60705 Mdot
.41767 .58316 Mdot
.24319 .5102 Mdot
.83019 .36279 Mdot
.62625 .492 Mdot
.59246 .59715 Mdot
.68967 .06008 Mdot
.00867 .19715 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.47878 .60904 Mdot
.43248 .58942 Mdot
.28791 .52869 Mdot
.91136 .38531 Mdot
.661 .4633 Mdot
.613 .58837 Mdot
.72062 .06651 Mdot
.06291 .21155 Mdot
.31328 .15473 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50894 .00379 Mdot
.52849 .01208 Mdot
.59054 .03835 Mdot
.78119 .11783 Mdot
.20601 .26255 Mdot
.40115 .12061 Mdot
.45737 .03475 Mdot
.45041 .61373 Mdot
.37027 .5685 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51977 .00838 Mdot
.56292 .02667 Mdot
.69802 .08349 Mdot
.05922 .22324 Mdot
.33363 .16959 Mdot
.40151 .04195 Mdot
.33091 .5744 Mdot
.05177 .44551 Mdot
.69633 .39837 Mdot
.49836 .61734 Mdot
.49479 .61582 Mdot
.4834 .611 Mdot
.44716 .59563 Mdot
.3331 .54754 Mdot
.01212 .41966 Mdot
.67298 .40843 Mdot
.54515 .53903 Mdot
.48414 .58033 Mdot
.39938 .56565 Mdot
.17355 .47846 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00117 Mdot
.50877 .00372 Mdot
.52792 .01184 Mdot
.58875 .03759 Mdot
.77592 .11567 Mdot
.19865 .26127 Mdot
.39498 .12133 Mdot
.44495 .03089 Mdot
.41399 .5989 Mdot
.26019 .52298 Mdot
.49897 .6176 Mdot
.4967 .61664 Mdot
.4895 .61358 Mdot
.46656 .60385 Mdot
.39382 .57308 Mdot
.17336 .48178 Mdot
.74132 .35102 Mdot
.54766 .49834 Mdot
.42441 .54187 Mdot
.19201 .4744 Mdot
.73654 .33654 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49083 .61415 Mdot
.47079 .60565 Mdot
.40719 .57872 Mdot
.21212 .49747 Mdot
.78505 .35409 Mdot
.59094 .49807 Mdot
.52595 .57787 Mdot
.49972 .60182 Mdot
.47307 .60156 Mdot
.49739 .61693 Mdot
.49169 .61451 Mdot
.47353 .60681 Mdot
.41585 .58238 Mdot
.23773 .50795 Mdot
.8216 .36085 Mdot
.62044 .49371 Mdot
.58319 .59501 Mdot
.66511 .05063 Mdot
.95262 .17769 Mdot
.31015 .22097 Mdot
.50055 .00024 Mdot
.50177 .00075 Mdot
.50563 .00239 Mdot
.51795 .00761 Mdot
.55712 .02421 Mdot
.68015 .07604 Mdot
.01929 .2096 Mdot
.32956 .19176 Mdot
.43032 .06227 Mdot
.42987 .61775 Mdot
.32759 .55482 Mdot
.01438 .42446 Mdot
.49746 .61696 Mdot
.4919 .6146 Mdot
.47419 .60709 Mdot
.41794 .58327 Mdot
.24398 .51052 Mdot
.83146 .36308 Mdot
.62708 .49172 Mdot
.59369 .5974 Mdot
.69287 .06129 Mdot
.01556 .19943 Mdot
.31495 .18503 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47916 .6092 Mdot
.43368 .58993 Mdot
.29158 .53021 Mdot
.91885 .38767 Mdot
.66264 .45969 Mdot
.61009 .58556 Mdot
.70982 .06163 Mdot
.04071 .2045 Mdot
.3112 .16718 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00032 Mdot
.50244 .00104 Mdot
.50778 .0033 Mdot
.52477 .0105 Mdot
.57878 .03338 Mdot
.74618 .10346 Mdot
.15224 .25096 Mdot
.36321 .13039 Mdot
.39334 .01862 Mdot
.27519 .54501 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50443 .00188 Mdot
.51411 .00598 Mdot
.54494 .01905 Mdot
.64229 .06016 Mdot
.92575 .17519 Mdot
.31659 .24155 Mdot
.48929 .10674 Mdot
.64595 .09682 Mdot
.9921 .21394 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48838 .6131 Mdot
.46298 .60234 Mdot
.38254 .56832 Mdot
.14149 .46906 Mdot
.71507 .35449 Mdot
.52166 .4985 Mdot
.36065 .51852 Mdot
.01631 .40522 Mdot
.64755 .39013 Mdot
.49824 .61729 Mdot
.4944 .61566 Mdot
.48216 .61047 Mdot
.4432 .59396 Mdot
.32085 .54242 Mdot
.98303 .40925 Mdot
.67062 .42495 Mdot
.56785 .55452 Mdot
.5638 .61553 Mdot
.65292 .05508 Mdot
.93772 .17602 Mdot
.49881 .61753 Mdot
.49622 .61643 Mdot
.48796 .61293 Mdot
.46165 .60177 Mdot
.37836 .56656 Mdot
.12986 .46445 Mdot
.70748 .35699 Mdot
.51536 .4993 Mdot
.34624 .51351 Mdot
.98071 .39213 Mdot
.64405 .40997 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48966 .61365 Mdot
.46707 .60407 Mdot
.39545 .57377 Mdot
.17803 .48366 Mdot
.74588 .35095 Mdot
.55238 .49844 Mdot
.43603 .54613 Mdot
.22629 .48841 Mdot
.78047 .3425 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50489 .00207 Mdot
.51556 .0066 Mdot
.54955 .02101 Mdot
.65667 .0662 Mdot
.96264 .1891 Mdot
.32414 .22342 Mdot
.47233 .09159 Mdot
.57923 .06607 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52399 .01017 Mdot
.57629 .03232 Mdot
.7387 .10037 Mdot
.13923 .24755 Mdot
.35656 .13431 Mdot
.38669 .01862 Mdot
.26086 .54026 Mdot
.89685 .39306 Mdot
.67696 .48214 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48863 .61321 Mdot
.46379 .60268 Mdot
.38509 .5694 Mdot
.14863 .47189 Mdot
.72024 .35328 Mdot
.52642 .49825 Mdot
.37206 .52263 Mdot
.04581 .4164 Mdot
.65178 .37452 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.4853 .6118 Mdot
.45319 .59819 Mdot
.35188 .55542 Mdot
.0591 .43709 Mdot
.67969 .38355 Mdot
.5161 .51693 Mdot
.37662 .53183 Mdot
.07005 .42856 Mdot
.66177 .3657 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.5015 .00063 Mdot
.50477 .00202 Mdot
.51519 .00644 Mdot
.54836 .0205 Mdot
.65296 .06464 Mdot
.95327 .1856 Mdot
.32267 .22831 Mdot
.47781 .09588 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51388 .00589 Mdot
.54421 .01874 Mdot
.64001 .0592 Mdot
.91976 .17289 Mdot
.31484 .24417 Mdot
.49072 .1087 Mdot
.65269 .1001 Mdot
.50072 .00031 Mdot
.50231 .00098 Mdot
.50735 .00312 Mdot
.52342 .00993 Mdot
.5745 .03157 Mdot
.7333 .09814 Mdot
.12951 .24487 Mdot
.3522 .13763 Mdot
.38371 .01947 Mdot
.25589 .53904 Mdot
.8895 .39159 Mdot
.67586 .486 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47986 .60949 Mdot
.4359 .59087 Mdot
.29837 .53304 Mdot
.93305 .39225 Mdot
.66522 .45251 Mdot
.60304 .57961 Mdot
.68486 .05057 Mdot
.9857 .18593 Mdot
.30796 .19917 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51819 .00771 Mdot
.55791 .02454 Mdot
.68258 .07705 Mdot
.02488 .21155 Mdot
.33001 .18859 Mdot
.42596 .0593 Mdot
.4148 .61114 Mdot
.28186 .53587 Mdot
.91495 .39127 Mdot
.50026 .00011 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52632 .01116 Mdot
.58367 .03545 Mdot
.76082 .10949 Mdot
.17616 .25669 Mdot
.378 .12474 Mdot
.41424 .0224 Mdot
.32796 .56471 Mdot
.03103 .43452 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50419 .00178 Mdot
.51336 .00566 Mdot
.54254 .01803 Mdot
.63476 .057 Mdot
.90582 .16753 Mdot
.31005 .24983 Mdot
.49234 .11266 Mdot
.66314 .10556 Mdot
.03799 .23167 Mdot
.3564 .19679 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47723 .60838 Mdot
.42756 .58734 Mdot
.27293 .52247 Mdot
.88205 .37646 Mdot
.65234 .47606 Mdot
.6178 .59669 Mdot
.74427 .07816 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52056 .00872 Mdot
.56543 .02773 Mdot
.70571 .0867 Mdot
.07554 .22857 Mdot
.33626 .16114 Mdot
.39247 .03474 Mdot
.29938 .5605 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49076 .61412 Mdot
.47058 .60556 Mdot
.4065 .57843 Mdot
.21011 .49666 Mdot
.78245 .35372 Mdot
.58857 .49821 Mdot
.5208 .57615 Mdot
.48414 .59538 Mdot
.42372 .58069 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54192 .01777 Mdot
.63284 .05619 Mdot
.90066 .16553 Mdot
.30801 .25175 Mdot
.4923 .1139 Mdot
.66505 .10677 Mdot
.04333 .23379 Mdot
.35741 .19411 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50648 .00275 Mdot
.52064 .00875 Mdot
.56566 .02783 Mdot
.70641 .08699 Mdot
.07699 .22903 Mdot
.33654 .16041 Mdot
.39178 .03414 Mdot
.29692 .5594 Mdot
.97362 .41822 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51189 .00504 Mdot
.53787 .01605 Mdot
.62011 .05083 Mdot
.8659 .15191 Mdot
.28987 .26203 Mdot
.48256 .11909 Mdot
.64914 .10295 Mdot
.49852 .6174 Mdot
.49527 .61603 Mdot
.48494 .61165 Mdot
.45205 .59771 Mdot
.34832 .55392 Mdot
.04998 .43365 Mdot
.6779 .38807 Mdot
.52046 .52073 Mdot
.39364 .53965 Mdot
.11889 .44823 Mdot
.68193 .34798 Mdot
.49843 .61737 Mdot
.495 .61591 Mdot
.48406 .61127 Mdot
.44924 .59652 Mdot
.33957 .55025 Mdot
.02799 .42547 Mdot
.67464 .39965 Mdot
.53375 .53096 Mdot
.44312 .56202 Mdot
.26898 .51041 Mdot
.8578 .36391 Mdot
.49757 .61701 Mdot
.49227 .61476 Mdot
.47538 .6076 Mdot
.42172 .58487 Mdot
.2553 .51518 Mdot
.85028 .36772 Mdot
.63815 .48693 Mdot
.6082 .59952 Mdot
.72832 .07424 Mdot
.08497 .22042 Mdot
.32013 .14534 Mdot
.49863 .61745 Mdot
.49565 .61619 Mdot
.48613 .61215 Mdot
.45583 .59931 Mdot
.36012 .55888 Mdot
.08057 .44527 Mdot
.68527 .37372 Mdot
.50921 .50923 Mdot
.34698 .51777 Mdot
.98897 .39677 Mdot
.6475 .40699 Mdot
.49765 .61704 Mdot
.4925 .61486 Mdot
.47612 .60791 Mdot
.42405 .58585 Mdot
.26233 .51808 Mdot
.86259 .37098 Mdot
.6443 .48312 Mdot
.61399 .59931 Mdot
.74043 .07814 Mdot
.10517 .22542 Mdot
.32339 .13486 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50715 .00303 Mdot
.52276 .00965 Mdot
.57241 .03068 Mdot
.72697 .09552 Mdot
.11777 .24153 Mdot
.3476 .14204 Mdot
.38219 .02138 Mdot
.25577 .5399 Mdot
.89078 .39246 Mdot
.67706 .48595 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51239 .00525 Mdot
.53944 .01672 Mdot
.62506 .05291 Mdot
.87954 .15728 Mdot
.29795 .25859 Mdot
.48838 .11769 Mdot
.6614 .10693 Mdot
.03709 .23219 Mdot
.35765 .19812 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51126 .00478 Mdot
.53587 .01521 Mdot
.61383 .04818 Mdot
.84835 .14494 Mdot
.27745 .2652 Mdot
.47136 .11984 Mdot
.62255 .09344 Mdot
.93992 .19615 Mdot
.34529 .25053 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.4788 .60904 Mdot
.43254 .58944 Mdot
.28808 .52876 Mdot
.91169 .38541 Mdot
.66107 .46314 Mdot
.61288 .58825 Mdot
.72017 .06631 Mdot
.06201 .21127 Mdot
.31317 .15523 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.52379 .01009 Mdot
.57568 .03207 Mdot
.73685 .09961 Mdot
.13594 .24665 Mdot
.35503 .1354 Mdot
.3855 .01883 Mdot
.25865 .53964 Mdot
.89343 .39231 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51352 .00573 Mdot
.54305 .01825 Mdot
.63636 .05767 Mdot
.91009 .16918 Mdot
.31163 .24816 Mdot
.4921 .11154 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48413 .6113 Mdot
.44946 .59661 Mdot
.34026 .55054 Mdot
.02969 .42609 Mdot
.67485 .39873 Mdot
.53261 .53013 Mdot
.43895 .56015 Mdot
.25595 .50493 Mdot
.83438 .35749 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50129 .00054 Mdot
.50409 .00174 Mdot
.51304 .00553 Mdot
.54154 .01761 Mdot
.63164 .05568 Mdot
.89744 .16427 Mdot
.30665 .25291 Mdot
.4921 .11461 Mdot
.6657 .10729 Mdot
.04532 .23462 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50336 .00143 Mdot
.51071 .00454 Mdot
.53412 .01446 Mdot
.6083 .04585 Mdot
.8327 .13868 Mdot
.26431 .26675 Mdot
.45816 .11981 Mdot
.58998 .08146 Mdot
.84968 .1605 Mdot
.3028 .28005 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.4939 .61545 Mdot
.48055 .60979 Mdot
.43811 .5918 Mdot
.30515 .53586 Mdot
.94766 .39709 Mdot
.66727 .44474 Mdot
.59407 .5728 Mdot
.65392 .03698 Mdot
.91029 .15845 Mdot
.49927 .61772 Mdot
.49768 .61705 Mdot
.4926 .6149 Mdot
.47642 .60804 Mdot
.42501 .58626 Mdot
.26522 .51928 Mdot
.86779 .37241 Mdot
.64664 .48136 Mdot
.61563 .59887 Mdot
.74319 .07884 Mdot
.10928 .22625 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.5225 .00954 Mdot
.57157 .03033 Mdot
.72441 .09446 Mdot
.11291 .24011 Mdot
.3459 .14399 Mdot
.38219 .02243 Mdot
.25747 .54095 Mdot
.89427 .39357 Mdot
.67826 .48453 Mdot
.50074 .00031 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52402 .01018 Mdot
.57639 .03237 Mdot
.73899 .10049 Mdot
.13976 .24769 Mdot
.35681 .13414 Mdot
.3869 .0186 Mdot
.26126 .54038 Mdot
.89749 .39321 Mdot
.67707 .48181 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50716 .00304 Mdot
.5228 .00967 Mdot
.57254 .03074 Mdot
.72736 .09568 Mdot
.1185 .24174 Mdot
.34787 .14175 Mdot
.38222 .02123 Mdot
.25561 .53978 Mdot
.8904 .39233 Mdot
.67691 .48609 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50541 .00229 Mdot
.51724 .00731 Mdot
.55488 .02326 Mdot
.67321 .07314 Mdot
.00303 .20384 Mdot
.3283 .20103 Mdot
.44315 .07098 Mdot
.47454 .0194 Mdot
.46788 .61392 Mdot
.41338 .58435 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50507 .00215 Mdot
.51615 .00685 Mdot
.55143 .0218 Mdot
.6625 .06865 Mdot
.97713 .19445 Mdot
.32595 .21558 Mdot
.46269 .08451 Mdot
.544 .05025 Mdot
.69045 .09052 Mdot
.49844 .61737 Mdot
.49504 .61593 Mdot
.48419 .61133 Mdot
.44966 .5967 Mdot
.34089 .55081 Mdot
.03127 .42668 Mdot
.67504 .39788 Mdot
.53156 .52936 Mdot
.43512 .55843 Mdot
.24403 .49993 Mdot
.81437 .35249 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48966 .61365 Mdot
.46707 .60407 Mdot
.39544 .57376 Mdot
.17801 .48366 Mdot
.74586 .35095 Mdot
.55236 .49844 Mdot
.43599 .54611 Mdot
.22616 .48835 Mdot
.78027 .34246 Mdot
.49896 .61759 Mdot
.49667 .61662 Mdot
.4894 .61354 Mdot
.46624 .60372 Mdot
.39283 .57266 Mdot
.17053 .48065 Mdot
.73865 .35112 Mdot
.54489 .49829 Mdot
.41759 .53935 Mdot
.17211 .46632 Mdot
.71593 .3361 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47917 .6092 Mdot
.43373 .58995 Mdot
.29173 .53027 Mdot
.91915 .38777 Mdot
.6627 .45954 Mdot
.60996 .58544 Mdot
.70933 .06142 Mdot
.03969 .20417 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47347 .60678 Mdot
.41566 .5823 Mdot
.23717 .50772 Mdot
.82073 .36066 Mdot
.61983 .49387 Mdot
.58216 .59476 Mdot
.66234 .04955 Mdot
.94595 .17528 Mdot
.30908 .22443 Mdot
.49878 .61752 Mdot
.49611 .61639 Mdot
.48761 .61278 Mdot
.46056 .60131 Mdot
.37494 .56512 Mdot
.12044 .46075 Mdot
.70204 .35945 Mdot
.51161 .50034 Mdot
.33859 .5111 Mdot
.96288 .38583 Mdot
.64234 .41993 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47661 .60812 Mdot
.4256 .58651 Mdot
.26701 .52002 Mdot
.87105 .37332 Mdot
.64804 .4802 Mdot
.61642 .59849 Mdot
.74426 .07901 Mdot
.11068 .22646 Mdot
.32414 .13193 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49068 .61408 Mdot
.47031 .60544 Mdot
.40565 .57807 Mdot
.20761 .49564 Mdot
.77926 .3533 Mdot
.58562 .49836 Mdot
.51429 .57395 Mdot
.46438 .58719 Mdot
.36149 .55444 Mdot
.49777 .61709 Mdot
.4929 .61502 Mdot
.47737 .60844 Mdot
.42801 .58753 Mdot
.27431 .52304 Mdot
.88465 .37721 Mdot
.65326 .47503 Mdot
.61785 .59615 Mdot
.7435 .07766 Mdot
.10769 .22508 Mdot
.32239 .13269 Mdot
.50006 2e-05 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.5019 .0008 Mdot
.50605 .00256 Mdot
.51926 .00817 Mdot
.5613 .02598 Mdot
.69305 .08142 Mdot
.0484 .21962 Mdot
.33227 .17544 Mdot
.40859 .04717 Mdot
.35522 .58505 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.49201 .61465 Mdot
.47455 .60724 Mdot
.41908 .58375 Mdot
.24738 .51192 Mdot
.83699 .3644 Mdot
.63055 .49045 Mdot
.5987 .59835 Mdot
.70558 .06606 Mdot
.04195 .20789 Mdot
.49854 .61742 Mdot
.49536 .61607 Mdot
.48522 .61176 Mdot
.45293 .59808 Mdot
.35106 .55508 Mdot
.05699 .43629 Mdot
.67925 .38458 Mdot
.51704 .51778 Mdot
.38035 .53355 Mdot
.08061 .43279 Mdot
.66506 .36121 Mdot
.49966 .61789 Mdot
.49892 .61758 Mdot
.49656 .61658 Mdot
.48906 .61339 Mdot
.46514 .60326 Mdot
.38936 .5712 Mdot
.16067 .4767 Mdot
.72988 .35179 Mdot
.53591 .49815 Mdot
.39534 .53116 Mdot
.10885 .44098 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.47482 .60736 Mdot
.41992 .58411 Mdot
.2499 .51296 Mdot
.84115 .36541 Mdot
.63304 .48941 Mdot
.60205 .59888 Mdot
.71385 .0691 Mdot
.05826 .21285 Mdot
.31721 .16005 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48122 .61007 Mdot
.44023 .5927 Mdot
.31167 .53858 Mdot
.96208 .40197 Mdot
.66883 .4368 Mdot
.58394 .56557 Mdot
.61921 .02179 Mdot
.81702 .12226 Mdot
.23272 .25691 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50779 .0033 Mdot
.52482 .01052 Mdot
.57892 .03344 Mdot
.7466 .10363 Mdot
.15296 .25114 Mdot
.3636 .13019 Mdot
.3938 .01866 Mdot
.27625 .54539 Mdot
.92322 .39984 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51252 .00531 Mdot
.53988 .01691 Mdot
.62643 .05349 Mdot
.88329 .15875 Mdot
.29995 .25751 Mdot
.48953 .11717 Mdot
.66341 .10747 Mdot
.04156 .23371 Mdot
.35807 .19562 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00322 Mdot
.52416 .01024 Mdot
.57684 .03256 Mdot
.74035 .10105 Mdot
.14215 .24833 Mdot
.35797 .13338 Mdot
.38791 .01851 Mdot
.26328 .54101 Mdot
.90074 .39398 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.5048 .00203 Mdot
.51529 .00648 Mdot
.54867 .02063 Mdot
.65393 .06505 Mdot
.95573 .18652 Mdot
.32308 .22704 Mdot
.47643 .09478 Mdot
.59456 .07301 Mdot
.84634 .15561 Mdot
.29443 .27694 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50375 .00159 Mdot
.51196 .00507 Mdot
.53808 .01615 Mdot
.62078 .05111 Mdot
.86776 .15264 Mdot
.29105 .26161 Mdot
.4835 .11894 Mdot
.65125 .10368 Mdot
.01324 .22372 Mdot
.35539 .21146 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51517 .00643 Mdot
.54829 .02047 Mdot
.65275 .06456 Mdot
.95274 .18541 Mdot
.32258 .22857 Mdot
.47809 .09611 Mdot
.60084 .07586 Mdot
.86493 .16322 Mdot
.30816 .27393 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51144 .00485 Mdot
.53645 .01545 Mdot
.61565 .04895 Mdot
.85347 .14698 Mdot
.28132 .26443 Mdot
.47504 .11973 Mdot
.63148 .09668 Mdot
.96346 .20518 Mdot
.34977 .23875 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50776 .00329 Mdot
.52471 .01048 Mdot
.57858 .03329 Mdot
.74559 .10322 Mdot
.15125 .25071 Mdot
.36267 .13066 Mdot
.39272 .01857 Mdot
.27376 .54452 Mdot
.91873 .39861 Mdot
.68037 .47072 Mdot
.49805 .61721 Mdot
.49379 .6154 Mdot
.48022 .60965 Mdot
.43706 .59136 Mdot
.30192 .53451 Mdot
.94064 .39475 Mdot
.66635 .44852 Mdot
.59857 .57615 Mdot
.66938 .04376 Mdot
.94895 .17278 Mdot
.30379 .2193 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51374 .00582 Mdot
.54374 .01854 Mdot
.63852 .05858 Mdot
.91584 .17139 Mdot
.31359 .24583 Mdot
.49142 .1099 Mdot
.65638 .10195 Mdot
.01996 .2247 Mdot
.49952 .61783 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48443 .61143 Mdot
.45044 .59703 Mdot
.34331 .55182 Mdot
.03732 .42892 Mdot
.67586 .39464 Mdot
.52769 .52646 Mdot
.42085 .552 Mdot
.20013 .48162 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50271 .00115 Mdot
.50865 .00367 Mdot
.52754 .01168 Mdot
.58753 .03708 Mdot
.7723 .1142 Mdot
.19347 .26029 Mdot
.3908 .12196 Mdot
.43689 .02848 Mdot
.39078 .58953 Mdot
.19339 .49604 Mdot
.50042 .00018 Mdot
.50132 .00056 Mdot
.50421 .00179 Mdot
.51342 .00569 Mdot
.54275 .01812 Mdot
.63543 .05728 Mdot
.9076 .16821 Mdot
.31072 .24914 Mdot
.49227 .1122 Mdot
.66222 .10504 Mdot
.03552 .23071 Mdot
.35597 .19805 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50418 .00177 Mdot
.51331 .00564 Mdot
.54239 .01797 Mdot
.63429 .0568 Mdot
.90457 .16704 Mdot
.30957 .2503 Mdot
.49236 .11297 Mdot
.6637 .10589 Mdot
.03952 .23227 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48083 .60991 Mdot
.439 .59218 Mdot
.3079 .53701 Mdot
.95368 .39912 Mdot
.66797 .44145 Mdot
.58997 .56983 Mdot
.63986 .03083 Mdot
.87355 .14443 Mdot
.27759 .24971 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50169 .00071 Mdot
.50537 .00228 Mdot
.51711 .00726 Mdot
.55447 .02309 Mdot
.67195 .07261 Mdot
3e-05 .20276 Mdot
.32806 .20274 Mdot
.44551 .07259 Mdot
.48282 .02306 Mdot
.49439 .00716 Mdot
.49961 .61787 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.48751 .61274 Mdot
.46021 .60116 Mdot
.37385 .56466 Mdot
.11747 .45958 Mdot
.70045 .3603 Mdot
.51069 .50075 Mdot
.33695 .51066 Mdot
.95923 .38459 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50464 .00197 Mdot
.51478 .00627 Mdot
.54705 .01995 Mdot
.64887 .06293 Mdot
.94283 .18168 Mdot
.32071 .23354 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.5056 .00238 Mdot
.51785 .00757 Mdot
.55681 .02408 Mdot
.6792 .07564 Mdot
.01707 .20882 Mdot
.32939 .19302 Mdot
.43206 .06346 Mdot
.4359 .00237 Mdot
.34617 .56258 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48669 .61239 Mdot
.45762 .60007 Mdot
.36573 .56124 Mdot
.09549 .45102 Mdot
.69046 .36771 Mdot
.50764 .50505 Mdot
.33627 .51212 Mdot
.9604 .38573 Mdot
.64332 .42207 Mdot
.49844 .61737 Mdot
.49504 .61593 Mdot
.48419 .61133 Mdot
.44968 .5967 Mdot
.34094 .55083 Mdot
.0314 .42672 Mdot
.67506 .39781 Mdot
.53148 .52929 Mdot
.4348 .55828 Mdot
.24304 .49952 Mdot
.81277 .35211 Mdot
.49773 .61707 Mdot
.49275 .61496 Mdot
.47691 .60824 Mdot
.42656 .58692 Mdot
.26993 .52123 Mdot
.87643 .37484 Mdot
.65022 .47823 Mdot
.61733 .59771 Mdot
.74494 .07886 Mdot
.11115 .22633 Mdot
.32387 .13147 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50412 .00175 Mdot
.51313 .00557 Mdot
.54183 .01773 Mdot
.63254 .05606 Mdot
.89987 .16522 Mdot
.30768 .25204 Mdot
.49226 .11408 Mdot
.66525 .10691 Mdot
.04392 .23403 Mdot
.49791 .61715 Mdot
.49335 .61521 Mdot
.47881 .60905 Mdot
.43257 .58946 Mdot
.2882 .5288 Mdot
.91193 .38549 Mdot
.66113 .46303 Mdot
.6128 .58817 Mdot
.71986 .06616 Mdot
.06138 .21107 Mdot
.3131 .15557 Mdot
.5001 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50979 .00415 Mdot
.53118 .01322 Mdot
.59906 .04195 Mdot
.8061 .12796 Mdot
.2372 .26643 Mdot
.43034 .11937 Mdot
.52229 .05683 Mdot
.64757 .07743 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49106 .61424 Mdot
.47151 .60595 Mdot
.40946 .57968 Mdot
.2188 .5002 Mdot
.79398 .35548 Mdot
.59884 .49743 Mdot
.5426 .58328 Mdot
.5495 .00427 Mdot
.62947 .04942 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.50728 .00309 Mdot
.5232 .00984 Mdot
.57381 .03127 Mdot
.73119 .09727 Mdot
.12565 .24379 Mdot
.35061 .13903 Mdot
.38296 .02 Mdot
.25517 .53905 Mdot
.88877 .39158 Mdot
.67596 .48651 Mdot
.49903 .61762 Mdot
.49692 .61673 Mdot
.49019 .61387 Mdot
.46874 .60478 Mdot
.40071 .57599 Mdot
.19321 .4898 Mdot
.76202 .35154 Mdot
.56888 .49867 Mdot
.47587 .56055 Mdot
.3468 .53826 Mdot
.0218 .41718 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50558 .00237 Mdot
.51778 .00754 Mdot
.5566 .02399 Mdot
.67855 .07537 Mdot
.01557 .20829 Mdot
.32927 .19388 Mdot
.43325 .06426 Mdot
.44002 .00418 Mdot
.35894 .56792 Mdot
.09289 .45361 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50814 .00345 Mdot
.52594 .011 Mdot
.58248 .03494 Mdot
.75728 .10803 Mdot
.17056 .25542 Mdot
.37424 .12588 Mdot
.40829 .02105 Mdot
.31227 .55869 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.48509 .61171 Mdot
.45254 .59791 Mdot
.34985 .55457 Mdot
.05388 .43512 Mdot
.67863 .38611 Mdot
.5185 .51907 Mdot
.38607 .53618 Mdot
.09696 .43935 Mdot
.67124 .35493 Mdot
.49923 .61771 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47496 .60742 Mdot
.42038 .5843 Mdot
.25128 .51353 Mdot
.84347 .36599 Mdot
.63438 .48881 Mdot
.60376 .59911 Mdot
.71798 .07059 Mdot
.06613 .21516 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.5109 .00462 Mdot
.53471 .01471 Mdot
.61016 .04663 Mdot
.83798 .1408 Mdot
.26898 .26637 Mdot
.46293 .11987 Mdot
.60178 .08582 Mdot
.88311 .17387 Mdot
.32443 .27275 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50782 .00332 Mdot
.52491 .01056 Mdot
.57921 .03356 Mdot
.74748 .104 Mdot
.15446 .25152 Mdot
.36444 .12978 Mdot
.39479 .01876 Mdot
.27858 .54621 Mdot
.92747 .40104 Mdot
.68143 .46597 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50523 .00222 Mdot
.51665 .00706 Mdot
.55299 .02246 Mdot
.66737 .07069 Mdot
.98902 .19879 Mdot
.32713 .20896 Mdot
.45399 .07841 Mdot
.51279 .03634 Mdot
.59077 .04819 Mdot
.79764 .12785 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50319 .00135 Mdot
.51016 .00431 Mdot
.53237 .01373 Mdot
.60281 .04353 Mdot
.81695 .13235 Mdot
.24901 .26703 Mdot
.44235 .11949 Mdot
.55108 .0672 Mdot
.73512 .11374 Mdot
.15684 .26064 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00321 Mdot
.52414 .01023 Mdot
.57676 .03253 Mdot
.74012 .10096 Mdot
.14175 .24822 Mdot
.35777 .13351 Mdot
.38774 .01852 Mdot
.26292 .5409 Mdot
.90016 .39384 Mdot
.67753 .48044 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49407 .61552 Mdot
.4811 .61002 Mdot
.43984 .59254 Mdot
.31049 .53809 Mdot
.95943 .40107 Mdot
.66857 .43827 Mdot
.58587 .56692 Mdot
.62583 .02469 Mdot
.83546 .12956 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50287 .00122 Mdot
.50915 .00388 Mdot
.52914 .01235 Mdot
.59259 .03922 Mdot
.78723 .12029 Mdot
.2141 .26382 Mdot
.40829 .12001 Mdot
.47239 .03962 Mdot
.49529 .01415 Mdot
.51113 .00979 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47813 .60876 Mdot
.43041 .58855 Mdot
.28161 .52607 Mdot
.89877 .38143 Mdot
.65774 .46907 Mdot
.61644 .59251 Mdot
.73464 .07305 Mdot
.09046 .21991 Mdot
.31778 .14049 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51415 .006 Mdot
.54504 .01909 Mdot
.6426 .0603 Mdot
.92657 .1755 Mdot
.31682 .24119 Mdot
.48906 .10645 Mdot
.64492 .09632 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52059 .00873 Mdot
.56552 .02777 Mdot
.70596 .0868 Mdot
.07607 .22874 Mdot
.33636 .16087 Mdot
.39222 .03452 Mdot
.29849 .5601 Mdot
.97701 .41935 Mdot
.6899 .44059 Mdot
.49772 .61707 Mdot
.49274 .61496 Mdot
.47688 .60823 Mdot
.42646 .58687 Mdot
.26961 .5211 Mdot
.87584 .37467 Mdot
.64998 .47845 Mdot
.61726 .59781 Mdot
.74493 .0789 Mdot
.11121 .22637 Mdot
.32392 .13147 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.5181 .00768 Mdot
.55761 .02442 Mdot
.68166 .07667 Mdot
.02277 .21082 Mdot
.32984 .18978 Mdot
.42759 .06041 Mdot
.42045 .61362 Mdot
.29888 .5429 Mdot
.94975 .40226 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46984 .60524 Mdot
.40417 .57745 Mdot
.20329 .49388 Mdot
.77388 .35265 Mdot
.58053 .49853 Mdot
.50287 .57004 Mdot
.42953 .5727 Mdot
.25389 .50949 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00226 Mdot
.51701 .00721 Mdot
.55416 .02296 Mdot
.67098 .0722 Mdot
.9977 .20193 Mdot
.32787 .20406 Mdot
.44732 .07382 Mdot
.4892 .02588 Mdot
.51488 .01587 Mdot
.56284 .02964 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48133 .61012 Mdot
.44057 .59285 Mdot
.31273 .53902 Mdot
.96446 .40279 Mdot
.66906 .43546 Mdot
.58217 .56434 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51263 .00535 Mdot
.54021 .01705 Mdot
.62748 .05393 Mdot
.88615 .15987 Mdot
.30141 .25664 Mdot
.49027 .11673 Mdot
.66455 .10771 Mdot
.04398 .2345 Mdot
.35827 .19425 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50443 .00188 Mdot
.51413 .00599 Mdot
.54498 .01907 Mdot
.64241 .06021 Mdot
.92607 .17531 Mdot
.31668 .24141 Mdot
.48921 .10663 Mdot
.64555 .09663 Mdot
.99104 .21352 Mdot
.34996 .22183 Mdot
.49993 .618 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49774 .61707 Mdot
.49279 .61497 Mdot
.47702 .60829 Mdot
.42689 .58706 Mdot
.27092 .52164 Mdot
.87828 .37537 Mdot
.65093 .47753 Mdot
.61754 .5974 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50288 .00122 Mdot
.50919 .0039 Mdot
.52927 .01241 Mdot
.59302 .0394 Mdot
.78847 .1208 Mdot
.21572 .26405 Mdot
.40975 .11992 Mdot
.47556 .04067 Mdot
.50484 .0181 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48653 .61232 Mdot
.45711 .59985 Mdot
.36413 .56057 Mdot
.09121 .44936 Mdot
.68884 .36936 Mdot
.5078 .50614 Mdot
.33845 .51337 Mdot
.9663 .38803 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.52301 .00976 Mdot
.57319 .03101 Mdot
.72931 .09649 Mdot
.12216 .24279 Mdot
.34924 .14034 Mdot
.3825 .02056 Mdot
.2551 .5393 Mdot
.88909 .39183 Mdot
.6763 .48652 Mdot
.50072 .00031 Mdot
.50231 .00098 Mdot
.50735 .00311 Mdot
.5234 .00992 Mdot
.57442 .03154 Mdot
.73306 .09804 Mdot
.12908 .24475 Mdot
.35202 .13778 Mdot
.38361 .01953 Mdot
.25577 .53903 Mdot
.88936 .39158 Mdot
.67586 .48608 Mdot
.49913 .61766 Mdot
.49721 .61685 Mdot
.49112 .61427 Mdot
.47172 .60604 Mdot
.41012 .57996 Mdot
.22076 .501 Mdot
.79668 .35594 Mdot
.60114 .49718 Mdot
.5473 .58476 Mdot
.56337 .00993 Mdot
.67201 .06714 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47697 .60827 Mdot
.42674 .58699 Mdot
.27045 .52144 Mdot
.87739 .37511 Mdot
.65059 .47786 Mdot
.61745 .59755 Mdot
.74492 .07878 Mdot
.111 .22625 Mdot
.32375 .13149 Mdot
.49857 .61743 Mdot
.49543 .6161 Mdot
.48545 .61186 Mdot
.45366 .59839 Mdot
.35334 .55603 Mdot
.06287 .43851 Mdot
.68053 .38173 Mdot
.51453 .51544 Mdot
.37031 .5289 Mdot
.05237 .42154 Mdot
.65729 .37386 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52515 .01067 Mdot
.57998 .03389 Mdot
.7498 .10495 Mdot
.15834 .2525 Mdot
.36667 .12875 Mdot
.39757 .0191 Mdot
.28522 .5486 Mdot
.93997 .40465 Mdot
.68264 .459 Mdot
.50004 1e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50364 .00154 Mdot
.5116 .00492 Mdot
.53695 .01567 Mdot
.61723 .04961 Mdot
.85787 .14873 Mdot
.28448 .26366 Mdot
.47794 .11956 Mdot
.63841 .09918 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49347 .61526 Mdot
.47919 .60921 Mdot
.4338 .58998 Mdot
.29193 .53036 Mdot
.91957 .3879 Mdot
.66278 .45933 Mdot
.60978 .58527 Mdot
.70868 .06113 Mdot
.03831 .20373 Mdot
.49882 .61753 Mdot
.49623 .61643 Mdot
.48797 .61293 Mdot
.4617 .6018 Mdot
.37853 .56663 Mdot
.13033 .46464 Mdot
.70777 .35687 Mdot
.51558 .49925 Mdot
.34672 .51367 Mdot
.98186 .39254 Mdot
.64416 .40932 Mdot
.50014 6e-05 Mdot
.50044 .00018 Mdot
.50139 .00059 Mdot
.50442 .00188 Mdot
.51409 .00597 Mdot
.54486 .01902 Mdot
.64202 .06005 Mdot
.92504 .17492 Mdot
.31639 .24187 Mdot
.48948 .10697 Mdot
.6468 .09723 Mdot
.99441 .21483 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00248 Mdot
.51866 .00791 Mdot
.5594 .02518 Mdot
.68717 .07897 Mdot
.03532 .21517 Mdot
.33092 .18269 Mdot
.41799 .05381 Mdot
.38742 .59914 Mdot
.2017 .50326 Mdot
.78817 .36245 Mdot
.49888 .61756 Mdot
.49645 .61653 Mdot
.48868 .61323 Mdot
.46394 .60274 Mdot
.38556 .56959 Mdot
.14993 .47241 Mdot
.72123 .35308 Mdot
.52737 .49822 Mdot
.37435 .52347 Mdot
.05185 .41871 Mdot
.65294 .37149 Mdot
.50041 .00017 Mdot
.50131 .00055 Mdot
.50416 .00176 Mdot
.51325 .00562 Mdot
.54219 .01789 Mdot
.63367 .05654 Mdot
.90291 .1664 Mdot
.30892 .25093 Mdot
.49236 .11338 Mdot
.66435 .1063 Mdot
.04133 .23299 Mdot
.35701 .1951 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .0014 Mdot
.5105 .00445 Mdot
.53344 .01418 Mdot
.60616 .04495 Mdot
.82658 .13622 Mdot
.25862 .26702 Mdot
.45228 .11969 Mdot
.57544 .07611 Mdot
.80756 .14346 Mdot
.26297 .28146 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51512 .00641 Mdot
.54813 .0204 Mdot
.65226 .06435 Mdot
.95148 .18493 Mdot
.32236 .22922 Mdot
.47877 .09666 Mdot
.60342 .07704 Mdot
.87251 .16631 Mdot
.31303 .27226 Mdot
.49973 .61792 Mdot
.49913 .61767 Mdot
.49724 .61687 Mdot
.49122 .61431 Mdot
.47202 .60617 Mdot
.41108 .58037 Mdot
.2236 .50216 Mdot
.80066 .35664 Mdot
.60446 .49678 Mdot
.55394 .58681 Mdot
.58278 .01783 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49605 .61636 Mdot
.48741 .6127 Mdot
.45992 .60104 Mdot
.37293 .56427 Mdot
.11495 .45859 Mdot
.69915 .36106 Mdot
.51 .50113 Mdot
.33585 .5104 Mdot
.95686 .3838 Mdot
.50062 .00026 Mdot
.50199 .00084 Mdot
.50633 .00268 Mdot
.52015 .00854 Mdot
.56412 .02718 Mdot
.70169 .08502 Mdot
.06708 .22582 Mdot
.3348 .16546 Mdot
.39688 .03837 Mdot
.31489 .56736 Mdot
.01373 .43191 Mdot
.692 .41919 Mdot
.49892 .61758 Mdot
.49656 .61657 Mdot
.48903 .61338 Mdot
.46505 .60322 Mdot
.38908 .57108 Mdot
.15986 .47637 Mdot
.72919 .35186 Mdot
.53521 .49815 Mdot
.39363 .53053 Mdot
.10411 .4391 Mdot
.66932 .34932 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51128 .00479 Mdot
.53594 .01524 Mdot
.61405 .04827 Mdot
.84897 .14519 Mdot
.27793 .26511 Mdot
.47182 .11983 Mdot
.62367 .09385 Mdot
.94292 .1973 Mdot
.34596 .2491 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00114 Mdot
.50859 .00364 Mdot
.52737 .0116 Mdot
.587 .03685 Mdot
.77071 .11354 Mdot
.19115 .25984 Mdot
.38898 .12227 Mdot
.43347 .0275 Mdot
.38106 .58564 Mdot
.16638 .48535 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.49419 .61557 Mdot
.4815 .61019 Mdot
.44113 .59308 Mdot
.31446 .53975 Mdot
.96837 .40414 Mdot
.66941 .43327 Mdot
.57923 .5623 Mdot
.60305 .01472 Mdot
.77088 .10372 Mdot
.5004 .00017 Mdot
.50126 .00054 Mdot
.50402 .00171 Mdot
.51281 .00543 Mdot
.5408 .0173 Mdot
.62932 .05471 Mdot
.89116 .16183 Mdot
.30383 .25505 Mdot
.4913 .11586 Mdot
.66572 .1078 Mdot
.04617 .23513 Mdot
.35834 .19293 Mdot
.4989 .61757 Mdot
.4965 .61655 Mdot
.48884 .6133 Mdot
.46447 .60297 Mdot
.38724 .5703 Mdot
.15466 .47429 Mdot
.72492 .35244 Mdot
.53095 .49816 Mdot
.38313 .52667 Mdot
.07533 .4278 Mdot
.65871 .36055 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51225 .00519 Mdot
.53901 .01654 Mdot
.6237 .05234 Mdot
.87581 .15581 Mdot
.29587 .25961 Mdot
.48704 .11815 Mdot
.65881 .10615 Mdot
.03117 .23013 Mdot
.35708 .20142 Mdot
.49975 .61793 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47423 .60711 Mdot
.41807 .58332 Mdot
.24437 .51068 Mdot
.83209 .36323 Mdot
.62748 .49158 Mdot
.59429 .59752 Mdot
.69441 .06188 Mdot
.49951 .61783 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48414 .61131 Mdot
.4495 .59663 Mdot
.34037 .55059 Mdot
.02998 .4262 Mdot
.67488 .39857 Mdot
.53242 .52999 Mdot
.43825 .55983 Mdot
.25376 .50401 Mdot
.49854 .61742 Mdot
.49536 .61607 Mdot
.48521 .61176 Mdot
.45291 .59807 Mdot
.35101 .55506 Mdot
.05687 .43625 Mdot
.67923 .38463 Mdot
.51709 .51783 Mdot
.38055 .53365 Mdot
.0812 .43302 Mdot
.66526 .36097 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.5139 .00589 Mdot
.54426 .01876 Mdot
.64016 .05927 Mdot
.92017 .17305 Mdot
.31496 .24399 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49897 .6176 Mdot
.49673 .61665 Mdot
.48957 .61361 Mdot
.46678 .60395 Mdot
.39454 .57338 Mdot
.17542 .48261 Mdot
.7433 .35097 Mdot
.54971 .49839 Mdot
.42947 .54372 Mdot
.50064 .00027 Mdot
.50202 .00086 Mdot
.50645 .00273 Mdot
.52054 .00871 Mdot
.56537 .0277 Mdot
.70552 .08662 Mdot
.07515 .22844 Mdot
.33619 .16134 Mdot
.39266 .0349 Mdot
.30007 .5608 Mdot
.98045 .4205 Mdot
.69009 .43858 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50578 .00245 Mdot
.51841 .00781 Mdot
.55859 .02484 Mdot
.6847 .07794 Mdot
.02971 .21323 Mdot
.33042 .18585 Mdot
.42223 .05674 Mdot
.40196 .60551 Mdot
.24376 .52026 Mdot
.84701 .37283 Mdot
.49857 .61743 Mdot
.49545 .6161 Mdot
.48549 .61188 Mdot
.45381 .59845 Mdot
.35381 .55623 Mdot
.06408 .43897 Mdot
.68081 .38116 Mdot
.51406 .51498 Mdot
.36838 .528 Mdot
.04701 .41942 Mdot
.65615 .37647 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00282 Mdot
.52122 .009 Mdot
.56751 .02861 Mdot
.71205 .08933 Mdot
.08857 .2327 Mdot
.33899 .15477 Mdot
.38703 .02969 Mdot
.27948 .55157 Mdot
.93729 .40655 Mdot
.68675 .46319 Mdot
.49756 .617 Mdot
.49222 .61474 Mdot
.47522 .60753 Mdot
.42119 .58464 Mdot
.25373 .51454 Mdot
.8476 .36703 Mdot
.6367 .48769 Mdot
.60656 .5994 Mdot
.72458 .07294 Mdot
.0783 .21861 Mdot
.31925 .14892 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.53112 .01319 Mdot
.59885 .04186 Mdot
.80549 .12771 Mdot
.2365 .26638 Mdot
.42964 .11937 Mdot
.52065 .05625 Mdot
.64255 .07534 Mdot
.49989 .61799 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49653 .61656 Mdot
.48896 .61335 Mdot
.46484 .60313 Mdot
.38841 .5708 Mdot
.15796 .47561 Mdot
.72761 .35206 Mdot
.53362 .49815 Mdot
.3897 .52908 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48405 .61127 Mdot
.44923 .59651 Mdot
.33955 .55025 Mdot
.02794 .42545 Mdot
.67463 .39968 Mdot
.53379 .53099 Mdot
.44324 .56207 Mdot
.26935 .51056 Mdot
.85849 .36411 Mdot
.4987 .61748 Mdot
.49585 .61627 Mdot
.48676 .61242 Mdot
.45785 .60017 Mdot
.36646 .56155 Mdot
.09744 .45177 Mdot
.69122 .36698 Mdot
.50764 .50458 Mdot
.33553 .51166 Mdot
.95833 .38491 Mdot
.64292 .42311 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47916 .6092 Mdot
.43368 .58993 Mdot
.29157 .53021 Mdot
.91884 .38767 Mdot
.66263 .45969 Mdot
.61009 .58556 Mdot
.70983 .06164 Mdot
.04074 .20451 Mdot
.3112 .16716 Mdot
.49765 .61704 Mdot
.49253 .61487 Mdot
.4762 .60794 Mdot
.4243 .58596 Mdot
.26308 .51839 Mdot
.86393 .37135 Mdot
.64492 .48268 Mdot
.61446 .59921 Mdot
.74127 .07837 Mdot
.10646 .2257 Mdot
.3236 .1342 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49057 .61403 Mdot
.46996 .6053 Mdot
.40456 .57762 Mdot
.20444 .49435 Mdot
.77529 .35281 Mdot
.58188 .49849 Mdot
.50592 .57109 Mdot
.43885 .57658 Mdot
.2823 .52128 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50766 .00325 Mdot
.5244 .01035 Mdot
.5776 .03288 Mdot
.74265 .102 Mdot
.14617 .24939 Mdot
.35999 .13215 Mdot
.38985 .01845 Mdot
.26735 .54233 Mdot
.90754 .39566 Mdot
.67875 .47663 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49454 .61572 Mdot
.4826 .61065 Mdot
.44461 .59455 Mdot
.32519 .54423 Mdot
.9932 .41285 Mdot
.6714 .41915 Mdot
.55982 .54907 Mdot
.53586 .60323 Mdot
.56524 .01816 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49427 .6156 Mdot
.48175 .61029 Mdot
.44191 .59341 Mdot
.31686 .54075 Mdot
.97383 .40603 Mdot
.66988 .43018 Mdot
.57505 .55942 Mdot
.58865 .00841 Mdot
.72847 .08641 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52304 .00977 Mdot
.57329 .03106 Mdot
.72963 .09662 Mdot
.12274 .24296 Mdot
.34946 .14012 Mdot
.38257 .02046 Mdot
.25508 .53924 Mdot
.88897 .39177 Mdot
.67623 .48655 Mdot
.49851 .6174 Mdot
.49527 .61603 Mdot
.48493 .61164 Mdot
.45201 .59769 Mdot
.34818 .55387 Mdot
.04962 .43351 Mdot
.67783 .38826 Mdot
.52065 .52089 Mdot
.39436 .53998 Mdot
.12098 .44908 Mdot
.68311 .34742 Mdot
.49793 .61716 Mdot
.49342 .61524 Mdot
.47903 .60914 Mdot
.43327 .58975 Mdot
.29033 .52969 Mdot
.91628 .38686 Mdot
.6621 .46094 Mdot
.61115 .58655 Mdot
.71372 .06339 Mdot
.04883 .20711 Mdot
.31184 .16255 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.50869 .00369 Mdot
.52768 .01174 Mdot
.58799 .03727 Mdot
.77367 .11476 Mdot
.19545 .26067 Mdot
.39238 .12171 Mdot
.4399 .02937 Mdot
.3994 .593 Mdot
.21785 .50583 Mdot
.49989 .61799 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49654 .61657 Mdot
.48898 .61336 Mdot
.46489 .60315 Mdot
.38856 .57086 Mdot
.1584 .47579 Mdot
.72797 .35201 Mdot
.53398 .49815 Mdot
.39059 .52941 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.5052 .00221 Mdot
.51657 .00703 Mdot
.55275 .02236 Mdot
.66663 .07038 Mdot
.98722 .19814 Mdot
.32696 .20997 Mdot
.45534 .07934 Mdot
.5176 .03848 Mdot
.60622 .05477 Mdot
.84261 .14609 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.52048 .00868 Mdot
.56517 .02762 Mdot
.7049 .08636 Mdot
.07385 .22802 Mdot
.33595 .16199 Mdot
.3933 .03544 Mdot
.30233 .56181 Mdot
.98541 .42217 Mdot
.69035 .43567 Mdot
.49822 .61728 Mdot
.49431 .61562 Mdot
.48189 .61035 Mdot
.44235 .5936 Mdot
.31823 .54132 Mdot
.97697 .40713 Mdot
.67014 .4284 Mdot
.57261 .55776 Mdot
.58025 .00472 Mdot
.70323 .07601 Mdot
.0547 .21722 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.5266 .01128 Mdot
.58458 .03583 Mdot
.76353 .1106 Mdot
.18036 .25761 Mdot
.38094 .12397 Mdot
.41914 .02361 Mdot
.34119 .56986 Mdot
.06264 .44588 Mdot
.69253 .3893 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50712 .00302 Mdot
.52269 .00962 Mdot
.57218 .03059 Mdot
.72627 .09523 Mdot
.11645 .24114 Mdot
.34712 .14257 Mdot
.38216 .02165 Mdot
.25614 .54015 Mdot
.89157 .39272 Mdot
.67735 .48564 Mdot
.49758 .61701 Mdot
.49228 .61476 Mdot
.47541 .60761 Mdot
.42179 .5849 Mdot
.25553 .51528 Mdot
.85068 .36782 Mdot
.63837 .48682 Mdot
.60843 .59953 Mdot
.72884 .07442 Mdot
.08588 .22066 Mdot
.32026 .14485 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50724 .00307 Mdot
.52306 .00978 Mdot
.57335 .03108 Mdot
.72981 .0967 Mdot
.12309 .24306 Mdot
.3496 .13999 Mdot
.38261 .0204 Mdot
.25507 .53921 Mdot
.88892 .39174 Mdot
.67619 .48656 Mdot
.4979 .61715 Mdot
.49332 .6152 Mdot
.47872 .60901 Mdot
.43231 .58935 Mdot
.28738 .52847 Mdot
.91028 .38497 Mdot
.66074 .46381 Mdot
.61337 .58875 Mdot
.72202 .06715 Mdot
.06573 .21242 Mdot
.31362 .15321 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.52081 .00882 Mdot
.56621 .02806 Mdot
.70809 .08769 Mdot
.08048 .23015 Mdot
.33722 .15868 Mdot
.3902 .03274 Mdot
.29125 .55687 Mdot
.96153 .41426 Mdot
.68896 .44958 Mdot
.4999 .61799 Mdot
.49969 .6179 Mdot
.49901 .61761 Mdot
.49683 .61669 Mdot
.48991 .61375 Mdot
.46785 .6044 Mdot
.39791 .5748 Mdot
.18511 .48652 Mdot
.75315 .35107 Mdot
.55987 .49858 Mdot
.4543 .55279 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47444 .6072 Mdot
.41874 .58361 Mdot
.24638 .51151 Mdot
.83535 .364 Mdot
.62954 .49083 Mdot
.59728 .5981 Mdot
.70202 .06473 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.5067 .00284 Mdot
.52133 .00905 Mdot
.56788 .02876 Mdot
.71318 .0898 Mdot
.09085 .23341 Mdot
.33953 .15369 Mdot
.38626 .02888 Mdot
.27654 .55022 Mdot
.9314 .40473 Mdot
.686 .46637 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52351 .00997 Mdot
.57477 .03168 Mdot
.73409 .09847 Mdot
.13096 .24528 Mdot
.35282 .13711 Mdot
.38405 .0193 Mdot
.25634 .5391 Mdot
.89008 .39168 Mdot
.49933 .61775 Mdot
.49786 .61713 Mdot
.49318 .61514 Mdot
.47828 .60883 Mdot
.43091 .58876 Mdot
.28312 .5267 Mdot
.90176 .38234 Mdot
.65857 .46774 Mdot
.6158 .5916 Mdot
.73181 .0717 Mdot
.085 .21828 Mdot
.49947 .61781 Mdot
.49831 .61732 Mdot
.49462 .61575 Mdot
.48286 .61076 Mdot
.44543 .5949 Mdot
.32774 .5453 Mdot
.99924 .41501 Mdot
.67188 .41571 Mdot
.55506 .54584 Mdot
.51921 .59587 Mdot
.51209 .61363 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.5041 .00174 Mdot
.51306 .00554 Mdot
.54158 .01763 Mdot
.63176 .05574 Mdot
.89778 .16441 Mdot
.3068 .25279 Mdot
.49213 .11454 Mdot
.66565 .10724 Mdot
.04516 .23455 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50303 .00128 Mdot
.50964 .00409 Mdot
.53071 .01302 Mdot
.59756 .04132 Mdot
.80177 .1262 Mdot
.23219 .26601 Mdot
.42537 .11939 Mdot
.51065 .05271 Mdot
.6119 .06258 Mdot
.86751 .15798 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50795 .00337 Mdot
.52531 .01073 Mdot
.58048 .0341 Mdot
.75129 .10556 Mdot
.16082 .2531 Mdot
.36813 .12812 Mdot
.3995 .01939 Mdot
.28993 .55032 Mdot
.94911 .40739 Mdot
.68333 .45377 Mdot
.49741 .61693 Mdot
.49174 .61453 Mdot
.47368 .60688 Mdot
.41634 .58259 Mdot
.23919 .50855 Mdot
.82386 .36135 Mdot
.62202 .49329 Mdot
.58579 .59564 Mdot
.6721 .05334 Mdot
.96911 .18356 Mdot
.31217 .21202 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00328 Mdot
.5246 .01043 Mdot
.57824 .03315 Mdot
.74456 .10279 Mdot
.14948 .25025 Mdot
.36172 .13117 Mdot
.39166 .01851 Mdot
.27136 .54368 Mdot
.91448 .39747 Mdot
.49981 .61795 Mdot
.49939 .61777 Mdot
.49805 .61721 Mdot
.49378 .6154 Mdot
.48019 .60963 Mdot
.43695 .59131 Mdot
.3016 .53438 Mdot
.93995 .39452 Mdot
.66625 .44888 Mdot
.599 .57647 Mdot
.67084 .0444 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51962 .00832 Mdot
.56243 .02646 Mdot
.69651 .08286 Mdot
.05596 .22215 Mdot
.33319 .17134 Mdot
.40357 .0435 Mdot
.33799 .5775 Mdot
.06924 .45194 Mdot
.69988 .38976 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47342 .60676 Mdot
.41551 .58224 Mdot
.23673 .50754 Mdot
.82005 .36051 Mdot
.61934 .49399 Mdot
.58135 .59455 Mdot
.66014 .04869 Mdot
.9406 .17334 Mdot
.49824 .61729 Mdot
.49439 .61566 Mdot
.48214 .61046 Mdot
.44316 .59394 Mdot
.32071 .54236 Mdot
.9827 .40914 Mdot
.67059 .42514 Mdot
.56811 .5547 Mdot
.5647 .61593 Mdot
.6557 .05624 Mdot
.94473 .17863 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50814 .00345 Mdot
.52594 .011 Mdot
.58249 .03494 Mdot
.75729 .10804 Mdot
.17058 .25543 Mdot
.37425 .12587 Mdot
.40831 .02105 Mdot
.31231 .55871 Mdot
.99565 .42232 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00343 Mdot
.5258 .01094 Mdot
.58203 .03475 Mdot
.75594 .10748 Mdot
.16842 .25492 Mdot
.37284 .12634 Mdot
.40618 .02061 Mdot
.30681 .55662 Mdot
.98376 .41838 Mdot
.68502 .4334 Mdot
.49834 .61733 Mdot
.4947 .61578 Mdot
.4831 .61087 Mdot
.44621 .59523 Mdot
.33016 .54631 Mdot
.00501 .41708 Mdot
.67235 .41244 Mdot
.55057 .54277 Mdot
.50338 .58887 Mdot
.46125 .592 Mdot
.36157 .55643 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.4822 .61049 Mdot
.44334 .59402 Mdot
.32128 .5426 Mdot
.98404 .40961 Mdot
.6707 .42438 Mdot
.56705 .55398 Mdot
.56104 .61432 Mdot
.64437 .0515 Mdot
.91575 .16772 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.51212 .00514 Mdot
.53859 .01636 Mdot
.62239 .05179 Mdot
.8722 .15439 Mdot
.29377 .26054 Mdot
.48557 .11854 Mdot
.65575 .10518 Mdot
.02402 .2276 Mdot
.35639 .20542 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52373 .01006 Mdot
.57547 .03198 Mdot
.73623 .09935 Mdot
.13483 .24635 Mdot
.35452 .13578 Mdot
.38514 .01892 Mdot
.25803 .53948 Mdot
.8925 .39212 Mdot
.67623 .48437 Mdot
.49869 .61748 Mdot
.49583 .61626 Mdot
.48671 .6124 Mdot
.45767 .60009 Mdot
.36588 .56131 Mdot
.09589 .45117 Mdot
.69061 .36756 Mdot
.50764 .50495 Mdot
.33611 .51202 Mdot
.95994 .38555 Mdot
.64323 .4223 Mdot
.49772 .61707 Mdot
.49272 .61495 Mdot
.47681 .6082 Mdot
.42624 .58678 Mdot
.26896 .52083 Mdot
.87464 .37433 Mdot
.64951 .4789 Mdot
.61708 .59799 Mdot
.74486 .07897 Mdot
.11124 .22644 Mdot
.32402 .13151 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51797 .00762 Mdot
.55721 .02425 Mdot
.68042 .07615 Mdot
.01992 .20982 Mdot
.32961 .1914 Mdot
.42983 .06194 Mdot
.42816 .617 Mdot
.32235 .55264 Mdot
.00205 .42008 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43731 .59146 Mdot
.30268 .53483 Mdot
.94229 .3953 Mdot
.66658 .44763 Mdot
.59754 .57537 Mdot
.66584 .04221 Mdot
.50049 .00021 Mdot
.50157 .00066 Mdot
.50499 .00212 Mdot
.51589 .00674 Mdot
.55059 .02145 Mdot
.65992 .06757 Mdot
.97074 .1921 Mdot
.32521 .21907 Mdot
.4671 .08769 Mdot
.55999 .05741 Mdot
.74076 .11172 Mdot
.15986 .25902 Mdot
.49824 .61729 Mdot
.49439 .61566 Mdot
.48214 .61046 Mdot
.44316 .59394 Mdot
.32072 .54236 Mdot
.98272 .40914 Mdot
.67059 .42513 Mdot
.56809 .55469 Mdot
.56465 .6159 Mdot
.65553 .05617 Mdot
.94432 .17848 Mdot
.49842 .61736 Mdot
.49496 .61589 Mdot
.48393 .61122 Mdot
.44884 .59635 Mdot
.33831 .54973 Mdot
.02487 .42432 Mdot
.67428 .40136 Mdot
.5359 .53251 Mdot
.45092 .56551 Mdot
.29348 .52073 Mdot
.90617 .37866 Mdot
.49785 .61712 Mdot
.49316 .61513 Mdot
.47821 .60879 Mdot
.43068 .58866 Mdot
.28242 .5264 Mdot
.90036 .38191 Mdot
.65819 .46837 Mdot
.61612 .59203 Mdot
.73318 .07235 Mdot
.08764 .21907 Mdot
.31718 .14187 Mdot
.49947 .61781 Mdot
.49831 .61732 Mdot
.4946 .61575 Mdot
.48281 .61075 Mdot
.44529 .59484 Mdot
.3273 .54511 Mdot
.99819 .41463 Mdot
.67179 .41631 Mdot
.55588 .5464 Mdot
.52209 .59715 Mdot
.52132 .61756 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51501 .00637 Mdot
.54779 .02026 Mdot
.6512 .06391 Mdot
.94879 .18392 Mdot
.32188 .23058 Mdot
.48017 .09783 Mdot
.6088 .0795 Mdot
.88821 .17268 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50304 .00129 Mdot
.50969 .00411 Mdot
.53086 .01309 Mdot
.59804 .04152 Mdot
.80316 .12677 Mdot
.23382 .26616 Mdot
.42697 .11938 Mdot
.51439 .05403 Mdot
.49799 .61718 Mdot
.49359 .61531 Mdot
.47956 .60937 Mdot
.43497 .59048 Mdot
.29553 .53186 Mdot
.92706 .39031 Mdot
.66421 .45558 Mdot
.60624 .5822 Mdot
.69604 .0555 Mdot
.011 .19465 Mdot
.30947 .18446 Mdot
.49943 .61779 Mdot
.4982 .61727 Mdot
.49426 .6156 Mdot
.4817 .61028 Mdot
.44177 .59335 Mdot
.31642 .54056 Mdot
.97283 .40568 Mdot
.6698 .43075 Mdot
.57582 .55995 Mdot
.59132 .00958 Mdot
.7364 .08966 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52365 .01003 Mdot
.57523 .03188 Mdot
.7355 .09905 Mdot
.13352 .24599 Mdot
.35393 .13622 Mdot
.38474 .01904 Mdot
.25738 .53932 Mdot
.89153 .39193 Mdot
.67609 .48488 Mdot
.49766 .61704 Mdot
.49254 .61487 Mdot
.47624 .60796 Mdot
.42443 .58602 Mdot
.26349 .51857 Mdot
.86467 .37155 Mdot
.64525 .48243 Mdot
.6147 .59915 Mdot
.7417 .07849 Mdot
.1071 .22583 Mdot
.32371 .13387 Mdot
.49868 .61747 Mdot
.4958 .61625 Mdot
.48661 .61236 Mdot
.45736 .59996 Mdot
.36493 .5609 Mdot
.09334 .45019 Mdot
.68963 .36853 Mdot
.50769 .50559 Mdot
.33727 .51271 Mdot
.96313 .3868 Mdot
.6438 .42067 Mdot
.49763 .61703 Mdot
.49245 .61483 Mdot
.47594 .60783 Mdot
.42347 .58561 Mdot
.26057 .51736 Mdot
.85946 .37014 Mdot
.64282 .48414 Mdot
.61278 .59947 Mdot
.73812 .07746 Mdot
.10152 .22459 Mdot
.32276 .13673 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51485 .0063 Mdot
.54728 .02004 Mdot
.64958 .06323 Mdot
.94464 .18236 Mdot
.32108 .23265 Mdot
.4822 .09958 Mdot
.61668 .08311 Mdot
.91092 .18185 Mdot
.33191 .26019 Mdot
.49948 .61782 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.48331 .61096 Mdot
.44688 .59552 Mdot
.33223 .54718 Mdot
.01002 .41889 Mdot
.67279 .40961 Mdot
.54674 .54013 Mdot
.4898 .58284 Mdot
.41756 .57339 Mdot
.49877 .61751 Mdot
.49607 .61637 Mdot
.48747 .61272 Mdot
.46011 .60112 Mdot
.37354 .56453 Mdot
.11661 .45924 Mdot
.7 .36056 Mdot
.51044 .50088 Mdot
.33654 .51056 Mdot
.95834 .38429 Mdot
.64192 .42247 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50612 .0026 Mdot
.5195 .00827 Mdot
.56205 .0263 Mdot
.69533 .08237 Mdot
.0534 .2213 Mdot
.33286 .17272 Mdot
.40523 .04472 Mdot
.34368 .58 Mdot
.08358 .45728 Mdot
.70379 .38331 Mdot
.50018 8e-05 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50598 .00254 Mdot
.51905 .00808 Mdot
.56064 .0257 Mdot
.691 .08057 Mdot
.04388 .21809 Mdot
.33177 .17792 Mdot
.41174 .04943 Mdot
.36602 .58977 Mdot
.14223 .47973 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.50931 .00395 Mdot
.52966 .01258 Mdot
.59425 .03992 Mdot
.7921 .12228 Mdot
.22038 .26469 Mdot
.41405 .11969 Mdot
.48497 .04383 Mdot
.53337 .02991 Mdot
.63145 .06062 Mdot
.49906 .61763 Mdot
.49699 .61676 Mdot
.49041 .61397 Mdot
.46945 .60508 Mdot
.40295 .57693 Mdot
.19972 .49243 Mdot
.76958 .35219 Mdot
.57636 .49862 Mdot
.49334 .56673 Mdot
.40034 .56056 Mdot
.16744 .47409 Mdot
.50019 8e-05 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50612 .0026 Mdot
.51951 .00827 Mdot
.56209 .02632 Mdot
.69546 .08243 Mdot
.05369 .2214 Mdot
.3329 .17256 Mdot
.40504 .04458 Mdot
.34303 .57971 Mdot
.08193 .45667 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50798 .00338 Mdot
.52541 .01077 Mdot
.58079 .03423 Mdot
.75221 .10595 Mdot
.16234 .25348 Mdot
.36905 .12775 Mdot
.40074 .01959 Mdot
.29302 .55146 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50565 .0024 Mdot
.51801 .00763 Mdot
.55731 .02429 Mdot
.68073 .07628 Mdot
.02062 .21007 Mdot
.32967 .191 Mdot
.42927 .06156 Mdot
.42625 .61616 Mdot
.31651 .55021 Mdot
.98859 .41537 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50597 .00253 Mdot
.51902 .00806 Mdot
.56052 .02565 Mdot
.69064 .08042 Mdot
.04307 .21782 Mdot
.33168 .17837 Mdot
.41232 .04984 Mdot
.36799 .59064 Mdot
.14758 .48181 Mdot
.73619 .36378 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.5169 .00717 Mdot
.55379 .0228 Mdot
.66986 .07173 Mdot
.99501 .20096 Mdot
.32765 .20558 Mdot
.44941 .07525 Mdot
.49655 .02914 Mdot
.53852 .02594 Mdot
.63772 .06131 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47991 .60951 Mdot
.43607 .59094 Mdot
.29888 .53325 Mdot
.93414 .39261 Mdot
.66539 .45194 Mdot
.60243 .57912 Mdot
.68272 .04962 Mdot
.98074 .18418 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50741 .00314 Mdot
.52361 .01001 Mdot
.57508 .03181 Mdot
.73504 .09886 Mdot
.13268 .24575 Mdot
.35356 .13651 Mdot
.3845 .01912 Mdot
.257 .53923 Mdot
.891 .39183 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51414 .006 Mdot
.54503 .01909 Mdot
.64257 .06028 Mdot
.92648 .17547 Mdot
.31679 .24123 Mdot
.48909 .10648 Mdot
.64503 .09638 Mdot
.98963 .21298 Mdot
.34978 .22258 Mdot
.49957 .61785 Mdot
.49863 .61745 Mdot
.49563 .61618 Mdot
.48607 .61212 Mdot
.45563 .59922 Mdot
.35949 .55862 Mdot
.07893 .44464 Mdot
.68476 .37443 Mdot
.50956 .50975 Mdot
.34868 .51861 Mdot
.9935 .39852 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51565 .00664 Mdot
.54982 .02112 Mdot
.65752 .06656 Mdot
.96477 .18989 Mdot
.32443 .22228 Mdot
.471 .09058 Mdot
.57431 .06385 Mdot
.78507 .13026 Mdot
.22879 .27424 Mdot
.49801 .61719 Mdot
.49366 .61534 Mdot
.47979 .60946 Mdot
.43569 .59078 Mdot
.29772 .53276 Mdot
.93166 .3918 Mdot
.66499 .45322 Mdot
.60381 .58022 Mdot
.68753 .05174 Mdot
.99182 .18806 Mdot
.30838 .19564 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50791 .00336 Mdot
.5252 .01069 Mdot
.58014 .03395 Mdot
.75028 .10515 Mdot
.15916 .2527 Mdot
.36714 .12854 Mdot
.39819 .01919 Mdot
.28673 .54915 Mdot
.94286 .40551 Mdot
.49751 .61698 Mdot
.49206 .61467 Mdot
.4747 .60731 Mdot
.41957 .58396 Mdot
.24885 .51253 Mdot
.83941 .36498 Mdot
.63201 .48985 Mdot
.60068 .59868 Mdot
.71051 .06788 Mdot
.05177 .21091 Mdot
.31673 .16376 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00248 Mdot
.51866 .00791 Mdot
.55939 .02517 Mdot
.68715 .07896 Mdot
.03527 .21515 Mdot
.33092 .18272 Mdot
.41802 .05384 Mdot
.38753 .59919 Mdot
.20204 .50339 Mdot
.78857 .3625 Mdot
.49772 .61707 Mdot
.49274 .61496 Mdot
.47688 .60823 Mdot
.42647 .58688 Mdot
.26965 .52111 Mdot
.87591 .37469 Mdot
.65001 .47842 Mdot
.61726 .5978 Mdot
.74493 .0789 Mdot
.1112 .22637 Mdot
.32392 .13147 Mdot
.49947 .61781 Mdot
.49832 .61732 Mdot
.49463 .61576 Mdot
.4829 .61078 Mdot
.44556 .59496 Mdot
.32816 .54547 Mdot
.00024 .41537 Mdot
.67196 .41515 Mdot
.55428 .54531 Mdot
.51646 .59466 Mdot
.50329 .60989 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50798 .00339 Mdot
.52543 .01078 Mdot
.58087 .03426 Mdot
.75245 .10605 Mdot
.16274 .25357 Mdot
.36929 .12765 Mdot
.40108 .01965 Mdot
.29386 .55177 Mdot
.95692 .40979 Mdot
.68381 .44924 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47715 .60834 Mdot
.42731 .58723 Mdot
.27218 .52216 Mdot
.88064 .37605 Mdot
.65182 .47661 Mdot
.61773 .59696 Mdot
.74456 .07839 Mdot
.10999 .22585 Mdot
.32325 .1318 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50276 .00117 Mdot
.50879 .00373 Mdot
.52799 .01187 Mdot
.58896 .03768 Mdot
.77653 .11592 Mdot
.19952 .26142 Mdot
.39569 .12124 Mdot
.44636 .03131 Mdot
.41807 .60055 Mdot
.27225 .52791 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.48049 .60976 Mdot
.43792 .59172 Mdot
.30456 .53562 Mdot
.94637 .39666 Mdot
.66711 .44544 Mdot
.59492 .57342 Mdot
.65683 .03826 Mdot
.91772 .16124 Mdot
.29661 .23416 Mdot
.49796 .61717 Mdot
.49349 .61527 Mdot
.47927 .60924 Mdot
.43404 .59008 Mdot
.29269 .53067 Mdot
.92115 .38841 Mdot
.6631 .45855 Mdot
.60908 .58465 Mdot
.70616 .06 Mdot
.03297 .20198 Mdot
.31068 .17164 Mdot
.49979 .61794 Mdot
.49932 .61775 Mdot
.49783 .61711 Mdot
.49309 .61511 Mdot
.478 .60871 Mdot
.43001 .58838 Mdot
.28039 .52556 Mdot
.89637 .3807 Mdot
.65705 .47012 Mdot
.61688 .59321 Mdot
.73668 .07405 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50821 .00348 Mdot
.52614 .01108 Mdot
.5831 .0352 Mdot
.75913 .10879 Mdot
.17349 .25609 Mdot
.37618 .12527 Mdot
.41132 .02172 Mdot
.32022 .56173 Mdot
.01326 .42832 Mdot
.68643 .41604 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50526 .00223 Mdot
.51675 .0071 Mdot
.55332 .0226 Mdot
.66837 .07111 Mdot
.99145 .19967 Mdot
.32734 .2076 Mdot
.45215 .07713 Mdot
.50625 .03344 Mdot
.56972 .03923 Mdot
.73447 .10182 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.4808 .60989 Mdot
.4389 .59214 Mdot
.30757 .53687 Mdot
.95296 .39887 Mdot
.66789 .44185 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.522 .00933 Mdot
.56997 .02965 Mdot
.71957 .09245 Mdot
.10354 .23731 Mdot
.34293 .14795 Mdot
.38314 .02485 Mdot
.26339 .54402 Mdot
.90575 .397 Mdot
.68137 .47936 Mdot
.49817 .61726 Mdot
.49418 .61557 Mdot
.48147 .61018 Mdot
.44102 .59304 Mdot
.31412 .5396 Mdot
.96759 .40387 Mdot
.66934 .43371 Mdot
.57982 .56271 Mdot
.60508 .01561 Mdot
.77675 .1061 Mdot
.18379 .25156 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50766 .00325 Mdot
.5244 .01034 Mdot
.57758 .03287 Mdot
.74259 .10198 Mdot
.14608 .24937 Mdot
.35994 .13217 Mdot
.3898 .01845 Mdot
.26725 .54229 Mdot
.90736 .39561 Mdot
.67872 .47673 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.50301 .00128 Mdot
.50958 .00406 Mdot
.53052 .01294 Mdot
.59696 .04106 Mdot
.80002 .1255 Mdot
.23012 .26581 Mdot
.42334 .11942 Mdot
.50597 .05107 Mdot
.59755 .0566 Mdot
.82645 .14147 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50521 .00221 Mdot
.51661 .00704 Mdot
.55286 .02241 Mdot
.66696 .07052 Mdot
.98803 .19843 Mdot
.32704 .20952 Mdot
.45474 .07892 Mdot
.51545 .03752 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.5235 .00996 Mdot
.57473 .03167 Mdot
.734 .09843 Mdot
.13079 .24523 Mdot
.35274 .13718 Mdot
.38401 .01932 Mdot
.49838 .61735 Mdot
.49485 .61585 Mdot
.48359 .61108 Mdot
.44776 .59589 Mdot
.33496 .54832 Mdot
.01665 .42131 Mdot
.67341 .4059 Mdot
.54179 .53669 Mdot
.47212 .57498 Mdot
.36086 .54927 Mdot
.06648 .43609 Mdot
.49875 .6175 Mdot
.49601 .61634 Mdot
.48729 .61264 Mdot
.45952 .60087 Mdot
.37167 .56374 Mdot
.11153 .45726 Mdot
.69745 .36212 Mdot
.50921 .50169 Mdot
.33478 .51023 Mdot
.95469 .38313 Mdot
.64165 .42457 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51265 .00537 Mdot
.5403 .01708 Mdot
.62774 .05404 Mdot
.88688 .16015 Mdot
.30177 .25642 Mdot
.49044 .11661 Mdot
.66479 .10775 Mdot
.04445 .23465 Mdot
.3583 .19397 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49427 .6156 Mdot
.48175 .61029 Mdot
.44191 .59341 Mdot
.31685 .54075 Mdot
.97382 .40603 Mdot
.66988 .43019 Mdot
.57505 .55943 Mdot
.58868 .00842 Mdot
.72855 .08644 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .00099 Mdot
.50747 .00317 Mdot
.5238 .01009 Mdot
.57571 .03208 Mdot
.73695 .09965 Mdot
.13612 .2467 Mdot
.35511 .13534 Mdot
.38556 .01882 Mdot
.25876 .53967 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48592 .61206 Mdot
.45516 .59903 Mdot
.35804 .55801 Mdot
.0751 .44317 Mdot
.68365 .3761 Mdot
.51048 .51101 Mdot
.35302 .52072 Mdot
.00512 .40302 Mdot
.64954 .39828 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.50648 .00275 Mdot
.52066 .00876 Mdot
.56573 .02786 Mdot
.70663 .08708 Mdot
.07745 .22918 Mdot
.33663 .16018 Mdot
.39157 .03396 Mdot
.29616 .55907 Mdot
.97198 .41768 Mdot
.68962 .44353 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49072 .6141 Mdot
.47045 .6055 Mdot
.4061 .57826 Mdot
.20893 .49617 Mdot
.78093 .35352 Mdot
.58717 .49828 Mdot
.51772 .57511 Mdot
.4748 .59151 Mdot
.39425 .56825 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48105 .61 Mdot
.43968 .59247 Mdot
.30997 .53787 Mdot
.95829 .40068 Mdot
.66846 .43891 Mdot
.5867 .56751 Mdot
.62866 .02593 Mdot
.84327 .13264 Mdot
.25678 .25556 Mdot
.49873 .6175 Mdot
.49597 .61632 Mdot
.48715 .61258 Mdot
.45908 .60069 Mdot
.3703 .56317 Mdot
.1078 .4558 Mdot
.69568 .36333 Mdot
.50853 .50237 Mdot
.33417 .51027 Mdot
.95369 .38289 Mdot
.6417 .42521 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55363 .02273 Mdot
.66934 .07151 Mdot
.99377 .20051 Mdot
.32754 .20629 Mdot
.45037 .07591 Mdot
.49995 .03064 Mdot
.54945 .03059 Mdot
.67193 .0757 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00115 Mdot
.5086 .00365 Mdot
.52741 .01162 Mdot
.58712 .0369 Mdot
.77109 .1137 Mdot
.19169 .25995 Mdot
.38941 .12219 Mdot
.43427 .02773 Mdot
.38332 .58654 Mdot
.1726 .4878 Mdot
.49743 .61694 Mdot
.4918 .61456 Mdot
.47389 .60696 Mdot
.41699 .58287 Mdot
.24114 .50935 Mdot
.82693 .36204 Mdot
.6241 .49268 Mdot
.58912 .59642 Mdot
.68095 .05675 Mdot
.9894 .19063 Mdot
.31374 .20045 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61007 Mdot
.44021 .59269 Mdot
.31161 .53856 Mdot
.96195 .40193 Mdot
.66882 .43687 Mdot
.58404 .56563 Mdot
.61953 .02194 Mdot
.81794 .12262 Mdot
.23366 .25693 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47562 .6077 Mdot
.42246 .58518 Mdot
.25754 .51611 Mdot
.85415 .36873 Mdot
.64018 .48579 Mdot
.61032 .59958 Mdot
.73301 .07583 Mdot
.09307 .22253 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50287 .00122 Mdot
.50913 .00387 Mdot
.52908 .01233 Mdot
.59242 .03914 Mdot
.78672 .12008 Mdot
.21343 .26372 Mdot
.40768 .12005 Mdot
.47108 .03919 Mdot
.49135 .01253 Mdot
.49865 .00451 Mdot
.4984 .61736 Mdot
.49492 .61588 Mdot
.48381 .61117 Mdot
.44844 .59618 Mdot
.33709 .54922 Mdot
.02187 .42322 Mdot
.67395 .403 Mdot
.53801 .53402 Mdot
.45854 .56892 Mdot
.31759 .53092 Mdot
.95912 .39649 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.5257 .0109 Mdot
.58171 .03461 Mdot
.75496 .10708 Mdot
.16683 .25455 Mdot
.37183 .1267 Mdot
.40469 .02031 Mdot
.30298 .55517 Mdot
.97564 .41573 Mdot
.49971 .61791 Mdot
.49906 .61764 Mdot
.49702 .61677 Mdot
.4905 .614 Mdot
.46973 .6052 Mdot
.40382 .5773 Mdot
.20226 .49346 Mdot
.77262 .35251 Mdot
.57932 .49856 Mdot
.50012 .56909 Mdot
.4211 .5692 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.51009 .00428 Mdot
.53213 .01362 Mdot
.60205 .04321 Mdot
.81478 .13147 Mdot
.24673 .26696 Mdot
.44 .11945 Mdot
.5454 .06514 Mdot
.49863 .61745 Mdot
.49563 .61618 Mdot
.48607 .61213 Mdot
.45566 .59923 Mdot
.35958 .55866 Mdot
.07916 .44472 Mdot
.68483 .37433 Mdot
.50951 .50968 Mdot
.34844 .51849 Mdot
.99286 .39827 Mdot
.64799 .40489 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50789 .00335 Mdot
.52515 .01066 Mdot
.57997 .03388 Mdot
.74976 .10494 Mdot
.15828 .25248 Mdot
.36663 .12877 Mdot
.39752 .01909 Mdot
.28511 .54856 Mdot
.93974 .40459 Mdot
.68262 .45912 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50692 .00293 Mdot
.52205 .00935 Mdot
.57014 .02972 Mdot
.72006 .09266 Mdot
.10451 .2376 Mdot
.34322 .14753 Mdot
.38298 .02458 Mdot
.26262 .54364 Mdot
.90427 .39656 Mdot
.68101 .48006 Mdot
.4974 .61693 Mdot
.49171 .61452 Mdot
.4736 .60684 Mdot
.41608 .58248 Mdot
.23843 .50824 Mdot
.82268 .36109 Mdot
.6212 .49351 Mdot
.58445 .59532 Mdot
.6685 .05195 Mdot
.96067 .18057 Mdot
.31123 .21666 Mdot
.49762 .61702 Mdot
.49241 .61482 Mdot
.47582 .60778 Mdot
.4231 .58545 Mdot
.25947 .5169 Mdot
.85752 .36962 Mdot
.64187 .48475 Mdot
.61194 .59954 Mdot
.73642 .07693 Mdot
.09877 .22394 Mdot
.32229 .13814 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.5112 .00475 Mdot
.53566 .01512 Mdot
.61317 .0479 Mdot
.84649 .1442 Mdot
.276 .26545 Mdot
.46995 .11987 Mdot
.61908 .09217 Mdot
.93063 .19255 Mdot
.34297 .25484 Mdot
.4983 .61731 Mdot
.49458 .61573 Mdot
.48273 .61071 Mdot
.44502 .59473 Mdot
.32647 .54477 Mdot
.99623 .41393 Mdot
.67164 .41743 Mdot
.55743 .54745 Mdot
.5275 .59954 Mdot
.53861 .00687 Mdot
.60708 .04231 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00254 Mdot
.5191 .0081 Mdot
.56079 .02577 Mdot
.69148 .08077 Mdot
.04493 .21845 Mdot
.33188 .17734 Mdot
.411 .0489 Mdot
.36348 .58866 Mdot
.13537 .47706 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50142 .0006 Mdot
.50451 .00191 Mdot
.51438 .0061 Mdot
.5458 .01942 Mdot
.64496 .06129 Mdot
.93273 .17785 Mdot
.31843 .23837 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.49861 .61744 Mdot
.49557 .61616 Mdot
.48589 .61205 Mdot
.45508 .59899 Mdot
.35777 .55789 Mdot
.07439 .4429 Mdot
.68345 .37642 Mdot
.51067 .51125 Mdot
.35388 .52113 Mdot
.49889 .61756 Mdot
.49646 .61653 Mdot
.48873 .61326 Mdot
.46412 .60282 Mdot
.38615 .56984 Mdot
.15159 .47307 Mdot
.7225 .35284 Mdot
.52859 .49819 Mdot
.37734 .52456 Mdot
.05978 .42177 Mdot
.65464 .36765 Mdot
.49888 .61756 Mdot
.49642 .61652 Mdot
.48861 .6132 Mdot
.46371 .60265 Mdot
.38485 .56929 Mdot
.14794 .47162 Mdot
.71972 .35338 Mdot
.52594 .49827 Mdot
.37088 .5222 Mdot
.0427 .41521 Mdot
.65124 .3761 Mdot
.49925 .61772 Mdot
.49762 .61703 Mdot
.49243 .61482 Mdot
.47587 .6078 Mdot
.42327 .58552 Mdot
.25998 .51712 Mdot
.85843 .36986 Mdot
.64232 .48447 Mdot
.61235 .59951 Mdot
.73724 .07719 Mdot
.10011 .22426 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.48479 .61159 Mdot
.45158 .59751 Mdot
.34686 .55331 Mdot
.04626 .43226 Mdot
.67725 .38997 Mdot
.52245 .52237 Mdot
.40122 .54311 Mdot
.14116 .45731 Mdot
.69604 .34294 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48534 .61182 Mdot
.45333 .59825 Mdot
.35231 .5556 Mdot
.06022 .43751 Mdot
.67994 .38301 Mdot
.51562 .51648 Mdot
.3747 .53094 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52125 .00901 Mdot
.5676 .02865 Mdot
.71234 .08945 Mdot
.08916 .23289 Mdot
.33913 .15449 Mdot
.38682 .02948 Mdot
.2787 .55121 Mdot
.93571 .40606 Mdot
.4992 .61769 Mdot
.49745 .61695 Mdot
.49187 .61459 Mdot
.47411 .60706 Mdot
.41768 .58316 Mdot
.24321 .5102 Mdot
.83022 .36279 Mdot
.62628 .49199 Mdot
.59249 .59715 Mdot
.68976 .06011 Mdot
.00885 .19721 Mdot
.49773 .61707 Mdot
.49275 .61496 Mdot
.47691 .60825 Mdot
.42657 .58692 Mdot
.26994 .52123 Mdot
.87646 .37485 Mdot
.65023 .47822 Mdot
.61734 .59771 Mdot
.74494 .07886 Mdot
.11115 .22633 Mdot
.32386 .13147 Mdot
.49798 .61718 Mdot
.49358 .61531 Mdot
.47954 .60936 Mdot
.43491 .59045 Mdot
.29533 .53177 Mdot
.92664 .39017 Mdot
.66413 .4558 Mdot
.60645 .58238 Mdot
.6968 .05584 Mdot
.01267 .19522 Mdot
.30955 .18349 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.5076 .00322 Mdot
.5242 .01026 Mdot
.57698 .03262 Mdot
.74077 .10123 Mdot
.14289 .24852 Mdot
.35833 .13315 Mdot
.38824 .01849 Mdot
.26396 .54122 Mdot
.90186 .39424 Mdot
.67782 .47957 Mdot
.49817 .61726 Mdot
.49416 .61556 Mdot
.4814 .61015 Mdot
.4408 .59294 Mdot
.31345 .53932 Mdot
.96608 .40335 Mdot
.66921 .43456 Mdot
.58097 .5635 Mdot
.609 .01733 Mdot
.78806 .11066 Mdot
.19905 .25401 Mdot
.49956 .61785 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48571 .61197 Mdot
.45448 .59874 Mdot
.35592 .55712 Mdot
.06956 .44106 Mdot
.68215 .3786 Mdot
.51211 .51294 Mdot
.36022 .52416 Mdot
.0246 .41061 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50289 .00122 Mdot
.50919 .0039 Mdot
.52928 .01242 Mdot
.59305 .03941 Mdot
.78857 .12084 Mdot
.21585 .26407 Mdot
.40987 .11991 Mdot
.47581 .04075 Mdot
.50561 .01842 Mdot
.54382 .02361 Mdot
.49966 .61789 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.48899 .61337 Mdot
.46495 .60317 Mdot
.38874 .57094 Mdot
.15891 .47599 Mdot
.72839 .35196 Mdot
.53441 .49815 Mdot
.39165 .5298 Mdot
.09862 .43693 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52199 .00933 Mdot
.56996 .02965 Mdot
.71953 .09244 Mdot
.10347 .23729 Mdot
.34291 .14798 Mdot
.38315 .02487 Mdot
.26344 .54405 Mdot
.90586 .39703 Mdot
.68139 .47931 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46985 .60525 Mdot
.4042 .57746 Mdot
.20339 .49392 Mdot
.774 .35266 Mdot
.58064 .49853 Mdot
.50313 .57013 Mdot
.43032 .57303 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50434 .00184 Mdot
.51381 .00586 Mdot
.54398 .01864 Mdot
.63928 .0589 Mdot
.91784 .17216 Mdot
.31424 .24499 Mdot
.49109 .1093 Mdot
.65457 .10104 Mdot
.01515 .22285 Mdot
.35304 .20883 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60202 Mdot
.38022 .56734 Mdot
.13501 .46649 Mdot
.71072 .35581 Mdot
.51792 .49888 Mdot
.35195 .51546 Mdot
.99458 .39717 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50612 .0026 Mdot
.51951 .00827 Mdot
.56208 .02631 Mdot
.69543 .08242 Mdot
.05362 .22137 Mdot
.33289 .1726 Mdot
.40508 .04462 Mdot
.34319 .57978 Mdot
.08234 .45682 Mdot
.70342 .38384 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50392 .00166 Mdot
.5125 .0053 Mdot
.53981 .01688 Mdot
.62621 .0534 Mdot
.8827 .15852 Mdot
.29964 .25768 Mdot
.48936 .11726 Mdot
.66313 .1074 Mdot
.04095 .2335 Mdot
.35802 .19596 Mdot
.50014 6e-05 Mdot
.50044 .00018 Mdot
.50139 .00059 Mdot
.50442 .00187 Mdot
.51407 .00597 Mdot
.5448 .01899 Mdot
.64185 .05998 Mdot
.92461 .17475 Mdot
.31627 .24206 Mdot
.4896 .10712 Mdot
.64732 .09748 Mdot
.9958 .21537 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00226 Mdot
.51695 .00719 Mdot
.55396 .02287 Mdot
.67036 .07194 Mdot
.99622 .20139 Mdot
.32775 .2049 Mdot
.44848 .07461 Mdot
.49327 .02768 Mdot
.52796 .02144 Mdot
.60436 .04722 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.4927 .61494 Mdot
.47675 .60817 Mdot
.42604 .5867 Mdot
.26835 .52057 Mdot
.87351 .37401 Mdot
.64905 .47931 Mdot
.61689 .59816 Mdot
.74473 .07901 Mdot
.11117 .22647 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48722 .61262 Mdot
.45931 .60078 Mdot
.37102 .56347 Mdot
.10975 .45656 Mdot
.6966 .36269 Mdot
.50886 .50201 Mdot
.33442 .51022 Mdot
.95404 .38295 Mdot
.64165 .42497 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.48901 .61337 Mdot
.46501 .6032 Mdot
.38893 .57102 Mdot
.15945 .47621 Mdot
.72884 .3519 Mdot
.53486 .49815 Mdot
.39276 .53021 Mdot
.1017 .43815 Mdot
.66826 .35016 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00227 Mdot
.51702 .00722 Mdot
.55419 .02297 Mdot
.67109 .07225 Mdot
.99798 .20203 Mdot
.3279 .2039 Mdot
.44711 .07368 Mdot
.48845 .02555 Mdot
.4974 .61693 Mdot
.49172 .61452 Mdot
.47361 .60684 Mdot
.4161 .58249 Mdot
.2385 .50827 Mdot
.82279 .36111 Mdot
.62127 .49349 Mdot
.58457 .59535 Mdot
.66883 .05208 Mdot
.96144 .18084 Mdot
.31133 .21624 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47577 .60776 Mdot
.42293 .58538 Mdot
.25894 .51669 Mdot
.8566 .36937 Mdot
.64141 .48504 Mdot
.61152 .59956 Mdot
.73555 .07666 Mdot
.09733 .22359 Mdot
.32205 .13888 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51712 .00726 Mdot
.55451 .02311 Mdot
.67207 .07266 Mdot
.00032 .20287 Mdot
.32809 .20257 Mdot
.44528 .07243 Mdot
.48201 .0227 Mdot
.49183 .00606 Mdot
.48938 .61652 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.5068 .00289 Mdot
.52167 .00919 Mdot
.56895 .02922 Mdot
.71646 .09116 Mdot
.09742 .23544 Mdot
.3412 .15067 Mdot
.38439 .02669 Mdot
.26903 .54673 Mdot
.91664 .40024 Mdot
.68365 .47404 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58509 .03604 Mdot
.76504 .11122 Mdot
.18266 .2581 Mdot
.3826 .12357 Mdot
.42199 .02434 Mdot
.34899 .57292 Mdot
.08196 .453 Mdot
.50079 .00033 Mdot
.50251 .00107 Mdot
.50801 .0034 Mdot
.52551 .01082 Mdot
.58113 .03437 Mdot
.75322 .10636 Mdot
.164 .25388 Mdot
.37006 .12735 Mdot
.40216 .01984 Mdot
.29656 .55277 Mdot
.96238 .4115 Mdot
.6841 .44605 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51092 .00463 Mdot
.53477 .01474 Mdot
.61035 .04671 Mdot
.83851 .14101 Mdot
.26943 .26632 Mdot
.46339 .11988 Mdot
.60292 .08623 Mdot
.88629 .17513 Mdot
.32608 .27181 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00321 Mdot
.52413 .01023 Mdot
.57675 .03252 Mdot
.74009 .10095 Mdot
.14169 .2482 Mdot
.35774 .13353 Mdot
.38771 .01852 Mdot
.26286 .54088 Mdot
.90007 .39381 Mdot
.67751 .48049 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.51081 .00458 Mdot
.53442 .0146 Mdot
.60927 .04626 Mdot
.83545 .13979 Mdot
.26677 .26657 Mdot
.46069 .11984 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50334 .00141 Mdot
.51063 .00451 Mdot
.53386 .01436 Mdot
.60749 .04551 Mdot
.83037 .13775 Mdot
.26219 .26688 Mdot
.45597 .11977 Mdot
.58455 .07947 Mdot
.83406 .15421 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47506 .60746 Mdot
.42069 .58443 Mdot
.25221 .51391 Mdot
.84502 .36638 Mdot
.63526 .4884 Mdot
.60485 .59924 Mdot
.72058 .07152 Mdot
.07097 .21655 Mdot
.3184 .15292 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50936 .00397 Mdot
.52983 .01265 Mdot
.59477 .04014 Mdot
.79363 .1229 Mdot
.2223 .26493 Mdot
.41584 .11962 Mdot
.48896 .04519 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00212 Mdot
.51596 .00677 Mdot
.5508 .02153 Mdot
.66056 .06783 Mdot
.97233 .19268 Mdot
.3254 .21821 Mdot
.46603 .08691 Mdot
.55609 .05566 Mdot
.72856 .10659 Mdot
.49799 .61718 Mdot
.49361 .61532 Mdot
.47964 .6094 Mdot
.43522 .59058 Mdot
.29628 .53217 Mdot
.92863 .39081 Mdot
.66448 .45478 Mdot
.60543 .58154 Mdot
.69321 .05425 Mdot
.00468 .1925 Mdot
.30913 .18816 Mdot
.49881 .61753 Mdot
.49621 .61642 Mdot
.48791 .61291 Mdot
.4615 .60171 Mdot
.3779 .56637 Mdot
.12859 .46395 Mdot
.70671 .3573 Mdot
.51478 .49942 Mdot
.34499 .5131 Mdot
.97774 .39106 Mdot
.64377 .41163 Mdot
.49783 .61711 Mdot
.49309 .6151 Mdot
.47798 .6087 Mdot
.42994 .58835 Mdot
.28018 .52548 Mdot
.89596 .38058 Mdot
.65692 .4703 Mdot
.61694 .59332 Mdot
.73701 .07421 Mdot
.09502 .22126 Mdot
.31882 .13831 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51217 .00516 Mdot
.53875 .01643 Mdot
.62288 .052 Mdot
.87356 .15493 Mdot
.29457 .2602 Mdot
.48615 .1184 Mdot
.65697 .10557 Mdot
.02688 .22862 Mdot
.35667 .20382 Mdot
.49939 .61778 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48027 .60967 Mdot
.43721 .59142 Mdot
.3024 .53471 Mdot
.94167 .39509 Mdot
.66649 .44796 Mdot
.59793 .57566 Mdot
.66717 .04279 Mdot
.94353 .1708 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50319 .00135 Mdot
.51016 .00431 Mdot
.53237 .01372 Mdot
.6028 .04353 Mdot
.81693 .13234 Mdot
.24899 .26703 Mdot
.44232 .11949 Mdot
.55102 .06718 Mdot
.73494 .11367 Mdot
.15652 .26055 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48769 .61282 Mdot
.46081 .60142 Mdot
.37573 .56545 Mdot
.12261 .4616 Mdot
.70323 .35885 Mdot
.51236 .50007 Mdot
.34002 .51152 Mdot
.96613 .38696 Mdot
.64266 .41812 Mdot
.49929 .61773 Mdot
.49774 .61708 Mdot
.4928 .61498 Mdot
.47706 .6083 Mdot
.42702 .58711 Mdot
.2713 .52179 Mdot
.87898 .37557 Mdot
.6512 .47726 Mdot
.61761 .59727 Mdot
.7448 .07861 Mdot
.11061 .22608 Mdot
.49802 .6172 Mdot
.4937 .61536 Mdot
.47992 .60952 Mdot
.4361 .59095 Mdot
.29898 .53329 Mdot
.93434 .39268 Mdot
.66542 .45183 Mdot
.60231 .57903 Mdot
.68232 .04944 Mdot
.97979 .18385 Mdot
.3075 .20254 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49448 .61569 Mdot
.48242 .61058 Mdot
.44404 .59431 Mdot
.32343 .5435 Mdot
.98906 .41138 Mdot
.67108 .42152 Mdot
.56309 .55129 Mdot
.54728 .60826 Mdot
.60135 .03342 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51268 .00538 Mdot
.54039 .01713 Mdot
.62805 .05417 Mdot
.88771 .16048 Mdot
.30218 .25616 Mdot
.49063 .11647 Mdot
.66503 .10778 Mdot
.04493 .2348 Mdot
.35833 .19369 Mdot
.49926 .61772 Mdot
.49765 .61704 Mdot
.49252 .61486 Mdot
.47618 .60793 Mdot
.42424 .58594 Mdot
.26292 .51833 Mdot
.86364 .37127 Mdot
.64478 .48277 Mdot
.61436 .59923 Mdot
.7411 .07833 Mdot
.1062 .22564 Mdot
.49778 .61709 Mdot
.49293 .61504 Mdot
.47749 .60849 Mdot
.42839 .58769 Mdot
.27547 .52352 Mdot
.88687 .37786 Mdot
.65403 .47413 Mdot
.61782 .59565 Mdot
.74263 .07714 Mdot
.10592 .22453 Mdot
.3218 .13342 Mdot
.50012 5e-05 Mdot
.5004 .00017 Mdot
.50126 .00054 Mdot
.50403 .00171 Mdot
.51282 .00544 Mdot
.54084 .01731 Mdot
.62944 .05476 Mdot
.89149 .16196 Mdot
.30399 .25494 Mdot
.49135 .1158 Mdot
.66576 .10779 Mdot
.04623 .23514 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50555 .00235 Mdot
.51768 .0075 Mdot
.55626 .02385 Mdot
.6775 .07493 Mdot
.01312 .20743 Mdot
.32908 .19528 Mdot
.43519 .06557 Mdot
.44673 .00714 Mdot
.37987 .57671 Mdot
.14943 .47561 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.51079 .00458 Mdot
.53437 .01457 Mdot
.60909 .04618 Mdot
.83493 .13958 Mdot
.26631 .26661 Mdot
.46021 .11984 Mdot
.59506 .08334 Mdot
.86416 .16631 Mdot
.31317 .2775 Mdot
.4979 .61714 Mdot
.49329 .61519 Mdot
.47864 .60898 Mdot
.43204 .58923 Mdot
.28657 .52813 Mdot
.90863 .38446 Mdot
.66035 .46458 Mdot
.61391 .58933 Mdot
.72411 .06811 Mdot
.06988 .2137 Mdot
.31417 .15098 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51978 .00839 Mdot
.56293 .02667 Mdot
.69805 .08351 Mdot
.05929 .22326 Mdot
.33364 .16956 Mdot
.40147 .04192 Mdot
.33076 .57434 Mdot
.05141 .44538 Mdot
.69627 .39855 Mdot
.50062 .00026 Mdot
.50199 .00084 Mdot
.50634 .00269 Mdot
.52021 .00857 Mdot
.5643 .02725 Mdot
.70224 .08525 Mdot
.06825 .2262 Mdot
.33499 .16486 Mdot
.39624 .03785 Mdot
.31264 .56637 Mdot
.00856 .4301 Mdot
.69165 .42217 Mdot
.4984 .61736 Mdot
.49491 .61588 Mdot
.48379 .61116 Mdot
.44839 .59616 Mdot
.33692 .54914 Mdot
.02144 .42306 Mdot
.6739 .40324 Mdot
.53831 .53424 Mdot
.45965 .56941 Mdot
.32109 .5324 Mdot
.96723 .39934 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50627 .00266 Mdot
.51999 .00848 Mdot
.56361 .02696 Mdot
.70011 .08437 Mdot
.06372 .22472 Mdot
.33428 .16722 Mdot
.39881 .03988 Mdot
.32156 .5703 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .0024 Mdot
.51805 .00766 Mdot
.55747 .02436 Mdot
.68121 .07648 Mdot
.02174 .21046 Mdot
.32976 .19036 Mdot
.4284 .06096 Mdot
.42322 .61483 Mdot
.30728 .54638 Mdot
.9679 .40829 Mdot
.49927 .61773 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47648 .60806 Mdot
.4252 .58634 Mdot
.26581 .51952 Mdot
.86886 .37271 Mdot
.6471 .48098 Mdot
.61591 .59875 Mdot
.7436 .07892 Mdot
.10983 .22634 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50171 .00073 Mdot
.50545 .00231 Mdot
.51735 .00736 Mdot
.55524 .02342 Mdot
.67434 .0736 Mdot
.00569 .20479 Mdot
.32851 .19951 Mdot
.44106 .06956 Mdot
.46721 .01616 Mdot
.44451 .60401 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48618 .61217 Mdot
.45599 .59938 Mdot
.36062 .55909 Mdot
.0819 .44577 Mdot
.68568 .37316 Mdot
.50896 .50882 Mdot
.34568 .51712 Mdot
.98553 .39545 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00147 Mdot
.51108 .0047 Mdot
.53528 .01496 Mdot
.61197 .0474 Mdot
.84309 .14284 Mdot
.27326 .26586 Mdot
.46725 .11989 Mdot
.61245 .08974 Mdot
.91263 .18552 Mdot
.49882 .61753 Mdot
.49623 .61643 Mdot
.48797 .61293 Mdot
.4617 .6018 Mdot
.37853 .56663 Mdot
.13034 .46464 Mdot
.70777 .35687 Mdot
.51558 .49925 Mdot
.34672 .51367 Mdot
.98188 .39255 Mdot
.64416 .40931 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51995 .00846 Mdot
.56347 .0269 Mdot
.69971 .0842 Mdot
.06285 .22443 Mdot
.33415 .16767 Mdot
.39932 .04028 Mdot
.32334 .57108 Mdot
.03353 .43892 Mdot
.6938 .40807 Mdot
.49756 .617 Mdot
.49221 .61473 Mdot
.47519 .60751 Mdot
.42111 .58461 Mdot
.25347 .51443 Mdot
.84715 .36692 Mdot
.63645 .48782 Mdot
.60627 .59938 Mdot
.72391 .0727 Mdot
.07708 .21827 Mdot
.3191 .14958 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51998 .00847 Mdot
.56358 .02695 Mdot
.70004 .08433 Mdot
.06356 .22467 Mdot
.33426 .1673 Mdot
.3989 .03995 Mdot
.32189 .57044 Mdot
.0301 .43769 Mdot
.69342 .40996 Mdot
.4974 .61693 Mdot
.49172 .61452 Mdot
.47362 .60685 Mdot
.41612 .5825 Mdot
.23856 .50829 Mdot
.82288 .36113 Mdot
.62134 .49347 Mdot
.58467 .59537 Mdot
.66911 .05218 Mdot
.96209 .18108 Mdot
.31141 .21589 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.50489 .00207 Mdot
.51559 .00661 Mdot
.54963 .02104 Mdot
.6569 .0663 Mdot
.96321 .18931 Mdot
.32422 .22311 Mdot
.47198 .09132 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52194 .0093 Mdot
.56979 .02957 Mdot
.71899 .09221 Mdot
.10241 .23697 Mdot
.3426 .14844 Mdot
.38333 .02517 Mdot
.26432 .54448 Mdot
.90755 .39753 Mdot
.68178 .4785 Mdot
.49988 .61799 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60203 Mdot
.38023 .56735 Mdot
.13506 .46651 Mdot
.71075 .3558 Mdot
.51795 .49888 Mdot
.35201 .51548 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.4876 .61277 Mdot
.4605 .60129 Mdot
.37476 .56504 Mdot
.11994 .46055 Mdot
.70177 .35959 Mdot
.51145 .50041 Mdot
.33829 .51102 Mdot
.96221 .3856 Mdot
.64228 .42031 Mdot
.49816 .61725 Mdot
.49413 .61554 Mdot
.48129 .6101 Mdot
.44046 .5928 Mdot
.31238 .53888 Mdot
.96367 .40252 Mdot
.66898 .43591 Mdot
.58276 .56475 Mdot
.61517 .02003 Mdot
.80563 .11771 Mdot
.22039 .25634 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50558 .00237 Mdot
.51778 .00754 Mdot
.5566 .02399 Mdot
.67854 .07536 Mdot
.01555 .20828 Mdot
.32927 .19389 Mdot
.43327 .06427 Mdot
.44007 .00421 Mdot
.35909 .56799 Mdot
.09331 .45377 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52147 .00911 Mdot
.56832 .02895 Mdot
.71452 .09036 Mdot
.09355 .23425 Mdot
.3402 .15243 Mdot
.38543 .02796 Mdot
.27327 .54871 Mdot
.92492 .40274 Mdot
.68506 .46979 Mdot
.49966 .61789 Mdot
.49893 .61758 Mdot
.49659 .61659 Mdot
.48913 .61342 Mdot
.46537 .60335 Mdot
.39008 .5715 Mdot
.16271 .47751 Mdot
.73162 .35161 Mdot
.53768 .49817 Mdot
.39972 .53277 Mdot
.1211 .44584 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49717 .61683 Mdot
.49098 .61421 Mdot
.47127 .60585 Mdot
.40869 .57936 Mdot
.21655 .49928 Mdot
.79093 .35499 Mdot
.59619 .49768 Mdot
.53711 .58152 Mdot
.53319 .61561 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50392 .00166 Mdot
.51248 .00529 Mdot
.53974 .01685 Mdot
.62598 .0533 Mdot
.88207 .15827 Mdot
.29931 .25787 Mdot
.48918 .11735 Mdot
.66282 .10732 Mdot
.04027 .23328 Mdot
.35796 .19634 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60745 Mdot
.42061 .5844 Mdot
.25197 .51381 Mdot
.84462 .36628 Mdot
.63504 .48851 Mdot
.60457 .59921 Mdot
.71992 .07129 Mdot
.06976 .21621 Mdot
.31827 .15359 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50971 .00412 Mdot
.53092 .01311 Mdot
.59824 .0416 Mdot
.80372 .127 Mdot
.23447 .26622 Mdot
.42762 .11937 Mdot
.51589 .05456 Mdot
.62798 .06927 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48671 .6124 Mdot
.45769 .6001 Mdot
.36595 .56134 Mdot
.09608 .45125 Mdot
.69069 .36749 Mdot
.50763 .5049 Mdot
.33603 .51198 Mdot
.95973 .38547 Mdot
.64319 .4224 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48384 .61118 Mdot
.44856 .59623 Mdot
.33744 .54936 Mdot
.02273 .42353 Mdot
.67404 .40253 Mdot
.5374 .53359 Mdot
.45635 .56794 Mdot
.31065 .52798 Mdot
.94334 .39102 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48364 .6111 Mdot
.44793 .59596 Mdot
.33549 .54854 Mdot
.01793 .42177 Mdot
.67354 .40519 Mdot
.54085 .53603 Mdot
.46876 .57348 Mdot
.3501 .5447 Mdot
.0384 .42539 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48376 .61115 Mdot
.4483 .59612 Mdot
.33666 .54903 Mdot
.0208 .42283 Mdot
.67383 .40359 Mdot
.53877 .53456 Mdot
.46129 .57015 Mdot
.32632 .53462 Mdot
.97955 .40372 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00336 Mdot
.52528 .01072 Mdot
.58038 .03405 Mdot
.75098 .10544 Mdot
.16032 .25298 Mdot
.36783 .12825 Mdot
.3991 .01932 Mdot
.28895 .54996 Mdot
.94718 .40681 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51485 .0063 Mdot
.54727 .02004 Mdot
.64956 .06322 Mdot
.9446 .18234 Mdot
.32107 .23267 Mdot
.48222 .0996 Mdot
.61676 .08315 Mdot
.91116 .18195 Mdot
.332 .26009 Mdot
.50021 9e-05 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52177 .00923 Mdot
.56926 .02935 Mdot
.7174 .09155 Mdot
.09928 .23601 Mdot
.34171 .14983 Mdot
.38396 .02611 Mdot
.26717 .54585 Mdot
.91303 .39917 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52245 .00952 Mdot
.57142 .03027 Mdot
.72397 .09428 Mdot
.11207 .23986 Mdot
.34561 .14434 Mdot
.38222 .02263 Mdot
.25786 .54117 Mdot
.89505 .39381 Mdot
.67851 .4842 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51465 .00621 Mdot
.54666 .01978 Mdot
.64766 .06242 Mdot
.93972 .1805 Mdot
.32005 .23506 Mdot
.4844 .10158 Mdot
.6254 .08714 Mdot
.93563 .19173 Mdot
.3398 .24979 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51299 .00551 Mdot
.54137 .01754 Mdot
.63111 .05546 Mdot
.89601 .16372 Mdot
.30603 .25341 Mdot
.49196 .11491 Mdot
.66585 .10747 Mdot
.04586 .23486 Mdot
.35803 .19293 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51352 .00573 Mdot
.54305 .01825 Mdot
.63638 .05768 Mdot
.91014 .16919 Mdot
.31164 .24814 Mdot
.4921 .11153 Mdot
.66071 .10421 Mdot
.03146 .22914 Mdot
.35533 .20016 Mdot
.50069 .00029 Mdot
.50218 .00093 Mdot
.50696 .00295 Mdot
.52217 .0094 Mdot
.57053 .02989 Mdot
.72127 .09316 Mdot
.10686 .23831 Mdot
.34393 .14652 Mdot
.38266 .02394 Mdot
.2609 .54278 Mdot
.90097 .39558 Mdot
.68018 .48158 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.4875 .61274 Mdot
.46021 .60116 Mdot
.37384 .56466 Mdot
.11745 .45957 Mdot
.70044 .36031 Mdot
.51068 .50076 Mdot
.33694 .51065 Mdot
.95921 .38458 Mdot
.642 .42199 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50556 .00236 Mdot
.51772 .00751 Mdot
.55641 .02391 Mdot
.67794 .07511 Mdot
.01415 .20779 Mdot
.32916 .19469 Mdot
.43438 .06502 Mdot
.44392 .0059 Mdot
.37106 .57301 Mdot
.12528 .46613 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48802 .61295 Mdot
.46185 .60186 Mdot
.37899 .56682 Mdot
.1316 .46514 Mdot
.70855 .35658 Mdot
.51618 .49914 Mdot
.34805 .51412 Mdot
.98507 .3937 Mdot
.64445 .40752 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50791 .00335 Mdot
.5252 .01068 Mdot
.58013 .03395 Mdot
.75023 .10513 Mdot
.15906 .25267 Mdot
.36708 .12857 Mdot
.39812 .01918 Mdot
.28655 .54908 Mdot
.94251 .40541 Mdot
.49799 .61718 Mdot
.49358 .61531 Mdot
.47955 .60936 Mdot
.43492 .59045 Mdot
.29538 .53179 Mdot
.92674 .3902 Mdot
.66415 .45575 Mdot
.6064 .58234 Mdot
.69662 .05576 Mdot
.01228 .19509 Mdot
.30953 .18371 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.5266 .01128 Mdot
.58457 .03583 Mdot
.76351 .11059 Mdot
.18032 .2576 Mdot
.38092 .12398 Mdot
.41909 .02359 Mdot
.34107 .56981 Mdot
.06233 .44577 Mdot
.69247 .38945 Mdot
.49933 .61775 Mdot
.49787 .61713 Mdot
.49321 .61516 Mdot
.47838 .60886 Mdot
.4312 .58888 Mdot
.28402 .52707 Mdot
.90353 .38288 Mdot
.65905 .46693 Mdot
.61537 .59104 Mdot
.72998 .07083 Mdot
.08143 .21721 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48465 .61153 Mdot
.45114 .59732 Mdot
.34549 .55274 Mdot
.0428 .43096 Mdot
.67668 .39176 Mdot
.52441 .52392 Mdot
.4086 .54646 Mdot
.1631 .46631 Mdot
.71358 .34022 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .0012 Mdot
.50905 .00384 Mdot
.52881 .01222 Mdot
.59157 .03878 Mdot
.78421 .11906 Mdot
.2101 .26321 Mdot
.40472 .12028 Mdot
.46479 .03713 Mdot
.47249 .00476 Mdot
.43914 .59742 Mdot
.49876 .61751 Mdot
.49606 .61637 Mdot
.48746 .61272 Mdot
.46007 .6011 Mdot
.37341 .56447 Mdot
.11625 .45911 Mdot
.69982 .36066 Mdot
.51035 .50093 Mdot
.33638 .51052 Mdot
.958 .38418 Mdot
.64189 .42266 Mdot
.49916 .61768 Mdot
.49734 .6169 Mdot
.49151 .61444 Mdot
.47297 .60657 Mdot
.41408 .58164 Mdot
.23247 .50579 Mdot
.81357 .35914 Mdot
.61462 .49507 Mdot
.5731 .59238 Mdot
.63743 .03976 Mdot
.88323 .15191 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52636 .01118 Mdot
.58381 .0355 Mdot
.76124 .10966 Mdot
.1768 .25683 Mdot
.37844 .12462 Mdot
.41497 .02257 Mdot
.32992 .56547 Mdot
.03561 .43614 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48618 .61218 Mdot
.456 .59938 Mdot
.36067 .55911 Mdot
.08203 .44583 Mdot
.68572 .3731 Mdot
.50894 .50878 Mdot
.34555 .51706 Mdot
.98519 .39532 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47696 .60826 Mdot
.4267 .58697 Mdot
.27034 .5214 Mdot
.87719 .37506 Mdot
.65051 .47794 Mdot
.61743 .59758 Mdot
.74493 .0788 Mdot
.11104 .22627 Mdot
.32378 .13148 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61006 Mdot
.44018 .59268 Mdot
.31154 .53853 Mdot
.96178 .40187 Mdot
.6688 .43696 Mdot
.58416 .56572 Mdot
.61995 .02212 Mdot
.8191 .12308 Mdot
.23484 .25694 Mdot
.49979 .61794 Mdot
.49932 .61775 Mdot
.49785 .61712 Mdot
.49314 .61512 Mdot
.47814 .60876 Mdot
.43045 .58856 Mdot
.28171 .52611 Mdot
.89897 .38149 Mdot
.6578 .46898 Mdot
.61641 .59245 Mdot
.73447 .07296 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.5144 .0061 Mdot
.54584 .01943 Mdot
.6451 .06134 Mdot
.93308 .17798 Mdot
.31851 .23821 Mdot
.48699 .10413 Mdot
.63597 .09208 Mdot
.965 .20335 Mdot
.3461 .23554 Mdot
.49889 .61757 Mdot
.49648 .61654 Mdot
.48877 .61327 Mdot
.46425 .60288 Mdot
.38654 .57001 Mdot
.15271 .47351 Mdot
.72337 .35269 Mdot
.52944 .49818 Mdot
.37941 .52531 Mdot
.06531 .42391 Mdot
.65597 .36505 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50331 .0014 Mdot
.51055 .00447 Mdot
.53359 .01424 Mdot
.60666 .04516 Mdot
.82801 .1368 Mdot
.25998 .26697 Mdot
.45369 .11972 Mdot
.57891 .07739 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.5209 .00886 Mdot
.56651 .02819 Mdot
.709 .08806 Mdot
.08235 .23074 Mdot
.33761 .15776 Mdot
.38941 .03201 Mdot
.28835 .55558 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50829 .00352 Mdot
.52641 .0112 Mdot
.58395 .03556 Mdot
.76165 .10983 Mdot
.17745 .25698 Mdot
.37889 .1245 Mdot
.4157 .02275 Mdot
.3319 .56624 Mdot
.04028 .4378 Mdot
.68888 .40086 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50781 .00331 Mdot
.52488 .01055 Mdot
.57912 .03352 Mdot
.74722 .10389 Mdot
.15401 .25141 Mdot
.36419 .1299 Mdot
.39449 .01873 Mdot
.27788 .54596 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51419 .00602 Mdot
.54517 .01915 Mdot
.64301 .06047 Mdot
.92765 .17592 Mdot
.31711 .2407 Mdot
.48875 .10608 Mdot
.64353 .09566 Mdot
.98559 .21141 Mdot
.34923 .22474 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50655 .00278 Mdot
.52088 .00885 Mdot
.56643 .02815 Mdot
.70875 .08796 Mdot
.08184 .23058 Mdot
.3375 .15801 Mdot
.38962 .03221 Mdot
.28913 .55593 Mdot
.95708 .41282 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51224 .00519 Mdot
.53897 .01652 Mdot
.62357 .05229 Mdot
.87547 .15568 Mdot
.29567 .2597 Mdot
.48691 .11819 Mdot
.65854 .10607 Mdot
.03055 .22992 Mdot
.35702 .20177 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.5114 .00483 Mdot
.5363 .01539 Mdot
.61519 .04875 Mdot
.85216 .14646 Mdot
.28035 .26464 Mdot
.47413 .11977 Mdot
.62928 .09589 Mdot
.95772 .20299 Mdot
.34884 .24172 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49492 .61588 Mdot
.48381 .61117 Mdot
.44846 .59619 Mdot
.33715 .54924 Mdot
.02201 .42327 Mdot
.67396 .40293 Mdot
.53791 .53395 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52531 .01073 Mdot
.58047 .03409 Mdot
.75127 .10556 Mdot
.16079 .2531 Mdot
.36811 .12813 Mdot
.39947 .01938 Mdot
.28987 .5503 Mdot
.94898 .40736 Mdot
.68332 .45385 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51919 .00814 Mdot
.56106 .02588 Mdot
.69229 .0811 Mdot
.04672 .21905 Mdot
.33208 .17636 Mdot
.40975 .048 Mdot
.35918 .58678 Mdot
.12389 .47262 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.5036 .00153 Mdot
.51146 .00486 Mdot
.5365 .01547 Mdot
.6158 .04901 Mdot
.85388 .14714 Mdot
.28162 .26436 Mdot
.47532 .11972 Mdot
.63216 .09693 Mdot
.96522 .20584 Mdot
.35004 .23783 Mdot
.49799 .61718 Mdot
.4936 .61532 Mdot
.47962 .60939 Mdot
.43515 .59055 Mdot
.29608 .53208 Mdot
.92822 .39068 Mdot
.66441 .45499 Mdot
.60565 .58171 Mdot
.69396 .05458 Mdot
.00637 .19308 Mdot
.30922 .18718 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51399 .00593 Mdot
.54454 .01888 Mdot
.64105 .05964 Mdot
.92249 .17394 Mdot
.31566 .24299 Mdot
.49012 .10782 Mdot
.64977 .09867 Mdot
.00236 .21791 Mdot
.35141 .21572 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57519 .03186 Mdot
.73539 .09901 Mdot
.13331 .24593 Mdot
.35384 .1363 Mdot
.38468 .01906 Mdot
.25728 .5393 Mdot
.89139 .39191 Mdot
.67607 .48495 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49733 .6169 Mdot
.49149 .61443 Mdot
.4729 .60654 Mdot
.41385 .58154 Mdot
.2318 .50552 Mdot
.81258 .35894 Mdot
.61387 .49522 Mdot
.57176 .59201 Mdot
.63369 .03827 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50464 .00197 Mdot
.51477 .00626 Mdot
.54703 .01994 Mdot
.64882 .06291 Mdot
.94271 .18163 Mdot
.32069 .2336 Mdot
.48309 .10037 Mdot
.62019 .08473 Mdot
.92092 .18586 Mdot
.33545 .25619 Mdot
.49794 .61716 Mdot
.49342 .61525 Mdot
.47905 .60915 Mdot
.43333 .58978 Mdot
.29052 .52977 Mdot
.91668 .38698 Mdot
.66218 .46075 Mdot
.61099 .5864 Mdot
.71312 .06312 Mdot
.04761 .20672 Mdot
.31174 .16324 Mdot
.50004 2e-05 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50418 .00177 Mdot
.51333 .00565 Mdot
.54245 .01799 Mdot
.63448 .05688 Mdot
.90507 .16723 Mdot
.30976 .25011 Mdot
.49235 .11285 Mdot
.66348 .10576 Mdot
.49938 .61777 Mdot
.49803 .6172 Mdot
.49371 .61537 Mdot
.47996 .60954 Mdot
.43622 .591 Mdot
.29935 .53345 Mdot
.93514 .39294 Mdot
.66555 .45142 Mdot
.60186 .57867 Mdot
.68073 .04875 Mdot
.97608 .18254 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52198 .00932 Mdot
.56993 .02963 Mdot
.71942 .09239 Mdot
.10326 .23722 Mdot
.34285 .14807 Mdot
.38318 .02493 Mdot
.26361 .54414 Mdot
.90619 .39713 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50787 .00334 Mdot
.52506 .01063 Mdot
.5797 .03377 Mdot
.74896 .10461 Mdot
.15695 .25215 Mdot
.36585 .12911 Mdot
.39654 .01896 Mdot
.28273 .54769 Mdot
.93521 .40326 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .00181 Mdot
.51358 .00576 Mdot
.54326 .01834 Mdot
.63702 .05795 Mdot
.91184 .16985 Mdot
.31224 .24746 Mdot
.49194 .11106 Mdot
.65955 .10359 Mdot
.02836 .22794 Mdot
.35486 .20179 Mdot
.49786 .61713 Mdot
.49318 .61514 Mdot
.47827 .60882 Mdot
.43086 .58873 Mdot
.28298 .52664 Mdot
.90147 .38225 Mdot
.65849 .46787 Mdot
.61587 .59169 Mdot
.7321 .07183 Mdot
.08555 .21845 Mdot
.31677 .1429 Mdot
.49795 .61716 Mdot
.49347 .61526 Mdot
.47919 .60921 Mdot
.4338 .58998 Mdot
.29194 .53036 Mdot
.9196 .38791 Mdot
.66279 .45932 Mdot
.60976 .58526 Mdot
.70864 .06111 Mdot
.03823 .2037 Mdot
.31103 .1686 Mdot
.49795 .61716 Mdot
.49345 .61526 Mdot
.47914 .60919 Mdot
.43363 .58991 Mdot
.29144 .53015 Mdot
.91856 .38758 Mdot
.66258 .45983 Mdot
.61021 .58567 Mdot
.71026 .06183 Mdot
.04164 .2048 Mdot
.31127 .16664 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50434 .00184 Mdot
.51384 .00587 Mdot
.54408 .01869 Mdot
.63959 .05903 Mdot
.91866 .17247 Mdot
.31449 .24464 Mdot
.49094 .10905 Mdot
.65379 .10065 Mdot
.01306 .22204 Mdot
.35277 .20995 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50791 .00335 Mdot
.5252 .01068 Mdot
.58013 .03395 Mdot
.75024 .10513 Mdot
.15908 .25268 Mdot
.3671 .12856 Mdot
.39813 .01918 Mdot
.28658 .54909 Mdot
.49918 .61769 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47347 .60679 Mdot
.41567 .58231 Mdot
.23721 .50774 Mdot
.82079 .36067 Mdot
.61988 .49386 Mdot
.58224 .59478 Mdot
.66256 .04964 Mdot
.94648 .17547 Mdot
.49993 .618 Mdot
.49977 .61793 Mdot
.49926 .61772 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47592 .60783 Mdot
.42343 .58559 Mdot
.26046 .51731 Mdot
.85927 .37009 Mdot
.64272 .4842 Mdot
.6127 .59948 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.42032 .58427 Mdot
.2511 .51345 Mdot
.84316 .36591 Mdot
.63421 .48889 Mdot
.60354 .59908 Mdot
.71746 .07041 Mdot
.06514 .21488 Mdot
.31781 .15616 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51775 .00753 Mdot
.5565 .02395 Mdot
.67825 .07524 Mdot
.01486 .20804 Mdot
.32922 .19428 Mdot
.43381 .06464 Mdot
.44195 .00503 Mdot
.36494 .57044 Mdot
.1088 .45973 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50591 .00251 Mdot
.51884 .00799 Mdot
.55996 .02541 Mdot
.68892 .0797 Mdot
.03924 .21651 Mdot
.3313 .1805 Mdot
.41509 .05179 Mdot
.37749 .59479 Mdot
.17375 .49211 Mdot
.75815 .36118 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50622 .00264 Mdot
.5198 .0084 Mdot
.56301 .0267 Mdot
.69828 .0836 Mdot
.05979 .22342 Mdot
.33371 .16929 Mdot
.40116 .04169 Mdot
.49956 .61785 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48593 .61207 Mdot
.4552 .59904 Mdot
.35816 .55806 Mdot
.07543 .4433 Mdot
.68374 .37596 Mdot
.51039 .5109 Mdot
.35263 .52053 Mdot
.00407 .40261 Mdot
.49799 .61718 Mdot
.4936 .61532 Mdot
.47963 .6094 Mdot
.43517 .59056 Mdot
.29615 .53211 Mdot
.92835 .39072 Mdot
.66444 .45493 Mdot
.60558 .58166 Mdot
.69372 .05448 Mdot
.00583 .19289 Mdot
.30919 .18749 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51256 .00532 Mdot
.53998 .01695 Mdot
.62675 .05363 Mdot
.88419 .1591 Mdot
.30041 .25724 Mdot
.48977 .11703 Mdot
.6638 .10756 Mdot
.04241 .23399 Mdot
.35815 .19514 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50417 .00177 Mdot
.51329 .00564 Mdot
.54232 .01794 Mdot
.6341 .05672 Mdot
.90405 .16684 Mdot
.30937 .2505 Mdot
.49237 .1131 Mdot
.66392 .10602 Mdot
.04012 .23251 Mdot
.35678 .1957 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.49861 .61744 Mdot
.49556 .61615 Mdot
.48587 .61204 Mdot
.455 .59896 Mdot
.35753 .55779 Mdot
.07376 .44266 Mdot
.68327 .3767 Mdot
.51084 .51147 Mdot
.35466 .52151 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50896 .0038 Mdot
.52855 .01211 Mdot
.59074 .03844 Mdot
.78179 .11807 Mdot
.20682 .26269 Mdot
.40186 .12054 Mdot
.45883 .03521 Mdot
.45473 .6155 Mdot
.38363 .57409 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52445 .01037 Mdot
.57775 .03294 Mdot
.74308 .10218 Mdot
.14693 .24959 Mdot
.36038 .13192 Mdot
.39024 .01846 Mdot
.26822 .54262 Mdot
.90902 .39604 Mdot
.67898 .47586 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00321 Mdot
.52414 .01024 Mdot
.57677 .03253 Mdot
.74014 .10097 Mdot
.14178 .24823 Mdot
.35778 .1335 Mdot
.38775 .01852 Mdot
.26294 .5409 Mdot
.90019 .39384 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50752 .00319 Mdot
.52396 .01016 Mdot
.5762 .03229 Mdot
.73843 .10026 Mdot
.13876 .24742 Mdot
.35633 .13447 Mdot
.38651 .01865 Mdot
.26051 .54016 Mdot
.89629 .39294 Mdot
.67686 .48242 Mdot
.49888 .61756 Mdot
.49642 .61651 Mdot
.48859 .61319 Mdot
.46365 .60262 Mdot
.38466 .56922 Mdot
.14741 .47141 Mdot
.71933 .35347 Mdot
.52557 .49828 Mdot
.36999 .52188 Mdot
.04037 .41432 Mdot
.65084 .37729 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49088 .61417 Mdot
.47096 .60572 Mdot
.40772 .57895 Mdot
.21367 .49811 Mdot
.78709 .35439 Mdot
.59278 .49795 Mdot
.5299 .57917 Mdot
.51162 .60673 Mdot
.51074 .61749 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52637 .01118 Mdot
.58384 .03552 Mdot
.76134 .1097 Mdot
.17697 .25687 Mdot
.37856 .12459 Mdot
.41516 .02262 Mdot
.33043 .56567 Mdot
.03682 .43657 Mdot
.68847 .40274 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48371 .61113 Mdot
.44814 .59605 Mdot
.33616 .54882 Mdot
.01958 .42238 Mdot
.6737 .40427 Mdot
.53965 .53518 Mdot
.46446 .57156 Mdot
.3364 .53889 Mdot
.00393 .41256 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48365 .6111 Mdot
.44796 .59597 Mdot
.33559 .54859 Mdot
.01818 .42187 Mdot
.67356 .40505 Mdot
.54066 .5359 Mdot
.4681 .57319 Mdot
.348 .54381 Mdot
.033 .42336 Mdot
.49852 .61741 Mdot
.4953 .61604 Mdot
.48502 .61168 Mdot
.45231 .59782 Mdot
.34914 .55427 Mdot
.05208 .43444 Mdot
.67828 .38702 Mdot
.51939 .51983 Mdot
.38952 .53777 Mdot
.10691 .44337 Mdot
.67573 .35155 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52057 .00872 Mdot
.56544 .02773 Mdot
.70574 .08671 Mdot
.07559 .22858 Mdot
.33627 .16111 Mdot
.39245 .03472 Mdot
.29929 .56046 Mdot
.97877 .41994 Mdot
.69 .43956 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49654 .61656 Mdot
.48896 .61335 Mdot
.46484 .60313 Mdot
.38842 .5708 Mdot
.15801 .47563 Mdot
.72764 .35205 Mdot
.53366 .49815 Mdot
.38979 .52912 Mdot
.09349 .43491 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00332 Mdot
.52497 .01059 Mdot
.5794 .03364 Mdot
.74805 .10423 Mdot
.15542 .25177 Mdot
.36498 .12952 Mdot
.39545 .01883 Mdot
.28014 .54677 Mdot
.93036 .40186 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52002 .00849 Mdot
.56369 .02699 Mdot
.70038 .08448 Mdot
.0643 .22491 Mdot
.33437 .16691 Mdot
.39847 .03962 Mdot
.3204 .56978 Mdot
.02658 .43644 Mdot
.69307 .41192 Mdot
.49947 .61781 Mdot
.49832 .61732 Mdot
.49464 .61576 Mdot
.48294 .6108 Mdot
.44569 .59501 Mdot
.32854 .54563 Mdot
.00115 .4157 Mdot
.67203 .41463 Mdot
.55357 .54482 Mdot
.51394 .59354 Mdot
.4952 .60645 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48384 .61118 Mdot
.44857 .59623 Mdot
.33748 .54938 Mdot
.02283 .42357 Mdot
.67405 .40248 Mdot
.53733 .53354 Mdot
.4561 .56783 Mdot
.30985 .52765 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50526 .00223 Mdot
.51675 .0071 Mdot
.55333 .02261 Mdot
.66841 .07113 Mdot
.99154 .1997 Mdot
.32735 .20754 Mdot
.45207 .07708 Mdot
.50599 .03332 Mdot
.56889 .03887 Mdot
.73193 .10076 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47451 .60723 Mdot
.41895 .5837 Mdot
.24702 .51177 Mdot
.83639 .36425 Mdot
.63018 .49059 Mdot
.59818 .59826 Mdot
.70429 .06558 Mdot
.03935 .20708 Mdot
.31599 .17097 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.5065 .00276 Mdot
.5207 .00878 Mdot
.56586 .02791 Mdot
.70702 .08724 Mdot
.07826 .22944 Mdot
.33678 .15978 Mdot
.39119 .03363 Mdot
.29481 .55847 Mdot
.9691 .41673 Mdot
.68945 .4452 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52601 .01103 Mdot
.58269 .03503 Mdot
.75791 .10829 Mdot
.17156 .25565 Mdot
.37489 .12567 Mdot
.40931 .02127 Mdot
.31492 .5597 Mdot
.00139 .42426 Mdot
.68577 .42297 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50328 .00139 Mdot
.51046 .00444 Mdot
.53332 .01413 Mdot
.60578 .04479 Mdot
.82549 .13579 Mdot
.25758 .26704 Mdot
.4512 .11967 Mdot
.57277 .07513 Mdot
.79974 .14027 Mdot
.25388 .28067 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48862 .61321 Mdot
.46376 .60267 Mdot
.385 .56936 Mdot
.14837 .47179 Mdot
.72004 .35332 Mdot
.52624 .49826 Mdot
.37161 .52247 Mdot
.04462 .41594 Mdot
.65157 .37512 Mdot
.4981 .61723 Mdot
.49396 .61547 Mdot
.48074 .60987 Mdot
.43871 .59206 Mdot
.30701 .53664 Mdot
.95174 .39846 Mdot
.66775 .44252 Mdot
.59132 .5708 Mdot
.64447 .03285 Mdot
.88577 .14913 Mdot
.28408 .24617 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52384 .01011 Mdot
.57582 .03213 Mdot
.73729 .09979 Mdot
.13673 .24687 Mdot
.35539 .13514 Mdot
.38577 .01877 Mdot
.49752 .61698 Mdot
.4921 .61468 Mdot
.47483 .60736 Mdot
.41997 .58413 Mdot
.25006 .51302 Mdot
.84141 .36548 Mdot
.63319 .48935 Mdot
.60225 .59891 Mdot
.71433 .06927 Mdot
.05918 .21313 Mdot
.31729 .15952 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49084 .61415 Mdot
.47082 .60566 Mdot
.40726 .57875 Mdot
.21233 .49756 Mdot
.78533 .35413 Mdot
.5912 .49806 Mdot
.52651 .57805 Mdot
.5014 .60251 Mdot
.47838 .60381 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48275 .61072 Mdot
.44509 .59476 Mdot
.3267 .54486 Mdot
.99677 .41413 Mdot
.67168 .41712 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50344 .00146 Mdot
.51097 .00465 Mdot
.53493 .01481 Mdot
.61088 .04694 Mdot
.84001 .14161 Mdot
.2707 .26618 Mdot
.46468 .11988 Mdot
.60611 .08741 Mdot
.89517 .17865 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50405 .00172 Mdot
.51291 .00547 Mdot
.54111 .01743 Mdot
.63029 .05512 Mdot
.89381 .16286 Mdot
.30505 .25416 Mdot
.4917 .11536 Mdot
.66591 .10767 Mdot
.0463 .23509 Mdot
.35821 .19277 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50836 .00354 Mdot
.52662 .01129 Mdot
.58462 .03585 Mdot
.76366 .11065 Mdot
.18055 .25765 Mdot
.38108 .12393 Mdot
.41937 .02367 Mdot
.34183 .57011 Mdot
.06421 .44646 Mdot
.69286 .38853 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.504 .00169 Mdot
.51273 .0054 Mdot
.54055 .01719 Mdot
.62853 .05438 Mdot
.88904 .161 Mdot
.30282 .25573 Mdot
.49932 .61774 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.4779 .60866 Mdot
.4297 .58825 Mdot
.27945 .52518 Mdot
.89455 .38015 Mdot
.6565 .47091 Mdot
.61715 .59372 Mdot
.73809 .07475 Mdot
.0971 .22188 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50825 .0035 Mdot
.52628 .01114 Mdot
.58354 .03539 Mdot
.76043 .10933 Mdot
.17554 .25655 Mdot
.37758 .12486 Mdot
.41355 .02223 Mdot
.32614 .56401 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51493 .00633 Mdot
.54754 .02015 Mdot
.65041 .06358 Mdot
.94678 .18316 Mdot
.3215 .23159 Mdot
.48118 .09869 Mdot
.61269 .08128 Mdot
.89945 .17723 Mdot
.3272 .26437 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50622 .00264 Mdot
.51983 .00841 Mdot
.56309 .02674 Mdot
.69854 .08371 Mdot
.06034 .22361 Mdot
.33379 .169 Mdot
.40082 .04143 Mdot
.32854 .57336 Mdot
.046 .44342 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.50728 .00309 Mdot
.52319 .00983 Mdot
.57377 .03126 Mdot
.73109 .09723 Mdot
.12547 .24373 Mdot
.35053 .1391 Mdot
.38294 .02003 Mdot
.25515 .53906 Mdot
.88876 .39159 Mdot
.67597 .48652 Mdot
.50066 .00028 Mdot
.50211 .00089 Mdot
.50672 .00285 Mdot
.52142 .00908 Mdot
.56814 .02888 Mdot
.71398 .09013 Mdot
.09246 .23391 Mdot
.33992 .15294 Mdot
.38576 .02833 Mdot
.27456 .54931 Mdot
.92748 .40352 Mdot
.68545 .46845 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50677 .00287 Mdot
.52158 .00915 Mdot
.56866 .0291 Mdot
.71556 .09079 Mdot
.09563 .23489 Mdot
.34073 .15148 Mdot
.38485 .02727 Mdot
.27093 .54763 Mdot
.92033 .40135 Mdot
.68431 .47216 Mdot
.49851 .6174 Mdot
.49526 .61603 Mdot
.48491 .61164 Mdot
.45196 .59767 Mdot
.34803 .5538 Mdot
.04924 .43337 Mdot
.67776 .38845 Mdot
.52085 .52106 Mdot
.39513 .54033 Mdot
.12323 .44999 Mdot
.68441 .34683 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.50509 .00216 Mdot
.51623 .00688 Mdot
.55167 .0219 Mdot
.66327 .06897 Mdot
.97901 .19514 Mdot
.32615 .21454 Mdot
.46136 .08356 Mdot
.53917 .04809 Mdot
.49783 .61711 Mdot
.49309 .61511 Mdot
.478 .60871 Mdot
.43001 .58837 Mdot
.28039 .52556 Mdot
.89637 .3807 Mdot
.65704 .47012 Mdot
.61688 .59321 Mdot
.73669 .07405 Mdot
.0944 .22108 Mdot
.31867 .13861 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50641 .00272 Mdot
.52041 .00865 Mdot
.56493 .02752 Mdot
.70417 .08606 Mdot
.07232 .22753 Mdot
.33568 .16277 Mdot
.39408 .03609 Mdot
.30507 .56302 Mdot
.99147 .42422 Mdot
.69066 .43213 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49088 .61417 Mdot
.47094 .60571 Mdot
.40766 .57892 Mdot
.21351 .49804 Mdot
.78687 .35436 Mdot
.59259 .49796 Mdot
.52949 .57903 Mdot
.51036 .60621 Mdot
.50676 .61581 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00305 Mdot
.52288 .0097 Mdot
.57277 .03084 Mdot
.72807 .09598 Mdot
.11983 .24212 Mdot
.34835 .14124 Mdot
.3823 .02098 Mdot
.25536 .53958 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.49421 .61558 Mdot
.48154 .61021 Mdot
.44125 .59313 Mdot
.31481 .53989 Mdot
.96916 .40441 Mdot
.66948 .43282 Mdot
.57863 .56188 Mdot
.60099 .01382 Mdot
.76486 .10128 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50512 .00217 Mdot
.51631 .00692 Mdot
.55192 .02201 Mdot
.66403 .06929 Mdot
.98088 .19582 Mdot
.32634 .21351 Mdot
.46002 .08262 Mdot
.53435 .04594 Mdot
.65982 .07754 Mdot
.49837 .61734 Mdot
.49481 .61583 Mdot
.48347 .61102 Mdot
.44737 .59573 Mdot
.33377 .54782 Mdot
.01374 .42025 Mdot
.67313 .40752 Mdot
.54394 .53819 Mdot
.47982 .57841 Mdot
.38552 .55975 Mdot
.13392 .46254 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47485 .60737 Mdot
.42003 .58415 Mdot
.25025 .5131 Mdot
.84174 .36556 Mdot
.63338 .48926 Mdot
.60249 .59894 Mdot
.71493 .06949 Mdot
.06032 .21347 Mdot
.31739 .15887 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47677 .60819 Mdot
.42613 .58673 Mdot
.2686 .52068 Mdot
.87397 .37414 Mdot
.64924 .47914 Mdot
.61697 .59809 Mdot
.74479 .079 Mdot
.11121 .22646 Mdot
.49878 .61752 Mdot
.49611 .61639 Mdot
.48761 .61278 Mdot
.46055 .60131 Mdot
.37492 .56511 Mdot
.12039 .46073 Mdot
.70201 .35946 Mdot
.5116 .50035 Mdot
.33856 .51109 Mdot
.96281 .38581 Mdot
.64234 .41997 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50323 .00137 Mdot
.5103 .00437 Mdot
.53282 .01391 Mdot
.60421 .04412 Mdot
.82099 .13398 Mdot
.25314 .26709 Mdot
.44661 .11957 Mdot
.56149 .071 Mdot
.76632 .12659 Mdot
.20862 .27336 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48045 .60975 Mdot
.43779 .59167 Mdot
.30418 .53546 Mdot
.94555 .39638 Mdot
.667 .44589 Mdot
.59546 .57382 Mdot
.65868 .03907 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50647 .00274 Mdot
.52061 .00874 Mdot
.56557 .02779 Mdot
.70613 .08687 Mdot
.0764 .22884 Mdot
.33643 .1607 Mdot
.39206 .03438 Mdot
.29791 .55985 Mdot
.97576 .41894 Mdot
.49878 .61752 Mdot
.49613 .61639 Mdot
.48766 .6128 Mdot
.46069 .60137 Mdot
.37537 .5653 Mdot
.12163 .46121 Mdot
.70269 .35912 Mdot
.51202 .50019 Mdot
.33935 .51132 Mdot
.9646 .38643 Mdot
.64251 .41897 Mdot
.49838 .61735 Mdot
.49482 .61584 Mdot
.48351 .61104 Mdot
.44751 .59578 Mdot
.3342 .548 Mdot
.01479 .42063 Mdot
.67323 .40694 Mdot
.54316 .53764 Mdot
.47703 .57716 Mdot
.37656 .55594 Mdot
.10894 .45264 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47834 .60885 Mdot
.4311 .58884 Mdot
.28371 .52694 Mdot
.90293 .3827 Mdot
.65889 .46721 Mdot
.61552 .59123 Mdot
.73061 .07113 Mdot
.08267 .21758 Mdot
.31622 .14434 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.42752 .58732 Mdot
.27282 .52242 Mdot
.88184 .37639 Mdot
.65226 .47615 Mdot
.61779 .59673 Mdot
.74432 .0782 Mdot
.10943 .22565 Mdot
.32302 .13201 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49807 .61721 Mdot
.49385 .61542 Mdot
.48039 .60972 Mdot
.4376 .59159 Mdot
.3036 .53521 Mdot
.94427 .39596 Mdot
.66684 .44657 Mdot
.59629 .57443 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51261 .00535 Mdot
.54015 .01702 Mdot
.62727 .05384 Mdot
.88559 .15965 Mdot
.30112 .25681 Mdot
.49013 .11681 Mdot
.66436 .10767 Mdot
.04357 .23437 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.44212 .5935 Mdot
.3175 .54102 Mdot
.97531 .40655 Mdot
.67 .42934 Mdot
.5739 .55864 Mdot
.5847 .00668 Mdot
.71665 .08155 Mdot
.08211 .22586 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48246 .6106 Mdot
.44417 .59437 Mdot
.32385 .54367 Mdot
.99004 .41173 Mdot
.67116 .42096 Mdot
.56231 .55076 Mdot
.54457 .60707 Mdot
.59282 .02982 Mdot
.77254 .11107 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51427 .00605 Mdot
.54544 .01926 Mdot
.64385 .06082 Mdot
.92982 .17674 Mdot
.31769 .23971 Mdot
.48809 .10531 Mdot
.64063 .09428 Mdot
.97772 .20833 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47572 .60774 Mdot
.42278 .58532 Mdot
.25851 .51651 Mdot
.85584 .36917 Mdot
.64104 .48528 Mdot
.61116 .59957 Mdot
.7348 .07641 Mdot
.09608 .22328 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50688 .00292 Mdot
.52193 .0093 Mdot
.56976 .02956 Mdot
.71892 .09218 Mdot
.10227 .23692 Mdot
.34256 .14851 Mdot
.38336 .02522 Mdot
.26444 .54454 Mdot
.90778 .3976 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.4778 .60862 Mdot
.42937 .5881 Mdot
.27843 .52475 Mdot
.89257 .37956 Mdot
.65589 .47176 Mdot
.6174 .59425 Mdot
.73948 .07545 Mdot
.09978 .22267 Mdot
.32002 .13612 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51074 .00455 Mdot
.53421 .0145 Mdot
.60859 .04597 Mdot
.83351 .13901 Mdot
.26505 .2667 Mdot
.45892 .11982 Mdot
.59185 .08216 Mdot
.85504 .16266 Mdot
.30682 .27922 Mdot
.49752 .61698 Mdot
.4921 .61468 Mdot
.47484 .60736 Mdot
.41998 .58413 Mdot
.2501 .51304 Mdot
.84149 .3655 Mdot
.63324 .48933 Mdot
.6023 .59892 Mdot
.71447 .06932 Mdot
.05944 .2132 Mdot
.31731 .15937 Mdot
.49783 .61711 Mdot
.49308 .6151 Mdot
.47796 .60869 Mdot
.42989 .58833 Mdot
.28004 .52542 Mdot
.89568 .38049 Mdot
.65684 .47042 Mdot
.61699 .5934 Mdot
.73723 .07432 Mdot
.09544 .22139 Mdot
.31892 .13811 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00137 Mdot
.51026 .00435 Mdot
.53267 .01385 Mdot
.60375 .04393 Mdot
.81966 .13344 Mdot
.2518 .26708 Mdot
.44522 .11954 Mdot
.55808 .06975 Mdot
.75614 .12241 Mdot
.19276 .26984 Mdot
.49793 .61715 Mdot
.49339 .61523 Mdot
.47896 .60911 Mdot
.43304 .58966 Mdot
.28962 .5294 Mdot
.91484 .3864 Mdot
.66178 .46164 Mdot
.61172 .58709 Mdot
.71582 .06433 Mdot
.05316 .20849 Mdot
.31224 .16012 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51803 .00765 Mdot
.55739 .02433 Mdot
.68099 .07639 Mdot
.02123 .21028 Mdot
.32972 .19065 Mdot
.4288 .06123 Mdot
.42459 .61544 Mdot
.31147 .54812 Mdot
.9772 .41144 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47645 .60805 Mdot
.42509 .58629 Mdot
.26546 .51938 Mdot
.86823 .37253 Mdot
.64683 .4812 Mdot
.61575 .59882 Mdot
.74337 .07888 Mdot
.10952 .22629 Mdot
.32405 .13259 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49088 .61417 Mdot
.47095 .60572 Mdot
.40768 .57893 Mdot
.21356 .49806 Mdot
.78694 .35437 Mdot
.59266 .49796 Mdot
.52963 .57908 Mdot
.51079 .60639 Mdot
.50813 .61639 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50565 .0024 Mdot
.51801 .00764 Mdot
.55732 .02429 Mdot
.68076 .07629 Mdot
.02069 .21009 Mdot
.32967 .19096 Mdot
.42922 .06152 Mdot
.42607 .61609 Mdot
.31597 .54999 Mdot
.98736 .41494 Mdot
.49813 .61724 Mdot
.49406 .61551 Mdot
.48106 .61 Mdot
.43973 .59249 Mdot
.31014 .53794 Mdot
.95865 .40081 Mdot
.66849 .43871 Mdot
.58644 .56732 Mdot
.62776 .02554 Mdot
.8408 .13166 Mdot
.25476 .25584 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51605 .00681 Mdot
.5511 .02166 Mdot
.66149 .06823 Mdot
.97465 .19354 Mdot
.32567 .21694 Mdot
.46443 .08576 Mdot
.5503 .05307 Mdot
.71035 .09892 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00147 Mdot
.51108 .0047 Mdot
.53529 .01496 Mdot
.61199 .04741 Mdot
.84317 .14287 Mdot
.27332 .26585 Mdot
.46731 .11989 Mdot
.6126 .08979 Mdot
.91304 .18568 Mdot
.33753 .26235 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50368 .00156 Mdot
.51173 .00498 Mdot
.53737 .01584 Mdot
.61855 .05017 Mdot
.86156 .15019 Mdot
.28702 .26295 Mdot
.48017 .11937 Mdot
.64365 .10104 Mdot
.99453 .21685 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.5076 .00322 Mdot
.52421 .01027 Mdot
.57701 .03263 Mdot
.74086 .10127 Mdot
.14306 .24857 Mdot
.35841 .1331 Mdot
.38832 .01848 Mdot
.26412 .54127 Mdot
.90212 .39431 Mdot
.67786 .47943 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.50911 .00386 Mdot
.52902 .01231 Mdot
.59222 .03906 Mdot
.78615 .11985 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.5072 .00305 Mdot
.52294 .00973 Mdot
.57296 .03092 Mdot
.72864 .09621 Mdot
.12089 .24243 Mdot
.34875 .14083 Mdot
.38238 .02078 Mdot
.25521 .53944 Mdot
.88943 .39197 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47762 .60855 Mdot
.42882 .58787 Mdot
.27676 .52406 Mdot
.88934 .37859 Mdot
.65485 .47312 Mdot
.6177 .59507 Mdot
.74143 .07647 Mdot
.10354 .2238 Mdot
.32107 .13444 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47959 .60938 Mdot
.43505 .59051 Mdot
.29576 .53195 Mdot
.92755 .39046 Mdot
.6643 .45533 Mdot
.60599 .582 Mdot
.69517 .05512 Mdot
.00906 .19399 Mdot
.49917 .61768 Mdot
.49735 .61691 Mdot
.49155 .61445 Mdot
.47307 .60661 Mdot
.41439 .58177 Mdot
.23339 .50617 Mdot
.81496 .35943 Mdot
.61565 .49485 Mdot
.57495 .59288 Mdot
.64256 .04178 Mdot
.89653 .15697 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49807 .61722 Mdot
.49385 .61543 Mdot
.48042 .60973 Mdot
.4377 .59163 Mdot
.30389 .53534 Mdot
.94491 .39617 Mdot
.66692 .44623 Mdot
.59587 .57412 Mdot
.6601 .03969 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48043 .60974 Mdot
.43772 .59164 Mdot
.30396 .53537 Mdot
.94506 .39622 Mdot
.66694 .44615 Mdot
.49749 .61697 Mdot
.49201 .61465 Mdot
.47455 .60724 Mdot
.41908 .58375 Mdot
.24739 .51192 Mdot
.83699 .3644 Mdot
.63055 .49044 Mdot
.5987 .59835 Mdot
.70559 .06606 Mdot
.04197 .2079 Mdot
.31613 .16944 Mdot
.50035 .00015 Mdot
.50112 .00047 Mdot
.50356 .00151 Mdot
.51133 .0048 Mdot
.53609 .0153 Mdot
.61451 .04847 Mdot
.85026 .1457 Mdot
.27892 .26492 Mdot
.47278 .11981 Mdot
.626 .0947 Mdot
.94908 .19968 Mdot
.34725 .24608 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49361 .61532 Mdot
.47964 .6094 Mdot
.4352 .59057 Mdot
.29624 .53215 Mdot
.92855 .39079 Mdot
.66447 .45482 Mdot
.60547 .58157 Mdot
.69335 .05431 Mdot
.005 .19261 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51574 .00667 Mdot
.5501 .02124 Mdot
.65839 .06693 Mdot
.96695 .1907 Mdot
.32473 .22112 Mdot
.4696 .08954 Mdot
.56917 .06153 Mdot
.76924 .12365 Mdot
.20631 .27012 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52638 .01118 Mdot
.58386 .03553 Mdot
.76139 .10972 Mdot
.17704 .25689 Mdot
.37861 .12458 Mdot
.41524 .02264 Mdot
.33065 .56575 Mdot
.03732 .43675 Mdot
.68853 .40247 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.5067 .00284 Mdot
.52135 .00905 Mdot
.56793 .02879 Mdot
.71333 .08986 Mdot
.09115 .23351 Mdot
.3396 .15355 Mdot
.38616 .02878 Mdot
.27616 .55005 Mdot
.93063 .40449 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50314 .00133 Mdot
.51002 .00425 Mdot
.53191 .01353 Mdot
.60136 .04292 Mdot
.81277 .13066 Mdot
.24458 .26688 Mdot
.43781 .11942 Mdot
.54009 .06322 Mdot
.70189 .09999 Mdot
.09159 .24085 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53222 .01366 Mdot
.60234 .04333 Mdot
.8156 .1318 Mdot
.2476 .26699 Mdot
.4409 .11946 Mdot
.54756 .06592 Mdot
.72452 .10936 Mdot
.13715 .25502 Mdot
.4982 .61727 Mdot
.49425 .6156 Mdot
.48168 .61027 Mdot
.4417 .59332 Mdot
.3162 .54047 Mdot
.97233 .40551 Mdot
.66975 .43103 Mdot
.57621 .56022 Mdot
.59265 .01016 Mdot
.74034 .09128 Mdot
.12633 .23855 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51144 .00485 Mdot
.53642 .01544 Mdot
.61556 .04891 Mdot
.8532 .14687 Mdot
.28112 .26447 Mdot
.47486 .11974 Mdot
.63104 .09653 Mdot
.96232 .20474 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47602 .60786 Mdot
.42372 .58571 Mdot
.26134 .51768 Mdot
.86084 .37051 Mdot
.64348 .4837 Mdot
.61334 .59941 Mdot
.7392 .07779 Mdot
.10324 .22499 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51878 .00796 Mdot
.55975 .02533 Mdot
.68828 .07943 Mdot
.0378 .21602 Mdot
.33116 .1813 Mdot
.41615 .05253 Mdot
.38111 .59638 Mdot
.18385 .49612 Mdot
.76819 .36114 Mdot
.49743 .61695 Mdot
.49182 .61457 Mdot
.47396 .60699 Mdot
.4172 .58295 Mdot
.24176 .50961 Mdot
.82791 .36226 Mdot
.62475 .49248 Mdot
.59015 .59665 Mdot
.68365 .05779 Mdot
.99543 .19269 Mdot
.31407 .19693 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50792 .00336 Mdot
.52522 .01069 Mdot
.58018 .03397 Mdot
.75039 .1052 Mdot
.15933 .25274 Mdot
.36724 .1285 Mdot
.39832 .01921 Mdot
.28706 .54927 Mdot
.9435 .4057 Mdot
.68292 .45699 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50806 .00342 Mdot
.52568 .01089 Mdot
.58164 .03459 Mdot
.75477 .107 Mdot
.16653 .25448 Mdot
.37164 .12677 Mdot
.40441 .02026 Mdot
.30227 .55491 Mdot
.97415 .41525 Mdot
.49886 .61755 Mdot
.49637 .61649 Mdot
.48843 .61313 Mdot
.46314 .6024 Mdot
.38305 .56854 Mdot
.14289 .46961 Mdot
.71606 .35424 Mdot
.52255 .49844 Mdot
.36274 .51927 Mdot
.02163 .40722 Mdot
.64818 .38723 Mdot
.49768 .61705 Mdot
.49259 .61489 Mdot
.4764 .60803 Mdot
.42495 .58624 Mdot
.26506 .51921 Mdot
.8675 .37233 Mdot
.64651 .48146 Mdot
.61555 .5989 Mdot
.74307 .07882 Mdot
.10911 .22622 Mdot
.324 .13281 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48501 .61168 Mdot
.45227 .5978 Mdot
.349 .55421 Mdot
.05171 .4343 Mdot
.67822 .3872 Mdot
.51957 .51999 Mdot
.39022 .53809 Mdot
.49746 .61696 Mdot
.4919 .6146 Mdot
.4742 .60709 Mdot
.41796 .58328 Mdot
.24403 .51054 Mdot
.83154 .3631 Mdot
.62713 .4917 Mdot
.59378 .59742 Mdot
.69308 .06138 Mdot
.01602 .19959 Mdot
.31497 .18476 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48414 .61131 Mdot
.4495 .59663 Mdot
.34037 .55059 Mdot
.02996 .42619 Mdot
.67488 .39858 Mdot
.53243 .52999 Mdot
.43828 .55985 Mdot
.25384 .50405 Mdot
.83075 .35655 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50948 .00402 Mdot
.53019 .0128 Mdot
.59591 .04062 Mdot
.79694 .12425 Mdot
.2264 .26542 Mdot
.41974 .11949 Mdot
.49774 .0482 Mdot
.57235 .04611 Mdot
.75177 .11089 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48031 .60969 Mdot
.43734 .59148 Mdot
.3028 .53488 Mdot
.94254 .39538 Mdot
.66661 .4475 Mdot
.59739 .57525 Mdot
.66529 .04197 Mdot
.93891 .16911 Mdot
.30193 .22436 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002>ooooo`0300000?oooooooooo00Cooooo00D00000
oooooooooooooooo00000004ooooo`8000001?ooool01@00003oooooooooooooool0000000Kooooo
00<00000ooooooooool0K_ooool002KoooooJ?l00003000000Go00000P0000000ol000000000o`00
000<000000;o00000P000004o`0000<00000H_l00003000000Wooooo000Vooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`07ooooo`<000001Oooool3
00000004ooooo`0000000000000000;ooooo1@0000000oooool00000ooooo`02ooooo`8000001Ooo
ool300000003ooooool0003ooooo02kooooo00?o0000ooooooooool0;Oooool00`00003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`1Zooooo`<000001?ooool300000003ooooo`000000
000000L000000_ooool300000004ooooo`0000000000000000Cooooo0`00001Oooooo`0300000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo06cooooo0`000005ooooo`8000000_ooool3
00000003ooooo`000000000000<0000000?ooooo0000000000000oooool3000000?ooooo0`00001M
ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05Wooooo2000000=oooo
o`<000001Oooool300000005ooooo`00003ooooo00000?ooool01P0000001Oooool0000000000000
003ooooo00<000001?ooool3000005[ooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0FOooool00`00003oooooooooo`04ooooo`@000003?ooool3000000Kooooo1P000000
0oooool0000000000008000000;ooooo0P000004ooooo`<00000F?ooool00`00003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`1Iooooo`8000002Oooool4000000_ooooo0`000005oooo
oa4000000_ooool3000000?ooooo0`00001Fooooo`0300000?oooooooooo00Oooooo000Vooooo`;o
0000Foooool2000000_ooooo1000000:ooooo`<000001_ooool200000004ooooo`0000000000oooo
o`H000000_ooool3000000;ooooo0P000003ooooo`<00000Doooool00ol000000000ooooo`08oooo
o`009_ooool00ol0003oooooooooo`1Kooooo`8000003_ooool4000000Sooooo0`000006ooooo`L0
00000_ooool300000004ooooo`0000000000000000?ooooo0`000003ooooo`<00000DOooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Looooo`<000003oooool3000000So
oooo0`000007ooooo`80000000Cooooo00000000003ooooo1@0000001?ooool00000ooooo`000004
ooooo`<000000_ooool3000004oooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0G_ooool20000017ooooo0`000008ooooo`<000001Oooool300000003ooooo`0000000000
0080000000?ooooo0000000000000`0000001?ooool00000000000000003ooooo`8000000_ooool3
000004gooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Goooool20000
01?ooooo0`000007ooooo`<000001_ooool>00000003ooooo`000000000000?ooooo0`0000000ooo
ool0000000000002000004[ooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0H?ooool3000001?ooooo10000006ooooo`<000001oooool200000003ooooo`00000000000080
000000Gooooo0000000000000000ooooo`05000000;ooooo0`000002ooooo`<00000B?ooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Rooooo`8000005Oooool4000000Go
oooo0`000007ooooo`@0000000?ooooo0000000000001@000002ooooo`8000001?ooool300000004
ooooo`0000000000000004Kooooo00<00000ooooooooool01oooool002Kooooo0_l0001Tooooo`<0
00005_ooool4000000Gooooo0`000006ooooo`<0000000?ooooo000000000000200000001?ooool0
0000000000000002ooooo`L00000@oooool00ol000000000ooooo`08ooooo`009_ooool00ol0003o
ooooooooo`1Uooooo`8000006?ooool3000000Gooooo0`00000:ooooo`@0000000?ooooo00000000
00000P0000001?ooool00000000000000004ooooo`<0000000Cooooo0000000000000000@Oooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Vooooo`<000006Oooool30000
00Cooooo0`000007ooooo`<0000000?ooooo0000000000001`0000001?ooool00000000000000003
ooooo`L00000?oooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Xoooo
o`8000006_ooool4000000?ooooo0`000007ooooo`0400000?ooool00000ooooo`P0000000Cooooo
00000000000000001Oooool6000003gooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0JOooool3000001_ooooo10000002ooooo`@000001oooool200000004ooooo`000000
0000ooooo`L0000000?ooooo0000000000001Oooool4000003cooooo00<00000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0Joooool2000001gooooo0`000003ooooo`<000002?ooool6
00000003ooooo`00000000000080000000?ooooo0000000000000`000011ooooo`0300000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo06cooooo0P00000Oooooo`<000000_ooool30000
00Sooooo1@000002ooooo`@0000000?ooooo00000?ooool00`00000oooooo`0300000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo06gooooo0`00000Pooooo`<0000000Cooooo00000000
000000002?ooool300000004ooooo`0000000000ooooo`H0000000Cooooo0000000000000000?Ooo
ool00`00003oooooooooo`07ooooo`009_ooool2o`00073ooooo0P00000Qooooo`L000002?ooool6
00000003ooooo`00003ooooo00T00000>Oooool00ol000000000ooooo`08ooooo`009_ooool00ol0
003oooooooooo`1`ooooo`8000008oooool6000000Wooooo1@000002ooooo`X00000>?ooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1aooooo`8000009Oooool5000000Wo
oooo00<00000ooooooooool00`0000000oooool00000ooooo`0400000004ooooo`00000000000000
03Kooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0L_ooool2000002Ko
oooo1000000<ooooo`D0000000?ooooo0000000000000`000003ooooo`800000<oooool00`00003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1cooooo`0300000?oooooooooo03Gooooo
0P0000001?ooool0000000000?ooool<0000033ooooo00<00000ooooooooool01oooool001?ooooo
0_l00004ooooo`04o`000?ooooooooooooooo`Go00001?ooool00ol0003oooooooooo`1booooo`80
0000>Oooool6000000?ooooo0`0000000oooool00000ooooo`03000002kooooo00<00000oooooooo
ool01oooool001;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo05_ooooo6000000nooooo`@0000000?ooooo0000000000002P00000[oooo
o`0300000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01?ooool2o`0005Sooooo1@00001Gooooo`D0000000?ooooo00000000000010000002oooo
o`800000:?ooool3000000Wooooo000Booooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Dooooo`@00000GOooool500000003ooooo`00003ooooo
00@000000oooool3000002Kooooo00<00000ooooooooool01oooool001;ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0B_ooool2
000000Oooooo0P00001Rooooo`D000000_ooool500000003ooooo`00003ooooo00<000009?ooool0
0`00003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`1:ooooo`8000001Oooool3000006Kooooo1P00
0002ooooo`H0000000Cooooo00000?ooool000008Oooool00`00003oooooooooo`07ooooo`004ooo
ool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo04Wooooo0P000005ooooo`800000J_oo
ool<000000;ooooo1000000Oooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo04Wooooo0P000005ooooo`0300000?oooooooooo06cooooo1@000002ooooo`/000007?ooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`18ooooo`<000001?ooool20000
073ooooo1@000002ooooo`0300000?ooool0000000<0000000?ooooo0000000000000`00000Ioooo
o`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Sooooo0`000003ooooo`80
0000M?ooool400000003ooooo`00003ooooo00D0000000Cooooo00000000003ooooo0P00000Goooo
o`0300000?oooooooooo00Oooooo000Vooooo`;o0000BOooool2000000Cooooo00<00000oooooooo
ool0MOooool500000004ooooo`0000000000ooooo`<000000_ooool00`00003ooooo000000020000
01?ooooo00?o000000000?ooool02?ooool002Kooooo00?o0000ooooooooool0B?ooool2000000Co
oooo00<00000ooooooooool0Moooool6000000;ooooo1P000002ooooo`@000004Oooool00`00003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`18ooooo`8000000oooool2000007cooooo
1@000003ooooo`H0000000?ooooo0000000000000P00000?ooooo`0300000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo04Sooooo0P000003ooooo`0300000?oooooooooo07kooooo0P00
00001?ooool00000ooooooooool200000003ooooo`000000000000<0000000?ooooo000000000000
0P00000<ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Oooooo0`00
0003ooooo`0300000?oooooooooo083ooooo1@000003ooooo`D0000000?ooooo0000000000001000
0009ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Oooooo00<00000
ooooo`0000000oooool00`00003oooooooooo`22ooooo`D000000_ooool200000005ooooo`000000
000000000?ooool01P000007ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo04Oooooo00<00000ooooo`0000000_ooool2000008Oooooo1@000002ooooo`H000000_ooool6
000000?ooooo00<00000ooooooooool01oooool002Kooooo0_l00018ooooo`0300000?ooool00000
00;ooooo00<00000ooooooooool0ROooool5000000;ooooo00<00000ooooo`0000000`0000000ooo
ool000000000000400000003o`000000003ooooo00Sooooo000Vooooo`800000B?ooool00`00003o
oooo00000002ooooo`0300000?oooooooooo08_ooooo1@0000000oooool000000000000600000003
ooooo`000000000000<000002Oooool002Kooooo1@000015ooooo`8000000oooool00`00003ooooo
ooooo`04ooooo`0300000?oooooooooo08Oooooo10000002ooooo`<0000000?ooooo000000000000
0P0000000oooool0000000000009ooooo`009_ooool00ol0003ooooo00000005000004;ooooo0P00
0003ooooo`0300000?oooooooooo00?ooooo0P00002;ooooo`D000000_ooool200000003ooooo`00
0000000000<000002Oooool002Kooooo0P0000000oooool0000000000006000003oooooo0P000003
ooooo`0300000?oooooooooo00?ooooo0P00002>ooooo`D000000oooool01000003ooooo00000000
0009ooooo`009_ooool00`00003ooooo0000000300000003ooooo`000000000000D00000??ooool2
000000?ooooo00<00000ooooooooool00oooool20000093ooooo1@000003ooooo`8000002Oooool0
02Kooooo00?o0000ooooo`0000003P00000hooooo`<000000_ooool2000000Gooooo00<00000oooo
ooooool0Toooool400000003ooooo`00003ooooo00Sooooo000Vooooo`0300000?oooooooooo00;o
oooo00<00000ooooo`0000000`000002ooooo`P00000=?ooool00`00003ooooo00000002ooooo`03
00000?oooooooooo00?ooooo0P00002Gooooo`@000002Oooool002Kooooo10000003ooooo`800000
00?ooooo0000000000000`000003ooooo`H00000<Oooool3000000;ooooo00<00000ooooooooool0
0oooool2000009Wooooo0P000009ooooo`009_ooool00ol0003ooooo00000003000000Cooooo0P00
00000oooool000000000000200000005ooooo`00003ooooo00000?ooool01@00000]ooooo`<00000
0oooool00`00003oooooooooo`03ooooo`800000V_ooool00`00003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`02ooooo`@000001?ooool200000003ooooo`000000000000@0000000Co
oooo00000?oooooooooo0P00000/ooooo`0300000?ooool0000000;ooooo0P000005ooooo`800000
V_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`04ooooo`D000001?oo
ool70000033ooooo0P000004ooooo`0300000?oooooooooo00?ooooo0`00002Jooooo`0300000?oo
oooooooo00Oooooo000Cooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool0
0ol0003oooooooooo`07ooooo`8000001oooool00`00003ooooo0000000500000003ooooo`00003o
oooo02Wooooo00<00000ooooooooool00_ooool2000000Gooooo0P00002Kooooo`0300000?oooooo
oooo00Oooooo000Booooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`/0000000?ooooo00000?ooool08_ooool00`00003oooooooooo`03
ooooo`0300000?oooooooooo00Cooooo0P00002Kooooo`0300000?oooooooooo00Oooooo000Boooo
o`04o`000?ooooooooooo`0000Oooooo1Ol00004ooooo`03o`000?oooooooooo01Gooooo00<00000
ooooo`0000000_ooool500000003ooooo`0000000000008000007Oooool2000000Gooooo0P000005
ooooo`<00000Voooool00`00003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Gooooo0_l0000Kooooo`0400000?ooool00000ooooo`@00000
0_ooool01000003oooooooooo`00000Gooooo`<000001Oooool2000000Gooooo0`00002Jooooo`<0
00002Oooool001;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo01_ooooo10000002ooooo`H000000_ooool00`00003oooooooooo`02000000go
oooo1@000006ooooo`8000001_ooool3000009cooooo00<00000ooooooooool01oooool001;ooooo
00Co0000oooooooooooo00002Oooool2o`0000Gooooo00?o0000ooooooooool07_ooool400000004
ooooo`00003oooooooooo`D000001?ooool7000000;ooooo10000008ooooo`<000001_ooool30000
09gooooo00<00000ooooooooool01oooool001?ooooo0_l0000;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool08oooool2000000;ooooo00<00000ooooooooool01`00000Aooooo`<0
00001oooool4000009gooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
9_ooool01@00003ooooo00000?ooool0000000Gooooo4P000009ooooo`@00000W_ooool00`00003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Yooooo`@0000000Cooooo000000000000
00006?ooool5000009oooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
;Oooool600000004ooooo`00003ooooo000000kooooo100000000oooool000000000002Qooooo`03
00000?oooooooooo00Oooooo000Vooooo`;o0000=?ooool:00000003ooooo`000000000000X00000
X_ooool00ol000000000ooooo`08ooooo`009_ooool00ol0003oooooooooo`0iooooo`@0000000?o
oooo0000000000000`0000001?ooool0000000000000002Vooooo`0300000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo0>gooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0kOooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]oooo
o`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00<00000oooooooo
ool01oooool000Oooooo0ol0000Looooo`03o`000?oooooooooo0>gooooo00<00000ooooooooool0
1oooool000Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3]ooooo`0300000?oo
oooooooo00Oooooo0008ooooo`03o`000?oooooooooo01_ooooo0_l0003]ooooo`03o`000000003o
oooo00Sooooo0008ooooo`;o00007?ooool00ol0003oooooooooo`3]ooooo`0300000?oooooooooo
00Oooooo0007ooooo`;o000000?oooooo`000?l000006_ooool00ol0003oooooooooo`3]ooooo`03
00000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0kOooool00`00003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`3]ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
0:Cooooo1P0000001_ooool0000000000?ooool00000ooooo`<00000>_ooool00`00003ooooooooo
o`07ooooo`009_ooool2o`000:;ooooo2P0000001?ooool00000000000000002ooooo`P00000<ooo
ool00ol000000000ooooo`08ooooo`009_ooool00ol0003oooooooooo`2Oooooo`L000003oooool2
00000003ooooo`000000000000;ooooo0P00000_ooooo`0300000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo09gooooo1@00000Iooooo`@0000000?ooooo000000000000:oooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2Mooooo`@000001ooooolD000000?o
oooo1`00000Wooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo09cooooo
00<00000ooooo`0000001oooool3000001;ooooo1P000002ooooo`<0000000?ooooo000000000000
9?ooool00`00003oooooooooo`07ooooo`004oooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool3o`0000Gooooo00?o0000ooooooooool0Voooool3000000Kooooo0`000008ooooo``000001Ooo
ool6000000;ooooo0`0000000oooool00000ooooo`0Oooooo`0300000?oooooooooo00Oooooo000B
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo09[ooooo0`000006ooooo`8000001_ooool4000000kooooo1P000002ooooo`D00000
00?ooooo0000000000000`00000Mooooo`0300000?oooooooooo00Oooooo000Booooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo09[o
oooo00<00000ooooo`0000001Oooool2000000Gooooo0P00000Hooooo`D0000000?ooooo00000000
00001P0000000oooool00000ooooo`0Iooooo`0300000?oooooooooo00Oooooo000Booooo`04o`00
0?ooooooooooo`0000Oooooo1?l00005ooooo`;o0000V_ooool3000000Gooooo0P000005ooooo`80
00007Oooool200000004ooooo`0000000000ooooo`@0000000?ooooo00000?ooool05oooool30000
00Wooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`2Iooooo`<000001Oooool00`00003oooooooooo`03ooooo`8000009?ooool20000
0003ooooo`000000000000<000000_ooool00`00003oooooooooo`0Cooooo`0300000?oooooooooo
00Oooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2Iooooo`8000001Oooool2000000Cooooo0P00000Xooooo`<0000000?ooooo0000
000000000`0000000oooool00000ooooo`06ooooo`8000002Oooool00`00003oooooooooo`07oooo
o`004oooool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo09Wooooo0P000005ooooo`04
00000?ooooooooooooooo`<00000;_ooool700000004ooooo`00003ooooo000000?ooooo10000006
ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo09Sooooo0`000004oooo
o`8000000_ooool00`00003ooooo0000000/ooooo`<000001?ooool5000000;ooooo00<00000oooo
ooooool00_ooool5000000?ooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0V?ooool2000000Gooooo00@00000oooooooooooooooo0`00000]ooooo`H000000_ooool00`00
003ooooo0000000400000004ooooo`0000000000000000;ooooo100000000oooool00000ooooo`08
ooooo`009_ooool2000009Wooooo0P000005ooooo`0400000?ooooooooooooooo`800000<Oooool6
00000003ooooo`000000000000L0000000Cooooo00000?oooooooooo10000009ooooo`009_ooool5
000009Kooooo0P000005ooooo`0600000?oooooooooo00000?ooool00000=Oooool600000003oooo
o`00003ooooo00@0000000?ooooo0000000000000_ooool00ol000000000ooooo`08ooooo`009_oo
ool00ol0003oooooooooo`04000009Cooooo0P000005ooooo`0600000?oooooooooo00000?ooool0
0000>?ooool600000003ooooo`000000000000P000002Oooool002Kooooo00?o000000000?ooool0
0_ooool50000097ooooo00<00000ooooooooool00oooool2000000;ooooo0`00000kooooo`L00000
00?ooooo00000000000010000009ooooo`009_ooool3000000;ooooo00<00000ooooooooool01000
002>ooooo`8000001Oooool01000003oooooooooooooool2000003oooooo1P0000000oooool00000
ooooo`02000000Wooooo000Vooooo`H000001?ooool5000008_ooooo0P000005ooooo`0400000?oo
ooooooooooooo`800000@_ooool8000000Wooooo000Vooooo`80000000?ooooo0000000000001@00
0003ooooo`@00000ROooool2000000Gooooo00@00000oooooooooooooooo0P000015ooooo`D00000
2Oooool002Kooooo1@000002ooooo`<0000000?ooooo00000?ooool00_ooool5000008gooooo00@0
0000oooooooooooooooo0P000018ooooo`8000002Oooool002Kooooo0_l0000>000000;ooooo0`00
002<ooooo`0300000?oooooooooo00<00000B?ooool00ol000000000ooooo`08ooooo`009_ooool0
0ol0003oooooooooo`02ooooo`d000001?ooool3000008Sooooo00H00000ooooooooool00000oooo
o`000019ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Gooooo1000
00000oooool00000ooooo`04000000;ooooo00<00000ooooo`00000010000024ooooo`8000000_oo
ool00`00003ooooo00000019ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo00Sooooo3@0000000oooool0000000000003000008;ooooo00L00000oooooooooooooooo0000
0?ooool0000004Wooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool02_oo
ool>00000006ooooo`000000000000000?ooool00000Ooooool01000003oooooooooooooool20000
04[ooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool03Oooool300000003
ooooo`000000000000D000000_ooool6000007gooooo00@00000oooooooooooooooo0P00001:oooo
o`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo013ooooo10000002ooooo`L0
000000?ooooo0000000000000`00001iooooo`8000000oooool2000004[ooooo00<00000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool04oooool200000003ooooo`000000000000@00000
00Cooooo00000?oooooooooo1@00001gooooo`0300000?oooooooooo00;ooooo0P00001:ooooo`03
00000?oooooooooo00Oooooo000Vooooo`;o00005_ooool2000000?ooooo1@000002ooooo`030000
0?ooool0000000@00000Loooool2000000Cooooo0P000019ooooo`03o`000000003ooooo00Sooooo
000Vooooo`03o`000?oooooooooo01Sooooo0P000002ooooo`L000000_ooool50000077ooooo00<0
0000ooooooooool00_ooool3000004[ooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool06_ooool600000003ooooo`000000000000T00000K_ooool2000000Cooooo0P00001;
ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo01gooooo2`000002oooo
o`0300000?oooooooooo00800000J_ooool2000000Gooooo0P00001;ooooo`0300000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo01oooooo0P0000000oooool00000ooooo`0700000003
ooooo`000000000000<00000I_ooool3000000Gooooo0`00001;ooooo`0300000?oooooooooo00Oo
oooo000Cooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0003ooooo
ooooo`0Rooooo`T000000_ooool00`00003ooooo00000004000006;ooooo0P000007ooooo`800000
C?ooool00`00003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Tooooo`X000001?ooool200000003
ooooo`000000000005cooooo1000001Fooooo`0300000?oooooooooo00Oooooo000Booooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`;o0000:?ooool30000
0003ooooo`000000000000<000001?ooool4000005Oooooo1@00001Gooooo`<000002Oooool001;o
oooo00Co0000oooooooooooo00002?ooool3o`0000Gooooo00?o0000ooooooooool0:Oooool50000
0003ooooo`00000000000080000000?ooooo00000?ooool01@00000moooooaL00000G_ooool00`00
003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0/ooooo`<0000000?ooooo00000?ooool010000002
ooooo`H00000>Oooool2000007Cooooo00<00000ooooooooool01oooool001;ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0;ooo
ool400000003ooooo`000000000000L0000000?ooooo000000000000=oooool00`00003ooooooooo
o`1cooooo`0300000?oooooooooo00Oooooo000Cooooo`;o00002Oooool3o`0000Gooooo00?o0000
ooooooooool0<Oooool300000003ooooo`000000000000@000000_ooool6000000[ooooo1000000V
ooooo`800000M?ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0doooo
o`X0000000?ooooo0000000000000P00000;ooooo`H000009?ooool2000007?ooooo00<00000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0=_ooool400000003ooooo`000000000000X0
00002Oooool7000002;ooooo0P00001booooo`0300000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo03Sooooo2@000003ooooo`H000002?ooool300000004ooooo`00000000000000027o
oooo0P00001aooooo`0300000?oooooooooo00Oooooo000Vooooo`;o0000??ooool:00000005oooo
o`000000000000000?ooool00P000008ooooo`<0000000?ooooo0000000000000P00000Pooooo`80
0000K_ooool00ol000000000ooooo`08ooooo`009_ooool00ol0003oooooooooo`0oooooo`040000
0?ooool00000ooooo`D0000000?ooooo0000000000000`000009ooooo`8000000_ooool3000001oo
oooo0P00001^ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo043ooooo
0`0000000oooool0000000000003000000;ooooo1@000009ooooo`<000000_ooool3000001gooooo
0`00001/ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo03[ooooo1000
0005ooooo`80000000?ooooo0000000000000`000003ooooo`H000001oooool3000000?ooooo0`00
000Looooo`800000Joooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0k
ooooo`H000001?ooool300000003ooooo`000000000000@000000_ooool200000003ooooo`000000
000000Oooooo0`000003ooooo`@000006_ooool3000006Wooooo00<00000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool0?Oooool7000000?ooooo100000000oooool00000000000030000
0005ooooo`000000000000000?ooool00P000007ooooo`<000001?ooool3000001[ooooo0P00001X
ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo043ooooo1P000004oooo
oa4000001_ooool3000000Gooooo0`00000Hooooo`800000Ioooool00`00003oooooooooo`07oooo
o`009_ooool2o`0004?ooooo0`0000001?ooool00000000000000003ooooo`<0000000?ooooo0000
00000000100000001?ooool00000000000000002ooooo`0300000?oooooooooo00Gooooo0`000005
ooooo`<000005_ooool3000006Cooooo00?o000000000?ooool02?ooool002Kooooo00?o0000oooo
ooooool0A?ooool300000003ooooo`0000000000008000000_ooool300000003ooooo`00003ooooo
00D0000000Cooooo00000000003ooooo0`000006ooooo`<000001Oooool4000001Gooooo0P00001T
ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Kooooo100000001?oo
ool00000000000000003ooooo`P0000000?ooooo0000000000001@000007ooooo`<000001_ooool4
000001?ooooo0`00001Rooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
04Wooooo0`0000000oooool0000000000002000000;ooooo3@000002ooooo`8000001_ooool30000
00Oooooo1000000Booooo`800000HOooool00`00003oooooooooo`07ooooo`009_ooool00ol0003o
ooooooooo`1;ooooo`<000000_ooool3000000?ooooo20000002ooooo`<0000000?ooooo00000000
00001oooool3000000Oooooo1000000@ooooo`<00000Goooool00`00003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`1=ooooo`<000000oooool00`00003oooooooooo`02ooooo`800000
0oooool3000000?ooooo1P000006ooooo`<000002?ooool30000013ooooo0P00001Nooooo`030000
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04oooooo10000002ooooo`<000000_oo
ool3000000;ooooo1@000002ooooo`H000001Oooool3000000Wooooo0`00000>ooooo`800000GOoo
ool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Booooo`<000000oooool3
00000007ooooo`000000000000000?ooool00000ooooo`0600000003ooooo`00003ooooo00<00000
1Oooool3000000[ooooo1000000;ooooo`800000G?ooool00`00003oooooooooo`07ooooo`009_oo
ool2o`0005Gooooo0`000004ooooo`8000000_ooool3000000;ooooo30000006ooooo`<000002_oo
ool4000000Wooooo0P00001Jooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`000?oooooo
oooo05Kooooo10000003ooooo`<0000000?ooooo0000000000001`0000000oooool00000ooooo`02
00000004ooooo`0000000000000000Gooooo0`00000<ooooo`@000001_ooool00`00003ooooooooo
o`1Iooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05Wooooo0`000003
ooooo`<000000_ooool8000000?ooooo0P0000001?ooool00000000000000005ooooo`<000003_oo
ool7000005_ooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Foooool3
000000Cooooo0P000002ooooo`<0000000?ooooo000000000000200000001?ooool0000000000000
0004ooooo`<00000K_ooool00`00003oooooooooo`07ooooo`007_ooool3o`0000Gooooo00?o0000
ooooooooool0GOooool3000000Cooooo0`000002ooooo`<0000000?ooooo00000000000010000000
1?ooool0000000000?ooool2000000Kooooo0`00001[ooooo`0300000?oooooooooo00Oooooo000O
ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0]
ooooo`0300000?ooool0000000<000001?ooool300000003ooooo`00000000000080000000?ooooo
0000000000001@000002ooooo`<000001Oooool3000000Wooooo00<00000ooooooooool0;Oooool0
0`00003oooooooooo`0]ooooo`0300000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo
00Cooooo00<00000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00`00003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`0300000?oooooooooo
00;ooooo0`000004ooooo`<0000000Gooooo0000000000000000ooooo`0:00000003ooooo`000000
000000?ooooo00?o0000ooooo`0000000P000007ooooo`0300000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00<00000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00`00003oooooooooo`07ooooo`007oooool00ol0003oooooooooo`04oooo
oo4000002Oooool001oooooo00?o0000ooooooooool0o_ooool001kooooo0_l0003oooooo`7ooooo
000Oooooo`03o`000?oooooooooo0?kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{73.4375, 302.812}, {399.625, 258.312}} -> {-0.54256, \
2.01759, 0.00417185, 0.0067502}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.002 w
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .0019 Mdot
.49552 .00606 Mdot
.48572 .01928 Mdot
.45452 .06087 Mdot
.35603 .17686 Mdot
.06986 .23957 Mdot
.68223 .1052 Mdot
.51202 .09407 Mdot
.35981 .20787 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49445 .00749 Mdot
.48233 .02384 Mdot
.44375 .07491 Mdot
.32255 .20738 Mdot
.987 .19535 Mdot
.67093 .06564 Mdot
.56472 .00728 Mdot
.55293 .57715 Mdot
.61909 .47676 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49583 .00563 Mdot
.48672 .01793 Mdot
.45771 .05667 Mdot
.36601 .16673 Mdot
.09624 .25061 Mdot
.69075 .11317 Mdot
.50763 .10609 Mdot
.33597 .23263 Mdot
.95956 .19555 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61507 Mdot
.507 .60858 Mdot
.52229 .58798 Mdot
.57091 .5244 Mdot
.72242 .37906 Mdot
.10908 .47245 Mdot
.34463 .59467 Mdot
.38243 .07599 Mdot
.25948 .22327 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50882 .60612 Mdot
.5281 .5802 Mdot
.58932 .50168 Mdot
.77759 .35634 Mdot
.20101 .49695 Mdot
.39692 .58597 Mdot
.4488 .01459 Mdot
.4252 .08141 Mdot
.29348 .22348 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48894 .01494 Mdot
.46477 .04733 Mdot
.3882 .14266 Mdot
.15738 .26591 Mdot
.72712 .11989 Mdot
.53314 .08939 Mdot
.3885 .18451 Mdot
.08996 .26354 Mdot
.66355 .13723 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00183 Mdot
.49569 .00583 Mdot
.48626 .01855 Mdot
.45625 .0586 Mdot
.36143 .17144 Mdot
.08403 .24577 Mdot
.68637 .10987 Mdot
.5086 .1019 Mdot
.34373 .22459 Mdot
.98033 .2064 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49212 .01064 Mdot
.47491 .03381 Mdot
.42021 .10471 Mdot
.25078 .25226 Mdot
.84262 .129 Mdot
.63389 .019 Mdot
.60314 .54797 Mdot
.7165 .40368 Mdot
.06333 .46086 Mdot
.50004 .61798 Mdot
.50013 .61785 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.50429 .61223 Mdot
.51368 .59956 Mdot
.54357 .55967 Mdot
.638 .44718 Mdot
.91444 .37163 Mdot
.31313 .50772 Mdot
.49162 .51548 Mdot
.50074 .61704 Mdot
.50235 .61485 Mdot
.5075 .60791 Mdot
.52388 .58585 Mdot
.57596 .51807 Mdot
.7377 .37097 Mdot
.13746 .48314 Mdot
.35573 .59931 Mdot
.38603 .07813 Mdot
.2596 .22541 Mdot
.89488 .13489 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48962 .01401 Mdot
.46695 .04443 Mdot
.39507 .13481 Mdot
.17695 .26708 Mdot
.74481 .11961 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50739 .60805 Mdot
.52353 .58632 Mdot
.57485 .51945 Mdot
.73436 .37262 Mdot
.13145 .48109 Mdot
.35303 .59879 Mdot
.38417 .0789 Mdot
.25651 .22632 Mdot
.89032 .1325 Mdot
.50099 .61669 Mdot
.50316 .61376 Mdot
.51008 .60442 Mdot
.5321 .57486 Mdot
.60195 .48668 Mdot
.81449 .35108 Mdot
.24643 .49859 Mdot
.43969 .55317 Mdot
.54464 .51233 Mdot
.71567 .3682 Mdot
.1199 .46914 Mdot
.50035 .61757 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.5112 .60291 Mdot
.53568 .57011 Mdot
.61322 .47378 Mdot
.84664 .3526 Mdot
.27611 .49817 Mdot
.47006 .52576 Mdot
.61936 .4252 Mdot
.93138 .36353 Mdot
.50002 .61801 Mdot
.50007 .61794 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50685 .60878 Mdot
.52183 .5886 Mdot
.56946 .52623 Mdot
.71801 .38165 Mdot
.10049 .46874 Mdot
.34205 .59229 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60904 Mdot
.52121 .58944 Mdot
.56747 .52875 Mdot
.71194 .3854 Mdot
.08834 .46316 Mdot
.33893 .58826 Mdot
.3871 .06633 Mdot
.27978 .2113 Mdot
.93789 .15517 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50702 .60855 Mdot
.52236 .58789 Mdot
.57113 .52412 Mdot
.72309 .37868 Mdot
.11037 .47299 Mdot
.34505 .595 Mdot
.38233 .07638 Mdot
.5011 .61655 Mdot
.50349 .61331 Mdot
.51113 .603 Mdot
.53545 .57041 Mdot
.6125 .47459 Mdot
.84461 .35235 Mdot
.27449 .49815 Mdot
.46847 .5272 Mdot
.61545 .42931 Mdot
.9208 .35889 Mdot
.34011 .48341 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50561 .61046 Mdot
.51787 .59392 Mdot
.55689 .5423 Mdot
.67943 .40903 Mdot
.01761 .42532 Mdot
.32943 .55486 Mdot
.43165 .6163 Mdot
.43445 .05733 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49246 .01019 Mdot
.47597 .03238 Mdot
.42359 .10053 Mdot
.26093 .24772 Mdot
.8601 .1341 Mdot
.64312 .01859 Mdot
.61305 .54042 Mdot
.73863 .39325 Mdot
.10234 .48172 Mdot
.50011 .61788 Mdot
.50035 .61756 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .60261 Mdot
.53639 .56917 Mdot
.61546 .47128 Mdot
.85291 .35352 Mdot
.28091 .49829 Mdot
.47466 .52168 Mdot
.63056 .41377 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00438 Mdot
.48967 .01395 Mdot
.46711 .04422 Mdot
.39556 .13424 Mdot
.17836 .26709 Mdot
.7462 .11958 Mdot
.55271 .07161 Mdot
.43685 .12863 Mdot
.22873 .27485 Mdot
.784 .13066 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.49309 .00934 Mdot
.47798 .02969 Mdot
.42995 .09255 Mdot
.2802 .23745 Mdot
.896 .14775 Mdot
.65693 .02472 Mdot
.61694 .54384 Mdot
.73698 .39679 Mdot
.09497 .4797 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00543 Mdot
.48719 .0173 Mdot
.45919 .05472 Mdot
.37065 .16186 Mdot
.10875 .25502 Mdot
.69613 .11584 Mdot
.50869 .1078 Mdot
.33427 .23514 Mdot
.95381 .19292 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48908 .01475 Mdot
.46522 .04674 Mdot
.38959 .14108 Mdot
.16133 .26631 Mdot
.73043 .11988 Mdot
.53647 .08636 Mdot
.39673 .17553 Mdot
.11272 .2715 Mdot
.67342 .14071 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50867 .60632 Mdot
.52763 .58083 Mdot
.58782 .50348 Mdot
.77317 .3575 Mdot
.19472 .49623 Mdot
.3918 .58899 Mdot
.43878 .02632 Mdot
.39619 .11588 Mdot
.20869 .25848 Mdot
.50106 .61661 Mdot
.50336 .61349 Mdot
.51071 .60357 Mdot
.53411 .57219 Mdot
.60829 .47937 Mdot
.83265 .35128 Mdot
.26428 .49823 Mdot
.45812 .5366 Mdot
.58988 .45764 Mdot
.8494 .33795 Mdot
.30259 .47751 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50724 .60826 Mdot
.52305 .58697 Mdot
.57332 .52137 Mdot
.72972 .37503 Mdot
.12291 .47798 Mdot
.34953 .5976 Mdot
.38259 .07881 Mdot
.25507 .22628 Mdot
.88894 .13148 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00267 Mdot
.49371 .0085 Mdot
.47996 .02702 Mdot
.43624 .08457 Mdot
.2994 .22506 Mdot
.93525 .16667 Mdot
.66556 .03941 Mdot
.60179 .56938 Mdot
.68052 .43568 Mdot
.97558 .41312 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50628 .60955 Mdot
.52001 .59105 Mdot
.56367 .53358 Mdot
.70031 .39317 Mdot
.06415 .45104 Mdot
.33434 .57835 Mdot
.39856 .04812 Mdot
.3207 .18134 Mdot
.02728 .20651 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.505 .61128 Mdot
.51593 .59654 Mdot
.5507 .55033 Mdot
.66026 .42562 Mdot
.97159 .39942 Mdot
.32531 .53075 Mdot
.46653 .56155 Mdot
.55792 .50903 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50528 .61089 Mdot
.51684 .59532 Mdot
.55359 .54657 Mdot
.66923 .41762 Mdot
.99351 .4116 Mdot
.32752 .54199 Mdot
.45057 .58708 Mdot
.50065 .58648 Mdot
.50066 .61714 Mdot
.50212 .61518 Mdot
.50674 .60893 Mdot
.52148 .58908 Mdot
.56832 .52767 Mdot
.71454 .38377 Mdot
.09359 .46562 Mdot
.34021 .59009 Mdot
.38542 .06934 Mdot
.27323 .21531 Mdot
.92484 .1482 Mdot
.50121 .61641 Mdot
.50384 .61284 Mdot
.51224 .60151 Mdot
.53897 .56574 Mdot
.62358 .46235 Mdot
.87548 .35833 Mdot
.29568 .49984 Mdot
.48692 .51196 Mdot
.65855 .38811 Mdot
.03057 .41628 Mdot
.35702 .5317 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48822 .01591 Mdot
.46247 .05038 Mdot
.38095 .15074 Mdot
.13705 .26266 Mdot
.71206 .11929 Mdot
.51904 .10168 Mdot
.35452 .21854 Mdot
.00092 .21939 Mdot
.64594 .10227 Mdot
.50076 .61701 Mdot
.50242 .61476 Mdot
.50772 .6076 Mdot
.52461 .58488 Mdot
.57826 .51522 Mdot
.74461 .36776 Mdot
.14957 .48689 Mdot
.36177 .59952 Mdot
.39172 .07431 Mdot
.27148 .22051 Mdot
.91469 .14516 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51012 .60437 Mdot
.53222 .57471 Mdot
.60233 .48625 Mdot
.81556 .35104 Mdot
.24756 .49857 Mdot
.44086 .55215 Mdot
.54746 .5088 Mdot
.72421 .36319 Mdot
.13655 .47481 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49527 .00639 Mdot
.48492 .02035 Mdot
.45199 .06418 Mdot
.34814 .18456 Mdot
.04952 .22973 Mdot
.67781 .0971 Mdot
.5207 .07797 Mdot
.39455 .16873 Mdot
.12154 .27077 Mdot
.50014 .61784 Mdot
.50046 .61742 Mdot
.50146 .61606 Mdot
.50464 .61176 Mdot
.5148 .59806 Mdot
.54712 .55502 Mdot
.64908 .43616 Mdot
.94336 .38475 Mdot
.32082 .51793 Mdot
.4828 .53384 Mdot
.61902 .43351 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48761 .01672 Mdot
.46056 .05291 Mdot
.37494 .15728 Mdot
.12045 .25859 Mdot
.70204 .11769 Mdot
.51162 .10693 Mdot
.3386 .2322 Mdot
.96289 .19811 Mdot
.64234 .08305 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48716 .01733 Mdot
.45912 .05482 Mdot
.37043 .1621 Mdot
.10814 .25481 Mdot
.69584 .11573 Mdot
.50859 .10777 Mdot
.3342 .23515 Mdot
.95373 .19285 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01037 Mdot
.47555 .03295 Mdot
.42223 .10221 Mdot
.25685 .24962 Mdot
.85296 .13189 Mdot
.63956 .01846 Mdot
.6097 .54266 Mdot
.73165 .3961 Mdot
.5013 .61628 Mdot
.50413 .61246 Mdot
.51315 .60028 Mdot
.54188 .5619 Mdot
.6327 .45265 Mdot
.90029 .36614 Mdot
.30785 .50405 Mdot
.49229 .5112 Mdot
.66515 .38413 Mdot
.04362 .42406 Mdot
.35747 .53922 Mdot
.50085 .61689 Mdot
.5027 .61438 Mdot
.50861 .6064 Mdot
.52743 .5811 Mdot
.58718 .50426 Mdot
.77127 .35803 Mdot
.19196 .49588 Mdot
.38962 .59019 Mdot
.43467 .03104 Mdot
.38444 .12901 Mdot
.1757 .26076 Mdot
.50082 .61693 Mdot
.5026 .61451 Mdot
.5083 .60682 Mdot
.52644 .58243 Mdot
.58405 .50808 Mdot
.76195 .36096 Mdot
.17791 .49362 Mdot
.37921 .59515 Mdot
.41624 .05124 Mdot
.33333 .17901 Mdot
.04368 .219 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49446 .00748 Mdot
.48236 .0238 Mdot
.44385 .07478 Mdot
.32286 .20713 Mdot
.98772 .19575 Mdot
.67098 .06602 Mdot
.56415 .00815 Mdot
.55096 .57974 Mdot
.61292 .48362 Mdot
.50065 .61715 Mdot
.50207 .61523 Mdot
.50661 .60911 Mdot
.52106 .58964 Mdot
.56699 .52936 Mdot
.71047 .38634 Mdot
.08537 .46174 Mdot
.33826 .58717 Mdot
.3882 .06446 Mdot
.2839 .20867 Mdot
.94625 .15979 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00354 Mdot
.49166 .01126 Mdot
.47344 .03576 Mdot
.41558 .11041 Mdot
.23693 .25746 Mdot
.82035 .12409 Mdot
.61956 .02339 Mdot
.58171 .56896 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61024 Mdot
.51837 .59325 Mdot
.55847 .54025 Mdot
.68432 .4051 Mdot
.02887 .43171 Mdot
.33035 .56085 Mdot
.42288 .01155 Mdot
.4042 .09509 Mdot
.25033 .24264 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01038 Mdot
.47552 .03298 Mdot
.42216 .10229 Mdot
.25665 .24971 Mdot
.85261 .13178 Mdot
.63938 .01846 Mdot
.60951 .5428 Mdot
.50092 .61679 Mdot
.50294 .61407 Mdot
.50935 .6054 Mdot
.52979 .57795 Mdot
.59466 .49528 Mdot
.79328 .35315 Mdot
.22187 .4984 Mdot
.41544 .57315 Mdot
.48806 .58421 Mdot
.54278 .54503 Mdot
.6609 .42001 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.5054 .61074 Mdot
.51719 .59483 Mdot
.55473 .54509 Mdot
.67277 .41458 Mdot
.00197 .4164 Mdot
.32822 .54648 Mdot
.44399 .59734 Mdot
.47747 .00012 Mdot
.47727 .02112 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49555 .00602 Mdot
.48581 .01915 Mdot
.45483 .06047 Mdot
.35699 .17591 Mdot
.07237 .24071 Mdot
.68289 .10609 Mdot
.51124 .09567 Mdot
.35644 .21143 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50642 .60937 Mdot
.52044 .59047 Mdot
.56504 .53183 Mdot
.70452 .39027 Mdot
.07304 .45564 Mdot
.33581 .58225 Mdot
.39371 .05559 Mdot
.30376 .1948 Mdot
.98858 .18422 Mdot
.49982 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49433 .00766 Mdot
.48194 .02437 Mdot
.4425 .07652 Mdot
.31869 .21053 Mdot
.97805 .19024 Mdot
.67022 .06085 Mdot
.57177 .61458 Mdot
.57735 .54567 Mdot
.69444 .40702 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01312 Mdot
.46905 .04163 Mdot
.4017 .12707 Mdot
.19609 .26623 Mdot
.76531 .11937 Mdot
.57217 .05474 Mdot
.48359 .06992 Mdot
.37045 .17719 Mdot
.08375 .2513 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61085 Mdot
.51693 .59518 Mdot
.55391 .54616 Mdot
.6702 .41678 Mdot
.99584 .41292 Mdot
.32772 .54322 Mdot
.44877 .5899 Mdot
.49429 .59519 Mdot
.53125 .56641 Mdot
.50075 .61702 Mdot
.5024 .6148 Mdot
.50763 .60772 Mdot
.52432 .58527 Mdot
.57733 .51637 Mdot
.74183 .36902 Mdot
.14475 .48546 Mdot
.35926 .59958 Mdot
.38913 .07621 Mdot
.26581 .22303 Mdot
.90494 .14005 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.4977 .00311 Mdot
.49266 .00991 Mdot
.47662 .03151 Mdot
.42563 .09797 Mdot
.26711 .24467 Mdot
.87122 .13789 Mdot
.64811 .01956 Mdot
.61645 .53902 Mdot
.7443 .39157 Mdot
.11073 .48614 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.4873 .01715 Mdot
.45956 .05424 Mdot
.37179 .16065 Mdot
.11186 .25602 Mdot
.69761 .1164 Mdot
.50928 .1078 Mdot
.33486 .23486 Mdot
.95484 .19356 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50865 .60635 Mdot
.52756 .58092 Mdot
.58761 .50374 Mdot
.77255 .35767 Mdot
.19382 .49612 Mdot
.39108 .58939 Mdot
.43742 .02789 Mdot
.3923 .12029 Mdot
.19767 .25993 Mdot
.49997 5e-05 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00468 Mdot
.48895 .01492 Mdot
.46482 .04727 Mdot
.38834 .1425 Mdot
.15777 .26595 Mdot
.72745 .11989 Mdot
.53346 .08909 Mdot
.38931 .18364 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51484 .59801 Mdot
.54724 .55486 Mdot
.64945 .43579 Mdot
.94433 .38523 Mdot
.32102 .51833 Mdot
.48235 .53466 Mdot
.61726 .43552 Mdot
.91257 .35848 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00214 Mdot
.49495 .00683 Mdot
.4839 .02173 Mdot
.44873 .06844 Mdot
.338 .194 Mdot
.0241 .21626 Mdot
.67419 .08514 Mdot
.53644 .05165 Mdot
.45286 .09471 Mdot
.29961 .23515 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00332 Mdot
.49217 .01058 Mdot
.47505 .03361 Mdot
.42067 .10414 Mdot
.25217 .25167 Mdot
.84496 .12962 Mdot
.63523 .0188 Mdot
.60481 .54655 Mdot
.49962 .00051 Mdot
.4988 .00161 Mdot
.49619 .00514 Mdot
.48787 .01638 Mdot
.46136 .05185 Mdot
.37747 .15455 Mdot
.1274 .26044 Mdot
.706 .1185 Mdot
.51426 .1053 Mdot
.34389 .22791 Mdot
.97513 .20494 Mdot
.64353 .0892 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50496 .61133 Mdot
.5158 .59671 Mdot
.5503 .55085 Mdot
.65901 .42676 Mdot
.96849 .39775 Mdot
.32493 .52924 Mdot
.4686 .55817 Mdot
.56546 .49917 Mdot
.75778 .35181 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49786 .00289 Mdot
.49318 .00922 Mdot
.47826 .02931 Mdot
.43084 .09143 Mdot
.2829 .23583 Mdot
.90132 .1501 Mdot
.65845 .0263 Mdot
.50043 .61745 Mdot
.50138 .61618 Mdot
.50438 .61211 Mdot
.51397 .59918 Mdot
.54447 .55849 Mdot
.64081 .44433 Mdot
.92187 .37478 Mdot
.31548 .51001 Mdot
.49026 .51903 Mdot
.65045 .39942 Mdot
.00419 .4033 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50686 .60877 Mdot
.52185 .58858 Mdot
.56951 .52617 Mdot
.71814 .38158 Mdot
.10074 .46885 Mdot
.34212 .59236 Mdot
.38365 .07284 Mdot
.2658 .21965 Mdot
.9104 .14091 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.5118 .6021 Mdot
.53759 .56757 Mdot
.61925 .46708 Mdot
.8635 .35549 Mdot
.28831 .49878 Mdot
.48127 .5161 Mdot
.6462 .39884 Mdot
.00085 .39963 Mdot
.35423 .51665 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48716 .01734 Mdot
.4591 .05484 Mdot
.37037 .16216 Mdot
.10799 .25476 Mdot
.69577 .1157 Mdot
.50856 .10777 Mdot
.33419 .23515 Mdot
.95371 .19284 Mdot
.64169 .07816 Mdot
.50119 .61643 Mdot
.50379 .61292 Mdot
.51207 .60174 Mdot
.53844 .56645 Mdot
.62191 .46416 Mdot
.87089 .35717 Mdot
.29298 .49937 Mdot
.48499 .51327 Mdot
.6545 .39149 Mdot
.02106 .41096 Mdot
.35612 .5269 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49817 .00248 Mdot
.49416 .00789 Mdot
.4814 .02509 Mdot
.44079 .07872 Mdot
.31341 .21471 Mdot
.966 .18343 Mdot
.6692 .0545 Mdot
.58102 .60063 Mdot
.60919 .50716 Mdot
.78858 .36393 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00467 Mdot
.489 .01486 Mdot
.46496 .04708 Mdot
.38878 .142 Mdot
.15902 .26609 Mdot
.72848 .11989 Mdot
.5345 .08815 Mdot
.39187 .18086 Mdot
.09922 .267 Mdot
.6672 .13898 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00647 Mdot
.48475 .02058 Mdot
.45144 .0649 Mdot
.34643 .18618 Mdot
.04518 .2275 Mdot
.67707 .09518 Mdot
.52306 .07388 Mdot
.40351 .15796 Mdot
.14793 .27618 Mdot
.5 .61803 Mdot
.5 .61803 Mdot
.50001 .61801 Mdot
.50005 .61797 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.5047 .61168 Mdot
.51499 .59781 Mdot
.54771 .55423 Mdot
.65094 .43436 Mdot
.50012 .61787 Mdot
.50038 .61753 Mdot
.5012 .61641 Mdot
.50382 .61288 Mdot
.51217 .60161 Mdot
.53874 .56605 Mdot
.62286 .46313 Mdot
.8735 .35782 Mdot
.29453 .49963 Mdot
.48612 .51248 Mdot
.65691 .38946 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60706 Mdot
.52587 .58319 Mdot
.58225 .51028 Mdot
.7566 .36286 Mdot
.16947 .49192 Mdot
.37352 .59722 Mdot
.40721 .06041 Mdot
.30946 .19778 Mdot
.98945 .18801 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49732 .00362 Mdot
.49147 .01152 Mdot
.47284 .03657 Mdot
.41367 .11273 Mdot
.23127 .25926 Mdot
.81178 .12269 Mdot
.61327 .02633 Mdot
.57067 .58098 Mdot
.63062 .47303 Mdot
.86525 .36251 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60702 Mdot
.52597 .58305 Mdot
.58257 .50989 Mdot
.75755 .36251 Mdot
.171 .49225 Mdot
.37452 .59689 Mdot
.40873 .05891 Mdot
.31341 .1949 Mdot
.99806 .1931 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50702 .60855 Mdot
.52236 .58789 Mdot
.57113 .52412 Mdot
.72309 .37868 Mdot
.11038 .473 Mdot
.34505 .595 Mdot
.38232 .07638 Mdot
.25873 .22371 Mdot
.89676 .13457 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50639 .6094 Mdot
.52037 .59056 Mdot
.56482 .53212 Mdot
.70384 .39073 Mdot
.07162 .45491 Mdot
.33556 .58165 Mdot
.39444 .05445 Mdot
.30633 .19285 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50891 .60599 Mdot
.5284 .57981 Mdot
.59025 .50056 Mdot
.78033 .35568 Mdot
.20482 .49732 Mdot
.40014 .58394 Mdot
.45529 .00681 Mdot
.44427 .05742 Mdot
.35136 .17605 Mdot
.50128 .61631 Mdot
.50407 .61254 Mdot
.51295 .60055 Mdot
.54125 .56273 Mdot
.63073 .45472 Mdot
.89498 .36427 Mdot
.30558 .50291 Mdot
.49185 .51046 Mdot
.6659 .38304 Mdot
.04613 .42521 Mdot
.35813 .53999 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49465 .00722 Mdot
.48297 .02298 Mdot
.44578 .07228 Mdot
.32882 .2021 Mdot
.00181 .20378 Mdot
.67209 .07357 Mdot
.55305 .02529 Mdot
.51213 .01406 Mdot
.48938 .0239 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.5108 .60344 Mdot
.53441 .57179 Mdot
.60923 .47829 Mdot
.83534 .35146 Mdot
.26668 .49819 Mdot
.46059 .53436 Mdot
.59598 .45067 Mdot
.86678 .3411 Mdot
.31488 .47655 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51666 .59555 Mdot
.55304 .54728 Mdot
.66752 .41911 Mdot
.98938 .40927 Mdot
.32716 .53981 Mdot
.45372 .58212 Mdot
.50003 .618 Mdot
.50009 .61792 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50877 .60619 Mdot
.52793 .58043 Mdot
.58878 .50232 Mdot
.776 .35674 Mdot
.19878 .49671 Mdot
.39508 .58709 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49791 .00283 Mdot
.49333 .00901 Mdot
.47876 .02864 Mdot
.43242 .08943 Mdot
.28772 .23285 Mdot
.91096 .15455 Mdot
.6609 .02952 Mdot
.61314 .55129 Mdot
.72114 .40616 Mdot
.06395 .46387 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01028 Mdot
.47576 .03266 Mdot
.42291 .10136 Mdot
.2589 .24868 Mdot
.85653 .13297 Mdot
.64138 .01847 Mdot
.61149 .5414 Mdot
.73548 .39447 Mdot
.09722 .47909 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .0054 Mdot
.48727 .01718 Mdot
.45947 .05435 Mdot
.37152 .16094 Mdot
.11113 .25579 Mdot
.69726 .11627 Mdot
.50913 .10781 Mdot
.33468 .23496 Mdot
.95451 .19336 Mdot
.64165 .07871 Mdot
.50092 .61679 Mdot
.50293 .61407 Mdot
.50934 .60542 Mdot
.52976 .57799 Mdot
.59454 .49541 Mdot
.79295 .35321 Mdot
.22145 .49838 Mdot
.41505 .57345 Mdot
.48719 .58532 Mdot
.54012 .54852 Mdot
.6526 .42775 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49261 .00998 Mdot
.47645 .03173 Mdot
.42511 .09863 Mdot
.26552 .24548 Mdot
.86833 .13687 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00805 Mdot
.48101 .02561 Mdot
.43958 .08029 Mdot
.30967 .21758 Mdot
.95761 .17875 Mdot
.66839 .05018 Mdot
.58719 .59137 Mdot
.63033 .48361 Mdot
.84784 .36307 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01801 Mdot
.45753 .05691 Mdot
.36544 .16732 Mdot
.09471 .25003 Mdot
.69015 .11279 Mdot
.50765 .10571 Mdot
.33661 .23194 Mdot
.96134 .19644 Mdot
.64348 .08073 Mdot
.50106 .61661 Mdot
.50337 .61349 Mdot
.51072 .60355 Mdot
.53416 .57213 Mdot
.60844 .4792 Mdot
.83307 .3513 Mdot
.26465 .49822 Mdot
.45851 .53625 Mdot
.59084 .45653 Mdot
.85216 .33835 Mdot
.30469 .47727 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49231 .01038 Mdot
.47551 .03299 Mdot
.42213 .10234 Mdot
.25655 .24976 Mdot
.85243 .13173 Mdot
.63929 .01847 Mdot
.60941 .54287 Mdot
.73103 .39637 Mdot
.08969 .47519 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49159 .01136 Mdot
.47321 .03608 Mdot
.41483 .11132 Mdot
.23471 .25819 Mdot
.81695 .12351 Mdot
.61712 .02447 Mdot
.57752 .57344 Mdot
.64967 .45426 Mdot
.91467 .37889 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.5049 .61141 Mdot
.51562 .59695 Mdot
.54973 .5516 Mdot
.65723 .42842 Mdot
.96403 .39536 Mdot
.32433 .5271 Mdot
.47146 .55341 Mdot
.57602 .48559 Mdot
.79032 .34275 Mdot
.49992 .00011 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49726 .00371 Mdot
.49126 .01181 Mdot
.47216 .03749 Mdot
.4115 .11536 Mdot
.22484 .26107 Mdot
.80242 .12146 Mdot
.6059 .03037 Mdot
.55677 .59688 Mdot
.591 .51705 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50457 .61186 Mdot
.51456 .59839 Mdot
.54635 .55602 Mdot
.64669 .43849 Mdot
.9372 .38177 Mdot
.31949 .51547 Mdot
.48544 .52895 Mdot
.62957 .42167 Mdot
.94729 .3737 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01324 Mdot
.46876 .04202 Mdot
.40078 .12816 Mdot
.19342 .26647 Mdot
.76225 .11937 Mdot
.56911 .05729 Mdot
.47642 .07907 Mdot
.34848 .19926 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49158 .01137 Mdot
.47319 .03611 Mdot
.41476 .11141 Mdot
.23449 .25826 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60703 Mdot
.52596 .58307 Mdot
.58253 .50994 Mdot
.75743 .36256 Mdot
.1708 .49221 Mdot
.37439 .59693 Mdot
.40853 .05911 Mdot
.3129 .19528 Mdot
.50108 .61657 Mdot
.50345 .61337 Mdot
.511 .60318 Mdot
.53505 .57095 Mdot
.61123 .47602 Mdot
.84101 .35195 Mdot
.27154 .49815 Mdot
.46553 .52986 Mdot
.6082 .4371 Mdot
.90095 .35109 Mdot
.33287 .47908 Mdot
.50082 .61692 Mdot
.50263 .61449 Mdot
.50837 .60673 Mdot
.52666 .58213 Mdot
.58475 .50722 Mdot
.76404 .36025 Mdot
.18114 .4942 Mdot
.3815 .59418 Mdot
.42009 .04715 Mdot
.3438 .16981 Mdot
.06904 .23182 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51438 .59862 Mdot
.54579 .55676 Mdot
.64493 .44021 Mdot
.93266 .37963 Mdot
.31841 .51375 Mdot
.48714 .52566 Mdot
.6366 .41402 Mdot
.96671 .38337 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50974 .60488 Mdot
.53103 .57629 Mdot
.59858 .49064 Mdot
.80471 .35172 Mdot
.23561 .49867 Mdot
.42876 .56253 Mdot
.51856 .54536 Mdot
.63615 .43398 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50923 .60557 Mdot
.52939 .57848 Mdot
.5934 .49677 Mdot
.78961 .35377 Mdot
.21719 .49819 Mdot
.41109 .57639 Mdot
.47847 .59629 Mdot
.51365 .58366 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60316 Mdot
.53509 .57089 Mdot
.61138 .47585 Mdot
.84143 .35199 Mdot
.27189 .49815 Mdot
.46588 .52954 Mdot
.60906 .43616 Mdot
.90334 .35196 Mdot
.33386 .4795 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49703 .00401 Mdot
.49054 .01277 Mdot
.46988 .04052 Mdot
.40431 .12398 Mdot
.2037 .26533 Mdot
.77439 .11951 Mdot
.58101 .04761 Mdot
.50397 .04394 Mdot
.43288 .10433 Mdot
.26406 .2513 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48933 .0144 Mdot
.46603 .04566 Mdot
.39214 .13817 Mdot
.16857 .26683 Mdot
.73684 .11978 Mdot
.54303 .08038 Mdot
.41297 .1571 Mdot
.15878 .28107 Mdot
.70401 .13964 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48761 .01673 Mdot
.46053 .05295 Mdot
.37486 .15737 Mdot
.12023 .25853 Mdot
.70192 .11766 Mdot
.51154 .10697 Mdot
.33846 .2323 Mdot
.96259 .19794 Mdot
.50051 .61735 Mdot
.50162 .61584 Mdot
.50517 .61104 Mdot
.51648 .59579 Mdot
.55247 .54802 Mdot
.66575 .42067 Mdot
.98508 .40687 Mdot
.32676 .53758 Mdot
.45694 .57702 Mdot
.5233 .5555 Mdot
.62448 .45151 Mdot
.49969 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48982 .01375 Mdot
.46757 .04361 Mdot
.39701 .13255 Mdot
.18254 .26704 Mdot
.75045 .1195 Mdot
.5571 .06769 Mdot
.44758 .11541 Mdot
.26086 .26261 Mdot
.83595 .13606 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49345 .00885 Mdot
.47912 .02816 Mdot
.43356 .08798 Mdot
.2912 .23061 Mdot
.91807 .15796 Mdot
.66248 .03217 Mdot
.61042 .55586 Mdot
.71102 .41272 Mdot
.04322 .4523 Mdot
.50095 .61675 Mdot
.50302 .61395 Mdot
.50964 .60502 Mdot
.53069 .57674 Mdot
.5975 .4919 Mdot
.80158 .35204 Mdot
.23197 .49864 Mdot
.42515 .5655 Mdot
.51016 .55609 Mdot
.61038 .46177 Mdot
.86323 .35001 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00314 Mdot
.4926 .00999 Mdot
.47644 .03175 Mdot
.42507 .09867 Mdot
.26541 .24553 Mdot
.86814 .1368 Mdot
.64679 .0192 Mdot
.61572 .53916 Mdot
.74333 .39175 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .01391 Mdot
.4672 .0441 Mdot
.39585 .1339 Mdot
.17919 .26708 Mdot
.74704 .11957 Mdot
.55358 .07083 Mdot
.43897 .12604 Mdot
.23504 .27293 Mdot
.79343 .13084 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00517 Mdot
.48781 .01646 Mdot
.46118 .05209 Mdot
.3769 .15517 Mdot
.12583 .26004 Mdot
.70508 .11834 Mdot
.51361 .10574 Mdot
.34252 .22905 Mdot
.97192 .20315 Mdot
.50038 .61752 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .60139 Mdot
.53925 .56537 Mdot
.62445 .4614 Mdot
.87789 .35898 Mdot
.29704 .50013 Mdot
.48781 .51142 Mdot
.66032 .38668 Mdot
.03466 .41856 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00312 Mdot
.49264 .00995 Mdot
.47654 .03162 Mdot
.42538 .09829 Mdot
.26635 .24505 Mdot
.86985 .1374 Mdot
.64753 .0194 Mdot
.61615 .53906 Mdot
.74393 .39162 Mdot
.11026 .48586 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00236 Mdot
.49444 .00752 Mdot
.48227 .02392 Mdot
.44357 .07514 Mdot
.32199 .20785 Mdot
.98568 .1946 Mdot
.67082 .06493 Mdot
.56576 .00569 Mdot
.55654 .5724 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.5394 .56518 Mdot
.62492 .4609 Mdot
.87916 .35934 Mdot
.29774 .50029 Mdot
.48825 .51117 Mdot
.66116 .38602 Mdot
.03656 .41962 Mdot
.3576 .53471 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60082 Mdot
.54061 .56357 Mdot
.62873 .45683 Mdot
.88957 .36247 Mdot
.30308 .50189 Mdot
.49101 .51022 Mdot
.66546 .383 Mdot
.04575 .42483 Mdot
.35836 .53948 Mdot
.5009 .61681 Mdot
.50288 .61415 Mdot
.50917 .60565 Mdot
.5292 .57873 Mdot
.59279 .4975 Mdot
.78782 .3541 Mdot
.21487 .49807 Mdot
.40898 .57792 Mdot
.47388 .60202 Mdot
.49979 .60222 Mdot
.52537 .5788 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .60219 Mdot
.53737 .56787 Mdot
.61854 .46786 Mdot
.86152 .35508 Mdot
.28699 .49866 Mdot
.48015 .51702 Mdot
.6436 .40123 Mdot
.99439 .39603 Mdot
.35359 .51341 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.4884 .01566 Mdot
.46306 .04959 Mdot
.38282 .14867 Mdot
.14226 .26368 Mdot
.71561 .11957 Mdot
.52214 .09911 Mdot
.36179 .21173 Mdot
.0192 .22949 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.4883 .0158 Mdot
.46272 .05004 Mdot
.38175 .14986 Mdot
.13928 .26311 Mdot
.71355 .11942 Mdot
.52032 .10063 Mdot
.3575 .21578 Mdot
.00835 .22352 Mdot
.64669 .10599 Mdot
.49961 .00053 Mdot
.49875 .00168 Mdot
.49603 .00537 Mdot
.48735 .01709 Mdot
.4597 .05405 Mdot
.37225 .16017 Mdot
.11309 .25641 Mdot
.69822 .1166 Mdot
.50955 .10775 Mdot
.33521 .23465 Mdot
.95553 .19396 Mdot
.64169 .07928 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00264 Mdot
.49377 .00842 Mdot
.48014 .02679 Mdot
.4368 .08385 Mdot
.30112 .22385 Mdot
.93892 .16861 Mdot
.66611 .04109 Mdot
.59962 .57268 Mdot
.67301 .44207 Mdot
.95772 .40334 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .60891 Mdot
.52152 .58902 Mdot
.56848 .52748 Mdot
.715 .38348 Mdot
.09451 .46604 Mdot
.34044 .5904 Mdot
.38516 .06983 Mdot
.27217 .21594 Mdot
.92276 .14712 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00494 Mdot
.48836 .01572 Mdot
.46292 .04978 Mdot
.38238 .14916 Mdot
.14103 .26345 Mdot
.71476 .11951 Mdot
.52138 .09975 Mdot
.35998 .21345 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46745 .04377 Mdot
.39663 .133 Mdot
.18143 .26706 Mdot
.74932 .11952 Mdot
.55593 .06873 Mdot
.44473 .11894 Mdot
.25227 .26647 Mdot
.82111 .13341 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48977 .01382 Mdot
.46741 .04382 Mdot
.3965 .13315 Mdot
.18106 .26707 Mdot
.74893 .11953 Mdot
.55553 .06908 Mdot
.44376 .12014 Mdot
.24936 .26769 Mdot
.81623 .13274 Mdot
.50039 .61751 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51265 .60096 Mdot
.54027 .56402 Mdot
.62767 .45796 Mdot
.88667 .36155 Mdot
.30166 .50139 Mdot
.49039 .51029 Mdot
.66472 .38343 Mdot
.04432 .42399 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48929 .01446 Mdot
.46589 .04585 Mdot
.3917 .13867 Mdot
.16733 .26676 Mdot
.73571 .11981 Mdot
.54186 .08145 Mdot
.41008 .16044 Mdot
.15048 .28007 Mdot
.69732 .14053 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49806 .00262 Mdot
.49382 .00835 Mdot
.48031 .02655 Mdot
.43735 .08314 Mdot
.30283 .22263 Mdot
.9426 .17057 Mdot
.66662 .04281 Mdot
.59735 .57612 Mdot
.66517 .44904 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.5134 .59994 Mdot
.54268 .56085 Mdot
.6352 .45005 Mdot
.90701 .36866 Mdot
.3105 .50568 Mdot
.4923 .51282 Mdot
.66254 .38699 Mdot
.03637 .42042 Mdot
.35612 .53637 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49067 .01261 Mdot
.47027 .04001 Mdot
.40553 .12254 Mdot
.20725 .26479 Mdot
.77881 .11966 Mdot
.58519 .0444 Mdot
.51335 .03203 Mdot
.46152 .06736 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49784 .00292 Mdot
.49311 .00931 Mdot
.47804 .0296 Mdot
.43014 .0923 Mdot
.2808 .23709 Mdot
.89717 .14826 Mdot
.65728 .02505 Mdot
.61674 .54431 Mdot
.73603 .39733 Mdot
.09313 .47883 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00554 Mdot
.48693 .01765 Mdot
.45837 .0558 Mdot
.36809 .16456 Mdot
.10182 .25265 Mdot
.69303 .11445 Mdot
.50784 .10719 Mdot
.33441 .23446 Mdot
.95505 .19334 Mdot
.64222 .07835 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .6042 Mdot
.53264 .57415 Mdot
.60364 .48473 Mdot
.81933 .35096 Mdot
.25147 .4985 Mdot
.44488 .54858 Mdot
.55725 .49665 Mdot
.75366 .34914 Mdot
.18873 .48589 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00533 Mdot
.48744 .01695 Mdot
.46001 .05364 Mdot
.37322 .15913 Mdot
.11575 .25722 Mdot
.69956 .11702 Mdot
.51021 .10756 Mdot
.33617 .23401 Mdot
.95753 .1951 Mdot
.64185 .08034 Mdot
.50027 .61768 Mdot
.50085 .61689 Mdot
.50269 .6144 Mdot
.50858 .60645 Mdot
.52733 .58123 Mdot
.58688 .50463 Mdot
.77036 .35829 Mdot
.19063 .49569 Mdot
.38858 .59075 Mdot
.43273 .03323 Mdot
.37896 .13494 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50775 .60757 Mdot
.52467 .58479 Mdot
.57847 .51496 Mdot
.74525 .36748 Mdot
.15066 .4872 Mdot
.36235 .59949 Mdot
.39236 .0738 Mdot
.27295 .21981 Mdot
.91728 .14654 Mdot
.49995 6e-05 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00197 Mdot
.49534 .00629 Mdot
.48517 .02002 Mdot
.45278 .06315 Mdot
.35059 .1822 Mdot
.05579 .23287 Mdot
.67901 .09976 Mdot
.51759 .08348 Mdot
.38252 .18277 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48852 .0155 Mdot
.46345 .04908 Mdot
.38404 .14732 Mdot
.14568 .26428 Mdot
.71806 .1197 Mdot
.52438 .09719 Mdot
.36712 .20655 Mdot
.03291 .23685 Mdot
.64968 .11765 Mdot
.50033 .61758 Mdot
.50107 .61659 Mdot
.50339 .61345 Mdot
.51081 .60343 Mdot
.53444 .57176 Mdot
.60932 .4782 Mdot
.83557 .35147 Mdot
.26688 .49819 Mdot
.4608 .53417 Mdot
.5965 .45009 Mdot
.86824 .34142 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51203 .60179 Mdot
.53832 .56661 Mdot
.62153 .46458 Mdot
.86982 .35691 Mdot
.29233 .49927 Mdot
.4845 .51362 Mdot
.65344 .39241 Mdot
.01852 .40953 Mdot
.35588 .52561 Mdot
.50003 .618 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61692 Mdot
.50264 .61447 Mdot
.5084 .60668 Mdot
.52677 .58198 Mdot
.5851 .50679 Mdot
.7651 .35991 Mdot
.18275 .49448 Mdot
.38267 .59366 Mdot
.50055 .61729 Mdot
.50176 .61565 Mdot
.50562 .61044 Mdot
.5179 .59388 Mdot
.55697 .54219 Mdot
.6797 .40881 Mdot
.01823 .42567 Mdot
.32948 .5552 Mdot
.43115 .61705 Mdot
.43274 .05953 Mdot
.33641 .18586 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61581 Mdot
.50524 .61096 Mdot
.51669 .59551 Mdot
.55313 .54717 Mdot
.66778 .41888 Mdot
.99001 .40963 Mdot
.32722 .54015 Mdot
.45324 .58288 Mdot
.51012 .5735 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51123 .60287 Mdot
.53578 .56998 Mdot
.61353 .47343 Mdot
.84751 .35272 Mdot
.2768 .49818 Mdot
.47073 .52516 Mdot
.621 .42348 Mdot
.93579 .36556 Mdot
.3443 .48795 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49782 .00295 Mdot
.49304 .0094 Mdot
.47783 .02989 Mdot
.42947 .09316 Mdot
.27874 .2383 Mdot
.89316 .14653 Mdot
.65607 .02394 Mdot
.61734 .54279 Mdot
.73909 .39559 Mdot
.09901 .48157 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .60141 Mdot
.53922 .56541 Mdot
.62437 .4615 Mdot
.87765 .35892 Mdot
.29691 .5001 Mdot
.48773 .51147 Mdot
.66016 .38681 Mdot
.03428 .41835 Mdot
.35738 .53356 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48934 .0144 Mdot
.46604 .04565 Mdot
.39218 .13813 Mdot
.16869 .26683 Mdot
.73695 .11978 Mdot
.54314 .08028 Mdot
.41324 .15678 Mdot
.15957 .28114 Mdot
.70467 .13954 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60723 Mdot
.52548 .58371 Mdot
.58103 .51179 Mdot
.75292 .36427 Mdot
.16351 .49057 Mdot
.36976 .59827 Mdot
.40174 .06566 Mdot
.2955 .20721 Mdot
.96022 .17072 Mdot
.49969 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48982 .01375 Mdot
.46757 .0436 Mdot
.39702 .13254 Mdot
.18256 .26704 Mdot
.75048 .1195 Mdot
.55713 .06766 Mdot
.44766 .11531 Mdot
.26107 .2625 Mdot
.83634 .13614 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00217 Mdot
.49489 .0069 Mdot
.48373 .02196 Mdot
.4482 .06913 Mdot
.33635 .19549 Mdot
.02005 .21402 Mdot
.67375 .08309 Mdot
.53932 .04701 Mdot
.46326 .08077 Mdot
.33257 .2089 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.48659 .0181 Mdot
.45731 .0572 Mdot
.36476 .16802 Mdot
.0929 .24933 Mdot
.68947 .11233 Mdot
.50771 .10519 Mdot
.33751 .23099 Mdot
.96376 .19768 Mdot
.6439 .08172 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00475 Mdot
.4888 .01512 Mdot
.46433 .04791 Mdot
.38681 .14422 Mdot
.15345 .26544 Mdot
.72396 .11987 Mdot
.53001 .09221 Mdot
.3808 .19267 Mdot
.06906 .2547 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48987 .01368 Mdot
.46774 .04338 Mdot
.39754 .13195 Mdot
.18405 .267 Mdot
.75203 .11947 Mdot
.55872 .06626 Mdot
.45152 .11051 Mdot
.27271 .25655 Mdot
.8576 .14146 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51128 .60281 Mdot
.53591 .56979 Mdot
.61397 .47294 Mdot
.84874 .35289 Mdot
.27775 .4982 Mdot
.47165 .52434 Mdot
.62326 .42116 Mdot
.94181 .36841 Mdot
.34572 .49006 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50694 .60866 Mdot
.52211 .58823 Mdot
.57034 .52512 Mdot
.72067 .38008 Mdot
.10569 .47101 Mdot
.34358 .59378 Mdot
.38281 .07483 Mdot
.26173 .22198 Mdot
.90256 .13718 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00526 Mdot
.48759 .01676 Mdot
.46046 .05304 Mdot
.37465 .1576 Mdot
.11965 .25836 Mdot
.70161 .11758 Mdot
.51135 .10707 Mdot
.33812 .23257 Mdot
.96181 .19751 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00294 Mdot
.49308 .00935 Mdot
.47795 .02973 Mdot
.42985 .09268 Mdot
.27989 .23763 Mdot
.89541 .14749 Mdot
.65676 .02455 Mdot
.61703 .54361 Mdot
.73745 .39652 Mdot
.09586 .48011 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51038 .60402 Mdot
.53306 .57358 Mdot
.60498 .48316 Mdot
.82321 .35096 Mdot
.25535 .49842 Mdot
.4489 .54498 Mdot
.5671 .4846 Mdot
.78299 .34022 Mdot
.23251 .48687 Mdot
.49972 .00038 Mdot
.49909 .00123 Mdot
.49711 .0039 Mdot
.49079 .01243 Mdot
.47067 .03947 Mdot
.40682 .121 Mdot
.21103 .26415 Mdot
.78364 .11988 Mdot
.58966 .04109 Mdot
.52317 .01969 Mdot
.49132 .02773 Mdot
.44645 .07644 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61024 Mdot
.51839 .59323 Mdot
.55852 .54019 Mdot
.68448 .40497 Mdot
.02922 .43191 Mdot
.33038 .56104 Mdot
.4226 .01196 Mdot
.40325 .09623 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.50799 .60724 Mdot
.52546 .58373 Mdot
.58096 .51188 Mdot
.75273 .36435 Mdot
.1632 .49049 Mdot
.36957 .59832 Mdot
.40146 .06591 Mdot
.29482 .20765 Mdot
.95884 .16991 Mdot
.50083 .61692 Mdot
.50264 .61447 Mdot
.5084 .60669 Mdot
.52677 .58199 Mdot
.58509 .50681 Mdot
.76505 .35993 Mdot
.18267 .49447 Mdot
.38261 .59369 Mdot
.422 .04511 Mdot
.34902 .165 Mdot
.08204 .23773 Mdot
.50008 .61792 Mdot
.50027 .61767 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50867 .60633 Mdot
.52761 .58086 Mdot
.58776 .50357 Mdot
.77297 .35755 Mdot
.19444 .4962 Mdot
.39157 .58912 Mdot
.43835 .02682 Mdot
.50032 .6176 Mdot
.50101 .61666 Mdot
.50323 .61367 Mdot
.5103 .60412 Mdot
.53281 .57392 Mdot
.60419 .48408 Mdot
.82093 .35095 Mdot
.25308 .49847 Mdot
.44654 .5471 Mdot
.56132 .49164 Mdot
.76583 .34483 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49428 .00773 Mdot
.48177 .02459 Mdot
.44199 .07718 Mdot
.31711 .2118 Mdot
.9744 .18817 Mdot
.66993 .05891 Mdot
.57461 .61029 Mdot
.58714 .53348 Mdot
.72395 .38791 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48933 .01441 Mdot
.46602 .04567 Mdot
.39211 .13821 Mdot
.16849 .26682 Mdot
.73677 .11979 Mdot
.54295 .08045 Mdot
.41278 .15732 Mdot
.15823 .28101 Mdot
.70355 .1397 Mdot
.50125 .61635 Mdot
.50397 .61266 Mdot
.51266 .60094 Mdot
.54033 .56395 Mdot
.62784 .45778 Mdot
.88713 .3617 Mdot
.30189 .50147 Mdot
.4905 .51027 Mdot
.66486 .38334 Mdot
.04461 .42415 Mdot
.35831 .53883 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50545 .61067 Mdot
.51737 .59459 Mdot
.55531 .54434 Mdot
.67454 .41308 Mdot
.00617 .41879 Mdot
.32855 .54873 Mdot
.44069 .60245 Mdot
.4659 .01579 Mdot
.44034 .06981 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49617 .00518 Mdot
.48779 .01649 Mdot
.4611 .0522 Mdot
.37664 .15544 Mdot
.12513 .25986 Mdot
.70467 .11826 Mdot
.51332 .10592 Mdot
.34194 .22952 Mdot
.97056 .20239 Mdot
.64309 .0869 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49047 .01287 Mdot
.46964 .04085 Mdot
.40354 .1249 Mdot
.20144 .26563 Mdot
.77164 .11945 Mdot
.57837 .0497 Mdot
.49795 .0516 Mdot
.41445 .12714 Mdot
.20873 .26976 Mdot
.50097 .61672 Mdot
.5031 .61385 Mdot
.50987 .6047 Mdot
.53145 .57574 Mdot
.59988 .4891 Mdot
.8085 .35141 Mdot
.23991 .49866 Mdot
.43306 .55891 Mdot
.52873 .53242 Mdot
.66726 .40436 Mdot
.01299 .41639 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.51091 .6033 Mdot
.53474 .57135 Mdot
.61027 .47711 Mdot
.8383 .35169 Mdot
.26925 .49816 Mdot
.46321 .53197 Mdot
.60247 .4434 Mdot
.88503 .34585 Mdot
.32543 .47713 Mdot
.50112 .61651 Mdot
.50358 .61319 Mdot
.51142 .60261 Mdot
.53637 .56919 Mdot
.6154 .47134 Mdot
.85275 .35349 Mdot
.28079 .49828 Mdot
.47455 .52178 Mdot
.63029 .41404 Mdot
.96035 .37766 Mdot
.34927 .49742 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50903 .60584 Mdot
.52876 .57933 Mdot
.59139 .49918 Mdot
.7837 .35493 Mdot
.20941 .4977 Mdot
.40411 .58132 Mdot
.46351 .61485 Mdot
.46866 .02568 Mdot
.42711 .09092 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50983 .60477 Mdot
.53129 .57594 Mdot
.5994 .48966 Mdot
.80711 .35152 Mdot
.23835 .49867 Mdot
.43149 .56024 Mdot
.52501 .53715 Mdot
.65588 .41466 Mdot
.98494 .40072 Mdot
.5001 .6179 Mdot
.5003 .61762 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50984 .60475 Mdot
.53134 .57588 Mdot
.59955 .48949 Mdot
.80755 .35148 Mdot
.23883 .49866 Mdot
.43198 .55982 Mdot
.52617 .53567 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.5081 .6071 Mdot
.52579 .5833 Mdot
.58199 .51061 Mdot
.75581 .36316 Mdot
.16821 .49165 Mdot
.37271 .59747 Mdot
.40598 .06161 Mdot
.3063 .20002 Mdot
.98266 .18398 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .6029 Mdot
.53569 .5701 Mdot
.61325 .47374 Mdot
.84672 .35262 Mdot
.27618 .49817 Mdot
.47012 .52571 Mdot
.61951 .42504 Mdot
.93179 .36372 Mdot
.34328 .48664 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48943 .01427 Mdot
.46634 .04525 Mdot
.39313 .13705 Mdot
.17138 .26695 Mdot
.73944 .11973 Mdot
.54571 .07793 Mdot
.41961 .14933 Mdot
.178 .28203 Mdot
.72167 .13682 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.4973 .00364 Mdot
.49141 .0116 Mdot
.47264 .03684 Mdot
.41304 .1135 Mdot
.2294 .25981 Mdot
.80902 .12229 Mdot
.61115 .02743 Mdot
.56676 .58537 Mdot
.61962 .48462 Mdot
.83548 .35785 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51587 .59662 Mdot
.55052 .55057 Mdot
.65968 .42615 Mdot
.97015 .39864 Mdot
.32513 .53005 Mdot
.4675 .55997 Mdot
.56145 .5044 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00536 Mdot
.48737 .01705 Mdot
.45978 .05394 Mdot
.37251 .15989 Mdot
.1138 .25662 Mdot
.69857 .11672 Mdot
.50972 .10771 Mdot
.33543 .23451 Mdot
.95599 .19423 Mdot
.64172 .07953 Mdot
.50119 .61642 Mdot
.5038 .61291 Mdot
.51209 .60171 Mdot
.53851 .56636 Mdot
.62212 .46394 Mdot
.87146 .35731 Mdot
.29332 .49942 Mdot
.48524 .51308 Mdot
.65505 .39103 Mdot
.02236 .41168 Mdot
.35624 .52756 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .60489 Mdot
.531 .57634 Mdot
.59847 .49077 Mdot
.80439 .35175 Mdot
.23524 .49866 Mdot
.42839 .56284 Mdot
.5177 .54646 Mdot
.6335 .43671 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50702 .60855 Mdot
.52238 .58787 Mdot
.57118 .52406 Mdot
.72324 .37859 Mdot
.11067 .47312 Mdot
.34515 .59507 Mdot
.3823 .07647 Mdot
.25857 .2238 Mdot
.89645 .13444 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49242 .01024 Mdot
.47586 .03253 Mdot
.42323 .10097 Mdot
.25985 .24824 Mdot
.85819 .13349 Mdot
.6422 .01852 Mdot
.61224 .54091 Mdot
.73703 .39385 Mdot
.09976 .4804 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .00299 Mdot
.49294 .00954 Mdot
.4775 .03033 Mdot
.42843 .09446 Mdot
.2756 .2401 Mdot
.88711 .144 Mdot
.65411 .02244 Mdot
.61781 .54096 Mdot
.74252 .39358 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51327 .60011 Mdot
.54227 .56138 Mdot
.63393 .45137 Mdot
.90361 .36737 Mdot
.30919 .50483 Mdot
.49237 .5119 Mdot
.66409 .38533 Mdot
.04061 .42257 Mdot
.35687 .53808 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.4928 .00972 Mdot
.47707 .0309 Mdot
.42707 .09617 Mdot
.27147 .24237 Mdot
.87931 .1409 Mdot
.65132 .02082 Mdot
.61763 .53946 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.467 .04437 Mdot
.39521 .13465 Mdot
.17734 .26708 Mdot
.74519 .11961 Mdot
.55166 .07255 Mdot
.43428 .13176 Mdot
.2211 .27687 Mdot
.7731 .13088 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49857 .00193 Mdot
.49546 .00614 Mdot
.48552 .01954 Mdot
.4539 .06168 Mdot
.3541 .17877 Mdot
.06484 .23723 Mdot
.68099 .10334 Mdot
.51377 .09059 Mdot
.36719 .19991 Mdot
.49983 .00024 Mdot
.49945 .00075 Mdot
.49823 .00239 Mdot
.49437 .00761 Mdot
.48206 .02421 Mdot
.44288 .07603 Mdot
.31987 .20958 Mdot
.98075 .19178 Mdot
.67044 .06229 Mdot
.56965 .6178 Mdot
.57002 .55496 Mdot
.67207 .42475 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00263 Mdot
.49379 .00838 Mdot
.48023 .02666 Mdot
.43708 .08348 Mdot
.30201 .22322 Mdot
.94083 .16962 Mdot
.66638 .04198 Mdot
.59846 .57445 Mdot
.66898 .44561 Mdot
.50124 .61635 Mdot
.50396 .61268 Mdot
.51262 .60099 Mdot
.5402 .56411 Mdot
.62745 .45819 Mdot
.88607 .36137 Mdot
.30137 .5013 Mdot
.49025 .51033 Mdot
.66452 .38355 Mdot
.04392 .42376 Mdot
.35827 .53846 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50215 .61512 Mdot
.50687 .60876 Mdot
.52187 .58855 Mdot
.56958 .52607 Mdot
.71838 .38143 Mdot
.10121 .46906 Mdot
.34225 .59251 Mdot
.38356 .07304 Mdot
.26538 .2199 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00417 Mdot
.49017 .01328 Mdot
.46867 .04214 Mdot
.4005 .12849 Mdot
.1926 .26654 Mdot
.76133 .11937 Mdot
.56819 .05807 Mdot
.47424 .08185 Mdot
.3418 .20552 Mdot
.50001 .61802 Mdot
.50003 .618 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50893 .60598 Mdot
.52843 .57976 Mdot
.59037 .50041 Mdot
.78068 .3556 Mdot
.20531 .49737 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49014 .01331 Mdot
.4686 .04223 Mdot
.40027 .12875 Mdot
.19194 .26659 Mdot
.76059 .11937 Mdot
.56744 .0587 Mdot
.47246 .08411 Mdot
.33637 .21046 Mdot
.99584 .2066 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.50578 .61022 Mdot
.51843 .59318 Mdot
.55865 .54003 Mdot
.68486 .40467 Mdot
.03008 .43239 Mdot
.33045 .56149 Mdot
.42195 .01294 Mdot
.401 .09892 Mdot
.24095 .24622 Mdot
.50093 .61678 Mdot
.50295 .61405 Mdot
.5094 .60534 Mdot
.52993 .57775 Mdot
.59511 .49474 Mdot
.79461 .35295 Mdot
.22352 .49846 Mdot
.417 .57196 Mdot
.49154 .5798 Mdot
.5534 .53122 Mdot
.69388 .39275 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50545 .61068 Mdot
.51735 .59463 Mdot
.55522 .54445 Mdot
.67428 .41329 Mdot
.00556 .41844 Mdot
.3285 .5484 Mdot
.44117 .60171 Mdot
.46758 .01352 Mdot
.4457 .06289 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01028 Mdot
.47576 .03266 Mdot
.42291 .10136 Mdot
.2589 .24868 Mdot
.85653 .13297 Mdot
.64138 .01847 Mdot
.61149 .5414 Mdot
.73548 .39447 Mdot
.09722 .4791 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.5029 .61412 Mdot
.50924 .60556 Mdot
.52942 .57844 Mdot
.59348 .49667 Mdot
.78985 .35373 Mdot
.2175 .49821 Mdot
.41138 .57618 Mdot
.4791 .5955 Mdot
.51557 .58109 Mdot
.50045 .61743 Mdot
.50142 .61611 Mdot
.50453 .61191 Mdot
.51444 .59854 Mdot
.54597 .55651 Mdot
.64552 .43964 Mdot
.93417 .38033 Mdot
.31878 .51431 Mdot
.4866 .52672 Mdot
.63434 .41646 Mdot
.9605 .38021 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00406 Mdot
.49043 .01293 Mdot
.46951 .04102 Mdot
.40314 .12537 Mdot
.20029 .26578 Mdot
.77026 .11942 Mdot
.57703 .05077 Mdot
.49487 .05553 Mdot
.40503 .13844 Mdot
.18103 .27234 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49157 .01139 Mdot
.47314 .03618 Mdot
.4146 .1116 Mdot
.23402 .25841 Mdot
.81591 .12333 Mdot
.61636 .02482 Mdot
.57619 .57489 Mdot
.646 .45774 Mdot
.90537 .37509 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50426 .61228 Mdot
.51358 .5997 Mdot
.54323 .56011 Mdot
.63695 .44825 Mdot
.91166 .3705 Mdot
.31218 .50693 Mdot
.49196 .51438 Mdot
.65968 .38996 Mdot
.0287 .41643 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48802 .01617 Mdot
.46186 .05119 Mdot
.37903 .15285 Mdot
.13172 .26149 Mdot
.70863 .1189 Mdot
.51624 .10387 Mdot
.34818 .22422 Mdot
.98538 .21069 Mdot
.64448 .0944 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00425 Mdot
.48999 .01352 Mdot
.46811 .04288 Mdot
.39873 .13055 Mdot
.18749 .26686 Mdot
.75569 .11941 Mdot
.56248 .06297 Mdot
.46059 .09913 Mdot
.30019 .2394 Mdot
.50124 .61636 Mdot
.50395 .61269 Mdot
.5126 .60103 Mdot
.54012 .56423 Mdot
.62718 .45847 Mdot
.88536 .36115 Mdot
.301 .50118 Mdot
.49008 .51038 Mdot
.66427 .38372 Mdot
.04339 .42345 Mdot
.35823 .53818 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49302 .00942 Mdot
.47778 .02996 Mdot
.4293 .09336 Mdot
.27824 .23859 Mdot
.89219 .14612 Mdot
.65577 .02369 Mdot
.61745 .54246 Mdot
.73973 .39522 Mdot
.10025 .48213 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.4882 .01593 Mdot
.46243 .05044 Mdot
.38082 .15088 Mdot
.13668 .26258 Mdot
.71181 .11927 Mdot
.51883 .10185 Mdot
.35404 .21897 Mdot
.99974 .21873 Mdot
.64583 .10168 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60315 Mdot
.5351 .57088 Mdot
.6114 .47583 Mdot
.8415 .352 Mdot
.27195 .49815 Mdot
.46593 .52949 Mdot
.60921 .43601 Mdot
.90373 .3521 Mdot
.33401 .47956 Mdot
.50094 .61677 Mdot
.50298 .614 Mdot
.50951 .6052 Mdot
.53028 .57729 Mdot
.5962 .49345 Mdot
.79779 .3525 Mdot
.22743 .49856 Mdot
.42073 .56905 Mdot
.49999 .56906 Mdot
.57924 .49859 Mdot
.7725 .35252 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60736 Mdot
.52518 .58411 Mdot
.58007 .51298 Mdot
.75005 .36543 Mdot
.15877 .48939 Mdot
.36691 .59889 Mdot
.39789 .06915 Mdot
.286 .21294 Mdot
.94145 .15988 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50729 .60819 Mdot
.52322 .58674 Mdot
.57386 .5207 Mdot
.73134 .37417 Mdot
.12593 .4791 Mdot
.35072 .59808 Mdot
.38301 .07899 Mdot
.2552 .22646 Mdot
.88878 .13154 Mdot
.49998 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00666 Mdot
.48431 .02118 Mdot
.45003 .06674 Mdot
.34204 .1903 Mdot
.03413 .2217 Mdot
.67542 .09006 Mdot
.5297 .06269 Mdot
.50102 .61666 Mdot
.50324 .61365 Mdot
.51034 .60408 Mdot
.53292 .57378 Mdot
.60453 .48369 Mdot
.8219 .35095 Mdot
.25406 .49844 Mdot
.44756 .54619 Mdot
.56381 .48861 Mdot
.77323 .34263 Mdot
.21884 .48736 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.4923 .01041 Mdot
.47546 .03307 Mdot
.42195 .10256 Mdot
.256 .25 Mdot
.85149 .13145 Mdot
.63879 .01848 Mdot
.60889 .54326 Mdot
.72987 .3969 Mdot
.08768 .47413 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46876 .04202 Mdot
.40077 .12817 Mdot
.19339 .26648 Mdot
.76222 .11937 Mdot
.56908 .05732 Mdot
.47634 .07918 Mdot
.34823 .1995 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51288 .60064 Mdot
.54102 .56303 Mdot
.63001 .45547 Mdot
.89305 .36362 Mdot
.30471 .50253 Mdot
.4916 .51032 Mdot
.66589 .3829 Mdot
.04634 .42525 Mdot
.35826 .53996 Mdot
.50066 .61714 Mdot
.50212 .61518 Mdot
.50674 .60893 Mdot
.52147 .58909 Mdot
.56831 .52769 Mdot
.71448 .38381 Mdot
.09347 .46556 Mdot
.34018 .59005 Mdot
.38545 .06927 Mdot
.27336 .21523 Mdot
.92511 .14834 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48873 .01522 Mdot
.46411 .04821 Mdot
.38611 .14501 Mdot
.15147 .26517 Mdot
.5001 .6179 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61383 Mdot
.50993 .60463 Mdot
.53161 .57551 Mdot
.60041 .48848 Mdot
.81004 .35131 Mdot
.24161 .49865 Mdot
.43478 .55743 Mdot
.53283 .52721 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48083 .02586 Mdot
.43899 .08104 Mdot
.30787 .21894 Mdot
.95361 .17654 Mdot
.66796 .04817 Mdot
.59002 .58713 Mdot
.64002 .47343 Mdot
.87399 .36844 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.50089 .61683 Mdot
.50285 .61418 Mdot
.50908 .60577 Mdot
.52892 .57911 Mdot
.59189 .49858 Mdot
.78516 .35463 Mdot
.21137 .49784 Mdot
.40584 .58013 Mdot
.46716 .61037 Mdot
.50104 .61663 Mdot
.5033 .61357 Mdot
.51052 .60383 Mdot
.53351 .57299 Mdot
.60639 .48155 Mdot
.82723 .35103 Mdot
.25924 .49833 Mdot
.45293 .54134 Mdot
.57703 .47268 Mdot
.81221 .33627 Mdot
.26811 .48286 Mdot
.50098 .61672 Mdot
.50311 .61384 Mdot
.5099 .60466 Mdot
.53153 .57562 Mdot
.60015 .48878 Mdot
.80928 .35136 Mdot
.24078 .49865 Mdot
.43394 .55816 Mdot
.53082 .52976 Mdot
.67365 .39887 Mdot
.02828 .42494 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46847 .04241 Mdot
.39985 .12925 Mdot
.19072 .26668 Mdot
.75923 .11938 Mdot
.56607 .05987 Mdot
.46919 .08826 Mdot
.32639 .21913 Mdot
.97184 .19315 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00557 Mdot
.48685 .01775 Mdot
.45814 .05611 Mdot
.36735 .16534 Mdot
.09983 .25193 Mdot
.69219 .11401 Mdot
.50772 .10686 Mdot
.33482 .23394 Mdot
.9563 .19393 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.49281 .00972 Mdot
.47708 .03089 Mdot
.42709 .09614 Mdot
.27153 .24234 Mdot
.87941 .14094 Mdot
.65136 .02084 Mdot
.61764 .53948 Mdot
.74475 .39201 Mdot
.11046 .48639 Mdot
.50083 .61691 Mdot
.50264 .61446 Mdot
.50842 .60666 Mdot
.52683 .5819 Mdot
.58529 .50657 Mdot
.76564 .35974 Mdot
.18357 .49462 Mdot
.38327 .59339 Mdot
.42315 .04386 Mdot
.35217 .16203 Mdot
.09 .24109 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56787 .52824 Mdot
.71316 .38463 Mdot
.09082 .46433 Mdot
.33952 .58914 Mdot
.38627 .0678 Mdot
.27657 .21329 Mdot
.93146 .1517 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48958 .01407 Mdot
.46681 .04462 Mdot
.39462 .13533 Mdot
.17564 .26706 Mdot
.74352 .11964 Mdot
.54994 .0741 Mdot
.43004 .13689 Mdot
.20855 .27946 Mdot
.5013 .61627 Mdot
.50415 .61242 Mdot
.51323 .60017 Mdot
.54214 .56155 Mdot
.63353 .45178 Mdot
.90254 .36697 Mdot
.30877 .50457 Mdot
.49236 .51165 Mdot
.66448 .3849 Mdot
.0417 .42312 Mdot
.35708 .53851 Mdot
.50067 .61713 Mdot
.50212 .61516 Mdot
.50677 .60889 Mdot
.52155 .58897 Mdot
.56857 .52735 Mdot
.7153 .3833 Mdot
.09511 .46632 Mdot
.3406 .5906 Mdot
.38499 .07014 Mdot
.2715 .21634 Mdot
.92144 .14644 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50913 .6057 Mdot
.52908 .5789 Mdot
.59241 .49796 Mdot
.78669 .35432 Mdot
.21339 .49798 Mdot
.40764 .57887 Mdot
.47101 .6056 Mdot
.49113 .61382 Mdot
.49796 .61571 Mdot
.50007 .61794 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50687 .60875 Mdot
.5219 .58851 Mdot
.56967 .52597 Mdot
.71863 .38128 Mdot
.1017 .46928 Mdot
.34239 .59265 Mdot
.38347 .07325 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49188 .01097 Mdot
.47412 .03486 Mdot
.41773 .10778 Mdot
.24334 .25519 Mdot
.83043 .12609 Mdot
.62641 .02084 Mdot
.5927 .55771 Mdot
.6903 .42043 Mdot
.01003 .42972 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51293 .60058 Mdot
.54118 .56283 Mdot
.6305 .45495 Mdot
.89437 .36406 Mdot
.3053 .50279 Mdot
.49177 .51041 Mdot
.66591 .38298 Mdot
.04623 .42524 Mdot
.35817 .54 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48777 .01652 Mdot
.46104 .05227 Mdot
.37647 .15563 Mdot
.12465 .25973 Mdot
.7044 .11821 Mdot
.51314 .10604 Mdot
.34156 .22984 Mdot
.96967 .20189 Mdot
.50037 .61753 Mdot
.50119 .61642 Mdot
.5038 .61291 Mdot
.51209 .60171 Mdot
.53851 .56635 Mdot
.62214 .46391 Mdot
.87151 .35732 Mdot
.29335 .49943 Mdot
.48526 .51307 Mdot
.6551 .39098 Mdot
.02248 .41175 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60044 Mdot
.54151 .56239 Mdot
.63154 .45386 Mdot
.89718 .36503 Mdot
.30654 .50337 Mdot
.49208 .51071 Mdot
.66573 .38337 Mdot
.04543 .42491 Mdot
.35791 .53983 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50814 .60704 Mdot
.52593 .5831 Mdot
.58246 .51003 Mdot
.75721 .36264 Mdot
.17044 .49213 Mdot
.37416 .59701 Mdot
.40817 .05946 Mdot
.31196 .19596 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49897 .00139 Mdot
.49673 .00441 Mdot
.48959 .01406 Mdot
.46684 .04458 Mdot
.39472 .13521 Mdot
.17594 .26707 Mdot
.74381 .11964 Mdot
.55024 .07383 Mdot
.43077 .136 Mdot
.21071 .27908 Mdot
.50104 .61664 Mdot
.5033 .61358 Mdot
.51051 .60384 Mdot
.53348 .57304 Mdot
.60628 .48167 Mdot
.82693 .35103 Mdot
.25896 .49834 Mdot
.45263 .5416 Mdot
.5763 .47354 Mdot
.81009 .33639 Mdot
.2658 .48321 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00527 Mdot
.48757 .01678 Mdot
.46041 .05311 Mdot
.37448 .15778 Mdot
.11918 .25823 Mdot
.70136 .11752 Mdot
.51121 .10714 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46218 .05077 Mdot
.38003 .15175 Mdot
.13449 .26211 Mdot
.71038 .11912 Mdot
.51765 .10279 Mdot
.35133 .22143 Mdot
.99306 .21499 Mdot
.64519 .0983 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46591 .04582 Mdot
.39177 .1386 Mdot
.16752 .26677 Mdot
.73588 .1198 Mdot
.54204 .08128 Mdot
.41052 .15993 Mdot
.15175 .28024 Mdot
.69831 .14041 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49616 .00519 Mdot
.48777 .01651 Mdot
.46106 .05225 Mdot
.37652 .15558 Mdot
.12478 .25977 Mdot
.70447 .11822 Mdot
.51319 .10601 Mdot
.34166 .22976 Mdot
.96991 .20202 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60706 Mdot
.52587 .58319 Mdot
.58225 .51028 Mdot
.7566 .36287 Mdot
.16947 .49192 Mdot
.37352 .59722 Mdot
.4072 .06042 Mdot
.30944 .19779 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49168 .01124 Mdot
.47349 .0357 Mdot
.41572 .11023 Mdot
.23736 .25731 Mdot
.82102 .12422 Mdot
.62003 .02319 Mdot
.58251 .56812 Mdot
.66328 .44194 Mdot
.9482 .39476 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51265 .60096 Mdot
.54028 .56401 Mdot
.62769 .45793 Mdot
.88675 .36158 Mdot
.3017 .50141 Mdot
.49041 .51029 Mdot
.66474 .38341 Mdot
.04437 .42402 Mdot
.3583 .5387 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48683 .01777 Mdot
.45808 .05619 Mdot
.36716 .16553 Mdot
.09932 .25175 Mdot
.69199 .1139 Mdot
.5077 .10676 Mdot
.33495 .23378 Mdot
.95668 .19412 Mdot
.64259 .07892 Mdot
.49989 .00015 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48818 .01596 Mdot
.46235 .05054 Mdot
.38058 .15114 Mdot
.13603 .26245 Mdot
.71138 .11922 Mdot
.51847 .10214 Mdot
.35321 .21973 Mdot
.99768 .21758 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.49671 .00445 Mdot
.48952 .01416 Mdot
.46661 .04489 Mdot
.39398 .13606 Mdot
.17383 .26703 Mdot
.74177 .11968 Mdot
.54812 .07575 Mdot
.42556 .14227 Mdot
.19536 .28121 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.47611 .0322 Mdot
.424 .10001 Mdot
.26219 .24712 Mdot
.86234 .13483 Mdot
.64418 .01871 Mdot
.61391 .53994 Mdot
.74027 .39267 Mdot
.10492 .48304 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50356 .61323 Mdot
.51134 .60272 Mdot
.53611 .56953 Mdot
.6146 .47224 Mdot
.8505 .35314 Mdot
.2791 .49823 Mdot
.47295 .52319 Mdot
.62641 .41793 Mdot
.95018 .3725 Mdot
.49989 .00015 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48888 .01502 Mdot
.46457 .04759 Mdot
.38757 .14337 Mdot
.1556 .26571 Mdot
.72567 .11988 Mdot
.5317 .09069 Mdot
.38495 .1883 Mdot
.08027 .2596 Mdot
.50033 .61758 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60342 Mdot
.53448 .5717 Mdot
.60945 .47805 Mdot
.83594 .3515 Mdot
.26721 .49818 Mdot
.46113 .53386 Mdot
.59732 .44916 Mdot
.87057 .34196 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .00429 Mdot
.48988 .01367 Mdot
.46777 .04335 Mdot
.39763 .13184 Mdot
.18431 .26699 Mdot
.75231 .11946 Mdot
.55901 .066 Mdot
.45222 .10963 Mdot
.27483 .25539 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48943 .01428 Mdot
.46633 .04526 Mdot
.3931 .13708 Mdot
.1713 .26695 Mdot
.73937 .11973 Mdot
.54563 .07801 Mdot
.41942 .14956 Mdot
.17743 .28203 Mdot
.72109 .13691 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49118 .01192 Mdot
.4719 .03783 Mdot
.41069 .11635 Mdot
.22243 .26169 Mdot
.79901 .12108 Mdot
.60309 .03205 Mdot
.55123 .60341 Mdot
.57489 .53652 Mdot
.70678 .39438 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51249 .60117 Mdot
.53978 .56467 Mdot
.62612 .45961 Mdot
.88246 .36028 Mdot
.29951 .50074 Mdot
.48929 .51067 Mdot
.66301 .38462 Mdot
.04069 .42193 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48721 .01727 Mdot
.45927 .05462 Mdot
.37089 .1616 Mdot
.10941 .25523 Mdot
.69644 .11597 Mdot
.5088 .10781 Mdot
.33436 .23511 Mdot
.95395 .19301 Mdot
.64165 .07835 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49072 .01253 Mdot
.47046 .03976 Mdot
.40613 .12183 Mdot
.20901 .2645 Mdot
.78103 .11975 Mdot
.58726 .04285 Mdot
.51793 .02626 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47323 .03605 Mdot
.4149 .11123 Mdot
.23493 .25811 Mdot
.81729 .12356 Mdot
.61736 .02436 Mdot
.57795 .57298 Mdot
.65085 .45315 Mdot
.91764 .38016 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00513 Mdot
.48791 .01632 Mdot
.4615 .05166 Mdot
.37791 .15407 Mdot
.12862 .26075 Mdot
.70673 .11862 Mdot
.51479 .10493 Mdot
.34502 .22694 Mdot
.97782 .20645 Mdot
.64378 .09056 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50393 .61272 Mdot
.51252 .60113 Mdot
.53988 .56454 Mdot
.62643 .45928 Mdot
.88329 .36053 Mdot
.29995 .50087 Mdot
.48953 .51057 Mdot
.66341 .38433 Mdot
.04156 .42242 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50203 .61529 Mdot
.50647 .6093 Mdot
.5206 .59025 Mdot
.56556 .53117 Mdot
.7061 .38921 Mdot
.07635 .45731 Mdot
.33642 .58363 Mdot
.39208 .05815 Mdot
.298 .19903 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61069 Mdot
.51732 .59467 Mdot
.55512 .54459 Mdot
.67396 .41357 Mdot
.00479 .41801 Mdot
.32844 .54799 Mdot
.44177 .60078 Mdot
.46969 .01067 Mdot
.45243 .05412 Mdot
.5013 .61627 Mdot
.50416 .61242 Mdot
.51324 .60016 Mdot
.54217 .56152 Mdot
.6336 .45171 Mdot
.90272 .36704 Mdot
.30884 .50461 Mdot
.49236 .51169 Mdot
.66442 .38497 Mdot
.04152 .42303 Mdot
.35705 .53844 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50376 .61295 Mdot
.51198 .60185 Mdot
.53816 .56681 Mdot
.62104 .46511 Mdot
.86847 .35659 Mdot
.29149 .49915 Mdot
.48385 .51409 Mdot
.65203 .39363 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01025 Mdot
.47583 .03256 Mdot
.42314 .10108 Mdot
.2596 .24835 Mdot
.85775 .13335 Mdot
.64198 .0185 Mdot
.61205 .54103 Mdot
.73663 .39401 Mdot
.09911 .48007 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48943 .01427 Mdot
.46634 .04524 Mdot
.39314 .13703 Mdot
.17142 .26695 Mdot
.73948 .11973 Mdot
.54575 .0779 Mdot
.41971 .14921 Mdot
.17829 .28203 Mdot
.72196 .13677 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50811 .60708 Mdot
.52583 .58323 Mdot
.58214 .51042 Mdot
.75626 .36299 Mdot
.16893 .49181 Mdot
.37317 .59732 Mdot
.40668 .06093 Mdot
.3081 .19875 Mdot
.98652 .18626 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50199 .61535 Mdot
.50632 .60949 Mdot
.52015 .59086 Mdot
.56411 .53302 Mdot
.70167 .39223 Mdot
.06703 .45255 Mdot
.33479 .57964 Mdot
.39691 .05063 Mdot
.31498 .18605 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49213 .01064 Mdot
.47492 .0338 Mdot
.42023 .10469 Mdot
.25085 .25223 Mdot
.84274 .12903 Mdot
.63396 .01899 Mdot
.60323 .5479 Mdot
.71672 .40357 Mdot
.06373 .46108 Mdot
.50065 .61716 Mdot
.50207 .61524 Mdot
.5066 .60912 Mdot
.52101 .5897 Mdot
.56686 .52952 Mdot
.71008 .38659 Mdot
.08456 .46135 Mdot
.33808 .58687 Mdot
.38851 .06394 Mdot
.28506 .20792 Mdot
.94864 .16113 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49346 .00884 Mdot
.47916 .0281 Mdot
.43368 .08782 Mdot
.29159 .23036 Mdot
.91887 .15836 Mdot
.66264 .03249 Mdot
.61008 .55641 Mdot
.70978 .41356 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00168 Mdot
.49603 .00536 Mdot
.48736 .01707 Mdot
.45974 .054 Mdot
.37237 .16003 Mdot
.11343 .25651 Mdot
.69839 .11666 Mdot
.50963 .10774 Mdot
.33531 .23459 Mdot
.95574 .19408 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50202 .6153 Mdot
.50644 .60934 Mdot
.52051 .59038 Mdot
.56525 .53157 Mdot
.70516 .38984 Mdot
.07439 .45632 Mdot
.33605 .58281 Mdot
.39304 .05664 Mdot
.30139 .19656 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00455 Mdot
.48927 .01448 Mdot
.46584 .04591 Mdot
.39156 .13884 Mdot
.1669 .26673 Mdot
.73532 .11981 Mdot
.54147 .0818 Mdot
.4091 .16156 Mdot
.14769 .27966 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60722 Mdot
.52549 .58369 Mdot
.58106 .51175 Mdot
.75303 .36423 Mdot
.16369 .49061 Mdot
.36987 .59825 Mdot
.40188 .06552 Mdot
.29587 .20698 Mdot
.96097 .17116 Mdot
.50125 .61635 Mdot
.50397 .61266 Mdot
.51266 .60094 Mdot
.54032 .56396 Mdot
.62782 .45779 Mdot
.88709 .36169 Mdot
.30187 .50146 Mdot
.49049 .51027 Mdot
.66485 .38335 Mdot
.04459 .42414 Mdot
.35831 .53882 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49726 .00371 Mdot
.49125 .01181 Mdot
.47214 .03751 Mdot
.41145 .11542 Mdot
.22469 .26111 Mdot
.80221 .12143 Mdot
.60573 .03046 Mdot
.55644 .59726 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.492 .0108 Mdot
.47452 .03432 Mdot
.41898 .10623 Mdot
.24711 .25375 Mdot
.83654 .12748 Mdot
.63027 .01975 Mdot
.59831 .55234 Mdot
.70461 .41075 Mdot
.04 .44744 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49063 .01266 Mdot
.47015 .04017 Mdot
.40515 .12298 Mdot
.20616 .26497 Mdot
.77744 .11961 Mdot
.58391 .04538 Mdot
.51048 .03567 Mdot
.45277 .07881 Mdot
.32526 .21016 Mdot
.50118 .61644 Mdot
.50377 .61295 Mdot
.512 .60183 Mdot
.53821 .56675 Mdot
.6212 .46494 Mdot
.86891 .3567 Mdot
.29177 .49919 Mdot
.48406 .51394 Mdot
.6525 .39322 Mdot
.01625 .40826 Mdot
.35567 .52446 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.4866 .01809 Mdot
.45733 .05718 Mdot
.3648 .16798 Mdot
.09301 .24938 Mdot
.68951 .11236 Mdot
.5077 .10523 Mdot
.33744 .23105 Mdot
.96359 .19759 Mdot
.64388 .08165 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00553 Mdot
.48695 .01762 Mdot
.45845 .0557 Mdot
.36832 .16432 Mdot
.10245 .25287 Mdot
.6933 .11459 Mdot
.50789 .10728 Mdot
.33432 .23459 Mdot
.95473 .19319 Mdot
.64214 .07826 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00455 Mdot
.48926 .0145 Mdot
.4658 .04596 Mdot
.39144 .13898 Mdot
.16657 .26671 Mdot
.73503 .11982 Mdot
.54116 .08208 Mdot
.40835 .16243 Mdot
.14553 .27931 Mdot
.69359 .14094 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49461 .00727 Mdot
.48284 .02315 Mdot
.44539 .07279 Mdot
.32761 .20313 Mdot
.99893 .20215 Mdot
.67185 .07203 Mdot
.5553 .02179 Mdot
.52004 .00326 Mdot
.51476 .60763 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49802 .00267 Mdot
.4937 .00851 Mdot
.47992 .02707 Mdot
.43612 .08472 Mdot
.29904 .22531 Mdot
.93448 .16627 Mdot
.66544 .03906 Mdot
.60224 .56871 Mdot
.68205 .4344 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00213 Mdot
.49497 .0068 Mdot
.48397 .02163 Mdot
.44898 .06812 Mdot
.33876 .19331 Mdot
.02598 .21728 Mdot
.6744 .08607 Mdot
.53513 .05377 Mdot
.44814 .101 Mdot
.28472 .24505 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48947 .01421 Mdot
.46648 .04506 Mdot
.39357 .13654 Mdot
.17264 .267 Mdot
.74064 .11971 Mdot
.54695 .07681 Mdot
.42266 .14572 Mdot
.18688 .28181 Mdot
.7309 .13533 Mdot
.50068 .61712 Mdot
.50216 .61511 Mdot
.50689 .60873 Mdot
.52194 .58845 Mdot
.56981 .52578 Mdot
.71908 .38102 Mdot
.10258 .46966 Mdot
.34265 .59291 Mdot
.3833 .07362 Mdot
.26418 .22058 Mdot
.90728 .1394 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00333 Mdot
.49215 .0106 Mdot
.47501 .03367 Mdot
.42053 .10432 Mdot
.25173 .25186 Mdot
.84421 .12942 Mdot
.63481 .01886 Mdot
.60429 .54699 Mdot
.71925 .40219 Mdot
.06849 .46374 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00336 Mdot
.49208 .01069 Mdot
.47478 .03397 Mdot
.41981 .10521 Mdot
.24958 .25275 Mdot
.84062 .12848 Mdot
.63273 .01921 Mdot
.60164 .5493 Mdot
.71285 .40575 Mdot
.05633 .45689 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.49482 .007 Mdot
.48349 .02228 Mdot
.44745 .07011 Mdot
.33401 .19758 Mdot
.01432 .21084 Mdot
.67318 .08015 Mdot
.5435 .04032 Mdot
.47827 .06039 Mdot
.38055 .16102 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49732 .00363 Mdot
.49145 .01155 Mdot
.47276 .03668 Mdot
.41342 .11304 Mdot
.23052 .25948 Mdot
.81068 .12253 Mdot
.61242 .02676 Mdot
.56912 .58271 Mdot
.62628 .47754 Mdot
.8536 .36017 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45725 .05728 Mdot
.36457 .16821 Mdot
.0924 .24914 Mdot
.68928 .1122 Mdot
.50773 .10504 Mdot
.33777 .23071 Mdot
.96448 .19805 Mdot
.64402 .08202 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00456 Mdot
.48925 .01452 Mdot
.46576 .04601 Mdot
.39132 .13912 Mdot
.16622 .26669 Mdot
.73471 .11982 Mdot
.54084 .08238 Mdot
.40755 .16335 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51033 .60409 Mdot
.53289 .57382 Mdot
.60443 .4838 Mdot
.82163 .35095 Mdot
.25378 .49845 Mdot
.44727 .54644 Mdot
.56311 .48945 Mdot
.77116 .34321 Mdot
.21583 .48737 Mdot
.50087 .61685 Mdot
.50278 .61427 Mdot
.50887 .60605 Mdot
.52826 .57999 Mdot
.58981 .50108 Mdot
.77905 .35599 Mdot
.20305 .49716 Mdot
.39863 .5849 Mdot
.45224 .01048 Mdot
.43527 .06885 Mdot
.32388 .20078 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00084 Mdot
.49801 .00269 Mdot
.49366 .00857 Mdot
.47979 .02726 Mdot
.43568 .08528 Mdot
.2977 .22624 Mdot
.93163 .1648 Mdot
.66499 .0378 Mdot
.60383 .56627 Mdot
.68758 .42992 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01505 Mdot
.4645 .04769 Mdot
.38734 .14363 Mdot
.15494 .26563 Mdot
.72515 .11988 Mdot
.53118 .09116 Mdot
.38368 .18965 Mdot
.07682 .25813 Mdot
.65915 .13398 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48887 .01503 Mdot
.46455 .04762 Mdot
.38749 .14345 Mdot
.15539 .26568 Mdot
.7255 .11988 Mdot
.53153 .09084 Mdot
.38454 .18874 Mdot
.07916 .25913 Mdot
.65988 .13462 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60498 Mdot
.53078 .57663 Mdot
.59778 .49158 Mdot
.80239 .35195 Mdot
.23291 .49865 Mdot
.42608 .56474 Mdot
.51232 .55333 Mdot
.61701 .45436 Mdot
.88184 .35461 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .60139 Mdot
.53925 .56538 Mdot
.62444 .46141 Mdot
.87786 .35898 Mdot
.29703 .50013 Mdot
.4878 .51142 Mdot
.6603 .3867 Mdot
.03461 .41853 Mdot
.35741 .53373 Mdot
.50102 .61666 Mdot
.50323 .61366 Mdot
.51031 .60412 Mdot
.53282 .5739 Mdot
.60423 .48403 Mdot
.82105 .35095 Mdot
.2532 .49846 Mdot
.44667 .54698 Mdot
.56164 .49126 Mdot
.76676 .34453 Mdot
.2093 .48728 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.51169 .60224 Mdot
.53724 .56803 Mdot
.61815 .46828 Mdot
.86046 .35487 Mdot
.28627 .4986 Mdot
.47952 .51753 Mdot
.64214 .40259 Mdot
.99072 .394 Mdot
.35322 .51159 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51112 .60302 Mdot
.53541 .57047 Mdot
.61238 .47473 Mdot
.84425 .35231 Mdot
.2742 .49815 Mdot
.46818 .52745 Mdot
.61474 .43006 Mdot
.91889 .35808 Mdot
.33951 .4829 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51227 .60147 Mdot
.53908 .5656 Mdot
.62392 .46198 Mdot
.87643 .35859 Mdot
.29622 .49995 Mdot
.48728 .51173 Mdot
.65928 .38752 Mdot
.03226 .41722 Mdot
.35718 .53255 Mdot
.50098 .61672 Mdot
.50311 .61384 Mdot
.5099 .60466 Mdot
.53154 .57562 Mdot
.60017 .48877 Mdot
.80932 .35135 Mdot
.24082 .49865 Mdot
.43398 .55812 Mdot
.53092 .52963 Mdot
.67396 .39861 Mdot
.029 .42535 Mdot
.50088 .61684 Mdot
.50282 .61423 Mdot
.50898 .60591 Mdot
.5286 .57954 Mdot
.59089 .49979 Mdot
.78221 .35525 Mdot
.2074 .49755 Mdot
.40235 .5825 Mdot
.45986 .00128 Mdot
.45778 .03997 Mdot
.39311 .13178 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50971 .60491 Mdot
.53094 .57641 Mdot
.59829 .49097 Mdot
.80389 .3518 Mdot
.23466 .49866 Mdot
.42781 .56331 Mdot
.51635 .54818 Mdot
.62939 .44101 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50808 .60712 Mdot
.52573 .58337 Mdot
.58182 .51081 Mdot
.75531 .36335 Mdot
.1674 .49147 Mdot
.37219 .59762 Mdot
.40522 .06235 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61167 Mdot
.515 .59779 Mdot
.54775 .55419 Mdot
.65105 .43425 Mdot
.94842 .38726 Mdot
.32181 .52004 Mdot
.48036 .53821 Mdot
.60952 .4445 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50605 .60986 Mdot
.51927 .59204 Mdot
.56133 .53658 Mdot
.69313 .39835 Mdot
.04858 .4427 Mdot
.33229 .57096 Mdot
.40846 .03318 Mdot
.35477 .14989 Mdot
.11224 .24553 Mdot
.50095 .61675 Mdot
.50302 .61396 Mdot
.50961 .60505 Mdot
.53062 .57683 Mdot
.59729 .49216 Mdot
.80096 .35211 Mdot
.23123 .49863 Mdot
.42443 .56608 Mdot
.50849 .55822 Mdot
.60527 .46759 Mdot
.8487 .34752 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00204 Mdot
.49519 .0065 Mdot
.48467 .02069 Mdot
.45118 .06524 Mdot
.34562 .18695 Mdot
.04312 .22644 Mdot
.67673 .09426 Mdot
.52422 .07189 Mdot
.4079 .15259 Mdot
.16101 .27766 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49594 .00549 Mdot
.48706 .01746 Mdot
.45881 .05523 Mdot
.36945 .16313 Mdot
.10549 .25392 Mdot
.69463 .11522 Mdot
.50821 .10761 Mdot
.33409 .23504 Mdot
.95379 .1928 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49292 .00957 Mdot
.47743 .03042 Mdot
.42822 .09473 Mdot
.27494 .24047 Mdot
.88585 .14349 Mdot
.65368 .02215 Mdot
.61784 .54065 Mdot
.74306 .39324 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61167 Mdot
.51501 .59778 Mdot
.54779 .55414 Mdot
.65118 .43413 Mdot
.94874 .38743 Mdot
.32187 .52018 Mdot
.4802 .53849 Mdot
.6089 .44523 Mdot
.88851 .35012 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49516 .00654 Mdot
.48457 .02082 Mdot
.45089 .06563 Mdot
.3447 .18781 Mdot
.04081 .22524 Mdot
.67637 .0932 Mdot
.52557 .0696 Mdot
.41296 .14632 Mdot
.17621 .27829 Mdot
.50103 .61664 Mdot
.50328 .6136 Mdot
.51045 .60392 Mdot
.53329 .57328 Mdot
.60571 .48233 Mdot
.82528 .35099 Mdot
.25737 .49837 Mdot
.45099 .54309 Mdot
.57225 .47839 Mdot
.79819 .33756 Mdot
.25201 .48509 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.5009 .61681 Mdot
.50288 .61414 Mdot
.50918 .60563 Mdot
.52925 .57866 Mdot
.59296 .4973 Mdot
.78831 .35401 Mdot
.21551 .4981 Mdot
.40956 .57751 Mdot
.47513 .60047 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.50929 .60548 Mdot
.5296 .5782 Mdot
.59406 .49599 Mdot
.79153 .35344 Mdot
.21965 .49831 Mdot
.41337 .57471 Mdot
.48347 .59001 Mdot
.52881 .56345 Mdot
.61713 .4644 Mdot
.50104 .61662 Mdot
.50333 .61354 Mdot
.5106 .60371 Mdot
.53377 .57264 Mdot
.60722 .48059 Mdot
.82961 .35112 Mdot
.26148 .49828 Mdot
.45524 .53923 Mdot
.58275 .46593 Mdot
.82885 .33613 Mdot
.28499 .48012 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60703 Mdot
.52595 .58308 Mdot
.5825 .50999 Mdot
.75732 .3626 Mdot
.17063 .49217 Mdot
.37428 .59697 Mdot
.40836 .05928 Mdot
.31245 .19561 Mdot
.99594 .19185 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49548 .00611 Mdot
.4856 .01944 Mdot
.45416 .06135 Mdot
.35489 .178 Mdot
.06689 .23819 Mdot
.68148 .10411 Mdot
.51302 .09205 Mdot
.36408 .20329 Mdot
.50129 .61629 Mdot
.50411 .61249 Mdot
.51308 .60037 Mdot
.54166 .56219 Mdot
.63203 .45335 Mdot
.89849 .3655 Mdot
.3071 .50365 Mdot
.49218 .51089 Mdot
.66554 .38365 Mdot
.04478 .42462 Mdot
.35774 .53963 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .60219 Mdot
.53737 .56787 Mdot
.61854 .46786 Mdot
.86153 .35508 Mdot
.287 .49866 Mdot
.48015 .51701 Mdot
.64361 .40122 Mdot
.99442 .39605 Mdot
.3536 .51343 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51129 .60278 Mdot
.53597 .56972 Mdot
.61413 .47275 Mdot
.8492 .35295 Mdot
.27811 .4982 Mdot
.472 .52403 Mdot
.6241 .42029 Mdot
.94405 .36949 Mdot
.34621 .49089 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61757 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60315 Mdot
.53509 .57088 Mdot
.61139 .47585 Mdot
.84145 .352 Mdot
.27191 .49815 Mdot
.46589 .52953 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00487 Mdot
.48851 .01551 Mdot
.46341 .04913 Mdot
.38392 .14745 Mdot
.14533 .26423 Mdot
.71781 .11969 Mdot
.52414 .09739 Mdot
.36656 .2071 Mdot
.03146 .23608 Mdot
.64947 .117 Mdot
.50127 .61631 Mdot
.50405 .61256 Mdot
.51292 .6006 Mdot
.54113 .56289 Mdot
.63035 .45512 Mdot
.89395 .36392 Mdot
.30512 .50271 Mdot
.49172 .51038 Mdot
.66591 .38295 Mdot
.04629 .42526 Mdot
.3582 .54 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00511 Mdot
.48794 .01629 Mdot
.46159 .05155 Mdot
.37818 .15378 Mdot
.12937 .26093 Mdot
.70718 .11869 Mdot
.51513 .10469 Mdot
.34574 .22633 Mdot
.97954 .20741 Mdot
.64394 .09143 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50482 .61153 Mdot
.51535 .59732 Mdot
.54886 .55274 Mdot
.6545 .43097 Mdot
.95718 .39175 Mdot
.32332 .52392 Mdot
.4756 .54645 Mdot
.59143 .46627 Mdot
.83699 .34022 Mdot
.49997 5e-05 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00466 Mdot
.48901 .01485 Mdot
.46499 .04704 Mdot
.38887 .1419 Mdot
.15928 .26611 Mdot
.7287 .11989 Mdot
.53472 .08796 Mdot
.3924 .18028 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49867 .0018 Mdot
.49575 .00574 Mdot
.48646 .01828 Mdot
.45687 .05778 Mdot
.36338 .16944 Mdot
.08922 .24789 Mdot
.68813 .11135 Mdot
.50796 .10398 Mdot
.33972 .2287 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00371 Mdot
.49124 .01183 Mdot
.4721 .03756 Mdot
.41133 .11558 Mdot
.22432 .26121 Mdot
.80167 .12137 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51222 .60153 Mdot
.53892 .56581 Mdot
.62341 .46253 Mdot
.87503 .35822 Mdot
.29542 .49979 Mdot
.48674 .51207 Mdot
.65819 .3884 Mdot
.02975 .41582 Mdot
.35694 .53129 Mdot
.50027 .61767 Mdot
.50087 .61687 Mdot
.50276 .61431 Mdot
.50878 .60617 Mdot
.52798 .58037 Mdot
.58892 .50216 Mdot
.7764 .35664 Mdot
.19934 .49678 Mdot
.39554 .58681 Mdot
.44606 .01784 Mdot
.4172 .09118 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49002 .01347 Mdot
.46823 .04273 Mdot
.39908 .13014 Mdot
.18851 .26681 Mdot
.7568 .1194 Mdot
.5636 .06199 Mdot
.4633 .09572 Mdot
.30842 .23344 Mdot
.93071 .17121 Mdot
.49971 .0004 Mdot
.49907 .00126 Mdot
.49702 .00402 Mdot
.49052 .0128 Mdot
.46981 .04062 Mdot
.40408 .12426 Mdot
.20302 .26542 Mdot
.77355 .11949 Mdot
.58021 .04824 Mdot
.50215 .04625 Mdot
.42731 .11132 Mdot
.24719 .25884 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.50099 .6167 Mdot
.50316 .61377 Mdot
.51005 .60446 Mdot
.53202 .57497 Mdot
.6017 .48698 Mdot
.81375 .35111 Mdot
.24564 .4986 Mdot
.43888 .55388 Mdot
.54269 .51477 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.5115 .60251 Mdot
.53662 .56885 Mdot
.6162 .47045 Mdot
.85499 .35386 Mdot
.28243 .49836 Mdot
.47607 .52046 Mdot
.63396 .41042 Mdot
.96988 .38267 Mdot
.35071 .50164 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50832 .6068 Mdot
.5265 .58234 Mdot
.58426 .50783 Mdot
.76257 .36074 Mdot
.17888 .4938 Mdot
.37989 .59487 Mdot
.41737 .05005 Mdot
.33639 .17639 Mdot
.05099 .22285 Mdot
.4998 .00027 Mdot
.49936 .00086 Mdot
.49797 .00275 Mdot
.49352 .00875 Mdot
.47936 .02783 Mdot
.43434 .08699 Mdot
.29359 .22903 Mdot
.923 .16041 Mdot
.66346 .03414 Mdot
.60822 .5594 Mdot
.70309 .41822 Mdot
.02639 .44257 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45743 .05704 Mdot
.36514 .16763 Mdot
.09391 .24972 Mdot
.68985 .11259 Mdot
.50767 .10548 Mdot
.33699 .23153 Mdot
.96237 .19697 Mdot
.64367 .08115 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48875 .01519 Mdot
.46418 .04812 Mdot
.38632 .14477 Mdot
.15208 .26526 Mdot
.72288 .11985 Mdot
.52896 .09315 Mdot
.37824 .19534 Mdot
.06218 .25152 Mdot
.6552 .12938 Mdot
.5011 .61655 Mdot
.50351 .6133 Mdot
.51117 .60295 Mdot
.53558 .57024 Mdot
.6129 .47414 Mdot
.84573 .35249 Mdot
.27539 .49816 Mdot
.46935 .5264 Mdot
.61762 .42702 Mdot
.92669 .36143 Mdot
.34188 .48507 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48813 .01602 Mdot
.46221 .05073 Mdot
.38012 .15165 Mdot
.13475 .26217 Mdot
.71055 .11914 Mdot
.51779 .10268 Mdot
.35164 .22115 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .616 Mdot
.50479 .61156 Mdot
.51527 .59743 Mdot
.54861 .55306 Mdot
.65373 .4317 Mdot
.95523 .39074 Mdot
.323 .52303 Mdot
.47671 .54455 Mdot
.59562 .46114 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49659 .00461 Mdot
.48912 .01469 Mdot
.46535 .04655 Mdot
.39003 .14058 Mdot
.16256 .26641 Mdot
.73149 .11987 Mdot
.53754 .08539 Mdot
.39938 .17257 Mdot
.12016 .27368 Mdot
.67734 .14125 Mdot
.50127 .61632 Mdot
.50405 .61257 Mdot
.51289 .60063 Mdot
.54105 .563 Mdot
.6301 .45538 Mdot
.89328 .36369 Mdot
.30481 .50257 Mdot
.49163 .51033 Mdot
.6659 .38291 Mdot
.04633 .42526 Mdot
.35825 .53997 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.50099 .61669 Mdot
.50316 .61377 Mdot
.51007 .60444 Mdot
.53206 .57492 Mdot
.60182 .48684 Mdot
.8141 .3511 Mdot
.24601 .4986 Mdot
.43927 .55354 Mdot
.54362 .51361 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48771 .01659 Mdot
.46086 .05251 Mdot
.37589 .15626 Mdot
.12306 .25931 Mdot
.70349 .11802 Mdot
.51253 .10642 Mdot
.34035 .23082 Mdot
.96687 .20033 Mdot
.64273 .08505 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48716 .01734 Mdot
.4591 .05484 Mdot
.37036 .16217 Mdot
.10797 .25476 Mdot
.69576 .1157 Mdot
.50856 .10777 Mdot
.33419 .23515 Mdot
.95371 .19284 Mdot
.64169 .07816 Mdot
.50132 .61625 Mdot
.50421 .61234 Mdot
.51343 .59991 Mdot
.54276 .56074 Mdot
.63547 .44978 Mdot
.90771 .36894 Mdot
.31076 .50586 Mdot
.49226 .51303 Mdot
.66217 .38739 Mdot
.03536 .4199 Mdot
.35595 .53594 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45872 .05535 Mdot
.36916 .16343 Mdot
.10472 .25366 Mdot
.69429 .11506 Mdot
.50812 .10754 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00494 Mdot
.48836 .01572 Mdot
.46293 .04977 Mdot
.3824 .14914 Mdot
.14109 .26347 Mdot
.7148 .11952 Mdot
.52142 .09972 Mdot
.36007 .21337 Mdot
.01483 .2271 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61075 Mdot
.51718 .59485 Mdot
.55469 .54514 Mdot
.67264 .41469 Mdot
.00166 .41623 Mdot
.32819 .54632 Mdot
.44423 .59697 Mdot
.47832 .61701 Mdot
.50013 .61786 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50417 .6124 Mdot
.51329 .60009 Mdot
.54233 .56131 Mdot
.63411 .45118 Mdot
.90408 .36755 Mdot
.30938 .50494 Mdot
.49237 .51202 Mdot
.66391 .38554 Mdot
.50129 .61629 Mdot
.50412 .61246 Mdot
.51314 .6003 Mdot
.54184 .56196 Mdot
.63257 .45279 Mdot
.89994 .36602 Mdot
.30771 .50397 Mdot
.49227 .51113 Mdot
.66524 .38403 Mdot
.04387 .42418 Mdot
.35753 .53931 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.49229 .01042 Mdot
.47544 .0331 Mdot
.42188 .10264 Mdot
.2558 .25009 Mdot
.85114 .13135 Mdot
.63861 .01849 Mdot
.60869 .54341 Mdot
.72944 .3971 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .60131 Mdot
.53946 .5651 Mdot
.6251 .4607 Mdot
.87967 .35948 Mdot
.29802 .50036 Mdot
.48842 .51108 Mdot
.66148 .38578 Mdot
.03727 .42002 Mdot
.35767 .53507 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.49309 .00933 Mdot
.47799 .02968 Mdot
.42997 .09253 Mdot
.28025 .23742 Mdot
.8961 .1478 Mdot
.65697 .02475 Mdot
.61692 .54388 Mdot
.7369 .39684 Mdot
.5009 .61681 Mdot
.50288 .61415 Mdot
.50916 .60566 Mdot
.52919 .57875 Mdot
.59275 .49756 Mdot
.78768 .35413 Mdot
.21469 .49806 Mdot
.40882 .57804 Mdot
.47353 .60246 Mdot
.49873 .60363 Mdot
.52203 .58327 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51004 .60447 Mdot
.53199 .57501 Mdot
.6016 .4871 Mdot
.81346 .35113 Mdot
.24532 .49861 Mdot
.43856 .55416 Mdot
.54192 .51575 Mdot
.70742 .37345 Mdot
.10317 .46253 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00533 Mdot
.48744 .01696 Mdot
.45999 .05366 Mdot
.37317 .15918 Mdot
.1156 .25718 Mdot
.69948 .117 Mdot
.51017 .10758 Mdot
.33611 .23405 Mdot
.9574 .19503 Mdot
.64184 .08027 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50297 .61403 Mdot
.50945 .60527 Mdot
.53009 .57754 Mdot
.59561 .49415 Mdot
.79606 .35274 Mdot
.22532 .49851 Mdot
.41871 .57064 Mdot
.49539 .57491 Mdot
.56516 .51618 Mdot
.50022 .61774 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50697 .60862 Mdot
.52219 .58811 Mdot
.57061 .52478 Mdot
.72149 .3796 Mdot
.10729 .4717 Mdot
.34407 .59421 Mdot
.38261 .0754 Mdot
.26061 .22262 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60459 Mdot
.53172 .57538 Mdot
.60074 .4881 Mdot
.81097 .35125 Mdot
.24263 .49864 Mdot
.43582 .55654 Mdot
.53532 .52406 Mdot
.68737 .38779 Mdot
.05991 .44203 Mdot
.5012 .61642 Mdot
.50381 .61289 Mdot
.51214 .60164 Mdot
.53866 .56616 Mdot
.62259 .46342 Mdot
.87277 .35763 Mdot
.2941 .49955 Mdot
.48581 .51269 Mdot
.65626 .39 Mdot
.02523 .41329 Mdot
.35651 .52901 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61094 Mdot
.51672 .59547 Mdot
.55323 .54703 Mdot
.66811 .41859 Mdot
.99082 .41009 Mdot
.32729 .54057 Mdot
.45262 .58385 Mdot
.50794 .57649 Mdot
.57516 .50937 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.4899 .01364 Mdot
.46784 .04325 Mdot
.39785 .13158 Mdot
.18495 .26697 Mdot
.75298 .11945 Mdot
.5597 .06539 Mdot
.45389 .10754 Mdot
.27988 .2525 Mdot
.87133 .14579 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00212 Mdot
.495 .00676 Mdot
.48407 .0215 Mdot
.44928 .06772 Mdot
.3397 .19245 Mdot
.02832 .21856 Mdot
.67468 .08723 Mdot
.53353 .05638 Mdot
.44232 .10869 Mdot
.26645 .25545 Mdot
.50094 .61676 Mdot
.503 .61398 Mdot
.50956 .60512 Mdot
.53046 .57705 Mdot
.59677 .49277 Mdot
.79945 .35229 Mdot
.22944 .4986 Mdot
.42268 .5675 Mdot
.50444 .56338 Mdot
.59287 .48209 Mdot
.81284 .34589 Mdot
.50057 .61726 Mdot
.50182 .61557 Mdot
.50581 .61018 Mdot
.51852 .59305 Mdot
.55893 .53966 Mdot
.68574 .40398 Mdot
.03209 .43353 Mdot
.33063 .56254 Mdot
.42041 .01525 Mdot
.39574 .10514 Mdot
.22561 .25096 Mdot
.50023 .61772 Mdot
.50074 .61703 Mdot
.50236 .61484 Mdot
.50753 .60786 Mdot
.524 .5857 Mdot
.57632 .51763 Mdot
.73877 .37045 Mdot
.13937 .48376 Mdot
.35662 .59942 Mdot
.38674 .07774 Mdot
.26096 .22493 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49384 .00833 Mdot
.48036 .02648 Mdot
.43751 .08294 Mdot
.30332 .22228 Mdot
.94367 .17114 Mdot
.66676 .04332 Mdot
.59667 .57714 Mdot
.66284 .45117 Mdot
.93283 .39073 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50895 .60594 Mdot
.52852 .57964 Mdot
.59064 .50009 Mdot
.78147 .35542 Mdot
.20639 .49746 Mdot
.40148 .58307 Mdot
.45806 .00347 Mdot
.45245 .0469 Mdot
.37657 .1502 Mdot
.50058 .61726 Mdot
.50183 .61556 Mdot
.50584 .61015 Mdot
.5186 .59295 Mdot
.55918 .53934 Mdot
.68652 .40337 Mdot
.03385 .43452 Mdot
.33079 .56346 Mdot
.41909 .01724 Mdot
.3912 .11043 Mdot
.21252 .2539 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48931 .01443 Mdot
.46596 .04575 Mdot
.39192 .13842 Mdot
.16795 .26679 Mdot
.73627 .11979 Mdot
.54244 .08091 Mdot
.41152 .15878 Mdot
.15461 .28061 Mdot
.70058 .14012 Mdot
.50108 .61658 Mdot
.50343 .61339 Mdot
.51094 .60326 Mdot
.53485 .5712 Mdot
.61063 .47671 Mdot
.8393 .35178 Mdot
.2701 .49815 Mdot
.46407 .53118 Mdot
.60461 .44103 Mdot
.89101 .3477 Mdot
.32841 .4777 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49806 .00263 Mdot
.49381 .00837 Mdot
.48027 .02661 Mdot
.43721 .08332 Mdot
.3024 .22294 Mdot
.94167 .17007 Mdot
.66649 .04237 Mdot
.59793 .57524 Mdot
.66718 .44723 Mdot
.94355 .39598 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00379 Mdot
.49107 .01206 Mdot
.47157 .03828 Mdot
.40964 .11762 Mdot
.21932 .26243 Mdot
.7947 .12067 Mdot
.59946 .03435 Mdot
.54387 .61223 Mdot
.55327 .56376 Mdot
.64109 .44943 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48963 .01401 Mdot
.46696 .04442 Mdot
.39509 .13478 Mdot
.17701 .26708 Mdot
.74487 .11961 Mdot
.55133 .07285 Mdot
.43346 .13275 Mdot
.21866 .27745 Mdot
.76974 .13104 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00394 Mdot
.4907 .01256 Mdot
.47038 .03986 Mdot
.40589 .12211 Mdot
.20832 .26462 Mdot
.78015 .11972 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49487 .00693 Mdot
.48366 .02205 Mdot
.44797 .06943 Mdot
.33564 .19613 Mdot
.0183 .21305 Mdot
.67357 .08219 Mdot
.54058 .04498 Mdot
.4678 .07463 Mdot
.34704 .19559 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56787 .52824 Mdot
.71317 .38463 Mdot
.09083 .46433 Mdot
.33952 .58914 Mdot
.38627 .0678 Mdot
.27656 .21329 Mdot
.93145 .15169 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49392 .00822 Mdot
.48062 .02614 Mdot
.43834 .08188 Mdot
.30585 .22044 Mdot
.94918 .17412 Mdot
.66745 .04598 Mdot
.59306 .58257 Mdot
.65044 .46297 Mdot
.90134 .37725 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51058 .60375 Mdot
.53369 .57274 Mdot
.60697 .48087 Mdot
.8289 .35109 Mdot
.26082 .4983 Mdot
.45456 .53985 Mdot
.58106 .46791 Mdot
.82397 .33602 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48082 .02587 Mdot
.43896 .08108 Mdot
.30777 .21901 Mdot
.95341 .17643 Mdot
.66794 .04807 Mdot
.59016 .58692 Mdot
.64051 .47294 Mdot
.87528 .36879 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01313 Mdot
.46903 .04166 Mdot
.40163 .12716 Mdot
.19588 .26625 Mdot
.76507 .11937 Mdot
.57192 .05494 Mdot
.48303 .07065 Mdot
.36872 .17901 Mdot
.07907 .24933 Mdot
.50051 .61734 Mdot
.50163 .61584 Mdot
.50519 .61103 Mdot
.51652 .59574 Mdot
.55259 .54787 Mdot
.66611 .42035 Mdot
.98596 .40736 Mdot
.32684 .53804 Mdot
.45628 .57806 Mdot
.52096 .55868 Mdot
.617 .45973 Mdot
.50067 .61713 Mdot
.50214 .61514 Mdot
.50682 .60883 Mdot
.52172 .58876 Mdot
.56909 .5267 Mdot
.71686 .38234 Mdot
.09822 .46773 Mdot
.34142 .59159 Mdot
.3842 .07169 Mdot
.26821 .21827 Mdot
.91505 .1432 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00636 Mdot
.48501 .02023 Mdot
.45227 .06382 Mdot
.34901 .18372 Mdot
.05174 .23085 Mdot
.67822 .09806 Mdot
.51956 .07997 Mdot
.39017 .1739 Mdot
.10879 .26708 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49516 .00653 Mdot
.4846 .02079 Mdot
.45096 .06554 Mdot
.34491 .18762 Mdot
.04134 .22551 Mdot
.67645 .09344 Mdot
.52526 .07012 Mdot
.41181 .14776 Mdot
.50018 .61779 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50583 .61016 Mdot
.51857 .59298 Mdot
.5591 .53944 Mdot
.68626 .40357 Mdot
.03327 .43419 Mdot
.33073 .56315 Mdot
.41953 .01658 Mdot
.3927 .10869 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49836 .00221 Mdot
.49478 .00705 Mdot
.48338 .02243 Mdot
.4471 .07057 Mdot
.33291 .19854 Mdot
.01166 .20934 Mdot
.67294 .07876 Mdot
.5455 .03716 Mdot
.48538 .05069 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49174 .01116 Mdot
.47367 .03546 Mdot
.4163 .10953 Mdot
.23908 .25673 Mdot
.82369 .12471 Mdot
.6219 .02244 Mdot
.58559 .5649 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50612 .60976 Mdot
.51951 .59172 Mdot
.56209 .53561 Mdot
.69546 .39664 Mdot
.05368 .44547 Mdot
.3329 .57345 Mdot
.40504 .03831 Mdot
.34306 .16134 Mdot
.082 .23404 Mdot
.50127 .61631 Mdot
.50405 .61256 Mdot
.51292 .60059 Mdot
.54114 .56288 Mdot
.63039 .45508 Mdot
.89405 .36396 Mdot
.30516 .50273 Mdot
.49173 .51039 Mdot
.66591 .38296 Mdot
.04627 .42525 Mdot
.3582 .54 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00379 Mdot
.49107 .01206 Mdot
.47156 .03828 Mdot
.40962 .11763 Mdot
.21929 .26244 Mdot
.79465 .12066 Mdot
.59942 .03438 Mdot
.54379 .61233 Mdot
.55303 .56407 Mdot
.64033 .45019 Mdot
.50036 .61754 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51175 .60217 Mdot
.53741 .56782 Mdot
.61866 .46772 Mdot
.86187 .35515 Mdot
.28723 .49868 Mdot
.48035 .51685 Mdot
.64407 .4008 Mdot
.99556 .39669 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48683 .01778 Mdot
.45807 .0562 Mdot
.36715 .16554 Mdot
.09929 .25174 Mdot
.69197 .11389 Mdot
.5077 .10676 Mdot
.33496 .23378 Mdot
.9567 .19413 Mdot
.64259 .07893 Mdot
.501 .61668 Mdot
.50319 .61373 Mdot
.51015 .60432 Mdot
.53234 .57454 Mdot
.60271 .4858 Mdot
.81667 .35101 Mdot
.24872 .49855 Mdot
.44205 .5511 Mdot
.55035 .5052 Mdot
.73292 .3585 Mdot
.15286 .47941 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00272 Mdot
.49358 .00867 Mdot
.47956 .02757 Mdot
.43495 .08621 Mdot
.29546 .22777 Mdot
.92692 .16238 Mdot
.66418 .03577 Mdot
.60631 .56241 Mdot
.69631 .42318 Mdot
.01158 .43391 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49643 .00483 Mdot
.48861 .01538 Mdot
.46373 .04871 Mdot
.38492 .14634 Mdot
.14814 .26468 Mdot
.71988 .11977 Mdot
.52608 .0957 Mdot
.37123 .20247 Mdot
.04362 .24241 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .60559 Mdot
.52935 .57854 Mdot
.59325 .49695 Mdot
.78918 .35385 Mdot
.21663 .49816 Mdot
.41059 .57676 Mdot
.47736 .59768 Mdot
.5103 .58813 Mdot
.55868 .53496 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50707 .60848 Mdot
.52253 .58766 Mdot
.57168 .52343 Mdot
.72475 .37774 Mdot
.11356 .47431 Mdot
.34612 .59575 Mdot
.38217 .07724 Mdot
.25719 .22464 Mdot
.89371 .13327 Mdot
.5007 .61709 Mdot
.50224 .61501 Mdot
.50713 .60841 Mdot
.5227 .58743 Mdot
.57222 .52275 Mdot
.7264 .37682 Mdot
.11668 .47556 Mdot
.34721 .59643 Mdot
.38216 .07793 Mdot
.25607 .22537 Mdot
.89142 .13233 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00505 Mdot
.4881 .01607 Mdot
.46211 .05086 Mdot
.37981 .15199 Mdot
.13388 .26198 Mdot
.70999 .11907 Mdot
.51733 .10304 Mdot
.35061 .22208 Mdot
.99128 .214 Mdot
.64503 .0974 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48906 .01477 Mdot
.46517 .0468 Mdot
.38944 .14125 Mdot
.16089 .26627 Mdot
.73006 .11988 Mdot
.53609 .08671 Mdot
.39579 .17656 Mdot
.11011 .27069 Mdot
.67213 .14045 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49035 .01303 Mdot
.46926 .04135 Mdot
.40236 .12629 Mdot
.19801 .26604 Mdot
.76755 .11939 Mdot
.57438 .05292 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49035 .01303 Mdot
.46927 .04134 Mdot
.40238 .12627 Mdot
.19808 .26603 Mdot
.76764 .11939 Mdot
.57446 .05285 Mdot
.48895 .06309 Mdot
.38687 .15935 Mdot
.12903 .26629 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50758 .6078 Mdot
.52413 .58551 Mdot
.57675 .51709 Mdot
.74008 .36983 Mdot
.14169 .48451 Mdot
.35774 .59951 Mdot
.38771 .07716 Mdot
.26286 .22422 Mdot
.90006 .13754 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51224 .60151 Mdot
.53898 .56573 Mdot
.6236 .46232 Mdot
.87554 .35835 Mdot
.29572 .49985 Mdot
.48694 .51194 Mdot
.6586 .38807 Mdot
.03069 .41634 Mdot
.35703 .53176 Mdot
.50079 .61697 Mdot
.5025 .61465 Mdot
.50797 .60727 Mdot
.52539 .58383 Mdot
.58073 .51215 Mdot
.75205 .36462 Mdot
.16208 .49022 Mdot
.36889 .59848 Mdot
.40053 .06678 Mdot
.29248 .2091 Mdot
.95416 .16718 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00407 Mdot
.49041 .01295 Mdot
.46946 .04109 Mdot
.40296 .12558 Mdot
.19977 .26584 Mdot
.76963 .11941 Mdot
.57642 .05126 Mdot
.49347 .05731 Mdot
.40073 .14349 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00505 Mdot
.48809 .01608 Mdot
.46207 .05091 Mdot
.3797 .15212 Mdot
.13356 .26191 Mdot
.70979 .11905 Mdot
.51717 .10316 Mdot
.35024 .2224 Mdot
.50003 .61799 Mdot
.5001 .61791 Mdot
.5003 .61762 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50981 .60479 Mdot
.53124 .57601 Mdot
.59924 .48985 Mdot
.80664 .35155 Mdot
.23782 .49867 Mdot
.43096 .56069 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.4977 .0031 Mdot
.49269 .00988 Mdot
.4767 .0314 Mdot
.4259 .09764 Mdot
.26792 .24425 Mdot
.87272 .13844 Mdot
.64873 .01976 Mdot
.61675 .53901 Mdot
.74461 .39155 Mdot
.11107 .48636 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51208 .60172 Mdot
.53847 .5664 Mdot
.62202 .46404 Mdot
.87118 .35724 Mdot
.29315 .49939 Mdot
.48512 .51317 Mdot
.65479 .39125 Mdot
.02173 .41133 Mdot
.35618 .52724 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.5417 .56214 Mdot
.63214 .45324 Mdot
.89878 .3656 Mdot
.30722 .50371 Mdot
.4922 .51094 Mdot
.66548 .38372 Mdot
.04462 .42454 Mdot
.3577 .53957 Mdot
.50075 .61702 Mdot
.5024 .6148 Mdot
.50763 .60772 Mdot
.52432 .58527 Mdot
.57733 .51637 Mdot
.74183 .36902 Mdot
.14474 .48546 Mdot
.35926 .59958 Mdot
.38912 .07622 Mdot
.2658 .22303 Mdot
.90492 .14004 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00287 Mdot
.49322 .00916 Mdot
.47841 .02911 Mdot
.4313 .09084 Mdot
.28432 .23497 Mdot
.90413 .15137 Mdot
.65921 .02719 Mdot
.61521 .5475 Mdot
.72933 .4012 Mdot
.08018 .47243 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50755 .60783 Mdot
.52407 .5856 Mdot
.57654 .51735 Mdot
.73945 .37013 Mdot
.14057 .48415 Mdot
.3572 .59947 Mdot
.38723 .07745 Mdot
.26191 .22458 Mdot
.89853 .13676 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48711 .0174 Mdot
.45895 .05503 Mdot
.36991 .16265 Mdot
.10674 .25435 Mdot
.6952 .11546 Mdot
.50837 .1077 Mdot
.33411 .23512 Mdot
.95367 .19278 Mdot
.50072 .61706 Mdot
.50231 .61492 Mdot
.50735 .60811 Mdot
.5234 .5865 Mdot
.57443 .51998 Mdot
.73308 .37327 Mdot
.12912 .48026 Mdot
.35203 .59851 Mdot
.38362 .07901 Mdot
.25578 .22646 Mdot
.88937 .13196 Mdot
.49989 .00015 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48892 .01497 Mdot
.4647 .04742 Mdot
.38798 .14291 Mdot
.15675 .26584 Mdot
.72661 .11989 Mdot
.53262 .08985 Mdot
.38724 .18586 Mdot
.08651 .26217 Mdot
.50005 .61797 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50165 .6158 Mdot
.50526 .61093 Mdot
.51675 .59543 Mdot
.55333 .54691 Mdot
.66842 .41832 Mdot
.99156 .4105 Mdot
.32735 .54096 Mdot
.45206 .58473 Mdot
.50128 .61631 Mdot
.50407 .61253 Mdot
.51298 .60051 Mdot
.54134 .56261 Mdot
.63102 .45441 Mdot
.89576 .36454 Mdot
.30592 .50307 Mdot
.49194 .51054 Mdot
.66586 .38314 Mdot
.04594 .42513 Mdot
.35806 .53996 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51159 .60239 Mdot
.5369 .56849 Mdot
.61707 .46949 Mdot
.85742 .35429 Mdot
.28416 .49845 Mdot
.47765 .5191 Mdot
.63773 .40677 Mdot
.97957 .38788 Mdot
.35197 .50616 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60555 Mdot
.52945 .5784 Mdot
.59359 .49655 Mdot
.79015 .35368 Mdot
.21789 .49823 Mdot
.41173 .57592 Mdot
.47987 .59454 Mdot
.51789 .57799 Mdot
.50067 .61712 Mdot
.50215 .61513 Mdot
.50684 .60879 Mdot
.52181 .58864 Mdot
.56937 .52634 Mdot
.71773 .38182 Mdot
.09994 .4685 Mdot
.34189 .59212 Mdot
.38382 .07248 Mdot
.26654 .21923 Mdot
.91182 .1416 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.53639 .56916 Mdot
.61547 .47126 Mdot
.85297 .35353 Mdot
.28095 .49829 Mdot
.4747 .52165 Mdot
.63065 .41369 Mdot
.96129 .37815 Mdot
.34943 .49783 Mdot
.50089 .61683 Mdot
.50285 .61419 Mdot
.50907 .60579 Mdot
.52889 .57915 Mdot
.5918 .49869 Mdot
.7849 .35468 Mdot
.21102 .49782 Mdot
.40553 .58035 Mdot
.46651 .61116 Mdot
.47763 .01379 Mdot
.45531 .05468 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49678 .00435 Mdot
.48975 .01385 Mdot
.46734 .04391 Mdot
.39629 .13339 Mdot
.18046 .26708 Mdot
.74832 .11954 Mdot
.55491 .06964 Mdot
.44222 .12203 Mdot
.24477 .2695 Mdot
.80871 .13188 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53083 .57656 Mdot
.59794 .49138 Mdot
.80287 .3519 Mdot
.23348 .49865 Mdot
.42664 .56428 Mdot
.51361 .55168 Mdot
.62096 .45003 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46941 .04115 Mdot
.40284 .12573 Mdot
.19939 .26588 Mdot
.76919 .11941 Mdot
.57598 .05161 Mdot
.49247 .0586 Mdot
.39766 .14707 Mdot
.1597 .27149 Mdot
.50101 .61667 Mdot
.50323 .61367 Mdot
.51028 .60415 Mdot
.53275 .574 Mdot
.60401 .4843 Mdot
.8204 .35095 Mdot
.25255 .49848 Mdot
.44599 .54759 Mdot
.55998 .49329 Mdot
.76181 .34616 Mdot
.20172 .48696 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.4985 .00202 Mdot
.49523 .00644 Mdot
.4848 .02051 Mdot
.45161 .06468 Mdot
.34696 .18568 Mdot
.04652 .2282 Mdot
.67729 .09578 Mdot
.52231 .07517 Mdot
.40068 .16138 Mdot
.13956 .27481 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49768 .00314 Mdot
.49259 .01 Mdot
.47641 .0318 Mdot
.42496 .09881 Mdot
.26508 .2457 Mdot
.86753 .13659 Mdot
.64653 .01914 Mdot
.61556 .53921 Mdot
.74309 .39181 Mdot
.10913 .48523 Mdot
.50049 .61737 Mdot
.50158 .6159 Mdot
.50502 .61125 Mdot
.51601 .59643 Mdot
.55097 .54999 Mdot
.66107 .42488 Mdot
.9736 .40052 Mdot
.32555 .53175 Mdot
.46516 .56379 Mdot
.55293 .51562 Mdot
.71864 .37093 Mdot
.49989 .00015 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48893 .01495 Mdot
.46475 .04736 Mdot
.38812 .14275 Mdot
.15715 .26589 Mdot
.72694 .11989 Mdot
.53295 .08956 Mdot
.38805 .18499 Mdot
.08873 .26305 Mdot
.49966 .00046 Mdot
.49893 .00145 Mdot
.49658 .00463 Mdot
.48909 .01473 Mdot
.46525 .04669 Mdot
.3897 .14096 Mdot
.16162 .26633 Mdot
.73068 .11987 Mdot
.53672 .08613 Mdot
.39735 .17483 Mdot
.11447 .27203 Mdot
.67431 .14086 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00256 Mdot
.49397 .00815 Mdot
.48078 .02593 Mdot
.43883 .08125 Mdot
.30736 .21931 Mdot
.9525 .17593 Mdot
.66784 .04762 Mdot
.59079 .58598 Mdot
.64266 .47074 Mdot
.88099 .37041 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50538 .61076 Mdot
.51715 .59489 Mdot
.5546 .54526 Mdot
.67235 .41493 Mdot
.00098 .41584 Mdot
.32814 .54595 Mdot
.44477 .59614 Mdot
.4802 .61444 Mdot
.48601 .00937 Mdot
.50023 .61772 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50748 .60793 Mdot
.52382 .58593 Mdot
.57576 .51832 Mdot
.73711 .37126 Mdot
.13641 .48279 Mdot
.35524 .59924 Mdot
.38565 .07832 Mdot
.25893 .22563 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50932 .60545 Mdot
.52969 .57808 Mdot
.59433 .49566 Mdot
.79234 .35331 Mdot
.22068 .49835 Mdot
.41433 .574 Mdot
.48558 .58734 Mdot
.53524 .55494 Mdot
.63733 .44285 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49565 .00587 Mdot
.48615 .0187 Mdot
.45589 .05907 Mdot
.36032 .17256 Mdot
.0811 .24454 Mdot
.68543 .10897 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00544 Mdot
.48718 .01731 Mdot
.45917 .05475 Mdot
.37058 .16194 Mdot
.10855 .25495 Mdot
.69603 .11581 Mdot
.50865 .10779 Mdot
.33425 .23514 Mdot
.95378 .19289 Mdot
.50083 .61691 Mdot
.50265 .61445 Mdot
.50846 .60661 Mdot
.52693 .58176 Mdot
.58562 .50616 Mdot
.76663 .35942 Mdot
.18507 .49486 Mdot
.38437 .59287 Mdot
.42509 .04175 Mdot
.35754 .15687 Mdot
.10372 .24636 Mdot
.49998 3e-05 Mdot
.49994 9e-05 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49791 .00282 Mdot
.49335 .00898 Mdot
.47883 .02855 Mdot
.43264 .08914 Mdot
.28841 .23241 Mdot
.91236 .15521 Mdot
.66123 .03003 Mdot
.61265 .55213 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60075 Mdot
.54077 .56337 Mdot
.62921 .45632 Mdot
.89087 .36289 Mdot
.3037 .50212 Mdot
.49125 .51023 Mdot
.66568 .38291 Mdot
.04612 .42507 Mdot
.35834 .53973 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49645 .0048 Mdot
.48868 .01529 Mdot
.46395 .04843 Mdot
.38559 .14559 Mdot
.15003 .26497 Mdot
.7213 .11982 Mdot
.52743 .09451 Mdot
.37452 .19915 Mdot
.05228 .24675 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51032 .60409 Mdot
.53288 .57383 Mdot
.6044 .48383 Mdot
.82154 .35095 Mdot
.2537 .49845 Mdot
.44719 .54652 Mdot
.5629 .48972 Mdot
.77052 .3434 Mdot
.21489 .48737 Mdot
.50097 .61672 Mdot
.50311 .61384 Mdot
.5099 .60467 Mdot
.53152 .57563 Mdot
.60013 .48881 Mdot
.80921 .35136 Mdot
.2407 .49866 Mdot
.43386 .55822 Mdot
.53063 .53001 Mdot
.67306 .39937 Mdot
.02687 .42416 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.47612 .03219 Mdot
.42404 .09996 Mdot
.2623 .24707 Mdot
.86254 .1349 Mdot
.64427 .01873 Mdot
.61398 .5399 Mdot
.7404 .39262 Mdot
.10512 .48314 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49514 .00657 Mdot
.48451 .02091 Mdot
.45067 .06591 Mdot
.34402 .18846 Mdot
.03909 .22433 Mdot
.67612 .0924 Mdot
.52661 .06785 Mdot
.41682 .1415 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00517 Mdot
.4878 .01647 Mdot
.46115 .05213 Mdot
.3768 .15528 Mdot
.12555 .25997 Mdot
.70491 .1183 Mdot
.51349 .10581 Mdot
.34228 .22924 Mdot
.97136 .20284 Mdot
.64317 .0873 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56788 .52823 Mdot
.71318 .38462 Mdot
.09085 .46434 Mdot
.33953 .58915 Mdot
.38626 .06781 Mdot
.27654 .21331 Mdot
.9314 .15166 Mdot
.50029 .61765 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60547 Mdot
.52962 .57817 Mdot
.59412 .49592 Mdot
.7917 .35341 Mdot
.21987 .49832 Mdot
.41357 .57457 Mdot
.4839 .58946 Mdot
.53013 .5617 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49462 .00727 Mdot
.48287 .02312 Mdot
.44546 .0727 Mdot
.32783 .20295 Mdot
.99946 .20245 Mdot
.6719 .07231 Mdot
.55489 .02243 Mdot
.5186 .00523 Mdot
.51013 .61388 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00383 Mdot
.49097 .01219 Mdot
.47124 .03871 Mdot
.4086 .11886 Mdot
.21627 .26311 Mdot
.79056 .12033 Mdot
.59586 .03674 Mdot
.53642 .00327 Mdot
.53113 .59263 Mdot
.57224 .52793 Mdot
.49994 8e-05 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00268 Mdot
.49367 .00855 Mdot
.47983 .0272 Mdot
.43582 .0851 Mdot
.29812 .22595 Mdot
.93253 .16526 Mdot
.66514 .0382 Mdot
.60333 .56702 Mdot
.68587 .4313 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01346 Mdot
.46824 .04271 Mdot
.39914 .13008 Mdot
.18867 .2668 Mdot
.75697 .1194 Mdot
.56378 .06184 Mdot
.46371 .09519 Mdot
.30969 .23248 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50972 .60491 Mdot
.53096 .57638 Mdot
.59836 .49089 Mdot
.80409 .35178 Mdot
.23489 .49866 Mdot
.42804 .56313 Mdot
.51688 .54751 Mdot
.631 .43932 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60737 Mdot
.52516 .58414 Mdot
.58001 .51305 Mdot
.74988 .3655 Mdot
.15848 .48932 Mdot
.36675 .59892 Mdot
.39768 .06934 Mdot
.28548 .21324 Mdot
.94045 .15931 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49547 .00612 Mdot
.48557 .01948 Mdot
.45405 .06149 Mdot
.35455 .17833 Mdot
.06601 .23778 Mdot
.68127 .10378 Mdot
.51334 .09143 Mdot
.3654 .20186 Mdot
.03877 .23746 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48945 .01425 Mdot
.4664 .04517 Mdot
.39332 .13682 Mdot
.17194 .26697 Mdot
.73997 .11972 Mdot
.54626 .07744 Mdot
.42096 .14774 Mdot
.18191 .28199 Mdot
.72565 .13617 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51112 .60302 Mdot
.53542 .57045 Mdot
.61241 .47469 Mdot
.84434 .35232 Mdot
.27428 .49815 Mdot
.46825 .52739 Mdot
.61493 .42986 Mdot
.91939 .35829 Mdot
.33967 .48303 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00335 Mdot
.4921 .01067 Mdot
.47483 .03391 Mdot
.41995 .10503 Mdot
.25001 .25258 Mdot
.84133 .12867 Mdot
.63315 .01914 Mdot
.60219 .54881 Mdot
.71419 .40499 Mdot
.0589 .45836 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48717 .01733 Mdot
.45913 .0548 Mdot
.37046 .16206 Mdot
.10825 .25485 Mdot
.69589 .11575 Mdot
.5086 .10778 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53084 .57655 Mdot
.59796 .49136 Mdot
.80292 .3519 Mdot
.23354 .49865 Mdot
.4267 .56423 Mdot
.51375 .5515 Mdot
.62141 .44955 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61075 Mdot
.51717 .59486 Mdot
.55467 .54517 Mdot
.67256 .41475 Mdot
.00147 .41612 Mdot
.32818 .54622 Mdot
.44438 .59674 Mdot
.47884 .61629 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.4971 .00392 Mdot
.49075 .01249 Mdot
.47053 .03966 Mdot
.40637 .12154 Mdot
.20971 .26438 Mdot
.78194 .1198 Mdot
.5881 .04223 Mdot
.51977 .02395 Mdot
.48102 .04151 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01781 Mdot
.45798 .05632 Mdot
.36685 .16585 Mdot
.0985 .25145 Mdot
.69165 .11371 Mdot
.50767 .1066 Mdot
.33518 .23351 Mdot
.95735 .19445 Mdot
.64273 .07917 Mdot
.50036 .61754 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51176 .60215 Mdot
.53745 .56775 Mdot
.61881 .46756 Mdot
.86228 .35523 Mdot
.2875 .4987 Mdot
.48058 .51666 Mdot
.64461 .4003 Mdot
.99691 .39744 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49179 .01109 Mdot
.47385 .03522 Mdot
.41686 .10884 Mdot
.24076 .25613 Mdot
.82633 .12523 Mdot
.6237 .02176 Mdot
.58849 .56192 Mdot
.67928 .42871 Mdot
.98562 .41539 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.50231 .61492 Mdot
.50735 .6081 Mdot
.52342 .58647 Mdot
.5745 .5199 Mdot
.73329 .37316 Mdot
.1295 .4804 Mdot
.3522 .59856 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49036 .01302 Mdot
.4693 .04131 Mdot
.40246 .12617 Mdot
.19831 .266 Mdot
.76791 .11939 Mdot
.57472 .05264 Mdot
.48956 .06231 Mdot
.38874 .15725 Mdot
.1343 .2675 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00306 Mdot
.49278 .00975 Mdot
.477 .03099 Mdot
.42685 .09644 Mdot
.27081 .24273 Mdot
.87806 .14043 Mdot
.65085 .0206 Mdot
.61752 .53932 Mdot
.74488 .39185 Mdot
.50067 .61713 Mdot
.50213 .61516 Mdot
.50677 .60889 Mdot
.52157 .58895 Mdot
.56863 .52728 Mdot
.71547 .38319 Mdot
.09546 .46647 Mdot
.34068 .59071 Mdot
.3849 .07032 Mdot
.27112 .21657 Mdot
.9207 .14606 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48958 .01407 Mdot
.4668 .04463 Mdot
.3946 .13535 Mdot
.17559 .26706 Mdot
.74347 .11964 Mdot
.54988 .07415 Mdot
.4299 .13706 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49082 .0124 Mdot
.47075 .03937 Mdot
.40705 .12072 Mdot
.21172 .26402 Mdot
.78453 .11993 Mdot
.59047 .0405 Mdot
.52493 .01748 Mdot
.49664 .02059 Mdot
.50081 .61693 Mdot
.5026 .61453 Mdot
.50827 .60686 Mdot
.52634 .58255 Mdot
.58375 .50845 Mdot
.76107 .36126 Mdot
.17654 .49336 Mdot
.37826 .59553 Mdot
.41466 .05288 Mdot
.32911 .18257 Mdot
.03371 .21359 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00562 Mdot
.48676 .01788 Mdot
.45783 .05652 Mdot
.36638 .16634 Mdot
.09724 .25098 Mdot
.69115 .11341 Mdot
.50764 .10633 Mdot
.33559 .23305 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00231 Mdot
.49455 .00736 Mdot
.48263 .02343 Mdot
.44472 .07366 Mdot
.32553 .2049 Mdot
.994 .19934 Mdot
.67147 .06939 Mdot
.55918 .01578 Mdot
.53364 .60286 Mdot
.55819 .55011 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51256 .60108 Mdot
.53999 .56439 Mdot
.62679 .4589 Mdot
.88428 .36082 Mdot
.30046 .50101 Mdot
.4898 .51047 Mdot
.66384 .38402 Mdot
.04249 .42294 Mdot
.35816 .53771 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49794 .00278 Mdot
.49345 .00884 Mdot
.47914 .02813 Mdot
.43363 .08788 Mdot
.29143 .23046 Mdot
.91855 .1582 Mdot
.66258 .03236 Mdot
.61022 .55619 Mdot
.71028 .41322 Mdot
.5009 .61682 Mdot
.50286 .61418 Mdot
.5091 .60575 Mdot
.52898 .57903 Mdot
.59209 .49834 Mdot
.78577 .3545 Mdot
.21217 .4979 Mdot
.40655 .57964 Mdot
.46868 .60848 Mdot
.48414 .00513 Mdot
.47583 .02745 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.5001 .61789 Mdot
.50033 .61759 Mdot
.50105 .61661 Mdot
.50336 .6135 Mdot
.5107 .60358 Mdot
.53409 .57222 Mdot
.60822 .47945 Mdot
.83246 .35127 Mdot
.2641 .49823 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50363 .61312 Mdot
.51158 .6024 Mdot
.53688 .56851 Mdot
.61701 .46955 Mdot
.85726 .35426 Mdot
.28405 .49844 Mdot
.47755 .51918 Mdot
.6375 .40699 Mdot
.97897 .38755 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .0021 Mdot
.49504 .0067 Mdot
.4842 .02132 Mdot
.4497 .06718 Mdot
.341 .19126 Mdot
.03153 .2203 Mdot
.67508 .0888 Mdot
.53139 .05989 Mdot
.43448 .11893 Mdot
.24204 .26629 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.5364 .56914 Mdot
.61551 .47121 Mdot
.85307 .35354 Mdot
.28102 .49829 Mdot
.47477 .52159 Mdot
.63082 .41351 Mdot
.96174 .37839 Mdot
.3495 .49803 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00231 Mdot
.49455 .00736 Mdot
.48264 .02342 Mdot
.44475 .07361 Mdot
.32565 .2048 Mdot
.99427 .19949 Mdot
.67149 .06954 Mdot
.55897 .01611 Mdot
.5329 .60386 Mdot
.55583 .55316 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .004 Mdot
.49058 .01273 Mdot
.46999 .04038 Mdot
.40464 .12359 Mdot
.20467 .26519 Mdot
.77558 .11955 Mdot
.58215 .04673 Mdot
.50654 .04066 Mdot
.44075 .09433 Mdot
.28812 .23766 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50546 .61066 Mdot
.51738 .59458 Mdot
.55533 .54431 Mdot
.67461 .41301 Mdot
.00635 .41889 Mdot
.32856 .54883 Mdot
.44054 .60267 Mdot
.4654 .01646 Mdot
.43876 .07185 Mdot
.49989 .00016 Mdot
.49963 .00049 Mdot
.49883 .00158 Mdot
.49629 .00502 Mdot
.48816 .01598 Mdot
.46231 .0506 Mdot
.38043 .15131 Mdot
.13561 .26236 Mdot
.71111 .1192 Mdot
.51825 .10232 Mdot
.35269 .2202 Mdot
.99641 .21687 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.51091 .6033 Mdot
.53475 .57135 Mdot
.61029 .47709 Mdot
.83834 .3517 Mdot
.26928 .49816 Mdot
.46324 .53193 Mdot
.60256 .4433 Mdot
.88529 .34593 Mdot
.32557 .47715 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49696 .0041 Mdot
.49032 .01307 Mdot
.46917 .04148 Mdot
.40205 .12666 Mdot
.19711 .26613 Mdot
.7665 .11938 Mdot
.57334 .05377 Mdot
.48635 .06641 Mdot
.37889 .16816 Mdot
.10681 .25991 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46277 .04998 Mdot
.38191 .14969 Mdot
.13971 .2632 Mdot
.71385 .11944 Mdot
.52058 .10042 Mdot
.3581 .21522 Mdot
.00986 .22436 Mdot
.64684 .10673 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47146 .03842 Mdot
.4093 .11802 Mdot
.21833 .26266 Mdot
.79334 .12055 Mdot
.59829 .03512 Mdot
.54147 .61514 Mdot
.54615 .57295 Mdot
.61909 .47257 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49723 .00374 Mdot
.49117 .01193 Mdot
.47187 .03787 Mdot
.4106 .11646 Mdot
.22217 .26175 Mdot
.79865 .12105 Mdot
.6028 .03224 Mdot
.55063 .60412 Mdot
.57314 .53867 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.51341 .59993 Mdot
.54271 .56081 Mdot
.63531 .44994 Mdot
.90728 .36877 Mdot
.3106 .50575 Mdot
.49228 .5129 Mdot
.6624 .38715 Mdot
.03598 .42022 Mdot
.35605 .5362 Mdot
.5004 .6175 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.54089 .5632 Mdot
.62962 .45589 Mdot
.89197 .36326 Mdot
.30421 .50232 Mdot
.49143 .51026 Mdot
.66581 .38289 Mdot
.04629 .42519 Mdot
.49993 .0001 Mdot
.49978 .0003 Mdot
.49929 .00097 Mdot
.49772 .00308 Mdot
.49274 .0098 Mdot
.47689 .03115 Mdot
.42648 .09691 Mdot
.26967 .24333 Mdot
.87594 .13962 Mdot
.65003 .02024 Mdot
.61727 .53914 Mdot
.74493 .39167 Mdot
.50115 .61648 Mdot
.50368 .61307 Mdot
.51171 .60222 Mdot
.53729 .56797 Mdot
.6183 .46813 Mdot
.86085 .35495 Mdot
.28654 .49862 Mdot
.47975 .51734 Mdot
.64269 .40208 Mdot
.9921 .39476 Mdot
.35336 .51227 Mdot
.50028 .61766 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52884 .57922 Mdot
.59164 .49888 Mdot
.78443 .35478 Mdot
.21039 .49778 Mdot
.40497 .58073 Mdot
.46533 .61262 Mdot
.47408 .01851 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .60559 Mdot
.52935 .57853 Mdot
.59327 .49693 Mdot
.78921 .35384 Mdot
.21668 .49817 Mdot
.41063 .57673 Mdot
.47746 .59756 Mdot
.51059 .58775 Mdot
.55958 .5338 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60118 Mdot
.53975 .56472 Mdot
.62601 .45973 Mdot
.88216 .36019 Mdot
.29936 .5007 Mdot
.4892 .5107 Mdot
.66287 .38472 Mdot
.04037 .42175 Mdot
.35797 .53663 Mdot
.50037 .61754 Mdot
.50116 .61646 Mdot
.50371 .61303 Mdot
.51181 .60209 Mdot
.53761 .56755 Mdot
.6193 .46702 Mdot
.86365 .35552 Mdot
.28841 .49879 Mdot
.48135 .51604 Mdot
.64639 .39867 Mdot
.00133 .3999 Mdot
.50037 .61754 Mdot
.50117 .61645 Mdot
.50374 .61299 Mdot
.5119 .60196 Mdot
.53791 .56714 Mdot
.62026 .46597 Mdot
.8663 .3561 Mdot
.29013 .49898 Mdot
.48277 .51492 Mdot
.64961 .39577 Mdot
.00924 .40433 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49782 .00295 Mdot
.49304 .0094 Mdot
.47783 .02989 Mdot
.42947 .09315 Mdot
.27875 .23829 Mdot
.89319 .14654 Mdot
.65608 .02395 Mdot
.61733 .5428 Mdot
.73906 .3956 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48993 .0136 Mdot
.46792 .04314 Mdot
.39813 .13126 Mdot
.18574 .26694 Mdot
.75382 .11944 Mdot
.56056 .06464 Mdot
.45597 .10494 Mdot
.28618 .24869 Mdot
.88379 .15028 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .0133 Mdot
.46862 .0422 Mdot
.40033 .12868 Mdot
.19213 .26658 Mdot
.7608 .11937 Mdot
.56765 .05853 Mdot
.47296 .08348 Mdot
.33789 .20909 Mdot
.99957 .2087 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49581 .00566 Mdot
.48665 .01802 Mdot
.45748 .05697 Mdot
.3653 .16746 Mdot
.09434 .24989 Mdot
.69001 .1127 Mdot
.50766 .1056 Mdot
.33679 .23175 Mdot
.96181 .19668 Mdot
.64357 .08092 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48932 .01442 Mdot
.46599 .04571 Mdot
.39202 .13831 Mdot
.16824 .26681 Mdot
.73654 .11979 Mdot
.54271 .08067 Mdot
.41219 .15801 Mdot
.15653 .28083 Mdot
.70214 .13991 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00341 Mdot
.49195 .01087 Mdot
.47436 .03453 Mdot
.41849 .10684 Mdot
.24561 .25433 Mdot
.8341 .12691 Mdot
.62875 .02015 Mdot
.59616 .55436 Mdot
.69918 .41428 Mdot
.02886 .44089 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52883 .57923 Mdot
.59161 .49891 Mdot
.78436 .35479 Mdot
.21029 .49777 Mdot
.40488 .58079 Mdot
.46515 .61284 Mdot
.47354 .01923 Mdot
.44244 .07143 Mdot
.50094 .61677 Mdot
.50299 .614 Mdot
.50952 .60517 Mdot
.53034 .57722 Mdot
.59638 .49323 Mdot
.79832 .35243 Mdot
.22807 .49858 Mdot
.42136 .56855 Mdot
.50141 .56724 Mdot
.58359 .49326 Mdot
.78548 .34937 Mdot
.49992 .00011 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49732 .00362 Mdot
.49146 .01154 Mdot
.47279 .03664 Mdot
.4135 .11294 Mdot
.23076 .25941 Mdot
.81103 .12258 Mdot
.6127 .02662 Mdot
.56963 .58215 Mdot
.62769 .47607 Mdot
.5009 .61682 Mdot
.50286 .61417 Mdot
.50912 .60572 Mdot
.52905 .57893 Mdot
.59232 .49806 Mdot
.78644 .35437 Mdot
.21306 .49796 Mdot
.40735 .57908 Mdot
.47037 .60639 Mdot
.48921 .61639 Mdot
.49187 .00589 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51159 .60238 Mdot
.53693 .56845 Mdot
.61715 .46939 Mdot
.85766 .35434 Mdot
.28433 .49846 Mdot
.4778 .51897 Mdot
.63809 .40642 Mdot
.98049 .38838 Mdot
.35208 .5066 Mdot
.50057 .61727 Mdot
.5018 .6156 Mdot
.50575 .61027 Mdot
.51832 .59332 Mdot
.55831 .54046 Mdot
.68383 .40549 Mdot
.02773 .43107 Mdot
.33025 .56025 Mdot
.42375 .01024 Mdot
.40718 .09148 Mdot
.25916 .23879 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49555 .00601 Mdot
.48583 .01912 Mdot
.4549 .06038 Mdot
.3572 .1757 Mdot
.07291 .24095 Mdot
.68304 .10628 Mdot
.51108 .09601 Mdot
.35574 .21217 Mdot
.01244 .22369 Mdot
.50046 .61742 Mdot
.50145 .61607 Mdot
.50463 .61178 Mdot
.51474 .59814 Mdot
.54693 .55525 Mdot
.64851 .4367 Mdot
.94191 .38404 Mdot
.32052 .51734 Mdot
.48345 .53265 Mdot
.62161 .43057 Mdot
.92493 .36353 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.50291 .61411 Mdot
.50926 .60553 Mdot
.5295 .57833 Mdot
.59373 .49637 Mdot
.79058 .3536 Mdot
.21844 .49826 Mdot
.41225 .57554 Mdot
.481 .59311 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.50579 .61021 Mdot
.51845 .59314 Mdot
.55873 .53993 Mdot
.6851 .40448 Mdot
.03064 .43271 Mdot
.3305 .56178 Mdot
.42152 .01359 Mdot
.39953 .10066 Mdot
.23665 .24769 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51586 .59663 Mdot
.55048 .55061 Mdot
.65957 .42625 Mdot
.96988 .3985 Mdot
.3251 .52992 Mdot
.46768 .55968 Mdot
.5621 .50355 Mdot
.74734 .35603 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49345 .00885 Mdot
.47913 .02814 Mdot
.43361 .08792 Mdot
.29136 .23051 Mdot
.91839 .15812 Mdot
.66254 .0323 Mdot
.61028 .55608 Mdot
.71053 .41305 Mdot
.0422 .45171 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50266 .61444 Mdot
.50847 .6066 Mdot
.52697 .58172 Mdot
.58573 .50603 Mdot
.76695 .35932 Mdot
.18556 .49494 Mdot
.38473 .5927 Mdot
.42573 .04104 Mdot
.35932 .15513 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.4967 .00445 Mdot
.4895 .01418 Mdot
.46655 .04497 Mdot
.39378 .13629 Mdot
.17326 .26701 Mdot
.74122 .11969 Mdot
.54755 .07626 Mdot
.42416 .14394 Mdot
.19127 .28155 Mdot
.73572 .1346 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50922 .60559 Mdot
.52936 .57853 Mdot
.59328 .49691 Mdot
.78926 .35384 Mdot
.21674 .49817 Mdot
.41068 .57669 Mdot
.47757 .59742 Mdot
.51093 .58729 Mdot
.56067 .5324 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00237 Mdot
.49442 .00753 Mdot
.48223 .02397 Mdot
.44344 .07531 Mdot
.3216 .20817 Mdot
.98477 .19407 Mdot
.67075 .06444 Mdot
.56648 .00459 Mdot
.55905 .56912 Mdot
.63819 .45652 Mdot
.50122 .61638 Mdot
.50389 .61277 Mdot
.5124 .60129 Mdot
.5395 .56504 Mdot
.62525 .46055 Mdot
.88006 .35959 Mdot
.29823 .50041 Mdot
.48855 .51101 Mdot
.66171 .3856 Mdot
.03781 .42032 Mdot
.35772 .53533 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00338 Mdot
.49202 .01078 Mdot
.47457 .03425 Mdot
.41915 .10602 Mdot
.24761 .25355 Mdot
.83736 .12768 Mdot
.63077 .01963 Mdot
.59901 .55169 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49346 .00884 Mdot
.47916 .02811 Mdot
.43368 .08782 Mdot
.29158 .23036 Mdot
.91885 .15835 Mdot
.66264 .03248 Mdot
.61009 .5564 Mdot
.70981 .41354 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47146 .03842 Mdot
.4093 .11803 Mdot
.21832 .26266 Mdot
.79333 .12055 Mdot
.59828 .03512 Mdot
.54145 .61516 Mdot
.54609 .57303 Mdot
.61891 .47276 Mdot
.50087 .61686 Mdot
.50276 .6143 Mdot
.5088 .60615 Mdot
.52804 .58029 Mdot
.58911 .50193 Mdot
.77697 .3565 Mdot
.20015 .49686 Mdot
.39621 .58641 Mdot
.44738 .01627 Mdot
.42105 .08649 Mdot
.2811 .23123 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00382 Mdot
.49098 .01218 Mdot
.47128 .03866 Mdot
.40873 .1187 Mdot
.21667 .26302 Mdot
.79109 .12037 Mdot
.59633 .03642 Mdot
.53739 .00207 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49517 .00652 Mdot
.48462 .02076 Mdot
.45102 .06545 Mdot
.34512 .18742 Mdot
.04186 .22578 Mdot
.67653 .09368 Mdot
.52495 .07064 Mdot
.41065 .14919 Mdot
.16926 .27815 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56446 Mdot
.62662 .45908 Mdot
.88382 .36068 Mdot
.30022 .50094 Mdot
.48967 .51051 Mdot
.66365 .38416 Mdot
.04207 .4227 Mdot
.35812 .53749 Mdot
.5013 .61628 Mdot
.50414 .61243 Mdot
.5132 .60021 Mdot
.54205 .56168 Mdot
.63324 .45209 Mdot
.90174 .36668 Mdot
.30845 .50438 Mdot
.49234 .51148 Mdot
.66474 .38461 Mdot
.04244 .42348 Mdot
.35723 .53879 Mdot
.5003 .61763 Mdot
.50095 .61674 Mdot
.50304 .61392 Mdot
.50969 .60495 Mdot
.53087 .57651 Mdot
.59805 .49126 Mdot
.80318 .35187 Mdot
.23384 .49866 Mdot
.427 .56398 Mdot
.51445 .5506 Mdot
.62356 .44722 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.51131 .60277 Mdot
.53601 .56967 Mdot
.61427 .47261 Mdot
.84957 .35301 Mdot
.27839 .49821 Mdot
.47227 .52379 Mdot
.62477 .41961 Mdot
.94583 .37035 Mdot
.34659 .49155 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00425 Mdot
.48997 .01355 Mdot
.46804 .04298 Mdot
.39851 .13082 Mdot
.18684 .2669 Mdot
.755 .11942 Mdot
.56177 .06359 Mdot
.45888 .10129 Mdot
.29499 .24298 Mdot
.90184 .15764 Mdot
.49963 .00049 Mdot
.49883 .00158 Mdot
.49628 .00502 Mdot
.48816 .01599 Mdot
.46228 .05063 Mdot
.38036 .15139 Mdot
.13541 .26231 Mdot
.71098 .11918 Mdot
.51814 .10241 Mdot
.35244 .22043 Mdot
.99578 .21652 Mdot
.64545 .09968 Mdot
.50106 .6166 Mdot
.50337 .61348 Mdot
.51074 .60352 Mdot
.53422 .57204 Mdot
.60864 .47897 Mdot
.83364 .35134 Mdot
.26516 .49821 Mdot
.45904 .53577 Mdot
.59214 .45505 Mdot
.85586 .33895 Mdot
.30742 .477 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50732 .60814 Mdot
.52333 .58659 Mdot
.57421 .52025 Mdot
.73243 .37361 Mdot
.12791 .47983 Mdot
.35153 .59836 Mdot
.38337 .07902 Mdot
.25551 .22648 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01653 Mdot
.46102 .05231 Mdot
.37639 .15572 Mdot
.12442 .25967 Mdot
.70426 .11818 Mdot
.51304 .1061 Mdot
.34137 .22999 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50709 .60846 Mdot
.52258 .5876 Mdot
.57182 .52325 Mdot
.72519 .37749 Mdot
.11439 .47464 Mdot
.3464 .59594 Mdot
.38215 .07744 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .0036 Mdot
.4915 .01148 Mdot
.47292 .03646 Mdot
.41392 .11243 Mdot
.232 .25903 Mdot
.81288 .12285 Mdot
.6141 .02591 Mdot
.57217 .57931 Mdot
.63483 .46874 Mdot
.8764 .36533 Mdot
.50106 .6166 Mdot
.50338 .61346 Mdot
.51078 .60348 Mdot
.53432 .57191 Mdot
.60894 .47862 Mdot
.83452 .3514 Mdot
.26595 .4982 Mdot
.45984 .53504 Mdot
.59414 .45277 Mdot
.86154 .34 Mdot
.31141 .4767 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49189 .01095 Mdot
.47417 .0348 Mdot
.41786 .10761 Mdot
.24374 .25504 Mdot
.83108 .12623 Mdot
.62683 .02071 Mdot
.59333 .5571 Mdot
.69193 .41926 Mdot
.01354 .4318 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.51149 .60251 Mdot
.53661 .56887 Mdot
.61615 .4705 Mdot
.85487 .35384 Mdot
.28234 .49835 Mdot
.47599 .52053 Mdot
.63376 .41061 Mdot
.96938 .3824 Mdot
.35064 .50141 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00486 Mdot
.48855 .01546 Mdot
.46353 .04898 Mdot
.38429 .14704 Mdot
.14636 .2644 Mdot
.71856 .11972 Mdot
.52484 .09679 Mdot
.36824 .20545 Mdot
.03581 .23837 Mdot
.65012 .11894 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48811 .01606 Mdot
.46212 .05085 Mdot
.37985 .15195 Mdot
.13398 .262 Mdot
.71006 .11908 Mdot
.51738 .103 Mdot
.35073 .22196 Mdot
.99159 .21417 Mdot
.64506 .09755 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51092 .60329 Mdot
.53478 .5713 Mdot
.6104 .47696 Mdot
.83867 .35173 Mdot
.26956 .49816 Mdot
.46353 .53167 Mdot
.60326 .44252 Mdot
.88724 .34652 Mdot
.32656 .47732 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51254 .6011 Mdot
.53995 .56445 Mdot
.62665 .45905 Mdot
.88389 .36071 Mdot
.30025 .50096 Mdot
.48969 .5105 Mdot
.66368 .38414 Mdot
.04213 .42274 Mdot
.35812 .53753 Mdot
.50027 .61766 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.52831 .57993 Mdot
.58996 .5009 Mdot
.77949 .35588 Mdot
.20366 .49722 Mdot
.39915 .58458 Mdot
.45328 .00924 Mdot
.43834 .06498 Mdot
.50036 .61755 Mdot
.50113 .6165 Mdot
.50361 .61315 Mdot
.51151 .60249 Mdot
.53666 .56881 Mdot
.61631 .47033 Mdot
.8553 .35392 Mdot
.28265 .49837 Mdot
.47628 .52028 Mdot
.63446 .40994 Mdot
.97117 .38335 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52048 .59042 Mdot
.56515 .53169 Mdot
.70486 .39004 Mdot
.07375 .45599 Mdot
.33594 .58255 Mdot
.39335 .05615 Mdot
.3025 .19574 Mdot
.9858 .18259 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49029 .01312 Mdot
.46907 .04161 Mdot
.40174 .12703 Mdot
.19621 .26622 Mdot
.76545 .11937 Mdot
.5723 .05463 Mdot
.48391 .06951 Mdot
.37144 .17615 Mdot
.08642 .25239 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49022 .0132 Mdot
.46886 .04189 Mdot
.40108 .1278 Mdot
.1943 .2664 Mdot
.76325 .11937 Mdot
.57012 .05645 Mdot
.47878 .07606 Mdot
.35571 .19224 Mdot
.04465 .2331 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00213 Mdot
.49499 .00677 Mdot
.48403 .02155 Mdot
.44916 .06789 Mdot
.33931 .19281 Mdot
.02734 .21803 Mdot
.67456 .08675 Mdot
.5342 .05529 Mdot
.44474 .10549 Mdot
.27405 .25136 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57437 .52006 Mdot
.73289 .37337 Mdot
.12877 .48014 Mdot
.35189 .59847 Mdot
.38355 .07902 Mdot
.2557 .22647 Mdot
.88927 .13189 Mdot
.49971 .0004 Mdot
.49907 .00126 Mdot
.49703 .00401 Mdot
.49054 .01278 Mdot
.46986 .04055 Mdot
.40424 .12407 Mdot
.20349 .26536 Mdot
.77414 .11951 Mdot
.58077 .0478 Mdot
.50342 .04463 Mdot
.4312 .10644 Mdot
.25898 .25375 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61718 Mdot
.50203 .6153 Mdot
.50645 .60932 Mdot
.52056 .59031 Mdot
.56542 .53135 Mdot
.70567 .38949 Mdot
.07546 .45686 Mdot
.33625 .58326 Mdot
.39251 .05747 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00387 Mdot
.49087 .01233 Mdot
.47092 .03914 Mdot
.40759 .12008 Mdot
.2133 .26372 Mdot
.7866 .12006 Mdot
.59234 .03917 Mdot
.52897 .01247 Mdot
.5088 .00431 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60118 Mdot
.53976 .5647 Mdot
.62605 .45968 Mdot
.88227 .36023 Mdot
.29941 .50072 Mdot
.48923 .51069 Mdot
.66292 .38468 Mdot
.04049 .42182 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49652 .0047 Mdot
.48893 .01495 Mdot
.46473 .04738 Mdot
.38807 .1428 Mdot
.15702 .26587 Mdot
.72683 .11989 Mdot
.53285 .08965 Mdot
.38779 .18527 Mdot
.08802 .26277 Mdot
.66285 .1368 Mdot
.50033 .61759 Mdot
.50105 .61662 Mdot
.50335 .61351 Mdot
.51066 .60364 Mdot
.53394 .57241 Mdot
.60776 .47997 Mdot
.83115 .35119 Mdot
.26291 .49825 Mdot
.45671 .53789 Mdot
.58639 .46167 Mdot
.83939 .33679 Mdot
.50082 .61693 Mdot
.5026 .61452 Mdot
.50829 .60684 Mdot
.52641 .58247 Mdot
.58395 .5082 Mdot
.76167 .36105 Mdot
.17747 .49354 Mdot
.37891 .59528 Mdot
.41573 .05177 Mdot
.33197 .18017 Mdot
.04044 .21726 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49167 .01125 Mdot
.47347 .03573 Mdot
.41565 .11032 Mdot
.23714 .25739 Mdot
.82068 .12415 Mdot
.61979 .02329 Mdot
.58211 .56854 Mdot
.66219 .44289 Mdot
.94558 .39341 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50168 .61576 Mdot
.50536 .61079 Mdot
.51708 .59499 Mdot
.55437 .54556 Mdot
.67165 .41553 Mdot
.9993 .41488 Mdot
.328 .54506 Mdot
.44608 .5941 Mdot
.48481 .60815 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02203 Mdot
.44804 .06935 Mdot
.33583 .19596 Mdot
.01876 .21331 Mdot
.67362 .08243 Mdot
.54024 .04552 Mdot
.46659 .07627 Mdot
.50108 .61657 Mdot
.50344 .61338 Mdot
.51097 .60322 Mdot
.53493 .5711 Mdot
.61088 .47643 Mdot
.84 .35185 Mdot
.27069 .49815 Mdot
.46467 .53063 Mdot
.60609 .43941 Mdot
.89511 .34906 Mdot
.33032 .47821 Mdot
.5013 .61627 Mdot
.50415 .61242 Mdot
.51323 .60017 Mdot
.54214 .56156 Mdot
.63353 .45179 Mdot
.90252 .36696 Mdot
.30876 .50457 Mdot
.49236 .51165 Mdot
.66449 .38489 Mdot
.04172 .42313 Mdot
.35708 .53852 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50364 .61311 Mdot
.5116 .60237 Mdot
.53695 .56842 Mdot
.61723 .4693 Mdot
.85789 .35438 Mdot
.28449 .49847 Mdot
.47795 .51885 Mdot
.63843 .40609 Mdot
.98136 .38885 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00488 Mdot
.4885 .01553 Mdot
.46336 .0492 Mdot
.38375 .14764 Mdot
.14486 .26415 Mdot
.71747 .11967 Mdot
.52383 .09766 Mdot
.36581 .20784 Mdot
.02951 .23504 Mdot
.50093 .61678 Mdot
.50295 .61404 Mdot
.50941 .60533 Mdot
.52997 .57771 Mdot
.59522 .49461 Mdot
.79493 .3529 Mdot
.22392 .49847 Mdot
.41738 .57167 Mdot
.4924 .57872 Mdot
.55602 .52785 Mdot
.70194 .38698 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00472 Mdot
.48886 .01504 Mdot
.46452 .04767 Mdot
.38739 .14356 Mdot
.1551 .26565 Mdot
.72528 .11988 Mdot
.53131 .09105 Mdot
.38399 .18932 Mdot
.07767 .2585 Mdot
.65941 .13421 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50455 .61189 Mdot
.5145 .59846 Mdot
.54617 .55626 Mdot
.64612 .43904 Mdot
.93574 .38107 Mdot
.31915 .51491 Mdot
.48601 .52787 Mdot
.6319 .41911 Mdot
.95377 .37685 Mdot
.50069 .6171 Mdot
.50221 .61504 Mdot
.50705 .60851 Mdot
.52247 .58774 Mdot
.57149 .52368 Mdot
.72416 .37807 Mdot
.11242 .47384 Mdot
.34573 .59549 Mdot
.38221 .07696 Mdot
.25769 .22433 Mdot
.89472 .13369 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00325 Mdot
.49234 .01034 Mdot
.47561 .03287 Mdot
.42242 .10198 Mdot
.25742 .24936 Mdot
.85395 .13218 Mdot
.64007 .01845 Mdot
.61022 .54228 Mdot
.73278 .3956 Mdot
.09269 .47675 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49871 .00174 Mdot
.49589 .00556 Mdot
.48689 .0177 Mdot
.45826 .05595 Mdot
.36773 .16494 Mdot
.10085 .2523 Mdot
.69262 .11424 Mdot
.50778 .10703 Mdot
.33459 .23423 Mdot
.9556 .1936 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60695 Mdot
.52614 .58282 Mdot
.58312 .50922 Mdot
.75919 .36192 Mdot
.1736 .49279 Mdot
.37625 .59629 Mdot
.41144 .05619 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51076 .60351 Mdot
.53427 .57198 Mdot
.60878 .47881 Mdot
.83405 .35137 Mdot
.26553 .49821 Mdot
.45941 .53543 Mdot
.59307 .45398 Mdot
.85852 .33942 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.51081 .60344 Mdot
.53443 .57177 Mdot
.60928 .47824 Mdot
.83547 .35146 Mdot
.26679 .49819 Mdot
.46071 .53425 Mdot
.59628 .45034 Mdot
.86761 .34128 Mdot
.31541 .47654 Mdot
.5002 .61777 Mdot
.50063 .61719 Mdot
.502 .61533 Mdot
.50637 .60943 Mdot
.5203 .59065 Mdot
.5646 .53239 Mdot
.70317 .39119 Mdot
.07021 .45419 Mdot
.33532 .58104 Mdot
.39518 .0533 Mdot
.30893 .19085 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .0137 Mdot
.4677 .04343 Mdot
.39742 .13208 Mdot
.18371 .26701 Mdot
.75167 .11948 Mdot
.55836 .06658 Mdot
.45064 .11161 Mdot
.27005 .25799 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48929 .01447 Mdot
.46588 .04586 Mdot
.39168 .1387 Mdot
.16727 .26675 Mdot
.73566 .11981 Mdot
.54181 .08149 Mdot
.40994 .1606 Mdot
.1501 .28001 Mdot
.69702 .14057 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61708 Mdot
.50224 .61501 Mdot
.50713 .6084 Mdot
.52272 .58741 Mdot
.57227 .52269 Mdot
.72654 .37675 Mdot
.11695 .47567 Mdot
.3473 .59649 Mdot
.50114 .6165 Mdot
.50362 .61314 Mdot
.51154 .60246 Mdot
.53674 .5687 Mdot
.61656 .47005 Mdot
.856 .35404 Mdot
.28316 .49839 Mdot
.47674 .51988 Mdot
.63556 .40886 Mdot
.97401 .38487 Mdot
.35127 .50354 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00236 Mdot
.49444 .00752 Mdot
.48227 .02392 Mdot
.44358 .07513 Mdot
.32201 .20783 Mdot
.98574 .19463 Mdot
.67083 .06496 Mdot
.56571 .00576 Mdot
.55639 .5726 Mdot
.6299 .46511 Mdot
.49998 3e-05 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49808 .0026 Mdot
.49387 .00828 Mdot
.48047 .02634 Mdot
.43785 .08251 Mdot
.30434 .22154 Mdot
.94589 .17234 Mdot
.66705 .04438 Mdot
.59524 .5793 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50538 .61076 Mdot
.51716 .59489 Mdot
.55461 .54525 Mdot
.67238 .41491 Mdot
.00104 .41587 Mdot
.32814 .54599 Mdot
.44472 .59622 Mdot
.48002 .61469 Mdot
.48543 .01014 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50641 .60937 Mdot
.52042 .59049 Mdot
.56499 .5319 Mdot
.70435 .39038 Mdot
.0727 .45546 Mdot
.33575 .5821 Mdot
.39388 .05532 Mdot
.30438 .19433 Mdot
.98995 .18502 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50621 .60965 Mdot
.51978 .59136 Mdot
.56293 .53453 Mdot
.69804 .39478 Mdot
.05927 .44847 Mdot
.33364 .5761 Mdot
.40148 .04368 Mdot
.3308 .17261 Mdot
.05151 .21954 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48755 .01681 Mdot
.46035 .05318 Mdot
.3743 .15797 Mdot
.1187 .25809 Mdot
.7011 .11745 Mdot
.51106 .10721 Mdot
.33758 .23297 Mdot
.96062 .19684 Mdot
.64213 .08191 Mdot
.50078 .61699 Mdot
.50247 .6147 Mdot
.50787 .6074 Mdot
.52507 .58426 Mdot
.57973 .5134 Mdot
.74903 .36586 Mdot
.15706 .48895 Mdot
.36592 .59906 Mdot
.39662 .07027 Mdot
.28293 .21466 Mdot
.9356 .15657 Mdot
.50065 .61715 Mdot
.50208 .61522 Mdot
.50663 .60908 Mdot
.52112 .58955 Mdot
.56721 .52908 Mdot
.71114 .38591 Mdot
.08672 .46239 Mdot
.33856 .58767 Mdot
.38769 .06533 Mdot
.28199 .2099 Mdot
.94236 .15763 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49658 .00462 Mdot
.48911 .0147 Mdot
.46532 .0466 Mdot
.38993 .1407 Mdot
.16227 .26639 Mdot
.73124 .11987 Mdot
.53729 .08562 Mdot
.39876 .17327 Mdot
.11841 .27319 Mdot
.67638 .14115 Mdot
.50045 .61742 Mdot
.50145 .61608 Mdot
.50462 .6118 Mdot
.5147 .59819 Mdot
.54682 .55541 Mdot
.64814 .43707 Mdot
.94095 .38357 Mdot
.32032 .51695 Mdot
.48387 .53188 Mdot
.62328 .42868 Mdot
.92967 .36558 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51192 .60195 Mdot
.53795 .5671 Mdot
.62036 .46585 Mdot
.8666 .35616 Mdot
.29031 .499 Mdot
.48292 .51481 Mdot
.64994 .39547 Mdot
.01006 .40479 Mdot
.3551 .52132 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50432 .6122 Mdot
.51376 .59946 Mdot
.5438 .55937 Mdot
.63873 .44644 Mdot
.91637 .37243 Mdot
.31377 .50829 Mdot
.49134 .51632 Mdot
.65591 .39381 Mdot
.01871 .41112 Mdot
.49994 8e-05 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00268 Mdot
.49367 .00855 Mdot
.47985 .02718 Mdot
.43587 .08503 Mdot
.29828 .22584 Mdot
.93287 .16543 Mdot
.66519 .03835 Mdot
.60314 .56731 Mdot
.68521 .43183 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51101 .60316 Mdot
.53508 .5709 Mdot
.61134 .4759 Mdot
.84133 .35198 Mdot
.27181 .49815 Mdot
.46579 .52962 Mdot
.60885 .43639 Mdot
.90276 .35175 Mdot
.33362 .47939 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50612 .60977 Mdot
.5195 .59174 Mdot
.56204 .53567 Mdot
.69531 .39675 Mdot
.05335 .44529 Mdot
.33286 .57329 Mdot
.40526 .03799 Mdot
.34379 .16065 Mdot
.08386 .23484 Mdot
.49984 .00021 Mdot
.49951 .00067 Mdot
.49842 .00213 Mdot
.49498 .00678 Mdot
.484 .02159 Mdot
.44906 .06801 Mdot
.33901 .19308 Mdot
.02661 .21763 Mdot
.67448 .08639 Mdot
.5347 .05448 Mdot
.44655 .1031 Mdot
.27972 .24808 Mdot
.50105 .61662 Mdot
.50335 .61351 Mdot
.51066 .60364 Mdot
.53395 .5724 Mdot
.60779 .47994 Mdot
.83122 .3512 Mdot
.26297 .49825 Mdot
.45678 .53783 Mdot
.58655 .46149 Mdot
.83983 .33684 Mdot
.29482 .47857 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49817 .00247 Mdot
.49418 .00786 Mdot
.48147 .02499 Mdot
.44103 .07842 Mdot
.31414 .21415 Mdot
.96764 .18436 Mdot
.66935 .05535 Mdot
.57978 .60248 Mdot
.60495 .51209 Mdot
.77636 .36657 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50876 .6062 Mdot
.52792 .58045 Mdot
.58873 .50238 Mdot
.77586 .35678 Mdot
.19858 .49669 Mdot
.39491 .58719 Mdot
.44482 .01929 Mdot
.41362 .09549 Mdot
.25911 .2428 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52049 .5904 Mdot
.5652 .53164 Mdot
.70499 .38995 Mdot
.07403 .45613 Mdot
.33599 .58266 Mdot
.39321 .05636 Mdot
.30202 .1961 Mdot
.98472 .18196 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54006 .5643 Mdot
.627 .45867 Mdot
.88486 .361 Mdot
.30075 .5011 Mdot
.48995 .51042 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49731 .00363 Mdot
.49144 .01156 Mdot
.47274 .0367 Mdot
.41336 .11312 Mdot
.23033 .25954 Mdot
.81039 .12249 Mdot
.6122 .02687 Mdot
.56872 .58317 Mdot
.62513 .47875 Mdot
.8505 .35966 Mdot
.49985 .00021 Mdot
.49952 .00065 Mdot
.49846 .00208 Mdot
.49509 .00663 Mdot
.48436 .02111 Mdot
.4502 .06653 Mdot
.34254 .18983 Mdot
.0354 .22237 Mdot
.67559 .09066 Mdot
.5289 .06402 Mdot
.42531 .13075 Mdot
.21375 .27449 Mdot
.50082 .61692 Mdot
.50262 .61449 Mdot
.50835 .60676 Mdot
.5266 .58221 Mdot
.58456 .50746 Mdot
.76348 .36044 Mdot
.18027 .49405 Mdot
.38088 .59446 Mdot
.41903 .04829 Mdot
.3409 .17241 Mdot
.06193 .22839 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.4761 .0322 Mdot
.424 .10001 Mdot
.26218 .24712 Mdot
.86233 .13483 Mdot
.64418 .01871 Mdot
.6139 .53994 Mdot
.74026 .39267 Mdot
.1049 .48303 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.5055 .6106 Mdot
.51753 .59439 Mdot
.55578 .54373 Mdot
.67602 .41184 Mdot
.00965 .42078 Mdot
.32882 .5506 Mdot
.43793 .60669 Mdot
.4563 .02866 Mdot
.40992 .10778 Mdot
.50031 .61761 Mdot
.50099 .61669 Mdot
.50316 .61377 Mdot
.51007 .60444 Mdot
.53206 .57492 Mdot
.60182 .48684 Mdot
.8141 .3511 Mdot
.24601 .4986 Mdot
.43927 .55354 Mdot
.54361 .51362 Mdot
.71257 .37013 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00488 Mdot
.48849 .01555 Mdot
.46333 .04925 Mdot
.38365 .14776 Mdot
.14457 .2641 Mdot
.71726 .11966 Mdot
.52364 .09783 Mdot
.36534 .20829 Mdot
.02832 .23441 Mdot
.64904 .11557 Mdot
.49999 1e-05 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49742 .00349 Mdot
.49176 .01112 Mdot
.47377 .03533 Mdot
.41659 .10916 Mdot
.23996 .25642 Mdot
.82507 .12498 Mdot
.62285 .02207 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.5045 .61196 Mdot
.51433 .5987 Mdot
.54562 .55698 Mdot
.6444 .44074 Mdot
.93127 .37898 Mdot
.31806 .51324 Mdot
.48761 .52471 Mdot
.63861 .41185 Mdot
.97221 .38623 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60623 Mdot
.52785 .58054 Mdot
.58851 .50265 Mdot
.77521 .35695 Mdot
.19765 .49659 Mdot
.39416 .58763 Mdot
.44334 .02102 Mdot
.40933 .1006 Mdot
.24656 .24811 Mdot
.49985 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49531 .00634 Mdot
.48505 .02018 Mdot
.45241 .06364 Mdot
.34943 .18332 Mdot
.05282 .23139 Mdot
.67842 .09851 Mdot
.51902 .08092 Mdot
.38809 .17632 Mdot
.1028 .26513 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00381 Mdot
.49101 .01214 Mdot
.47138 .03853 Mdot
.40904 .11834 Mdot
.21756 .26283 Mdot
.79229 .12046 Mdot
.59737 .03572 Mdot
.53958 .61744 Mdot
.54053 .58027 Mdot
.50131 .61626 Mdot
.50419 .61238 Mdot
.51334 .60003 Mdot
.54246 .56113 Mdot
.63454 .45074 Mdot
.90522 .36798 Mdot
.30982 .50522 Mdot
.49235 .51231 Mdot
.66341 .38607 Mdot
.03874 .42163 Mdot
.35653 .53734 Mdot
.50101 .61667 Mdot
.50323 .61367 Mdot
.51028 .60415 Mdot
.53275 .57401 Mdot
.60398 .48432 Mdot
.82033 .35095 Mdot
.25248 .49848 Mdot
.44592 .54765 Mdot
.5598 .49351 Mdot
.76128 .34634 Mdot
.20089 .48691 Mdot
.50044 .61744 Mdot
.50139 .61615 Mdot
.50444 .61203 Mdot
.51416 .59892 Mdot
.54509 .55768 Mdot
.64275 .44239 Mdot
.92695 .37702 Mdot
.31692 .51171 Mdot
.48895 .52194 Mdot
.64443 .40568 Mdot
.98802 .39459 Mdot
.50124 .61635 Mdot
.50396 .61268 Mdot
.51262 .601 Mdot
.54018 .56414 Mdot
.62739 .45825 Mdot
.88592 .36132 Mdot
.30129 .50127 Mdot
.49021 .51034 Mdot
.66447 .38359 Mdot
.04381 .42369 Mdot
.35826 .5384 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48887 .01503 Mdot
.46454 .04763 Mdot
.38747 .14348 Mdot
.15532 .26567 Mdot
.72545 .11988 Mdot
.53148 .09089 Mdot
.38441 .18887 Mdot
.07881 .25899 Mdot
.65977 .13453 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00394 Mdot
.49071 .01255 Mdot
.4704 .03983 Mdot
.40595 .12203 Mdot
.2085 .26459 Mdot
.78038 .11973 Mdot
.58666 .0433 Mdot
.5166 .02794 Mdot
.4714 .05431 Mdot
.38353 .1529 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.4873 .01715 Mdot
.45954 .05425 Mdot
.37176 .16068 Mdot
.11177 .25599 Mdot
.69757 .11638 Mdot
.50926 .1078 Mdot
.33484 .23488 Mdot
.9548 .19353 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00487 Mdot
.48851 .01552 Mdot
.46339 .04916 Mdot
.38385 .14753 Mdot
.14514 .26419 Mdot
.71766 .11968 Mdot
.52401 .09751 Mdot
.36624 .20741 Mdot
.03064 .23564 Mdot
.64936 .11663 Mdot
.5008 .61695 Mdot
.50255 .61458 Mdot
.50814 .60704 Mdot
.52592 .58312 Mdot
.58241 .51009 Mdot
.75706 .36269 Mdot
.17021 .49208 Mdot
.37401 .59706 Mdot
.40794 .05969 Mdot
.31136 .1964 Mdot
.99358 .19045 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.4954 .00622 Mdot
.48534 .01979 Mdot
.45331 .06246 Mdot
.35224 .1806 Mdot
.06003 .23493 Mdot
.67989 .10147 Mdot
.5157 .08694 Mdot
.37503 .19125 Mdot
.06559 .25035 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50967 .60497 Mdot
.5308 .5766 Mdot
.59784 .4915 Mdot
.80258 .35193 Mdot
.23314 .49865 Mdot
.42631 .56455 Mdot
.51284 .55266 Mdot
.61862 .45259 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.505 .61128 Mdot
.51594 .59652 Mdot
.55074 .55028 Mdot
.66037 .42552 Mdot
.97187 .39958 Mdot
.32534 .53089 Mdot
.46634 .56187 Mdot
.55722 .50996 Mdot
.50032 .6176 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51032 .60409 Mdot
.53288 .57383 Mdot
.6044 .48384 Mdot
.82152 .35095 Mdot
.25368 .49845 Mdot
.44716 .54654 Mdot
.56284 .48979 Mdot
.77034 .34345 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00557 Mdot
.48685 .01775 Mdot
.45814 .05611 Mdot
.36734 .16534 Mdot
.09982 .25193 Mdot
.69219 .11401 Mdot
.50772 .10686 Mdot
.33482 .23394 Mdot
.9563 .19393 Mdot
.64251 .07878 Mdot
.5008 .61695 Mdot
.50255 .61458 Mdot
.50814 .60704 Mdot
.52593 .58311 Mdot
.58243 .51006 Mdot
.75713 .36267 Mdot
.17032 .49211 Mdot
.37408 .59704 Mdot
.40805 .05958 Mdot
.31165 .1962 Mdot
.99419 .19081 Mdot
.49986 .00018 Mdot
.49957 .00058 Mdot
.49862 .00186 Mdot
.49562 .00592 Mdot
.48604 .01885 Mdot
.45554 .05953 Mdot
.35921 .17368 Mdot
.07819 .24329 Mdot
.68454 .10805 Mdot
.50972 .09904 Mdot
.34948 .21869 Mdot
.99563 .21464 Mdot
.5011 .61654 Mdot
.50351 .61329 Mdot
.51119 .60292 Mdot
.53565 .57015 Mdot
.61313 .47389 Mdot
.84636 .35257 Mdot
.2759 .49817 Mdot
.46985 .52595 Mdot
.61884 .42574 Mdot
.92998 .3629 Mdot
.3428 .48607 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49715 .00385 Mdot
.49091 .01227 Mdot
.47105 .03896 Mdot
.40802 .11956 Mdot
.21456 .26347 Mdot
.78826 .12016 Mdot
.59383 .03813 Mdot
.53214 .00853 Mdot
.51834 .60961 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.5062 .60966 Mdot
.51975 .59139 Mdot
.56286 .53463 Mdot
.69781 .39494 Mdot
.05878 .4482 Mdot
.33357 .57587 Mdot
.40179 .04322 Mdot
.33186 .17167 Mdot
.05409 .22086 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50933 .60544 Mdot
.52971 .57806 Mdot
.59439 .4956 Mdot
.79249 .35328 Mdot
.22087 .49836 Mdot
.4145 .57386 Mdot
.48597 .58685 Mdot
.53642 .55338 Mdot
.64103 .43909 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49324 .00913 Mdot
.47847 .02903 Mdot
.43151 .09058 Mdot
.28494 .23458 Mdot
.90538 .15194 Mdot
.65953 .0276 Mdot
.61488 .54815 Mdot
.72796 .40201 Mdot
.07748 .47104 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50592 .61003 Mdot
.51887 .59258 Mdot
.56006 .53821 Mdot
.68923 .40129 Mdot
.03994 .43792 Mdot
.33136 .5666 Mdot
.41458 .02401 Mdot
.37574 .12785 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00109 Mdot
.49744 .00346 Mdot
.49184 .01103 Mdot
.474 .03503 Mdot
.41732 .10827 Mdot
.24214 .25564 Mdot
.82851 .12568 Mdot
.62515 .02125 Mdot
.59077 .55963 Mdot
.68527 .42412 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49583 .00563 Mdot
.48673 .01792 Mdot
.45773 .05665 Mdot
.36607 .16667 Mdot
.0964 .25067 Mdot
.69081 .11321 Mdot
.50763 .10613 Mdot
.33591 .2327 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00282 Mdot
.49336 .00897 Mdot
.47885 .02852 Mdot
.4327 .08907 Mdot
.28859 .2323 Mdot
.91272 .15538 Mdot
.66131 .03016 Mdot
.61251 .55236 Mdot
.71878 .40765 Mdot
.05919 .46126 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50503 .61124 Mdot
.51603 .5964 Mdot
.55104 .54989 Mdot
.66131 .42466 Mdot
.97419 .40084 Mdot
.32562 .53204 Mdot
.46475 .56445 Mdot
.55145 .51758 Mdot
.71399 .3738 Mdot
.50064 .61718 Mdot
.50202 .6153 Mdot
.50645 .60932 Mdot
.52054 .59034 Mdot
.56536 .53144 Mdot
.70547 .38963 Mdot
.07504 .45665 Mdot
.33617 .58309 Mdot
.39272 .05715 Mdot
.30025 .1974 Mdot
.98085 .17969 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00204 Mdot
.4952 .00648 Mdot
.48471 .02064 Mdot
.45132 .06507 Mdot
.34603 .18656 Mdot
.04416 .22698 Mdot
.6769 .09473 Mdot
.52363 .0729 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47146 .03842 Mdot
.40929 .11803 Mdot
.21832 .26266 Mdot
.79332 .12055 Mdot
.59827 .03513 Mdot
.54143 .61518 Mdot
.54604 .57309 Mdot
.61876 .47293 Mdot
.50009 .61792 Mdot
.50027 .61766 Mdot
.50087 .61686 Mdot
.50278 .61428 Mdot
.50884 .60609 Mdot
.52816 .58012 Mdot
.58951 .50144 Mdot
.77816 .3562 Mdot
.20181 .49704 Mdot
.39759 .58556 Mdot
.45014 .01299 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49038 .01299 Mdot
.46936 .04122 Mdot
.40266 .12594 Mdot
.19888 .26594 Mdot
.76857 .1194 Mdot
.57538 .0521 Mdot
.49108 .06037 Mdot
.39339 .15197 Mdot
.49992 .0001 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00329 Mdot
.49225 .01047 Mdot
.47532 .03326 Mdot
.42151 .10311 Mdot
.25467 .25059 Mdot
.84921 .13079 Mdot
.63758 .01855 Mdot
.60756 .54429 Mdot
.72687 .3983 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.48839 .01567 Mdot
.46303 .04964 Mdot
.38272 .14878 Mdot
.14199 .26363 Mdot
.71542 .11956 Mdot
.52197 .09925 Mdot
.36138 .21212 Mdot
.01817 .22892 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.4975 .00338 Mdot
.49202 .01078 Mdot
.47458 .03424 Mdot
.41917 .106 Mdot
.24766 .25353 Mdot
.83745 .1277 Mdot
.63083 .01962 Mdot
.59908 .55162 Mdot
.70654 .40954 Mdot
.04389 .44971 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.5074 .60804 Mdot
.52357 .58627 Mdot
.57497 .5193 Mdot
.73472 .37244 Mdot
.13211 .48132 Mdot
.35331 .59886 Mdot
.38434 .07885 Mdot
.25676 .22626 Mdot
.89066 .13269 Mdot
.50093 .61678 Mdot
.50297 .61403 Mdot
.50945 .60527 Mdot
.53011 .57752 Mdot
.59565 .49409 Mdot
.79619 .35272 Mdot
.22548 .49852 Mdot
.41887 .57052 Mdot
.49575 .57445 Mdot
.56627 .51478 Mdot
.73333 .36805 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50657 .60916 Mdot
.52093 .58981 Mdot
.56661 .52984 Mdot
.7093 .3871 Mdot
.08296 .46057 Mdot
.33774 .58626 Mdot
.38915 .06288 Mdot
.28742 .20636 Mdot
.95352 .16388 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00351 Mdot
.49171 .01119 Mdot
.4736 .03555 Mdot
.41607 .1098 Mdot
.23841 .25695 Mdot
.82265 .12452 Mdot
.62118 .02272 Mdot
.58441 .56612 Mdot
.66841 .43754 Mdot
.96046 .40126 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51271 .60087 Mdot
.54049 .56374 Mdot
.62834 .45724 Mdot
.88852 .36213 Mdot
.30257 .5017 Mdot
.4908 .51023 Mdot
.66523 .38312 Mdot
.04533 .42458 Mdot
.35835 .53923 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50386 .61281 Mdot
.51231 .60141 Mdot
.53921 .56543 Mdot
.62431 .46155 Mdot
.8775 .35888 Mdot
.29683 .50008 Mdot
.48767 .5115 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50883 .6061 Mdot
.52813 .58016 Mdot
.58942 .50156 Mdot
.77788 .35627 Mdot
.20142 .497 Mdot
.39727 .58576 Mdot
.44949 .01377 Mdot
.42722 .07891 Mdot
.29953 .21937 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52554 .58362 Mdot
.58122 .51155 Mdot
.75351 .36404 Mdot
.16448 .49079 Mdot
.37036 .59812 Mdot
.40257 .06487 Mdot
.2976 .20587 Mdot
.9645 .17323 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00294 Mdot
.49306 .00937 Mdot
.47789 .0298 Mdot
.42967 .0929 Mdot
.27936 .23794 Mdot
.89437 .14705 Mdot
.65644 .02427 Mdot
.61718 .54322 Mdot
.73823 .39608 Mdot
.09736 .48081 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51436 .59864 Mdot
.54574 .55682 Mdot
.64478 .44037 Mdot
.93225 .37944 Mdot
.3183 .5136 Mdot
.48728 .52538 Mdot
.63719 .41337 Mdot
.96834 .38422 Mdot
.50021 .61775 Mdot
.50067 .61713 Mdot
.50214 .61515 Mdot
.50681 .60884 Mdot
.52168 .5888 Mdot
.56898 .52684 Mdot
.71654 .38254 Mdot
.09758 .46744 Mdot
.34125 .59139 Mdot
.38435 .07138 Mdot
.26886 .21789 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49271 .00985 Mdot
.47676 .03132 Mdot
.42609 .0974 Mdot
.26849 .24395 Mdot
.87377 .13882 Mdot
.64916 .01991 Mdot
.61694 .53903 Mdot
.74477 .39157 Mdot
.1112 .48647 Mdot
.50089 .61683 Mdot
.50285 .61418 Mdot
.50908 .60577 Mdot
.52891 .57912 Mdot
.59188 .4986 Mdot
.78513 .35463 Mdot
.21133 .49784 Mdot
.4058 .58016 Mdot
.46708 .61046 Mdot
.47934 .01152 Mdot
.4607 .04758 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49236 .01032 Mdot
.47567 .03278 Mdot
.42262 .10172 Mdot
.25803 .24908 Mdot
.85501 .1325 Mdot
.64062 .01846 Mdot
.61076 .5419 Mdot
.73394 .39511 Mdot
.09464 .47776 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00198 Mdot
.49532 .00632 Mdot
.4851 .02012 Mdot
.45254 .06346 Mdot
.34986 .1829 Mdot
.05392 .23194 Mdot
.67864 .09898 Mdot
.51849 .08188 Mdot
.386 .17875 Mdot
.09677 .26304 Mdot
.50011 .61788 Mdot
.50035 .61756 Mdot
.50113 .61651 Mdot
.50359 .61318 Mdot
.51144 .60258 Mdot
.53644 .56909 Mdot
.61563 .47108 Mdot
.85342 .3536 Mdot
.28128 .4983 Mdot
.47501 .52138 Mdot
.63139 .41294 Mdot
.49967 .00045 Mdot
.49893 .00144 Mdot
.4966 .00459 Mdot
.48918 .01462 Mdot
.46552 .04633 Mdot
.39056 .13997 Mdot
.16408 .26654 Mdot
.73282 .11985 Mdot
.5389 .08415 Mdot
.40274 .16881 Mdot
.12961 .27611 Mdot
.68285 .14151 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50629 .60954 Mdot
.52004 .59101 Mdot
.56376 .53348 Mdot
.70058 .39299 Mdot
.06471 .45134 Mdot
.33443 .5786 Mdot
.39823 .04861 Mdot
.31958 .18228 Mdot
.02464 .20503 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49083 .01239 Mdot
.47079 .03932 Mdot
.40717 .12058 Mdot
.21206 .26396 Mdot
.78497 .11996 Mdot
.59087 .04022 Mdot
.5258 .0164 Mdot
.49926 .01708 Mdot
.47162 .04326 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01782 Mdot
.45797 .05633 Mdot
.36684 .16587 Mdot
.09846 .25143 Mdot
.69164 .1137 Mdot
.50767 .10659 Mdot
.3352 .2335 Mdot
.95739 .19446 Mdot
.64274 .07918 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50565 .6104 Mdot
.518 .59375 Mdot
.55728 .54179 Mdot
.68064 .40804 Mdot
.02042 .42692 Mdot
.32965 .55637 Mdot
.42943 .00163 Mdot
.42679 .06714 Mdot
.31816 .20136 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49527 .00639 Mdot
.48492 .02035 Mdot
.45199 .06419 Mdot
.34813 .18456 Mdot
.0495 .22972 Mdot
.67781 .09709 Mdot
.52071 .07795 Mdot
.39459 .16867 Mdot
.12167 .2708 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50793 .60733 Mdot
.52525 .58402 Mdot
.58028 .51272 Mdot
.75068 .36517 Mdot
.15982 .48966 Mdot
.36753 .59877 Mdot
.3987 .06843 Mdot
.28798 .21179 Mdot
.9453 .16207 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50824 .60691 Mdot
.52624 .5827 Mdot
.58341 .50886 Mdot
.76006 .36161 Mdot
.17496 .49306 Mdot
.37718 .59595 Mdot
.41291 .05468 Mdot
.32443 .18638 Mdot
.02286 .2075 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60223 Mdot
.53727 .56799 Mdot
.61824 .46819 Mdot
.86069 .35491 Mdot
.28643 .49861 Mdot
.47966 .51742 Mdot
.64246 .4023 Mdot
.99153 .39444 Mdot
.3533 .51199 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49258 .01002 Mdot
.47636 .03186 Mdot
.42482 .09899 Mdot
.26465 .24591 Mdot
.86676 .13632 Mdot
.64619 .01906 Mdot
.61534 .53929 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01634 Mdot
.46147 .05171 Mdot
.3778 .15419 Mdot
.12831 .26067 Mdot
.70654 .11859 Mdot
.51466 .10502 Mdot
.34472 .2272 Mdot
.97711 .20605 Mdot
.64371 .0902 Mdot
.5003 .61763 Mdot
.50096 .61673 Mdot
.50307 .61389 Mdot
.50978 .60483 Mdot
.53115 .57613 Mdot
.59895 .4902 Mdot
.80579 .35163 Mdot
.23684 .49867 Mdot
.42998 .56151 Mdot
.52144 .54169 Mdot
.64498 .42512 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51244 .60124 Mdot
.53962 .56488 Mdot
.62563 .46014 Mdot
.8811 .35989 Mdot
.29879 .50055 Mdot
.48888 .51085 Mdot
.66231 .38514 Mdot
.03913 .42106 Mdot
.35785 .536 Mdot
.50122 .61639 Mdot
.50387 .6128 Mdot
.51234 .60137 Mdot
.5393 .5653 Mdot
.62463 .46122 Mdot
.87836 .35911 Mdot
.2973 .50019 Mdot
.48798 .51132 Mdot
.66064 .38643 Mdot
.03538 .41896 Mdot
.35749 .53412 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00317 Mdot
.49252 .0101 Mdot
.47618 .0321 Mdot
.42423 .09972 Mdot
.26288 .24678 Mdot
.86358 .13524 Mdot
.64476 .0188 Mdot
.61434 .53972 Mdot
.74106 .3924 Mdot
.10614 .48367 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.5085 .60655 Mdot
.52709 .58155 Mdot
.58612 .50556 Mdot
.7681 .35897 Mdot
.18728 .4952 Mdot
.38602 .59206 Mdot
.42804 .03849 Mdot
.36577 .14869 Mdot
.12518 .25314 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50593 .61003 Mdot
.51889 .59256 Mdot
.5601 .53815 Mdot
.68935 .40119 Mdot
.04021 .43807 Mdot
.33139 .56674 Mdot
.41439 .0243 Mdot
.37507 .12859 Mdot
.16701 .25652 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49438 .00759 Mdot
.48209 .02416 Mdot
.44301 .07587 Mdot
.32025 .20927 Mdot
.98164 .19229 Mdot
.67051 .06277 Mdot
.56895 .00083 Mdot
.5676 .55806 Mdot
.66464 .43124 Mdot
.50038 .61752 Mdot
.50121 .61641 Mdot
.50384 .61285 Mdot
.51223 .60152 Mdot
.53896 .56576 Mdot
.62354 .46239 Mdot
.87537 .35831 Mdot
.29562 .49983 Mdot
.48687 .51199 Mdot
.65846 .38818 Mdot
.03038 .41617 Mdot
.50023 .61772 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50747 .60794 Mdot
.5238 .58596 Mdot
.57569 .51841 Mdot
.73689 .37136 Mdot
.13602 .48266 Mdot
.35506 .59921 Mdot
.38552 .07838 Mdot
.2587 .22571 Mdot
.50102 .61666 Mdot
.50323 .61366 Mdot
.51031 .60412 Mdot
.53282 .5739 Mdot
.60422 .48404 Mdot
.82103 .35095 Mdot
.25318 .49846 Mdot
.44665 .547 Mdot
.56158 .49132 Mdot
.7666 .34458 Mdot
.20906 .48727 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48856 .01544 Mdot
.46358 .04891 Mdot
.38443 .14688 Mdot
.14677 .26446 Mdot
.71886 .11974 Mdot
.52512 .09654 Mdot
.36892 .20478 Mdot
.03757 .23929 Mdot
.65039 .11971 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49506 .00667 Mdot
.48427 .02122 Mdot
.44993 .06688 Mdot
.34172 .19059 Mdot
.03334 .22127 Mdot
.67531 .08968 Mdot
.53021 .06184 Mdot
.43015 .12453 Mdot
.22865 .27075 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01652 Mdot
.46103 .05229 Mdot
.37643 .15567 Mdot
.12455 .25971 Mdot
.70433 .11819 Mdot
.51309 .10607 Mdot
.34147 .22991 Mdot
.96947 .20178 Mdot
.64298 .08635 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50768 .60767 Mdot
.52445 .58509 Mdot
.57776 .51583 Mdot
.74312 .36843 Mdot
.147 .48614 Mdot
.36041 .59958 Mdot
.39028 .07539 Mdot
.2683 .22196 Mdot
.90915 .14224 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49573 .00577 Mdot
.48639 .01837 Mdot
.45666 .05805 Mdot
.36273 .17011 Mdot
.08749 .24719 Mdot
.68752 .11087 Mdot
.50813 .10333 Mdot
.34094 .22744 Mdot
.97294 .20247 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49711 .00391 Mdot
.49078 .01245 Mdot
.47064 .03952 Mdot
.4067 .12114 Mdot
.21068 .26421 Mdot
.78318 .11986 Mdot
.58925 .04139 Mdot
.52228 .02081 Mdot
.48861 .03136 Mdot
.43787 .08751 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.48751 .01687 Mdot
.46022 .05336 Mdot
.37387 .15843 Mdot
.11752 .25775 Mdot
.70048 .11729 Mdot
.51071 .10737 Mdot
.33698 .23343 Mdot
.95929 .19609 Mdot
.642 .08123 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48857 .01543 Mdot
.46361 .04887 Mdot
.38453 .14678 Mdot
.14704 .26451 Mdot
.71906 .11974 Mdot
.52531 .09638 Mdot
.36936 .20434 Mdot
.03873 .23989 Mdot
.65058 .12021 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48701 .01754 Mdot
.45863 .05547 Mdot
.36888 .16373 Mdot
.10397 .2534 Mdot
.69396 .11491 Mdot
.50803 .10746 Mdot
.33415 .23486 Mdot
.95415 .19293 Mdot
.64197 .07809 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49631 .00498 Mdot
.48824 .01587 Mdot
.46256 .05026 Mdot
.38124 .15042 Mdot
.13785 .26283 Mdot
.71259 .11934 Mdot
.51949 .10131 Mdot
.35556 .21758 Mdot
.00352 .22084 Mdot
.49978 .0003 Mdot
.49928 .00097 Mdot
.49772 .00309 Mdot
.49272 .00983 Mdot
.47682 .03124 Mdot
.42628 .09716 Mdot
.26908 .24364 Mdot
.87485 .13922 Mdot
.64959 .02007 Mdot
.61711 .53907 Mdot
.74487 .39161 Mdot
.11124 .48654 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49696 .0041 Mdot
.49032 .01307 Mdot
.46918 .04146 Mdot
.40209 .12661 Mdot
.19723 .26612 Mdot
.76664 .11938 Mdot
.57348 .05365 Mdot
.48667 .066 Mdot
.37988 .16708 Mdot
.10953 .2608 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50119 .61642 Mdot
.5038 .6129 Mdot
.5121 .60169 Mdot
.53854 .56631 Mdot
.62223 .46381 Mdot
.87177 .35738 Mdot
.29351 .49945 Mdot
.48538 .51299 Mdot
.65534 .39078 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .00681 Mdot
.48393 .02169 Mdot
.44884 .0683 Mdot
.33834 .19369 Mdot
.02493 .21671 Mdot
.67428 .08555 Mdot
.53586 .05259 Mdot
.45076 .09752 Mdot
.29298 .23971 Mdot
.50031 .61762 Mdot
.50098 .61672 Mdot
.50311 .61383 Mdot
.50991 .60465 Mdot
.53156 .57559 Mdot
.60023 .48869 Mdot
.80951 .35134 Mdot
.24102 .49865 Mdot
.43418 .55794 Mdot
.53141 .52901 Mdot
.67545 .39736 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49134 .0117 Mdot
.4724 .03716 Mdot
.41227 .11444 Mdot
.22711 .26046 Mdot
.80568 .12185 Mdot
.60852 .02886 Mdot
.56183 .59101 Mdot
.60555 .50018 Mdot
.79625 .35882 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57437 .52005 Mdot
.73291 .37336 Mdot
.1288 .48015 Mdot
.3519 .59847 Mdot
.38355 .07901 Mdot
.2557 .22646 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.4649 .04715 Mdot
.38861 .14219 Mdot
.15854 .26604 Mdot
.72809 .11989 Mdot
.5341 .08852 Mdot
.39088 .18193 Mdot
.0965 .26602 Mdot
.66608 .13851 Mdot
.50079 .61696 Mdot
.50253 .61462 Mdot
.50806 .60715 Mdot
.52567 .58345 Mdot
.58163 .51105 Mdot
.75472 .36357 Mdot
.16645 .49125 Mdot
.37159 .59779 Mdot
.40434 .0632 Mdot
.30208 .20291 Mdot
.97376 .1787 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .01561 Mdot
.46319 .04943 Mdot
.3832 .14825 Mdot
.14333 .26388 Mdot
.71637 .11961 Mdot
.52283 .09853 Mdot
.36341 .21017 Mdot
.49983 .00023 Mdot
.49946 .00074 Mdot
.49826 .00235 Mdot
.49447 .00747 Mdot
.48238 .02377 Mdot
.44392 .07469 Mdot
.32307 .20695 Mdot
.98822 .19604 Mdot
.67102 .06629 Mdot
.56376 .00876 Mdot
.54959 .58156 Mdot
.60861 .4885 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .0019 Mdot
.49552 .00605 Mdot
.48574 .01925 Mdot
.45458 .06079 Mdot
.35623 .17667 Mdot
.07037 .2398 Mdot
.68236 .10538 Mdot
.51185 .0944 Mdot
.3591 .20862 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00328 Mdot
.49226 .01045 Mdot
.47534 .03322 Mdot
.42159 .103 Mdot
.25493 .25048 Mdot
.84966 .13092 Mdot
.63782 .01854 Mdot
.60783 .54408 Mdot
.72749 .39801 Mdot
.08349 .47191 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.5064 .60938 Mdot
.5204 .59052 Mdot
.56492 .53199 Mdot
.70415 .39052 Mdot
.07228 .45524 Mdot
.33567 .58192 Mdot
.3941 .05498 Mdot
.30514 .19375 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49245 .01019 Mdot
.47596 .0324 Mdot
.42353 .10059 Mdot
.26078 .2478 Mdot
.85983 .13401 Mdot
.64299 .01858 Mdot
.61293 .54048 Mdot
.73841 .39333 Mdot
.102 .48154 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .00421 Mdot
.49008 .0134 Mdot
.46839 .04251 Mdot
.39961 .12952 Mdot
.19004 .26672 Mdot
.75848 .11939 Mdot
.56531 .06052 Mdot
.46738 .09056 Mdot
.32086 .22372 Mdot
.95887 .18601 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47147 .03841 Mdot
.40932 .11799 Mdot
.21841 .26264 Mdot
.79345 .12056 Mdot
.59838 .03506 Mdot
.54166 .61491 Mdot
.54671 .57223 Mdot
.62083 .47067 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50779 .60751 Mdot
.52481 .58461 Mdot
.5789 .51442 Mdot
.74654 .36691 Mdot
.15286 .48782 Mdot
.36355 .59938 Mdot
.39374 .0727 Mdot
.27611 .21826 Mdot
.92296 .14959 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51018 .60429 Mdot
.53242 .57444 Mdot
.60295 .48552 Mdot
.81736 .35099 Mdot
.24944 .49854 Mdot
.44279 .55044 Mdot
.55216 .50295 Mdot
.73837 .3558 Mdot
.16268 .48169 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60082 Mdot
.5406 .56359 Mdot
.62869 .45687 Mdot
.88946 .36244 Mdot
.30303 .50187 Mdot
.49099 .51022 Mdot
.66544 .38301 Mdot
.04571 .42481 Mdot
.35836 .53946 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .00421 Mdot
.49008 .01339 Mdot
.46841 .04249 Mdot
.39966 .12947 Mdot
.19017 .26671 Mdot
.75862 .11938 Mdot
.56545 .0604 Mdot
.46772 .09012 Mdot
.3219 .22287 Mdot
.96129 .18733 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61025 Mdot
.51836 .59327 Mdot
.55842 .54032 Mdot
.68416 .40522 Mdot
.0285 .4315 Mdot
.33032 .56066 Mdot
.42316 .01112 Mdot
.40516 .09393 Mdot
.25317 .24145 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50972 .60491 Mdot
.53095 .5764 Mdot
.59832 .49094 Mdot
.80396 .35179 Mdot
.23474 .49866 Mdot
.42789 .56325 Mdot
.51654 .54794 Mdot
.62994 .44042 Mdot
.91732 .36718 Mdot
.50029 .61764 Mdot
.50094 .61677 Mdot
.50299 .614 Mdot
.50951 .60519 Mdot
.53029 .57727 Mdot
.59624 .49339 Mdot
.79792 .35248 Mdot
.22759 .49857 Mdot
.42089 .56892 Mdot
.50035 .5686 Mdot
.58034 .49725 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.51081 .60344 Mdot
.53443 .57177 Mdot
.60929 .47822 Mdot
.83552 .35147 Mdot
.26683 .49819 Mdot
.46074 .53421 Mdot
.59637 .45023 Mdot
.86788 .34134 Mdot
.31558 .47654 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50198 .61535 Mdot
.50632 .6095 Mdot
.52014 .59088 Mdot
.56407 .53307 Mdot
.70155 .39231 Mdot
.06678 .45241 Mdot
.33475 .57953 Mdot
.39706 .05041 Mdot
.31549 .18564 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00666 Mdot
.4843 .02119 Mdot
.45 .06678 Mdot
.34194 .19039 Mdot
.03389 .22157 Mdot
.67539 .08994 Mdot
.52985 .06243 Mdot
.42884 .12623 Mdot
.2246 .2719 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49457 .00733 Mdot
.48272 .02332 Mdot
.44498 .07332 Mdot
.32635 .2042 Mdot
.99594 .20045 Mdot
.67162 .07044 Mdot
.55765 .01815 Mdot
.52828 .6101 Mdot
.54111 .57241 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00244 Mdot
.49425 .00777 Mdot
.48167 .02473 Mdot
.44167 .0776 Mdot
.3161 .2126 Mdot
.97211 .18687 Mdot
.66974 .0577 Mdot
.57638 .60761 Mdot
.59324 .52604 Mdot
.7421 .37867 Mdot
.49991 .00012 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .00379 Mdot
.49106 .01207 Mdot
.47153 .03833 Mdot
.40951 .11777 Mdot
.21896 .26251 Mdot
.7942 .12062 Mdot
.59903 .03463 Mdot
.543 .61328 Mdot
.55069 .56708 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50622 .60963 Mdot
.51982 .5913 Mdot
.56307 .53435 Mdot
.69846 .39448 Mdot
.06019 .44895 Mdot
.33377 .57653 Mdot
.40092 .04453 Mdot
.32887 .17433 Mdot
.0468 .21709 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01062 Mdot
.47496 .03373 Mdot
.42038 .1045 Mdot
.2513 .25204 Mdot
.84349 .12923 Mdot
.6344 .01892 Mdot
.60378 .54742 Mdot
.71803 .40285 Mdot
.06621 .46247 Mdot
.49999 1e-05 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .00491 Mdot
.48842 .01564 Mdot
.46312 .04952 Mdot
.38299 .14849 Mdot
.14273 .26377 Mdot
.71595 .11959 Mdot
.52244 .09885 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51179 .60212 Mdot
.53754 .56764 Mdot
.61908 .46726 Mdot
.86303 .35539 Mdot
.288 .49875 Mdot
.481 .51632 Mdot
.64559 .3994 Mdot
.99934 .39879 Mdot
.35408 .51589 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49457 .00733 Mdot
.48271 .02332 Mdot
.44498 .07332 Mdot
.32634 .20422 Mdot
.99591 .20042 Mdot
.67161 .07042 Mdot
.55768 .01811 Mdot
.52838 .60997 Mdot
.50069 .6171 Mdot
.5022 .61507 Mdot
.507 .60858 Mdot
.5223 .58798 Mdot
.57093 .52437 Mdot
.72248 .37903 Mdot
.1092 .4725 Mdot
.34467 .59471 Mdot
.38242 .07603 Mdot
.2594 .22332 Mdot
.89807 .13515 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49393 .0082 Mdot
.48065 .02609 Mdot
.43844 .08175 Mdot
.30616 .22021 Mdot
.94985 .17448 Mdot
.66753 .04631 Mdot
.5926 .58325 Mdot
.64888 .4645 Mdot
.8973 .37577 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49632 .00497 Mdot
.48829 .01582 Mdot
.46269 .05009 Mdot
.38164 .14998 Mdot
.13898 .26305 Mdot
.71335 .11941 Mdot
.52015 .10078 Mdot
.35708 .21617 Mdot
.00732 .22295 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01028 Mdot
.47576 .03266 Mdot
.42291 .10137 Mdot
.25889 .24869 Mdot
.85651 .13296 Mdot
.64137 .01847 Mdot
.61148 .54141 Mdot
.73546 .39448 Mdot
.09718 .47907 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60311 Mdot
.53519 .57075 Mdot
.6117 .47549 Mdot
.84234 .35209 Mdot
.27264 .49815 Mdot
.46663 .52886 Mdot
.61092 .43415 Mdot
.90845 .35388 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48943 .01427 Mdot
.46634 .04525 Mdot
.39313 .13704 Mdot
.17139 .26695 Mdot
.73945 .11973 Mdot
.54572 .07793 Mdot
.41963 .14931 Mdot
.17803 .28203 Mdot
.7217 .13681 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50199 .61535 Mdot
.50634 .60947 Mdot
.52019 .59081 Mdot
.56423 .53287 Mdot
.70203 .39198 Mdot
.0678 .45295 Mdot
.33492 .57998 Mdot
.39649 .05129 Mdot
.3135 .18725 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00586 Mdot
.48619 .01864 Mdot
.45603 .05888 Mdot
.36076 .17212 Mdot
.08227 .24503 Mdot
.6858 .10933 Mdot
.50889 .10109 Mdot
.34533 .22295 Mdot
.98459 .20868 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50417 .6124 Mdot
.51329 .60009 Mdot
.54234 .5613 Mdot
.63413 .45116 Mdot
.90415 .36757 Mdot
.3094 .50496 Mdot
.49236 .51203 Mdot
.66388 .38557 Mdot
.04001 .42227 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.5128 .60075 Mdot
.54077 .56336 Mdot
.62923 .4563 Mdot
.89092 .36291 Mdot
.30372 .50213 Mdot
.49126 .51023 Mdot
.66569 .38291 Mdot
.04613 .42508 Mdot
.35834 .53973 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53084 .57655 Mdot
.59796 .49137 Mdot
.80291 .3519 Mdot
.23352 .49865 Mdot
.42668 .56424 Mdot
.51372 .55154 Mdot
.6213 .44967 Mdot
.89373 .35831 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49394 .00819 Mdot
.4807 .02604 Mdot
.43857 .08158 Mdot
.30656 .21991 Mdot
.95074 .17497 Mdot
.66763 .04674 Mdot
.592 .58416 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49615 .0052 Mdot
.48773 .01656 Mdot
.46094 .05241 Mdot
.37613 .15599 Mdot
.12373 .25949 Mdot
.70387 .1181 Mdot
.51278 .10626 Mdot
.34084 .23042 Mdot
.96802 .20097 Mdot
.64284 .08562 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48854 .01548 Mdot
.4635 .04902 Mdot
.38419 .14715 Mdot
.14609 .26435 Mdot
.71836 .11971 Mdot
.52465 .09695 Mdot
.36778 .2059 Mdot
.03463 .23775 Mdot
.64994 .11842 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00244 Mdot
.49424 .00778 Mdot
.48166 .02474 Mdot
.44163 .07765 Mdot
.31599 .21269 Mdot
.97185 .18673 Mdot
.66971 .05756 Mdot
.57658 .60731 Mdot
.59392 .52521 Mdot
.74411 .37777 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49714 .00387 Mdot
.49088 .01232 Mdot
.47094 .03911 Mdot
.40767 .11998 Mdot
.21354 .26367 Mdot
.78691 .12008 Mdot
.59262 .03897 Mdot
.52956 .01172 Mdot
.5106 .00191 Mdot
.50751 .61298 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50661 .6091 Mdot
.52107 .58963 Mdot
.56703 .52931 Mdot
.71059 .38626 Mdot
.08561 .46185 Mdot
.33831 .58726 Mdot
.38811 .06462 Mdot
.28355 .2089 Mdot
.94555 .1594 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50775 .60757 Mdot
.52468 .58479 Mdot
.57847 .51495 Mdot
.74525 .36748 Mdot
.15067 .4872 Mdot
.36235 .59949 Mdot
.39237 .0738 Mdot
.27295 .21981 Mdot
.91729 .14654 Mdot
.50103 .61664 Mdot
.5033 .61358 Mdot
.5105 .60385 Mdot
.53345 .57307 Mdot
.60621 .48175 Mdot
.82672 .35102 Mdot
.25875 .49834 Mdot
.45242 .5418 Mdot
.57578 .47417 Mdot
.80855 .3365 Mdot
.26409 .48347 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48083 .02586 Mdot
.43898 .08105 Mdot
.30784 .21896 Mdot
.95356 .17651 Mdot
.66795 .04814 Mdot
.59006 .58707 Mdot
.64015 .4733 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50102 .61666 Mdot
.50325 .61365 Mdot
.51034 .60407 Mdot
.53294 .57375 Mdot
.60459 .48361 Mdot
.82209 .35095 Mdot
.25424 .49844 Mdot
.44775 .54602 Mdot
.56428 .48803 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49465 .00723 Mdot
.48296 .023 Mdot
.44574 .07233 Mdot
.32871 .20219 Mdot
.00155 .20364 Mdot
.67207 .07343 Mdot
.55325 .02498 Mdot
.51284 .01309 Mdot
.49166 .02081 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51217 .6016 Mdot
.53876 .56603 Mdot
.6229 .46308 Mdot
.87361 .35785 Mdot
.2946 .49964 Mdot
.48617 .51245 Mdot
.65701 .38938 Mdot
.02698 .41427 Mdot
.35668 .5299 Mdot
.50131 .61627 Mdot
.50416 .61241 Mdot
.51327 .60012 Mdot
.54225 .56141 Mdot
.63386 .45144 Mdot
.90342 .3673 Mdot
.30912 .50478 Mdot
.49236 .51186 Mdot
.66416 .38525 Mdot
.04081 .42267 Mdot
.35691 .53816 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50747 .60794 Mdot
.52381 .58595 Mdot
.57572 .51837 Mdot
.73697 .37132 Mdot
.13616 .4827 Mdot
.35512 .59922 Mdot
.38557 .07836 Mdot
.25878 .22568 Mdot
.89362 .13424 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.496 .0054 Mdot
.48727 .01719 Mdot
.45946 .05437 Mdot
.37149 .16098 Mdot
.11102 .25575 Mdot
.6972 .11625 Mdot
.50911 .10781 Mdot
.33466 .23497 Mdot
.95447 .19333 Mdot
.64165 .07868 Mdot
.50024 .61772 Mdot
.50075 .61702 Mdot
.50239 .6148 Mdot
.50762 .60774 Mdot
.52428 .58531 Mdot
.57723 .51649 Mdot
.74152 .36916 Mdot
.14421 .48529 Mdot
.35899 .59957 Mdot
.38886 .07639 Mdot
.26525 .22326 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60801 Mdot
.52365 .58616 Mdot
.57522 .519 Mdot
.73545 .37207 Mdot
.13343 .48178 Mdot
.35389 .59899 Mdot
.38471 .07873 Mdot
.25733 .22611 Mdot
.89147 .13312 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49703 .00401 Mdot
.49055 .01276 Mdot
.4699 .0405 Mdot
.40438 .12391 Mdot
.20389 .2653 Mdot
.77463 .11952 Mdot
.58124 .04744 Mdot
.50448 .04328 Mdot
.43445 .10234 Mdot
.26886 .24885 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51129 .60279 Mdot
.53596 .56973 Mdot
.61411 .47278 Mdot
.84914 .35295 Mdot
.27806 .4982 Mdot
.47195 .52407 Mdot
.62399 .4204 Mdot
.94377 .36935 Mdot
.34615 .49078 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00553 Mdot
.48695 .01762 Mdot
.45844 .05571 Mdot
.36831 .16433 Mdot
.10242 .25286 Mdot
.69329 .11458 Mdot
.50789 .10727 Mdot
.33432 .23459 Mdot
.95475 .1932 Mdot
.64214 .07826 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .00229 Mdot
.49459 .0073 Mdot
.48278 .02324 Mdot
.44518 .07306 Mdot
.32697 .20368 Mdot
.9974 .20127 Mdot
.67173 .07121 Mdot
.55651 .01992 Mdot
.52427 .61554 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49457 .00733 Mdot
.4827 .02334 Mdot
.44495 .07336 Mdot
.32624 .2043 Mdot
.99568 .2003 Mdot
.6716 .0703 Mdot
.50118 .61644 Mdot
.50375 .61297 Mdot
.51194 .60191 Mdot
.53803 .56699 Mdot
.62062 .46557 Mdot
.86732 .35633 Mdot
.29077 .49906 Mdot
.48328 .51452 Mdot
.65077 .39474 Mdot
.01206 .40591 Mdot
.35528 .52234 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49072 .01253 Mdot
.47045 .03977 Mdot
.4061 .12185 Mdot
.20895 .26451 Mdot
.78095 .11975 Mdot
.58719 .0429 Mdot
.51778 .02646 Mdot
.47497 .04957 Mdot
.39477 .14016 Mdot
.50122 .61639 Mdot
.50388 .6128 Mdot
.51235 .60135 Mdot
.53934 .56525 Mdot
.62475 .46109 Mdot
.87869 .3592 Mdot
.29748 .50023 Mdot
.48809 .51126 Mdot
.66085 .38626 Mdot
.03587 .41923 Mdot
.35753 .53436 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00057 Mdot
.49864 .00183 Mdot
.49568 .00584 Mdot
.48624 .01858 Mdot
.45618 .05869 Mdot
.36122 .17165 Mdot
.08348 .24554 Mdot
.68619 .1097 Mdot
.50869 .10165 Mdot
.34422 .22409 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50995 .6046 Mdot
.53169 .57542 Mdot
.60065 .48821 Mdot
.81071 .35127 Mdot
.24235 .49864 Mdot
.43553 .55678 Mdot
.53464 .52493 Mdot
.68529 .38941 Mdot
.05521 .43957 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50993 .60462 Mdot
.53164 .57548 Mdot
.60049 .48839 Mdot
.81026 .35129 Mdot
.24186 .49865 Mdot
.43503 .55722 Mdot
.53343 .52645 Mdot
.68161 .39232 Mdot
.04681 .4351 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52555 .58361 Mdot
.58125 .51151 Mdot
.75361 .36401 Mdot
.16463 .49083 Mdot
.37045 .5981 Mdot
.4027 .06475 Mdot
.29794 .20565 Mdot
.96518 .17363 Mdot
.50054 .6173 Mdot
.50172 .61571 Mdot
.50549 .61062 Mdot
.51748 .59446 Mdot
.55563 .54393 Mdot
.67553 .41225 Mdot
.0085 .42012 Mdot
.32873 .54998 Mdot
.43884 .60529 Mdot
.45946 .02443 Mdot
.41994 .09556 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48875 .01519 Mdot
.46417 .04813 Mdot
.38629 .1448 Mdot
.15199 .26525 Mdot
.72282 .11985 Mdot
.5289 .09321 Mdot
.37808 .1955 Mdot
.06177 .25133 Mdot
.65511 .12924 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51288 .60064 Mdot
.54103 .56302 Mdot
.63004 .45544 Mdot
.89312 .36364 Mdot
.30474 .50254 Mdot
.49161 .51032 Mdot
.66589 .38291 Mdot
.04633 .42526 Mdot
.35826 .53996 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00479 Mdot
.48871 .01524 Mdot
.46405 .04829 Mdot
.38591 .14523 Mdot
.15093 .2651 Mdot
.72199 .11983 Mdot
.5281 .09392 Mdot
.37613 .1975 Mdot
.05657 .24885 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00381 Mdot
.49101 .01214 Mdot
.47137 .03854 Mdot
.40902 .11836 Mdot
.21751 .26284 Mdot
.79223 .12046 Mdot
.59732 .03575 Mdot
.53947 .61757 Mdot
.54022 .58069 Mdot
.60064 .49348 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50755 .60783 Mdot
.52406 .58561 Mdot
.57652 .51737 Mdot
.73939 .37016 Mdot
.14047 .48412 Mdot
.35715 .59947 Mdot
.38719 .07748 Mdot
.26183 .22461 Mdot
.8984 .13669 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45943 .0544 Mdot
.37141 .16106 Mdot
.11082 .25569 Mdot
.69711 .11622 Mdot
.50907 .10782 Mdot
.33462 .23499 Mdot
.95439 .19329 Mdot
.64164 .07864 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01444 Mdot
.46593 .04579 Mdot
.39185 .13851 Mdot
.16774 .26678 Mdot
.73608 .1198 Mdot
.54224 .08109 Mdot
.41103 .15934 Mdot
.15321 .28043 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46948 .04105 Mdot
.40306 .12547 Mdot
.20004 .26581 Mdot
.76996 .11942 Mdot
.57673 .05101 Mdot
.4942 .05638 Mdot
.40298 .14086 Mdot
.50067 .61712 Mdot
.50214 .61514 Mdot
.50683 .60881 Mdot
.52176 .5887 Mdot
.56923 .52652 Mdot
.7173 .38208 Mdot
.09908 .46811 Mdot
.34166 .59186 Mdot
.38401 .07209 Mdot
.26736 .21876 Mdot
.91341 .14238 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49465 .00722 Mdot
.48297 .02298 Mdot
.44579 .07227 Mdot
.32886 .20207 Mdot
.00191 .20384 Mdot
.67209 .07362 Mdot
.55298 .0254 Mdot
.51187 .01441 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50267 .61442 Mdot
.50852 .60653 Mdot
.52713 .5815 Mdot
.58625 .5054 Mdot
.76849 .35885 Mdot
.18786 .49529 Mdot
.38646 .59185 Mdot
.42883 .03761 Mdot
.36798 .14644 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00297 Mdot
.49299 .00947 Mdot
.47766 .03011 Mdot
.42894 .09382 Mdot
.27713 .23923 Mdot
.89006 .14522 Mdot
.65509 .02314 Mdot
.61764 .54178 Mdot
.74103 .39447 Mdot
.10276 .48325 Mdot
.50089 .61684 Mdot
.50282 .61422 Mdot
.50899 .60589 Mdot
.52865 .57947 Mdot
.59104 .4996 Mdot
.78266 .35516 Mdot
.20801 .49759 Mdot
.40288 .58214 Mdot
.46096 .61798 Mdot
.46105 .03569 Mdot
.40329 .11993 Mdot
.49994 9e-05 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49337 .00896 Mdot
.47887 .02849 Mdot
.43278 .08897 Mdot
.28882 .23215 Mdot
.91319 .1556 Mdot
.66142 .03033 Mdot
.61234 .55265 Mdot
.71814 .40805 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49092 .01227 Mdot
.47106 .03895 Mdot
.40805 .11953 Mdot
.21465 .26345 Mdot
.78838 .12017 Mdot
.59394 .03805 Mdot
.53237 .00825 Mdot
.51902 .6087 Mdot
.53413 .5773 Mdot
.50065 .61715 Mdot
.50207 .61523 Mdot
.50661 .6091 Mdot
.52106 .58964 Mdot
.567 .52935 Mdot
.7105 .38632 Mdot
.08541 .46176 Mdot
.33827 .58719 Mdot
.38818 .06449 Mdot
.28383 .20872 Mdot
.94612 .15972 Mdot
.50103 .61664 Mdot
.5033 .61358 Mdot
.51051 .60385 Mdot
.53346 .57306 Mdot
.60624 .48172 Mdot
.82679 .35102 Mdot
.25883 .49834 Mdot
.45249 .54173 Mdot
.57596 .47395 Mdot
.80909 .33646 Mdot
.26468 .48338 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49374 .00845 Mdot
.48006 .02689 Mdot
.43655 .08416 Mdot
.30038 .22437 Mdot
.93734 .16777 Mdot
.66588 .04036 Mdot
.60057 .57124 Mdot
.67629 .43924 Mdot
.96558 .40758 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49202 .01078 Mdot
.47457 .03426 Mdot
.41913 .10605 Mdot
.24753 .25358 Mdot
.83723 .12765 Mdot
.63069 .01965 Mdot
.5989 .55179 Mdot
.70609 .40982 Mdot
.04298 .44918 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00233 Mdot
.49451 .00741 Mdot
.48251 .02359 Mdot
.44434 .07414 Mdot
.32438 .20587 Mdot
.99127 .19778 Mdot
.67125 .06793 Mdot
.56134 .01246 Mdot
.54117 .59276 Mdot
.58207 .52 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.4871 .01741 Mdot
.45893 .05507 Mdot
.36983 .16273 Mdot
.10653 .25428 Mdot
.6951 .11542 Mdot
.50834 .10769 Mdot
.3341 .23511 Mdot
.95368 .19277 Mdot
.64176 .07805 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49726 .0037 Mdot
.49128 .01178 Mdot
.47222 .03741 Mdot
.41169 .11514 Mdot
.22539 .26092 Mdot
.8032 .12155 Mdot
.60653 .03 Mdot
.558 .59544 Mdot
.59455 .51286 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01098 Mdot
.47409 .03489 Mdot
.41763 .10789 Mdot
.24307 .25529 Mdot
.82999 .126 Mdot
.62613 .02093 Mdot
.59226 .55814 Mdot
.68917 .42124 Mdot
.50024 .6177 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60736 Mdot
.52517 .58412 Mdot
.58005 .513 Mdot
.75 .36545 Mdot
.15868 .48937 Mdot
.36686 .5989 Mdot
.39783 .06921 Mdot
.28585 .21303 Mdot
.50116 .61646 Mdot
.50371 .61303 Mdot
.51181 .60209 Mdot
.5376 .56755 Mdot
.61928 .46704 Mdot
.86359 .35551 Mdot
.28837 .49878 Mdot
.48132 .51606 Mdot
.64631 .39874 Mdot
.00113 .39979 Mdot
.35426 .5168 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.49309 .00933 Mdot
.47799 .02967 Mdot
.42999 .0925 Mdot
.28032 .23737 Mdot
.89625 .14786 Mdot
.65701 .02479 Mdot
.6169 .54394 Mdot
.73679 .3969 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48754 .01683 Mdot
.46031 .05324 Mdot
.37417 .15812 Mdot
.11833 .25798 Mdot
.7009 .1174 Mdot
.51094 .10726 Mdot
.33739 .23312 Mdot
.96019 .1966 Mdot
.64209 .08169 Mdot
.49994 8e-05 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00268 Mdot
.49367 .00855 Mdot
.47984 .02719 Mdot
.43585 .08506 Mdot
.29821 .22589 Mdot
.93272 .16536 Mdot
.66517 .03828 Mdot
.60323 .56719 Mdot
.6855 .4316 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49711 .0039 Mdot
.4908 .01242 Mdot
.4707 .03944 Mdot
.40689 .12092 Mdot
.21124 .26411 Mdot
.78391 .1199 Mdot
.58991 .04091 Mdot
.52371 .01901 Mdot
.49295 .02555 Mdot
.45162 .06971 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .0039 Mdot
.49081 .01241 Mdot
.47074 .03938 Mdot
.40703 .12075 Mdot
.21165 .26403 Mdot
.78443 .11993 Mdot
.59039 .04056 Mdot
.52475 .01771 Mdot
.4961 .02133 Mdot
.50043 .61746 Mdot
.50136 .61619 Mdot
.50435 .61216 Mdot
.51385 .59933 Mdot
.54411 .55896 Mdot
.63968 .44547 Mdot
.91891 .3735 Mdot
.31457 .50907 Mdot
.49089 .51751 Mdot
.65354 .39624 Mdot
.01241 .40773 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00527 Mdot
.48757 .01679 Mdot
.46041 .05311 Mdot
.37447 .15779 Mdot
.11915 .25822 Mdot
.70134 .11752 Mdot
.5112 .10714 Mdot
.33783 .23279 Mdot
.96118 .19715 Mdot
.64218 .08219 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49179 .01109 Mdot
.47385 .03522 Mdot
.41687 .10882 Mdot
.24079 .25612 Mdot
.82638 .12524 Mdot
.62373 .02175 Mdot
.58854 .56187 Mdot
.67941 .4286 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51225 .6015 Mdot
.53901 .5657 Mdot
.62369 .46223 Mdot
.87579 .35842 Mdot
.29586 .49988 Mdot
.48704 .51188 Mdot
.65879 .38791 Mdot
.03113 .41659 Mdot
.35707 .53199 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .00499 Mdot
.48822 .0159 Mdot
.46249 .05036 Mdot
.381 .15068 Mdot
.13719 .26269 Mdot
.71215 .1193 Mdot
.51912 .10162 Mdot
.3547 .21837 Mdot
.00136 .21963 Mdot
.64598 .10249 Mdot
.50079 .61696 Mdot
.50252 .61463 Mdot
.50803 .60718 Mdot
.52559 .58357 Mdot
.58136 .51138 Mdot
.75392 .36388 Mdot
.16515 .49095 Mdot
.37077 .59801 Mdot
.40317 .06431 Mdot
.2991 .20489 Mdot
.96758 .17504 Mdot
.50019 .61778 Mdot
.50059 .61723 Mdot
.50188 .61549 Mdot
.506 .60992 Mdot
.51913 .59223 Mdot
.56088 .53716 Mdot
.69173 .3994 Mdot
.04549 .441 Mdot
.33194 .56942 Mdot
.41061 .02996 Mdot
.36213 .14238 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60602 Mdot
.52833 .57989 Mdot
.59005 .50079 Mdot
.77975 .35582 Mdot
.20402 .49725 Mdot
.39945 .58438 Mdot
.4539 .00849 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51076 .60351 Mdot
.53427 .57198 Mdot
.60878 .47881 Mdot
.83404 .35136 Mdot
.26552 .49821 Mdot
.4594 .53544 Mdot
.59305 .45401 Mdot
.85844 .33941 Mdot
.30927 .47684 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .0051 Mdot
.48797 .01624 Mdot
.46168 .05142 Mdot
.37848 .15344 Mdot
.1302 .26113 Mdot
.70769 .11877 Mdot
.51552 .10441 Mdot
.34658 .22561 Mdot
.98154 .20854 Mdot
.64413 .09245 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50483 .6115 Mdot
.5154 .59725 Mdot
.54902 .55252 Mdot
.65503 .43048 Mdot
.9585 .39244 Mdot
.32352 .52452 Mdot
.47483 .54775 Mdot
.58855 .46984 Mdot
.82833 .33981 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49802 .00268 Mdot
.49368 .00854 Mdot
.47987 .02715 Mdot
.43594 .08495 Mdot
.29849 .2257 Mdot
.93329 .16566 Mdot
.66526 .03854 Mdot
.6029 .56768 Mdot
.68438 .4325 Mdot
.98457 .41822 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50529 .61089 Mdot
.51685 .5953 Mdot
.55364 .5465 Mdot
.66938 .41749 Mdot
.99386 .4118 Mdot
.32755 .54218 Mdot
.45029 .58751 Mdot
.49968 .5878 Mdot
.5486 .54344 Mdot
.50068 .61711 Mdot
.50217 .6151 Mdot
.50691 .6087 Mdot
.52202 .58835 Mdot
.57004 .5255 Mdot
.71977 .38061 Mdot
.10394 .47026 Mdot
.34305 .5933 Mdot
.38307 .07417 Mdot
.26307 .22122 Mdot
.90513 .13838 Mdot
.50042 .61746 Mdot
.50134 .61622 Mdot
.50428 .61226 Mdot
.51363 .59964 Mdot
.54339 .55992 Mdot
.63742 .44777 Mdot
.91292 .37101 Mdot
.31262 .50728 Mdot
.49182 .51486 Mdot
.65876 .39091 Mdot
.02626 .41514 Mdot
.50097 .61672 Mdot
.5031 .61385 Mdot
.50987 .6047 Mdot
.53144 .57574 Mdot
.59988 .48911 Mdot
.80848 .35141 Mdot
.23988 .49866 Mdot
.43304 .55892 Mdot
.52868 .53248 Mdot
.6671 .4045 Mdot
.01261 .41618 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49439 .00758 Mdot
.48212 .02412 Mdot
.44309 .07577 Mdot
.32049 .20907 Mdot
.9822 .19261 Mdot
.67055 .06307 Mdot
.5685 .00151 Mdot
.56606 .56004 Mdot
.6599 .43551 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00383 Mdot
.49098 .01219 Mdot
.47126 .03869 Mdot
.40866 .11879 Mdot
.21645 .26307 Mdot
.7908 .12035 Mdot
.59607 .03659 Mdot
.53686 .00273 Mdot
.53245 .59089 Mdot
.57637 .52278 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50592 .61003 Mdot
.51887 .59258 Mdot
.56005 .53822 Mdot
.6892 .40131 Mdot
.03986 .43788 Mdot
.33136 .56656 Mdot
.41464 .02393 Mdot
.37593 .12765 Mdot
.16939 .25667 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.4955 .00608 Mdot
.48565 .01937 Mdot
.45431 .06115 Mdot
.35537 .17752 Mdot
.06813 .23877 Mdot
.68179 .10457 Mdot
.51259 .09291 Mdot
.36225 .20526 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.4934 .00892 Mdot
.47896 .02836 Mdot
.43307 .0886 Mdot
.28971 .23157 Mdot
.91502 .15648 Mdot
.66182 .03101 Mdot
.61165 .55382 Mdot
.71555 .40972 Mdot
.05262 .45761 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50642 .60937 Mdot
.52044 .59047 Mdot
.56505 .53183 Mdot
.70453 .39026 Mdot
.07307 .45565 Mdot
.33581 .58226 Mdot
.39369 .05561 Mdot
.30371 .19484 Mdot
.98846 .18415 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61085 Mdot
.51694 .59518 Mdot
.55391 .54615 Mdot
.67022 .41676 Mdot
.99588 .41294 Mdot
.32772 .54324 Mdot
.44874 .58994 Mdot
.49419 .59533 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49624 .00508 Mdot
.48802 .01618 Mdot
.46183 .05123 Mdot
.37895 .15294 Mdot
.13149 .26143 Mdot
.70848 .11888 Mdot
.51613 .10395 Mdot
.34794 .22443 Mdot
.9848 .21036 Mdot
.64443 .0941 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.5025 .61465 Mdot
.50797 .60726 Mdot
.5254 .58381 Mdot
.58078 .5121 Mdot
.75218 .36457 Mdot
.1623 .49027 Mdot
.36902 .59845 Mdot
.40071 .06661 Mdot
.29293 .20882 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.5054 .61074 Mdot
.51719 .59484 Mdot
.55472 .5451 Mdot
.67274 .4146 Mdot
.0019 .41636 Mdot
.32821 .54644 Mdot
.44405 .59726 Mdot
.47767 .61789 Mdot
.4779 .02028 Mdot
.49972 .00038 Mdot
.49909 .00123 Mdot
.49711 .00391 Mdot
.49079 .01244 Mdot
.47067 .03948 Mdot
.40679 .12104 Mdot
.21095 .26416 Mdot
.78353 .11988 Mdot
.58956 .04116 Mdot
.52296 .01996 Mdot
.49066 .02861 Mdot
.44438 .07913 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00457 Mdot
.48922 .01456 Mdot
.46567 .04614 Mdot
.39102 .13946 Mdot
.16537 .26663 Mdot
.73396 .11983 Mdot
.54006 .08309 Mdot
.40563 .16554 Mdot
.13779 .2779 Mdot
.68813 .14136 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50264 .61447 Mdot
.50841 .60668 Mdot
.52679 .58196 Mdot
.58516 .50673 Mdot
.76526 .35986 Mdot
.183 .49452 Mdot
.38285 .59358 Mdot
.42241 .04466 Mdot
.50107 .61659 Mdot
.5034 .61345 Mdot
.51082 .60343 Mdot
.53445 .57174 Mdot
.60937 .47814 Mdot
.83572 .35148 Mdot
.26701 .49819 Mdot
.46093 .53405 Mdot
.59682 .44973 Mdot
.86915 .34163 Mdot
.31638 .47653 Mdot
.50023 .61772 Mdot
.50074 .61703 Mdot
.50236 .61485 Mdot
.50752 .60788 Mdot
.52395 .58575 Mdot
.57618 .51779 Mdot
.73838 .37064 Mdot
.13866 .48353 Mdot
.35629 .59938 Mdot
.38647 .07789 Mdot
.26044 .22512 Mdot
.50018 .61779 Mdot
.50056 .61727 Mdot
.5018 .6156 Mdot
.50573 .61029 Mdot
.51826 .59341 Mdot
.5581 .54073 Mdot
.68319 .406 Mdot
.02627 .43024 Mdot
.33013 .55948 Mdot
.42487 .00853 Mdot
.41107 .08675 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50352 .61327 Mdot
.51123 .60287 Mdot
.53576 .57 Mdot
.61347 .4735 Mdot
.84733 .3527 Mdot
.27665 .49818 Mdot
.47059 .52529 Mdot
.62065 .42384 Mdot
.93486 .36513 Mdot
.50093 .61678 Mdot
.50295 .61405 Mdot
.50939 .60535 Mdot
.52992 .57777 Mdot
.59508 .49477 Mdot
.79452 .35296 Mdot
.22341 .49845 Mdot
.41689 .57204 Mdot
.49131 .5801 Mdot
.55269 .53213 Mdot
.69168 .39438 Mdot
.50108 .61657 Mdot
.50345 .61338 Mdot
.51098 .60321 Mdot
.53497 .57104 Mdot
.611 .47628 Mdot
.84037 .35189 Mdot
.271 .49815 Mdot
.46498 .53035 Mdot
.60685 .43857 Mdot
.89724 .34978 Mdot
.33127 .47851 Mdot
.49984 .00022 Mdot
.49947 .00071 Mdot
.49833 .00226 Mdot
.49466 .00721 Mdot
.483 .02294 Mdot
.44588 .07215 Mdot
.32915 .20182 Mdot
.0026 .20423 Mdot
.67215 .07399 Mdot
.55244 .02625 Mdot
.50997 .01701 Mdot
.48244 .03325 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60225 Mdot
.53722 .56806 Mdot
.61809 .46835 Mdot
.86028 .35483 Mdot
.28615 .49859 Mdot
.47941 .51762 Mdot
.64189 .40283 Mdot
.9901 .39366 Mdot
.35315 .51128 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46506 .04694 Mdot
.3891 .14163 Mdot
.15994 .26618 Mdot
.72926 .11988 Mdot
.53528 .08744 Mdot
.39379 .17876 Mdot
.10455 .26886 Mdot
.66953 .13978 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49788 .00286 Mdot
.49325 .00912 Mdot
.4785 .02899 Mdot
.43159 .09047 Mdot
.2852 .23442 Mdot
.90589 .15218 Mdot
.65966 .02777 Mdot
.61473 .54842 Mdot
.72737 .40236 Mdot
.07633 .47044 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00237 Mdot
.49441 .00755 Mdot
.48219 .02402 Mdot
.44332 .07547 Mdot
.32122 .20848 Mdot
.98388 .19357 Mdot
.67068 .06397 Mdot
.56718 .00352 Mdot
.56149 .56596 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51226 .60149 Mdot
.53903 .56566 Mdot
.62378 .46214 Mdot
.87602 .35848 Mdot
.29599 .49991 Mdot
.48713 .51183 Mdot
.65897 .38777 Mdot
.03155 .41682 Mdot
.50113 .6165 Mdot
.50361 .61315 Mdot
.51151 .6025 Mdot
.53665 .56882 Mdot
.61627 .47037 Mdot
.85521 .3539 Mdot
.28258 .49836 Mdot
.47621 .52033 Mdot
.6343 .41009 Mdot
.97077 .38314 Mdot
.35084 .50205 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50793 .60732 Mdot
.52527 .58399 Mdot
.58036 .51261 Mdot
.75094 .36507 Mdot
.16025 .48977 Mdot
.36779 .59872 Mdot
.39904 .06813 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54176 .56206 Mdot
.63232 .45305 Mdot
.89928 .36578 Mdot
.30743 .50382 Mdot
.49223 .51102 Mdot
.66538 .38384 Mdot
.04431 .42439 Mdot
.35763 .53947 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00406 Mdot
.49043 .01293 Mdot
.46952 .04101 Mdot
.40315 .12536 Mdot
.20032 .26577 Mdot
.7703 .11943 Mdot
.57706 .05074 Mdot
.49496 .05542 Mdot
.40529 .13813 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49737 .00355 Mdot
.49164 .0113 Mdot
.47336 .03588 Mdot
.4153 .11075 Mdot
.23611 .25773 Mdot
.8191 .12387 Mdot
.61867 .02378 Mdot
.5802 .57057 Mdot
.657 .44751 Mdot
.93292 .38714 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51257 .60107 Mdot
.54002 .56436 Mdot
.62687 .45881 Mdot
.8845 .36089 Mdot
.30057 .50105 Mdot
.48986 .51045 Mdot
.66394 .38395 Mdot
.04269 .42305 Mdot
.35817 .53781 Mdot
.50115 .61648 Mdot
.50365 .6131 Mdot
.51164 .60231 Mdot
.53708 .56824 Mdot
.61764 .46885 Mdot
.85903 .35459 Mdot
.28529 .49852 Mdot
.47866 .51825 Mdot
.64012 .40449 Mdot
.98563 .39119 Mdot
.35267 .50909 Mdot
.50078 .61698 Mdot
.50249 .61466 Mdot
.50795 .6073 Mdot
.52532 .58393 Mdot
.5805 .51245 Mdot
.75134 .36491 Mdot
.16091 .48993 Mdot
.36818 .59863 Mdot
.39957 .06764 Mdot
.29012 .21053 Mdot
.94949 .16448 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46847 .0424 Mdot
.39986 .12923 Mdot
.19076 .26667 Mdot
.75927 .11938 Mdot
.56611 .05984 Mdot
.50082 .61693 Mdot
.50261 .6145 Mdot
.50832 .60679 Mdot
.52651 .58233 Mdot
.58428 .5078 Mdot
.76265 .36072 Mdot
.179 .49382 Mdot
.37998 .59484 Mdot
.41751 .0499 Mdot
.33677 .17606 Mdot
.0519 .22332 Mdot
.50088 .61684 Mdot
.50282 .61423 Mdot
.50897 .60592 Mdot
.52857 .57958 Mdot
.5908 .4999 Mdot
.78195 .35531 Mdot
.20704 .49752 Mdot
.40204 .5827 Mdot
.45921 .00207 Mdot
.45585 .04247 Mdot
.38713 .13856 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00269 Mdot
.49366 .00856 Mdot
.47982 .02722 Mdot
.43578 .08515 Mdot
.298 .22604 Mdot
.93226 .16512 Mdot
.66509 .03808 Mdot
.60348 .56679 Mdot
.68639 .43088 Mdot
.98922 .42089 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .608 Mdot
.52365 .58616 Mdot
.57523 .51899 Mdot
.73549 .37205 Mdot
.1335 .4818 Mdot
.35393 .59899 Mdot
.38473 .07872 Mdot
.25737 .2261 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.49251 .01012 Mdot
.47614 .03216 Mdot
.4241 .09989 Mdot
.26248 .24698 Mdot
.86285 .135 Mdot
.64442 .01875 Mdot
.61409 .53984 Mdot
.7406 .39255 Mdot
.10544 .48331 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00266 Mdot
.49372 .00849 Mdot
.47998 .027 Mdot
.4363 .08448 Mdot
.29961 .22492 Mdot
.93568 .1669 Mdot
.66563 .03961 Mdot
.60154 .56977 Mdot
.67964 .4364 Mdot
.97352 .41197 Mdot
.50035 .61756 Mdot
.50113 .61651 Mdot
.5036 .61318 Mdot
.51145 .60257 Mdot
.53648 .56904 Mdot
.61575 .47095 Mdot
.85373 .35365 Mdot
.28151 .49831 Mdot
.47522 .52119 Mdot
.63191 .41244 Mdot
.96457 .37986 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50639 .6094 Mdot
.52036 .59058 Mdot
.56477 .53218 Mdot
.70368 .39084 Mdot
.07129 .45474 Mdot
.3355 .5815 Mdot
.39461 .05418 Mdot
.30694 .19238 Mdot
.99566 .18836 Mdot
.49984 .00021 Mdot
.49951 .00067 Mdot
.49842 .00213 Mdot
.49498 .00678 Mdot
.48401 .02158 Mdot
.4491 .06797 Mdot
.33913 .19297 Mdot
.02689 .21778 Mdot
.67451 .08653 Mdot
.53451 .05479 Mdot
.44586 .10402 Mdot
.27755 .24936 Mdot
.50123 .61637 Mdot
.50393 .61273 Mdot
.51251 .60115 Mdot
.53983 .56461 Mdot
.62627 .45945 Mdot
.88286 .3604 Mdot
.29972 .5008 Mdot
.48941 .51062 Mdot
.66321 .38447 Mdot
.04112 .42217 Mdot
.35803 .53701 Mdot
.50053 .61732 Mdot
.50168 .61576 Mdot
.50536 .61079 Mdot
.51708 .59499 Mdot
.55436 .54557 Mdot
.67162 .41556 Mdot
.99923 .41484 Mdot
.328 .54502 Mdot
.44613 .59401 Mdot
.48501 .60789 Mdot
.50142 .60657 Mdot
.50038 .61751 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51244 .60123 Mdot
.53963 .56488 Mdot
.62564 .46013 Mdot
.88114 .3599 Mdot
.29881 .50056 Mdot
.48889 .51085 Mdot
.66233 .38513 Mdot
.03918 .42108 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49632 .00497 Mdot
.48828 .01583 Mdot
.46267 .05012 Mdot
.38156 .15006 Mdot
.13876 .26301 Mdot
.7132 .11939 Mdot
.52002 .10088 Mdot
.35678 .21645 Mdot
.00656 .22253 Mdot
.6465 .1051 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60697 Mdot
.5261 .58288 Mdot
.58298 .50939 Mdot
.75876 .36207 Mdot
.17292 .49265 Mdot
.3758 .59645 Mdot
.41071 .05692 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00506 Mdot
.48806 .01612 Mdot
.46197 .05104 Mdot
.37939 .15245 Mdot
.13272 .26172 Mdot
.70925 .11898 Mdot
.51673 .1035 Mdot
.34928 .22326 Mdot
.98804 .21218 Mdot
.64473 .09575 Mdot
.50058 .61726 Mdot
.50184 .61555 Mdot
.50585 .61013 Mdot
.51865 .59288 Mdot
.55934 .53914 Mdot
.687 .403 Mdot
.03494 .43513 Mdot
.33089 .56402 Mdot
.41828 .01847 Mdot
.3884 .11366 Mdot
.2045 .25521 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50302 .61395 Mdot
.50964 .60502 Mdot
.5307 .57674 Mdot
.59752 .49188 Mdot
.80163 .35204 Mdot
.23203 .49864 Mdot
.42521 .56545 Mdot
.51029 .55591 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51165 .6023 Mdot
.53711 .56821 Mdot
.61772 .46877 Mdot
.85924 .35463 Mdot
.28543 .49853 Mdot
.47879 .51814 Mdot
.64041 .40422 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50452 .61193 Mdot
.51439 .59861 Mdot
.54583 .55671 Mdot
.64505 .4401 Mdot
.93296 .37977 Mdot
.31848 .51386 Mdot
.48703 .52587 Mdot
.63615 .4145 Mdot
.96547 .38274 Mdot
.50008 .61793 Mdot
.50024 .61771 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50774 .60758 Mdot
.52465 .58482 Mdot
.5784 .51504 Mdot
.74504 .36757 Mdot
.15031 .4871 Mdot
.36216 .5995 Mdot
.39215 .07397 Mdot
.50018 .61779 Mdot
.50058 .61726 Mdot
.50184 .61555 Mdot
.50585 .61013 Mdot
.51864 .59289 Mdot
.55932 .53916 Mdot
.68694 .40305 Mdot
.0348 .43505 Mdot
.33087 .56395 Mdot
.41838 .01831 Mdot
.38875 .11325 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50296 .61404 Mdot
.50942 .60531 Mdot
.53002 .57764 Mdot
.59537 .49443 Mdot
.79537 .35284 Mdot
.22447 .49849 Mdot
.4179 .57127 Mdot
.49356 .57724 Mdot
.55957 .52329 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51002 .6045 Mdot
.53193 .5751 Mdot
.6014 .48732 Mdot
.8129 .35115 Mdot
.24473 .49861 Mdot
.43795 .55469 Mdot
.54044 .5176 Mdot
.70294 .37646 Mdot
.09381 .45848 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48761 .01672 Mdot
.46056 .05291 Mdot
.37494 .15728 Mdot
.12045 .25859 Mdot
.70205 .11769 Mdot
.51162 .10693 Mdot
.3386 .2322 Mdot
.9629 .19811 Mdot
.64235 .08305 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50697 .60862 Mdot
.5222 .58811 Mdot
.57061 .52478 Mdot
.72151 .37959 Mdot
.10732 .47171 Mdot
.34408 .59422 Mdot
.38261 .07541 Mdot
.26059 .22263 Mdot
.90037 .13618 Mdot
.50073 .61704 Mdot
.50234 .61488 Mdot
.50744 .60798 Mdot
.52371 .58608 Mdot
.57541 .51876 Mdot
.73603 .37179 Mdot
.13447 .48213 Mdot
.35436 .59908 Mdot
.38502 .0786 Mdot
.25784 .22597 Mdot
.89222 .13351 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.50291 .61411 Mdot
.50926 .60553 Mdot
.52949 .57835 Mdot
.59369 .49643 Mdot
.79046 .35362 Mdot
.21829 .49825 Mdot
.4121 .57565 Mdot
.48068 .59352 Mdot
.52034 .57472 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00543 Mdot
.48719 .0173 Mdot
.4592 .0547 Mdot
.3707 .16182 Mdot
.10887 .25506 Mdot
.69618 .11587 Mdot
.50871 .1078 Mdot
.33429 .23513 Mdot
.5001 .6179 Mdot
.50032 .61761 Mdot
.50101 .61668 Mdot
.5032 .61371 Mdot
.5102 .60425 Mdot
.5325 .57433 Mdot
.60322 .48521 Mdot
.81814 .35098 Mdot
.25024 .49852 Mdot
.44361 .54971 Mdot
.55416 .50047 Mdot
.50003 .618 Mdot
.50009 .61792 Mdot
.50027 .61767 Mdot
.50087 .61686 Mdot
.50276 .61431 Mdot
.50879 .60616 Mdot
.528 .58034 Mdot
.58899 .50207 Mdot
.77663 .35658 Mdot
.19966 .49681 Mdot
.39581 .58665 Mdot
.50126 .61634 Mdot
.50401 .61262 Mdot
.51276 .6008 Mdot
.54065 .56353 Mdot
.62884 .45671 Mdot
.88987 .36257 Mdot
.30322 .50194 Mdot
.49107 .51022 Mdot
.66552 .38298 Mdot
.04585 .4249 Mdot
.35836 .53955 Mdot
.50057 .61726 Mdot
.50182 .61557 Mdot
.5058 .6102 Mdot
.51849 .5931 Mdot
.55884 .53979 Mdot
.68544 .40421 Mdot
.03141 .43315 Mdot
.33057 .56219 Mdot
.42093 .01447 Mdot
.39751 .10305 Mdot
.23077 .24952 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49257 .01004 Mdot
.47633 .0319 Mdot
.42472 .09912 Mdot
.26435 .24606 Mdot
.86621 .13613 Mdot
.64594 .01901 Mdot
.61518 .53935 Mdot
.7425 .39197 Mdot
.10828 .48478 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.53941 .56517 Mdot
.62494 .46087 Mdot
.87923 .35936 Mdot
.29778 .5003 Mdot
.48828 .51116 Mdot
.6612 .38599 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49395 .00817 Mdot
.48073 .026 Mdot
.43866 .08147 Mdot
.30685 .2197 Mdot
.95137 .17531 Mdot
.66771 .04705 Mdot
.59157 .5848 Mdot
.64534 .46802 Mdot
.88807 .3726 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .0156 Mdot
.46319 .04942 Mdot
.38323 .14822 Mdot
.1434 .26389 Mdot
.71641 .11962 Mdot
.52287 .09849 Mdot
.36351 .21007 Mdot
.0236 .23188 Mdot
.64842 .11338 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00388 Mdot
.49084 .01237 Mdot
.47082 .03927 Mdot
.40727 .12045 Mdot
.21237 .2639 Mdot
.78538 .11998 Mdot
.59125 .03995 Mdot
.52661 .01539 Mdot
.50171 .01381 Mdot
.47937 .03288 Mdot
.4996 .00054 Mdot
.49872 .00174 Mdot
.49591 .00553 Mdot
.48696 .01761 Mdot
.45847 .05567 Mdot
.36839 .16424 Mdot
.10264 .25293 Mdot
.69338 .11463 Mdot
.50791 .1073 Mdot
.33429 .23463 Mdot
.95465 .19316 Mdot
.64212 .07823 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49763 .00321 Mdot
.49244 .01022 Mdot
.47591 .03247 Mdot
.42337 .10079 Mdot
.26028 .24803 Mdot
.85896 .13373 Mdot
.64257 .01854 Mdot
.61257 .5407 Mdot
.7377 .3936 Mdot
.10084 .48095 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00534 Mdot
.4874 .01702 Mdot
.45987 .05383 Mdot
.37277 .15961 Mdot
.11452 .25685 Mdot
.69893 .11683 Mdot
.50989 .10767 Mdot
.33568 .23434 Mdot
.95651 .19453 Mdot
.50033 .61759 Mdot
.50105 .61662 Mdot
.50334 .61352 Mdot
.51065 .60365 Mdot
.53393 .57243 Mdot
.60772 .48002 Mdot
.83102 .35119 Mdot
.26278 .49826 Mdot
.45659 .53801 Mdot
.58608 .46204 Mdot
.83848 .33672 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.4762 .03207 Mdot
.42431 .09962 Mdot
.26312 .24666 Mdot
.86401 .13539 Mdot
.64495 .01883 Mdot
.61449 .53965 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50437 .61212 Mdot
.51394 .59922 Mdot
.54438 .55861 Mdot
.64054 .4446 Mdot
.92116 .37446 Mdot
.31526 .50978 Mdot
.49042 .51865 Mdot
.65123 .39862 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60623 Mdot
.52783 .58057 Mdot
.58845 .50273 Mdot
.77502 .357 Mdot
.19737 .49655 Mdot
.39393 .58777 Mdot
.44291 .02153 Mdot
.40806 .1021 Mdot
.24286 .2495 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48805 .01613 Mdot
.46195 .05107 Mdot
.37933 .15252 Mdot
.13254 .26168 Mdot
.70914 .11897 Mdot
.51665 .10356 Mdot
.34908 .22342 Mdot
.98757 .21192 Mdot
.64468 .09551 Mdot
.50096 .61673 Mdot
.50306 .6139 Mdot
.50976 .60485 Mdot
.53109 .57622 Mdot
.59875 .49043 Mdot
.80522 .35168 Mdot
.2362 .49867 Mdot
.42934 .56204 Mdot
.51993 .54361 Mdot
.64035 .42972 Mdot
.94504 .37978 Mdot
.50047 .61739 Mdot
.50151 .616 Mdot
.5048 .61155 Mdot
.5153 .59738 Mdot
.54872 .55292 Mdot
.65408 .43137 Mdot
.9561 .39119 Mdot
.32314 .52343 Mdot
.47622 .54539 Mdot
.59377 .4634 Mdot
.84397 .34084 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50767 .60768 Mdot
.52443 .58512 Mdot
.57768 .51593 Mdot
.74288 .36854 Mdot
.14657 .48601 Mdot
.36019 .59958 Mdot
.39006 .07555 Mdot
.26781 .22218 Mdot
.90832 .14181 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00232 Mdot
.49454 .00738 Mdot
.4826 .02347 Mdot
.44463 .07378 Mdot
.32525 .20514 Mdot
.99334 .19896 Mdot
.67141 .06904 Mdot
.55971 .01497 Mdot
.53548 .60039 Mdot
.56403 .54262 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00472 Mdot
.48886 .01504 Mdot
.46453 .04765 Mdot
.38744 .14351 Mdot
.15524 .26566 Mdot
.72538 .11988 Mdot
.53141 .09095 Mdot
.38425 .18904 Mdot
.07837 .2588 Mdot
.65963 .1344 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .0156 Mdot
.4632 .04942 Mdot
.38323 .14822 Mdot
.14341 .26389 Mdot
.71642 .11962 Mdot
.52288 .09848 Mdot
.36353 .21005 Mdot
.02366 .23191 Mdot
.64843 .1134 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49548 .00611 Mdot
.48559 .01946 Mdot
.4541 .06142 Mdot
.35473 .17816 Mdot
.06646 .238 Mdot
.68138 .10395 Mdot
.51318 .09175 Mdot
.36471 .2026 Mdot
.03689 .2365 Mdot
.50069 .6171 Mdot
.50219 .61507 Mdot
.50699 .60859 Mdot
.52226 .58802 Mdot
.57082 .52451 Mdot
.72214 .37922 Mdot
.10854 .47223 Mdot
.34446 .59454 Mdot
.38248 .07582 Mdot
.2598 .22308 Mdot
.89885 .1355 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50652 .60923 Mdot
.52077 .59003 Mdot
.56608 .53051 Mdot
.70769 .38815 Mdot
.07964 .45894 Mdot
.33706 .58496 Mdot
.39057 .06057 Mdot
.29257 .20287 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49659 .00461 Mdot
.48913 .01467 Mdot
.46539 .04651 Mdot
.39014 .14046 Mdot
.16288 .26644 Mdot
.73177 .11986 Mdot
.53782 .08513 Mdot
.40009 .17179 Mdot
.12213 .27422 Mdot
.67844 .14134 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60458 Mdot
.53173 .57535 Mdot
.60079 .48804 Mdot
.81113 .35124 Mdot
.24281 .49864 Mdot
.436 .55638 Mdot
.53575 .52352 Mdot
.68868 .38679 Mdot
.5001 .61791 Mdot
.5003 .61762 Mdot
.50096 .61673 Mdot
.50307 .61388 Mdot
.50979 .60481 Mdot
.53118 .57609 Mdot
.59906 .49007 Mdot
.80611 .3516 Mdot
.23721 .49867 Mdot
.43035 .5612 Mdot
.52231 .54059 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00535 Mdot
.48737 .01705 Mdot
.45979 .05393 Mdot
.37253 .15986 Mdot
.11387 .25665 Mdot
.6986 .11673 Mdot
.50973 .10771 Mdot
.33546 .23449 Mdot
.95604 .19425 Mdot
.64173 .07955 Mdot
.50085 .61688 Mdot
.50271 .61437 Mdot
.50864 .60637 Mdot
.52751 .58099 Mdot
.58745 .50393 Mdot
.77207 .35781 Mdot
.19313 .49603 Mdot
.39053 .5897 Mdot
.43638 .02908 Mdot
.38933 .12361 Mdot
.18933 .26056 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51249 .60117 Mdot
.53977 .56469 Mdot
.62608 .45966 Mdot
.88234 .36025 Mdot
.29945 .50073 Mdot
.48925 .51068 Mdot
.66296 .38466 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49667 .0045 Mdot
.4894 .01432 Mdot
.46622 .0454 Mdot
.39277 .13746 Mdot
.17036 .26691 Mdot
.73849 .11975 Mdot
.54472 .07883 Mdot
.41717 .1522 Mdot
.1709 .2819 Mdot
.4996 .00054 Mdot
.49872 .00174 Mdot
.49591 .00553 Mdot
.48696 .0176 Mdot
.45848 .05566 Mdot
.36842 .16421 Mdot
.10273 .25297 Mdot
.69342 .11465 Mdot
.50792 .10731 Mdot
.33428 .23465 Mdot
.95461 .19314 Mdot
.64211 .07822 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50875 .60621 Mdot
.52788 .5805 Mdot
.58861 .50254 Mdot
.77549 .35688 Mdot
.19804 .49663 Mdot
.39448 .58744 Mdot
.44397 .02029 Mdot
.41115 .09844 Mdot
.49974 .00035 Mdot
.49919 .0011 Mdot
.4974 .00351 Mdot
.49173 .01117 Mdot
.47366 .03547 Mdot
.41626 .10957 Mdot
.23898 .25676 Mdot
.82353 .12468 Mdot
.62179 .02248 Mdot
.58542 .56508 Mdot
.6711 .43529 Mdot
.96679 .40472 Mdot
.50067 .61713 Mdot
.50213 .61516 Mdot
.50678 .60887 Mdot
.52161 .5889 Mdot
.56874 .52714 Mdot
.7158 .38299 Mdot
.0961 .46677 Mdot
.34085 .59092 Mdot
.38473 .07065 Mdot
.27041 .21698 Mdot
.91933 .14536 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60226 Mdot
.53721 .56807 Mdot
.61806 .46839 Mdot
.86019 .35482 Mdot
.28609 .49858 Mdot
.47936 .51766 Mdot
.64177 .40294 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48792 .01631 Mdot
.46153 .05163 Mdot
.37799 .15398 Mdot
.12885 .2608 Mdot
.70687 .11864 Mdot
.5149 .10485 Mdot
.34524 .22676 Mdot
.97834 .20674 Mdot
.64383 .09083 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .00151 Mdot
.49645 .0048 Mdot
.48869 .01527 Mdot
.46397 .04839 Mdot
.38568 .14549 Mdot
.15028 .265 Mdot
.72149 .11982 Mdot
.52762 .09434 Mdot
.37497 .19869 Mdot
.05347 .24734 Mdot
.50052 .61733 Mdot
.50166 .6158 Mdot
.50527 .61091 Mdot
.5168 .59536 Mdot
.55349 .54669 Mdot
.66892 .41788 Mdot
.99278 .41119 Mdot
.32746 .5416 Mdot
.45113 .5862 Mdot
.50265 .58374 Mdot
.55813 .53104 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50484 .61149 Mdot
.51544 .5972 Mdot
.54914 .55237 Mdot
.6554 .43013 Mdot
.95943 .39293 Mdot
.32366 .52495 Mdot
.47428 .54869 Mdot
.58649 .4724 Mdot
.82213 .33975 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48907 .01475 Mdot
.4652 .04676 Mdot
.38955 .14113 Mdot
.1612 .2663 Mdot
.73033 .11988 Mdot
.53636 .08646 Mdot
.39647 .17581 Mdot
.112 .27128 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50224 .61501 Mdot
.50712 .60841 Mdot
.5227 .58744 Mdot
.57219 .52279 Mdot
.72631 .37687 Mdot
.11651 .47549 Mdot
.34715 .5964 Mdot
.38216 .0779 Mdot
.25612 .22533 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49134 .0117 Mdot
.47241 .03715 Mdot
.41229 .11441 Mdot
.22717 .26044 Mdot
.80577 .12186 Mdot
.6086 .02882 Mdot
.56196 .59085 Mdot
.60595 .49973 Mdot
.50025 .6177 Mdot
.50079 .61696 Mdot
.50253 .61462 Mdot
.50805 .60716 Mdot
.52565 .58349 Mdot
.58155 .51115 Mdot
.75448 .36367 Mdot
.16606 .49116 Mdot
.37134 .59786 Mdot
.40398 .06354 Mdot
.30118 .20352 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48303 .0229 Mdot
.44598 .07202 Mdot
.32945 .20156 Mdot
.00331 .20463 Mdot
.67221 .07436 Mdot
.55189 .02711 Mdot
.50803 .01967 Mdot
.4762 .04165 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.49331 .00904 Mdot
.47868 .02875 Mdot
.43215 .08976 Mdot
.28692 .23335 Mdot
.90935 .15378 Mdot
.66052 .02895 Mdot
.61368 .55034 Mdot
.72321 .40488 Mdot
.06811 .46611 Mdot
.50037 .61754 Mdot
.50118 .61645 Mdot
.50375 .61297 Mdot
.51194 .60192 Mdot
.53802 .567 Mdot
.62058 .46561 Mdot
.86721 .3563 Mdot
.29071 .49905 Mdot
.48323 .51457 Mdot
.65065 .39485 Mdot
.01177 .40575 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48703 .01751 Mdot
.45869 .05538 Mdot
.36908 .16352 Mdot
.10449 .25358 Mdot
.69419 .11502 Mdot
.50809 .10752 Mdot
.33412 .23493 Mdot
.95399 .19287 Mdot
.64192 .07806 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00336 Mdot
.49209 .01069 Mdot
.47479 .03396 Mdot
.41984 .10517 Mdot
.24967 .25272 Mdot
.84076 .12852 Mdot
.63281 .0192 Mdot
.60175 .5492 Mdot
.71312 .4056 Mdot
.05683 .45718 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50363 .61313 Mdot
.51158 .6024 Mdot
.53687 .56853 Mdot
.61696 .4696 Mdot
.85714 .35424 Mdot
.28396 .49844 Mdot
.47747 .51925 Mdot
.6373 .40718 Mdot
.97847 .38728 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48933 .01441 Mdot
.46601 .04568 Mdot
.3921 .13822 Mdot
.16845 .26682 Mdot
.73673 .11979 Mdot
.54291 .08049 Mdot
.41268 .15744 Mdot
.15794 .28098 Mdot
.7033 .13974 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51311 .60034 Mdot
.54174 .56209 Mdot
.63226 .4531 Mdot
.89913 .36573 Mdot
.30737 .50379 Mdot
.49222 .511 Mdot
.66541 .3838 Mdot
.04441 .42444 Mdot
.35765 .5395 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49013 .01333 Mdot
.46857 .04227 Mdot
.40017 .12887 Mdot
.19165 .26661 Mdot
.76027 .11937 Mdot
.56712 .05898 Mdot
.47169 .08508 Mdot
.33402 .21254 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48895 .01492 Mdot
.4648 .04729 Mdot
.3883 .14255 Mdot
.15765 .26594 Mdot
.72735 .11989 Mdot
.53336 .08918 Mdot
.38906 .1839 Mdot
.0915 .26413 Mdot
.66413 .13755 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50611 .60978 Mdot
.51947 .59178 Mdot
.56195 .53578 Mdot
.69504 .39695 Mdot
.05277 .44498 Mdot
.33279 .57301 Mdot
.40564 .03741 Mdot
.34511 .15939 Mdot
.08722 .23625 Mdot
.50125 .61634 Mdot
.50398 .61265 Mdot
.51269 .6009 Mdot
.54042 .56383 Mdot
.62812 .45747 Mdot
.88792 .36194 Mdot
.30228 .5016 Mdot
.49067 .51024 Mdot
.66508 .38321 Mdot
.04504 .42441 Mdot
.35834 .53907 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.50761 .60775 Mdot
.52424 .58537 Mdot
.5771 .51666 Mdot
.74113 .36934 Mdot
.14353 .48508 Mdot
.35865 .59956 Mdot
.38854 .07661 Mdot
.26457 .22354 Mdot
.90288 .13899 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51067 .60362 Mdot
.53399 .57235 Mdot
.6079 .47981 Mdot
.83154 .35122 Mdot
.26327 .49825 Mdot
.45708 .53755 Mdot
.58731 .46061 Mdot
.84202 .33705 Mdot
.29666 .4783 Mdot
.50126 .61633 Mdot
.50401 .61261 Mdot
.51278 .60078 Mdot
.54071 .56345 Mdot
.62902 .45652 Mdot
.89037 .36273 Mdot
.30346 .50203 Mdot
.49116 .51022 Mdot
.6656 .38294 Mdot
.046 .42499 Mdot
.35835 .53964 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49391 .00823 Mdot
.48059 .02618 Mdot
.43822 .08203 Mdot
.30549 .2207 Mdot
.9484 .17369 Mdot
.66736 .0456 Mdot
.59358 .58179 Mdot
.65223 .46122 Mdot
.50061 .6172 Mdot
.50196 .61539 Mdot
.50624 .60961 Mdot
.51987 .59124 Mdot
.56322 .53416 Mdot
.69894 .39414 Mdot
.0612 .44949 Mdot
.33391 .577 Mdot
.4003 .04547 Mdot
.32673 .17619 Mdot
.04165 .21436 Mdot
.50008 .61793 Mdot
.50024 .61771 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.50779 .60751 Mdot
.52483 .58458 Mdot
.57895 .51436 Mdot
.74669 .36685 Mdot
.15312 .48789 Mdot
.3637 .59936 Mdot
.39391 .07256 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00252 Mdot
.49405 .00803 Mdot
.48106 .02555 Mdot
.43971 .08011 Mdot
.31009 .21726 Mdot
.95855 .17927 Mdot
.66848 .05066 Mdot
.58651 .59238 Mdot
.62802 .48609 Mdot
.84151 .36227 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56788 .52824 Mdot
.71317 .38462 Mdot
.09084 .46434 Mdot
.33953 .58915 Mdot
.38626 .06781 Mdot
.27655 .2133 Mdot
.93142 .15167 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48793 .0163 Mdot
.46156 .05159 Mdot
.37809 .15387 Mdot
.12911 .26087 Mdot
.70702 .11867 Mdot
.51502 .10477 Mdot
.3455 .22654 Mdot
.97895 .20708 Mdot
.50118 .61644 Mdot
.50376 .61295 Mdot
.51199 .60185 Mdot
.53817 .5668 Mdot
.62106 .46509 Mdot
.86854 .35661 Mdot
.29153 .49916 Mdot
.48388 .51407 Mdot
.6521 .39357 Mdot
.01528 .40772 Mdot
.35558 .52397 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51023 .60422 Mdot
.53257 .57424 Mdot
.60344 .48495 Mdot
.81877 .35097 Mdot
.25089 .49851 Mdot
.44429 .54911 Mdot
.5558 .49843 Mdot
.74933 .35089 Mdot
.18158 .48501 Mdot
.49971 .00039 Mdot
.49909 .00124 Mdot
.49709 .00394 Mdot
.49072 .01254 Mdot
.47043 .0398 Mdot
.40603 .12193 Mdot
.20874 .26455 Mdot
.78069 .11974 Mdot
.58695 .04308 Mdot
.51724 .02713 Mdot
.47334 .05173 Mdot
.38964 .14604 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00505 Mdot
.48808 .01609 Mdot
.46205 .05094 Mdot
.37964 .15218 Mdot
.1334 .26187 Mdot
.70968 .11903 Mdot
.51708 .10323 Mdot
.35005 .22257 Mdot
.98993 .21324 Mdot
.6449 .09671 Mdot
.50051 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51665 .59557 Mdot
.553 .54734 Mdot
.66738 .41924 Mdot
.98904 .40908 Mdot
.32713 .53964 Mdot
.45398 .58171 Mdot
.51275 .5699 Mdot
.59063 .49036 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49303 .00942 Mdot
.47778 .02995 Mdot
.42933 .09334 Mdot
.2783 .23855 Mdot
.89232 .14617 Mdot
.65581 .02372 Mdot
.61743 .5425 Mdot
.73965 .39527 Mdot
.1001 .48206 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00414 Mdot
.49023 .01319 Mdot
.4689 .04184 Mdot
.4012 .12766 Mdot
.19464 .26637 Mdot
.76364 .11937 Mdot
.5705 .05612 Mdot
.47969 .0749 Mdot
.3585 .18946 Mdot
.05195 .23677 Mdot
.50093 .61678 Mdot
.50297 .61403 Mdot
.50945 .60527 Mdot
.53011 .57752 Mdot
.59565 .49409 Mdot
.79619 .35272 Mdot
.22548 .49852 Mdot
.41886 .57052 Mdot
.49574 .57446 Mdot
.56624 .51481 Mdot
.73325 .36809 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48814 .01602 Mdot
.46222 .05071 Mdot
.38018 .15159 Mdot
.1349 .2622 Mdot
.71065 .11915 Mdot
.51786 .10262 Mdot
.35182 .22099 Mdot
.99425 .21566 Mdot
.64531 .09891 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00414 Mdot
.49024 .01318 Mdot
.46892 .0418 Mdot
.40129 .12756 Mdot
.1949 .26635 Mdot
.76394 .11937 Mdot
.5708 .05588 Mdot
.48039 .07401 Mdot
.36065 .18731 Mdot
.05758 .23953 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .00399 Mdot
.49058 .01272 Mdot
.47 .04037 Mdot
.40468 .12355 Mdot
.20478 .26518 Mdot
.77571 .11955 Mdot
.58227 .04663 Mdot
.50682 .04031 Mdot
.44161 .09323 Mdot
.29075 .23597 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49712 .0039 Mdot
.49081 .01241 Mdot
.47073 .03939 Mdot
.407 .12078 Mdot
.21157 .26405 Mdot
.78433 .11992 Mdot
.59029 .04063 Mdot
.52455 .01797 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51264 .60096 Mdot
.54026 .56404 Mdot
.62763 .458 Mdot
.88657 .36152 Mdot
.30161 .50138 Mdot
.49037 .5103 Mdot
.66469 .38345 Mdot
.04426 .42395 Mdot
.35829 .53864 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49231 .01039 Mdot
.47551 .033 Mdot
.42211 .10236 Mdot
.25649 .24978 Mdot
.85234 .1317 Mdot
.63924 .01847 Mdot
.60936 .54291 Mdot
.73092 .39642 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49134 .01169 Mdot
.47242 .03713 Mdot
.41234 .11435 Mdot
.22733 .2604 Mdot
.806 .12189 Mdot
.60877 .02872 Mdot
.5623 .59046 Mdot
.60692 .49863 Mdot
.80011 .35834 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50494 .61136 Mdot
.51573 .5968 Mdot
.55009 .55112 Mdot
.65836 .42737 Mdot
.96686 .39687 Mdot
.32471 .52845 Mdot
.46966 .55641 Mdot
.56937 .49412 Mdot
.76987 .34772 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48852 .0155 Mdot
.46343 .04911 Mdot
.38397 .14739 Mdot
.14549 .26425 Mdot
.71792 .11969 Mdot
.52425 .0973 Mdot
.36681 .20686 Mdot
.03211 .23642 Mdot
.64957 .11729 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49445 .0075 Mdot
.48232 .02386 Mdot
.44372 .07495 Mdot
.32245 .20747 Mdot
.98675 .1952 Mdot
.67091 .0655 Mdot
.56492 .00698 Mdot
.55363 .57623 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58922 Mdot
.568 .52808 Mdot
.71355 .38438 Mdot
.09161 .4647 Mdot
.33971 .58942 Mdot
.38602 .06824 Mdot
.2756 .21389 Mdot
.92952 .15066 Mdot
.5012 .61642 Mdot
.50382 .61288 Mdot
.51216 .60162 Mdot
.53871 .56608 Mdot
.62277 .46323 Mdot
.87325 .35776 Mdot
.29439 .4996 Mdot
.48601 .51255 Mdot
.65669 .38964 Mdot
.02624 .41386 Mdot
.3566 .52952 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51222 .60153 Mdot
.53892 .56581 Mdot
.62342 .46252 Mdot
.87505 .35822 Mdot
.29544 .4998 Mdot
.48675 .51207 Mdot
.65821 .38839 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.4971 .00392 Mdot
.49075 .01249 Mdot
.47054 .03965 Mdot
.40638 .12152 Mdot
.20975 .26438 Mdot
.78198 .1198 Mdot
.58814 .0422 Mdot
.51985 .02384 Mdot
.48128 .04116 Mdot
.41467 .11653 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48656 .01815 Mdot
.4572 .05735 Mdot
.36441 .16838 Mdot
.09196 .24897 Mdot
.68912 .11209 Mdot
.50775 .1049 Mdot
.33802 .23045 Mdot
.96514 .19839 Mdot
.64413 .0823 Mdot
.50025 .6177 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50794 .60731 Mdot
.52528 .58398 Mdot
.58039 .51258 Mdot
.75102 .36504 Mdot
.16037 .4898 Mdot
.36786 .5987 Mdot
.39914 .06804 Mdot
.28906 .21116 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50267 .61442 Mdot
.50851 .60653 Mdot
.52712 .58151 Mdot
.58621 .50544 Mdot
.76839 .35888 Mdot
.18771 .49527 Mdot
.38635 .5919 Mdot
.42863 .03784 Mdot
.36741 .14702 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00814 Mdot
.48081 .02588 Mdot
.43893 .08112 Mdot
.30768 .21908 Mdot
.95321 .17632 Mdot
.66792 .04797 Mdot
.5903 .58671 Mdot
.64097 .47246 Mdot
.87652 .36913 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60548 Mdot
.52961 .57818 Mdot
.59409 .49595 Mdot
.79162 .35342 Mdot
.21977 .49832 Mdot
.41348 .57463 Mdot
.48371 .5897 Mdot
.52955 .56246 Mdot
.61947 .46181 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50967 .60497 Mdot
.53081 .57659 Mdot
.59787 .49147 Mdot
.80264 .35193 Mdot
.23321 .49865 Mdot
.42638 .5645 Mdot
.513 .55246 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.5109 .60331 Mdot
.53472 .57138 Mdot
.6102 .47719 Mdot
.83809 .35167 Mdot
.26907 .49816 Mdot
.46302 .53213 Mdot
.60201 .44391 Mdot
.88375 .34547 Mdot
.32477 .47703 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.4875 .01688 Mdot
.46018 .05341 Mdot
.37377 .15854 Mdot
.11723 .25766 Mdot
.70033 .11725 Mdot
.51062 .10741 Mdot
.33684 .23353 Mdot
.95898 .19592 Mdot
.64197 .08108 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50561 .61046 Mdot
.51787 .59393 Mdot
.55687 .54233 Mdot
.67936 .40908 Mdot
.01746 .42523 Mdot
.32942 .55478 Mdot
.43176 .61612 Mdot
.43486 .0568 Mdot
.34295 .17989 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50495 .61134 Mdot
.51579 .59673 Mdot
.55026 .55091 Mdot
.65887 .4269 Mdot
.96813 .39755 Mdot
.32488 .52907 Mdot
.46883 .55778 Mdot
.56633 .49805 Mdot
.76048 .35082 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.50931 .60546 Mdot
.52965 .57813 Mdot
.59421 .49581 Mdot
.79198 .35336 Mdot
.22022 .49833 Mdot
.4139 .57432 Mdot
.48464 .58854 Mdot
.53237 .55874 Mdot
.62831 .45226 Mdot
.50105 .61661 Mdot
.50336 .61349 Mdot
.51071 .60358 Mdot
.5341 .5722 Mdot
.60826 .47941 Mdot
.83256 .35127 Mdot
.26419 .49823 Mdot
.45803 .53669 Mdot
.58966 .45789 Mdot
.84877 .33786 Mdot
.3021 .47757 Mdot
.50015 .61782 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.50501 .61126 Mdot
.51596 .59649 Mdot
.55082 .55017 Mdot
.66063 .42528 Mdot
.97251 .39992 Mdot
.32542 .53121 Mdot
.4659 .56258 Mdot
.55564 .51204 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01026 Mdot
.47581 .0326 Mdot
.42306 .10118 Mdot
.25936 .24846 Mdot
.85733 .13322 Mdot
.64178 .01849 Mdot
.61186 .54116 Mdot
.73625 .39416 Mdot
.09848 .47975 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51012 .60437 Mdot
.53223 .57469 Mdot
.60236 .4862 Mdot
.81567 .35104 Mdot
.24767 .49857 Mdot
.44097 .55205 Mdot
.54773 .50847 Mdot
.72501 .36274 Mdot
.13809 .47529 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.4892 .01459 Mdot
.46559 .04625 Mdot
.39076 .13975 Mdot
.16464 .26658 Mdot
.7333 .11984 Mdot
.53939 .0837 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00436 Mdot
.48973 .01387 Mdot
.46728 .04399 Mdot
.39611 .1336 Mdot
.17994 .26708 Mdot
.7478 .11955 Mdot
.55436 .07013 Mdot
.44089 .12367 Mdot
.24079 .27097 Mdot
.50009 .61791 Mdot
.50029 .61764 Mdot
.50092 .61679 Mdot
.50294 .61407 Mdot
.50935 .6054 Mdot
.52979 .57795 Mdot
.59465 .49528 Mdot
.79327 .35316 Mdot
.22185 .4984 Mdot
.41543 .57317 Mdot
.48802 .58426 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60703 Mdot
.52596 .58307 Mdot
.58252 .50995 Mdot
.7574 .36257 Mdot
.17075 .4922 Mdot
.37436 .59695 Mdot
.40848 .05915 Mdot
.31277 .19537 Mdot
.99666 .19227 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01626 Mdot
.46164 .05148 Mdot
.37833 .15361 Mdot
.12979 .26103 Mdot
.70744 .11873 Mdot
.51533 .10454 Mdot
.34617 .22596 Mdot
.98055 .20798 Mdot
.64403 .09195 Mdot
.50035 .61757 Mdot
.50111 .61654 Mdot
.50352 .61328 Mdot
.51122 .60289 Mdot
.53573 .57004 Mdot
.61339 .47359 Mdot
.84709 .35266 Mdot
.27647 .49817 Mdot
.47041 .52545 Mdot
.62022 .4243 Mdot
.93369 .36459 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60848 Mdot
.52252 .58767 Mdot
.57164 .52348 Mdot
.72464 .3778 Mdot
.11334 .47422 Mdot
.34604 .5957 Mdot
.38218 .07719 Mdot
.25728 .22458 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47926 .02797 Mdot
.43401 .0874 Mdot
.29259 .2297 Mdot
.92093 .15937 Mdot
.66306 .0333 Mdot
.60917 .55788 Mdot
.7065 .41581 Mdot
.03371 .44683 Mdot
.50105 .61662 Mdot
.50335 .61351 Mdot
.51066 .60364 Mdot
.53395 .57241 Mdot
.60777 .47997 Mdot
.83116 .3512 Mdot
.26291 .49825 Mdot
.45672 .53788 Mdot
.58641 .46165 Mdot
.83944 .3368 Mdot
.29448 .47862 Mdot
.50035 .61757 Mdot
.5011 .61655 Mdot
.50351 .61329 Mdot
.51118 .60294 Mdot
.5356 .57021 Mdot
.61299 .47404 Mdot
.84598 .35252 Mdot
.27559 .49816 Mdot
.46955 .52622 Mdot
.6181 .42651 Mdot
.928 .36201 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51318 .60024 Mdot
.54198 .56177 Mdot
.63301 .45233 Mdot
.90112 .36645 Mdot
.30819 .50424 Mdot
.49232 .51136 Mdot
.66493 .38439 Mdot
.04297 .42374 Mdot
.35734 .53899 Mdot
.50042 .61747 Mdot
.50134 .61622 Mdot
.50427 .61226 Mdot
.51361 .59966 Mdot
.54334 .55998 Mdot
.63727 .44792 Mdot
.91252 .37084 Mdot
.31248 .50717 Mdot
.49187 .5147 Mdot
.65906 .3906 Mdot
.02706 .41556 Mdot
.50032 .6176 Mdot
.50101 .61667 Mdot
.50323 .61367 Mdot
.51028 .60415 Mdot
.53275 .574 Mdot
.60399 .48431 Mdot
.82036 .35095 Mdot
.25251 .49848 Mdot
.44596 .54762 Mdot
.55988 .49341 Mdot
.76153 .34625 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50767 .60768 Mdot
.52442 .58513 Mdot
.57766 .51595 Mdot
.74283 .36856 Mdot
.14649 .48598 Mdot
.36015 .59958 Mdot
.39001 .07559 Mdot
.26771 .22222 Mdot
.90815 .14172 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00527 Mdot
.48757 .01679 Mdot
.46041 .05311 Mdot
.37447 .15779 Mdot
.11916 .25822 Mdot
.70135 .11752 Mdot
.5112 .10714 Mdot
.33784 .23278 Mdot
.50067 .61713 Mdot
.50214 .61514 Mdot
.50682 .60881 Mdot
.52174 .58872 Mdot
.56917 .5266 Mdot
.71712 .38219 Mdot
.09873 .46796 Mdot
.34156 .59175 Mdot
.38408 .07193 Mdot
.26771 .21856 Mdot
.91407 .14271 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.52311 .58689 Mdot
.5735 .52115 Mdot
.73025 .37474 Mdot
.1239 .47835 Mdot
.34991 .59776 Mdot
.38271 .07889 Mdot
.25507 .22636 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00483 Mdot
.4886 .01539 Mdot
.46371 .04874 Mdot
.38484 .14643 Mdot
.14792 .26465 Mdot
.71971 .11977 Mdot
.52592 .09584 Mdot
.37085 .20286 Mdot
.04262 .2419 Mdot
.65122 .12187 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50727 .60821 Mdot
.52317 .5868 Mdot
.57371 .52088 Mdot
.7309 .3744 Mdot
.12511 .4788 Mdot
.35039 .59795 Mdot
.38288 .07896 Mdot
.25512 .22643 Mdot
.88876 .13149 Mdot
.50108 .61657 Mdot
.50344 .61338 Mdot
.51097 .60322 Mdot
.53494 .57109 Mdot
.6109 .4764 Mdot
.84006 .35186 Mdot
.27075 .49815 Mdot
.46472 .53059 Mdot
.60621 .43927 Mdot
.89546 .34918 Mdot
.33048 .47826 Mdot
.50049 .61737 Mdot
.50158 .6159 Mdot
.50502 .61125 Mdot
.516 .59644 Mdot
.55095 .55 Mdot
.66103 .42492 Mdot
.9735 .40046 Mdot
.32554 .5317 Mdot
.46523 .56368 Mdot
.55317 .5153 Mdot
.71939 .37048 Mdot
.50005 .61797 Mdot
.50015 .61783 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50493 .61137 Mdot
.5157 .59684 Mdot
.55 .55125 Mdot
.65806 .42765 Mdot
.96611 .39646 Mdot
.32461 .52809 Mdot
.47015 .5556 Mdot
.50014 .61785 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.50451 .61195 Mdot
.51436 .59865 Mdot
.54571 .55686 Mdot
.6447 .44044 Mdot
.93205 .37935 Mdot
.31825 .51353 Mdot
.48735 .52524 Mdot
.63748 .41306 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00534 Mdot
.4874 .01702 Mdot
.45987 .05383 Mdot
.37277 .15961 Mdot
.11451 .25684 Mdot
.69893 .11683 Mdot
.50989 .10767 Mdot
.33568 .23434 Mdot
.95651 .19452 Mdot
.64176 .0798 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.4919 .01094 Mdot
.47421 .03474 Mdot
.418 .10744 Mdot
.24415 .25489 Mdot
.83174 .12638 Mdot
.62726 .02058 Mdot
.59396 .55648 Mdot
.69356 .41811 Mdot
.01704 .43388 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00413 Mdot
.49026 .01316 Mdot
.46896 .04175 Mdot
.40141 .12742 Mdot
.19524 .26632 Mdot
.76433 .11937 Mdot
.57119 .05555 Mdot
.4813 .07285 Mdot
.36343 .18448 Mdot
.06494 .24302 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45873 .05533 Mdot
.3692 .16339 Mdot
.10482 .25369 Mdot
.69433 .11508 Mdot
.50813 .10755 Mdot
.3341 .23497 Mdot
.95392 .19284 Mdot
.64189 .07805 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.4927 .00986 Mdot
.47675 .03133 Mdot
.42606 .09744 Mdot
.2684 .244 Mdot
.8736 .13876 Mdot
.64909 .01989 Mdot
.61691 .53903 Mdot
.74474 .39156 Mdot
.11118 .48645 Mdot
.49971 .0004 Mdot
.49906 .00126 Mdot
.49702 .00403 Mdot
.4905 .01284 Mdot
.46973 .04073 Mdot
.40382 .12456 Mdot
.20227 .26552 Mdot
.77264 .11947 Mdot
.57934 .04893 Mdot
.50017 .04878 Mdot
.42124 .11884 Mdot
.22895 .2651 Mdot
.50002 .61801 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50191 .61545 Mdot
.50609 .60981 Mdot
.5194 .59187 Mdot
.56174 .53606 Mdot
.69438 .39743 Mdot
.05133 .44419 Mdot
.33261 .5723 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49827 .00233 Mdot
.4945 .00743 Mdot
.48248 .02364 Mdot
.44424 .07428 Mdot
.32404 .20614 Mdot
.9905 .19734 Mdot
.67119 .06751 Mdot
.56195 .01152 Mdot
.54331 .58989 Mdot
.50125 .61635 Mdot
.50398 .61266 Mdot
.51267 .60093 Mdot
.54034 .56394 Mdot
.62787 .45775 Mdot
.88722 .36172 Mdot
.30193 .50148 Mdot
.49052 .51027 Mdot
.66489 .38332 Mdot
.04466 .42418 Mdot
.35832 .53886 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00284 Mdot
.49329 .00906 Mdot
.47863 .02881 Mdot
.43201 .08995 Mdot
.28647 .23363 Mdot
.90845 .15336 Mdot
.6603 .02864 Mdot
.61396 .54982 Mdot
.72434 .40419 Mdot
.07034 .4673 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51013 .60435 Mdot
.53228 .57463 Mdot
.6025 .48604 Mdot
.81607 .35103 Mdot
.24809 .49856 Mdot
.4414 .55167 Mdot
.54878 .50715 Mdot
.7282 .36098 Mdot
.14412 .47707 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49855 .00196 Mdot
.49537 .00626 Mdot
.48524 .01992 Mdot
.45301 .06285 Mdot
.35131 .1815 Mdot
.05763 .23377 Mdot
.67938 .10051 Mdot
.51675 .08501 Mdot
.37921 .18655 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00215 Mdot
.49494 .00683 Mdot
.48388 .02175 Mdot
.44869 .0685 Mdot
.33785 .19413 Mdot
.02374 .21606 Mdot
.67415 .08496 Mdot
.53669 .05125 Mdot
.45377 .09351 Mdot
.30247 .2331 Mdot
.50035 .61757 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .6029 Mdot
.53571 .57007 Mdot
.61331 .47368 Mdot
.84688 .35264 Mdot
.2763 .49817 Mdot
.47024 .5256 Mdot
.61981 .42472 Mdot
.9326 .36409 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00466 Mdot
.48901 .01484 Mdot
.46501 .04701 Mdot
.38894 .14182 Mdot
.15948 .26613 Mdot
.72887 .11989 Mdot
.53489 .0878 Mdot
.39282 .17982 Mdot
.10187 .26794 Mdot
.66833 .1394 Mdot
.5013 .61627 Mdot
.50415 .61243 Mdot
.51322 .60018 Mdot
.54211 .5616 Mdot
.63343 .45189 Mdot
.90226 .36687 Mdot
.30866 .50451 Mdot
.49235 .51159 Mdot
.66457 .3848 Mdot
.04196 .42325 Mdot
.35713 .53861 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.505 .61128 Mdot
.51594 .59653 Mdot
.55074 .55028 Mdot
.66036 .42553 Mdot
.97184 .39956 Mdot
.32534 .53088 Mdot
.46636 .56184 Mdot
.55729 .50987 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49617 .00518 Mdot
.48779 .01649 Mdot
.46111 .05218 Mdot
.37668 .15541 Mdot
.12523 .25988 Mdot
.70472 .11827 Mdot
.51336 .1059 Mdot
.34202 .22946 Mdot
.97074 .20249 Mdot
.64311 .08699 Mdot
.4996 .00054 Mdot
.49871 .00174 Mdot
.49591 .00553 Mdot
.48696 .01761 Mdot
.45846 .05568 Mdot
.36836 .16427 Mdot
.10257 .25291 Mdot
.69335 .11461 Mdot
.5079 .10729 Mdot
.3343 .23462 Mdot
.95468 .19317 Mdot
.64212 .07824 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00318 Mdot
.4925 .01014 Mdot
.4761 .03221 Mdot
.42398 .10004 Mdot
.26211 .24716 Mdot
.8622 .13478 Mdot
.64412 .0187 Mdot
.61385 .53996 Mdot
.74017 .3927 Mdot
.10477 .48296 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50405 .61256 Mdot
.51292 .6006 Mdot
.54113 .56289 Mdot
.63035 .45511 Mdot
.89396 .36392 Mdot
.30512 .50271 Mdot
.49172 .51038 Mdot
.66591 .38295 Mdot
.04628 .42526 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01627 Mdot
.46163 .05149 Mdot
.37832 .15363 Mdot
.12975 .26102 Mdot
.70741 .11873 Mdot
.5153 .10456 Mdot
.34612 .226 Mdot
.98044 .20792 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01062 Mdot
.47495 .03374 Mdot
.42035 .10454 Mdot
.25121 .25208 Mdot
.84334 .12919 Mdot
.50045 .61743 Mdot
.50142 .61611 Mdot
.50454 .61191 Mdot
.51445 .59853 Mdot
.54602 .55646 Mdot
.64565 .43951 Mdot
.93451 .38049 Mdot
.31886 .51444 Mdot
.48647 .52697 Mdot
.63382 .41702 Mdot
.95907 .37949 Mdot
.50032 .61761 Mdot
.50101 .61668 Mdot
.5032 .61371 Mdot
.51021 .60425 Mdot
.53251 .57433 Mdot
.60322 .4852 Mdot
.81815 .35098 Mdot
.25026 .49852 Mdot
.44363 .5497 Mdot
.5542 .50042 Mdot
.74451 .35296 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49086 .01234 Mdot
.47089 .03918 Mdot
.4075 .12019 Mdot
.21303 .26377 Mdot
.78624 .12003 Mdot
.59202 .0394 Mdot
.52827 .01332 Mdot
.50671 .0071 Mdot
.49522 .01153 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00511 Mdot
.48794 .01629 Mdot
.46159 .05155 Mdot
.37818 .15378 Mdot
.12936 .26093 Mdot
.70718 .11869 Mdot
.51513 .10469 Mdot
.34574 .22633 Mdot
.97953 .20741 Mdot
.5004 .6175 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51288 .60064 Mdot
.54102 .56303 Mdot
.63001 .45547 Mdot
.89304 .36361 Mdot
.3047 .50253 Mdot
.4916 .51032 Mdot
.66589 .3829 Mdot
.04634 .42525 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00399 Mdot
.49059 .01271 Mdot
.47003 .04033 Mdot
.40476 .12345 Mdot
.20502 .26514 Mdot
.77602 .11956 Mdot
.58256 .04641 Mdot
.50747 .03949 Mdot
.44358 .0907 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.48691 .01767 Mdot
.45832 .05587 Mdot
.36792 .16473 Mdot
.10138 .25249 Mdot
.69285 .11436 Mdot
.50781 .10712 Mdot
.33449 .23436 Mdot
.95529 .19345 Mdot
.64228 .07843 Mdot
.50093 .61677 Mdot
.50298 .61401 Mdot
.50948 .60523 Mdot
.5302 .57741 Mdot
.59593 .49376 Mdot
.79702 .3526 Mdot
.22649 .49854 Mdot
.41983 .56976 Mdot
.49794 .57166 Mdot
.57297 .50636 Mdot
.75366 .35885 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49231 .01038 Mdot
.47552 .03299 Mdot
.42215 .10232 Mdot
.25659 .24973 Mdot
.85252 .13175 Mdot
.63933 .01846 Mdot
.60946 .54284 Mdot
.73113 .39633 Mdot
.08986 .47527 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.4931 .00932 Mdot
.47801 .02964 Mdot
.43005 .09242 Mdot
.2805 .23727 Mdot
.89659 .14801 Mdot
.65711 .02489 Mdot
.61684 .54408 Mdot
.73651 .39706 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50707 .60848 Mdot
.52253 .58766 Mdot
.57168 .52343 Mdot
.72475 .37774 Mdot
.11356 .4743 Mdot
.34612 .59575 Mdot
.38217 .07724 Mdot
.25719 .22464 Mdot
.89372 .13327 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60075 Mdot
.54076 .56338 Mdot
.6292 .45633 Mdot
.89084 .36288 Mdot
.30368 .50212 Mdot
.49124 .51023 Mdot
.66568 .38291 Mdot
.04611 .42506 Mdot
.35834 .53972 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50722 .60828 Mdot
.52301 .58702 Mdot
.57319 .52154 Mdot
.72933 .37523 Mdot
.12219 .4777 Mdot
.34925 .59748 Mdot
.38251 .07874 Mdot
.2551 .22621 Mdot
.88909 .13151 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49669 .00448 Mdot
.48944 .01426 Mdot
.46636 .04521 Mdot
.3932 .13695 Mdot
.17161 .26696 Mdot
.73966 .11973 Mdot
.54593 .07773 Mdot
.42016 .14868 Mdot
.17959 .28202 Mdot
.72327 .13655 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46847 .04241 Mdot
.39985 .12924 Mdot
.19073 .26668 Mdot
.75924 .11938 Mdot
.56608 .05987 Mdot
.46921 .08823 Mdot
.32646 .21907 Mdot
.97199 .19324 Mdot
.50102 .61666 Mdot
.50324 .61365 Mdot
.51033 .60408 Mdot
.53291 .57379 Mdot
.6045 .48372 Mdot
.82183 .35095 Mdot
.25398 .49845 Mdot
.44748 .54626 Mdot
.56362 .48884 Mdot
.77266 .34279 Mdot
.21802 .48736 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50745 .60797 Mdot
.52374 .58604 Mdot
.5755 .51864 Mdot
.73632 .37164 Mdot
.135 .48231 Mdot
.3546 .59913 Mdot
.38519 .07853 Mdot
.25812 .22589 Mdot
.89263 .13373 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50132 .61625 Mdot
.50421 .61234 Mdot
.51343 .59991 Mdot
.54275 .56075 Mdot
.63545 .4498 Mdot
.90766 .36891 Mdot
.31074 .50584 Mdot
.49227 .51301 Mdot
.6622 .38736 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00472 Mdot
.48886 .01504 Mdot
.46452 .04767 Mdot
.38739 .14357 Mdot
.15509 .26565 Mdot
.72526 .11988 Mdot
.53129 .09106 Mdot
.38395 .18936 Mdot
.07756 .25845 Mdot
.65938 .13418 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50992 .60463 Mdot
.53161 .57552 Mdot
.60039 .4885 Mdot
.80998 .35131 Mdot
.24155 .49865 Mdot
.43472 .55749 Mdot
.53268 .5274 Mdot
.67932 .39417 Mdot
.04154 .43225 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50478 .61157 Mdot
.51524 .59746 Mdot
.54853 .55316 Mdot
.6535 .43192 Mdot
.95464 .39043 Mdot
.3229 .52277 Mdot
.47705 .54397 Mdot
.59689 .45959 Mdot
.50106 .61661 Mdot
.50337 .61349 Mdot
.51072 .60355 Mdot
.53415 .57214 Mdot
.60842 .47922 Mdot
.83302 .3513 Mdot
.2646 .49822 Mdot
.45846 .5363 Mdot
.59071 .45668 Mdot
.85179 .3383 Mdot
.30441 .4773 Mdot
.5006 .61722 Mdot
.50191 .61545 Mdot
.50609 .6098 Mdot
.51941 .59185 Mdot
.56178 .536 Mdot
.69451 .39733 Mdot
.05161 .44435 Mdot
.33264 .57244 Mdot
.40641 .03625 Mdot
.34775 .15684 Mdot
.09399 .23899 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00467 Mdot
.489 .01486 Mdot
.46495 .04709 Mdot
.38876 .14203 Mdot
.15895 .26608 Mdot
.72843 .11989 Mdot
.53445 .0882 Mdot
.39173 .18101 Mdot
.09885 .26687 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51042 .60396 Mdot
.53319 .57342 Mdot
.60537 .48272 Mdot
.82432 .35097 Mdot
.25644 .49839 Mdot
.45003 .54396 Mdot
.56988 .48124 Mdot
.79121 .33862 Mdot
.24331 .48603 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49814 .00252 Mdot
.49407 .00802 Mdot
.48109 .0255 Mdot
.43983 .07996 Mdot
.31045 .21699 Mdot
.95936 .17972 Mdot
.66857 .05107 Mdot
.58593 .59326 Mdot
.62602 .48826 Mdot
.83599 .36174 Mdot
.50018 .6178 Mdot
.50056 .61728 Mdot
.50178 .61563 Mdot
.50567 .61038 Mdot
.51806 .59368 Mdot
.55747 .54155 Mdot
.68123 .40757 Mdot
.02177 .42768 Mdot
.32976 .55709 Mdot
.42838 .00323 Mdot
.42315 .07174 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00556 Mdot
.48688 .01772 Mdot
.45821 .05601 Mdot
.36759 .16508 Mdot
.10048 .25217 Mdot
.69247 .11416 Mdot
.50775 .10697 Mdot
.33467 .23413 Mdot
.95584 .19371 Mdot
.64241 .07862 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49292 .00956 Mdot
.47745 .03039 Mdot
.42828 .09466 Mdot
.27512 .24037 Mdot
.8862 .14363 Mdot
.6538 .02223 Mdot
.61784 .54073 Mdot
.74291 .39333 Mdot
.10649 .48485 Mdot
.50103 .61664 Mdot
.50329 .61359 Mdot
.51047 .60389 Mdot
.53336 .57319 Mdot
.60591 .48209 Mdot
.82587 .351 Mdot
.25794 .49836 Mdot
.45158 .54256 Mdot
.57371 .47664 Mdot
.80248 .33705 Mdot
.25713 .48444 Mdot
.50014 .61785 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.5045 .61195 Mdot
.51435 .59867 Mdot
.54569 .55689 Mdot
.64462 .44052 Mdot
.93185 .37925 Mdot
.3182 .51345 Mdot
.48742 .52511 Mdot
.63778 .41275 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49085 .01236 Mdot
.47086 .03922 Mdot
.4074 .1203 Mdot
.21275 .26382 Mdot
.78587 .12001 Mdot
.59169 .03963 Mdot
.52757 .0142 Mdot
.50459 .00995 Mdot
.48848 .02062 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48715 .01734 Mdot
.45909 .05485 Mdot
.37034 .16219 Mdot
.10791 .25474 Mdot
.69573 .11569 Mdot
.50855 .10777 Mdot
.33418 .23515 Mdot
.9537 .19283 Mdot
.6417 .07815 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49919 .0011 Mdot
.49741 .00351 Mdot
.49173 .01116 Mdot
.47367 .03546 Mdot
.41629 .10954 Mdot
.23906 .25673 Mdot
.82365 .12471 Mdot
.62187 .02245 Mdot
.58555 .56494 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.50779 .60751 Mdot
.52483 .58458 Mdot
.57895 .51435 Mdot
.74672 .36684 Mdot
.15316 .4879 Mdot
.36371 .59936 Mdot
.39393 .07254 Mdot
.27655 .21804 Mdot
.92376 .15003 Mdot
.49974 .00035 Mdot
.49916 .00113 Mdot
.49733 .0036 Mdot
.49151 .01147 Mdot
.47294 .03644 Mdot
.41398 .11236 Mdot
.23219 .25898 Mdot
.81315 .1229 Mdot
.6143 .02581 Mdot
.57254 .5789 Mdot
.63586 .4677 Mdot
.8791 .36609 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49338 .00894 Mdot
.47892 .02842 Mdot
.43294 .08876 Mdot
.28933 .23182 Mdot
.91424 .15611 Mdot
.66165 .03072 Mdot
.61195 .55332 Mdot
.71667 .409 Mdot
.0549 .45888 Mdot
.49989 .00015 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48819 .01595 Mdot
.46239 .05049 Mdot
.38069 .15103 Mdot
.13632 .26251 Mdot
.71157 .11924 Mdot
.51863 .10201 Mdot
.35357 .2194 Mdot
.99858 .21808 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .61231 Mdot
.51351 .5998 Mdot
.54301 .56041 Mdot
.63625 .44897 Mdot
.90979 .36975 Mdot
.31152 .50641 Mdot
.49213 .51371 Mdot
.66093 .38867 Mdot
.03205 .41818 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49463 .00726 Mdot
.48288 .0231 Mdot
.4455 .07264 Mdot
.32797 .20283 Mdot
.99977 .20262 Mdot
.67192 .07248 Mdot
.55464 .02281 Mdot
.51773 .00641 Mdot
.50737 .61761 Mdot
.49998 3e-05 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00264 Mdot
.49377 .00841 Mdot
.48016 .02676 Mdot
.43685 .08378 Mdot
.30129 .22373 Mdot
.93928 .1688 Mdot
.66616 .04126 Mdot
.5994 .57302 Mdot
.50083 .61691 Mdot
.50264 .61446 Mdot
.50842 .60666 Mdot
.52684 .5819 Mdot
.58531 .50654 Mdot
.7657 .35972 Mdot
.18367 .49463 Mdot
.38334 .59335 Mdot
.42327 .04373 Mdot
.35252 .1617 Mdot
.09088 .24145 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50193 .61543 Mdot
.50614 .60974 Mdot
.51956 .59165 Mdot
.56224 .53541 Mdot
.69594 .3963 Mdot
.05472 .44603 Mdot
.33303 .57394 Mdot
.40437 .03933 Mdot
.34074 .16354 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49816 .00249 Mdot
.49413 .00793 Mdot
.48129 .02524 Mdot
.44044 .07917 Mdot
.31234 .21554 Mdot
.96358 .18208 Mdot
.66898 .05324 Mdot
.58283 .59791 Mdot
.61539 .50006 Mdot
.50112 .61652 Mdot
.50356 .61323 Mdot
.51134 .60272 Mdot
.53611 .56953 Mdot
.61459 .47225 Mdot
.85048 .35314 Mdot
.27908 .49823 Mdot
.47293 .5232 Mdot
.62637 .41798 Mdot
.95007 .37245 Mdot
.34744 .49319 Mdot
.5011 .61655 Mdot
.5035 .6133 Mdot
.51116 .60297 Mdot
.53553 .57031 Mdot
.61275 .47431 Mdot
.84531 .35244 Mdot
.27506 .49816 Mdot
.46902 .52669 Mdot
.61681 .42787 Mdot
.92451 .36048 Mdot
.34124 .48443 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50929 .60549 Mdot
.52958 .57822 Mdot
.594 .49606 Mdot
.79135 .35347 Mdot
.21942 .4983 Mdot
.41315 .57488 Mdot
.48299 .59062 Mdot
.52734 .56539 Mdot
.61252 .46956 Mdot
.49963 .00049 Mdot
.49883 .00158 Mdot
.49628 .00502 Mdot
.48816 .01599 Mdot
.46228 .05063 Mdot
.38036 .15139 Mdot
.13541 .26231 Mdot
.71098 .11918 Mdot
.51814 .1024 Mdot
.35244 .22043 Mdot
.99578 .21652 Mdot
.64545 .09968 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00532 Mdot
.48747 .01692 Mdot
.46008 .05354 Mdot
.37345 .15888 Mdot
.11638 .25741 Mdot
.69988 .11712 Mdot
.51038 .1075 Mdot
.33644 .23382 Mdot
.95812 .19543 Mdot
.6419 .08064 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51158 .60239 Mdot
.53689 .5685 Mdot
.61704 .46951 Mdot
.85735 .35428 Mdot
.28411 .49845 Mdot
.47761 .51914 Mdot
.63763 .40686 Mdot
.97931 .38774 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00252 Mdot
.49405 .00803 Mdot
.48106 .02555 Mdot
.43972 .08011 Mdot
.3101 .21726 Mdot
.95857 .17928 Mdot
.66849 .05067 Mdot
.5865 .5924 Mdot
.62798 .48614 Mdot
.8414 .36226 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48783 .01644 Mdot
.46123 .05203 Mdot
.37704 .15501 Mdot
.12623 .26014 Mdot
.70531 .11838 Mdot
.51377 .10563 Mdot
.34286 .22877 Mdot
.97271 .20359 Mdot
.6433 .08798 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60723 Mdot
.52547 .58372 Mdot
.581 .51183 Mdot
.75284 .36431 Mdot
.16338 .49053 Mdot
.36968 .59829 Mdot
.40162 .06576 Mdot
.29521 .2074 Mdot
.95963 .17038 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50662 .6091 Mdot
.52108 .58961 Mdot
.56706 .52927 Mdot
.71069 .3862 Mdot
.08581 .46195 Mdot
.33836 .58733 Mdot
.38803 .06475 Mdot
.28327 .20908 Mdot
.94496 .15907 Mdot
.5006 .61722 Mdot
.50191 .61545 Mdot
.50609 .6098 Mdot
.51942 .59184 Mdot
.56179 .53599 Mdot
.69454 .39731 Mdot
.05168 .44439 Mdot
.33265 .57248 Mdot
.40636 .03633 Mdot
.34759 .157 Mdot
.09356 .23882 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51043 .60395 Mdot
.53321 .57339 Mdot
.60545 .48263 Mdot
.82454 .35097 Mdot
.25666 .49839 Mdot
.45025 .54376 Mdot
.57043 .48058 Mdot
.79283 .33835 Mdot
.24537 .48583 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50739 .60805 Mdot
.52354 .58631 Mdot
.57487 .51943 Mdot
.73441 .3726 Mdot
.13153 .48112 Mdot
.35306 .59879 Mdot
.38419 .07889 Mdot
.25654 .22631 Mdot
.89036 .13252 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00814 Mdot
.48081 .02588 Mdot
.43893 .08112 Mdot
.30767 .21908 Mdot
.95319 .17631 Mdot
.66791 .04796 Mdot
.59031 .58669 Mdot
.64103 .4724 Mdot
.87668 .36917 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51175 .60216 Mdot
.53744 .56778 Mdot
.61875 .46762 Mdot
.86212 .3552 Mdot
.28739 .49869 Mdot
.48049 .51673 Mdot
.6444 .40049 Mdot
.99639 .39715 Mdot
.3538 .51441 Mdot
.50054 .61731 Mdot
.50172 .61572 Mdot
.50547 .61065 Mdot
.51742 .59453 Mdot
.55545 .54416 Mdot
.67499 .4127 Mdot
.00723 .4194 Mdot
.32863 .5493 Mdot
.43984 .60375 Mdot
.46296 .01975 Mdot
.431 .08173 Mdot
.50005 .61796 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50175 .61566 Mdot
.50559 .61048 Mdot
.51781 .594 Mdot
.5567 .54255 Mdot
.67883 .40951 Mdot
.01624 .42453 Mdot
.32933 .55413 Mdot
.43273 .61465 Mdot
.5011 .61655 Mdot
.5035 .61331 Mdot
.51114 .60299 Mdot
.53547 .57038 Mdot
.61257 .47451 Mdot
.8448 .35237 Mdot
.27465 .49815 Mdot
.46862 .52706 Mdot
.61582 .42892 Mdot
.92182 .35932 Mdot
.34043 .48368 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49814 .00252 Mdot
.49406 .00802 Mdot
.48108 .02552 Mdot
.43979 .08002 Mdot
.31031 .2171 Mdot
.95904 .17954 Mdot
.66853 .05091 Mdot
.58616 .59292 Mdot
.6268 .48741 Mdot
.83815 .36193 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49168 .01124 Mdot
.47349 .0357 Mdot
.41572 .11024 Mdot
.23735 .25732 Mdot
.82101 .12421 Mdot
.62003 .02319 Mdot
.5825 .56813 Mdot
.66325 .44196 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48771 .01659 Mdot
.46086 .05251 Mdot
.3759 .15625 Mdot
.12309 .25932 Mdot
.7035 .11802 Mdot
.51254 .10641 Mdot
.34037 .2308 Mdot
.96692 .20036 Mdot
.64274 .08507 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00455 Mdot
.48926 .0145 Mdot
.46579 .04597 Mdot
.3914 .13902 Mdot
.16647 .2667 Mdot
.73493 .11982 Mdot
.54106 .08217 Mdot
.40811 .16271 Mdot
.14484 .2792 Mdot
.69309 .14099 Mdot
.50055 .61729 Mdot
.50175 .61566 Mdot
.50559 .61048 Mdot
.5178 .59401 Mdot
.55667 .54258 Mdot
.67875 .40958 Mdot
.01604 .42442 Mdot
.32931 .55402 Mdot
.43288 .61442 Mdot
.43873 .0518 Mdot
.35492 .16843 Mdot
.50125 .61635 Mdot
.50398 .61265 Mdot
.51269 .60091 Mdot
.5404 .56386 Mdot
.62805 .45755 Mdot
.88772 .36188 Mdot
.30218 .50157 Mdot
.49063 .51025 Mdot
.66503 .38324 Mdot
.04494 .42435 Mdot
.35833 .53901 Mdot
.49969 .00043 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48983 .01374 Mdot
.46759 .04357 Mdot
.39709 .13247 Mdot
.18275 .26704 Mdot
.75068 .11949 Mdot
.55733 .06749 Mdot
.44814 .11472 Mdot
.26252 .26181 Mdot
.83891 .13669 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49156 .0114 Mdot
.47311 .03622 Mdot
.41451 .11171 Mdot
.23375 .25849 Mdot
.81551 .12327 Mdot
.61606 .02496 Mdot
.57567 .57546 Mdot
.64456 .45913 Mdot
.90167 .37366 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50976 .60486 Mdot
.53107 .57624 Mdot
.5987 .49049 Mdot
.80507 .35169 Mdot
.23602 .49867 Mdot
.42916 .56219 Mdot
.51952 .54414 Mdot
.63909 .43099 Mdot
.94173 .37817 Mdot
.50109 .61656 Mdot
.50348 .61334 Mdot
.51107 .60308 Mdot
.53527 .57065 Mdot
.61195 .47522 Mdot
.84303 .35217 Mdot
.27321 .49815 Mdot
.46719 .52834 Mdot
.61231 .43265 Mdot
.91227 .35538 Mdot
.33726 .4813 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48891 .01498 Mdot
.46467 .04747 Mdot
.38787 .14303 Mdot
.15644 .26581 Mdot
.72636 .11989 Mdot
.53238 .09008 Mdot
.38663 .18651 Mdot
.08485 .2615 Mdot
.66174 .13607 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50138 .61618 Mdot
.50438 .61211 Mdot
.51397 .59918 Mdot
.54447 .55849 Mdot
.64082 .44432 Mdot
.9219 .37479 Mdot
.31548 .51002 Mdot
.49026 .51904 Mdot
.65043 .39945 Mdot
.50022 .61773 Mdot
.50071 .61708 Mdot
.50225 .615 Mdot
.50716 .60836 Mdot
.5228 .5873 Mdot
.57254 .52235 Mdot
.72735 .3763 Mdot
.11848 .47627 Mdot
.34786 .5968 Mdot
.38222 .07825 Mdot
.25561 .2257 Mdot
.50097 .61673 Mdot
.50307 .61388 Mdot
.5098 .6048 Mdot
.5312 .57606 Mdot
.59911 .49001 Mdot
.80626 .35159 Mdot
.23739 .49867 Mdot
.43053 .56105 Mdot
.52273 .54005 Mdot
.64891 .42128 Mdot
.96727 .39115 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .00239 Mdot
.49436 .00761 Mdot
.48204 .02423 Mdot
.44285 .07608 Mdot
.31975 .20968 Mdot
.98048 .19163 Mdot
.67042 .06215 Mdot
.56986 .61748 Mdot
.57075 .55403 Mdot
.67431 .42286 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60694 Mdot
.52616 .58279 Mdot
.58318 .50914 Mdot
.75938 .36185 Mdot
.17389 .49284 Mdot
.37645 .59622 Mdot
.41175 .05587 Mdot
.32134 .18884 Mdot
.0158 .20346 Mdot
.50095 .61676 Mdot
.50301 .61396 Mdot
.50961 .60506 Mdot
.5306 .57687 Mdot
.5972 .49226 Mdot
.80071 .35214 Mdot
.23093 .49863 Mdot
.42414 .56632 Mdot
.5078 .55909 Mdot
.60317 .47 Mdot
.84269 .34678 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51282 .60072 Mdot
.54083 .56328 Mdot
.62942 .45609 Mdot
.89145 .36308 Mdot
.30397 .50223 Mdot
.49135 .51024 Mdot
.66575 .38289 Mdot
.04622 .42514 Mdot
.35833 .53981 Mdot
.50004 .61798 Mdot
.50013 .61785 Mdot
.50043 .61746 Mdot
.50137 .61619 Mdot
.50435 .61216 Mdot
.51386 .59933 Mdot
.54413 .55894 Mdot
.63975 .4454 Mdot
.91907 .37357 Mdot
.31462 .50912 Mdot
.49086 .51759 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50078 .61698 Mdot
.5025 .61466 Mdot
.50795 .6073 Mdot
.52532 .58392 Mdot
.58053 .51241 Mdot
.75143 .36487 Mdot
.16106 .48997 Mdot
.36827 .59862 Mdot
.39969 .06754 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.5113 .60277 Mdot
.536 .56967 Mdot
.61425 .47262 Mdot
.84953 .353 Mdot
.27836 .49821 Mdot
.47224 .52381 Mdot
.62469 .41969 Mdot
.94563 .37025 Mdot
.34654 .49148 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00259 Mdot
.4939 .00824 Mdot
.48057 .02621 Mdot
.43816 .0821 Mdot
.30532 .22083 Mdot
.94801 .17348 Mdot
.66731 .04541 Mdot
.59384 .5814 Mdot
.6531 .46037 Mdot
.90821 .37992 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54245 .56115 Mdot
.6345 .45078 Mdot
.90512 .36794 Mdot
.30978 .5052 Mdot
.49235 .51228 Mdot
.66346 .38602 Mdot
.03887 .4217 Mdot
.35655 .53739 Mdot
.50031 .61762 Mdot
.50097 .61672 Mdot
.5031 .61385 Mdot
.50988 .6047 Mdot
.53146 .57572 Mdot
.59992 .48906 Mdot
.8086 .35141 Mdot
.24001 .49866 Mdot
.43316 .55882 Mdot
.52898 .5321 Mdot
.66803 .40369 Mdot
.50037 .61753 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51207 .60173 Mdot
.53845 .56643 Mdot
.62196 .46411 Mdot
.87101 .3572 Mdot
.29305 .49938 Mdot
.48504 .51323 Mdot
.65462 .39139 Mdot
.02133 .41111 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60457 Mdot
.53175 .57534 Mdot
.60083 .488 Mdot
.81123 .35124 Mdot
.24292 .49864 Mdot
.43611 .55629 Mdot
.53602 .52318 Mdot
.68949 .38617 Mdot
.06466 .44448 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51217 .60161 Mdot
.53875 .56604 Mdot
.62288 .46311 Mdot
.87355 .35783 Mdot
.29456 .49963 Mdot
.48614 .51246 Mdot
.65696 .38942 Mdot
.02686 .4142 Mdot
.35666 .52984 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50393 .61273 Mdot
.51251 .60115 Mdot
.53983 .56461 Mdot
.62627 .45945 Mdot
.88286 .3604 Mdot
.29972 .5008 Mdot
.4894 .51062 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51166 .6023 Mdot
.53712 .5682 Mdot
.61776 .46872 Mdot
.85936 .35465 Mdot
.28552 .49854 Mdot
.47886 .51808 Mdot
.64058 .40405 Mdot
.98681 .39184 Mdot
.3528 .50966 Mdot
.50106 .61661 Mdot
.50337 .61348 Mdot
.51074 .60354 Mdot
.53419 .57208 Mdot
.60854 .47908 Mdot
.83337 .35132 Mdot
.26492 .49822 Mdot
.45879 .536 Mdot
.59153 .45575 Mdot
.85411 .33866 Mdot
.30615 .47712 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.52831 .57992 Mdot
.58998 .50088 Mdot
.77953 .35587 Mdot
.20372 .49722 Mdot
.3992 .58455 Mdot
.45338 .00912 Mdot
.43862 .06462 Mdot
.33406 .19206 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49855 .00196 Mdot
.49538 .00625 Mdot
.48527 .01989 Mdot
.45308 .06275 Mdot
.35155 .18127 Mdot
.05824 .23407 Mdot
.67951 .10076 Mdot
.51648 .08551 Mdot
.37812 .18777 Mdot
.07429 .25418 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48845 .0156 Mdot
.46321 .04941 Mdot
.38326 .14818 Mdot
.14349 .26391 Mdot
.71648 .11962 Mdot
.52293 .09844 Mdot
.36366 .20993 Mdot
.02399 .23209 Mdot
.64847 .11356 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54176 .56206 Mdot
.63233 .45303 Mdot
.89931 .36579 Mdot
.30744 .50383 Mdot
.49223 .51103 Mdot
.66538 .38385 Mdot
.0443 .42439 Mdot
.35763 .53946 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50653 .60922 Mdot
.52079 .58999 Mdot
.56616 .53041 Mdot
.70794 .38799 Mdot
.08017 .4592 Mdot
.33716 .58517 Mdot
.39034 .06094 Mdot
.29173 .20344 Mdot
.96255 .16905 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50745 .60797 Mdot
.52374 .58604 Mdot
.57552 .51863 Mdot
.73636 .37162 Mdot
.13506 .48233 Mdot
.35462 .59913 Mdot
.38521 .07853 Mdot
.25815 .22588 Mdot
.89268 .13375 Mdot
.49999 1e-05 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00475 Mdot
.4888 .01512 Mdot
.46433 .04791 Mdot
.38681 .14422 Mdot
.15346 .26544 Mdot
.72397 .11987 Mdot
.53002 .0922 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .01369 Mdot
.46772 .04341 Mdot
.39748 .13202 Mdot
.18387 .26701 Mdot
.75184 .11947 Mdot
.55853 .06642 Mdot
.45106 .11108 Mdot
.27133 .2573 Mdot
.855 .14072 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49871 .00174 Mdot
.49589 .00556 Mdot
.4869 .01769 Mdot
.45828 .05592 Mdot
.36781 .16485 Mdot
.10107 .25238 Mdot
.69271 .11429 Mdot
.50779 .10707 Mdot
.33455 .23428 Mdot
.50125 .61634 Mdot
.50398 .61265 Mdot
.51269 .6009 Mdot
.54042 .56383 Mdot
.62813 .45746 Mdot
.88795 .36195 Mdot
.30229 .50161 Mdot
.49068 .51024 Mdot
.66509 .3832 Mdot
.04506 .42442 Mdot
.35834 .53908 Mdot
.50034 .61757 Mdot
.5011 .61655 Mdot
.5035 .6133 Mdot
.51116 .60297 Mdot
.53553 .5703 Mdot
.61277 .47428 Mdot
.84537 .35244 Mdot
.2751 .49816 Mdot
.46907 .52665 Mdot
.61693 .42775 Mdot
.92482 .36061 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49702 .00403 Mdot
.4905 .01284 Mdot
.46973 .04073 Mdot
.40382 .12457 Mdot
.20227 .26553 Mdot
.77264 .11947 Mdot
.57933 .04894 Mdot
.50015 .0488 Mdot
.42119 .11892 Mdot
.22877 .26515 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .60219 Mdot
.53737 .56786 Mdot
.61855 .46784 Mdot
.86157 .35509 Mdot
.28703 .49866 Mdot
.48018 .51699 Mdot
.64367 .40117 Mdot
.99456 .39613 Mdot
.35361 .5135 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49952 .00065 Mdot
.49846 .00209 Mdot
.49508 .00664 Mdot
.48433 .02115 Mdot
.45012 .06664 Mdot
.3423 .19006 Mdot
.03478 .22204 Mdot
.67551 .09037 Mdot
.52929 .06337 Mdot
.42675 .12891 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50565 .6104 Mdot
.518 .59375 Mdot
.5573 .54177 Mdot
.6807 .40799 Mdot
.02057 .427 Mdot
.32967 .55644 Mdot
.42932 .0018 Mdot
.4264 .06762 Mdot
.31699 .20229 Mdot
.50099 .6167 Mdot
.50315 .61377 Mdot
.51005 .60446 Mdot
.53201 .57499 Mdot
.60165 .48703 Mdot
.81361 .35112 Mdot
.24549 .4986 Mdot
.43874 .55401 Mdot
.54233 .51522 Mdot
.70868 .37262 Mdot
.10576 .46361 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51186 .60202 Mdot
.53776 .56735 Mdot
.61978 .46649 Mdot
.86497 .3558 Mdot
.28927 .49888 Mdot
.48207 .51547 Mdot
.64803 .39719 Mdot
.00537 .40216 Mdot
.35466 .51894 Mdot
.50087 .61686 Mdot
.50277 .6143 Mdot
.50881 .60613 Mdot
.52807 .58025 Mdot
.5892 .50182 Mdot
.77724 .35643 Mdot
.20052 .4969 Mdot
.39652 .58622 Mdot
.448 .01554 Mdot
.42285 .08429 Mdot
.28647 .22798 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.48841 .01565 Mdot
.46308 .04957 Mdot
.38287 .14862 Mdot
.14239 .26371 Mdot
.7157 .11957 Mdot
.52222 .09904 Mdot
.36198 .21155 Mdot
.01969 .22975 Mdot
.64794 .11152 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45742 .05706 Mdot
.3651 .16767 Mdot
.09381 .24969 Mdot
.68981 .11257 Mdot
.50767 .10546 Mdot
.33704 .23148 Mdot
.9625 .19703 Mdot
.64369 .0812 Mdot
.50129 .61628 Mdot
.50413 .61246 Mdot
.51314 .60029 Mdot
.54185 .56193 Mdot
.63262 .45273 Mdot
.9001 .36608 Mdot
.30777 .50401 Mdot
.49228 .51116 Mdot
.6652 .38407 Mdot
.04376 .42413 Mdot
.3575 .53927 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00213 Mdot
.49497 .0068 Mdot
.48398 .02163 Mdot
.44898 .06812 Mdot
.33877 .1933 Mdot
.02601 .2173 Mdot
.67441 .08609 Mdot
.53511 .0538 Mdot
.44806 .1011 Mdot
.28448 .2452 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49021 .01323 Mdot
.4688 .04196 Mdot
.4009 .12801 Mdot
.19378 .26644 Mdot
.76266 .11937 Mdot
.56952 .05695 Mdot
.47738 .07785 Mdot
.35141 .19644 Mdot
.03356 .22733 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01439 Mdot
.46607 .0456 Mdot
.39228 .13801 Mdot
.16897 .26685 Mdot
.73721 .11978 Mdot
.5434 .08004 Mdot
.4139 .15602 Mdot
.16146 .28131 Mdot
.70629 .1393 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49711 .0039 Mdot
.4908 .01242 Mdot
.4707 .03943 Mdot
.4069 .1209 Mdot
.21129 .2641 Mdot
.78397 .1199 Mdot
.58996 .04087 Mdot
.52383 .01886 Mdot
.49332 .02504 Mdot
.4528 .06816 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60042 Mdot
.54155 .56233 Mdot
.63168 .45372 Mdot
.89755 .36516 Mdot
.3067 .50344 Mdot
.49211 .51076 Mdot
.66568 .38344 Mdot
.04527 .42484 Mdot
.35786 .53978 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01579 Mdot
.46275 .05001 Mdot
.38184 .14975 Mdot
.13954 .26317 Mdot
.71373 .11944 Mdot
.52048 .10051 Mdot
.35785 .21545 Mdot
.00925 .22402 Mdot
.64678 .10643 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00437 Mdot
.48969 .01393 Mdot
.46715 .04417 Mdot
.39569 .13409 Mdot
.17873 .26709 Mdot
.74657 .11958 Mdot
.55309 .07126 Mdot
.43779 .12748 Mdot
.23152 .27403 Mdot
.78813 .1307 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49276 .00977 Mdot
.47695 .03107 Mdot
.42668 .09666 Mdot
.27027 .24301 Mdot
.87707 .14005 Mdot
.65047 .02043 Mdot
.61741 .53922 Mdot
.74493 .39175 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01061 Mdot
.47497 .03373 Mdot
.4204 .10448 Mdot
.25134 .25202 Mdot
.84356 .12925 Mdot
.63444 .01892 Mdot
.60383 .54738 Mdot
.71815 .40278 Mdot
.06645 .4626 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58923 Mdot
.56798 .5281 Mdot
.71349 .38442 Mdot
.09148 .46464 Mdot
.33968 .58937 Mdot
.38606 .06817 Mdot
.27575 .21379 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51328 .60011 Mdot
.54227 .56138 Mdot
.63394 .45136 Mdot
.90363 .36738 Mdot
.3092 .50483 Mdot
.49237 .51191 Mdot
.66408 .38534 Mdot
.04059 .42256 Mdot
.35687 .53808 Mdot
.50123 .61637 Mdot
.50391 .61274 Mdot
.51247 .60119 Mdot
.53972 .56475 Mdot
.62594 .45981 Mdot
.88195 .36013 Mdot
.29924 .50067 Mdot
.48914 .51073 Mdot
.66276 .3848 Mdot
.04013 .42161 Mdot
.35794 .53651 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47739 .03048 Mdot
.42807 .09491 Mdot
.2745 .24071 Mdot
.88502 .14315 Mdot
.65339 .02196 Mdot
.61785 .54046 Mdot
.74337 .39304 Mdot
.10742 .48523 Mdot
.50119 .61643 Mdot
.50378 .61292 Mdot
.51206 .60175 Mdot
.5384 .5665 Mdot
.62178 .46431 Mdot
.87051 .35708 Mdot
.29275 .49933 Mdot
.48481 .51339 Mdot
.65413 .39181 Mdot
.02017 .41046 Mdot
.35603 .52646 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50933 .60544 Mdot
.52971 .57806 Mdot
.59439 .49559 Mdot
.7925 .35328 Mdot
.22088 .49836 Mdot
.41452 .57385 Mdot
.486 .58681 Mdot
.53652 .55326 Mdot
.64132 .43879 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.48728 .01717 Mdot
.45951 .0543 Mdot
.37165 .16081 Mdot
.11146 .25589 Mdot
.69742 .11633 Mdot
.5092 .10781 Mdot
.33476 .23492 Mdot
.95466 .19345 Mdot
.64165 .07879 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60736 Mdot
.52516 .58413 Mdot
.58002 .51304 Mdot
.74991 .36549 Mdot
.15853 .48933 Mdot
.36677 .59891 Mdot
.39771 .06931 Mdot
.28556 .21319 Mdot
.94062 .1594 Mdot
.49978 .00029 Mdot
.49931 .00094 Mdot
.49779 .00299 Mdot
.49295 .00952 Mdot
.47755 .03026 Mdot
.42858 .09427 Mdot
.27604 .23985 Mdot
.88796 .14435 Mdot
.6544 .02263 Mdot
.61777 .54118 Mdot
.74213 .39381 Mdot
.10492 .48419 Mdot
.50125 .61634 Mdot
.504 .61264 Mdot
.51273 .60085 Mdot
.54054 .56367 Mdot
.62851 .45706 Mdot
.88897 .36228 Mdot
.30279 .50178 Mdot
.49089 .51022 Mdot
.66534 .38306 Mdot
.04553 .4247 Mdot
.35835 .53935 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00471 Mdot
.48888 .01501 Mdot
.46459 .04757 Mdot
.38761 .14331 Mdot
.15573 .26572 Mdot
.72578 .11988 Mdot
.5318 .0906 Mdot
.38521 .18802 Mdot
.08098 .2599 Mdot
.66045 .1351 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56446 Mdot
.62663 .45907 Mdot
.88384 .36069 Mdot
.30023 .50095 Mdot
.48968 .51051 Mdot
.66366 .38415 Mdot
.04209 .42272 Mdot
.35812 .5375 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00378 Mdot
.49109 .01203 Mdot
.47162 .0382 Mdot
.40982 .1174 Mdot
.21986 .26231 Mdot
.79543 .12073 Mdot
.60008 .03395 Mdot
.54515 .61068 Mdot
.55705 .55892 Mdot
.6527 .4381 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51265 .60096 Mdot
.54028 .56401 Mdot
.62769 .45793 Mdot
.88675 .36158 Mdot
.3017 .50141 Mdot
.49041 .51029 Mdot
.66474 .38341 Mdot
.04437 .42402 Mdot
.3583 .5387 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.48919 .0146 Mdot
.46557 .04626 Mdot
.39072 .13979 Mdot
.16453 .26657 Mdot
.73321 .11984 Mdot
.5393 .08378 Mdot
.40374 .16767 Mdot
.13244 .27677 Mdot
.68462 .14149 Mdot
.50041 .61749 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54179 .56202 Mdot
.63242 .45295 Mdot
.89953 .36587 Mdot
.30754 .50388 Mdot
.49225 .51106 Mdot
.66533 .38391 Mdot
.04415 .42431 Mdot
.49961 .00053 Mdot
.49876 .00167 Mdot
.49606 .00533 Mdot
.48743 .01697 Mdot
.45998 .05368 Mdot
.37312 .15923 Mdot
.11548 .25714 Mdot
.69942 .11698 Mdot
.51014 .10759 Mdot
.33606 .23409 Mdot
.9573 .19497 Mdot
.64183 .08021 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50985 .60473 Mdot
.53137 .57584 Mdot
.59964 .48938 Mdot
.8078 .35146 Mdot
.23912 .49866 Mdot
.43227 .55958 Mdot
.52685 .5348 Mdot
.66152 .40948 Mdot
.99897 .40852 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51184 .60204 Mdot
.53772 .5674 Mdot
.61964 .46665 Mdot
.86458 .35572 Mdot
.28902 .49885 Mdot
.48186 .51563 Mdot
.64754 .39762 Mdot
.00418 .4015 Mdot
.35455 .51834 Mdot
.50045 .61743 Mdot
.50142 .61612 Mdot
.50452 .61192 Mdot
.51441 .59858 Mdot
.54589 .55662 Mdot
.64526 .43989 Mdot
.93349 .38002 Mdot
.31861 .51406 Mdot
.48684 .52625 Mdot
.63535 .41536 Mdot
.96329 .38163 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54007 .5643 Mdot
.62701 .45866 Mdot
.88489 .36101 Mdot
.30077 .50111 Mdot
.48996 .51041 Mdot
.66409 .38385 Mdot
.04302 .42324 Mdot
.3582 .53798 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58922 Mdot
.56799 .52808 Mdot
.71354 .3844 Mdot
.09157 .46468 Mdot
.3397 .5894 Mdot
.38603 .06822 Mdot
.27564 .21386 Mdot
.92961 .15071 Mdot
.50007 .61795 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60898 Mdot
.52135 .58925 Mdot
.56792 .52817 Mdot
.71332 .38453 Mdot
.09114 .46448 Mdot
.3396 .58925 Mdot
.38617 .06798 Mdot
.49997 4e-05 Mdot
.49989 .00014 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49658 .00461 Mdot
.48912 .01469 Mdot
.46534 .04657 Mdot
.38999 .14062 Mdot
.16246 .26641 Mdot
.73141 .11987 Mdot
.53746 .08546 Mdot
.39918 .1728 Mdot
.49991 .00012 Mdot
.49971 .0004 Mdot
.49907 .00126 Mdot
.49702 .00402 Mdot
.49051 .01281 Mdot
.46978 .04066 Mdot
.40399 .12436 Mdot
.20277 .26546 Mdot
.77325 .11948 Mdot
.57992 .04847 Mdot
.50149 .04709 Mdot
.4253 .11382 Mdot
.50068 .61712 Mdot
.50216 .61511 Mdot
.50689 .60873 Mdot
.52194 .58846 Mdot
.56979 .52581 Mdot
.71902 .38105 Mdot
.10246 .46961 Mdot
.34261 .59287 Mdot
.38332 .07357 Mdot
.26428 .22052 Mdot
.90746 .13949 Mdot
.50016 .61782 Mdot
.50051 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51665 .59556 Mdot
.55302 .54731 Mdot
.66744 .41918 Mdot
.9892 .40917 Mdot
.32714 .53972 Mdot
.45385 .58191 Mdot
.51231 .57051 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49257 .01003 Mdot
.47634 .03189 Mdot
.42474 .09909 Mdot
.26441 .24603 Mdot
.86633 .13617 Mdot
.646 .01902 Mdot
.61522 .53934 Mdot
.74255 .39195 Mdot
.10836 .48482 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .0068 Mdot
.48395 .02166 Mdot
.44891 .06821 Mdot
.33855 .1935 Mdot
.02547 .21701 Mdot
.67434 .08582 Mdot
.53548 .0532 Mdot
.44941 .09932 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51101 .60316 Mdot
.53508 .5709 Mdot
.61134 .4759 Mdot
.84131 .35198 Mdot
.27179 .49815 Mdot
.46577 .52963 Mdot
.60881 .43643 Mdot
.90265 .35171 Mdot
.33357 .47937 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.5009 .61681 Mdot
.50287 .61415 Mdot
.50916 .60566 Mdot
.52918 .57877 Mdot
.59271 .4976 Mdot
.78758 .35415 Mdot
.21456 .49805 Mdot
.4087 .57812 Mdot
.47328 .60277 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00806 Mdot
.48098 .02565 Mdot
.43947 .08042 Mdot
.30935 .21783 Mdot
.9569 .17835 Mdot
.66831 .04982 Mdot
.5877 .5906 Mdot
.63208 .48173 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47456 .03428 Mdot
.4191 .10609 Mdot
.24744 .25361 Mdot
.83709 .12761 Mdot
.63061 .01967 Mdot
.59878 .5519 Mdot
.70579 .41001 Mdot
.04237 .44883 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51174 .60219 Mdot
.53738 .56785 Mdot
.61857 .46782 Mdot
.86162 .3551 Mdot
.28706 .49866 Mdot
.4802 .51697 Mdot
.64373 .40111 Mdot
.99472 .39622 Mdot
.35363 .51357 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49857 .00194 Mdot
.49543 .00617 Mdot
.48546 .01963 Mdot
.45369 .06196 Mdot
.35343 .17943 Mdot
.06311 .23641 Mdot
.68058 .10268 Mdot
.51444 .08931 Mdot
.36993 .19691 Mdot
.49997 4e-05 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00414 Mdot
.49023 .0132 Mdot
.46888 .04186 Mdot
.40114 .12773 Mdot
.19447 .26638 Mdot
.76345 .11937 Mdot
.57031 .05628 Mdot
.47924 .07548 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00531 Mdot
.48747 .01692 Mdot
.46009 .05353 Mdot
.37347 .15886 Mdot
.11643 .25742 Mdot
.69991 .11713 Mdot
.5104 .1075 Mdot
.33646 .2338 Mdot
.95817 .19546 Mdot
.6419 .08066 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56447 Mdot
.62661 .45908 Mdot
.8838 .36068 Mdot
.30021 .50094 Mdot
.48967 .51051 Mdot
.66364 .38416 Mdot
.04205 .42269 Mdot
.35812 .53748 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48701 .01754 Mdot
.45862 .05547 Mdot
.36888 .16373 Mdot
.10395 .25339 Mdot
.69395 .1149 Mdot
.50803 .10746 Mdot
.33416 .23486 Mdot
.95415 .19294 Mdot
.50082 .61692 Mdot
.50263 .61448 Mdot
.50837 .60673 Mdot
.52667 .58212 Mdot
.58479 .50718 Mdot
.76416 .36022 Mdot
.18131 .49423 Mdot
.38163 .59413 Mdot
.4203 .04693 Mdot
.34437 .16929 Mdot
.07046 .23249 Mdot
.49959 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45727 .05725 Mdot
.36463 .16815 Mdot
.09256 .2492 Mdot
.68934 .11224 Mdot
.50772 .10509 Mdot
.33769 .2308 Mdot
.96425 .19793 Mdot
.64399 .08193 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01453 Mdot
.46573 .04606 Mdot
.3912 .13925 Mdot
.16588 .26666 Mdot
.73441 .11983 Mdot
.54052 .08266 Mdot
.40677 .16423 Mdot
.14103 .27853 Mdot
.69037 .14122 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01062 Mdot
.47496 .03374 Mdot
.42037 .10451 Mdot
.25127 .25205 Mdot
.84344 .12921 Mdot
.63437 .01893 Mdot
.60374 .54745 Mdot
.71794 .40289 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46941 .04116 Mdot
.40281 .12577 Mdot
.19932 .26589 Mdot
.76909 .11941 Mdot
.57589 .05169 Mdot
.49226 .05887 Mdot
.39701 .14782 Mdot
.15784 .27131 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48745 .01694 Mdot
.46005 .05359 Mdot
.37333 .15901 Mdot
.11606 .25731 Mdot
.69972 .11707 Mdot
.51029 .10753 Mdot
.3363 .23392 Mdot
.95782 .19527 Mdot
.64187 .08048 Mdot
.49988 .00017 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.4872 .01727 Mdot
.45925 .05464 Mdot
.37085 .16165 Mdot
.10929 .25519 Mdot
.69638 .11594 Mdot
.50878 .10781 Mdot
.33434 .23511 Mdot
.95392 .19299 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51033 .60409 Mdot
.53289 .57381 Mdot
.60444 .48379 Mdot
.82165 .35095 Mdot
.2538 .49845 Mdot
.44729 .54642 Mdot
.56316 .4894 Mdot
.7713 .34317 Mdot
.21604 .48737 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.50492 .61139 Mdot
.51568 .59688 Mdot
.54991 .55136 Mdot
.65779 .42789 Mdot
.96545 .39611 Mdot
.32453 .52778 Mdot
.47057 .55491 Mdot
.57271 .48982 Mdot
.78015 .34492 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50389 .61278 Mdot
.51238 .60132 Mdot
.53942 .56515 Mdot
.62499 .46083 Mdot
.87936 .35939 Mdot
.29785 .50032 Mdot
.48832 .51114 Mdot
.66128 .38593 Mdot
.03684 .41977 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.52589 .58315 Mdot
.58233 .51019 Mdot
.75683 .36278 Mdot
.16984 .492 Mdot
.37376 .59714 Mdot
.40757 .06006 Mdot
.3104 .1971 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.4985 .00202 Mdot
.49523 .00644 Mdot
.48481 .0205 Mdot
.45164 .06465 Mdot
.34703 .18562 Mdot
.04669 .22828 Mdot
.67732 .09586 Mdot
.52222 .07533 Mdot
.40034 .1618 Mdot
.13854 .27462 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .00149 Mdot
.49648 .00476 Mdot
.48878 .01515 Mdot
.46427 .048 Mdot
.38661 .14444 Mdot
.1529 .26537 Mdot
.72352 .11986 Mdot
.52958 .09259 Mdot
.37976 .19375 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47455 .03428 Mdot
.41909 .1061 Mdot
.24742 .25362 Mdot
.83705 .1276 Mdot
.63059 .01968 Mdot
.59875 .55193 Mdot
.70571 .41006 Mdot
.04223 .44875 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.5159 .59657 Mdot
.55062 .55043 Mdot
.66001 .42585 Mdot
.97097 .39909 Mdot
.32523 .53045 Mdot
.46695 .56087 Mdot
.55944 .50704 Mdot
.73904 .35984 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50778 .60752 Mdot
.5248 .58463 Mdot
.57885 .51448 Mdot
.7464 .36698 Mdot
.15262 .48775 Mdot
.36342 .59939 Mdot
.39358 .07283 Mdot
.27574 .21845 Mdot
.92229 .14923 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48731 .01713 Mdot
.4596 .05417 Mdot
.37195 .16049 Mdot
.11227 .25615 Mdot
.69781 .11647 Mdot
.50937 .10779 Mdot
.33497 .2348 Mdot
.95506 .19369 Mdot
.64167 .07902 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56064 Mdot
.63571 .44953 Mdot
.90835 .36919 Mdot
.311 .50603 Mdot
.49223 .51323 Mdot
.6618 .38777 Mdot
.03438 .41939 Mdot
.35579 .53553 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58922 Mdot
.56799 .52809 Mdot
.71353 .3844 Mdot
.09157 .46468 Mdot
.3397 .5894 Mdot
.38603 .06822 Mdot
.27565 .21386 Mdot
.92962 .15072 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .0018 Mdot
.49576 .00572 Mdot
.4865 .01823 Mdot
.45701 .0576 Mdot
.36382 .169 Mdot
.09038 .24835 Mdot
.68854 .11167 Mdot
.50786 .10438 Mdot
.33896 .22947 Mdot
.96767 .19971 Mdot
.50017 .6178 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.50552 .61058 Mdot
.51757 .59433 Mdot
.55593 .54354 Mdot
.67646 .41147 Mdot
.0107 .42138 Mdot
.3289 .55116 Mdot
.4371 .60796 Mdot
.4534 .03252 Mdot
.50123 .61637 Mdot
.50393 .61272 Mdot
.51253 .60111 Mdot
.53991 .5645 Mdot
.62652 .45918 Mdot
.88355 .3606 Mdot
.30008 .5009 Mdot
.4896 .51054 Mdot
.66353 .38424 Mdot
.04181 .42256 Mdot
.3581 .53736 Mdot
.50075 .61702 Mdot
.50239 .6148 Mdot
.50762 .60774 Mdot
.52428 .58532 Mdot
.57721 .51652 Mdot
.74147 .36918 Mdot
.14412 .48526 Mdot
.35894 .59957 Mdot
.38882 .07643 Mdot
.26516 .2233 Mdot
.90385 .13949 Mdot
.50131 .61626 Mdot
.50417 .6124 Mdot
.51329 .60009 Mdot
.54233 .5613 Mdot
.63413 .45116 Mdot
.90413 .36756 Mdot
.3094 .50495 Mdot
.49236 .51203 Mdot
.66389 .38556 Mdot
.04004 .42229 Mdot
.35676 .53786 Mdot
.50067 .61713 Mdot
.50214 .61515 Mdot
.50681 .60883 Mdot
.5217 .58878 Mdot
.56904 .52676 Mdot
.71673 .38242 Mdot
.09796 .46761 Mdot
.34135 .59151 Mdot
.38426 .07156 Mdot
.26848 .21811 Mdot
.91557 .14346 Mdot
.50123 .61637 Mdot
.50392 .61273 Mdot
.5125 .60116 Mdot
.5398 .56465 Mdot
.62617 .45955 Mdot
.8826 .36032 Mdot
.29958 .50076 Mdot
.48933 .51065 Mdot
.66308 .38456 Mdot
.04084 .42202 Mdot
.35801 .53687 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50493 .61138 Mdot
.5157 .59684 Mdot
.54999 .55125 Mdot
.65804 .42766 Mdot
.96608 .39645 Mdot
.32461 .52808 Mdot
.47017 .55557 Mdot
.57123 .49172 Mdot
.77562 .34608 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.50231 .61492 Mdot
.50735 .6081 Mdot
.52342 .58647 Mdot
.5745 .51989 Mdot
.7333 .37316 Mdot
.12951 .48041 Mdot
.3522 .59856 Mdot
.38371 .079 Mdot
.25589 .22644 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50296 .61403 Mdot
.50944 .60528 Mdot
.53007 .57757 Mdot
.59555 .49421 Mdot
.79589 .35276 Mdot
.22511 .49851 Mdot
.41851 .57079 Mdot
.49495 .57547 Mdot
.56382 .51788 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51159 .60239 Mdot
.53691 .56847 Mdot
.6171 .46945 Mdot
.85752 .35431 Mdot
.28423 .49845 Mdot
.47771 .51905 Mdot
.63788 .40663 Mdot
.97994 .38808 Mdot
.35201 .50634 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00191 Mdot
.49549 .00609 Mdot
.48563 .01939 Mdot
.45426 .06122 Mdot
.35521 .17768 Mdot
.06771 .23858 Mdot
.68168 .10442 Mdot
.51274 .09262 Mdot
.36287 .20459 Mdot
.03183 .2339 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61069 Mdot
.51732 .59467 Mdot
.55512 .54459 Mdot
.67395 .41357 Mdot
.00479 .41801 Mdot
.32844 .54799 Mdot
.44177 .60077 Mdot
.4697 .01066 Mdot
.45246 .05408 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.5115 .60251 Mdot
.53661 .56887 Mdot
.61617 .47048 Mdot
.85491 .35385 Mdot
.28237 .49835 Mdot
.47602 .5205 Mdot
.63383 .41055 Mdot
.96955 .38249 Mdot
.35067 .50149 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.4982 .00244 Mdot
.49425 .00777 Mdot
.48168 .02471 Mdot
.4417 .07756 Mdot
.31621 .21252 Mdot
.97235 .18701 Mdot
.66976 .05783 Mdot
.57619 .6079 Mdot
.59259 .52683 Mdot
.74016 .37957 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50639 .6094 Mdot
.52037 .59057 Mdot
.56481 .53213 Mdot
.70381 .39076 Mdot
.07155 .45487 Mdot
.33555 .58161 Mdot
.39448 .05439 Mdot
.30646 .19275 Mdot
.99458 .18773 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39525 .1346 Mdot
.17745 .26708 Mdot
.7453 .1196 Mdot
.55178 .07244 Mdot
.43457 .1314 Mdot
.22196 .27666 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49135 .01169 Mdot
.47244 .03711 Mdot
.4124 .11428 Mdot
.22749 .26035 Mdot
.80623 .12192 Mdot
.60896 .02862 Mdot
.56266 .59005 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00476 Mdot
.48878 .01514 Mdot
.46428 .04798 Mdot
.38665 .1444 Mdot
.15299 .26538 Mdot
.7236 .11986 Mdot
.52966 .09253 Mdot
.37995 .19356 Mdot
.06676 .25365 Mdot
.65634 .13093 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01627 Mdot
.46162 .05151 Mdot
.37828 .15367 Mdot
.12964 .26099 Mdot
.70734 .11872 Mdot
.51526 .1046 Mdot
.34602 .22609 Mdot
.98019 .20778 Mdot
.644 .09176 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.50771 .60762 Mdot
.52456 .58495 Mdot
.57809 .51542 Mdot
.74412 .36798 Mdot
.14872 .48664 Mdot
.36132 .59955 Mdot
.39123 .07468 Mdot
.27039 .22102 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00698 Mdot
.48355 .0222 Mdot
.44763 .06988 Mdot
.33455 .19709 Mdot
.01565 .21158 Mdot
.67331 .08083 Mdot
.54252 .04188 Mdot
.47476 .06519 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00476 Mdot
.48879 .01514 Mdot
.46428 .04798 Mdot
.38665 .1444 Mdot
.15301 .26538 Mdot
.72361 .11986 Mdot
.52967 .09251 Mdot
.37999 .19352 Mdot
.06686 .2537 Mdot
.65637 .13096 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00225 Mdot
.49469 .00717 Mdot
.4831 .02281 Mdot
.44619 .07175 Mdot
.33009 .20101 Mdot
.00486 .20551 Mdot
.67234 .07518 Mdot
.55069 .02898 Mdot
.5038 .02546 Mdot
.46261 .05981 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.4932 .00918 Mdot
.47835 .02919 Mdot
.43111 .09108 Mdot
.28374 .23533 Mdot
.90297 .15084 Mdot
.6589 .02682 Mdot
.61551 .54692 Mdot
.73057 .40048 Mdot
.08258 .47365 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.5101 .60439 Mdot
.53218 .57476 Mdot
.60219 .48641 Mdot
.81516 .35106 Mdot
.24714 .49858 Mdot
.44042 .55253 Mdot
.54641 .51012 Mdot
.72102 .36501 Mdot
.13042 .47283 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48971 .0139 Mdot
.46722 .04408 Mdot
.3959 .13385 Mdot
.17932 .26708 Mdot
.74717 .11956 Mdot
.55372 .07071 Mdot
.43931 .12561 Mdot
.23606 .27259 Mdot
.795 .13091 Mdot
.50005 .61796 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50168 .61577 Mdot
.50535 .61081 Mdot
.51704 .59505 Mdot
.55423 .54574 Mdot
.6712 .41592 Mdot
.99823 .41427 Mdot
.32792 .54449 Mdot
.44692 .59279 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49336 .00897 Mdot
.47885 .02851 Mdot
.43272 .08904 Mdot
.28865 .23226 Mdot
.91284 .15544 Mdot
.66134 .0302 Mdot
.61247 .55243 Mdot
.71861 .40775 Mdot
.05886 .46108 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48984 .01373 Mdot
.46763 .04353 Mdot
.39719 .13235 Mdot
.18305 .26703 Mdot
.75099 .11949 Mdot
.55765 .0672 Mdot
.44891 .11375 Mdot
.26486 .26065 Mdot
.84311 .13765 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49066 .01261 Mdot
.47026 .04002 Mdot
.40551 .12256 Mdot
.20721 .2648 Mdot
.77875 .11966 Mdot
.58514 .04444 Mdot
.51324 .03218 Mdot
.46118 .06781 Mdot
.35146 .18637 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52883 .57922 Mdot
.59163 .4989 Mdot
.7844 .35478 Mdot
.21035 .49777 Mdot
.40493 .58076 Mdot
.46525 .61271 Mdot
.47386 .01881 Mdot
.44343 .07016 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51436 .59864 Mdot
.54574 .55683 Mdot
.64477 .44037 Mdot
.93224 .37943 Mdot
.3183 .5136 Mdot
.48728 .52537 Mdot
.63721 .41336 Mdot
.96839 .38424 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51056 .60377 Mdot
.53364 .57281 Mdot
.60681 .48106 Mdot
.82845 .35108 Mdot
.26039 .49831 Mdot
.45412 .54025 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49765 .00317 Mdot
.49253 .01009 Mdot
.4762 .03208 Mdot
.4243 .09964 Mdot
.26308 .24669 Mdot
.86393 .13536 Mdot
.64491 .01882 Mdot
.61446 .53966 Mdot
.74127 .39234 Mdot
.10646 .48383 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51104 .60312 Mdot
.53517 .57078 Mdot
.61162 .47558 Mdot
.84211 .35207 Mdot
.27245 .49815 Mdot
.50123 .61637 Mdot
.50393 .61272 Mdot
.51253 .60112 Mdot
.53989 .56452 Mdot
.62648 .45923 Mdot
.88342 .36057 Mdot
.30001 .50089 Mdot
.48956 .51055 Mdot
.66347 .38428 Mdot
.04169 .42249 Mdot
.35809 .5373 Mdot
.50023 .61773 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50728 .6082 Mdot
.52318 .58679 Mdot
.57374 .52085 Mdot
.73099 .37435 Mdot
.12527 .47886 Mdot
.35046 .59798 Mdot
.38291 .07897 Mdot
.25514 .22643 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .60219 Mdot
.53736 .56787 Mdot
.61852 .46788 Mdot
.86148 .35507 Mdot
.28696 .49866 Mdot
.48012 .51704 Mdot
.64354 .40129 Mdot
.99425 .39595 Mdot
.35358 .51334 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50717 .60835 Mdot
.52283 .58726 Mdot
.57263 .52224 Mdot
.72764 .37614 Mdot
.11902 .47648 Mdot
.34806 .5969 Mdot
.38225 .07834 Mdot
.2555 .22579 Mdot
.89016 .13186 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50232 .61489 Mdot
.50741 .60803 Mdot
.52359 .58624 Mdot
.57504 .51923 Mdot
.73491 .37234 Mdot
.13244 .48144 Mdot
.35346 .59889 Mdot
.38444 .07882 Mdot
.2569 .22623 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00438 Mdot
.48968 .01393 Mdot
.46714 .04418 Mdot
.39565 .13414 Mdot
.17861 .26709 Mdot
.74646 .11958 Mdot
.55298 .07137 Mdot
.4375 .12783 Mdot
.23066 .27429 Mdot
.78685 .13068 Mdot
.50094 .61677 Mdot
.50298 .61401 Mdot
.50949 .60521 Mdot
.53024 .57735 Mdot
.59607 .4936 Mdot
.79741 .35255 Mdot
.22696 .49855 Mdot
.42029 .5694 Mdot
.49898 .57035 Mdot
.57613 .50244 Mdot
.76316 .3554 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61025 Mdot
.51837 .59326 Mdot
.55846 .54027 Mdot
.68428 .40513 Mdot
.02877 .43166 Mdot
.33034 .5608 Mdot
.42295 .01144 Mdot
.40444 .0948 Mdot
.25105 .24234 Mdot
.50132 .61626 Mdot
.50419 .61237 Mdot
.51336 .6 Mdot
.54254 .56103 Mdot
.63477 .4505 Mdot
.90584 .36822 Mdot
.31006 .50538 Mdot
.49234 .51248 Mdot
.66313 .38638 Mdot
.03796 .42123 Mdot
.35639 .53702 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50476 .61161 Mdot
.51516 .59758 Mdot
.54825 .55353 Mdot
.65263 .43274 Mdot
.95244 .3893 Mdot
.32253 .52179 Mdot
.47826 .54188 Mdot
.60147 .45406 Mdot
.86679 .34449 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.52311 .58689 Mdot
.57351 .52114 Mdot
.73028 .37473 Mdot
.12396 .47837 Mdot
.34994 .59777 Mdot
.38272 .07889 Mdot
.25507 .22636 Mdot
.88881 .13146 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01025 Mdot
.47582 .03259 Mdot
.42309 .10114 Mdot
.25944 .24843 Mdot
.85748 .13327 Mdot
.64185 .0185 Mdot
.61192 .54111 Mdot
.73638 .39411 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60898 Mdot
.52135 .58925 Mdot
.56793 .52817 Mdot
.71334 .38452 Mdot
.09117 .46449 Mdot
.33961 .58926 Mdot
.38616 .068 Mdot
.27614 .21356 Mdot
.9306 .15123 Mdot
.5008 .61695 Mdot
.50255 .6146 Mdot
.50811 .60708 Mdot
.52583 .58324 Mdot
.58213 .51044 Mdot
.75622 .36301 Mdot
.16887 .49179 Mdot
.37313 .59734 Mdot
.40662 .06099 Mdot
.30794 .19886 Mdot
.98618 .18607 Mdot
.5004 .61749 Mdot
.50128 .6163 Mdot
.50409 .6125 Mdot
.51304 .60043 Mdot
.54153 .56237 Mdot
.6316 .4538 Mdot
.89734 .36509 Mdot
.30661 .5034 Mdot
.49209 .51073 Mdot
.66571 .3834 Mdot
.04536 .42488 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51054 .60379 Mdot
.53358 .57289 Mdot
.60663 .48127 Mdot
.82792 .35106 Mdot
.25989 .49832 Mdot
.4536 .54072 Mdot
.57869 .47071 Mdot
.81706 .33607 Mdot
.27329 .48204 Mdot
.5 0 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .00499 Mdot
.48822 .0159 Mdot
.4625 .05034 Mdot
.38104 .15064 Mdot
.1373 .26271 Mdot
.71222 .11931 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50482 .61152 Mdot
.51535 .59731 Mdot
.54888 .55271 Mdot
.65458 .4309 Mdot
.95738 .39185 Mdot
.32335 .524 Mdot
.47549 .54664 Mdot
.59101 .46679 Mdot
.83573 .34014 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01098 Mdot
.47411 .03487 Mdot
.41769 .10782 Mdot
.24323 .25523 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48804 .01615 Mdot
.46191 .05113 Mdot
.37918 .15268 Mdot
.13214 .26158 Mdot
.70889 .11893 Mdot
.51645 .10371 Mdot
.34864 .22382 Mdot
.98649 .21131 Mdot
.64458 .09496 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50883 .60611 Mdot
.52813 .58016 Mdot
.58941 .50157 Mdot
.77785 .35628 Mdot
.20138 .49699 Mdot
.39723 .58578 Mdot
.44941 .01386 Mdot
.42699 .07919 Mdot
.29886 .21984 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47145 .03843 Mdot
.40928 .11805 Mdot
.21828 .26267 Mdot
.79327 .12054 Mdot
.59822 .03516 Mdot
.54134 .6153 Mdot
.54577 .57345 Mdot
.6179 .47388 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49399 .00811 Mdot
.48086 .02581 Mdot
.4391 .08091 Mdot
.30819 .2187 Mdot
.95433 .17694 Mdot
.66804 .04853 Mdot
.58952 .58788 Mdot
.6383 .47521 Mdot
.86941 .36727 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50139 .61616 Mdot
.50441 .61207 Mdot
.51406 .59905 Mdot
.54478 .55808 Mdot
.6418 .44334 Mdot
.92446 .37591 Mdot
.31623 .51086 Mdot
.48963 .52047 Mdot
.6475 .40248 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50976 .60486 Mdot
.53108 .57623 Mdot
.59873 .49046 Mdot
.80515 .35168 Mdot
.23611 .49867 Mdot
.42925 .56212 Mdot
.51973 .54387 Mdot
.63972 .43035 Mdot
.9434 .37898 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50704 .60853 Mdot
.52241 .58782 Mdot
.5713 .52391 Mdot
.7236 .37839 Mdot
.11136 .4734 Mdot
.34538 .59524 Mdot
.38226 .07667 Mdot
.25821 .22401 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00182 Mdot
.49572 .00579 Mdot
.48635 .01843 Mdot
.45653 .05823 Mdot
.36232 .17053 Mdot
.0864 .24675 Mdot
.68715 .11056 Mdot
.50826 .1029 Mdot
.34177 .22659 Mdot
.97513 .20363 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50767 .60767 Mdot
.52444 .5851 Mdot
.57772 .51588 Mdot
.74301 .36848 Mdot
.14679 .48607 Mdot
.36031 .59958 Mdot
.39017 .07547 Mdot
.26806 .22207 Mdot
.90875 .14203 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48082 .02587 Mdot
.43896 .08108 Mdot
.30776 .21902 Mdot
.95339 .17642 Mdot
.66794 .04806 Mdot
.59018 .5869 Mdot
.64056 .47288 Mdot
.87541 .36883 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .00399 Mdot
.49058 .01272 Mdot
.46999 .04038 Mdot
.40466 .12357 Mdot
.20471 .26518 Mdot
.77564 .11955 Mdot
.5822 .04669 Mdot
.50666 .04052 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48953 .01414 Mdot
.46664 .04484 Mdot
.39408 .13595 Mdot
.17412 .26704 Mdot
.74204 .11968 Mdot
.54841 .07549 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .0049 Mdot
.48845 .01559 Mdot
.46322 .04938 Mdot
.38332 .14812 Mdot
.14366 .26394 Mdot
.71661 .11963 Mdot
.52304 .09834 Mdot
.36392 .20967 Mdot
.02467 .23245 Mdot
.64856 .11387 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49814 .00251 Mdot
.49407 .008 Mdot
.48112 .02546 Mdot
.43992 .07985 Mdot
.31072 .21678 Mdot
.95996 .18005 Mdot
.66863 .05138 Mdot
.58549 .59391 Mdot
.62452 .4899 Mdot
.83184 .36144 Mdot
.50077 .617 Mdot
.50244 .61474 Mdot
.50777 .60754 Mdot
.52475 .58469 Mdot
.5787 .51467 Mdot
.74595 .36717 Mdot
.15185 .48754 Mdot
.363 .59943 Mdot
.3931 .07322 Mdot
.27462 .219 Mdot
.92027 .14814 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50588 .6101 Mdot
.51872 .59278 Mdot
.55958 .53883 Mdot
.68774 .40243 Mdot
.03659 .43605 Mdot
.33104 .56488 Mdot
.41704 .02031 Mdot
.38418 .11846 Mdot
.1925 .25648 Mdot
.50042 .61746 Mdot
.50135 .61622 Mdot
.50429 .61224 Mdot
.51367 .59959 Mdot
.54351 .55975 Mdot
.63782 .44736 Mdot
.91398 .37144 Mdot
.31298 .50758 Mdot
.49169 .51529 Mdot
.65793 .39175 Mdot
.02407 .41398 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50839 .6067 Mdot
.52672 .58204 Mdot
.58496 .50697 Mdot
.76466 .36005 Mdot
.18209 .49437 Mdot
.38219 .59388 Mdot
.42127 .0459 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54176 .56206 Mdot
.63233 .45304 Mdot
.89929 .36579 Mdot
.30744 .50383 Mdot
.49223 .51102 Mdot
.66538 .38385 Mdot
.0443 .42439 Mdot
.35763 .53946 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00495 Mdot
.48833 .01576 Mdot
.46283 .0499 Mdot
.38209 .14949 Mdot
.14021 .2633 Mdot
.71419 .11947 Mdot
.52088 .10017 Mdot
.3588 .21456 Mdot
.01164 .22534 Mdot
.64703 .10761 Mdot
.50071 .61708 Mdot
.50226 .61498 Mdot
.5072 .60831 Mdot
.52293 .58712 Mdot
.57294 .52185 Mdot
.72858 .37563 Mdot
.12079 .47717 Mdot
.34871 .59723 Mdot
.38237 .07858 Mdot
.25522 .22605 Mdot
.88947 .13162 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00531 Mdot
.48749 .01689 Mdot
.46015 .05345 Mdot
.37367 .15865 Mdot
.11696 .25758 Mdot
.70019 .11721 Mdot
.51054 .10744 Mdot
.33671 .23362 Mdot
.9587 .19576 Mdot
.64195 .08093 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00697 Mdot
.48356 .02218 Mdot
.44768 .06982 Mdot
.33471 .19695 Mdot
.01604 .2118 Mdot
.67335 .08103 Mdot
.54223 .04234 Mdot
.47373 .06658 Mdot
.36599 .17665 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61025 Mdot
.51835 .59328 Mdot
.5584 .54034 Mdot
.68411 .40526 Mdot
.02838 .43143 Mdot
.33031 .56059 Mdot
.42325 .01098 Mdot
.40548 .09354 Mdot
.50056 .61727 Mdot
.50179 .61561 Mdot
.50571 .61033 Mdot
.51818 .59351 Mdot
.55786 .54105 Mdot
.68242 .4066 Mdot
.02452 .42925 Mdot
.32998 .55855 Mdot
.42623 .00648 Mdot
.41574 .081 Mdot
.28468 .22505 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00335 Mdot
.49211 .01066 Mdot
.47486 .03386 Mdot
.42007 .10488 Mdot
.25037 .25243 Mdot
.84193 .12882 Mdot
.6335 .01907 Mdot
.60264 .54842 Mdot
.71528 .40437 Mdot
.061 .45954 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49035 .01303 Mdot
.46926 .04136 Mdot
.40234 .12631 Mdot
.19797 .26604 Mdot
.7675 .11939 Mdot
.57433 .05296 Mdot
.48863 .06349 Mdot
.3859 .16044 Mdot
.1263 .26562 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .00239 Mdot
.49436 .00762 Mdot
.48203 .02424 Mdot
.44282 .07612 Mdot
.31965 .20976 Mdot
.98026 .1915 Mdot
.6704 .06203 Mdot
.57003 .61721 Mdot
.57136 .55326 Mdot
.67617 .4213 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00387 Mdot
.49087 .01234 Mdot
.47091 .03916 Mdot
.40755 .12012 Mdot
.21318 .26374 Mdot
.78644 .12005 Mdot
.59221 .03927 Mdot
.52867 .01284 Mdot
.5079 .00552 Mdot
.49896 .00648 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49581 .00567 Mdot
.48664 .01804 Mdot
.45745 .05702 Mdot
.36519 .16758 Mdot
.09404 .24977 Mdot
.6899 .11262 Mdot
.50767 .10552 Mdot
.33693 .2316 Mdot
.9622 .19688 Mdot
.50016 .61782 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61117 Mdot
.51619 .59619 Mdot
.55153 .54925 Mdot
.66281 .4233 Mdot
.9779 .40288 Mdot
.32603 .5339 Mdot
.46215 .56866 Mdot
.54205 .53013 Mdot
.50119 .61642 Mdot
.5038 .6129 Mdot
.5121 .6017 Mdot
.53853 .56633 Mdot
.6222 .46385 Mdot
.87167 .35736 Mdot
.29345 .49944 Mdot
.48534 .51302 Mdot
.65526 .39085 Mdot
.02285 .41196 Mdot
.35628 .52781 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48932 .01442 Mdot
.46599 .04571 Mdot
.39203 .1383 Mdot
.16825 .26681 Mdot
.73654 .11979 Mdot
.54272 .08066 Mdot
.41221 .15798 Mdot
.15659 .28083 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48837 .0157 Mdot
.46297 .04972 Mdot
.38252 .14901 Mdot
.14142 .26353 Mdot
.71503 .11953 Mdot
.52162 .09955 Mdot
.36055 .21291 Mdot
.01605 .22776 Mdot
.64752 .10976 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00464 Mdot
.48907 .01476 Mdot
.46518 .04678 Mdot
.38949 .14119 Mdot
.16104 .26628 Mdot
.73019 .11988 Mdot
.53622 .08659 Mdot
.39612 .1762 Mdot
.11102 .27098 Mdot
.67258 .14055 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00444 Mdot
.48953 .01413 Mdot
.46667 .04481 Mdot
.39417 .13585 Mdot
.17436 .26704 Mdot
.74228 .11967 Mdot
.54865 .07527 Mdot
.42687 .1407 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00223 Mdot
.49474 .0071 Mdot
.48325 .0226 Mdot
.44667 .07112 Mdot
.3316 .1997 Mdot
.00848 .20755 Mdot
.67265 .07709 Mdot
.54791 .03335 Mdot
.49395 .03895 Mdot
.43093 .10099 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50775 .60756 Mdot
.52469 .58476 Mdot
.57853 .51488 Mdot
.74543 .3674 Mdot
.15097 .48729 Mdot
.36252 .59947 Mdot
.39255 .07365 Mdot
.27338 .21961 Mdot
.91805 .14695 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00222 Mdot
.49475 .00709 Mdot
.48329 .02255 Mdot
.44679 .07097 Mdot
.33197 .19937 Mdot
.00937 .20806 Mdot
.67273 .07756 Mdot
.54723 .03442 Mdot
.49153 .04227 Mdot
.42315 .11078 Mdot
.50064 .61716 Mdot
.50205 .61526 Mdot
.50655 .60919 Mdot
.52086 .58991 Mdot
.56636 .53016 Mdot
.70855 .38759 Mdot
.08143 .45982 Mdot
.33742 .58566 Mdot
.38979 .06183 Mdot
.28976 .20479 Mdot
.9584 .16666 Mdot
.50038 .61751 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51245 .60123 Mdot
.53964 .56486 Mdot
.62568 .46009 Mdot
.88124 .35993 Mdot
.29886 .50057 Mdot
.48892 .51083 Mdot
.66238 .38509 Mdot
.0393 .42115 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49347 .00882 Mdot
.4792 .02805 Mdot
.43382 .08764 Mdot
.29202 .23008 Mdot
.91975 .15879 Mdot
.66282 .03283 Mdot
.6097 .55703 Mdot
.7084 .4145 Mdot
.03773 .44915 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49846 .00208 Mdot
.49509 .00663 Mdot
.48437 .0211 Mdot
.45023 .06648 Mdot
.34266 .18972 Mdot
.03569 .22253 Mdot
.67563 .0908 Mdot
.52871 .06433 Mdot
.42462 .13163 Mdot
.21163 .27491 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50476 .6116 Mdot
.51518 .59755 Mdot
.54832 .55343 Mdot
.65285 .43254 Mdot
.95299 .38959 Mdot
.32263 .52203 Mdot
.47796 .5424 Mdot
.60033 .45543 Mdot
.86343 .3438 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51016 .60431 Mdot
.53237 .57451 Mdot
.60279 .48571 Mdot
.8169 .35101 Mdot
.24896 .49855 Mdot
.44229 .55088 Mdot
.55095 .50445 Mdot
.73473 .35758 Mdot
.15615 .48021 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.47621 .03207 Mdot
.42432 .09961 Mdot
.26315 .24665 Mdot
.86407 .1354 Mdot
.64498 .01883 Mdot
.61451 .53964 Mdot
.74135 .39231 Mdot
.10658 .4839 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01782 Mdot
.45796 .05634 Mdot
.3668 .1659 Mdot
.09836 .2514 Mdot
.6916 .11368 Mdot
.50766 .10657 Mdot
.33523 .23346 Mdot
.95747 .19451 Mdot
.64275 .07921 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.49671 .00445 Mdot
.4895 .01418 Mdot
.46656 .04494 Mdot
.39384 .13622 Mdot
.17343 .26702 Mdot
.74139 .11969 Mdot
.54772 .07611 Mdot
.42458 .14344 Mdot
.19249 .28146 Mdot
.73709 .1344 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00382 Mdot
.491 .01215 Mdot
.47134 .03858 Mdot
.40892 .11848 Mdot
.21721 .26291 Mdot
.79182 .12043 Mdot
.59697 .03599 Mdot
.53874 .00043 Mdot
.53804 .58353 Mdot
.59387 .50146 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00553 Mdot
.48697 .01759 Mdot
.4585 .05563 Mdot
.36848 .16415 Mdot
.10289 .25302 Mdot
.69349 .11468 Mdot
.50793 .10733 Mdot
.33426 .23468 Mdot
.95454 .19311 Mdot
.64209 .0782 Mdot
.50098 .61672 Mdot
.50311 .61383 Mdot
.5099 .60466 Mdot
.53155 .57561 Mdot
.60019 .48874 Mdot
.8094 .35135 Mdot
.24091 .49865 Mdot
.43407 .55804 Mdot
.53114 .52936 Mdot
.67462 .39805 Mdot
.03056 .42621 Mdot
.50085 .61689 Mdot
.5027 .61439 Mdot
.5086 .60642 Mdot
.52738 .58117 Mdot
.58703 .50444 Mdot
.77083 .35816 Mdot
.19131 .49579 Mdot
.38911 .59047 Mdot
.43371 .03213 Mdot
.38173 .13195 Mdot
.16822 .26045 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00565 Mdot
.48668 .01798 Mdot
.45759 .05683 Mdot
.36564 .16711 Mdot
.09525 .25024 Mdot
.69036 .11293 Mdot
.50764 .10585 Mdot
.33637 .23219 Mdot
.96068 .19611 Mdot
.64337 .08046 Mdot
.50045 .61742 Mdot
.50145 .61608 Mdot
.50462 .6118 Mdot
.5147 .59819 Mdot
.54682 .5554 Mdot
.64816 .43705 Mdot
.94099 .38359 Mdot
.32033 .51697 Mdot
.48386 .53191 Mdot
.62322 .42875 Mdot
.92948 .36549 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49486 .00695 Mdot
.48361 .02212 Mdot
.44782 .06963 Mdot
.33516 .19655 Mdot
.01714 .21241 Mdot
.67346 .0816 Mdot
.54143 .04363 Mdot
.47084 .07051 Mdot
.35675 .18609 Mdot
.50098 .61671 Mdot
.50312 .61381 Mdot
.50995 .6046 Mdot
.53169 .57541 Mdot
.60066 .48819 Mdot
.81075 .35126 Mdot
.2424 .49864 Mdot
.43558 .55675 Mdot
.53474 .52479 Mdot
.68562 .38916 Mdot
.05595 .43996 Mdot
.50034 .61757 Mdot
.50109 .61655 Mdot
.50349 .61332 Mdot
.51111 .60303 Mdot
.53539 .57049 Mdot
.61232 .47479 Mdot
.8441 .35229 Mdot
.27408 .49815 Mdot
.46806 .52756 Mdot
.61445 .43038 Mdot
.91808 .35774 Mdot
.50027 .61766 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.52831 .57993 Mdot
.58996 .5009 Mdot
.77949 .35588 Mdot
.20367 .49722 Mdot
.39915 .58457 Mdot
.45329 .00922 Mdot
.43838 .06493 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00325 Mdot
.49233 .01036 Mdot
.47558 .03291 Mdot
.42233 .10209 Mdot
.25714 .24949 Mdot
.85345 .13203 Mdot
.63982 .01845 Mdot
.60996 .54247 Mdot
.73223 .39584 Mdot
.09174 .47626 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49212 .01064 Mdot
.4749 .03381 Mdot
.42019 .10474 Mdot
.25073 .25228 Mdot
.84253 .12898 Mdot
.63385 .01901 Mdot
.60308 .54803 Mdot
.71636 .40377 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00636 Mdot
.485 .02025 Mdot
.45224 .06386 Mdot
.34892 .18381 Mdot
.05151 .23073 Mdot
.67818 .09796 Mdot
.51968 .07976 Mdot
.39062 .17336 Mdot
.11011 .26749 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.50849 .60657 Mdot
.52705 .58161 Mdot
.58598 .50572 Mdot
.76771 .35909 Mdot
.18669 .49511 Mdot
.38558 .59228 Mdot
.42724 .03937 Mdot
.36353 .15094 Mdot
.1193 .25147 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51103 .60314 Mdot
.53514 .57082 Mdot
.61153 .47569 Mdot
.84185 .35204 Mdot
.27224 .49815 Mdot
.46622 .52923 Mdot
.60992 .43524 Mdot
.90569 .35283 Mdot
.33479 .47993 Mdot
.50044 .61744 Mdot
.50139 .61615 Mdot
.50443 .61204 Mdot
.51413 .59896 Mdot
.54498 .55781 Mdot
.64242 .44271 Mdot
.9261 .37664 Mdot
.31669 .51142 Mdot
.4892 .52143 Mdot
.64551 .40455 Mdot
.99093 .39615 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50484 .6115 Mdot
.51542 .59723 Mdot
.54909 .55244 Mdot
.65522 .43029 Mdot
.95899 .3927 Mdot
.3236 .52475 Mdot
.47454 .54825 Mdot
.58746 .47118 Mdot
.82507 .33975 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.51589 .59658 Mdot
.5506 .55046 Mdot
.65994 .42592 Mdot
.97079 .39899 Mdot
.32521 .53036 Mdot
.46707 .56068 Mdot
.55987 .50647 Mdot
.50024 .6177 Mdot
.50078 .61698 Mdot
.50249 .61468 Mdot
.50792 .60734 Mdot
.52523 .58405 Mdot
.58022 .51279 Mdot
.7505 .36525 Mdot
.15951 .48958 Mdot
.36735 .5988 Mdot
.39846 .06864 Mdot
.2874 .21213 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54179 .56202 Mdot
.63243 .45293 Mdot
.89957 .36588 Mdot
.30755 .50389 Mdot
.49225 .51107 Mdot
.66532 .38392 Mdot
.04412 .4243 Mdot
.35759 .5394 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.5259 .58315 Mdot
.58235 .51016 Mdot
.75689 .36276 Mdot
.16994 .49202 Mdot
.37383 .59712 Mdot
.40767 .05996 Mdot
.31065 .19692 Mdot
.99203 .18953 Mdot
.49986 .00018 Mdot
.49956 .00059 Mdot
.49861 .00187 Mdot
.49558 .00597 Mdot
.48592 .019 Mdot
.45517 .06002 Mdot
.35806 .17484 Mdot
.07517 .24196 Mdot
.68367 .10705 Mdot
.51046 .09736 Mdot
.35294 .2151 Mdot
.00489 .21964 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60842 Mdot
.52266 .58748 Mdot
.57209 .52291 Mdot
.726 .37704 Mdot
.11594 .47527 Mdot
.34694 .59628 Mdot
.38215 .07778 Mdot
.2563 .22521 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51017 .6043 Mdot
.53239 .57449 Mdot
.60285 .48564 Mdot
.81707 .351 Mdot
.24913 .49854 Mdot
.44247 .55072 Mdot
.55138 .50391 Mdot
.73603 .35694 Mdot
.1585 .48076 Mdot
.50036 .61754 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.51171 .60223 Mdot
.53728 .56798 Mdot
.61828 .46814 Mdot
.86081 .35494 Mdot
.28651 .49862 Mdot
.47973 .51736 Mdot
.64262 .40214 Mdot
.99194 .39467 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49516 .00654 Mdot
.48458 .02081 Mdot
.4509 .06561 Mdot
.34475 .18777 Mdot
.04093 .2253 Mdot
.67639 .09325 Mdot
.5255 .06971 Mdot
.4127 .14664 Mdot
.17543 .27829 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.50578 .61022 Mdot
.51842 .59318 Mdot
.55864 .54004 Mdot
.68483 .40469 Mdot
.03003 .43237 Mdot
.33045 .56146 Mdot
.42199 .01289 Mdot
.40113 .09876 Mdot
.24133 .24609 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46216 .05079 Mdot
.37998 .15181 Mdot
.13435 .26208 Mdot
.71029 .11911 Mdot
.51757 .10285 Mdot
.35116 .22158 Mdot
.99264 .21476 Mdot
.64516 .09809 Mdot
.50035 .61756 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51127 .60281 Mdot
.5359 .56981 Mdot
.61393 .47298 Mdot
.84864 .35288 Mdot
.27768 .49819 Mdot
.47158 .5244 Mdot
.62308 .42134 Mdot
.94134 .36818 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.504 .61263 Mdot
.51274 .60084 Mdot
.54057 .56363 Mdot
.62859 .45698 Mdot
.88919 .36235 Mdot
.30289 .50182 Mdot
.49093 .51022 Mdot
.66538 .38304 Mdot
.04561 .42475 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00341 Mdot
.49195 .01087 Mdot
.47436 .03454 Mdot
.41847 .10686 Mdot
.24557 .25435 Mdot
.83403 .12689 Mdot
.62871 .02016 Mdot
.5961 .55442 Mdot
.69903 .41437 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49737 .00355 Mdot
.49162 .01132 Mdot
.47331 .03594 Mdot
.41516 .11092 Mdot
.23569 .25787 Mdot
.81845 .12376 Mdot
.6182 .02398 Mdot
.5794 .57142 Mdot
.65482 .44948 Mdot
.92755 .38461 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.4866 .01809 Mdot
.45732 .05719 Mdot
.36479 .16799 Mdot
.09297 .24936 Mdot
.68949 .11235 Mdot
.5077 .10521 Mdot
.33747 .23103 Mdot
.96365 .19763 Mdot
.64389 .08168 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01653 Mdot
.46101 .05232 Mdot
.37635 .15576 Mdot
.12432 .25965 Mdot
.7042 .11817 Mdot
.51301 .10612 Mdot
.34129 .23005 Mdot
.96906 .20155 Mdot
.64294 .08614 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49169 .01123 Mdot
.47352 .03566 Mdot
.41581 .11012 Mdot
.23763 .25722 Mdot
.82144 .12429 Mdot
.62033 .02307 Mdot
.583 .5676 Mdot
.66461 .44078 Mdot
.95141 .39644 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50755 .60784 Mdot
.52405 .58563 Mdot
.57648 .51743 Mdot
.73927 .37022 Mdot
.14025 .48405 Mdot
.35704 .59946 Mdot
.3871 .07753 Mdot
.26165 .22468 Mdot
.89811 .13654 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50476 .61161 Mdot
.51516 .59757 Mdot
.54827 .55351 Mdot
.65267 .4327 Mdot
.95255 .38936 Mdot
.32255 .52184 Mdot
.4782 .54199 Mdot
.60124 .45434 Mdot
.86611 .34434 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49272 .00984 Mdot
.4768 .03127 Mdot
.42621 .09725 Mdot
.26887 .24376 Mdot
.87446 .13907 Mdot
.64944 .02001 Mdot
.61705 .53906 Mdot
.74484 .39159 Mdot
.11124 .48652 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .0025 Mdot
.49411 .00796 Mdot
.48123 .02532 Mdot
.44026 .07942 Mdot
.31176 .21599 Mdot
.96227 .18134 Mdot
.66885 .05257 Mdot
.5838 .59645 Mdot
.61872 .49632 Mdot
.81565 .36115 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00438 Mdot
.48966 .01396 Mdot
.46707 .04427 Mdot
.39543 .13439 Mdot
.17799 .26709 Mdot
.74583 .11959 Mdot
.55233 .07195 Mdot
.43591 .12977 Mdot
.22595 .27563 Mdot
.77997 .13069 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51337 .59998 Mdot
.54258 .56097 Mdot
.63491 .45035 Mdot
.90622 .36836 Mdot
.3102 .50548 Mdot
.49233 .51259 Mdot
.66294 .38657 Mdot
.03746 .42097 Mdot
.3563 .53681 Mdot
.50045 .61742 Mdot
.50145 .61608 Mdot
.50461 .61181 Mdot
.51468 .59823 Mdot
.54673 .55553 Mdot
.64786 .43734 Mdot
.94023 .38323 Mdot
.32016 .51666 Mdot
.48418 .5313 Mdot
.62452 .42729 Mdot
.93316 .36713 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61118 Mdot
.51617 .59621 Mdot
.55148 .54931 Mdot
.66268 .42342 Mdot
.97758 .4027 Mdot
.32599 .53374 Mdot
.46238 .56829 Mdot
.54286 .52904 Mdot
.68686 .39296 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00424 Mdot
.48999 .01352 Mdot
.46812 .04288 Mdot
.39874 .13054 Mdot
.18752 .26686 Mdot
.75573 .11941 Mdot
.56252 .06294 Mdot
.46068 .09902 Mdot
.30046 .23921 Mdot
.91341 .16284 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49179 .01109 Mdot
.47384 .03523 Mdot
.41684 .10887 Mdot
.24068 .25616 Mdot
.8262 .12521 Mdot
.62361 .02179 Mdot
.58835 .56206 Mdot
.67892 .42899 Mdot
.9848 .41492 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00598 Mdot
.48589 .01905 Mdot
.45507 .06015 Mdot
.35775 .17515 Mdot
.07434 .24159 Mdot
.68344 .10677 Mdot
.51068 .09687 Mdot
.35394 .21405 Mdot
.0076 .22109 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49667 .0045 Mdot
.48939 .01433 Mdot
.46621 .04542 Mdot
.39271 .13752 Mdot
.17019 .2669 Mdot
.73833 .11975 Mdot
.54456 .07898 Mdot
.41677 .15267 Mdot
.16975 .28185 Mdot
.71371 .13812 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00908 Mdot
.47858 .02888 Mdot
.43185 .09014 Mdot
.286 .23393 Mdot
.90749 .15292 Mdot
.66007 .02831 Mdot
.61426 .54929 Mdot
.72549 .40349 Mdot
.07264 .46851 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.505 .61129 Mdot
.51591 .59656 Mdot
.55067 .55038 Mdot
.66014 .42573 Mdot
.97129 .39926 Mdot
.32527 .53061 Mdot
.46673 .56123 Mdot
.55865 .50808 Mdot
.4996 .00054 Mdot
.49872 .00174 Mdot
.49591 .00553 Mdot
.48696 .01761 Mdot
.45847 .05567 Mdot
.36838 .16425 Mdot
.10262 .25293 Mdot
.69337 .11462 Mdot
.50791 .1073 Mdot
.33429 .23463 Mdot
.95466 .19316 Mdot
.64212 .07823 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49063 .01265 Mdot
.47016 .04015 Mdot
.40521 .12292 Mdot
.20631 .26494 Mdot
.77763 .11962 Mdot
.58408 .04524 Mdot
.51088 .03516 Mdot
.45398 .07723 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00352 Mdot
.4917 .01121 Mdot
.47357 .03559 Mdot
.41599 .10991 Mdot
.23815 .25705 Mdot
.82224 .12444 Mdot
.62089 .02284 Mdot
.58394 .56662 Mdot
.66713 .43862 Mdot
.95742 .39962 Mdot
.50113 .61651 Mdot
.5036 .61316 Mdot
.51148 .60253 Mdot
.53657 .56892 Mdot
.61604 .47063 Mdot
.85454 .35379 Mdot
.2821 .49834 Mdot
.47577 .52071 Mdot
.63324 .41112 Mdot
.96803 .38168 Mdot
.35045 .5008 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48857 .01543 Mdot
.4636 .04888 Mdot
.38451 .1468 Mdot
.14699 .2645 Mdot
.71902 .11974 Mdot
.52527 .09641 Mdot
.36927 .20443 Mdot
.0385 .23977 Mdot
.50128 .6163 Mdot
.50409 .6125 Mdot
.51304 .60043 Mdot
.54153 .56237 Mdot
.63159 .45381 Mdot
.89732 .36508 Mdot
.3066 .5034 Mdot
.49209 .51073 Mdot
.66571 .38339 Mdot
.04537 .42489 Mdot
.35789 .53981 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45742 .05706 Mdot
.3651 .16767 Mdot
.09381 .24968 Mdot
.68981 .11257 Mdot
.50767 .10546 Mdot
.33704 .23148 Mdot
.9625 .19704 Mdot
.64369 .0812 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.53641 .56913 Mdot
.61553 .47119 Mdot
.85313 .35355 Mdot
.28107 .4983 Mdot
.47481 .52155 Mdot
.63092 .41342 Mdot
.962 .37852 Mdot
.34954 .49814 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00203 Mdot
.4952 .00648 Mdot
.48472 .02062 Mdot
.45135 .06503 Mdot
.34613 .18647 Mdot
.04442 .22712 Mdot
.67694 .09485 Mdot
.52348 .07316 Mdot
.4051 .15601 Mdot
.15267 .27682 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60736 Mdot
.52516 .58413 Mdot
.58002 .51304 Mdot
.74991 .36549 Mdot
.15853 .48933 Mdot
.36678 .59891 Mdot
.39771 .06931 Mdot
.28557 .21318 Mdot
.94063 .15941 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.47621 .03206 Mdot
.42435 .09958 Mdot
.26323 .24661 Mdot
.8642 .13545 Mdot
.64504 .01884 Mdot
.61455 .53962 Mdot
.74143 .39229 Mdot
.10669 .48395 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00287 Mdot
.49322 .00916 Mdot
.4784 .02912 Mdot
.43129 .09086 Mdot
.28428 .23499 Mdot
.90405 .15133 Mdot
.65919 .02716 Mdot
.61523 .54746 Mdot
.72942 .40115 Mdot
.08035 .47251 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46507 .04694 Mdot
.38912 .14161 Mdot
.15999 .26618 Mdot
.7293 .11988 Mdot
.53533 .0874 Mdot
.3939 .17864 Mdot
.10486 .26897 Mdot
.66966 .13982 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51094 .60327 Mdot
.53483 .57124 Mdot
.61055 .4768 Mdot
.83908 .35176 Mdot
.26991 .49815 Mdot
.46388 .53135 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.4663 .0453 Mdot
.393 .13719 Mdot
.17103 .26694 Mdot
.73911 .11974 Mdot
.54537 .07824 Mdot
.41877 .15032 Mdot
.17554 .28201 Mdot
.71923 .13722 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.4933 .00905 Mdot
.47866 .02877 Mdot
.4321 .08982 Mdot
.28676 .23345 Mdot
.90903 .15364 Mdot
.66044 .02884 Mdot
.61378 .55015 Mdot
.72361 .40463 Mdot
.0689 .46653 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00286 Mdot
.49324 .00913 Mdot
.47848 .02902 Mdot
.43152 .09056 Mdot
.285 .23455 Mdot
.90548 .15199 Mdot
.65956 .02763 Mdot
.61485 .5482 Mdot
.72784 .40209 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50872 .60626 Mdot
.52776 .58065 Mdot
.58825 .50297 Mdot
.77442 .35716 Mdot
.19652 .49645 Mdot
.39324 .58817 Mdot
.44156 .0231 Mdot
.40418 .10666 Mdot
.23159 .25322 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51288 .60064 Mdot
.54102 .56303 Mdot
.63001 .45547 Mdot
.89305 .36362 Mdot
.30471 .50253 Mdot
.4916 .51032 Mdot
.66589 .3829 Mdot
.04634 .42525 Mdot
.35826 .53996 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00506 Mdot
.48806 .01612 Mdot
.46197 .05104 Mdot
.37938 .15246 Mdot
.1327 .26171 Mdot
.70924 .11898 Mdot
.51673 .1035 Mdot
.34926 .22327 Mdot
.988 .21216 Mdot
.64472 .09573 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01505 Mdot
.4645 .04769 Mdot
.38735 .14362 Mdot
.15497 .26563 Mdot
.72517 .11988 Mdot
.5312 .09114 Mdot
.38373 .18959 Mdot
.07696 .25819 Mdot
.6592 .13402 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50587 .6101 Mdot
.51871 .5928 Mdot
.55955 .53887 Mdot
.68763 .40251 Mdot
.03636 .43592 Mdot
.33102 .56476 Mdot
.41722 .02006 Mdot
.38476 .11779 Mdot
.19417 .25635 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60972 Mdot
.5196 .5916 Mdot
.56237 .53525 Mdot
.69631 .39603 Mdot
.05553 .44646 Mdot
.33313 .57433 Mdot
.40384 .04011 Mdot
.33894 .16521 Mdot
.07162 .22939 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .0024 Mdot
.49435 .00764 Mdot
.48199 .0243 Mdot
.44267 .07631 Mdot
.3192 .21013 Mdot
.97921 .19091 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .0156 Mdot
.46319 .04942 Mdot
.38323 .14822 Mdot
.1434 .26389 Mdot
.71642 .11962 Mdot
.52287 .09849 Mdot
.36352 .21006 Mdot
.02363 .23189 Mdot
.64842 .11339 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00197 Mdot
.49536 .00627 Mdot
.48521 .01996 Mdot
.45292 .06297 Mdot
.35102 .18178 Mdot
.0569 .23341 Mdot
.67923 .10021 Mdot
.51708 .08441 Mdot
.38051 .18507 Mdot
.08106 .25701 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.50099 .61669 Mdot
.50317 .61376 Mdot
.51009 .60441 Mdot
.53213 .57483 Mdot
.60203 .48659 Mdot
.8147 .35107 Mdot
.24665 .49859 Mdot
.43992 .55297 Mdot
.5452 .51162 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61545 Mdot
.5061 .60979 Mdot
.51944 .59181 Mdot
.56188 .53588 Mdot
.69481 .39711 Mdot
.05227 .4447 Mdot
.33272 .57276 Mdot
.40598 .03691 Mdot
.34626 .15828 Mdot
.50054 .6173 Mdot
.50172 .61571 Mdot
.50548 .61063 Mdot
.51747 .59446 Mdot
.55562 .54394 Mdot
.67549 .41227 Mdot
.00842 .42008 Mdot
.32872 .54994 Mdot
.4389 .6052 Mdot
.45967 .02415 Mdot
.4206 .09475 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .00179 Mdot
.49577 .00571 Mdot
.48653 .01818 Mdot
.45711 .05747 Mdot
.36412 .16868 Mdot
.09119 .24867 Mdot
.68883 .11188 Mdot
.5078 .10465 Mdot
.33847 .22999 Mdot
.96634 .19902 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60553 Mdot
.52948 .57836 Mdot
.59367 .49645 Mdot
.79039 .35363 Mdot
.21819 .49824 Mdot
.41202 .57571 Mdot
.48049 .59375 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56446 Mdot
.62662 .45907 Mdot
.88383 .36069 Mdot
.30023 .50095 Mdot
.48968 .51051 Mdot
.66365 .38415 Mdot
.04208 .42271 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.4678 .04331 Mdot
.39772 .13173 Mdot
.18458 .26698 Mdot
.75259 .11946 Mdot
.5593 .06574 Mdot
.45293 .10875 Mdot
.27696 .25418 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50423 .61232 Mdot
.51346 .59986 Mdot
.54287 .56059 Mdot
.63582 .44941 Mdot
.90866 .36931 Mdot
.31111 .50611 Mdot
.49221 .51333 Mdot
.66163 .38795 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49841 .00215 Mdot
.49492 .00686 Mdot
.48383 .02182 Mdot
.44852 .06872 Mdot
.33734 .1946 Mdot
.02247 .21536 Mdot
.67401 .08432 Mdot
.53758 .0498 Mdot
.457 .08918 Mdot
.31271 .22541 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49726 .0037 Mdot
.49128 .01178 Mdot
.47221 .03741 Mdot
.41168 .11515 Mdot
.22535 .26093 Mdot
.80316 .12154 Mdot
.6065 .03002 Mdot
.55793 .59552 Mdot
.59435 .51309 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49434 .00765 Mdot
.48197 .02432 Mdot
.44261 .07638 Mdot
.31903 .21026 Mdot
.97883 .19069 Mdot
.67029 .06127 Mdot
.57115 .61551 Mdot
.57523 .54834 Mdot
.688 .41185 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00529 Mdot
.48753 .01683 Mdot
.4603 .05325 Mdot
.37414 .15814 Mdot
.11826 .25796 Mdot
.70087 .11739 Mdot
.51092 .10727 Mdot
.33735 .23315 Mdot
.96011 .19655 Mdot
.64208 .08165 Mdot
.49975 .00033 Mdot
.49922 .00106 Mdot
.49751 .00337 Mdot
.49205 .01074 Mdot
.47468 .03411 Mdot
.41949 .1056 Mdot
.24863 .25314 Mdot
.83905 .12809 Mdot
.63179 .0194 Mdot
.6004 .55042 Mdot
.70981 .40755 Mdot
.05038 .45348 Mdot
.49971 .0004 Mdot
.49906 .00126 Mdot
.49702 .00403 Mdot
.49051 .01282 Mdot
.46976 .04068 Mdot
.40393 .12443 Mdot
.20259 .26548 Mdot
.77304 .11948 Mdot
.57971 .04863 Mdot
.50102 .04768 Mdot
.42387 .1156 Mdot
.23683 .26264 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50992 .60464 Mdot
.53158 .57556 Mdot
.60031 .4886 Mdot
.80974 .35133 Mdot
.24128 .49865 Mdot
.43444 .55772 Mdot
.53203 .52822 Mdot
.67735 .39579 Mdot
.03696 .42974 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00328 Mdot
.49227 .01044 Mdot
.47538 .03317 Mdot
.42172 .10285 Mdot
.2553 .25031 Mdot
.85028 .1311 Mdot
.63815 .01851 Mdot
.6082 .54379 Mdot
.72832 .39762 Mdot
.08497 .47269 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49262 .00996 Mdot
.4765 .03167 Mdot
.42527 .09843 Mdot
.266 .24523 Mdot
.86921 .13717 Mdot
.64726 .01932 Mdot
.61599 .53909 Mdot
.74372 .39166 Mdot
.10999 .48571 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00467 Mdot
.48899 .01486 Mdot
.46495 .0471 Mdot
.38874 .14204 Mdot
.15892 .26608 Mdot
.7284 .11989 Mdot
.53442 .08823 Mdot
.39166 .18109 Mdot
.09865 .2668 Mdot
.66696 .13888 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.50761 .60776 Mdot
.52423 .58538 Mdot
.57707 .5167 Mdot
.74103 .36939 Mdot
.14336 .48503 Mdot
.35856 .59956 Mdot
.38846 .07667 Mdot
.26441 .22361 Mdot
.9026 .13885 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49526 .0064 Mdot
.4849 .02038 Mdot
.45193 .06426 Mdot
.34796 .18473 Mdot
.04906 .22949 Mdot
.67773 .0969 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49242 .01023 Mdot
.47587 .03252 Mdot
.42325 .10094 Mdot
.25993 .2482 Mdot
.85834 .13354 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.5025 .61465 Mdot
.50797 .60726 Mdot
.5254 .58382 Mdot
.58077 .51211 Mdot
.75215 .36458 Mdot
.16225 .49026 Mdot
.36899 .59846 Mdot
.40066 .06665 Mdot
.29282 .20889 Mdot
.50056 .61727 Mdot
.50179 .61561 Mdot
.50571 .61032 Mdot
.51819 .59349 Mdot
.5579 .541 Mdot
.68255 .4065 Mdot
.02481 .42941 Mdot
.33001 .5587 Mdot
.42601 .00682 Mdot
.41497 .08195 Mdot
.28238 .22645 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47146 .03841 Mdot
.40931 .11802 Mdot
.21835 .26265 Mdot
.79337 .12055 Mdot
.59831 .0351 Mdot
.54152 .61507 Mdot
.54632 .57274 Mdot
.6196 .47201 Mdot
.50122 .61639 Mdot
.50389 .61278 Mdot
.51239 .60131 Mdot
.53945 .56511 Mdot
.62507 .46074 Mdot
.87958 .35945 Mdot
.29797 .50035 Mdot
.48839 .5111 Mdot
.66142 .38582 Mdot
.03715 .41995 Mdot
.35766 .535 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48713 .01737 Mdot
.45903 .05494 Mdot
.37014 .16241 Mdot
.10736 .25455 Mdot
.69548 .11558 Mdot
.50846 .10774 Mdot
.33414 .23514 Mdot
.95367 .1928 Mdot
.64172 .0781 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .00561 Mdot
.48677 .01786 Mdot
.45788 .05645 Mdot
.36653 .16618 Mdot
.09764 .25113 Mdot
.6913 .11351 Mdot
.50765 .10642 Mdot
.33546 .2332 Mdot
.95813 .19483 Mdot
.64289 .07946 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50872 .60625 Mdot
.52779 .58062 Mdot
.58831 .50289 Mdot
.77462 .35711 Mdot
.19681 .49649 Mdot
.39347 .58803 Mdot
.44201 .02257 Mdot
.40549 .10513 Mdot
.23538 .25205 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49802 .00267 Mdot
.4937 .00852 Mdot
.47992 .02709 Mdot
.43609 .08476 Mdot
.29895 .22538 Mdot
.93427 .16617 Mdot
.66541 .03897 Mdot
.60235 .56853 Mdot
.68245 .43407 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48933 .01441 Mdot
.46601 .04568 Mdot
.39209 .13823 Mdot
.16844 .26682 Mdot
.73672 .11979 Mdot
.5429 .0805 Mdot
.41265 .15747 Mdot
.15787 .28097 Mdot
.50033 .61758 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60341 Mdot
.53449 .57168 Mdot
.60949 .478 Mdot
.83606 .35151 Mdot
.26731 .49818 Mdot
.46123 .53377 Mdot
.59758 .44887 Mdot
.8713 .34214 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49394 .00818 Mdot
.4807 .02603 Mdot
.43858 .08156 Mdot
.30661 .21987 Mdot
.95085 .17503 Mdot
.66765 .0468 Mdot
.59192 .58428 Mdot
.64654 .46683 Mdot
.8912 .37364 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39525 .1346 Mdot
.17747 .26708 Mdot
.74532 .1196 Mdot
.5518 .07243 Mdot
.43461 .13136 Mdot
.22207 .27664 Mdot
.77446 .13083 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.5409 .5632 Mdot
.62962 .45589 Mdot
.89198 .36326 Mdot
.30421 .50233 Mdot
.49143 .51026 Mdot
.66581 .38289 Mdot
.04629 .42519 Mdot
.35831 .53987 Mdot
.49986 .00018 Mdot
.49957 .00059 Mdot
.49862 .00186 Mdot
.4956 .00594 Mdot
.48599 .01891 Mdot
.4554 .05971 Mdot
.35879 .1741 Mdot
.07709 .24281 Mdot
.68422 .10769 Mdot
.50998 .09844 Mdot
.3507 .21742 Mdot
.9989 .21641 Mdot
.49978 .00029 Mdot
.49931 .00094 Mdot
.49779 .00299 Mdot
.49295 .00952 Mdot
.47755 .03026 Mdot
.4286 .09425 Mdot
.27609 .23982 Mdot
.88806 .14439 Mdot
.65443 .02266 Mdot
.61777 .54121 Mdot
.74208 .39384 Mdot
.10483 .48415 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51104 .60312 Mdot
.53518 .57078 Mdot
.61164 .47556 Mdot
.84217 .35207 Mdot
.2725 .49815 Mdot
.46649 .52898 Mdot
.61057 .43453 Mdot
.90749 .35352 Mdot
.33549 .48028 Mdot
.50087 .61685 Mdot
.50279 .61427 Mdot
.50888 .60604 Mdot
.52829 .57995 Mdot
.58991 .50096 Mdot
.77935 .35591 Mdot
.20347 .4972 Mdot
.39899 .58468 Mdot
.45295 .00963 Mdot
.43737 .0662 Mdot
.33026 .19538 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00369 Mdot
.4913 .01175 Mdot
.47228 .03732 Mdot
.41189 .11489 Mdot
.22599 .26076 Mdot
.80407 .12165 Mdot
.60723 .02959 Mdot
.55935 .59387 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48723 .01724 Mdot
.45933 .05454 Mdot
.37108 .1614 Mdot
.10992 .2554 Mdot
.69668 .11606 Mdot
.50889 .10782 Mdot
.33444 .23508 Mdot
.95409 .1931 Mdot
.64165 .07845 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50497 .61132 Mdot
.51582 .59668 Mdot
.55037 .55076 Mdot
.65923 .42656 Mdot
.96904 .39804 Mdot
.32499 .5295 Mdot
.46824 .55875 Mdot
.56415 .50088 Mdot
.75371 .35337 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60934 Mdot
.5205 .59039 Mdot
.56522 .53161 Mdot
.70506 .38991 Mdot
.07417 .45621 Mdot
.33601 .58273 Mdot
.39314 .05648 Mdot
.30176 .19629 Mdot
.98416 .18163 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.5159 .59658 Mdot
.55061 .55045 Mdot
.65997 .42589 Mdot
.97087 .39903 Mdot
.32522 .5304 Mdot
.46702 .56076 Mdot
.55969 .50671 Mdot
.73982 .35947 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50264 .61447 Mdot
.50841 .60668 Mdot
.52679 .58196 Mdot
.58515 .50673 Mdot
.76524 .35986 Mdot
.18297 .49452 Mdot
.38283 .59359 Mdot
.42238 .04469 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49159 .01136 Mdot
.4732 .03609 Mdot
.4148 .11136 Mdot
.2346 .25822 Mdot
.8168 .12348 Mdot
.617 .02452 Mdot
.57733 .57366 Mdot
.64913 .45476 Mdot
.91331 .37831 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01286 Mdot
.46967 .04081 Mdot
.40364 .12479 Mdot
.20173 .2656 Mdot
.77199 .11946 Mdot
.5787 .04943 Mdot
.49871 .05063 Mdot
.4168 .12429 Mdot
.21569 .26842 Mdot
.50125 .61634 Mdot
.504 .61263 Mdot
.51273 .60084 Mdot
.54055 .56366 Mdot
.62854 .45703 Mdot
.88904 .3623 Mdot
.30283 .50179 Mdot
.49091 .51022 Mdot
.66535 .38306 Mdot
.04556 .42471 Mdot
.35835 .53937 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49633 .00495 Mdot
.48832 .01577 Mdot
.4628 .04995 Mdot
.38197 .14961 Mdot
.1399 .26324 Mdot
.71398 .11946 Mdot
.52069 .10032 Mdot
.35837 .21497 Mdot
.01054 .22473 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.49769 .00312 Mdot
.49265 .00992 Mdot
.4766 .03154 Mdot
.42556 .09807 Mdot
.26688 .24478 Mdot
.87082 .13775 Mdot
.64794 .01951 Mdot
.61637 .53903 Mdot
.7442 .39158 Mdot
.11061 .48606 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.4678 .0433 Mdot
.39774 .13171 Mdot
.18462 .26698 Mdot
.75263 .11946 Mdot
.55934 .06571 Mdot
.45302 .10864 Mdot
.27724 .25403 Mdot
.86621 .1441 Mdot
.50123 .61637 Mdot
.50393 .61273 Mdot
.51251 .60115 Mdot
.53983 .5646 Mdot
.62629 .45943 Mdot
.88291 .36041 Mdot
.29975 .50081 Mdot
.48942 .51061 Mdot
.66323 .38446 Mdot
.04117 .4222 Mdot
.35804 .53703 Mdot
.5001 .61789 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.51081 .60344 Mdot
.53442 .57178 Mdot
.60927 .47825 Mdot
.83545 .35146 Mdot
.26677 .49819 Mdot
.46068 .53427 Mdot
.59621 .45041 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50809 .60711 Mdot
.52576 .58334 Mdot
.5819 .51072 Mdot
.75553 .36327 Mdot
.16775 .49154 Mdot
.37241 .59755 Mdot
.40555 .06203 Mdot
.30519 .20079 Mdot
.98029 .18257 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50669 .60899 Mdot
.52132 .58928 Mdot
.56785 .52827 Mdot
.71308 .38468 Mdot
.09065 .46425 Mdot
.33948 .58908 Mdot
.38632 .0677 Mdot
.27678 .21316 Mdot
.93189 .15192 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49566 .00587 Mdot
.48616 .01869 Mdot
.45593 .05902 Mdot
.36042 .17246 Mdot
.08138 .24466 Mdot
.68552 .10906 Mdot
.50906 .10066 Mdot
.34618 .22207 Mdot
.98686 .20991 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00269 Mdot
.49367 .00855 Mdot
.47983 .0272 Mdot
.43581 .08511 Mdot
.29811 .22596 Mdot
.93249 .16524 Mdot
.66513 .03818 Mdot
.60336 .56699 Mdot
.68595 .43123 Mdot
.98819 .4203 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.51589 .59658 Mdot
.5506 .55046 Mdot
.65995 .42591 Mdot
.97081 .399 Mdot
.32522 .53037 Mdot
.46705 .5607 Mdot
.55983 .50653 Mdot
.74024 .35927 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50731 .60817 Mdot
.52327 .58667 Mdot
.57402 .5205 Mdot
.73184 .37391 Mdot
.12684 .47944 Mdot
.35109 .59821 Mdot
.38317 .07902 Mdot
.25532 .22648 Mdot
.88887 .13162 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.4866 .01809 Mdot
.45732 .05718 Mdot
.3648 .16798 Mdot
.09299 .24937 Mdot
.6895 .11236 Mdot
.5077 .10522 Mdot
.33745 .23104 Mdot
.96362 .19761 Mdot
.64388 .08166 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45943 .0544 Mdot
.3714 .16106 Mdot
.1108 .25568 Mdot
.6971 .11621 Mdot
.50906 .10782 Mdot
.33461 .235 Mdot
.95438 .19328 Mdot
.64164 .07863 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.5074 .60804 Mdot
.52357 .58627 Mdot
.57496 .51932 Mdot
.73469 .37245 Mdot
.13205 .4813 Mdot
.35329 .59885 Mdot
.38433 .07885 Mdot
.25674 .22627 Mdot
.89063 .13267 Mdot
.50117 .61645 Mdot
.50373 .613 Mdot
.51188 .602 Mdot
.53783 .56726 Mdot
.61998 .46627 Mdot
.86554 .35593 Mdot
.28963 .49892 Mdot
.48237 .51523 Mdot
.6487 .39658 Mdot
.00702 .40309 Mdot
.35481 .51978 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50922 .60558 Mdot
.52938 .57849 Mdot
.59336 .49682 Mdot
.78948 .35379 Mdot
.21703 .49819 Mdot
.41095 .5765 Mdot
.47816 .59668 Mdot
.49959 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45726 .05726 Mdot
.36461 .16818 Mdot
.09249 .24917 Mdot
.68931 .11223 Mdot
.50773 .10507 Mdot
.33773 .23076 Mdot
.96435 .19799 Mdot
.644 .08197 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.4649 .04716 Mdot
.38859 .14222 Mdot
.15848 .26603 Mdot
.72803 .11989 Mdot
.53405 .08857 Mdot
.39074 .18208 Mdot
.09613 .26588 Mdot
.66593 .13844 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49749 .0034 Mdot
.49199 .01082 Mdot
.47448 .03437 Mdot
.41886 .10638 Mdot
.24674 .25389 Mdot
.83594 .12734 Mdot
.6299 .01984 Mdot
.5978 .55281 Mdot
.70332 .41157 Mdot
.03739 .44591 Mdot
.50092 .61679 Mdot
.50294 .61406 Mdot
.50937 .60538 Mdot
.52985 .57786 Mdot
.59486 .49504 Mdot
.79387 .35306 Mdot
.2226 .49843 Mdot
.41613 .57263 Mdot
.48959 .58227 Mdot
.54746 .53892 Mdot
.67548 .40725 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.49192 .01092 Mdot
.47426 .03468 Mdot
.41815 .10726 Mdot
.24461 .25472 Mdot
.83247 .12654 Mdot
.62772 .02044 Mdot
.59465 .55581 Mdot
.50107 .61659 Mdot
.5034 .61343 Mdot
.51085 .60339 Mdot
.53454 .57161 Mdot
.60965 .47781 Mdot
.83653 .35155 Mdot
.26772 .49818 Mdot
.46165 .53338 Mdot
.59862 .44769 Mdot
.87424 .34287 Mdot
.31947 .47658 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00506 Mdot
.48806 .01612 Mdot
.46197 .05104 Mdot
.37938 .15247 Mdot
.13268 .26171 Mdot
.70923 .11898 Mdot
.51672 .10351 Mdot
.34924 .22329 Mdot
.98795 .21213 Mdot
.64472 .09571 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.51009 .6044 Mdot
.53215 .5748 Mdot
.60209 .48652 Mdot
.81489 .35107 Mdot
.24685 .49858 Mdot
.44012 .55279 Mdot
.54569 .51101 Mdot
.71885 .36629 Mdot
.12619 .47139 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.46629 .04531 Mdot
.39298 .13721 Mdot
.17097 .26694 Mdot
.73906 .11974 Mdot
.54532 .07829 Mdot
.41863 .15048 Mdot
.17515 .28201 Mdot
.71885 .13728 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50474 .61163 Mdot
.5151 .59765 Mdot
.54807 .55376 Mdot
.65206 .43328 Mdot
.951 .38857 Mdot
.32228 .52116 Mdot
.47903 .54055 Mdot
.6044 .45056 Mdot
.87538 .34648 Mdot
.50114 .61649 Mdot
.50365 .61311 Mdot
.51162 .60234 Mdot
.53701 .56834 Mdot
.61743 .46909 Mdot
.85842 .35448 Mdot
.28487 .4985 Mdot
.47828 .51857 Mdot
.63923 .40534 Mdot
.98338 .38996 Mdot
.35242 .50799 Mdot
.50109 .61656 Mdot
.50346 .61335 Mdot
.51104 .60313 Mdot
.53516 .5708 Mdot
.61158 .47563 Mdot
.84199 .35205 Mdot
.27236 .49815 Mdot
.46634 .52912 Mdot
.61021 .43491 Mdot
.90651 .35314 Mdot
.33511 .48009 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50575 .61026 Mdot
.51833 .59331 Mdot
.55834 .54043 Mdot
.68391 .40542 Mdot
.02793 .43118 Mdot
.33027 .56035 Mdot
.4236 .01046 Mdot
.40667 .09211 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.51011 .60438 Mdot
.53219 .57474 Mdot
.60224 .48635 Mdot
.81531 .35105 Mdot
.2473 .49858 Mdot
.44058 .55239 Mdot
.5468 .50962 Mdot
.72221 .36432 Mdot
.13273 .47359 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49732 .00362 Mdot
.49147 .01152 Mdot
.47284 .03657 Mdot
.41367 .11273 Mdot
.23127 .25926 Mdot
.81178 .12269 Mdot
.61327 .02633 Mdot
.57067 .58098 Mdot
.63061 .47304 Mdot
.86522 .3625 Mdot
.50019 .61778 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60973 Mdot
.51958 .59163 Mdot
.5623 .53533 Mdot
.69612 .39616 Mdot
.05511 .44624 Mdot
.33308 .57413 Mdot
.40411 .03971 Mdot
.33985 .16436 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00225 Mdot
.49468 .00718 Mdot
.48306 .02285 Mdot
.44608 .07189 Mdot
.32976 .20129 Mdot
.00407 .20506 Mdot
.67227 .07477 Mdot
.5513 .02803 Mdot
.50594 .02252 Mdot
.4695 .05063 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00353 Mdot
.49166 .01126 Mdot
.47345 .03576 Mdot
.41559 .1104 Mdot
.23695 .25745 Mdot
.82039 .1241 Mdot
.61959 .02338 Mdot
.58177 .5689 Mdot
.66127 .4437 Mdot
.94335 .39228 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49243 .01023 Mdot
.47588 .03251 Mdot
.42328 .10091 Mdot
.26001 .24816 Mdot
.85847 .13358 Mdot
.64234 .01852 Mdot
.61236 .54083 Mdot
.73728 .39376 Mdot
.50018 .61778 Mdot
.50059 .61724 Mdot
.50188 .6155 Mdot
.50598 .60995 Mdot
.51906 .59233 Mdot
.56065 .53746 Mdot
.69103 .39992 Mdot
.04394 .44014 Mdot
.33177 .56863 Mdot
.41171 .02832 Mdot
.36589 .13845 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00256 Mdot
.49397 .00815 Mdot
.48079 .02591 Mdot
.43886 .08121 Mdot
.30745 .21925 Mdot
.9527 .17604 Mdot
.66786 .04772 Mdot
.59065 .58618 Mdot
.64219 .47121 Mdot
.87975 .37004 Mdot
.49993 .0001 Mdot
.49978 .0003 Mdot
.49928 .00097 Mdot
.49772 .00308 Mdot
.49273 .00981 Mdot
.47686 .03119 Mdot
.42638 .09703 Mdot
.26938 .24349 Mdot
.87541 .13942 Mdot
.64981 .02016 Mdot
.6172 .5391 Mdot
.74491 .39163 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49188 .01097 Mdot
.47412 .03486 Mdot
.41772 .10778 Mdot
.24333 .2552 Mdot
.83042 .12609 Mdot
.6264 .02084 Mdot
.59268 .55773 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01686 Mdot
.46024 .05333 Mdot
.37395 .15835 Mdot
.11773 .25781 Mdot
.70059 .11732 Mdot
.51077 .10734 Mdot
.33708 .23335 Mdot
.95951 .19622 Mdot
.64202 .08135 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49394 .00819 Mdot
.48068 .02605 Mdot
.43853 .08163 Mdot
.30645 .21999 Mdot
.95049 .17483 Mdot
.66761 .04662 Mdot
.59217 .58391 Mdot
.64739 .46598 Mdot
.89341 .37439 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00637 Mdot
.48499 .02026 Mdot
.4522 .06392 Mdot
.34878 .18394 Mdot
.05115 .23055 Mdot
.67811 .09781 Mdot
.51986 .07944 Mdot
.39132 .17255 Mdot
.11213 .26811 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49376 .00843 Mdot
.48011 .02683 Mdot
.4367 .08397 Mdot
.30083 .22406 Mdot
.9383 .16828 Mdot
.66602 .0408 Mdot
.6 .57212 Mdot
.67429 .44095 Mdot
.96082 .405 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47323 .03605 Mdot
.4149 .11124 Mdot
.23491 .25812 Mdot
.81725 .12356 Mdot
.61734 .02437 Mdot
.57791 .57303 Mdot
.65073 .45327 Mdot
.91732 .38002 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60698 Mdot
.52608 .58291 Mdot
.58292 .50947 Mdot
.75858 .36214 Mdot
.17263 .49259 Mdot
.37561 .59652 Mdot
.41041 .05722 Mdot
.31782 .19157 Mdot
.00786 .19885 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.49329 .00906 Mdot
.47864 .0288 Mdot
.43203 .08992 Mdot
.28655 .23359 Mdot
.9086 .15343 Mdot
.66034 .02869 Mdot
.61392 .5499 Mdot
.72415 .4043 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00329 Mdot
.49224 .01048 Mdot
.47529 .03329 Mdot
.42143 .10321 Mdot
.25444 .25069 Mdot
.84881 .13068 Mdot
.63736 .01857 Mdot
.60731 .54449 Mdot
.72631 .39857 Mdot
.08141 .4708 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .00681 Mdot
.48393 .02168 Mdot
.44885 .06829 Mdot
.33836 .19367 Mdot
.025 .21675 Mdot
.67429 .08559 Mdot
.53581 .05267 Mdot
.45059 .09774 Mdot
.29243 .24008 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61085 Mdot
.51694 .59518 Mdot
.55392 .54614 Mdot
.67024 .41674 Mdot
.99594 .41298 Mdot
.32773 .54328 Mdot
.44869 .59002 Mdot
.49401 .59557 Mdot
.53035 .5676 Mdot
.50065 .61715 Mdot
.50207 .61523 Mdot
.50661 .6091 Mdot
.52106 .58964 Mdot
.567 .52935 Mdot
.7105 .38632 Mdot
.08542 .46176 Mdot
.33827 .58719 Mdot
.38818 .0645 Mdot
.28381 .20873 Mdot
.94609 .1597 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49814 .00251 Mdot
.49408 .008 Mdot
.48113 .02546 Mdot
.43993 .07983 Mdot
.31076 .21675 Mdot
.96005 .18011 Mdot
.66863 .05143 Mdot
.58543 .59401 Mdot
.62429 .49015 Mdot
.83121 .3614 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49737 .00355 Mdot
.49163 .01131 Mdot
.47334 .03591 Mdot
.41523 .11083 Mdot
.23591 .2578 Mdot
.81879 .12382 Mdot
.61845 .02387 Mdot
.57982 .57097 Mdot
.65597 .44844 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49006 .01343 Mdot
.46833 .04259 Mdot
.39941 .12976 Mdot
.18946 .26676 Mdot
.75783 .11939 Mdot
.56466 .06109 Mdot
.46582 .09253 Mdot
.31609 .22754 Mdot
.94793 .18012 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60459 Mdot
.53171 .57538 Mdot
.60073 .48811 Mdot
.81094 .35125 Mdot
.2426 .49864 Mdot
.43578 .55657 Mdot
.53524 .52417 Mdot
.68712 .38799 Mdot
.05935 .44174 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.49659 .0046 Mdot
.48915 .01465 Mdot
.46544 .04645 Mdot
.39028 .14029 Mdot
.16328 .26647 Mdot
.73212 .11986 Mdot
.53818 .0848 Mdot
.40097 .17079 Mdot
.12463 .27488 Mdot
.67987 .14143 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60602 Mdot
.52834 .57988 Mdot
.59008 .50076 Mdot
.77983 .3558 Mdot
.20414 .49726 Mdot
.39955 .58432 Mdot
.45411 .00824 Mdot
.44077 .0619 Mdot
.34061 .18617 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50883 .60611 Mdot
.52812 .58018 Mdot
.58937 .50162 Mdot
.77773 .35631 Mdot
.20122 .49698 Mdot
.3971 .58586 Mdot
.44915 .01417 Mdot
.42622 .08015 Mdot
.29654 .22143 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50484 .6115 Mdot
.51541 .59723 Mdot
.54908 .55245 Mdot
.6552 .43032 Mdot
.95893 .39266 Mdot
.32359 .52472 Mdot
.47458 .54818 Mdot
.58761 .471 Mdot
.82551 .33975 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51586 .59663 Mdot
.55049 .5506 Mdot
.6596 .42623 Mdot
.96995 .39853 Mdot
.32511 .52995 Mdot
.46763 .55975 Mdot
.56193 .50378 Mdot
.74679 .35627 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49357 .00869 Mdot
.4795 .02764 Mdot
.43479 .08642 Mdot
.29496 .22812 Mdot
.92586 .16184 Mdot
.66399 .03532 Mdot
.60684 .56158 Mdot
.69818 .42179 Mdot
.01572 .43633 Mdot
.50014 .61785 Mdot
.50044 .61744 Mdot
.5014 .61614 Mdot
.50447 .61199 Mdot
.51425 .5988 Mdot
.54538 .55729 Mdot
.64366 .44147 Mdot
.92934 .3781 Mdot
.31756 .51255 Mdot
.48824 .52344 Mdot
.64129 .409 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00269 Mdot
.49366 .00856 Mdot
.47982 .02722 Mdot
.43578 .08515 Mdot
.29799 .22604 Mdot
.93225 .16511 Mdot
.66509 .03807 Mdot
.60349 .56679 Mdot
.6864 .43087 Mdot
.98924 .4209 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00325 Mdot
.49232 .01037 Mdot
.47555 .03295 Mdot
.42224 .1022 Mdot
.25688 .24961 Mdot
.85301 .1319 Mdot
.63959 .01846 Mdot
.60972 .54264 Mdot
.73171 .39607 Mdot
.09085 .4758 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49768 .00314 Mdot
.4926 .01 Mdot
.47642 .03178 Mdot
.425 .09876 Mdot
.2652 .24564 Mdot
.86775 .13666 Mdot
.64662 .01916 Mdot
.61562 .5392 Mdot
.74318 .39179 Mdot
.10926 .4853 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48093 .02573 Mdot
.4393 .08065 Mdot
.30881 .21823 Mdot
.9557 .17769 Mdot
.66819 .04922 Mdot
.58855 .58933 Mdot
.63501 .47865 Mdot
.86054 .36528 Mdot
.50117 .61646 Mdot
.50371 .61302 Mdot
.51183 .60206 Mdot
.53768 .56746 Mdot
.61952 .46678 Mdot
.86425 .35565 Mdot
.2888 .49883 Mdot
.48168 .51578 Mdot
.64713 .39799 Mdot
.00317 .40093 Mdot
.35445 .51782 Mdot
.50118 .61643 Mdot
.50377 .61294 Mdot
.51202 .6018 Mdot
.53829 .56665 Mdot
.62143 .46469 Mdot
.86954 .35684 Mdot
.29216 .49924 Mdot
.48436 .51371 Mdot
.65316 .39265 Mdot
.01783 .40915 Mdot
.35582 .52527 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48755 .01681 Mdot
.46035 .05319 Mdot
.37428 .158 Mdot
.11863 .25807 Mdot
.70107 .11744 Mdot
.51104 .10722 Mdot
.33755 .233 Mdot
.96055 .1968 Mdot
.64212 .08187 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.49771 .0031 Mdot
.49269 .00988 Mdot
.47671 .03139 Mdot
.42591 .09762 Mdot
.26796 .24422 Mdot
.8728 .13846 Mdot
.64876 .01977 Mdot
.61677 .53901 Mdot
.50005 .61797 Mdot
.50015 .61783 Mdot
.50048 .61738 Mdot
.50154 .61596 Mdot
.50489 .61143 Mdot
.51558 .597 Mdot
.54961 .55175 Mdot
.65686 .42876 Mdot
.96311 .39487 Mdot
.3242 .52666 Mdot
.47204 .55245 Mdot
.50062 .61719 Mdot
.50198 .61535 Mdot
.50632 .60949 Mdot
.52015 .59086 Mdot
.56411 .53302 Mdot
.70166 .39223 Mdot
.06702 .45254 Mdot
.33479 .57964 Mdot
.39692 .05062 Mdot
.31501 .18603 Mdot
.014 .199 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50604 .60987 Mdot
.51926 .59206 Mdot
.56129 .53664 Mdot
.69299 .39846 Mdot
.04826 .44252 Mdot
.33225 .5708 Mdot
.40868 .03285 Mdot
.35553 .14913 Mdot
.11423 .24617 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60802 Mdot
.52363 .58619 Mdot
.57515 .51908 Mdot
.73526 .37217 Mdot
.13307 .48165 Mdot
.35374 .59895 Mdot
.38461 .07876 Mdot
.25717 .22616 Mdot
.89124 .133 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50733 .60814 Mdot
.52334 .58658 Mdot
.57423 .52024 Mdot
.73247 .37359 Mdot
.12799 .47986 Mdot
.35156 .59837 Mdot
.38339 .07902 Mdot
.25552 .22648 Mdot
.88907 .13177 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01652 Mdot
.46103 .05229 Mdot
.37642 .15569 Mdot
.1245 .25969 Mdot
.70431 .11819 Mdot
.51308 .10608 Mdot
.34144 .22993 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48476 .02056 Mdot
.45149 .06484 Mdot
.34658 .18604 Mdot
.04556 .2277 Mdot
.67713 .09535 Mdot
.52284 .07425 Mdot
.4027 .15894 Mdot
.14553 .27582 Mdot
.50038 .61751 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51245 .60123 Mdot
.53963 .56487 Mdot
.62566 .46011 Mdot
.88118 .35991 Mdot
.29884 .50056 Mdot
.48891 .51084 Mdot
.66235 .38511 Mdot
.03923 .42111 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51082 .60342 Mdot
.53447 .57171 Mdot
.60942 .47808 Mdot
.83587 .35149 Mdot
.26714 .49818 Mdot
.46106 .53392 Mdot
.59716 .44934 Mdot
.87011 .34186 Mdot
.31698 .47653 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49881 .00161 Mdot
.49619 .00514 Mdot
.48787 .01638 Mdot
.46137 .05183 Mdot
.3775 .15451 Mdot
.1275 .26047 Mdot
.70606 .11851 Mdot
.5143 .10527 Mdot
.34397 .22783 Mdot
.97533 .20506 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.4977 .0031 Mdot
.49269 .00988 Mdot
.4767 .03141 Mdot
.42588 .09766 Mdot
.26786 .24428 Mdot
.87261 .1384 Mdot
.64869 .01975 Mdot
.50084 .6169 Mdot
.50268 .61442 Mdot
.50853 .60651 Mdot
.52718 .58143 Mdot
.5864 .50521 Mdot
.76895 .35871 Mdot
.18854 .49539 Mdot
.38698 .59158 Mdot
.42978 .03656 Mdot
.37062 .14372 Mdot
.13808 .25626 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.47621 .03207 Mdot
.42432 .09961 Mdot
.26315 .24665 Mdot
.86406 .1354 Mdot
.64498 .01883 Mdot
.6145 .53964 Mdot
.74135 .39231 Mdot
.10657 .48389 Mdot
.50046 .61741 Mdot
.50147 .61605 Mdot
.50467 .61173 Mdot
.51488 .59796 Mdot
.54736 .55469 Mdot
.64985 .43541 Mdot
.94534 .38573 Mdot
.32122 .51874 Mdot
.48187 .53551 Mdot
.6154 .43766 Mdot
.90724 .35646 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49275 .00979 Mdot
.47691 .03112 Mdot
.42657 .0968 Mdot
.26994 .24319 Mdot
.87646 .13982 Mdot
.65023 .02033 Mdot
.61734 .53917 Mdot
.74494 .3917 Mdot
.11115 .48657 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00268 Mdot
.49367 .00854 Mdot
.47985 .02718 Mdot
.43588 .08503 Mdot
.2983 .22583 Mdot
.93291 .16546 Mdot
.6652 .03837 Mdot
.60312 .56735 Mdot
.68513 .43189 Mdot
.98631 .41922 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .6014 Mdot
.53923 .5654 Mdot
.6244 .46146 Mdot
.87775 .35894 Mdot
.29696 .50011 Mdot
.48776 .51145 Mdot
.66022 .38676 Mdot
.03443 .41843 Mdot
.35739 .53364 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00478 Mdot
.48874 .01521 Mdot
.46413 .04818 Mdot
.38618 .14492 Mdot
.15169 .2652 Mdot
.72258 .11984 Mdot
.52867 .09341 Mdot
.37752 .19608 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.4867 .01795 Mdot
.45765 .05675 Mdot
.36583 .16691 Mdot
.09577 .25043 Mdot
.69056 .11306 Mdot
.50764 .10598 Mdot
.33616 .23243 Mdot
.96008 .19581 Mdot
.64326 .08022 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60033 Mdot
.54176 .56205 Mdot
.63234 .45302 Mdot
.89934 .3658 Mdot
.30746 .50384 Mdot
.49224 .51103 Mdot
.66537 .38386 Mdot
.04427 .42438 Mdot
.35762 .53945 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45871 .05535 Mdot
.36916 .16344 Mdot
.10471 .25366 Mdot
.69428 .11506 Mdot
.50811 .10754 Mdot
.33411 .23496 Mdot
.95394 .19285 Mdot
.6419 .07805 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51043 .60395 Mdot
.53322 .57338 Mdot
.60548 .4826 Mdot
.82462 .35097 Mdot
.25674 .49839 Mdot
.45033 .54369 Mdot
.50124 .61636 Mdot
.50396 .61269 Mdot
.51261 .60101 Mdot
.54015 .56419 Mdot
.62728 .45838 Mdot
.88561 .36123 Mdot
.30113 .50122 Mdot
.49014 .51036 Mdot
.66436 .38366 Mdot
.04358 .42356 Mdot
.35824 .53828 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51236 .60135 Mdot
.53935 .56525 Mdot
.62476 .46107 Mdot
.87873 .35922 Mdot
.29751 .50024 Mdot
.48811 .51125 Mdot
.5 .61803 Mdot
.5 .61803 Mdot
.50001 .61802 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50022 .61773 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50727 .60821 Mdot
.52317 .5868 Mdot
.57371 .52088 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50745 .60797 Mdot
.52374 .58604 Mdot
.57551 .51864 Mdot
.73633 .37164 Mdot
.135 .48232 Mdot
.3546 .59913 Mdot
.38519 .07853 Mdot
.25812 .22589 Mdot
.89263 .13373 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49784 .00292 Mdot
.49311 .00931 Mdot
.47805 .0296 Mdot
.43016 .09228 Mdot
.28084 .23707 Mdot
.89726 .1483 Mdot
.65731 .02508 Mdot
.61672 .54435 Mdot
.73595 .39738 Mdot
.09298 .47875 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50642 .60936 Mdot
.52045 .59046 Mdot
.56507 .5318 Mdot
.7046 .39022 Mdot
.07321 .45572 Mdot
.33584 .58232 Mdot
.39363 .05572 Mdot
.30347 .19501 Mdot
.98793 .18384 Mdot
.5006 .61722 Mdot
.50193 .61543 Mdot
.50614 .60975 Mdot
.51955 .59167 Mdot
.5622 .53547 Mdot
.6958 .39639 Mdot
.05442 .44587 Mdot
.33299 .5738 Mdot
.40456 .03904 Mdot
.34139 .16292 Mdot
.07778 .23219 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00203 Mdot
.4952 .00648 Mdot
.48472 .02062 Mdot
.45135 .06503 Mdot
.34613 .18646 Mdot
.04443 .22712 Mdot
.67694 .09485 Mdot
.52347 .07317 Mdot
.40509 .15603 Mdot
.15263 .27681 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51134 .60271 Mdot
.53613 .56951 Mdot
.61465 .47218 Mdot
.85065 .35317 Mdot
.27922 .49823 Mdot
.47306 .52309 Mdot
.62669 .41766 Mdot
.9509 .37286 Mdot
.3476 .49352 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48906 .01477 Mdot
.46515 .04682 Mdot
.3894 .1413 Mdot
.16077 .26626 Mdot
.72995 .11988 Mdot
.53598 .0868 Mdot
.39553 .17684 Mdot
.10939 .27046 Mdot
.67178 .14038 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50877 .60619 Mdot
.52792 .58044 Mdot
.58875 .50236 Mdot
.77592 .35677 Mdot
.19865 .4967 Mdot
.39498 .58715 Mdot
.44495 .01914 Mdot
.41398 .09506 Mdot
.26017 .2423 Mdot
.50123 .61637 Mdot
.50391 .61275 Mdot
.51246 .60121 Mdot
.53969 .56479 Mdot
.62585 .4599 Mdot
.88171 .36006 Mdot
.29912 .50064 Mdot
.48907 .51076 Mdot
.66263 .3849 Mdot
.03985 .42146 Mdot
.35792 .53637 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.494 .0081 Mdot
.48089 .02578 Mdot
.43918 .0808 Mdot
.30844 .21851 Mdot
.95488 .17724 Mdot
.6681 .0488 Mdot
.58913 .58846 Mdot
.63698 .47658 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48082 .02587 Mdot
.43897 .08107 Mdot
.30779 .219 Mdot
.95344 .17645 Mdot
.66794 .04808 Mdot
.59014 .58695 Mdot
.64044 .473 Mdot
.8751 .36874 Mdot
.50027 .61766 Mdot
.50087 .61685 Mdot
.50278 .61428 Mdot
.50886 .60606 Mdot
.52823 .58003 Mdot
.58972 .50119 Mdot
.77879 .35605 Mdot
.20269 .49712 Mdot
.39833 .5851 Mdot
.45162 .01123 Mdot
.43345 .07114 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49434 .00764 Mdot
.48197 .02432 Mdot
.44262 .07637 Mdot
.31906 .21024 Mdot
.97889 .19072 Mdot
.67029 .0613 Mdot
.57111 .61558 Mdot
.57508 .54854 Mdot
.68753 .41221 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.49191 .01093 Mdot
.47423 .03471 Mdot
.41806 .10736 Mdot
.24434 .25482 Mdot
.83204 .12644 Mdot
.62745 .02052 Mdot
.59425 .5562 Mdot
.69431 .41759 Mdot
.01863 .43482 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48685 .01775 Mdot
.45813 .05612 Mdot
.36733 .16535 Mdot
.09978 .25191 Mdot
.69217 .114 Mdot
.50772 .10685 Mdot
.33483 .23393 Mdot
.95633 .19395 Mdot
.64252 .07879 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60119 Mdot
.53973 .56474 Mdot
.62596 .45978 Mdot
.88202 .36015 Mdot
.29928 .50068 Mdot
.48916 .51072 Mdot
.6628 .38478 Mdot
.04021 .42166 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60601 Mdot
.52837 .57985 Mdot
.59015 .50067 Mdot
.78004 .35575 Mdot
.20443 .49729 Mdot
.3998 .58416 Mdot
.4546 .00764 Mdot
.44224 .06003 Mdot
.34511 .182 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49175 .01114 Mdot
.47373 .03538 Mdot
.41649 .10929 Mdot
.23966 .25652 Mdot
.8246 .12489 Mdot
.62253 .0222 Mdot
.58661 .56384 Mdot
.6743 .43268 Mdot
.97421 .40887 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00543 Mdot
.48719 .01729 Mdot
.45921 .0547 Mdot
.3707 .16181 Mdot
.10889 .25506 Mdot
.69619 .11587 Mdot
.50871 .1078 Mdot
.33429 .23513 Mdot
.95384 .19293 Mdot
.64166 .07827 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51092 .60329 Mdot
.53478 .57131 Mdot
.61038 .47699 Mdot
.8386 .35172 Mdot
.26951 .49816 Mdot
.46347 .53173 Mdot
.60311 .44269 Mdot
.88683 .34639 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49513 .00658 Mdot
.48448 .02095 Mdot
.45059 .06602 Mdot
.34376 .18869 Mdot
.03845 .22399 Mdot
.67602 .0921 Mdot
.527 .0672 Mdot
.41827 .13968 Mdot
.19227 .27762 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00314 Mdot
.4926 .00999 Mdot
.47643 .03177 Mdot
.42503 .09872 Mdot
.26529 .24559 Mdot
.86792 .13672 Mdot
.6467 .01918 Mdot
.61566 .53918 Mdot
.74325 .39177 Mdot
.10935 .48535 Mdot
.50003 .618 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50266 .61445 Mdot
.50846 .6066 Mdot
.52696 .58173 Mdot
.58569 .50608 Mdot
.76684 .35936 Mdot
.18539 .49491 Mdot
.38461 .59276 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00425 Mdot
.48997 .01355 Mdot
.46804 .04298 Mdot
.3985 .13083 Mdot
.18682 .2669 Mdot
.75497 .11942 Mdot
.56174 .06361 Mdot
.45881 .10138 Mdot
.29477 .24312 Mdot
.90139 .15745 Mdot
.50011 .61788 Mdot
.50035 .61755 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51147 .60254 Mdot
.53654 .56896 Mdot
.61595 .47073 Mdot
.8543 .35375 Mdot
.28193 .49833 Mdot
.47561 .52086 Mdot
.63284 .41151 Mdot
.50128 .61631 Mdot
.50406 .61254 Mdot
.51295 .60056 Mdot
.54122 .56276 Mdot
.63065 .4548 Mdot
.89478 .3642 Mdot
.30549 .50287 Mdot
.49183 .51045 Mdot
.66591 .38302 Mdot
.04617 .42522 Mdot
.35814 .54 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.5073 .60818 Mdot
.52324 .58671 Mdot
.57393 .5206 Mdot
.73158 .37404 Mdot
.12636 .47927 Mdot
.3509 .59814 Mdot
.38308 .07901 Mdot
.25525 .22647 Mdot
.88881 .13158 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49135 .01168 Mdot
.47244 .0371 Mdot
.41241 .11427 Mdot
.22752 .26034 Mdot
.80627 .12193 Mdot
.60899 .0286 Mdot
.56272 .58998 Mdot
.60811 .49729 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49247 .01017 Mdot
.47602 .03231 Mdot
.42374 .10034 Mdot
.26138 .24751 Mdot
.86091 .13436 Mdot
.64351 .01863 Mdot
.61337 .54023 Mdot
.73925 .39302 Mdot
.10332 .48222 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48815 .016 Mdot
.46225 .05067 Mdot
.38026 .15149 Mdot
.13514 .26226 Mdot
.7108 .11916 Mdot
.51799 .10252 Mdot
.35212 .22072 Mdot
.99499 .21607 Mdot
.64537 .09928 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50478 .61157 Mdot
.51524 .59746 Mdot
.54852 .55317 Mdot
.65347 .43194 Mdot
.95458 .3904 Mdot
.32289 .52274 Mdot
.47708 .54391 Mdot
.59701 .45944 Mdot
.85362 .34208 Mdot
.50019 .61777 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50628 .60954 Mdot
.52002 .59103 Mdot
.56371 .53353 Mdot
.70044 .39308 Mdot
.06441 .45118 Mdot
.33439 .57847 Mdot
.3984 .04835 Mdot
.32016 .18179 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49346 .00883 Mdot
.47917 .02809 Mdot
.43373 .08776 Mdot
.29172 .23027 Mdot
.91914 .15849 Mdot
.6627 .03259 Mdot
.60996 .55661 Mdot
.70935 .41385 Mdot
.03974 .4503 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.5111 .60305 Mdot
.53535 .57054 Mdot
.6122 .47493 Mdot
.84374 .35225 Mdot
.27379 .49815 Mdot
.46777 .52782 Mdot
.61373 .43114 Mdot
.91613 .35694 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49156 .01141 Mdot
.4731 .03622 Mdot
.41449 .11173 Mdot
.2337 .25851 Mdot
.81543 .12326 Mdot
.616 .02499 Mdot
.57557 .57557 Mdot
.64427 .4594 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51264 .60096 Mdot
.54027 .56403 Mdot
.62765 .45798 Mdot
.88662 .36154 Mdot
.30164 .50138 Mdot
.49038 .5103 Mdot
.66471 .38344 Mdot
.04429 .42397 Mdot
.35829 .53866 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51257 .60106 Mdot
.54004 .56433 Mdot
.62694 .45873 Mdot
.8847 .36095 Mdot
.30067 .50108 Mdot
.48991 .51043 Mdot
.66402 .3839 Mdot
.04285 .42315 Mdot
.35819 .5379 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48092 .02574 Mdot
.43926 .08069 Mdot
.30871 .21831 Mdot
.95547 .17757 Mdot
.66816 .0491 Mdot
.58871 .58909 Mdot
.63555 .47808 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .00399 Mdot
.49058 .01272 Mdot
.47 .04036 Mdot
.4047 .12353 Mdot
.20483 .26517 Mdot
.77577 .11955 Mdot
.58233 .04659 Mdot
.50695 .04014 Mdot
.442 .09273 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49852 .002 Mdot
.49528 .00638 Mdot
.48495 .02032 Mdot
.45207 .06408 Mdot
.34839 .18432 Mdot
.05015 .23005 Mdot
.67793 .09737 Mdot
.52037 .07854 Mdot
.3933 .17021 Mdot
.11789 .26978 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49022 .01321 Mdot
.46883 .04192 Mdot
.401 .12789 Mdot
.19407 .26642 Mdot
.76299 .11937 Mdot
.56985 .05667 Mdot
.47815 .07686 Mdot
.35379 .19413 Mdot
.03969 .23054 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .00301 Mdot
.49291 .00958 Mdot
.47742 .03044 Mdot
.42817 .0948 Mdot
.27478 .24056 Mdot
.88556 .14337 Mdot
.65358 .02208 Mdot
.61785 .54058 Mdot
.74317 .39317 Mdot
.10701 .48507 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48853 .01548 Mdot
.46348 .04905 Mdot
.38412 .14723 Mdot
.14589 .26432 Mdot
.71821 .11971 Mdot
.52452 .09707 Mdot
.36746 .20622 Mdot
.03379 .23731 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.5053 .61087 Mdot
.51689 .59524 Mdot
.55377 .54633 Mdot
.66979 .41714 Mdot
.99485 .41236 Mdot
.32764 .54269 Mdot
.44954 .58869 Mdot
.49701 .59146 Mdot
.54001 .55476 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50854 .6065 Mdot
.52721 .5814 Mdot
.58648 .50512 Mdot
.76918 .35864 Mdot
.18889 .49544 Mdot
.38724 .59145 Mdot
.43027 .03601 Mdot
.372 .14229 Mdot
.14177 .25701 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49587 .00557 Mdot
.48686 .01774 Mdot
.45815 .0561 Mdot
.36738 .1653 Mdot
.09991 .25196 Mdot
.69223 .11403 Mdot
.50772 .10687 Mdot
.3348 .23397 Mdot
.95623 .1939 Mdot
.64249 .07876 Mdot
.50095 .61676 Mdot
.50301 .61397 Mdot
.50959 .60508 Mdot
.53056 .57693 Mdot
.59707 .49241 Mdot
.80033 .35218 Mdot
.23048 .49862 Mdot
.4237 .56668 Mdot
.5068 .56038 Mdot
.60008 .47359 Mdot
.8338 .34603 Mdot
.50019 .61778 Mdot
.50059 .61724 Mdot
.50188 .61549 Mdot
.506 .60993 Mdot
.5191 .59227 Mdot
.5608 .53726 Mdot
.69149 .39958 Mdot
.04496 .4407 Mdot
.33188 .56915 Mdot
.41098 .0294 Mdot
.36341 .14105 Mdot
.49981 .00025 Mdot
.4994 .0008 Mdot
.4981 .00256 Mdot
.49396 .00816 Mdot
.48075 .02597 Mdot
.43873 .08138 Mdot
.30705 .21955 Mdot
.95181 .17555 Mdot
.66776 .04727 Mdot
.59127 .58525 Mdot
.64431 .46906 Mdot
.88535 .37173 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49603 .00536 Mdot
.48736 .01706 Mdot
.45976 .05396 Mdot
.37245 .15996 Mdot
.11363 .25657 Mdot
.69849 .11669 Mdot
.50968 .10772 Mdot
.33538 .23454 Mdot
.95588 .19416 Mdot
.64172 .07947 Mdot
.49966 .00047 Mdot
.4989 .00149 Mdot
.4965 .00473 Mdot
.48884 .01507 Mdot
.46446 .04774 Mdot
.38723 .14375 Mdot
.15463 .26559 Mdot
.7249 .11988 Mdot
.53093 .09138 Mdot
.38307 .19029 Mdot
.07517 .25742 Mdot
.65866 .13351 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00376 Mdot
.49114 .01196 Mdot
.47179 .03798 Mdot
.41034 .11677 Mdot
.22139 .26194 Mdot
.79757 .12094 Mdot
.60189 .0328 Mdot
.54881 .6063 Mdot
.5678 .54533 Mdot
.68544 .40975 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01616 Mdot
.46188 .05117 Mdot
.37909 .15278 Mdot
.13189 .26153 Mdot
.70873 .11891 Mdot
.51633 .10381 Mdot
.34836 .22406 Mdot
.98583 .21094 Mdot
.64452 .09463 Mdot
.50125 .61635 Mdot
.50398 .61266 Mdot
.51267 .60093 Mdot
.54035 .56392 Mdot
.62791 .4577 Mdot
.88734 .36176 Mdot
.302 .5015 Mdot
.49055 .51026 Mdot
.66492 .3833 Mdot
.04473 .42423 Mdot
.35832 .5389 Mdot
.49992 .0001 Mdot
.49975 .00033 Mdot
.49922 .00105 Mdot
.49751 .00336 Mdot
.49207 .01071 Mdot
.47475 .03401 Mdot
.41972 .10532 Mdot
.24931 .25286 Mdot
.84017 .12837 Mdot
.63246 .01927 Mdot
.60129 .54961 Mdot
.71199 .40626 Mdot
.50026 .61768 Mdot
.50082 .61692 Mdot
.50262 .61449 Mdot
.50836 .60674 Mdot
.52664 .58216 Mdot
.58469 .5073 Mdot
.76386 .36031 Mdot
.18086 .49415 Mdot
.38131 .59427 Mdot
.41975 .04752 Mdot
.34287 .17065 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52555 .58361 Mdot
.58125 .51152 Mdot
.7536 .36401 Mdot
.16462 .49083 Mdot
.37044 .5981 Mdot
.40269 .06476 Mdot
.29791 .20567 Mdot
.96512 .1736 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49573 .00576 Mdot
.48641 .01835 Mdot
.45672 .05798 Mdot
.3629 .16994 Mdot
.08794 .24737 Mdot
.68768 .111 Mdot
.50808 .1035 Mdot
.34061 .22778 Mdot
.97206 .20201 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.48671 .01794 Mdot
.45768 .05672 Mdot
.36591 .16683 Mdot
.09596 .2505 Mdot
.69064 .1131 Mdot
.50763 .10603 Mdot
.33608 .23251 Mdot
.95986 .1957 Mdot
.64322 .08013 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50343 .61339 Mdot
.51094 .60326 Mdot
.53485 .57121 Mdot
.6106 .47673 Mdot
.83923 .35178 Mdot
.27004 .49815 Mdot
.46401 .53123 Mdot
.60446 .4412 Mdot
.89059 .34757 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60601 Mdot
.52835 .57986 Mdot
.59011 .50072 Mdot
.77994 .35577 Mdot
.20428 .49727 Mdot
.39968 .58424 Mdot
.45435 .00795 Mdot
.44149 .06097 Mdot
.34284 .18412 Mdot
.50109 .61656 Mdot
.50347 .61334 Mdot
.51107 .60309 Mdot
.53525 .57068 Mdot
.61187 .4753 Mdot
.84283 .35214 Mdot
.27304 .49815 Mdot
.46703 .52849 Mdot
.61191 .43309 Mdot
.91115 .35493 Mdot
.33685 .48105 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50994 .60462 Mdot
.53165 .57547 Mdot
.60052 .48836 Mdot
.81034 .35129 Mdot
.24194 .49865 Mdot
.43511 .55715 Mdot
.53363 .5262 Mdot
.68222 .39183 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49834 .00225 Mdot
.4947 .00715 Mdot
.48313 .02276 Mdot
.4463 .07161 Mdot
.33043 .20071 Mdot
.00568 .20597 Mdot
.67241 .07562 Mdot
.55006 .02998 Mdot
.50155 .02853 Mdot
.45539 .06935 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51667 .59554 Mdot
.55307 .54725 Mdot
.66759 .41905 Mdot
.98956 .40938 Mdot
.32718 .53991 Mdot
.45358 .58233 Mdot
.51134 .57183 Mdot
.58611 .49584 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.5047 .61168 Mdot
.51498 .59781 Mdot
.5477 .55425 Mdot
.6509 .4344 Mdot
.94803 .38707 Mdot
.32174 .51988 Mdot
.48055 .53786 Mdot
.61027 .44362 Mdot
.89247 .35135 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00286 Mdot
.49326 .0091 Mdot
.47854 .02893 Mdot
.43173 .0903 Mdot
.28561 .23417 Mdot
.90672 .15256 Mdot
.65987 .02805 Mdot
.61449 .54886 Mdot
.72642 .40293 Mdot
.07446 .46947 Mdot
.50028 .61765 Mdot
.5009 .61682 Mdot
.50286 .61417 Mdot
.5091 .60574 Mdot
.52899 .57901 Mdot
.59213 .49829 Mdot
.78588 .35448 Mdot
.21232 .49791 Mdot
.40668 .57955 Mdot
.46896 .60814 Mdot
.48496 .00403 Mdot
.501 .61668 Mdot
.50318 .61373 Mdot
.51015 .60433 Mdot
.53231 .57458 Mdot
.60262 .4859 Mdot
.81642 .35102 Mdot
.24846 .49856 Mdot
.44178 .55134 Mdot
.5497 .50601 Mdot
.73095 .35952 Mdot
.14923 .47847 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .6121 Mdot
.51399 .59915 Mdot
.54455 .55838 Mdot
.64108 .44406 Mdot
.92258 .37508 Mdot
.31568 .51024 Mdot
.4901 .51941 Mdot
.64967 .40022 Mdot
.0021 .40217 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00388 Mdot
.49084 .01237 Mdot
.47082 .03927 Mdot
.40728 .12045 Mdot
.21239 .26389 Mdot
.7854 .11998 Mdot
.59126 .03994 Mdot
.52664 .01536 Mdot
.5018 .01369 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46026 .05331 Mdot
.37401 .15829 Mdot
.11789 .25785 Mdot
.70067 .11734 Mdot
.51081 .10732 Mdot
.33716 .23329 Mdot
.95969 .19632 Mdot
.64204 .08144 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50872 .60626 Mdot
.52776 .58066 Mdot
.58824 .50298 Mdot
.77439 .35717 Mdot
.19648 .49645 Mdot
.39321 .58819 Mdot
.4415 .02317 Mdot
.404 .10687 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51139 .60266 Mdot
.53626 .56934 Mdot
.61506 .47172 Mdot
.85179 .35334 Mdot
.28007 .49826 Mdot
.47387 .52237 Mdot
.62866 .41567 Mdot
.95609 .37548 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49483 .00699 Mdot
.48352 .02223 Mdot
.44755 .06998 Mdot
.33432 .1973 Mdot
.01508 .21126 Mdot
.67326 .08054 Mdot
.54295 .0412 Mdot
.47628 .06312 Mdot
.37415 .168 Mdot
.50097 .61673 Mdot
.50309 .61387 Mdot
.50983 .60476 Mdot
.53131 .57591 Mdot
.59947 .48959 Mdot
.80729 .3515 Mdot
.23855 .49867 Mdot
.43169 .56006 Mdot
.52549 .53654 Mdot
.65736 .41329 Mdot
.98864 .40277 Mdot
.50012 .61787 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.51271 .60088 Mdot
.54046 .56377 Mdot
.62825 .45733 Mdot
.88827 .36206 Mdot
.30245 .50166 Mdot
.49075 .51023 Mdot
.66517 .38315 Mdot
.50043 .61745 Mdot
.50137 .61619 Mdot
.50436 .61215 Mdot
.51388 .5993 Mdot
.54419 .55886 Mdot
.63994 .44521 Mdot
.91959 .37379 Mdot
.31478 .50928 Mdot
.49075 .51784 Mdot
.65286 .39694 Mdot
.01061 .40676 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51077 .60349 Mdot
.5343 .57194 Mdot
.60889 .47868 Mdot
.83436 .35139 Mdot
.26581 .4982 Mdot
.4597 .53517 Mdot
.59377 .45318 Mdot
.86051 .3398 Mdot
.31071 .47674 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49375 .00844 Mdot
.4801 .02684 Mdot
.43666 .08402 Mdot
.30072 .22414 Mdot
.93806 .16815 Mdot
.66598 .04069 Mdot
.60014 .57189 Mdot
.6748 .44051 Mdot
.96203 .40565 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52129 .58932 Mdot
.56775 .5284 Mdot
.71278 .38487 Mdot
.09004 .46396 Mdot
.33933 .58887 Mdot
.38653 .06734 Mdot
.27756 .21268 Mdot
.93344 .15276 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49517 .00653 Mdot
.48461 .02078 Mdot
.45099 .06549 Mdot
.34502 .18752 Mdot
.04161 .22565 Mdot
.6765 .09357 Mdot
.5251 .07039 Mdot
.41121 .1485 Mdot
.17093 .27821 Mdot
.50104 .61662 Mdot
.50333 .61354 Mdot
.51061 .60371 Mdot
.53378 .57263 Mdot
.60726 .48055 Mdot
.82971 .35113 Mdot
.26157 .49828 Mdot
.45534 .53914 Mdot
.58298 .46565 Mdot
.82954 .33615 Mdot
.28563 .48002 Mdot
.50037 .61753 Mdot
.50118 .61643 Mdot
.50377 .61294 Mdot
.51202 .6018 Mdot
.53828 .56666 Mdot
.62141 .46471 Mdot
.86948 .35683 Mdot
.29212 .49924 Mdot
.48434 .51374 Mdot
.6531 .3927 Mdot
.01769 .40907 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51124 .60286 Mdot
.53579 .56997 Mdot
.61356 .4734 Mdot
.84759 .35273 Mdot
.27686 .49818 Mdot
.47079 .52511 Mdot
.62115 .42333 Mdot
.93618 .36574 Mdot
.3444 .48809 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .0033 Mdot
.49221 .01052 Mdot
.47518 .03344 Mdot
.42107 .10365 Mdot
.25337 .25116 Mdot
.84699 .13017 Mdot
.63636 .01866 Mdot
.60617 .54542 Mdot
.72366 .39989 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00806 Mdot
.481 .02563 Mdot
.43952 .08036 Mdot
.30948 .21772 Mdot
.9572 .17852 Mdot
.66834 .04997 Mdot
.58748 .59093 Mdot
.63134 .48253 Mdot
.85059 .36349 Mdot
.49986 .00018 Mdot
.49957 .00058 Mdot
.49862 .00186 Mdot
.49561 .00593 Mdot
.48603 .01886 Mdot
.4555 .05958 Mdot
.3591 .1738 Mdot
.07789 .24316 Mdot
.68445 .10795 Mdot
.50979 .09888 Mdot
.3498 .21835 Mdot
.99651 .21511 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01006 Mdot
.47627 .03198 Mdot
.42452 .09936 Mdot
.26374 .24636 Mdot
.86512 .13576 Mdot
.64546 .01892 Mdot
.61485 .53948 Mdot
.74195 .39213 Mdot
.10747 .48436 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.50631 .60952 Mdot
.52009 .59094 Mdot
.56393 .53325 Mdot
.70111 .39262 Mdot
.06584 .45193 Mdot
.33461 .57911 Mdot
.39759 .0496 Mdot
.31733 .18414 Mdot
.01939 .20207 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48732 .01712 Mdot
.45961 .05416 Mdot
.37197 .16046 Mdot
.11234 .25617 Mdot
.69785 .11648 Mdot
.50938 .10778 Mdot
.33499 .23479 Mdot
.95509 .19371 Mdot
.64167 .07904 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50621 .60964 Mdot
.51979 .59135 Mdot
.56297 .53448 Mdot
.69815 .3947 Mdot
.05951 .4486 Mdot
.33367 .57622 Mdot
.40133 .0439 Mdot
.33029 .17307 Mdot
.05027 .2189 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01781 Mdot
.45798 .05632 Mdot
.36686 .16584 Mdot
.09852 .25145 Mdot
.69166 .11371 Mdot
.50767 .10661 Mdot
.33518 .23352 Mdot
.95734 .19444 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01558 Mdot
.46325 .04935 Mdot
.3834 .14803 Mdot
.14388 .26398 Mdot
.71676 .11964 Mdot
.52319 .09822 Mdot
.36426 .20934 Mdot
.02554 .23292 Mdot
.64867 .11428 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50365 .61311 Mdot
.51162 .60235 Mdot
.537 .56836 Mdot
.61737 .46915 Mdot
.85827 .35445 Mdot
.28476 .49849 Mdot
.47819 .51864 Mdot
.63901 .40555 Mdot
.98282 .38965 Mdot
.50052 .61734 Mdot
.50164 .61581 Mdot
.50524 .61096 Mdot
.51668 .59552 Mdot
.55311 .5472 Mdot
.66772 .41894 Mdot
.98987 .40955 Mdot
.3272 .54007 Mdot
.45335 .58271 Mdot
.51051 .57297 Mdot
.58342 .49913 Mdot
.50065 .61716 Mdot
.50206 .61524 Mdot
.50658 .60915 Mdot
.52095 .58978 Mdot
.56667 .52977 Mdot
.70948 .38698 Mdot
.08334 .46076 Mdot
.33782 .5864 Mdot
.389 .06313 Mdot
.28685 .20674 Mdot
.95235 .16322 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49834 .00224 Mdot
.49471 .00714 Mdot
.48316 .02272 Mdot
.44639 .07149 Mdot
.33072 .20046 Mdot
.00637 .20636 Mdot
.67247 .07598 Mdot
.54953 .03081 Mdot
.49968 .03111 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00197 Mdot
.49536 .00626 Mdot
.48523 .01994 Mdot
.45297 .06291 Mdot
.35118 .18163 Mdot
.0573 .23361 Mdot
.67931 .10038 Mdot
.5169 .08474 Mdot
.37979 .18588 Mdot
.07902 .25617 Mdot
.50087 .61685 Mdot
.50278 .61428 Mdot
.50886 .60607 Mdot
.52822 .58005 Mdot
.58969 .50123 Mdot
.77867 .35608 Mdot
.20253 .49711 Mdot
.3982 .58518 Mdot
.45135 .01154 Mdot
.43268 .07211 Mdot
.316 .20715 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01098 Mdot
.47411 .03488 Mdot
.41767 .10784 Mdot
.24319 .25525 Mdot
.83018 .12604 Mdot
.62625 .02089 Mdot
.59245 .55796 Mdot
.68966 .42089 Mdot
.00864 .4289 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.5237 .5861 Mdot
.57537 .51881 Mdot
.73592 .37184 Mdot
.13427 .48207 Mdot
.35427 .59906 Mdot
.38496 .07863 Mdot
.25774 .226 Mdot
.89207 .13344 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00264 Mdot
.49378 .0084 Mdot
.48018 .02673 Mdot
.43693 .08368 Mdot
.30155 .22355 Mdot
.93983 .16909 Mdot
.66624 .04151 Mdot
.59907 .57352 Mdot
.67109 .44375 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50165 .6158 Mdot
.50527 .61092 Mdot
.51677 .5954 Mdot
.5534 .54682 Mdot
.66862 .41815 Mdot
.99204 .41077 Mdot
.3274 .54121 Mdot
.45169 .58531 Mdot
.50464 .58101 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.48621 .01861 Mdot
.4561 .0588 Mdot
.36095 .17192 Mdot
.08278 .24525 Mdot
.68596 .10949 Mdot
.50881 .10133 Mdot
.34485 .22344 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .00509 Mdot
.48799 .01622 Mdot
.46174 .05135 Mdot
.37866 .15325 Mdot
.1307 .26125 Mdot
.70799 .11881 Mdot
.51575 .10423 Mdot
.3471 .22516 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.50089 .61683 Mdot
.50285 .61418 Mdot
.50908 .60577 Mdot
.52892 .57911 Mdot
.5919 .49857 Mdot
.7852 .35462 Mdot
.21142 .49785 Mdot
.40588 .5801 Mdot
.46726 .61025 Mdot
.50112 .61653 Mdot
.50356 .61323 Mdot
.51133 .60273 Mdot
.5361 .56955 Mdot
.61454 .4723 Mdot
.85034 .35312 Mdot
.27898 .49823 Mdot
.47283 .52329 Mdot
.62613 .41822 Mdot
.94944 .37213 Mdot
.34732 .49294 Mdot
.50008 .61792 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50872 .60625 Mdot
.52779 .58062 Mdot
.58833 .50288 Mdot
.77465 .3571 Mdot
.19686 .49649 Mdot
.39351 .58801 Mdot
.44209 .02249 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00517 Mdot
.48781 .01646 Mdot
.46117 .0521 Mdot
.37688 .15519 Mdot
.12577 .26003 Mdot
.70504 .11833 Mdot
.51358 .10575 Mdot
.34247 .22909 Mdot
.97179 .20307 Mdot
.64321 .08752 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.49341 .00891 Mdot
.47899 .02833 Mdot
.43316 .08849 Mdot
.28998 .2314 Mdot
.91557 .15675 Mdot
.66195 .03122 Mdot
.61143 .55418 Mdot
.71475 .41024 Mdot
.05097 .45669 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50722 .60828 Mdot
.523 .58703 Mdot
.57316 .52157 Mdot
.72924 .37528 Mdot
.12203 .47764 Mdot
.34919 .59745 Mdot
.38249 .07872 Mdot
.25511 .22619 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49486 .00695 Mdot
.48361 .02212 Mdot
.44782 .06963 Mdot
.33516 .19655 Mdot
.01713 .2124 Mdot
.67346 .0816 Mdot
.54143 .04362 Mdot
.47085 .07049 Mdot
.3568 .18605 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .00681 Mdot
.48393 .02169 Mdot
.44884 .0683 Mdot
.33832 .19371 Mdot
.02489 .21669 Mdot
.67428 .08553 Mdot
.53589 .05254 Mdot
.45087 .09737 Mdot
.29332 .23949 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00312 Mdot
.49263 .00995 Mdot
.47654 .03162 Mdot
.42537 .0983 Mdot
.26633 .24507 Mdot
.8698 .13738 Mdot
.64751 .01939 Mdot
.61614 .53906 Mdot
.74391 .39163 Mdot
.11025 .48585 Mdot
.50094 .61677 Mdot
.50298 .614 Mdot
.50951 .60519 Mdot
.53029 .57728 Mdot
.59623 .49341 Mdot
.79787 .35249 Mdot
.22753 .49857 Mdot
.42083 .56897 Mdot
.50022 .56877 Mdot
.57993 .49774 Mdot
.77457 .35195 Mdot
.50123 .61638 Mdot
.50391 .61275 Mdot
.51245 .60122 Mdot
.53965 .56485 Mdot
.62571 .46005 Mdot
.88133 .35995 Mdot
.29892 .50058 Mdot
.48895 .51082 Mdot
.66243 .38505 Mdot
.03941 .42121 Mdot
.35788 .53614 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49782 .00295 Mdot
.49304 .0094 Mdot
.47783 .02988 Mdot
.42948 .09314 Mdot
.27877 .23828 Mdot
.89322 .14655 Mdot
.65609 .02396 Mdot
.61733 .54281 Mdot
.73904 .39561 Mdot
.09893 .48153 Mdot
.50024 .61771 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50778 .60752 Mdot
.52479 .58463 Mdot
.57884 .51449 Mdot
.74638 .36699 Mdot
.15258 .48774 Mdot
.3634 .59939 Mdot
.39356 .07284 Mdot
.27569 .21847 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49082 .0124 Mdot
.47076 .03936 Mdot
.40707 .1207 Mdot
.21178 .26401 Mdot
.78461 .11994 Mdot
.59054 .04045 Mdot
.52509 .01729 Mdot
.49712 .01996 Mdot
.46483 .0523 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49242 .01024 Mdot
.47585 .03254 Mdot
.4232 .101 Mdot
.25978 .24827 Mdot
.85807 .13345 Mdot
.64214 .01851 Mdot
.61219 .54094 Mdot
.73692 .3939 Mdot
.09958 .48031 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60702 Mdot
.52598 .58305 Mdot
.58259 .50987 Mdot
.7576 .3625 Mdot
.17107 .49226 Mdot
.37457 .59688 Mdot
.4088 .05884 Mdot
.3136 .19476 Mdot
.99847 .19334 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49363 .00861 Mdot
.47969 .02739 Mdot
.43538 .08566 Mdot
.29677 .22688 Mdot
.92967 .16378 Mdot
.66466 .03694 Mdot
.60488 .56463 Mdot
.69129 .42701 Mdot
.00037 .42735 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00194 Mdot
.49541 .0062 Mdot
.48539 .01972 Mdot
.45348 .06224 Mdot
.35277 .18008 Mdot
.06139 .23559 Mdot
.68019 .10201 Mdot
.51513 .08801 Mdot
.37273 .19381 Mdot
.05914 .24738 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48709 .01742 Mdot
.4589 .0551 Mdot
.36975 .16281 Mdot
.10631 .2542 Mdot
.695 .11538 Mdot
.50831 .10768 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07804 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45944 .0544 Mdot
.37142 .16105 Mdot
.11084 .25569 Mdot
.69712 .11622 Mdot
.50907 .10782 Mdot
.33462 .23499 Mdot
.95439 .19329 Mdot
.64164 .07864 Mdot
.50089 .61683 Mdot
.50283 .6142 Mdot
.50903 .60584 Mdot
.52877 .57931 Mdot
.59142 .49914 Mdot
.7838 .35491 Mdot
.20954 .49771 Mdot
.40422 .58124 Mdot
.46376 .61455 Mdot
.4694 .02471 Mdot
.42941 .08803 Mdot
.50071 .61707 Mdot
.50226 .61497 Mdot
.50722 .60829 Mdot
.52299 .58705 Mdot
.57311 .52163 Mdot
.72909 .37536 Mdot
.12175 .47754 Mdot
.34908 .5974 Mdot
.38246 .0787 Mdot
.25513 .22616 Mdot
.88919 .13154 Mdot
.50019 .61778 Mdot
.5006 .61723 Mdot
.50191 .61546 Mdot
.50607 .60983 Mdot
.51935 .59193 Mdot
.56159 .53625 Mdot
.69391 .39778 Mdot
.05029 .44363 Mdot
.33249 .5718 Mdot
.4073 .03492 Mdot
.3508 .15385 Mdot
.50019 .61778 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50605 .60986 Mdot
.51927 .59204 Mdot
.56134 .53657 Mdot
.69315 .39833 Mdot
.04863 .44272 Mdot
.33229 .57098 Mdot
.40843 .03323 Mdot
.35466 .15001 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00225 Mdot
.49468 .00718 Mdot
.48306 .02286 Mdot
.44608 .07189 Mdot
.32976 .20129 Mdot
.00406 .20505 Mdot
.67227 .07476 Mdot
.55131 .02801 Mdot
.50598 .02247 Mdot
.46963 .05045 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50934 .60543 Mdot
.52974 .57802 Mdot
.59448 .49549 Mdot
.79277 .35324 Mdot
.22122 .49837 Mdot
.41483 .57362 Mdot
.4867 .58593 Mdot
.53864 .55046 Mdot
.64799 .4322 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48759 .01675 Mdot
.46049 .053 Mdot
.37473 .15751 Mdot
.11987 .25843 Mdot
.70173 .11761 Mdot
.51143 .10703 Mdot
.33825 .23247 Mdot
.96211 .19767 Mdot
.64227 .08266 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50203 .61529 Mdot
.50647 .6093 Mdot
.5206 .59026 Mdot
.56554 .5312 Mdot
.70604 .38925 Mdot
.07622 .45724 Mdot
.33639 .58357 Mdot
.39215 .05805 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48782 .01644 Mdot
.46122 .05203 Mdot
.37703 .15502 Mdot
.1262 .26014 Mdot
.70529 .11838 Mdot
.51376 .10564 Mdot
.34283 .22879 Mdot
.97264 .20355 Mdot
.64329 .08795 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .00271 Mdot
.49362 .00862 Mdot
.47966 .02743 Mdot
.43528 .08579 Mdot
.29646 .22709 Mdot
.92902 .16345 Mdot
.66455 .03667 Mdot
.60523 .5641 Mdot
.69249 .42609 Mdot
.00307 .42893 Mdot
.50061 .61721 Mdot
.50194 .61541 Mdot
.50619 .60967 Mdot
.51973 .59143 Mdot
.56277 .53473 Mdot
.69756 .39513 Mdot
.05823 .44791 Mdot
.33349 .57561 Mdot
.40213 .0427 Mdot
.33304 .17061 Mdot
.05699 .22232 Mdot
.49976 .00032 Mdot
.49923 .00103 Mdot
.49756 .0033 Mdot
.49223 .0105 Mdot
.47524 .03336 Mdot
.42126 .10342 Mdot
.25393 .25091 Mdot
.84794 .13044 Mdot
.63689 .01861 Mdot
.60678 .54492 Mdot
.72508 .39918 Mdot
.07919 .4696 Mdot
.50085 .61688 Mdot
.50271 .61437 Mdot
.50864 .60636 Mdot
.52753 .58097 Mdot
.58751 .50387 Mdot
.77224 .35776 Mdot
.19337 .49606 Mdot
.39073 .58959 Mdot
.43675 .02866 Mdot
.39037 .12245 Mdot
.19224 .26038 Mdot
.49992 .0001 Mdot
.49976 .00032 Mdot
.49923 .00103 Mdot
.49756 .0033 Mdot
.49223 .0105 Mdot
.47524 .03336 Mdot
.42125 .10343 Mdot
.25391 .25093 Mdot
.8479 .13043 Mdot
.63687 .01861 Mdot
.60675 .54494 Mdot
.72502 .39921 Mdot
.50071 .61708 Mdot
.50226 .61498 Mdot
.50719 .60832 Mdot
.52292 .58714 Mdot
.57291 .52189 Mdot
.72847 .37569 Mdot
.12059 .47709 Mdot
.34864 .59719 Mdot
.38236 .07856 Mdot
.25525 .22602 Mdot
.88954 .13164 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51264 .60097 Mdot
.54025 .56405 Mdot
.6276 .45803 Mdot
.88648 .3615 Mdot
.30157 .50136 Mdot
.49035 .5103 Mdot
.66466 .38347 Mdot
.0442 .42392 Mdot
.35829 .53861 Mdot
.49978 .0003 Mdot
.49929 .00097 Mdot
.49772 .00308 Mdot
.49275 .0098 Mdot
.47689 .03115 Mdot
.4265 .09689 Mdot
.26972 .2433 Mdot
.87605 .13967 Mdot
.65007 .02026 Mdot
.61728 .53914 Mdot
.74493 .39167 Mdot
.11119 .48657 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49329 .00907 Mdot
.47862 .02883 Mdot
.43196 .09 Mdot
.28634 .23372 Mdot
.90817 .15324 Mdot
.66023 .02854 Mdot
.61405 .54967 Mdot
.72467 .40399 Mdot
.07101 .46765 Mdot
.50013 .61786 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.51341 .59993 Mdot
.54271 .56081 Mdot
.6353 .44995 Mdot
.90726 .36876 Mdot
.31059 .50574 Mdot
.49229 .51289 Mdot
.66241 .38713 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49103 .01211 Mdot
.47143 .03845 Mdot
.40921 .11813 Mdot
.21807 .26272 Mdot
.79299 .12052 Mdot
.59798 .03532 Mdot
.54084 .61591 Mdot
.54428 .57538 Mdot
.61329 .479 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51257 .60106 Mdot
.54004 .56432 Mdot
.62695 .45872 Mdot
.88472 .36095 Mdot
.30068 .50108 Mdot
.48991 .51043 Mdot
.66402 .38389 Mdot
.04287 .42316 Mdot
.35819 .53791 Mdot
.50112 .61653 Mdot
.50356 .61323 Mdot
.51133 .60274 Mdot
.53608 .56958 Mdot
.61448 .47237 Mdot
.85017 .35309 Mdot
.27885 .49822 Mdot
.47271 .5234 Mdot
.62582 .41853 Mdot
.94862 .37173 Mdot
.34716 .49262 Mdot
.50008 .61793 Mdot
.50024 .61771 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50785 .60743 Mdot
.525 .58436 Mdot
.57949 .51369 Mdot
.74832 .36615 Mdot
.15587 .48864 Mdot
.36524 .59917 Mdot
.39577 .071 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49696 .00411 Mdot
.49032 .01308 Mdot
.46915 .0415 Mdot
.40201 .1267 Mdot
.197 .26614 Mdot
.76638 .11938 Mdot
.57322 .05387 Mdot
.48605 .06679 Mdot
.37799 .16914 Mdot
.10432 .25907 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.49009 .01338 Mdot
.46843 .04246 Mdot
.39974 .12938 Mdot
.19039 .2667 Mdot
.75887 .11938 Mdot
.5657 .06019 Mdot
.46832 .08936 Mdot
.32373 .22136 Mdot
.96557 .18968 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49066 .01262 Mdot
.47024 .04004 Mdot
.40546 .12262 Mdot
.20705 .26483 Mdot
.77855 .11965 Mdot
.58495 .04458 Mdot
.51282 .03271 Mdot
.45989 .0695 Mdot
.34744 .19025 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .6014 Mdot
.53924 .56539 Mdot
.62441 .46145 Mdot
.87776 .35895 Mdot
.29697 .50011 Mdot
.48777 .51144 Mdot
.66023 .38675 Mdot
.03446 .41844 Mdot
.3574 .53365 Mdot
.50018 .61778 Mdot
.50059 .61724 Mdot
.50187 .61551 Mdot
.50596 .60998 Mdot
.51899 .59242 Mdot
.56044 .53772 Mdot
.69039 .4004 Mdot
.04252 .43936 Mdot
.33163 .56792 Mdot
.41271 .02681 Mdot
.36933 .13479 Mdot
.50087 .61685 Mdot
.50278 .61428 Mdot
.50886 .60607 Mdot
.52822 .58004 Mdot
.58969 .50122 Mdot
.7787 .35607 Mdot
.20257 .49711 Mdot
.39823 .58516 Mdot
.45142 .01147 Mdot
.43286 .07189 Mdot
.31654 .20672 Mdot
.49984 .00022 Mdot
.49949 .0007 Mdot
.49836 .00221 Mdot
.49478 .00706 Mdot
.48336 .02245 Mdot
.44703 .07066 Mdot
.3327 .19873 Mdot
.01114 .20905 Mdot
.67289 .07849 Mdot
.54589 .03653 Mdot
.48677 .04878 Mdot
.40784 .12952 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51127 .60281 Mdot
.5359 .56981 Mdot
.61393 .47298 Mdot
.84864 .35287 Mdot
.27767 .49819 Mdot
.47158 .5244 Mdot
.62307 .42134 Mdot
.94132 .36817 Mdot
.34561 .48989 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49616 .00518 Mdot
.48778 .0165 Mdot
.46109 .05222 Mdot
.3766 .15549 Mdot
.125 .25983 Mdot
.7046 .11824 Mdot
.51327 .10595 Mdot
.34183 .22961 Mdot
.97032 .20225 Mdot
.64307 .08678 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50758 .60779 Mdot
.52415 .58549 Mdot
.57682 .51701 Mdot
.74028 .36974 Mdot
.14204 .48462 Mdot
.35791 .59953 Mdot
.38786 .07706 Mdot
.26317 .2241 Mdot
.90057 .13781 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48771 .0166 Mdot
.46085 .05252 Mdot
.37587 .15628 Mdot
.12301 .2593 Mdot
.70346 .11801 Mdot
.51251 .10643 Mdot
.34031 .23085 Mdot
.9668 .20029 Mdot
.64272 .08501 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49737 .00355 Mdot
.49163 .01131 Mdot
.47333 .03592 Mdot
.41522 .11085 Mdot
.23585 .25781 Mdot
.8187 .1238 Mdot
.61838 .0239 Mdot
.57971 .57109 Mdot
.65567 .44871 Mdot
.92965 .38559 Mdot
.50089 .61684 Mdot
.50283 .61421 Mdot
.50901 .60587 Mdot
.52869 .57942 Mdot
.59118 .49944 Mdot
.78306 .35507 Mdot
.20855 .49764 Mdot
.40336 .58182 Mdot
.46195 .61677 Mdot
.464 .03183 Mdot
.4125 .10892 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .6013 Mdot
.53947 .56509 Mdot
.62514 .46067 Mdot
.87976 .3595 Mdot
.29807 .50037 Mdot
.48845 .51107 Mdot
.66153 .38574 Mdot
.03739 .42008 Mdot
.35768 .53513 Mdot
.50035 .61755 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51147 .60254 Mdot
.53654 .56896 Mdot
.61595 .47073 Mdot
.8543 .35375 Mdot
.28193 .49833 Mdot
.47561 .52086 Mdot
.63284 .41151 Mdot
.967 .38114 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00286 Mdot
.49327 .0091 Mdot
.47855 .02892 Mdot
.43175 .09027 Mdot
.28569 .23412 Mdot
.90688 .15264 Mdot
.65991 .0281 Mdot
.61444 .54895 Mdot
.72622 .40305 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50982 .60477 Mdot
.53128 .57596 Mdot
.59936 .48971 Mdot
.80699 .35153 Mdot
.23821 .49867 Mdot
.43135 .56035 Mdot
.52469 .53755 Mdot
.65491 .41557 Mdot
.98251 .39938 Mdot
.50061 .61721 Mdot
.50194 .61541 Mdot
.50619 .60967 Mdot
.51973 .59142 Mdot
.56279 .53471 Mdot
.6976 .39509 Mdot
.05832 .44796 Mdot
.33351 .57566 Mdot
.40207 .04279 Mdot
.33283 .1708 Mdot
.05648 .22206 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00424 Mdot
.49 .01351 Mdot
.46814 .04285 Mdot
.3988 .13048 Mdot
.18768 .26686 Mdot
.7559 .11941 Mdot
.56268 .06279 Mdot
.46109 .09851 Mdot
.3017 .23834 Mdot
.50099 .6167 Mdot
.50314 .61379 Mdot
.51002 .6045 Mdot
.53191 .57512 Mdot
.60136 .48738 Mdot
.81276 .35116 Mdot
.24458 .49862 Mdot
.4378 .55482 Mdot
.54008 .51806 Mdot
.70183 .37722 Mdot
.09148 .45743 Mdot
.50053 .61732 Mdot
.50167 .61577 Mdot
.50534 .61083 Mdot
.517 .5951 Mdot
.55411 .54589 Mdot
.67084 .41622 Mdot
.99737 .41379 Mdot
.32785 .54403 Mdot
.44758 .59176 Mdot
.4901 .60093 Mdot
.51778 .58448 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50707 .60848 Mdot
.52253 .58766 Mdot
.57167 .52344 Mdot
.72472 .37776 Mdot
.1135 .47428 Mdot
.34609 .59574 Mdot
.38217 .07723 Mdot
.25721 .22462 Mdot
.89377 .13329 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48971 .0139 Mdot
.46723 .04406 Mdot
.39593 .13381 Mdot
.17942 .26708 Mdot
.74727 .11956 Mdot
.55382 .07061 Mdot
.43957 .1253 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.48659 .0181 Mdot
.45731 .0572 Mdot
.36476 .16802 Mdot
.09291 .24934 Mdot
.68947 .11234 Mdot
.50771 .10519 Mdot
.3375 .23099 Mdot
.96374 .19767 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.51589 .59658 Mdot
.5506 .55046 Mdot
.65994 .42591 Mdot
.9708 .39899 Mdot
.32521 .53037 Mdot
.46706 .56068 Mdot
.55986 .50648 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51124 .60285 Mdot
.53581 .56993 Mdot
.61364 .4733 Mdot
.84782 .35276 Mdot
.27704 .49818 Mdot
.47096 .52495 Mdot
.62157 .42289 Mdot
.93732 .36628 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49487 .00692 Mdot
.48367 .02204 Mdot
.44801 .06938 Mdot
.33575 .19602 Mdot
.01857 .2132 Mdot
.6736 .08234 Mdot
.54038 .0453 Mdot
.46708 .0756 Mdot
.34475 .19776 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49021 .01323 Mdot
.4688 .04196 Mdot
.4009 .12801 Mdot
.19378 .26644 Mdot
.76267 .11937 Mdot
.56953 .05694 Mdot
.47739 .07783 Mdot
.35146 .19639 Mdot
.5013 .61628 Mdot
.50413 .61246 Mdot
.51315 .60028 Mdot
.54187 .56191 Mdot
.63267 .45268 Mdot
.90023 .36612 Mdot
.30783 .50403 Mdot
.49228 .51119 Mdot
.66517 .38411 Mdot
.04366 .42408 Mdot
.35748 .53924 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60706 Mdot
.52588 .58318 Mdot
.58227 .51026 Mdot
.75666 .36284 Mdot
.16957 .49194 Mdot
.37359 .5972 Mdot
.4073 .06032 Mdot
.30971 .1976 Mdot
.98998 .18832 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49581 .00566 Mdot
.48664 .01803 Mdot
.45747 .05699 Mdot
.36525 .16751 Mdot
.09421 .24984 Mdot
.68996 .11267 Mdot
.50766 .10557 Mdot
.33685 .23169 Mdot
.96197 .19677 Mdot
.6436 .08098 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49093 .01225 Mdot
.47111 .03889 Mdot
.40819 .11936 Mdot
.21506 .26336 Mdot
.78893 .12021 Mdot
.59443 .03772 Mdot
.5334 .00698 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51191 .60195 Mdot
.53794 .5671 Mdot
.62035 .46586 Mdot
.86657 .35616 Mdot
.2903 .499 Mdot
.4829 .51482 Mdot
.64991 .3955 Mdot
.00998 .40474 Mdot
.35509 .52128 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00548 Mdot
.48709 .01743 Mdot
.45888 .05513 Mdot
.36968 .16289 Mdot
.10612 .25414 Mdot
.69492 .11534 Mdot
.50829 .10766 Mdot
.33409 .23509 Mdot
.95371 .19278 Mdot
.64179 .07804 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .60131 Mdot
.53945 .5651 Mdot
.6251 .46071 Mdot
.87965 .35947 Mdot
.29801 .50036 Mdot
.48842 .51108 Mdot
.66146 .38579 Mdot
.03725 .42 Mdot
.35767 .53505 Mdot
.49982 .00025 Mdot
.49941 .0008 Mdot
.49812 .00253 Mdot
.49402 .00807 Mdot
.48096 .02568 Mdot
.43942 .08049 Mdot
.30918 .21795 Mdot
.95653 .17815 Mdot
.66827 .04963 Mdot
.58797 .59021 Mdot
.63299 .48077 Mdot
.85508 .36424 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48945 .01424 Mdot
.46641 .04515 Mdot
.39336 .13678 Mdot
.17204 .26698 Mdot
.74006 .11972 Mdot
.54636 .07735 Mdot
.4212 .14745 Mdot
.18262 .28197 Mdot
.72638 .13605 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48815 .016 Mdot
.46225 .05067 Mdot
.38027 .15149 Mdot
.13516 .26226 Mdot
.71082 .11916 Mdot
.51801 .10251 Mdot
.35214 .2207 Mdot
.99505 .21611 Mdot
.64538 .09931 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00198 Mdot
.49533 .0063 Mdot
.48513 .02006 Mdot
.45267 .0633 Mdot
.35025 .18253 Mdot
.05491 .23243 Mdot
.67883 .09939 Mdot
.51801 .08273 Mdot
.38415 .1809 Mdot
.09145 .26109 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50959 .60508 Mdot
.53055 .57693 Mdot
.59706 .49242 Mdot
.80031 .35219 Mdot
.23046 .49862 Mdot
.42367 .5667 Mdot
.50674 .56045 Mdot
.59991 .47379 Mdot
.8333 .346 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.49309 .00934 Mdot
.47798 .02969 Mdot
.42994 .09257 Mdot
.28016 .23747 Mdot
.89593 .14772 Mdot
.65691 .0247 Mdot
.61695 .54381 Mdot
.73704 .39676 Mdot
.09508 .47975 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.49541 .0062 Mdot
.48537 .01975 Mdot
.45342 .06231 Mdot
.3526 .18024 Mdot
.06096 .23539 Mdot
.6801 .10184 Mdot
.51531 .08767 Mdot
.37345 .19301 Mdot
.06116 .24832 Mdot
.50118 .61645 Mdot
.50374 .61298 Mdot
.51193 .60193 Mdot
.53799 .56705 Mdot
.62048 .46572 Mdot
.86694 .35624 Mdot
.29053 .49903 Mdot
.48309 .51467 Mdot
.65033 .39513 Mdot
.01101 .40532 Mdot
.35518 .5218 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60045 Mdot
.54148 .56243 Mdot
.63146 .45395 Mdot
.89695 .36496 Mdot
.30644 .50332 Mdot
.49206 .51068 Mdot
.66576 .38333 Mdot
.04553 .42496 Mdot
.35793 .53985 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51223 .60152 Mdot
.53895 .56577 Mdot
.62352 .46241 Mdot
.87532 .35829 Mdot
.29559 .49983 Mdot
.48685 .512 Mdot
.65842 .38821 Mdot
.50018 .6178 Mdot
.50056 .61727 Mdot
.50179 .61562 Mdot
.5057 .61033 Mdot
.51817 .59352 Mdot
.55783 .54108 Mdot
.68235 .40666 Mdot
.02436 .42916 Mdot
.32997 .55846 Mdot
.42636 .00629 Mdot
.41618 .08045 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .00221 Mdot
.4948 .00703 Mdot
.48343 .02236 Mdot
.44724 .07038 Mdot
.33336 .19815 Mdot
.01276 .20996 Mdot
.67304 .07933 Mdot
.54467 .03846 Mdot
.50037 .61753 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51204 .60177 Mdot
.53836 .56655 Mdot
.62166 .46444 Mdot
.87018 .357 Mdot
.29255 .4993 Mdot
.48466 .5135 Mdot
.6538 .3921 Mdot
.01938 .41001 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.54169 .56215 Mdot
.63212 .45326 Mdot
.89873 .36558 Mdot
.3072 .5037 Mdot
.4922 .51093 Mdot
.66549 .3837 Mdot
.04465 .42455 Mdot
.35771 .53958 Mdot
.50115 .61647 Mdot
.50368 .61307 Mdot
.51171 .60222 Mdot
.53731 .56795 Mdot
.61835 .46806 Mdot
.86101 .35498 Mdot
.28665 .49863 Mdot
.47985 .51726 Mdot
.64291 .40188 Mdot
.99266 .39507 Mdot
.35342 .51255 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49723 .00375 Mdot
.49116 .01194 Mdot
.47184 .03791 Mdot
.4105 .11658 Mdot
.22188 .26182 Mdot
.79824 .121 Mdot
.60245 .03245 Mdot
.54994 .60494 Mdot
.57112 .54119 Mdot
.69546 .40222 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.4934 .00891 Mdot
.47898 .02835 Mdot
.43311 .08855 Mdot
.28983 .2315 Mdot
.91525 .15659 Mdot
.66187 .0311 Mdot
.61156 .55397 Mdot
.71522 .40993 Mdot
.05193 .45723 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.5134 .59995 Mdot
.54266 .56087 Mdot
.63516 .4501 Mdot
.90689 .36862 Mdot
.31045 .50565 Mdot
.4923 .51278 Mdot
.6626 .38693 Mdot
.03654 .42051 Mdot
.35615 .53644 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49014 .01332 Mdot
.46859 .04225 Mdot
.40022 .12881 Mdot
.1918 .2666 Mdot
.76043 .11937 Mdot
.56729 .05884 Mdot
.47209 .08458 Mdot
.33523 .21147 Mdot
.99307 .20505 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .00379 Mdot
.49106 .01207 Mdot
.47153 .03832 Mdot
.40952 .11775 Mdot
.21899 .26251 Mdot
.79424 .12063 Mdot
.59906 .03461 Mdot
.54307 .6132 Mdot
.5509 .56681 Mdot
.63377 .45689 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50775 .60757 Mdot
.52468 .58478 Mdot
.57849 .51493 Mdot
.74532 .36745 Mdot
.15077 .48723 Mdot
.36241 .59948 Mdot
.39243 .07375 Mdot
.2731 .21974 Mdot
.91755 .14668 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01616 Mdot
.46188 .05117 Mdot
.37909 .15278 Mdot
.13189 .26153 Mdot
.70873 .11891 Mdot
.51632 .10381 Mdot
.34836 .22406 Mdot
.98582 .21094 Mdot
.64452 .09462 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49673 .00441 Mdot
.4896 .01405 Mdot
.46686 .04455 Mdot
.39479 .13513 Mdot
.17614 .26707 Mdot
.74401 .11963 Mdot
.55044 .07365 Mdot
.43127 .1354 Mdot
.21219 .2788 Mdot
.76109 .13161 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49213 .01063 Mdot
.47492 .03379 Mdot
.42025 .10467 Mdot
.25089 .25221 Mdot
.84281 .12905 Mdot
.63401 .01899 Mdot
.60329 .54785 Mdot
.71685 .40349 Mdot
.06398 .46122 Mdot
.50003 .618 Mdot
.50008 .61792 Mdot
.50027 .61767 Mdot
.50086 .61688 Mdot
.50273 .61434 Mdot
.5087 .60628 Mdot
.52772 .58071 Mdot
.58812 .50312 Mdot
.77405 .35726 Mdot
.19599 .49639 Mdot
.39282 .58841 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51203 .60179 Mdot
.53831 .56662 Mdot
.6215 .4646 Mdot
.86976 .3569 Mdot
.29229 .49926 Mdot
.48446 .51364 Mdot
.65338 .39246 Mdot
.01836 .40944 Mdot
.35586 .52553 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .00509 Mdot
.488 .01621 Mdot
.46177 .05131 Mdot
.37874 .15316 Mdot
.13092 .2613 Mdot
.70813 .11883 Mdot
.51586 .10416 Mdot
.34733 .22496 Mdot
.98334 .20954 Mdot
.64429 .09336 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .6042 Mdot
.53264 .57415 Mdot
.60364 .48472 Mdot
.81935 .35096 Mdot
.25148 .4985 Mdot
.44489 .54857 Mdot
.55728 .49661 Mdot
.75375 .34911 Mdot
.18888 .4859 Mdot
.50041 .61748 Mdot
.5013 .61628 Mdot
.50413 .61245 Mdot
.51316 .60027 Mdot
.54191 .56186 Mdot
.6328 .45255 Mdot
.90056 .36624 Mdot
.30797 .50411 Mdot
.4923 .51125 Mdot
.66508 .38421 Mdot
.04341 .42396 Mdot
.50054 .6173 Mdot
.50172 .61571 Mdot
.50549 .61062 Mdot
.51749 .59444 Mdot
.55567 .54388 Mdot
.67565 .41214 Mdot
.00879 .42029 Mdot
.32875 .55014 Mdot
.43861 .60564 Mdot
.45866 .0255 Mdot
.4174 .09869 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50604 .60987 Mdot
.51924 .59208 Mdot
.56124 .5367 Mdot
.69285 .39856 Mdot
.04796 .44236 Mdot
.33222 .57065 Mdot
.40889 .03254 Mdot
.35624 .14842 Mdot
.1161 .24675 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51177 .60214 Mdot
.53749 .5677 Mdot
.61893 .46742 Mdot
.86263 .35531 Mdot
.28773 .49872 Mdot
.48078 .5165 Mdot
.64507 .39988 Mdot
.99805 .39807 Mdot
.35396 .51524 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50456 .61188 Mdot
.51452 .59843 Mdot
.54624 .55617 Mdot
.64634 .43883 Mdot
.93629 .38134 Mdot
.31928 .51512 Mdot
.48579 .52827 Mdot
.63103 .42007 Mdot
.95135 .37566 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49083 .01238 Mdot
.47079 .03931 Mdot
.40719 .12056 Mdot
.21212 .26394 Mdot
.78505 .11996 Mdot
.59095 .04016 Mdot
.52596 .0162 Mdot
.49975 .01643 Mdot
.47316 .0412 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49711 .0039 Mdot
.4908 .01243 Mdot
.47068 .03945 Mdot
.40684 .12097 Mdot
.21111 .26413 Mdot
.78374 .11989 Mdot
.58976 .04102 Mdot
.52338 .01942 Mdot
.49196 .02688 Mdot
.44847 .07382 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48814 .01602 Mdot
.46222 .05072 Mdot
.38016 .15161 Mdot
.13484 .26219 Mdot
.71061 .11914 Mdot
.51783 .10265 Mdot
.35175 .22105 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48732 .01711 Mdot
.45963 .05414 Mdot
.37204 .16039 Mdot
.11252 .25623 Mdot
.69793 .11651 Mdot
.50942 .10778 Mdot
.33504 .23476 Mdot
.95519 .19376 Mdot
.64167 .07909 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00374 Mdot
.49119 .0119 Mdot
.47194 .03778 Mdot
.41082 .11619 Mdot
.22282 .26159 Mdot
.79956 .12114 Mdot
.60355 .03177 Mdot
.55214 .60233 Mdot
.57754 .53326 Mdot
.71472 .38932 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49254 .01008 Mdot
.47622 .03205 Mdot
.42437 .09955 Mdot
.26329 .24658 Mdot
.86432 .13549 Mdot
.64509 .01885 Mdot
.61459 .5396 Mdot
.7415 .39227 Mdot
.1068 .48401 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00245 Mdot
.49422 .00781 Mdot
.48158 .02485 Mdot
.44137 .07798 Mdot
.31519 .21332 Mdot
.97003 .1857 Mdot
.66956 .0566 Mdot
.57797 .60521 Mdot
.59872 .51945 Mdot
.75822 .37211 Mdot
.50073 .61705 Mdot
.50232 .61491 Mdot
.50738 .60807 Mdot
.5235 .58636 Mdot
.57475 .51959 Mdot
.73403 .37279 Mdot
.13085 .48088 Mdot
.35277 .59872 Mdot
.38402 .07894 Mdot
.2563 .22637 Mdot
.89003 .13234 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00371 Mdot
.49125 .01182 Mdot
.47212 .03754 Mdot
.41138 .11551 Mdot
.22448 .26116 Mdot
.8019 .1214 Mdot
.60548 .03061 Mdot
.55595 .59784 Mdot
.58861 .51988 Mdot
.74744 .37235 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48894 .01493 Mdot
.46479 .04731 Mdot
.38824 .14261 Mdot
.1575 .26593 Mdot
.72722 .11989 Mdot
.53324 .0893 Mdot
.38875 .18424 Mdot
.09065 .2638 Mdot
.66381 .13737 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .01391 Mdot
.4672 .0441 Mdot
.39584 .13392 Mdot
.17916 .26708 Mdot
.74701 .11957 Mdot
.55355 .07086 Mdot
.4389 .12612 Mdot
.23483 .273 Mdot
.79311 .13083 Mdot
.50129 .61629 Mdot
.50411 .61249 Mdot
.51308 .60037 Mdot
.54166 .56219 Mdot
.63202 .45336 Mdot
.89846 .36549 Mdot
.30709 .50364 Mdot
.49218 .51089 Mdot
.66554 .38364 Mdot
.0448 .42463 Mdot
.35774 .53963 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48976 .01382 Mdot
.4674 .04384 Mdot
.39646 .1332 Mdot
.18095 .26707 Mdot
.74882 .11953 Mdot
.55542 .06918 Mdot
.44348 .12049 Mdot
.24852 .26803 Mdot
.81484 .13256 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60075 Mdot
.54076 .56337 Mdot
.62921 .45632 Mdot
.89086 .36289 Mdot
.30369 .50212 Mdot
.49125 .51023 Mdot
.66568 .38291 Mdot
.04611 .42507 Mdot
.35834 .53973 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51103 .60314 Mdot
.53512 .57084 Mdot
.61148 .47574 Mdot
.84171 .35202 Mdot
.27213 .49815 Mdot
.46611 .52933 Mdot
.60964 .43553 Mdot
.90494 .35255 Mdot
.3345 .47979 Mdot
.49998 3e-05 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.4935 .00878 Mdot
.4793 .02792 Mdot
.43412 .08726 Mdot
.29293 .22947 Mdot
.92163 .15972 Mdot
.6632 .03359 Mdot
.60885 .55839 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49119 .0119 Mdot
.47193 .03779 Mdot
.41078 .11624 Mdot
.22271 .26162 Mdot
.7994 .12112 Mdot
.60342 .03185 Mdot
.55188 .60264 Mdot
.57678 .53419 Mdot
.71245 .39073 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51135 .60271 Mdot
.53615 .56948 Mdot
.61472 .47209 Mdot
.85086 .3532 Mdot
.27937 .49824 Mdot
.47321 .52296 Mdot
.62705 .41729 Mdot
.95185 .37334 Mdot
.34778 .4939 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00537 Mdot
.48733 .01711 Mdot
.45965 .05412 Mdot
.37208 .16035 Mdot
.11263 .25626 Mdot
.69799 .11653 Mdot
.50945 .10777 Mdot
.33507 .23474 Mdot
.95525 .1938 Mdot
.64168 .07913 Mdot
.50086 .61688 Mdot
.50273 .61435 Mdot
.50868 .60631 Mdot
.52766 .58079 Mdot
.58791 .50338 Mdot
.77343 .35743 Mdot
.1951 .49628 Mdot
.3921 .58882 Mdot
.43937 .02564 Mdot
.39788 .11395 Mdot
.2135 .25763 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01162 Mdot
.47259 .03691 Mdot
.41286 .11372 Mdot
.22886 .25996 Mdot
.80822 .12218 Mdot
.61053 .02776 Mdot
.56561 .58668 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49744 .00345 Mdot
.49186 .011 Mdot
.47406 .03493 Mdot
.41754 .10801 Mdot
.24278 .2554 Mdot
.82954 .1259 Mdot
.62583 .02103 Mdot
.59181 .55859 Mdot
.68798 .42211 Mdot
.005 .42674 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00466 Mdot
.48901 .01484 Mdot
.46499 .04703 Mdot
.38889 .14187 Mdot
.15934 .26612 Mdot
.72875 .11989 Mdot
.53477 .08791 Mdot
.39254 .18013 Mdot
.10108 .26766 Mdot
.66799 .13928 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49067 .0126 Mdot
.47029 .03999 Mdot
.40559 .12247 Mdot
.20742 .26477 Mdot
.77902 .11967 Mdot
.58539 .04425 Mdot
.5138 .03147 Mdot
.46288 .06557 Mdot
.35679 .18113 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49487 .00693 Mdot
.48365 .02206 Mdot
.44795 .06946 Mdot
.33556 .1962 Mdot
.0181 .21294 Mdot
.67355 .08209 Mdot
.54072 .04475 Mdot
.46831 .07393 Mdot
.34869 .19401 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48761 .01673 Mdot
.46054 .05294 Mdot
.37488 .15735 Mdot
.12028 .25854 Mdot
.70195 .11767 Mdot
.51156 .10696 Mdot
.33849 .23228 Mdot
.96265 .19798 Mdot
.64232 .08293 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50363 .61313 Mdot
.51157 .60241 Mdot
.53685 .56856 Mdot
.61691 .46966 Mdot
.85697 .35421 Mdot
.28385 .49843 Mdot
.47737 .51934 Mdot
.63706 .40742 Mdot
.97784 .38694 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.46781 .04329 Mdot
.39777 .13167 Mdot
.18472 .26698 Mdot
.75273 .11946 Mdot
.55945 .06562 Mdot
.45328 .10831 Mdot
.27802 .25358 Mdot
.86772 .14459 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49022 .0132 Mdot
.46886 .04189 Mdot
.40108 .12781 Mdot
.19428 .2664 Mdot
.76324 .11937 Mdot
.5701 .05646 Mdot
.47874 .07611 Mdot
.35559 .19236 Mdot
.04434 .23293 Mdot
.50084 .6169 Mdot
.50268 .61442 Mdot
.50853 .60652 Mdot
.52716 .58146 Mdot
.58634 .50529 Mdot
.76876 .35877 Mdot
.18826 .49535 Mdot
.38677 .59169 Mdot
.4294 .03698 Mdot
.36956 .14482 Mdot
.13524 .25564 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48713 .01738 Mdot
.45901 .05496 Mdot
.37008 .16247 Mdot
.10719 .2545 Mdot
.6954 .11555 Mdot
.50844 .10773 Mdot
.33413 .23514 Mdot
.95367 .19279 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48716 .01733 Mdot
.45912 .05482 Mdot
.37043 .1621 Mdot
.10814 .25482 Mdot
.69584 .11573 Mdot
.50859 .10777 Mdot
.3342 .23515 Mdot
.95373 .19285 Mdot
.50122 .61638 Mdot
.5039 .61276 Mdot
.51243 .60125 Mdot
.53958 .56493 Mdot
.6255 .46028 Mdot
.88076 .35979 Mdot
.29861 .5005 Mdot
.48877 .5109 Mdot
.66211 .38529 Mdot
.0387 .42082 Mdot
.35781 .53578 Mdot
.5006 .61722 Mdot
.50192 .61543 Mdot
.50613 .60975 Mdot
.51953 .5917 Mdot
.56214 .53555 Mdot
.6956 .39654 Mdot
.05399 .44564 Mdot
.33294 .5736 Mdot
.40484 .03862 Mdot
.34236 .16201 Mdot
.08022 .23327 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.4928 .00972 Mdot
.47708 .0309 Mdot
.42708 .09615 Mdot
.2715 .24235 Mdot
.87937 .14092 Mdot
.65134 .02083 Mdot
.61764 .53947 Mdot
.74476 .39201 Mdot
.11048 .4864 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00494 Mdot
.48834 .01574 Mdot
.46288 .04984 Mdot
.38224 .14932 Mdot
.14064 .26338 Mdot
.71448 .11949 Mdot
.52114 .09995 Mdot
.35941 .21398 Mdot
.01318 .22619 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .60559 Mdot
.52934 .57854 Mdot
.59324 .49696 Mdot
.78914 .35386 Mdot
.21659 .49816 Mdot
.41055 .57679 Mdot
.47728 .59778 Mdot
.51004 .58848 Mdot
.55786 .53602 Mdot
.50067 .61713 Mdot
.50213 .61516 Mdot
.50678 .60887 Mdot
.5216 .58891 Mdot
.56873 .52715 Mdot
.71579 .383 Mdot
.09609 .46676 Mdot
.34085 .59091 Mdot
.38473 .07064 Mdot
.27043 .21697 Mdot
.91936 .14537 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.4985 .00202 Mdot
.49523 .00644 Mdot
.4848 .02051 Mdot
.45161 .06468 Mdot
.34696 .18569 Mdot
.04651 .22819 Mdot
.67729 .09578 Mdot
.52232 .07516 Mdot
.40071 .16135 Mdot
.13963 .27482 Mdot
.50103 .61664 Mdot
.50328 .61361 Mdot
.51044 .60394 Mdot
.53324 .57335 Mdot
.60554 .48253 Mdot
.82479 .35098 Mdot
.2569 .49838 Mdot
.4505 .54353 Mdot
.57105 .47983 Mdot
.79467 .33806 Mdot
.24768 .48559 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50457 .61186 Mdot
.51456 .59838 Mdot
.54637 .55599 Mdot
.64675 .43842 Mdot
.93737 .38185 Mdot
.31953 .51554 Mdot
.48537 .52908 Mdot
.62931 .42196 Mdot
.94655 .37334 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50888 .60604 Mdot
.5283 .57994 Mdot
.58993 .50094 Mdot
.7794 .3559 Mdot
.20353 .4972 Mdot
.39904 .58465 Mdot
.45306 .0095 Mdot
.4377 .06579 Mdot
.33125 .19452 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49445 .0075 Mdot
.48231 .02386 Mdot
.4437 .07497 Mdot
.32239 .20752 Mdot
.98662 .19513 Mdot
.6709 .06543 Mdot
.56502 .00682 Mdot
.55399 .57575 Mdot
.6224 .47314 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.4883 .0158 Mdot
.46274 .05003 Mdot
.38179 .14982 Mdot
.13937 .26313 Mdot
.71362 .11943 Mdot
.52038 .10059 Mdot
.35763 .21566 Mdot
.00868 .22371 Mdot
.64672 .10615 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49748 .00341 Mdot
.49196 .01085 Mdot
.4744 .03448 Mdot
.41861 .10668 Mdot
.246 .25418 Mdot
.83472 .12705 Mdot
.62915 .02004 Mdot
.59672 .55383 Mdot
.70061 .41333 Mdot
.03184 .44265 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51138 .60267 Mdot
.53624 .56937 Mdot
.61499 .4718 Mdot
.85159 .35331 Mdot
.27992 .49825 Mdot
.47373 .5225 Mdot
.62832 .41601 Mdot
.95519 .37502 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49748 .0034 Mdot
.49199 .01083 Mdot
.47447 .03439 Mdot
.41882 .10643 Mdot
.24662 .25394 Mdot
.83574 .12729 Mdot
.62978 .01988 Mdot
.59762 .55298 Mdot
.70287 .41186 Mdot
.03647 .44537 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51108 .60307 Mdot
.53529 .57062 Mdot
.61202 .47514 Mdot
.84323 .35219 Mdot
.27337 .49815 Mdot
.46735 .5282 Mdot
.61271 .43223 Mdot
.91335 .35581 Mdot
.33764 .48155 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51055 .60379 Mdot
.5336 .57286 Mdot
.60669 .4812 Mdot
.82809 .35106 Mdot
.26006 .49831 Mdot
.45378 .54057 Mdot
.57912 .4702 Mdot
.81832 .33604 Mdot
.2746 .48183 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60723 Mdot
.52547 .58373 Mdot
.58098 .51185 Mdot
.75279 .36433 Mdot
.1633 .49052 Mdot
.36963 .59831 Mdot
.40155 .06583 Mdot
.29504 .20751 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61025 Mdot
.51835 .59328 Mdot
.55841 .54034 Mdot
.68413 .40525 Mdot
.02843 .43146 Mdot
.33031 .56062 Mdot
.42321 .01104 Mdot
.40536 .09369 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50773 .60759 Mdot
.52464 .58484 Mdot
.57835 .5151 Mdot
.7449 .36763 Mdot
.15006 .48703 Mdot
.36203 .59951 Mdot
.392 .07408 Mdot
.27213 .2202 Mdot
.91584 .14577 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50687 .60875 Mdot
.5219 .58851 Mdot
.56967 .52597 Mdot
.71864 .38128 Mdot
.10172 .46928 Mdot
.3424 .59266 Mdot
.38346 .07326 Mdot
.26492 .22016 Mdot
.9087 .14009 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.52369 .58611 Mdot
.57535 .51884 Mdot
.73586 .37187 Mdot
.13415 .48203 Mdot
.35422 .59905 Mdot
.38493 .07864 Mdot
.25768 .22602 Mdot
.89198 .13339 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01027 Mdot
.47577 .03265 Mdot
.42295 .10132 Mdot
.259 .24863 Mdot
.85671 .13303 Mdot
.64147 .01848 Mdot
.61157 .54134 Mdot
.73566 .3944 Mdot
.09751 .47924 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49461 .00728 Mdot
.48284 .02315 Mdot
.44538 .0728 Mdot
.32759 .20315 Mdot
.99889 .20212 Mdot
.67185 .07201 Mdot
.55534 .02173 Mdot
.52018 .00308 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60737 Mdot
.52516 .58414 Mdot
.58001 .51305 Mdot
.74987 .36551 Mdot
.15847 .48932 Mdot
.36674 .59892 Mdot
.39766 .06935 Mdot
.28545 .21325 Mdot
.9404 .15928 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49619 .00515 Mdot
.48785 .0164 Mdot
.46132 .05191 Mdot
.37733 .15469 Mdot
.12703 .26035 Mdot
.70578 .11846 Mdot
.5141 .1054 Mdot
.34356 .22818 Mdot
.97435 .20451 Mdot
.64345 .08881 Mdot
.50128 .6163 Mdot
.50409 .6125 Mdot
.51304 .60042 Mdot
.54154 .56235 Mdot
.63163 .45377 Mdot
.89742 .36512 Mdot
.30664 .50342 Mdot
.4921 .51074 Mdot
.6657 .38341 Mdot
.04533 .42487 Mdot
.35788 .5398 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00487 Mdot
.48851 .01551 Mdot
.46342 .04912 Mdot
.38394 .14743 Mdot
.14538 .26423 Mdot
.71784 .11969 Mdot
.52418 .09736 Mdot
.36664 .20703 Mdot
.03166 .23619 Mdot
.6495 .11709 Mdot
.5012 .61642 Mdot
.50381 .61289 Mdot
.51214 .60164 Mdot
.53866 .56615 Mdot
.6226 .46341 Mdot
.8728 .35764 Mdot
.29412 .49955 Mdot
.48582 .51268 Mdot
.65629 .38998 Mdot
.02529 .41333 Mdot
.35651 .52904 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00232 Mdot
.49453 .00739 Mdot
.48256 .02353 Mdot
.44449 .07395 Mdot
.32483 .20549 Mdot
.99235 .1984 Mdot
.67134 .06851 Mdot
.56049 .01377 Mdot
.53821 .59673 Mdot
.57268 .53166 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50436 .61214 Mdot
.51389 .59928 Mdot
.54423 .5588 Mdot
.64008 .44507 Mdot
.91995 .37394 Mdot
.31489 .50939 Mdot
.49068 .51803 Mdot
.6525 .39731 Mdot
.00963 .40624 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49734 .00359 Mdot
.49153 .01144 Mdot
.47303 .03632 Mdot
.41425 .11203 Mdot
.23299 .25873 Mdot
.81435 .12308 Mdot
.6152 .02537 Mdot
.57415 .57713 Mdot
.64034 .46324 Mdot
.89079 .36976 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .0025 Mdot
.49411 .00795 Mdot
.48125 .02529 Mdot
.44033 .07932 Mdot
.31198 .21582 Mdot
.96278 .18163 Mdot
.6689 .05283 Mdot
.58342 .59702 Mdot
.61743 .49776 Mdot
.81203 .36129 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49083 .01238 Mdot
.4708 .0393 Mdot
.4072 .12054 Mdot
.21217 .26393 Mdot
.78512 .11997 Mdot
.59101 .04012 Mdot
.52609 .01604 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00479 Mdot
.48872 .01524 Mdot
.46406 .04827 Mdot
.38595 .14518 Mdot
.15104 .26511 Mdot
.72208 .11983 Mdot
.52818 .09384 Mdot
.37634 .19729 Mdot
.05712 .24912 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46745 .04377 Mdot
.39662 .13301 Mdot
.1814 .26706 Mdot
.74928 .11952 Mdot
.5559 .06876 Mdot
.44464 .11905 Mdot
.252 .26659 Mdot
.82066 .13335 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49645 .00479 Mdot
.4887 .01526 Mdot
.464 .04835 Mdot
.38576 .1454 Mdot
.1505 .26504 Mdot
.72166 .11982 Mdot
.52778 .0942 Mdot
.37537 .19829 Mdot
.05453 .24786 Mdot
.65349 .12662 Mdot
.50088 .61684 Mdot
.50282 .61423 Mdot
.50898 .60591 Mdot
.5286 .57953 Mdot
.5909 .49977 Mdot
.78226 .35525 Mdot
.20746 .49755 Mdot
.4024 .58246 Mdot
.45996 .00115 Mdot
.45809 .03955 Mdot
.39409 .13065 Mdot
.49972 .00038 Mdot
.49912 .0012 Mdot
.49718 .00381 Mdot
.49102 .01213 Mdot
.47139 .03851 Mdot
.40908 .11828 Mdot
.2177 .2628 Mdot
.79248 .12048 Mdot
.59754 .03561 Mdot
.53992 .61702 Mdot
.54157 .57892 Mdot
.60486 .48859 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00333 Mdot
.49215 .0106 Mdot
.475 .03369 Mdot
.42049 .10437 Mdot
.25162 .2519 Mdot
.84404 .12937 Mdot
.63471 .01888 Mdot
.60417 .54709 Mdot
.71895 .40234 Mdot
.06795 .46344 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47324 .03604 Mdot
.41493 .1112 Mdot
.235 .25809 Mdot
.8174 .12358 Mdot
.61744 .02432 Mdot
.57809 .57283 Mdot
.65123 .4528 Mdot
.91858 .38057 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49302 .00943 Mdot
.47775 .02999 Mdot
.42923 .09346 Mdot
.278 .23873 Mdot
.89173 .14592 Mdot
.65562 .02357 Mdot
.61749 .5423 Mdot
.74003 .39505 Mdot
.10082 .48239 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50266 .61443 Mdot
.50849 .60657 Mdot
.52705 .58161 Mdot
.58597 .50573 Mdot
.76768 .3591 Mdot
.18665 .49511 Mdot
.38555 .5923 Mdot
.42719 .03943 Mdot
.3634 .15108 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.49322 .00916 Mdot
.47839 .02914 Mdot
.43124 .09092 Mdot
.28413 .23508 Mdot
.90376 .1512 Mdot
.65911 .02707 Mdot
.61531 .54731 Mdot
.72974 .40096 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49818 .00246 Mdot
.4942 .00784 Mdot
.48152 .02494 Mdot
.44117 .07824 Mdot
.31457 .21381 Mdot
.96861 .1849 Mdot
.66943 .05586 Mdot
.57905 .60359 Mdot
.60242 .51506 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46875 .04203 Mdot
.40074 .1282 Mdot
.19331 .26648 Mdot
.76213 .11937 Mdot
.56899 .0574 Mdot
.47612 .07945 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .0137 Mdot
.46769 .04344 Mdot
.3974 .1321 Mdot
.18365 .26701 Mdot
.75162 .11948 Mdot
.5583 .06663 Mdot
.45049 .11179 Mdot
.26961 .25822 Mdot
.50128 .6163 Mdot
.50408 .61252 Mdot
.51301 .60046 Mdot
.54144 .56248 Mdot
.63134 .45407 Mdot
.89663 .36484 Mdot
.3063 .50325 Mdot
.49203 .51064 Mdot
.66579 .38327 Mdot
.04565 .42501 Mdot
.35797 .53989 Mdot
.50037 .61754 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.5119 .60197 Mdot
.53789 .56717 Mdot
.62019 .46604 Mdot
.86612 .35606 Mdot
.29001 .49896 Mdot
.48267 .51499 Mdot
.64939 .39596 Mdot
.00872 .40404 Mdot
.49993 .0001 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49275 .00979 Mdot
.47692 .03111 Mdot
.42657 .09679 Mdot
.26996 .24318 Mdot
.87648 .13983 Mdot
.65024 .02033 Mdot
.61734 .53918 Mdot
.74494 .39171 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49723 .00375 Mdot
.49116 .01194 Mdot
.47185 .0379 Mdot
.41054 .11653 Mdot
.22198 .2618 Mdot
.79838 .12102 Mdot
.60257 .03238 Mdot
.55018 .60466 Mdot
.57182 .54032 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60312 Mdot
.53518 .57076 Mdot
.61167 .47553 Mdot
.84224 .35208 Mdot
.27256 .49815 Mdot
.46655 .52893 Mdot
.61073 .43436 Mdot
.90791 .35368 Mdot
.33565 .48037 Mdot
.5005 .61736 Mdot
.50158 .61589 Mdot
.50505 .61121 Mdot
.51608 .59633 Mdot
.55121 .54967 Mdot
.66182 .4242 Mdot
.97544 .40153 Mdot
.32576 .53267 Mdot
.46388 .56587 Mdot
.54829 .52178 Mdot
.70403 .38035 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49678 .00435 Mdot
.48975 .01385 Mdot
.46734 .04391 Mdot
.39628 .1334 Mdot
.18043 .26708 Mdot
.7483 .11954 Mdot
.55488 .06967 Mdot
.44215 .12212 Mdot
.24456 .26958 Mdot
.80837 .13185 Mdot
.50062 .61719 Mdot
.50198 .61535 Mdot
.50632 .6095 Mdot
.52013 .59088 Mdot
.56407 .53308 Mdot
.70153 .39232 Mdot
.06675 .4524 Mdot
.33475 .57952 Mdot
.39707 .05039 Mdot
.31554 .1856 Mdot
.01523 .1997 Mdot
.5006 .61723 Mdot
.5019 .61546 Mdot
.50606 .60985 Mdot
.51931 .59199 Mdot
.56145 .53642 Mdot
.6935 .39808 Mdot
.0494 .44314 Mdot
.33238 .57136 Mdot
.40791 .03401 Mdot
.35287 .1518 Mdot
.10726 .24387 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49748 .00341 Mdot
.49197 .01085 Mdot
.47442 .03446 Mdot
.41867 .10662 Mdot
.24615 .25412 Mdot
.83497 .12711 Mdot
.6293 .02 Mdot
.59694 .55362 Mdot
.70118 .41296 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.5041 .61249 Mdot
.51307 .60039 Mdot
.54162 .56224 Mdot
.6319 .45348 Mdot
.89815 .36538 Mdot
.30696 .50358 Mdot
.49216 .51084 Mdot
.66559 .38357 Mdot
.04497 .4247 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48856 .01545 Mdot
.46355 .04895 Mdot
.38435 .14697 Mdot
.14654 .26443 Mdot
.71869 .11973 Mdot
.52496 .09668 Mdot
.36853 .20516 Mdot
.03657 .23877 Mdot
.50028 .61766 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50901 .60586 Mdot
.5287 .5794 Mdot
.59122 .49938 Mdot
.7832 .35504 Mdot
.20874 .49765 Mdot
.40352 .58171 Mdot
.46229 .61635 Mdot
.46501 .03049 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00198 Mdot
.49533 .00631 Mdot
.48512 .02008 Mdot
.45262 .06336 Mdot
.35011 .18266 Mdot
.05455 .23225 Mdot
.67876 .09924 Mdot
.51818 .08243 Mdot
.38481 .18013 Mdot
.09336 .2618 Mdot
.50084 .61689 Mdot
.50269 .6144 Mdot
.50858 .60645 Mdot
.52732 .58125 Mdot
.58685 .50467 Mdot
.77027 .35832 Mdot
.19049 .49567 Mdot
.38848 .59081 Mdot
.43253 .03346 Mdot
.37839 .13554 Mdot
.15909 .25966 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01089 Mdot
.47431 .03461 Mdot
.41832 .10705 Mdot
.2451 .25453 Mdot
.83327 .12672 Mdot
.62823 .02029 Mdot
.5954 .55508 Mdot
.69726 .41557 Mdot
.02485 .43851 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00375 Mdot
.49115 .01195 Mdot
.47182 .03794 Mdot
.41044 .11665 Mdot
.22169 .26187 Mdot
.79798 .12098 Mdot
.60223 .03259 Mdot
.54951 .60546 Mdot
.56985 .54277 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01313 Mdot
.46903 .04166 Mdot
.40162 .12717 Mdot
.19585 .26626 Mdot
.76504 .11937 Mdot
.57189 .05497 Mdot
.48296 .07073 Mdot
.36851 .17923 Mdot
.0785 .24909 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52138 .5892 Mdot
.56803 .52804 Mdot
.71365 .38433 Mdot
.09179 .46478 Mdot
.33976 .58948 Mdot
.38596 .06835 Mdot
.27537 .21402 Mdot
.50027 .61767 Mdot
.50086 .61688 Mdot
.50272 .61435 Mdot
.50868 .60631 Mdot
.52765 .58081 Mdot
.58789 .50341 Mdot
.77335 .35745 Mdot
.19498 .49627 Mdot
.39201 .58888 Mdot
.43919 .02586 Mdot
.39735 .11456 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51281 .60074 Mdot
.54078 .56335 Mdot
.62926 .45626 Mdot
.89101 .36294 Mdot
.30376 .50215 Mdot
.49127 .51023 Mdot
.6657 .38291 Mdot
.04614 .42509 Mdot
.35834 .53975 Mdot
.50055 .6173 Mdot
.50174 .61568 Mdot
.50555 .61053 Mdot
.51769 .59417 Mdot
.5563 .54306 Mdot
.6776 .41052 Mdot
.01336 .4229 Mdot
.3291 .55259 Mdot
.43499 .61119 Mdot
.44607 .0422 Mdot
.37778 .14469 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48962 .01402 Mdot
.46694 .04445 Mdot
.39501 .13487 Mdot
.17679 .26708 Mdot
.74465 .11962 Mdot
.5511 .07305 Mdot
.4329 .13343 Mdot
.217 .27782 Mdot
.76748 .13116 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49245 .01019 Mdot
.47596 .03239 Mdot
.42355 .10057 Mdot
.26081 .24778 Mdot
.8599 .13403 Mdot
.64303 .01858 Mdot
.61296 .54047 Mdot
.73847 .39331 Mdot
.10208 .48159 Mdot
.5013 .61627 Mdot
.50416 .61242 Mdot
.51325 .60015 Mdot
.54218 .56151 Mdot
.63364 .45167 Mdot
.90282 .36707 Mdot
.30888 .50464 Mdot
.49236 .51172 Mdot
.66438 .38501 Mdot
.04142 .42298 Mdot
.35703 .5384 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48836 .01571 Mdot
.46294 .04976 Mdot
.38243 .14911 Mdot
.14116 .26348 Mdot
.71485 .11952 Mdot
.52146 .09968 Mdot
.36017 .21327 Mdot
.01509 .22724 Mdot
.64741 .1093 Mdot
.50053 .61732 Mdot
.50168 .61577 Mdot
.50535 .61081 Mdot
.51704 .59505 Mdot
.55423 .54574 Mdot
.67121 .41591 Mdot
.99825 .41429 Mdot
.32792 .5445 Mdot
.4469 .59282 Mdot
.4877 .60421 Mdot
.51007 .59487 Mdot
.50086 .61688 Mdot
.50272 .61435 Mdot
.50868 .60631 Mdot
.52765 .5808 Mdot
.5879 .50339 Mdot
.77339 .35744 Mdot
.19504 .49627 Mdot
.39205 .58885 Mdot
.43927 .02576 Mdot
.39759 .11428 Mdot
.21268 .25779 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48874 .0152 Mdot
.46415 .04815 Mdot
.38625 .14485 Mdot
.15187 .26523 Mdot
.72272 .11985 Mdot
.5288 .09329 Mdot
.37785 .19574 Mdot
.06114 .25103 Mdot
.65496 .12902 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .0139 Mdot
.46721 .04409 Mdot
.39587 .13388 Mdot
.17924 .26708 Mdot
.74709 .11956 Mdot
.55363 .07079 Mdot
.43909 .12588 Mdot
.23541 .27281 Mdot
.50021 .61775 Mdot
.50067 .61712 Mdot
.50215 .61513 Mdot
.50684 .60879 Mdot
.5218 .58864 Mdot
.56936 .52636 Mdot
.71769 .38184 Mdot
.09985 .46846 Mdot
.34187 .5921 Mdot
.38384 .07244 Mdot
.26662 .21918 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48891 .01498 Mdot
.46467 .04746 Mdot
.38788 .14302 Mdot
.15647 .26581 Mdot
.72638 .11989 Mdot
.5324 .09006 Mdot
.38668 .18646 Mdot
.08499 .26155 Mdot
.66179 .1361 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.48769 .01662 Mdot
.46081 .05259 Mdot
.37572 .15644 Mdot
.12259 .25918 Mdot
.70323 .11796 Mdot
.51236 .10652 Mdot
.34002 .23108 Mdot
.96611 .19991 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51274 .60083 Mdot
.54058 .56362 Mdot
.62862 .45694 Mdot
.88928 .36238 Mdot
.30294 .50184 Mdot
.49095 .51022 Mdot
.6654 .38303 Mdot
.04565 .42477 Mdot
.35836 .53942 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.5115 .60251 Mdot
.53662 .56886 Mdot
.6162 .47045 Mdot
.85499 .35386 Mdot
.28242 .49836 Mdot
.47607 .52046 Mdot
.63395 .41043 Mdot
.96986 .38266 Mdot
.35071 .50163 Mdot
.50059 .61724 Mdot
.50187 .61551 Mdot
.50595 .60999 Mdot
.51897 .59245 Mdot
.56036 .53782 Mdot
.69015 .40059 Mdot
.04198 .43906 Mdot
.33157 .56764 Mdot
.41311 .02622 Mdot
.37068 .13335 Mdot
.15492 .25534 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .6089 Mdot
.52154 .58899 Mdot
.56854 .52739 Mdot
.71521 .38336 Mdot
.09493 .46623 Mdot
.34055 .59054 Mdot
.38504 .07005 Mdot
.2717 .21622 Mdot
.92185 .14665 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50396 .61268 Mdot
.51261 .601 Mdot
.54017 .56416 Mdot
.62735 .4583 Mdot
.8858 .36128 Mdot
.30123 .50125 Mdot
.49018 .51035 Mdot
.66443 .38362 Mdot
.04372 .42364 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48947 .01422 Mdot
.46646 .04509 Mdot
.3935 .13661 Mdot
.17246 .26699 Mdot
.74046 .11971 Mdot
.54676 .07698 Mdot
.42221 .14626 Mdot
.18556 .28187 Mdot
.72948 .13555 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50056 .61727 Mdot
.5018 .6156 Mdot
.50573 .6103 Mdot
.51825 .59341 Mdot
.55808 .54075 Mdot
.68313 .40604 Mdot
.02613 .43016 Mdot
.33012 .5594 Mdot
.42498 .00837 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00529 Mdot
.48753 .01684 Mdot
.46028 .05328 Mdot
.37407 .15821 Mdot
.11808 .25791 Mdot
.70077 .11737 Mdot
.51087 .1073 Mdot
.33726 .23322 Mdot
.9599 .19644 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.5074 .60804 Mdot
.52357 .58627 Mdot
.57496 .51933 Mdot
.73467 .37247 Mdot
.132 .48128 Mdot
.35327 .59884 Mdot
.50008 .61793 Mdot
.50026 .61769 Mdot
.50082 .61693 Mdot
.5026 .61452 Mdot
.50828 .60685 Mdot
.52638 .58251 Mdot
.58386 .50832 Mdot
.76138 .36115 Mdot
.17702 .49346 Mdot
.3786 .5954 Mdot
.41522 .0523 Mdot
.50111 .61653 Mdot
.50354 .61324 Mdot
.51129 .60278 Mdot
.53597 .56972 Mdot
.61414 .47275 Mdot
.84922 .35296 Mdot
.27812 .4982 Mdot
.47201 .52402 Mdot
.62412 .42027 Mdot
.94412 .36952 Mdot
.34622 .49091 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49897 .00139 Mdot
.49673 .00441 Mdot
.48959 .01406 Mdot
.46684 .04457 Mdot
.39472 .13521 Mdot
.17595 .26707 Mdot
.74383 .11964 Mdot
.55025 .07382 Mdot
.43081 .13596 Mdot
.21082 .27906 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.5259 .58315 Mdot
.58235 .51016 Mdot
.7569 .36275 Mdot
.16995 .49202 Mdot
.37383 .59712 Mdot
.40768 .05995 Mdot
.31067 .1969 Mdot
.99208 .18956 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.49281 .00972 Mdot
.47709 .03088 Mdot
.42712 .09611 Mdot
.2716 .2423 Mdot
.87956 .141 Mdot
.65142 .02087 Mdot
.61765 .53949 Mdot
.74473 .39203 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61076 Mdot
.51716 .59488 Mdot
.55462 .54523 Mdot
.67242 .41487 Mdot
.00114 .41593 Mdot
.32815 .54604 Mdot
.44464 .59633 Mdot
.47975 .61505 Mdot
.48458 .01129 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00413 Mdot
.49025 .01316 Mdot
.46896 .04176 Mdot
.40139 .12744 Mdot
.19519 .26632 Mdot
.76428 .11937 Mdot
.57114 .05559 Mdot
.48118 .073 Mdot
.36307 .18485 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.50631 .6095 Mdot
.52012 .59091 Mdot
.56401 .53315 Mdot
.70135 .39245 Mdot
.06635 .45219 Mdot
.33469 .57934 Mdot
.39729 .05005 Mdot
.31632 .18497 Mdot
.01703 .20073 Mdot
.50058 .61726 Mdot
.50184 .61555 Mdot
.50585 .61013 Mdot
.51863 .5929 Mdot
.55931 .53918 Mdot
.6869 .40308 Mdot
.0347 .435 Mdot
.33086 .5639 Mdot
.41845 .0182 Mdot
.389 .11297 Mdot
.20621 .25496 Mdot
.501 .61668 Mdot
.50319 .61373 Mdot
.51016 .60432 Mdot
.53236 .57453 Mdot
.60275 .48575 Mdot
.81679 .35101 Mdot
.24885 .49855 Mdot
.44218 .55098 Mdot
.55067 .50479 Mdot
.7339 .358 Mdot
.15463 .47984 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00223 Mdot
.49474 .0071 Mdot
.48325 .0226 Mdot
.44668 .07111 Mdot
.33162 .19968 Mdot
.00854 .20759 Mdot
.67265 .07712 Mdot
.54787 .03342 Mdot
.4938 .03916 Mdot
.43043 .10163 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48755 .01681 Mdot
.46034 .0532 Mdot
.37427 .158 Mdot
.11861 .25806 Mdot
.70106 .11744 Mdot
.51103 .10722 Mdot
.33754 .23301 Mdot
.96052 .19679 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00414 Mdot
.49025 .01317 Mdot
.46894 .04179 Mdot
.40132 .12751 Mdot
.195 .26634 Mdot
.76406 .11937 Mdot
.57092 .05578 Mdot
.48067 .07365 Mdot
.3615 .18645 Mdot
.05982 .24061 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.5078 .6075 Mdot
.52484 .58457 Mdot
.57899 .51431 Mdot
.74681 .3668 Mdot
.15331 .48795 Mdot
.3638 .59935 Mdot
.39403 .07246 Mdot
.27679 .21792 Mdot
.9242 .15027 Mdot
.50119 .61643 Mdot
.50379 .61292 Mdot
.51206 .60175 Mdot
.5384 .56649 Mdot
.6218 .46428 Mdot
.87058 .35709 Mdot
.29279 .49934 Mdot
.48484 .51337 Mdot
.6542 .39176 Mdot
.02032 .41055 Mdot
.35605 .52653 Mdot
.4999 .00013 Mdot
.49969 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48981 .01376 Mdot
.46755 .04363 Mdot
.39696 .13262 Mdot
.18238 .26704 Mdot
.7503 .1195 Mdot
.55694 .06783 Mdot
.44719 .11589 Mdot
.25967 .26317 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01053 Mdot
.47516 .03347 Mdot
.42101 .10373 Mdot
.25317 .25124 Mdot
.84665 .13008 Mdot
.63618 .01868 Mdot
.60594 .5456 Mdot
.72315 .40015 Mdot
.0757 .46771 Mdot
.49964 .00049 Mdot
.49886 .00155 Mdot
.49636 .00492 Mdot
.48839 .01568 Mdot
.46302 .04965 Mdot
.38269 .14881 Mdot
.14191 .26362 Mdot
.71536 .11955 Mdot
.52192 .09929 Mdot
.36126 .21223 Mdot
.01787 .22876 Mdot
.64773 .11064 Mdot
.49975 .00034 Mdot
.4992 .00109 Mdot
.49744 .00346 Mdot
.49184 .01102 Mdot
.47402 .035 Mdot
.41738 .1082 Mdot
.24232 .25557 Mdot
.82879 .12574 Mdot
.62534 .02119 Mdot
.59106 .55934 Mdot
.68603 .42355 Mdot
.00072 .42421 Mdot
.50062 .6172 Mdot
.50198 .61536 Mdot
.5063 .60953 Mdot
.52006 .59098 Mdot
.56384 .53337 Mdot
.70083 .39281 Mdot
.06526 .45162 Mdot
.33452 .57885 Mdot
.39791 .0491 Mdot
.31847 .1832 Mdot
.02205 .20358 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00455 Mdot
.48928 .01448 Mdot
.46586 .04589 Mdot
.39161 .13878 Mdot
.16706 .26674 Mdot
.73547 .11981 Mdot
.54161 .08167 Mdot
.40946 .16115 Mdot
.14872 .27981 Mdot
.69597 .14069 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50408 .61253 Mdot
.51299 .6005 Mdot
.54136 .56259 Mdot
.63108 .45435 Mdot
.89592 .3646 Mdot
.30599 .5031 Mdot
.49195 .51056 Mdot
.66585 .38316 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .60559 Mdot
.52934 .57855 Mdot
.59323 .49698 Mdot
.78911 .35386 Mdot
.21654 .49816 Mdot
.4105 .57682 Mdot
.47718 .5979 Mdot
.50976 .58887 Mdot
.55695 .53719 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49261 .00998 Mdot
.47647 .03171 Mdot
.42517 .09855 Mdot
.26572 .24537 Mdot
.86869 .13699 Mdot
.64703 .01926 Mdot
.61586 .53913 Mdot
.74354 .3917 Mdot
.10975 .48557 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50611 .60978 Mdot
.51947 .59177 Mdot
.56196 .53577 Mdot
.69506 .39693 Mdot
.05281 .44499 Mdot
.33279 .57302 Mdot
.40562 .03745 Mdot
.34503 .15946 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50344 .61339 Mdot
.51096 .60324 Mdot
.5349 .57114 Mdot
.61078 .47653 Mdot
.83974 .35183 Mdot
.27047 .49815 Mdot
.46445 .53084 Mdot
.60553 .44002 Mdot
.89357 .34854 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46846 .04242 Mdot
.39982 .12928 Mdot
.19063 .26668 Mdot
.75913 .11938 Mdot
.56597 .05996 Mdot
.46895 .08856 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00279 Mdot
.49343 .00888 Mdot
.47907 .02823 Mdot
.43339 .08819 Mdot
.29071 .23093 Mdot
.91705 .15747 Mdot
.66226 .03178 Mdot
.61084 .55517 Mdot
.71256 .41168 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49072 .01253 Mdot
.47045 .03977 Mdot
.40609 .12187 Mdot
.20891 .26452 Mdot
.78091 .11975 Mdot
.58715 .04293 Mdot
.51768 .02657 Mdot
.47468 .04994 Mdot
.39387 .1412 Mdot
.50113 .6165 Mdot
.50361 .61315 Mdot
.51151 .6025 Mdot
.53665 .56882 Mdot
.61628 .47036 Mdot
.85522 .3539 Mdot
.28259 .49836 Mdot
.47622 .52032 Mdot
.63432 .41007 Mdot
.97081 .38316 Mdot
.35084 .50207 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04864 Mdot
.38509 .14614 Mdot
.14863 .26476 Mdot
.72024 .11978 Mdot
.52642 .0954 Mdot
.37206 .20164 Mdot
.04581 .24352 Mdot
.65178 .12319 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61117 Mdot
.51618 .5962 Mdot
.5515 .54929 Mdot
.66273 .42338 Mdot
.97769 .40276 Mdot
.32601 .5338 Mdot
.4623 .56842 Mdot
.54257 .52943 Mdot
.68594 .39367 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49947 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48301 .02292 Mdot
.44592 .0721 Mdot
.32926 .20172 Mdot
.00286 .20438 Mdot
.67217 .07412 Mdot
.55224 .02656 Mdot
.50926 .01798 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01634 Mdot
.46145 .05173 Mdot
.37774 .15425 Mdot
.12817 .26063 Mdot
.70645 .11858 Mdot
.51459 .10507 Mdot
.34459 .22731 Mdot
.97679 .20587 Mdot
.64368 .09004 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57438 .52005 Mdot
.73293 .37335 Mdot
.12884 .48016 Mdot
.35192 .59848 Mdot
.38356 .07901 Mdot
.25571 .22646 Mdot
.88929 .13191 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49553 .00604 Mdot
.48577 .01922 Mdot
.45467 .06067 Mdot
.35651 .17639 Mdot
.07111 .24014 Mdot
.68256 .10564 Mdot
.51162 .09488 Mdot
.35811 .20967 Mdot
.01885 .22711 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49462 .00726 Mdot
.48288 .02311 Mdot
.44549 .07266 Mdot
.32793 .20287 Mdot
.99968 .20257 Mdot
.67191 .07243 Mdot
.55471 .0227 Mdot
.51798 .00607 Mdot
.50816 .61654 Mdot
.4998 .00027 Mdot
.49936 .00086 Mdot
.49798 .00273 Mdot
.49355 .00871 Mdot
.47946 .0277 Mdot
.43463 .08661 Mdot
.2945 .22842 Mdot
.9249 .16136 Mdot
.66382 .03492 Mdot
.60731 .56084 Mdot
.69986 .42056 Mdot
.01938 .43848 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60624 Mdot
.52783 .58057 Mdot
.58844 .50274 Mdot
.77499 .35701 Mdot
.19734 .49655 Mdot
.39391 .58778 Mdot
.44286 .02159 Mdot
.40792 .10227 Mdot
.24245 .24965 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51218 .60158 Mdot
.5388 .56597 Mdot
.62304 .46294 Mdot
.87399 .35795 Mdot
.29482 .49968 Mdot
.48632 .51234 Mdot
.65733 .38911 Mdot
.02774 .4147 Mdot
.35675 .53028 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00468 Mdot
.48897 .0149 Mdot
.46487 .0472 Mdot
.38849 .14232 Mdot
.15821 .266 Mdot
.72781 .11989 Mdot
.53383 .08876 Mdot
.39021 .18267 Mdot
.09465 .26533 Mdot
.66534 .13817 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00352 Mdot
.49171 .0112 Mdot
.47359 .03557 Mdot
.41603 .10986 Mdot
.23827 .25701 Mdot
.82242 .12447 Mdot
.62102 .02279 Mdot
.58415 .56639 Mdot
.66771 .43814 Mdot
.95878 .40035 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50344 .61339 Mdot
.51096 .60324 Mdot
.53489 .57115 Mdot
.61075 .47656 Mdot
.83966 .35182 Mdot
.27041 .49815 Mdot
.46438 .5309 Mdot
.60537 .4402 Mdot
.89311 .34839 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49243 .01022 Mdot
.47589 .03249 Mdot
.42332 .10085 Mdot
.26014 .2481 Mdot
.85871 .13366 Mdot
.64245 .01853 Mdot
.61247 .54077 Mdot
.73749 .39368 Mdot
.1005 .48078 Mdot
.50129 .61628 Mdot
.50413 .61246 Mdot
.51314 .60029 Mdot
.54185 .56194 Mdot
.63262 .45274 Mdot
.90008 .36607 Mdot
.30777 .504 Mdot
.49228 .51116 Mdot
.6652 .38407 Mdot
.04377 .42413 Mdot
.35751 .53928 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.53939 .56518 Mdot
.62491 .46092 Mdot
.87913 .35933 Mdot
.29772 .50029 Mdot
.48824 .51118 Mdot
.66114 .38604 Mdot
.03651 .41959 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50768 .60766 Mdot
.52447 .58506 Mdot
.57782 .51576 Mdot
.7433 .36835 Mdot
.1473 .48622 Mdot
.36057 .59957 Mdot
.39044 .07527 Mdot
.26865 .2218 Mdot
.90976 .14256 Mdot
.50131 .61627 Mdot
.50417 .61241 Mdot
.51327 .60012 Mdot
.54226 .5614 Mdot
.63389 .45141 Mdot
.9035 .36733 Mdot
.30915 .5048 Mdot
.49237 .51187 Mdot
.66413 .38529 Mdot
.04073 .42263 Mdot
.35689 .53813 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47738 .0305 Mdot
.42803 .09496 Mdot
.27438 .24078 Mdot
.88479 .14306 Mdot
.65331 .02191 Mdot
.61785 .54041 Mdot
.74346 .39299 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00552 Mdot
.48699 .01757 Mdot
.45857 .05554 Mdot
.3687 .16392 Mdot
.10347 .25323 Mdot
.69374 .11481 Mdot
.50798 .10741 Mdot
.3342 .23478 Mdot
.95431 .19301 Mdot
.64202 .07813 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00203 Mdot
.4952 .00648 Mdot
.48472 .02063 Mdot
.45134 .06504 Mdot
.34611 .18649 Mdot
.04436 .22709 Mdot
.67693 .09482 Mdot
.52351 .0731 Mdot
.40523 .15585 Mdot
.15306 .27686 Mdot
.50019 .61778 Mdot
.50059 .61724 Mdot
.50188 .61549 Mdot
.50599 .60994 Mdot
.51908 .5923 Mdot
.56071 .53738 Mdot
.69122 .39978 Mdot
.04436 .44037 Mdot
.33182 .56885 Mdot
.41141 .02877 Mdot
.36486 .13953 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00272 Mdot
.4936 .00865 Mdot
.4796 .02751 Mdot
.43508 .08605 Mdot
.29585 .22751 Mdot
.92773 .16279 Mdot
.66433 .03611 Mdot
.60589 .56306 Mdot
.69484 .42429 Mdot
.00832 .432 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48894 .01494 Mdot
.46476 .04734 Mdot
.38816 .1427 Mdot
.15727 .2659 Mdot
.72703 .11989 Mdot
.53305 .08947 Mdot
.38828 .18475 Mdot
.08935 .2633 Mdot
.66333 .13709 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49784 .00292 Mdot
.49312 .00929 Mdot
.47808 .02955 Mdot
.43027 .09215 Mdot
.28117 .23687 Mdot
.8979 .14858 Mdot
.65749 .02527 Mdot
.61661 .54461 Mdot
.73541 .39769 Mdot
.09193 .47825 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51026 .60418 Mdot
.53267 .57411 Mdot
.60373 .48462 Mdot
.8196 .35096 Mdot
.25174 .49849 Mdot
.44516 .54833 Mdot
.55794 .4958 Mdot
.75573 .34835 Mdot
.19209 .48623 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50872 .60625 Mdot
.52779 .58062 Mdot
.58832 .50289 Mdot
.77463 .3571 Mdot
.19683 .49649 Mdot
.39349 .58803 Mdot
.44204 .02254 Mdot
.40557 .10504 Mdot
.23561 .25198 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00526 Mdot
.48759 .01676 Mdot
.46047 .05303 Mdot
.37466 .15758 Mdot
.11969 .25837 Mdot
.70163 .11759 Mdot
.51137 .10706 Mdot
.33814 .23255 Mdot
.96187 .19754 Mdot
.64225 .08254 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49756 .0033 Mdot
.49221 .01052 Mdot
.47519 .03343 Mdot
.4211 .10362 Mdot
.25344 .25113 Mdot
.8471 .1302 Mdot
.63643 .01866 Mdot
.60624 .54536 Mdot
.50013 .61786 Mdot
.5004 .6175 Mdot
.50127 .61632 Mdot
.50405 .61257 Mdot
.51289 .60063 Mdot
.54105 .563 Mdot
.6301 .45538 Mdot
.89327 .36369 Mdot
.30481 .50257 Mdot
.49163 .51033 Mdot
.6659 .38291 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61716 Mdot
.50205 .61526 Mdot
.50654 .6092 Mdot
.52083 .58994 Mdot
.56629 .53025 Mdot
.70833 .38773 Mdot
.08096 .45959 Mdot
.33732 .58548 Mdot
.38999 .0615 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50749 .60792 Mdot
.52386 .58589 Mdot
.57587 .51818 Mdot
.73744 .37109 Mdot
.137 .48299 Mdot
.35551 .59928 Mdot
.38586 .07822 Mdot
.2593 .22551 Mdot
.89441 .13465 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51259 .60104 Mdot
.54009 .56426 Mdot
.6271 .45857 Mdot
.88512 .36108 Mdot
.30088 .50114 Mdot
.49001 .51039 Mdot
.66418 .38379 Mdot
.0432 .42334 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.50809 .6071 Mdot
.52578 .5833 Mdot
.58198 .51062 Mdot
.75579 .36317 Mdot
.16817 .49164 Mdot
.37268 .59747 Mdot
.40595 .06165 Mdot
.3062 .20009 Mdot
.49995 7e-05 Mdot
.49982 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49433 .00766 Mdot
.48195 .02436 Mdot
.44253 .07648 Mdot
.31878 .21046 Mdot
.97825 .19036 Mdot
.67024 .06096 Mdot
.57161 .61482 Mdot
.5768 .54636 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50741 .60802 Mdot
.52362 .58621 Mdot
.57511 .51913 Mdot
.73515 .37223 Mdot
.13287 .48159 Mdot
.35365 .59893 Mdot
.38456 .07878 Mdot
.25708 .22618 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49594 .00549 Mdot
.48706 .01747 Mdot
.45879 .05525 Mdot
.36939 .16319 Mdot
.10535 .25388 Mdot
.69457 .11519 Mdot
.50819 .1076 Mdot
.33409 .23503 Mdot
.95381 .1928 Mdot
.64185 .07803 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48934 .01439 Mdot
.46605 .04563 Mdot
.39223 .13807 Mdot
.16882 .26684 Mdot
.73707 .11978 Mdot
.54326 .08017 Mdot
.41355 .15642 Mdot
.16045 .28122 Mdot
.49995 6e-05 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00198 Mdot
.49532 .00632 Mdot
.4851 .02011 Mdot
.45256 .06344 Mdot
.34991 .18286 Mdot
.05404 .232 Mdot
.67866 .09903 Mdot
.51843 .08198 Mdot
.38578 .17901 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.5119 .60197 Mdot
.53789 .56717 Mdot
.62019 .46604 Mdot
.86611 .35605 Mdot
.29001 .49896 Mdot
.48267 .515 Mdot
.64938 .39597 Mdot
.00869 .40402 Mdot
.35497 .52062 Mdot
.49978 .0003 Mdot
.49929 .00095 Mdot
.49775 .00304 Mdot
.49283 .00968 Mdot
.47716 .03078 Mdot
.42736 .09581 Mdot
.27233 .24191 Mdot
.88091 .14153 Mdot
.65192 .02112 Mdot
.61775 .53969 Mdot
.74451 .39223 Mdot
.10987 .48619 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48992 .01361 Mdot
.46791 .04316 Mdot
.39808 .13131 Mdot
.18561 .26695 Mdot
.75368 .11944 Mdot
.56042 .06476 Mdot
.45563 .10537 Mdot
.28515 .24933 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48731 .01714 Mdot
.45958 .05421 Mdot
.37187 .16056 Mdot
.11207 .25609 Mdot
.69772 .11643 Mdot
.50933 .10779 Mdot
.33491 .23483 Mdot
.95495 .19362 Mdot
.64166 .07896 Mdot
.50113 .61651 Mdot
.5036 .61318 Mdot
.51146 .60257 Mdot
.53648 .56904 Mdot
.61576 .47094 Mdot
.85375 .35366 Mdot
.28153 .49831 Mdot
.47524 .52118 Mdot
.63195 .41239 Mdot
.96469 .37992 Mdot
.34996 .49931 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51108 .60307 Mdot
.5353 .57062 Mdot
.61202 .47513 Mdot
.84324 .35219 Mdot
.27338 .49815 Mdot
.46736 .52819 Mdot
.61274 .4322 Mdot
.91342 .35584 Mdot
.33766 .48156 Mdot
.50083 .61691 Mdot
.50264 .61447 Mdot
.50841 .60667 Mdot
.5268 .58195 Mdot
.58519 .50669 Mdot
.76534 .35983 Mdot
.18312 .49454 Mdot
.38294 .59354 Mdot
.42257 .04448 Mdot
.3506 .16353 Mdot
.08601 .23943 Mdot
.50071 .61708 Mdot
.50225 .615 Mdot
.50717 .60835 Mdot
.52283 .58727 Mdot
.57261 .52226 Mdot
.72758 .37618 Mdot
.11891 .47644 Mdot
.34801 .59688 Mdot
.38224 .07832 Mdot
.25552 .22577 Mdot
.89021 .13188 Mdot
.50089 .61683 Mdot
.50285 .61419 Mdot
.50907 .60579 Mdot
.52888 .57917 Mdot
.59177 .49873 Mdot
.78481 .3547 Mdot
.2109 .49781 Mdot
.40542 .58042 Mdot
.46628 .61145 Mdot
.47692 .01474 Mdot
.45308 .05761 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51437 .59864 Mdot
.54574 .55682 Mdot
.64478 .44036 Mdot
.93226 .37944 Mdot
.31831 .51361 Mdot
.48727 .52539 Mdot
.63717 .41339 Mdot
.96829 .38419 Mdot
.50114 .61649 Mdot
.50364 .61311 Mdot
.51161 .60236 Mdot
.53698 .56839 Mdot
.61731 .46922 Mdot
.8581 .35442 Mdot
.28464 .49848 Mdot
.47808 .51874 Mdot
.63875 .40579 Mdot
.98217 .38929 Mdot
.35228 .50741 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.5119 .60197 Mdot
.53789 .56718 Mdot
.62017 .46606 Mdot
.86606 .35604 Mdot
.28997 .49896 Mdot
.48264 .51502 Mdot
.64932 .39602 Mdot
.00855 .40394 Mdot
.35496 .52055 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52556 .5836 Mdot
.58129 .51147 Mdot
.7537 .36397 Mdot
.16479 .49087 Mdot
.37055 .59807 Mdot
.40285 .06462 Mdot
.2983 .20542 Mdot
.96592 .17407 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49743 .00347 Mdot
.49182 .01105 Mdot
.47395 .03509 Mdot
.41718 .10845 Mdot
.2417 .2558 Mdot
.82781 .12554 Mdot
.62469 .02141 Mdot
.59005 .56035 Mdot
.68339 .42554 Mdot
.99486 .42077 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .00421 Mdot
.49008 .0134 Mdot
.46841 .04249 Mdot
.39965 .12948 Mdot
.19015 .26671 Mdot
.7586 .11938 Mdot
.56543 .06042 Mdot
.46767 .09018 Mdot
.32175 .22299 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00297 Mdot
.49298 .00948 Mdot
.47765 .03013 Mdot
.42891 .09386 Mdot
.27704 .23928 Mdot
.88987 .14514 Mdot
.65503 .0231 Mdot
.61766 .54172 Mdot
.74113 .39441 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00548 Mdot
.48708 .01744 Mdot
.45887 .05515 Mdot
.36963 .16294 Mdot
.10599 .2541 Mdot
.69486 .11532 Mdot
.50827 .10765 Mdot
.33409 .23508 Mdot
.95372 .19278 Mdot
.6418 .07804 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50132 .61624 Mdot
.50422 .61233 Mdot
.51345 .59988 Mdot
.54282 .56066 Mdot
.63566 .44958 Mdot
.90822 .36913 Mdot
.31095 .50599 Mdot
.49224 .51319 Mdot
.66188 .38769 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.5078 .6075 Mdot
.52485 .58456 Mdot
.57902 .51428 Mdot
.7469 .36676 Mdot
.15347 .48799 Mdot
.36389 .59934 Mdot
.39413 .07237 Mdot
.27704 .21779 Mdot
.92464 .15051 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60044 Mdot
.54149 .56241 Mdot
.6315 .45391 Mdot
.89706 .36499 Mdot
.30649 .50334 Mdot
.49207 .51069 Mdot
.66575 .38334 Mdot
.04548 .42494 Mdot
.35792 .53984 Mdot
.49994 7e-05 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.4943 .00771 Mdot
.48183 .02452 Mdot
.44216 .07696 Mdot
.31763 .21139 Mdot
.9756 .18885 Mdot
.67003 .05955 Mdot
.57368 .61169 Mdot
.58393 .53744 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50824 .6069 Mdot
.52626 .58267 Mdot
.58349 .50877 Mdot
.76028 .36153 Mdot
.17531 .49313 Mdot
.37742 .59586 Mdot
.41329 .05429 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.49769 .00312 Mdot
.49265 .00993 Mdot
.47657 .03158 Mdot
.42548 .09817 Mdot
.26664 .24491 Mdot
.87037 .13759 Mdot
.64775 .01946 Mdot
.61627 .53904 Mdot
.74408 .3916 Mdot
.5001 .61789 Mdot
.50033 .61759 Mdot
.50104 .61662 Mdot
.50333 .61354 Mdot
.51061 .60371 Mdot
.53378 .57263 Mdot
.60724 .48056 Mdot
.82967 .35112 Mdot
.26154 .49828 Mdot
.4553 .53917 Mdot
.5829 .46575 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01025 Mdot
.47583 .03257 Mdot
.42314 .10109 Mdot
.25957 .24836 Mdot
.85771 .13334 Mdot
.64196 .0185 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00232 Mdot
.49453 .00739 Mdot
.48256 .02353 Mdot
.4445 .07394 Mdot
.32485 .20547 Mdot
.99239 .19842 Mdot
.67134 .06853 Mdot
.56045 .01383 Mdot
.53808 .5969 Mdot
.57227 .53218 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49605 .00534 Mdot
.4874 .01701 Mdot
.45988 .05382 Mdot
.3728 .15958 Mdot
.1146 .25687 Mdot
.69897 .11684 Mdot
.50991 .10766 Mdot
.33571 .23432 Mdot
.95657 .19456 Mdot
.64177 .07984 Mdot
.50003 .618 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.5009 .61681 Mdot
.50288 .61414 Mdot
.50917 .60564 Mdot
.52922 .57871 Mdot
.59286 .49743 Mdot
.788 .35407 Mdot
.21511 .49808 Mdot
.4092 .57777 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50176 .61565 Mdot
.50562 .61044 Mdot
.51791 .59388 Mdot
.557 .54216 Mdot
.67977 .40875 Mdot
.01839 .42576 Mdot
.32949 .55528 Mdot
.43103 .61724 Mdot
.4323 .06009 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49903 .00132 Mdot
.4969 .00419 Mdot
.49012 .01335 Mdot
.46853 .04233 Mdot
.40003 .12904 Mdot
.19124 .26664 Mdot
.7598 .11938 Mdot
.56665 .05938 Mdot
.47057 .0865 Mdot
.33061 .21552 Mdot
.49977 .00032 Mdot
.49926 .00101 Mdot
.49763 .00321 Mdot
.49244 .01021 Mdot
.47592 .03245 Mdot
.42342 .10073 Mdot
.26044 .24796 Mdot
.85923 .13382 Mdot
.64271 .01855 Mdot
.61269 .54063 Mdot
.73793 .39351 Mdot
.10121 .48114 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50657 .60916 Mdot
.52094 .5898 Mdot
.56662 .52983 Mdot
.70933 .38708 Mdot
.08301 .4606 Mdot
.33775 .58628 Mdot
.38913 .06291 Mdot
.28734 .20641 Mdot
.95336 .16379 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60972 Mdot
.5196 .5916 Mdot
.56237 .53524 Mdot
.69633 .39601 Mdot
.05557 .44649 Mdot
.33314 .57435 Mdot
.40382 .04016 Mdot
.33884 .16531 Mdot
.07137 .22927 Mdot
.50058 .61726 Mdot
.50183 .61556 Mdot
.50584 .61014 Mdot
.51862 .59292 Mdot
.55925 .53925 Mdot
.68673 .40321 Mdot
.03431 .43478 Mdot
.33083 .5637 Mdot
.41874 .01777 Mdot
.39 .11182 Mdot
.20907 .25451 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.49428 .00772 Mdot
.48179 .02456 Mdot
.44205 .07711 Mdot
.31729 .21166 Mdot
.97481 .18841 Mdot
.66996 .05913 Mdot
.57429 .61077 Mdot
.58604 .53484 Mdot
.72066 .38979 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.5259 .58315 Mdot
.58234 .51018 Mdot
.75685 .36277 Mdot
.16987 .49201 Mdot
.37378 .59713 Mdot
.4076 .06003 Mdot
.31048 .19705 Mdot
.99165 .18931 Mdot
.50114 .61649 Mdot
.50363 .61312 Mdot
.51158 .6024 Mdot
.53688 .56851 Mdot
.61701 .46955 Mdot
.85727 .35427 Mdot
.28406 .49844 Mdot
.47756 .51918 Mdot
.63751 .40698 Mdot
.97901 .38757 Mdot
.3519 .50589 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61025 Mdot
.51836 .59327 Mdot
.55842 .54032 Mdot
.68417 .40522 Mdot
.02851 .43151 Mdot
.33032 .56066 Mdot
.42315 .01113 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51085 .60338 Mdot
.53456 .57159 Mdot
.60971 .47775 Mdot
.8367 .35156 Mdot
.26787 .49817 Mdot
.4618 .53325 Mdot
.59899 .44728 Mdot
.87529 .34313 Mdot
.32008 .4766 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49005 .01344 Mdot
.46831 .04262 Mdot
.39935 .12983 Mdot
.18927 .26677 Mdot
.75764 .11939 Mdot
.56445 .06126 Mdot
.46533 .09314 Mdot
.31462 .22869 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51104 .60312 Mdot
.53517 .57078 Mdot
.61164 .47556 Mdot
.84217 .35207 Mdot
.2725 .49815 Mdot
.46648 .52899 Mdot
.61057 .43453 Mdot
.90748 .35351 Mdot
.33549 .48028 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.5127 .60089 Mdot
.54043 .56381 Mdot
.62817 .45743 Mdot
.88803 .36198 Mdot
.30234 .50162 Mdot
.4907 .51024 Mdot
.66511 .38319 Mdot
.0451 .42444 Mdot
.35834 .5391 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .00441 Mdot
.4896 .01405 Mdot
.46687 .04454 Mdot
.3948 .13512 Mdot
.17618 .26707 Mdot
.74405 .11963 Mdot
.55048 .07361 Mdot
.43137 .13528 Mdot
.21248 .27875 Mdot
.76146 .13158 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.4973 .00365 Mdot
.4914 .01162 Mdot
.4726 .03689 Mdot
.41291 .11366 Mdot
.229 .25992 Mdot
.80844 .12221 Mdot
.61069 .02767 Mdot
.56592 .58633 Mdot
.61723 .48721 Mdot
.49998 3e-05 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00267 Mdot
.49371 .00849 Mdot
.47997 .02701 Mdot
.43627 .08453 Mdot
.2995 .22499 Mdot
.93546 .16678 Mdot
.6656 .03951 Mdot
.60167 .56957 Mdot
.49995 7e-05 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00212 Mdot
.495 .00675 Mdot
.48407 .0215 Mdot
.44929 .06772 Mdot
.33972 .19244 Mdot
.02835 .21858 Mdot
.67468 .08725 Mdot
.53351 .05641 Mdot
.44224 .10879 Mdot
.50053 .61732 Mdot
.50168 .61576 Mdot
.50536 .61079 Mdot
.51708 .59499 Mdot
.55436 .54557 Mdot
.67161 .41556 Mdot
.99921 .41484 Mdot
.328 .54501 Mdot
.44615 .59399 Mdot
.48505 .60783 Mdot
.50156 .60639 Mdot
.50096 .61674 Mdot
.50305 .61392 Mdot
.50971 .60492 Mdot
.53093 .57643 Mdot
.59824 .49103 Mdot
.80374 .35182 Mdot
.23449 .49866 Mdot
.42764 .56345 Mdot
.51595 .54869 Mdot
.62815 .44232 Mdot
.91247 .3652 Mdot
.50129 .61629 Mdot
.5041 .61249 Mdot
.51307 .60039 Mdot
.54162 .56225 Mdot
.63188 .45351 Mdot
.89809 .36536 Mdot
.30693 .50356 Mdot
.49215 .51084 Mdot
.6656 .38355 Mdot
.045 .42472 Mdot
.35779 .5397 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00405 Mdot
.49045 .0129 Mdot
.46958 .04093 Mdot
.40336 .12511 Mdot
.20093 .2657 Mdot
.77102 .11944 Mdot
.57777 .05018 Mdot
.49657 .05336 Mdot
.41024 .13223 Mdot
.19629 .27145 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.50451 .61195 Mdot
.51436 .59865 Mdot
.54572 .55685 Mdot
.64471 .44044 Mdot
.93206 .37935 Mdot
.31826 .51353 Mdot
.48734 .52526 Mdot
.63746 .41309 Mdot
.96907 .3846 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48717 .01733 Mdot
.45913 .0548 Mdot
.37047 .16206 Mdot
.10825 .25485 Mdot
.69589 .11575 Mdot
.5086 .10778 Mdot
.33421 .23515 Mdot
.95374 .19286 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49785 .0029 Mdot
.49315 .00925 Mdot
.47819 .0294 Mdot
.43061 .09171 Mdot
.28222 .23625 Mdot
.89996 .14949 Mdot
.65808 .02588 Mdot
.6162 .54551 Mdot
.73355 .39875 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50701 .60857 Mdot
.52232 .58795 Mdot
.57099 .5243 Mdot
.72267 .37892 Mdot
.10956 .47265 Mdot
.34479 .5948 Mdot
.38239 .07614 Mdot
.25919 .22344 Mdot
.89766 .13497 Mdot
.49996 6e-05 Mdot
.49986 .00018 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00598 Mdot
.4859 .01903 Mdot
.4551 .06011 Mdot
.35785 .17505 Mdot
.07461 .24171 Mdot
.68351 .10686 Mdot
.51061 .09703 Mdot
.35362 .21439 Mdot
.50028 .61765 Mdot
.5009 .61682 Mdot
.50285 .61418 Mdot
.50909 .60575 Mdot
.52896 .57905 Mdot
.59204 .4984 Mdot
.78562 .35453 Mdot
.21197 .49789 Mdot
.40637 .57976 Mdot
.4683 .60895 Mdot
.483 .00665 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50515 .61107 Mdot
.51642 .59588 Mdot
.55226 .5483 Mdot
.6651 .42125 Mdot
.9835 .40598 Mdot
.32661 .53676 Mdot
.45811 .57515 Mdot
.52749 .54979 Mdot
.6379 .43736 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48771 .0166 Mdot
.46085 .05252 Mdot
.37587 .15628 Mdot
.12301 .2593 Mdot
.70346 .11801 Mdot
.51251 .10642 Mdot
.34031 .23084 Mdot
.9668 .20029 Mdot
.64273 .08501 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49714 .00387 Mdot
.49087 .01233 Mdot
.47092 .03913 Mdot
.40761 .12006 Mdot
.21335 .26371 Mdot
.78667 .12006 Mdot
.59241 .03913 Mdot
.5291 .0123 Mdot
.5092 .00378 Mdot
.50308 .00093 Mdot
.50081 .61695 Mdot
.50257 .61457 Mdot
.50818 .60699 Mdot
.52605 .58294 Mdot
.58283 .50958 Mdot
.75832 .36223 Mdot
.17221 .4925 Mdot
.37533 .59662 Mdot
.40998 .05766 Mdot
.31668 .19244 Mdot
.0053 .19736 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50703 .60854 Mdot
.52238 .58786 Mdot
.5712 .52403 Mdot
.7233 .37856 Mdot
.11077 .47316 Mdot
.34518 .5951 Mdot
.3823 .0765 Mdot
.25852 .22383 Mdot
.89635 .13439 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.50059 .61723 Mdot
.50189 .61548 Mdot
.50603 .60989 Mdot
.51922 .59211 Mdot
.56116 .5368 Mdot
.69259 .39876 Mdot
.04739 .44204 Mdot
.33215 .57036 Mdot
.40929 .03194 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49347 .00882 Mdot
.47921 .02803 Mdot
.43385 .08761 Mdot
.29209 .23003 Mdot
.9199 .15887 Mdot
.66285 .03289 Mdot
.60963 .55714 Mdot
.70815 .41467 Mdot
.03721 .44885 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00091 Mdot
.49785 .00291 Mdot
.49314 .00927 Mdot
.47815 .02946 Mdot
.43048 .09188 Mdot
.28182 .23648 Mdot
.89918 .14914 Mdot
.65786 .02564 Mdot
.61636 .54516 Mdot
.73428 .39833 Mdot
.50093 .61678 Mdot
.50296 .61403 Mdot
.50944 .60529 Mdot
.53005 .57759 Mdot
.59549 .49429 Mdot
.79571 .35279 Mdot
.22489 .4985 Mdot
.4183 .57096 Mdot
.49447 .57609 Mdot
.56234 .51976 Mdot
.72135 .3746 Mdot
.50013 .61785 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.50431 .61222 Mdot
.51372 .59952 Mdot
.54368 .55953 Mdot
.63835 .44682 Mdot
.91537 .37201 Mdot
.31344 .50799 Mdot
.49149 .51588 Mdot
.65679 .39292 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46949 .04104 Mdot
.40308 .12544 Mdot
.20011 .2658 Mdot
.77004 .11942 Mdot
.57681 .05094 Mdot
.49438 .05615 Mdot
.40353 .1402 Mdot
.17668 .27237 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48709 .01743 Mdot
.4589 .05511 Mdot
.36973 .16283 Mdot
.10627 .25419 Mdot
.69498 .11537 Mdot
.50831 .10767 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07804 Mdot
.49989 .00014 Mdot
.49967 .00045 Mdot
.49893 .00144 Mdot
.4966 .00459 Mdot
.48917 .01462 Mdot
.46551 .04635 Mdot
.39051 .14004 Mdot
.16392 .26652 Mdot
.73267 .11985 Mdot
.53875 .08428 Mdot
.40238 .16922 Mdot
.12858 .27586 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48947 .01422 Mdot
.46645 .0451 Mdot
.39348 .13663 Mdot
.17241 .26699 Mdot
.74041 .11971 Mdot
.54672 .07702 Mdot
.42209 .14639 Mdot
.18522 .28189 Mdot
.72912 .13561 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49852 .00201 Mdot
.49527 .00639 Mdot
.48493 .02034 Mdot
.45203 .06414 Mdot
.34825 .18445 Mdot
.04981 .22988 Mdot
.67787 .09723 Mdot
.52055 .07823 Mdot
.39397 .16942 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49084 .01238 Mdot
.47081 .03928 Mdot
.40726 .12048 Mdot
.21232 .26391 Mdot
.78531 .11998 Mdot
.59119 .03999 Mdot
.52648 .01556 Mdot
.5013 .01436 Mdot
.47807 .03462 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46941 .04116 Mdot
.40281 .12576 Mdot
.19933 .26589 Mdot
.76911 .11941 Mdot
.57591 .05168 Mdot
.4923 .05881 Mdot
.39713 .14768 Mdot
.50123 .61637 Mdot
.50391 .61275 Mdot
.51247 .6012 Mdot
.53971 .56476 Mdot
.62591 .45984 Mdot
.88187 .36011 Mdot
.2992 .50066 Mdot
.48912 .51074 Mdot
.66272 .38483 Mdot
.04005 .42157 Mdot
.35794 .53646 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50746 .60795 Mdot
.52378 .58599 Mdot
.57562 .5185 Mdot
.73666 .37147 Mdot
.13561 .48252 Mdot
.35487 .59918 Mdot
.38539 .07845 Mdot
.25846 .22578 Mdot
.89313 .13399 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50832 .6068 Mdot
.5265 .58234 Mdot
.58425 .50784 Mdot
.76255 .36075 Mdot
.17884 .49379 Mdot
.37987 .59488 Mdot
.41732 .0501 Mdot
.33627 .17649 Mdot
.0507 .2227 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51259 .60104 Mdot
.54009 .56427 Mdot
.62708 .45858 Mdot
.88508 .36107 Mdot
.30087 .50114 Mdot
.49001 .5104 Mdot
.66417 .3838 Mdot
.04317 .42333 Mdot
.35821 .53806 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47455 .03428 Mdot
.41908 .10611 Mdot
.2474 .25363 Mdot
.83702 .12759 Mdot
.63056 .01968 Mdot
.59872 .55196 Mdot
.70563 .41011 Mdot
.04207 .44865 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.4954 .00622 Mdot
.48534 .01979 Mdot
.45332 .06245 Mdot
.35228 .18056 Mdot
.06014 .23499 Mdot
.67992 .10152 Mdot
.51566 .08703 Mdot
.37485 .19146 Mdot
.06507 .25011 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47455 .03428 Mdot
.41908 .10611 Mdot
.2474 .25363 Mdot
.83701 .12759 Mdot
.63056 .01968 Mdot
.59871 .55196 Mdot
.70562 .41011 Mdot
.04204 .44864 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48083 .02586 Mdot
.43898 .08106 Mdot
.30783 .21897 Mdot
.95353 .1765 Mdot
.66795 .04813 Mdot
.59008 .58704 Mdot
.64022 .47323 Mdot
.87452 .36859 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49085 .01236 Mdot
.47085 .03923 Mdot
.40738 .12033 Mdot
.21269 .26384 Mdot
.78579 .12001 Mdot
.59162 .03968 Mdot
.52741 .0144 Mdot
.50411 .01058 Mdot
.48699 .02263 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00379 Mdot
.49107 .01206 Mdot
.47156 .03828 Mdot
.40962 .11763 Mdot
.21929 .26244 Mdot
.79465 .12066 Mdot
.59941 .03438 Mdot
.54378 .61233 Mdot
.553 .5641 Mdot
.64027 .45025 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00367 Mdot
.49136 .01168 Mdot
.47246 .03708 Mdot
.41247 .11419 Mdot
.2277 .26029 Mdot
.80654 .12196 Mdot
.60921 .02848 Mdot
.56313 .58951 Mdot
.60927 .49598 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50041 .61748 Mdot
.5013 .61627 Mdot
.50416 .61242 Mdot
.51324 .60015 Mdot
.54217 .56151 Mdot
.63363 .45168 Mdot
.9028 .36707 Mdot
.30887 .50463 Mdot
.49236 .51171 Mdot
.50037 .61754 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60208 Mdot
.53764 .56751 Mdot
.61939 .46692 Mdot
.8639 .35557 Mdot
.28857 .49881 Mdot
.48149 .51593 Mdot
.64669 .39839 Mdot
.00208 .40032 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60311 Mdot
.5352 .57074 Mdot
.61172 .47547 Mdot
.84239 .3521 Mdot
.27269 .49815 Mdot
.46667 .52882 Mdot
.61103 .43403 Mdot
.90875 .354 Mdot
.33597 .48054 Mdot
.50127 .61632 Mdot
.50405 .61257 Mdot
.51289 .60063 Mdot
.54106 .56298 Mdot
.63013 .45535 Mdot
.89336 .36372 Mdot
.30485 .50259 Mdot
.49164 .51034 Mdot
.6659 .38292 Mdot
.04633 .42526 Mdot
.35824 .53998 Mdot
.50044 .61744 Mdot
.50139 .61616 Mdot
.50443 .61205 Mdot
.51411 .59899 Mdot
.54492 .5579 Mdot
.64222 .44291 Mdot
.92558 .37641 Mdot
.31654 .51124 Mdot
.48934 .52112 Mdot
.64615 .40388 Mdot
.99265 .39708 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .00471 Mdot
.4889 .01498 Mdot
.46466 .04748 Mdot
.38784 .14306 Mdot
.15637 .2658 Mdot
.7263 .11989 Mdot
.53232 .09013 Mdot
.38649 .18666 Mdot
.08446 .26134 Mdot
.66161 .13597 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50718 .60834 Mdot
.52286 .58722 Mdot
.57272 .52212 Mdot
.72791 .376 Mdot
.11953 .47668 Mdot
.34824 .597 Mdot
.38228 .07841 Mdot
.25541 .22587 Mdot
.88994 .13178 Mdot
.50122 .61639 Mdot
.50388 .6128 Mdot
.51235 .60136 Mdot
.53932 .56528 Mdot
.62467 .46117 Mdot
.87849 .35915 Mdot
.29737 .50021 Mdot
.48802 .5113 Mdot
.66072 .38637 Mdot
.03557 .41907 Mdot
.35751 .53421 Mdot
.49983 .00024 Mdot
.49945 .00075 Mdot
.49823 .00239 Mdot
.49437 .0076 Mdot
.48207 .02418 Mdot
.44294 .07595 Mdot
.32004 .20944 Mdot
.98116 .19202 Mdot
.67047 .06251 Mdot
.56932 .00026 Mdot
.5689 .5564 Mdot
.66862 .42773 Mdot
.50127 .61632 Mdot
.50405 .61257 Mdot
.51289 .60063 Mdot
.54105 .56299 Mdot
.63011 .45537 Mdot
.8933 .3637 Mdot
.30482 .50258 Mdot
.49163 .51033 Mdot
.6659 .38291 Mdot
.04633 .42526 Mdot
.35825 .53997 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00648 Mdot
.48473 .02061 Mdot
.45138 .06499 Mdot
.34623 .18637 Mdot
.04467 .22724 Mdot
.67698 .09496 Mdot
.52334 .07339 Mdot
.40459 .15665 Mdot
.15113 .27662 Mdot
.50079 .61696 Mdot
.50253 .61462 Mdot
.50806 .60715 Mdot
.52566 .58347 Mdot
.58159 .5111 Mdot
.75462 .36361 Mdot
.16629 .49121 Mdot
.37149 .59782 Mdot
.40419 .06334 Mdot
.30171 .20316 Mdot
.97298 .17824 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51084 .60339 Mdot
.53453 .57163 Mdot
.60961 .47787 Mdot
.8364 .35154 Mdot
.26761 .49818 Mdot
.46154 .53349 Mdot
.59834 .44801 Mdot
.87344 .34266 Mdot
.31899 .47656 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00553 Mdot
.48697 .0176 Mdot
.4585 .05564 Mdot
.36848 .16415 Mdot
.10287 .25302 Mdot
.69348 .11468 Mdot
.50793 .10733 Mdot
.33426 .23468 Mdot
.95455 .19311 Mdot
.64209 .0782 Mdot
.50012 .61787 Mdot
.50038 .61753 Mdot
.5012 .61642 Mdot
.50382 .61288 Mdot
.51216 .60162 Mdot
.53871 .56609 Mdot
.62276 .46324 Mdot
.87323 .35775 Mdot
.29438 .4996 Mdot
.48601 .51255 Mdot
.65668 .38966 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51319 .60023 Mdot
.542 .56174 Mdot
.63309 .45224 Mdot
.90135 .36653 Mdot
.30829 .50429 Mdot
.49233 .5114 Mdot
.66486 .38447 Mdot
.04278 .42365 Mdot
.3573 .53892 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.51171 .60223 Mdot
.53728 .56798 Mdot
.61828 .46815 Mdot
.8608 .35494 Mdot
.2865 .49862 Mdot
.47972 .51736 Mdot
.64262 .40215 Mdot
.99193 .39467 Mdot
.35334 .51219 Mdot
.50083 .61691 Mdot
.50264 .61447 Mdot
.50841 .60668 Mdot
.52679 .58196 Mdot
.58516 .50673 Mdot
.76525 .35986 Mdot
.18299 .49452 Mdot
.38284 .59358 Mdot
.4224 .04467 Mdot
.35012 .16397 Mdot
.0848 .23892 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00325 Mdot
.49235 .01034 Mdot
.47561 .03286 Mdot
.42245 .10194 Mdot
.25751 .24932 Mdot
.8541 .13223 Mdot
.64015 .01845 Mdot
.61029 .54223 Mdot
.73295 .39553 Mdot
.09297 .4769 Mdot
.50076 .61701 Mdot
.50242 .61476 Mdot
.50773 .6076 Mdot
.52461 .58488 Mdot
.57826 .51521 Mdot
.74463 .36775 Mdot
.1496 .4869 Mdot
.36178 .59952 Mdot
.39173 .07429 Mdot
.27152 .22049 Mdot
.91476 .1452 Mdot
.50042 .61747 Mdot
.50134 .61622 Mdot
.50427 .61226 Mdot
.51361 .59966 Mdot
.54334 .55998 Mdot
.63728 .44792 Mdot
.91253 .37085 Mdot
.31248 .50717 Mdot
.49186 .51471 Mdot
.65905 .39061 Mdot
.02703 .41555 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.50411 .61249 Mdot
.51308 .60037 Mdot
.54166 .5622 Mdot
.63201 .45338 Mdot
.89843 .36548 Mdot
.30707 .50364 Mdot
.49218 .51089 Mdot
.66555 .38363 Mdot
.04482 .42463 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00517 Mdot
.48782 .01645 Mdot
.46121 .05205 Mdot
.37698 .15508 Mdot
.12606 .2601 Mdot
.70521 .11836 Mdot
.5137 .10568 Mdot
.34271 .22888 Mdot
.97237 .2034 Mdot
.64326 .08781 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00407 Mdot
.49039 .01297 Mdot
.4694 .04117 Mdot
.40279 .12579 Mdot
.19926 .2659 Mdot
.76903 .11941 Mdot
.57582 .05174 Mdot
.4921 .05906 Mdot
.39653 .14837 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00407 Mdot
.49041 .01295 Mdot
.46945 .0411 Mdot
.40294 .1256 Mdot
.19971 .26585 Mdot
.76956 .11941 Mdot
.57635 .05132 Mdot
.49332 .05751 Mdot
.40026 .14404 Mdot
.16719 .27206 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00554 Mdot
.48694 .01763 Mdot
.45842 .05574 Mdot
.36824 .16441 Mdot
.10222 .25279 Mdot
.6932 .11454 Mdot
.50787 .10724 Mdot
.33435 .23455 Mdot
.95484 .19324 Mdot
.64217 .07829 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49022 .01321 Mdot
.46885 .0419 Mdot
.40105 .12783 Mdot
.19421 .26641 Mdot
.76316 .11937 Mdot
.57002 .05653 Mdot
.47855 .07636 Mdot
.355 .19294 Mdot
.04281 .23215 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00332 Mdot
.49218 .01057 Mdot
.47508 .03357 Mdot
.42077 .10403 Mdot
.25245 .25155 Mdot
.84543 .12975 Mdot
.6355 .01877 Mdot
.60513 .54627 Mdot
.72124 .40113 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49943 .00076 Mdot
.4982 .00243 Mdot
.49426 .00776 Mdot
.48171 .02468 Mdot
.44178 .07745 Mdot
.31646 .21232 Mdot
.97292 .18734 Mdot
.6698 .05813 Mdot
.57575 .60856 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.51149 .60252 Mdot
.5366 .56888 Mdot
.61613 .47053 Mdot
.8548 .35383 Mdot
.28229 .49835 Mdot
.47594 .52057 Mdot
.63365 .41072 Mdot
.96908 .38224 Mdot
.3506 .50128 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.4965 .00473 Mdot
.48884 .01507 Mdot
.46446 .04774 Mdot
.38722 .14376 Mdot
.1546 .26559 Mdot
.72488 .11988 Mdot
.53091 .0914 Mdot
.38302 .19034 Mdot
.07504 .25736 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.49571 .0058 Mdot
.48632 .01847 Mdot
.45643 .05836 Mdot
.36201 .17084 Mdot
.08558 .24641 Mdot
.68688 .11032 Mdot
.50837 .10256 Mdot
.34242 .22592 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49737 .00356 Mdot
.49161 .01134 Mdot
.47327 .036 Mdot
.41501 .1111 Mdot
.23524 .25801 Mdot
.81777 .12364 Mdot
.61771 .0242 Mdot
.57855 .57233 Mdot
.6525 .45162 Mdot
.92177 .38198 Mdot
.50119 .61643 Mdot
.50378 .61292 Mdot
.51205 .60176 Mdot
.53839 .56651 Mdot
.62176 .46433 Mdot
.87046 .35706 Mdot
.29272 .49933 Mdot
.48479 .51341 Mdot
.65408 .39186 Mdot
.02004 .41039 Mdot
.35602 .52639 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48784 .01642 Mdot
.46127 .05198 Mdot
.37717 .15488 Mdot
.12657 .26023 Mdot
.70551 .11841 Mdot
.51391 .10554 Mdot
.34315 .22852 Mdot
.97339 .20397 Mdot
.64336 .08832 Mdot
.5004 .61749 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.5129 .60061 Mdot
.54109 .56294 Mdot
.63024 .45523 Mdot
.89367 .36383 Mdot
.30499 .50265 Mdot
.49168 .51036 Mdot
.66591 .38293 Mdot
.04631 .42526 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00245 Mdot
.49422 .00781 Mdot
.48158 .02484 Mdot
.44139 .07796 Mdot
.31525 .21328 Mdot
.97015 .18577 Mdot
.66957 .05667 Mdot
.57787 .60536 Mdot
.59839 .51985 Mdot
.75726 .37246 Mdot
.50115 .61649 Mdot
.50365 .6131 Mdot
.51163 .60232 Mdot
.53705 .56828 Mdot
.61755 .46895 Mdot
.85877 .35454 Mdot
.28511 .49851 Mdot
.4785 .51838 Mdot
.63974 .40486 Mdot
.98467 .39066 Mdot
.35256 .50862 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50965 .605 Mdot
.53073 .57669 Mdot
.59763 .49176 Mdot
.80195 .352 Mdot
.2324 .49864 Mdot
.50042 .61746 Mdot
.50135 .6162 Mdot
.50431 .61221 Mdot
.51374 .59948 Mdot
.54376 .55942 Mdot
.6386 .44656 Mdot
.91605 .37229 Mdot
.31366 .50819 Mdot
.49139 .51617 Mdot
.6562 .39352 Mdot
.01948 .41153 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48715 .01735 Mdot
.45907 .05488 Mdot
.37028 .16225 Mdot
.10776 .25469 Mdot
.69566 .11566 Mdot
.50852 .10776 Mdot
.33417 .23515 Mdot
.95369 .19282 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48977 .01381 Mdot
.46742 .04381 Mdot
.39654 .1331 Mdot
.18118 .26707 Mdot
.74905 .11952 Mdot
.55566 .06897 Mdot
.44406 .11976 Mdot
.25028 .26731 Mdot
.81776 .13294 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.49429 .00771 Mdot
.48182 .02452 Mdot
.44215 .07698 Mdot
.31759 .21142 Mdot
.9755 .1888 Mdot
.67002 .0595 Mdot
.57375 .61158 Mdot
.58419 .53712 Mdot
.71512 .3931 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51004 .60447 Mdot
.53199 .57502 Mdot
.60158 .48711 Mdot
.81342 .35113 Mdot
.24529 .49861 Mdot
.43853 .55419 Mdot
.54183 .51586 Mdot
.70715 .37363 Mdot
.10261 .4623 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50515 .61108 Mdot
.5164 .5959 Mdot
.55222 .54836 Mdot
.66495 .42138 Mdot
.98315 .40579 Mdot
.32657 .53658 Mdot
.45837 .57474 Mdot
.52842 .54854 Mdot
.64087 .43434 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .00379 Mdot
.49106 .01207 Mdot
.47152 .03833 Mdot
.4095 .11778 Mdot
.21893 .26252 Mdot
.79416 .12062 Mdot
.59899 .03465 Mdot
.54292 .61338 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49302 .00943 Mdot
.47777 .02997 Mdot
.42928 .09339 Mdot
.27817 .23863 Mdot
.89206 .14606 Mdot
.65573 .02365 Mdot
.61746 .54241 Mdot
.73982 .39517 Mdot
.10042 .48221 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00544 Mdot
.48718 .01731 Mdot
.45917 .05475 Mdot
.37057 .16195 Mdot
.10854 .25495 Mdot
.69603 .1158 Mdot
.50865 .10779 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60041 Mdot
.54157 .56231 Mdot
.63173 .45367 Mdot
.89768 .36521 Mdot
.30676 .50347 Mdot
.49212 .51078 Mdot
.66567 .38347 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45872 .05535 Mdot
.36916 .16343 Mdot
.10472 .25366 Mdot
.69429 .11506 Mdot
.50812 .10754 Mdot
.33411 .23496 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01438 Mdot
.46607 .0456 Mdot
.39229 .138 Mdot
.169 .26685 Mdot
.73723 .11978 Mdot
.54343 .08001 Mdot
.41396 .15595 Mdot
.16164 .28133 Mdot
.70644 .13928 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00483 Mdot
.4886 .01539 Mdot
.46371 .04874 Mdot
.38484 .14642 Mdot
.14792 .26465 Mdot
.71971 .11977 Mdot
.52593 .09584 Mdot
.37086 .20285 Mdot
.04264 .24191 Mdot
.65123 .12188 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.4884 .01567 Mdot
.46305 .04961 Mdot
.38277 .14873 Mdot
.14212 .26366 Mdot
.71552 .11956 Mdot
.52206 .09918 Mdot
.36158 .21192 Mdot
.01869 .22921 Mdot
.64782 .11104 Mdot
.50007 .61794 Mdot
.50021 .61774 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50695 .60865 Mdot
.52213 .5882 Mdot
.57041 .52504 Mdot
.72088 .37996 Mdot
.10609 .47119 Mdot
.3437 .59389 Mdot
.38276 .07498 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.5063 .60952 Mdot
.52008 .59095 Mdot
.5639 .53329 Mdot
.70103 .39267 Mdot
.06567 .45184 Mdot
.33458 .57904 Mdot
.39768 .04946 Mdot
.31765 .18388 Mdot
.02013 .20249 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51085 .60338 Mdot
.53457 .57159 Mdot
.60972 .47774 Mdot
.83672 .35156 Mdot
.26789 .49817 Mdot
.46182 .53323 Mdot
.59904 .44723 Mdot
.87541 .34317 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51024 .6042 Mdot
.53263 .57416 Mdot
.60361 .48475 Mdot
.81927 .35096 Mdot
.2514 .4985 Mdot
.44481 .54864 Mdot
.55709 .49685 Mdot
.75317 .34933 Mdot
.18793 .4858 Mdot
.50021 .61776 Mdot
.50065 .61715 Mdot
.50208 .61522 Mdot
.50664 .60907 Mdot
.52114 .58952 Mdot
.56727 .529 Mdot
.71134 .38578 Mdot
.08713 .46258 Mdot
.33865 .58782 Mdot
.38754 .06558 Mdot
.28143 .21026 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.50501 .61126 Mdot
.51597 .59648 Mdot
.55084 .55015 Mdot
.66069 .42523 Mdot
.97266 .4 Mdot
.32544 .53128 Mdot
.4658 .56274 Mdot
.55527 .51252 Mdot
.72599 .36665 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51281 .60074 Mdot
.54079 .56334 Mdot
.62929 .45623 Mdot
.8911 .36297 Mdot
.3038 .50216 Mdot
.49129 .51023 Mdot
.66571 .3829 Mdot
.04616 .4251 Mdot
.35834 .53976 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60697 Mdot
.52609 .58289 Mdot
.58295 .50942 Mdot
.75869 .3621 Mdot
.1728 .49262 Mdot
.37572 .59648 Mdot
.41059 .05705 Mdot
.31828 .19122 Mdot
.50038 .61751 Mdot
.50122 .61638 Mdot
.5039 .61276 Mdot
.51243 .60125 Mdot
.5396 .56492 Mdot
.62554 .46023 Mdot
.88088 .35982 Mdot
.29867 .50052 Mdot
.48881 .51089 Mdot
.66218 .38524 Mdot
.03885 .4209 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49732 .00362 Mdot
.49147 .01153 Mdot
.47281 .03661 Mdot
.41358 .11285 Mdot
.23099 .25934 Mdot
.81137 .12263 Mdot
.61295 .02649 Mdot
.57009 .58162 Mdot
.629 .4747 Mdot
.86092 .36156 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .0021 Mdot
.49504 .0067 Mdot
.4842 .02132 Mdot
.44971 .06716 Mdot
.34104 .19122 Mdot
.03164 .22036 Mdot
.67509 .08886 Mdot
.53132 .06001 Mdot
.43422 .11927 Mdot
.24124 .26659 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49785 .0029 Mdot
.49315 .00925 Mdot
.47818 .02942 Mdot
.43058 .09175 Mdot
.28212 .2363 Mdot
.89978 .14941 Mdot
.65803 .02583 Mdot
.61624 .54543 Mdot
.73372 .39865 Mdot
.08869 .47668 Mdot
.50007 .61794 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50688 .60875 Mdot
.52191 .5885 Mdot
.56969 .52594 Mdot
.71871 .38124 Mdot
.10185 .46934 Mdot
.34244 .5927 Mdot
.38344 .07332 Mdot
.50105 .61662 Mdot
.50333 .61353 Mdot
.51062 .60369 Mdot
.53384 .57255 Mdot
.60743 .48035 Mdot
.8302 .35115 Mdot
.26203 .49827 Mdot
.45581 .53871 Mdot
.58416 .46427 Mdot
.83295 .33632 Mdot
.28877 .47951 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00666 Mdot
.48431 .02118 Mdot
.45003 .06674 Mdot
.34204 .1903 Mdot
.03413 .2217 Mdot
.67542 .09006 Mdot
.5297 .06269 Mdot
.42827 .12696 Mdot
.50014 .61784 Mdot
.50046 .61742 Mdot
.50146 .61607 Mdot
.50464 .61177 Mdot
.51478 .59808 Mdot
.54706 .55508 Mdot
.64892 .43631 Mdot
.94296 .38455 Mdot
.32074 .51776 Mdot
.48298 .53351 Mdot
.61975 .43267 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.4881 .01606 Mdot
.46212 .05085 Mdot
.37984 .15196 Mdot
.13395 .26199 Mdot
.71004 .11908 Mdot
.51737 .10301 Mdot
.35069 .222 Mdot
.99149 .21411 Mdot
.64505 .0975 Mdot
.50041 .61748 Mdot
.5013 .61627 Mdot
.50415 .61243 Mdot
.51322 .60019 Mdot
.54209 .56162 Mdot
.63337 .45195 Mdot
.90209 .36681 Mdot
.30859 .50446 Mdot
.49235 .51156 Mdot
.66463 .38473 Mdot
.04212 .42333 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.5123 .60142 Mdot
.53918 .56546 Mdot
.62425 .46163 Mdot
.87732 .35883 Mdot
.29672 .50006 Mdot
.48761 .51154 Mdot
.65992 .387 Mdot
.03375 .41805 Mdot
.35733 .5333 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49583 .00563 Mdot
.48672 .01793 Mdot
.4577 .05669 Mdot
.36598 .16676 Mdot
.09616 .25058 Mdot
.69072 .11315 Mdot
.50763 .10608 Mdot
.336 .2326 Mdot
.95964 .19559 Mdot
.64318 .08005 Mdot
.50028 .61766 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50903 .60583 Mdot
.52877 .5793 Mdot
.59144 .49912 Mdot
.78384 .3549 Mdot
.2096 .49772 Mdot
.40428 .5812 Mdot
.46387 .61442 Mdot
.46972 .02428 Mdot
.50013 .61785 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.50429 .61224 Mdot
.51367 .59957 Mdot
.54354 .55971 Mdot
.63792 .44726 Mdot
.91424 .37155 Mdot
.31306 .50766 Mdot
.49165 .51539 Mdot
.65773 .39196 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .6042 Mdot
.53263 .57416 Mdot
.60363 .48473 Mdot
.81932 .35096 Mdot
.25145 .4985 Mdot
.44486 .5486 Mdot
.55721 .4967 Mdot
.75354 .34919 Mdot
.18854 .48587 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51177 .60214 Mdot
.53749 .5677 Mdot
.61893 .46742 Mdot
.86263 .35531 Mdot
.28773 .49872 Mdot
.48078 .5165 Mdot
.64506 .39988 Mdot
.99805 .39807 Mdot
.35396 .51524 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49645 .00479 Mdot
.4887 .01526 Mdot
.464 .04835 Mdot
.38577 .14539 Mdot
.15052 .26504 Mdot
.72168 .11982 Mdot
.5278 .09418 Mdot
.37541 .19825 Mdot
.05463 .24791 Mdot
.65351 .12666 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.5085 .60656 Mdot
.52707 .58158 Mdot
.58604 .50565 Mdot
.76789 .35903 Mdot
.18696 .49515 Mdot
.38578 .59218 Mdot
.42761 .03897 Mdot
.36456 .14991 Mdot
.122 .25226 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49792 .0028 Mdot
.49339 .00893 Mdot
.47893 .02841 Mdot
.43296 .08874 Mdot
.28937 .2318 Mdot
.91431 .15614 Mdot
.66167 .03074 Mdot
.61192 .55336 Mdot
.71656 .40906 Mdot
.05469 .45877 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00506 Mdot
.48807 .0161 Mdot
.46202 .05098 Mdot
.37954 .15229 Mdot
.13313 .26181 Mdot
.70951 .11901 Mdot
.51695 .10333 Mdot
.34975 .22284 Mdot
.98919 .21282 Mdot
.64483 .09633 Mdot
.50001 .61802 Mdot
.50002 .61801 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50697 .60862 Mdot
.52221 .58809 Mdot
.57065 .52473 Mdot
.72163 .37952 Mdot
.10755 .47181 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01346 Mdot
.46825 .04271 Mdot
.39915 .13007 Mdot
.18869 .2668 Mdot
.757 .1194 Mdot
.56381 .06182 Mdot
.46378 .09511 Mdot
.30989 .23233 Mdot
.93396 .17285 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00807 Mdot
.48098 .02566 Mdot
.43947 .08043 Mdot
.30933 .21784 Mdot
.95686 .17833 Mdot
.66831 .0498 Mdot
.58773 .59056 Mdot
.63218 .48164 Mdot
.85287 .36385 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.4663 .04529 Mdot
.39302 .13717 Mdot
.17108 .26694 Mdot
.73916 .11974 Mdot
.54542 .0782 Mdot
.4189 .15017 Mdot
.50095 .61675 Mdot
.50302 .61396 Mdot
.50962 .60504 Mdot
.53064 .57681 Mdot
.59733 .4921 Mdot
.80109 .3521 Mdot
.23139 .49863 Mdot
.42458 .56596 Mdot
.50884 .55777 Mdot
.60635 .46635 Mdot
.85178 .34796 Mdot
.50118 .61643 Mdot
.50377 .61294 Mdot
.51202 .60181 Mdot
.53828 .56666 Mdot
.6214 .46472 Mdot
.86947 .35683 Mdot
.29211 .49924 Mdot
.48433 .51374 Mdot
.65308 .39272 Mdot
.01765 .40905 Mdot
.3558 .52517 Mdot
.50123 .61638 Mdot
.5039 .61276 Mdot
.51244 .60124 Mdot
.53962 .56488 Mdot
.62562 .46015 Mdot
.88108 .35988 Mdot
.29878 .50055 Mdot
.48887 .51086 Mdot
.66229 .38515 Mdot
.0391 .42104 Mdot
.35785 .53599 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49235 .01033 Mdot
.47564 .03282 Mdot
.42253 .10184 Mdot
.25776 .24921 Mdot
.85453 .13236 Mdot
.64037 .01845 Mdot
.61052 .54207 Mdot
.73343 .39532 Mdot
.09378 .47732 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00191 Mdot
.49549 .0061 Mdot
.48562 .01941 Mdot
.45423 .06126 Mdot
.35511 .17778 Mdot
.06745 .23846 Mdot
.68162 .10432 Mdot
.51283 .09244 Mdot
.36325 .20419 Mdot
.03287 .23444 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49622 .00511 Mdot
.48794 .01628 Mdot
.4616 .05154 Mdot
.3782 .15375 Mdot
.12943 .26094 Mdot
.70722 .1187 Mdot
.51516 .10466 Mdot
.34581 .22627 Mdot
.9797 .2075 Mdot
.64396 .09151 Mdot
.50005 .61796 Mdot
.50017 .61781 Mdot
.50053 .61731 Mdot
.5017 .61574 Mdot
.50542 .61071 Mdot
.51726 .59475 Mdot
.55494 .54482 Mdot
.67341 .41403 Mdot
.0035 .41727 Mdot
.32834 .5473 Mdot
.44279 .5992 Mdot
.50043 .61745 Mdot
.50137 .61619 Mdot
.50435 .61216 Mdot
.51386 .59932 Mdot
.54414 .55892 Mdot
.63979 .44536 Mdot
.91918 .37361 Mdot
.31466 .50915 Mdot
.49083 .51764 Mdot
.65327 .39652 Mdot
.01169 .40735 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00257 Mdot
.49393 .0082 Mdot
.48066 .02608 Mdot
.43846 .08173 Mdot
.30622 .22016 Mdot
.94998 .17456 Mdot
.66755 .04637 Mdot
.59251 .58339 Mdot
.64857 .46481 Mdot
.89649 .37547 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01185 Mdot
.47205 .03763 Mdot
.41117 .11577 Mdot
.22385 .26133 Mdot
.80101 .1213 Mdot
.60475 .03105 Mdot
.55452 .59952 Mdot
.58447 .52485 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50168 .61576 Mdot
.50536 .61079 Mdot
.51709 .59498 Mdot
.55439 .54553 Mdot
.6717 .41548 Mdot
.99944 .41496 Mdot
.32802 .54513 Mdot
.44597 .59426 Mdot
.48444 .60867 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61239 Mdot
.51332 .60005 Mdot
.54242 .56119 Mdot
.63439 .45089 Mdot
.90482 .36783 Mdot
.30967 .50512 Mdot
.49236 .51221 Mdot
.66359 .38588 Mdot
.03923 .42188 Mdot
.50045 .61743 Mdot
.50143 .61611 Mdot
.50455 .61189 Mdot
.51449 .59847 Mdot
.54614 .55629 Mdot
.64604 .43912 Mdot
.93552 .38097 Mdot
.3191 .51483 Mdot
.48609 .52771 Mdot
.63225 .41873 Mdot
.95472 .37732 Mdot
.50092 .61679 Mdot
.50294 .61407 Mdot
.50935 .6054 Mdot
.52979 .57794 Mdot
.59466 .49528 Mdot
.79328 .35315 Mdot
.22187 .4984 Mdot
.41544 .57315 Mdot
.48806 .58421 Mdot
.54279 .54502 Mdot
.66092 .41999 Mdot
.50048 .61738 Mdot
.50154 .61596 Mdot
.50489 .61143 Mdot
.51558 .597 Mdot
.54961 .55175 Mdot
.65687 .42875 Mdot
.96313 .39488 Mdot
.3242 .52667 Mdot
.47203 .55247 Mdot
.57812 .48292 Mdot
.79673 .34169 Mdot
.50058 .61725 Mdot
.50184 .61555 Mdot
.50586 .61011 Mdot
.51868 .59284 Mdot
.55944 .53901 Mdot
.6873 .40277 Mdot
.0356 .4355 Mdot
.33095 .56437 Mdot
.41778 .01922 Mdot
.38668 .11561 Mdot
.19962 .25583 Mdot
.50024 .61771 Mdot
.50075 .61702 Mdot
.5024 .61479 Mdot
.50764 .60771 Mdot
.52434 .58524 Mdot
.57739 .51629 Mdot
.74202 .36893 Mdot
.14508 .48556 Mdot
.35943 .59958 Mdot
.38929 .0761 Mdot
.26616 .22288 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49605 .00534 Mdot
.4874 .01701 Mdot
.45988 .05381 Mdot
.37282 .15956 Mdot
.11465 .25689 Mdot
.699 .11685 Mdot
.50993 .10766 Mdot
.33573 .23431 Mdot
.95661 .19458 Mdot
.64177 .07986 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00263 Mdot
.49379 .00839 Mdot
.48022 .02667 Mdot
.43707 .0835 Mdot
.30196 .22326 Mdot
.94072 .16956 Mdot
.66636 .04193 Mdot
.59852 .57435 Mdot
.6692 .44541 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50433 .61218 Mdot
.51381 .5994 Mdot
.54396 .55916 Mdot
.63923 .44593 Mdot
.91771 .37299 Mdot
.31419 .50869 Mdot
.49111 .51693 Mdot
.6547 .39506 Mdot
.01548 .40938 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48888 .01502 Mdot
.46457 .04759 Mdot
.38756 .14337 Mdot
.15558 .26571 Mdot
.72566 .11988 Mdot
.53169 .0907 Mdot
.38493 .18833 Mdot
.08021 .25958 Mdot
.66021 .1349 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51082 .60342 Mdot
.53448 .5717 Mdot
.60944 .47805 Mdot
.83593 .3515 Mdot
.26719 .49818 Mdot
.46112 .53387 Mdot
.59729 .44919 Mdot
.87049 .34195 Mdot
.31721 .47653 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49704 .004 Mdot
.49057 .01274 Mdot
.46996 .04042 Mdot
.40455 .1237 Mdot
.20439 .26523 Mdot
.77524 .11954 Mdot
.58182 .04698 Mdot
.5058 .0416 Mdot
.43849 .09722 Mdot
.28118 .24194 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.49192 .01091 Mdot
.47427 .03466 Mdot
.41818 .10722 Mdot
.2447 .25468 Mdot
.83261 .12657 Mdot
.62782 .02041 Mdot
.59479 .55567 Mdot
.69569 .41663 Mdot
.02156 .43656 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49271 .00985 Mdot
.47678 .0313 Mdot
.42614 .09733 Mdot
.26865 .24387 Mdot
.87407 .13893 Mdot
.64928 .01996 Mdot
.61699 .53904 Mdot
.7448 .39158 Mdot
.11122 .48649 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51226 .60148 Mdot
.53904 .56565 Mdot
.6238 .46211 Mdot
.87609 .3585 Mdot
.29603 .49991 Mdot
.48715 .51181 Mdot
.65902 .38773 Mdot
.03167 .41689 Mdot
.35713 .53225 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49158 .01137 Mdot
.47318 .03612 Mdot
.41474 .11143 Mdot
.23444 .25827 Mdot
.81654 .12344 Mdot
.61682 .02461 Mdot
.577 .57401 Mdot
.64824 .4556 Mdot
.91106 .37738 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51302 .60045 Mdot
.54147 .56244 Mdot
.63141 .454 Mdot
.89683 .36491 Mdot
.30639 .50329 Mdot
.49205 .51066 Mdot
.66577 .3833 Mdot
.04557 .42498 Mdot
.35795 .53987 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51068 .60362 Mdot
.53401 .57233 Mdot
.60796 .47975 Mdot
.83171 .35122 Mdot
.26342 .49824 Mdot
.45724 .53741 Mdot
.5877 .46015 Mdot
.84316 .33717 Mdot
.2976 .47817 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60336 Mdot
.5346 .57154 Mdot
.60984 .4776 Mdot
.83706 .35159 Mdot
.26818 .49817 Mdot
.46212 .53296 Mdot
.59978 .4464 Mdot
.8775 .34372 Mdot
.32135 .47668 Mdot
.50044 .61743 Mdot
.50141 .61613 Mdot
.5045 .61195 Mdot
.51434 .59868 Mdot
.54566 .55693 Mdot
.64453 .44062 Mdot
.93159 .37913 Mdot
.31814 .51336 Mdot
.4875 .52493 Mdot
.63814 .41235 Mdot
.97094 .38556 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48476 .02057 Mdot
.45149 .06485 Mdot
.34656 .18606 Mdot
.04551 .22768 Mdot
.67712 .09533 Mdot
.52287 .0742 Mdot
.40281 .15881 Mdot
.14584 .27587 Mdot
.50032 .6176 Mdot
.50103 .61664 Mdot
.50329 .61358 Mdot
.51049 .60386 Mdot
.53342 .5731 Mdot
.60612 .48185 Mdot
.82646 .35101 Mdot
.25851 .49835 Mdot
.45217 .54202 Mdot
.57516 .4749 Mdot
.80675 .33664 Mdot
.50002 .61801 Mdot
.50005 .61796 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61084 Mdot
.51696 .59515 Mdot
.55399 .54605 Mdot
.67045 .41656 Mdot
.99645 .41327 Mdot
.32777 .54354 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48936 .01436 Mdot
.46612 .04553 Mdot
.39245 .13782 Mdot
.16945 .26687 Mdot
.73765 .11977 Mdot
.54386 .07962 Mdot
.41503 .15471 Mdot
.1647 .28157 Mdot
.70912 .13886 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50449 .61197 Mdot
.51431 .59872 Mdot
.54555 .55707 Mdot
.6442 .44094 Mdot
.93074 .37874 Mdot
.31792 .51305 Mdot
.48779 .52436 Mdot
.63935 .41106 Mdot
.97423 .38728 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.5122 .60156 Mdot
.53885 .5659 Mdot
.6232 .46276 Mdot
.87443 .35806 Mdot
.29507 .49973 Mdot
.4865 .51223 Mdot
.6577 .38881 Mdot
.0286 .41517 Mdot
.35683 .53071 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50427 .61227 Mdot
.51359 .59969 Mdot
.54328 .56006 Mdot
.63708 .44812 Mdot
.912 .37063 Mdot
.3123 .50702 Mdot
.49192 .5145 Mdot
.65944 .39021 Mdot
.02807 .41609 Mdot
.49994 9e-05 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.49339 .00893 Mdot
.47895 .02839 Mdot
.43302 .08866 Mdot
.28956 .23167 Mdot
.91471 .15633 Mdot
.66176 .03089 Mdot
.61177 .55362 Mdot
.716 .40943 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51208 .60172 Mdot
.53848 .5664 Mdot
.62203 .46403 Mdot
.87121 .35725 Mdot
.29317 .4994 Mdot
.48513 .51316 Mdot
.65481 .39123 Mdot
.02179 .41137 Mdot
.35618 .52728 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48836 .01571 Mdot
.46294 .04976 Mdot
.38242 .14912 Mdot
.14114 .26348 Mdot
.71483 .11952 Mdot
.52145 .09969 Mdot
.36014 .2133 Mdot
.01502 .2272 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60336 Mdot
.5346 .57154 Mdot
.60984 .47761 Mdot
.83705 .35159 Mdot
.26817 .49817 Mdot
.46211 .53296 Mdot
.59976 .44642 Mdot
.87744 .3437 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54244 .56116 Mdot
.63446 .45082 Mdot
.90503 .3679 Mdot
.30974 .50517 Mdot
.49236 .51226 Mdot
.6635 .38597 Mdot
.03899 .42175 Mdot
.35657 .53744 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.49429 .00771 Mdot
.48182 .02452 Mdot
.44215 .07698 Mdot
.3176 .21141 Mdot
.97552 .18881 Mdot
.67002 .05951 Mdot
.57374 .6116 Mdot
.58414 .53718 Mdot
.71496 .3932 Mdot
.49982 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49402 .00808 Mdot
.48094 .02571 Mdot
.43934 .08059 Mdot
.30895 .21813 Mdot
.956 .17786 Mdot
.66822 .04937 Mdot
.58834 .58965 Mdot
.63426 .47943 Mdot
.85853 .36488 Mdot
.50059 .61723 Mdot
.5019 .61547 Mdot
.50604 .60988 Mdot
.51924 .59208 Mdot
.56123 .53672 Mdot
.6928 .3986 Mdot
.04786 .4423 Mdot
.3322 .5706 Mdot
.40896 .03243 Mdot
.35648 .14817 Mdot
.11674 .24695 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.50931 .60547 Mdot
.52964 .57814 Mdot
.59419 .49584 Mdot
.79191 .35338 Mdot
.22013 .49833 Mdot
.41382 .57438 Mdot
.48446 .58877 Mdot
.53181 .55947 Mdot
.62657 .45411 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49652 .0047 Mdot
.48892 .01496 Mdot
.46471 .04741 Mdot
.388 .14289 Mdot
.1568 .26585 Mdot
.72665 .11989 Mdot
.53267 .08981 Mdot
.38735 .18574 Mdot
.08681 .26229 Mdot
.66242 .13653 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49619 .00515 Mdot
.48785 .0164 Mdot
.46131 .05191 Mdot
.37732 .15471 Mdot
.12699 .26034 Mdot
.70576 .11846 Mdot
.51409 .10542 Mdot
.34352 .22821 Mdot
.97426 .20446 Mdot
.64344 .08876 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50723 .60826 Mdot
.52304 .58698 Mdot
.57329 .52141 Mdot
.72964 .37507 Mdot
.12277 .47793 Mdot
.34947 .59758 Mdot
.38257 .0788 Mdot
.25507 .22627 Mdot
.88897 .13148 Mdot
.50042 .61747 Mdot
.50134 .61622 Mdot
.50427 .61226 Mdot
.51361 .59966 Mdot
.54334 .55998 Mdot
.63728 .44792 Mdot
.91253 .37085 Mdot
.31248 .50717 Mdot
.49186 .51471 Mdot
.65905 .39061 Mdot
.02703 .41555 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01438 Mdot
.46608 .04559 Mdot
.39232 .13797 Mdot
.16909 .26685 Mdot
.73731 .11978 Mdot
.54351 .07994 Mdot
.41418 .1557 Mdot
.16225 .28138 Mdot
.70697 .1392 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49063 .01266 Mdot
.47015 .04017 Mdot
.40516 .12297 Mdot
.20619 .26496 Mdot
.77747 .11961 Mdot
.58394 .04536 Mdot
.51055 .03558 Mdot
.45297 .07855 Mdot
.32588 .20964 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50982 .60477 Mdot
.53129 .57595 Mdot
.59938 .4897 Mdot
.80703 .35152 Mdot
.23826 .49867 Mdot
.4314 .56031 Mdot
.52479 .53742 Mdot
.65522 .41527 Mdot
.9833 .39982 Mdot
.5013 .61627 Mdot
.50415 .61243 Mdot
.51322 .60018 Mdot
.54211 .56159 Mdot
.63344 .45188 Mdot
.90227 .36687 Mdot
.30866 .50451 Mdot
.49235 .5116 Mdot
.66457 .3848 Mdot
.04195 .42324 Mdot
.35713 .5386 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50759 .60779 Mdot
.52417 .58546 Mdot
.57687 .51694 Mdot
.74044 .36966 Mdot
.14232 .48471 Mdot
.35805 .59953 Mdot
.38799 .07698 Mdot
.26343 .224 Mdot
.90099 .13802 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.50252 .61464 Mdot
.50801 .60721 Mdot
.52553 .58365 Mdot
.58116 .51162 Mdot
.75334 .36411 Mdot
.16419 .49073 Mdot
.37018 .59817 Mdot
.40232 .06511 Mdot
.49988 .00016 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.48791 .01633 Mdot
.46148 .05169 Mdot
.37784 .15414 Mdot
.12844 .2607 Mdot
.70662 .1186 Mdot
.51471 .10498 Mdot
.34485 .22709 Mdot
.97741 .20622 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51041 .60398 Mdot
.53315 .57347 Mdot
.60526 .48285 Mdot
.82399 .35096 Mdot
.25611 .4984 Mdot
.44969 .54427 Mdot
.56904 .48226 Mdot
.78873 .33906 Mdot
.24012 .48632 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39526 .13459 Mdot
.17748 .26708 Mdot
.74533 .1196 Mdot
.55181 .07242 Mdot
.43464 .13132 Mdot
.22216 .27661 Mdot
.77459 .13083 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50204 .61527 Mdot
.50651 .60924 Mdot
.52075 .59005 Mdot
.56602 .53059 Mdot
.70751 .38827 Mdot
.07927 .45876 Mdot
.33698 .58481 Mdot
.39074 .0603 Mdot
.29317 .20245 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61075 Mdot
.51718 .59485 Mdot
.55468 .54515 Mdot
.67261 .41471 Mdot
.0016 .41619 Mdot
.32819 .54629 Mdot
.44428 .5969 Mdot
.47848 .61679 Mdot
.48049 .0168 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49013 .01333 Mdot
.46857 .04228 Mdot
.40016 .12889 Mdot
.19162 .26661 Mdot
.76023 .11937 Mdot
.56708 .05902 Mdot
.47159 .08522 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00381 Mdot
.49101 .01214 Mdot
.47138 .03853 Mdot
.40904 .11833 Mdot
.21758 .26283 Mdot
.79232 .12047 Mdot
.5974 .0357 Mdot
.53963 .61737 Mdot
.54071 .58005 Mdot
.60217 .4917 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00329 Mdot
.49224 .01048 Mdot
.47529 .03329 Mdot
.42142 .10322 Mdot
.2544 .25071 Mdot
.84875 .13066 Mdot
.63733 .01857 Mdot
.60728 .54452 Mdot
.72623 .39861 Mdot
.08126 .47072 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48853 .01549 Mdot
.46347 .04906 Mdot
.38408 .14727 Mdot
.14579 .2643 Mdot
.71814 .1197 Mdot
.52445 .09713 Mdot
.3673 .20638 Mdot
.03337 .23709 Mdot
.64975 .11786 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.4973 .00364 Mdot
.49141 .01161 Mdot
.47263 .03685 Mdot
.413 .11355 Mdot
.22926 .25985 Mdot
.80882 .12227 Mdot
.61099 .02751 Mdot
.56648 .58569 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51017 .60429 Mdot
.5324 .57446 Mdot
.60291 .48557 Mdot
.81724 .351 Mdot
.24931 .49854 Mdot
.44266 .55056 Mdot
.55183 .50335 Mdot
.73739 .35627 Mdot
.16092 .48131 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51168 .60226 Mdot
.5372 .56809 Mdot
.618 .46845 Mdot
.86002 .35478 Mdot
.28597 .49857 Mdot
.47926 .51775 Mdot
.64153 .40316 Mdot
.9892 .39316 Mdot
.35306 .51084 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49594 .00548 Mdot
.48708 .01745 Mdot
.45884 .05518 Mdot
.36956 .16301 Mdot
.10581 .25403 Mdot
.69478 .11528 Mdot
.50825 .10764 Mdot
.33409 .23507 Mdot
.95374 .19278 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.5033 .61357 Mdot
.51052 .60383 Mdot
.5335 .573 Mdot
.60636 .48158 Mdot
.82716 .35103 Mdot
.25918 .49833 Mdot
.45286 .5414 Mdot
.57686 .47289 Mdot
.81171 .33629 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.5078 .6075 Mdot
.52485 .58455 Mdot
.57902 .51427 Mdot
.74692 .36675 Mdot
.1535 .488 Mdot
.36391 .59934 Mdot
.39415 .07236 Mdot
.27708 .21777 Mdot
.92472 .15055 Mdot
.50102 .61665 Mdot
.50326 .61364 Mdot
.51037 .60403 Mdot
.53304 .57362 Mdot
.60491 .48325 Mdot
.82298 .35095 Mdot
.25513 .49842 Mdot
.44867 .54519 Mdot
.56653 .48529 Mdot
.78131 .34059 Mdot
.23022 .487 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61511 Mdot
.5069 .60872 Mdot
.52197 .58842 Mdot
.56989 .52569 Mdot
.71931 .38088 Mdot
.10303 .46986 Mdot
.34278 .59304 Mdot
.38322 .07381 Mdot
.2638 .2208 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60118 Mdot
.53975 .56471 Mdot
.62603 .4597 Mdot
.88222 .36021 Mdot
.29938 .50071 Mdot
.48922 .5107 Mdot
.6629 .3847 Mdot
.04043 .42178 Mdot
.35797 .53666 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.505 .61128 Mdot
.51592 .59655 Mdot
.55067 .55037 Mdot
.66016 .42571 Mdot
.97135 .3993 Mdot
.32528 .53064 Mdot
.46669 .5613 Mdot
.55849 .50829 Mdot
.73607 .36131 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50629 .60954 Mdot
.52004 .59101 Mdot
.56377 .53346 Mdot
.7006 .39297 Mdot
.06477 .45137 Mdot
.33444 .57863 Mdot
.3982 .04866 Mdot
.31946 .18238 Mdot
.02436 .20488 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.5058 .6102 Mdot
.51847 .59312 Mdot
.55877 .53987 Mdot
.68524 .40437 Mdot
.03095 .43288 Mdot
.33053 .56194 Mdot
.42129 .01394 Mdot
.39873 .10161 Mdot
.23432 .24844 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51271 .60087 Mdot
.54048 .56375 Mdot
.62832 .45727 Mdot
.88845 .36211 Mdot
.30254 .50169 Mdot
.49078 .51023 Mdot
.66522 .38313 Mdot
.0453 .42456 Mdot
.35835 .53922 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60337 Mdot
.5346 .57155 Mdot
.60982 .47763 Mdot
.837 .35158 Mdot
.26813 .49817 Mdot
.46207 .53301 Mdot
.59964 .44655 Mdot
.87712 .34361 Mdot
.32114 .47666 Mdot
.49975 .00033 Mdot
.49922 .00106 Mdot
.4975 .00337 Mdot
.49205 .01074 Mdot
.47466 .03413 Mdot
.41944 .10567 Mdot
.24847 .2532 Mdot
.83878 .12802 Mdot
.63163 .01944 Mdot
.60018 .55062 Mdot
.70926 .40788 Mdot
.0493 .45285 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.4877 .01661 Mdot
.46082 .05257 Mdot
.37575 .15641 Mdot
.12268 .25921 Mdot
.70328 .11797 Mdot
.51239 .1065 Mdot
.34008 .23104 Mdot
.96625 .19998 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01506 Mdot
.46449 .0477 Mdot
.38731 .14366 Mdot
.15485 .26562 Mdot
.72507 .11988 Mdot
.53111 .09122 Mdot
.3835 .18984 Mdot
.07634 .25793 Mdot
.65901 .13384 Mdot
.50076 .617 Mdot
.50244 .61474 Mdot
.50777 .60754 Mdot
.52474 .5847 Mdot
.57867 .51471 Mdot
.74585 .36722 Mdot
.15168 .48749 Mdot
.3629 .59944 Mdot
.39299 .07331 Mdot
.27437 .21913 Mdot
.91982 .1479 Mdot
.50034 .61757 Mdot
.50108 .61657 Mdot
.50346 .61336 Mdot
.51101 .60316 Mdot
.53507 .57091 Mdot
.61132 .47592 Mdot
.84127 .35198 Mdot
.27176 .49815 Mdot
.46574 .52966 Mdot
.60872 .43653 Mdot
.90241 .35162 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51338 .59997 Mdot
.54261 .56094 Mdot
.63499 .45027 Mdot
.90644 .36844 Mdot
.31028 .50553 Mdot
.49232 .51265 Mdot
.66283 .38668 Mdot
.03717 .42083 Mdot
.50032 .6176 Mdot
.50103 .61664 Mdot
.50328 .61361 Mdot
.51044 .60394 Mdot
.53325 .57334 Mdot
.60557 .48249 Mdot
.82488 .35098 Mdot
.25699 .49838 Mdot
.45059 .54345 Mdot
.57127 .47956 Mdot
.79533 .33796 Mdot
.50032 .6176 Mdot
.50103 .61664 Mdot
.5033 .61358 Mdot
.5105 .60385 Mdot
.53345 .57306 Mdot
.60622 .48174 Mdot
.82674 .35102 Mdot
.25878 .49834 Mdot
.45244 .54178 Mdot
.57583 .4741 Mdot
.80872 .33649 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49776 .00303 Mdot
.49286 .00964 Mdot
.47726 .03065 Mdot
.42767 .09542 Mdot
.27327 .24139 Mdot
.88269 .14222 Mdot
.65257 .02147 Mdot
.61782 .53999 Mdot
.74411 .39254 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60849 Mdot
.52251 .58769 Mdot
.5716 .52354 Mdot
.7245 .37788 Mdot
.11308 .47411 Mdot
.34595 .59564 Mdot
.38218 .07712 Mdot
.25739 .22451 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49067 .0126 Mdot
.47028 .04 Mdot
.40556 .1225 Mdot
.20736 .26478 Mdot
.77894 .11967 Mdot
.58532 .04431 Mdot
.51363 .03169 Mdot
.46236 .06626 Mdot
.35515 .18275 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50658 .60915 Mdot
.52095 .58978 Mdot
.56666 .52977 Mdot
.70947 .38699 Mdot
.08331 .46074 Mdot
.33782 .58639 Mdot
.38901 .06311 Mdot
.28689 .20671 Mdot
.95243 .16326 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49852 .002 Mdot
.49527 .00639 Mdot
.48494 .02033 Mdot
.45204 .06412 Mdot
.34829 .18441 Mdot
.04991 .22992 Mdot
.67788 .09727 Mdot
.5205 .07832 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49775 .00304 Mdot
.49282 .0097 Mdot
.47713 .03083 Mdot
.42724 .09596 Mdot
.27198 .2421 Mdot
.88026 .14127 Mdot
.65168 .021 Mdot
.61771 .53959 Mdot
.74463 .39213 Mdot
.11015 .48628 Mdot
.50008 .61792 Mdot
.50026 .61769 Mdot
.50082 .61692 Mdot
.50262 .6145 Mdot
.50834 .60677 Mdot
.52657 .58225 Mdot
.58446 .50758 Mdot
.76318 .36054 Mdot
.17982 .49397 Mdot
.38056 .59459 Mdot
.41849 .04886 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51223 .60152 Mdot
.53895 .56578 Mdot
.6235 .46243 Mdot
.87527 .35828 Mdot
.29556 .49982 Mdot
.48684 .51201 Mdot
.65839 .38824 Mdot
.0302 .41607 Mdot
.35698 .53151 Mdot
.50026 .61769 Mdot
.50082 .61692 Mdot
.50262 .6145 Mdot
.50833 .60678 Mdot
.52654 .58229 Mdot
.58438 .50767 Mdot
.76295 .36062 Mdot
.17945 .4939 Mdot
.3803 .5947 Mdot
.41805 .04933 Mdot
.33824 .17477 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.54169 .56215 Mdot
.63212 .45325 Mdot
.89874 .36559 Mdot
.30721 .5037 Mdot
.4922 .51093 Mdot
.66549 .38371 Mdot
.04464 .42455 Mdot
.50018 .6178 Mdot
.50056 .61727 Mdot
.50179 .61561 Mdot
.50571 .61032 Mdot
.51819 .59349 Mdot
.5579 .54099 Mdot
.68257 .40649 Mdot
.02485 .42943 Mdot
.33001 .55872 Mdot
.42598 .00687 Mdot
.41486 .08208 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00264 Mdot
.49378 .0084 Mdot
.48018 .02673 Mdot
.43694 .08367 Mdot
.30156 .22354 Mdot
.93987 .16911 Mdot
.66624 .04153 Mdot
.59904 .57356 Mdot
.671 .44382 Mdot
.95288 .40078 Mdot
.50096 .61673 Mdot
.50307 .61389 Mdot
.50978 .60483 Mdot
.53115 .57614 Mdot
.59894 .49021 Mdot
.80577 .35163 Mdot
.23683 .49867 Mdot
.42996 .56152 Mdot
.52141 .54173 Mdot
.64487 .42522 Mdot
.95684 .3857 Mdot
.50116 .61647 Mdot
.50369 .61304 Mdot
.51177 .60215 Mdot
.53748 .56772 Mdot
.61888 .46748 Mdot
.86248 .35528 Mdot
.28763 .49871 Mdot
.4807 .51657 Mdot
.64487 .40006 Mdot
.99757 .3978 Mdot
.35391 .515 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50253 .61461 Mdot
.50807 .60713 Mdot
.52572 .58339 Mdot
.58178 .51087 Mdot
.75518 .3634 Mdot
.16718 .49142 Mdot
.37205 .59766 Mdot
.40502 .06254 Mdot
.30382 .20173 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .01561 Mdot
.46318 .04944 Mdot
.38318 .14827 Mdot
.14327 .26387 Mdot
.71632 .11961 Mdot
.52279 .09856 Mdot
.36331 .21026 Mdot
.0231 .2316 Mdot
.50042 .61746 Mdot
.50134 .61622 Mdot
.50428 .61225 Mdot
.51363 .59963 Mdot
.54341 .55989 Mdot
.63749 .4477 Mdot
.91309 .37108 Mdot
.31267 .50733 Mdot
.4918 .51493 Mdot
.65863 .39104 Mdot
.02592 .41496 Mdot
.50021 .61774 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50693 .60867 Mdot
.52208 .58827 Mdot
.57024 .52524 Mdot
.72039 .38024 Mdot
.10514 .47078 Mdot
.34341 .59363 Mdot
.38289 .07463 Mdot
.26213 .22175 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50023 .61772 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.52369 .58611 Mdot
.57534 .51885 Mdot
.73581 .37189 Mdot
.13408 .482 Mdot
.35418 .59905 Mdot
.5002 .61776 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50656 .60917 Mdot
.52091 .58984 Mdot
.56652 .52995 Mdot
.70904 .38726 Mdot
.08244 .46032 Mdot
.33763 .58606 Mdot
.38937 .06252 Mdot
.28821 .20583 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00536 Mdot
.48737 .01705 Mdot
.45977 .05395 Mdot
.37248 .15992 Mdot
.11373 .2566 Mdot
.69854 .11671 Mdot
.5097 .10772 Mdot
.33541 .23452 Mdot
.95594 .1942 Mdot
.64172 .0795 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.5364 .56915 Mdot
.6155 .47123 Mdot
.85303 .35354 Mdot
.281 .49829 Mdot
.47474 .52161 Mdot
.63075 .41358 Mdot
.96157 .3783 Mdot
.34947 .49795 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51041 .60398 Mdot
.53315 .57347 Mdot
.60525 .48286 Mdot
.82397 .35096 Mdot
.2561 .4984 Mdot
.44968 .54428 Mdot
.56901 .48229 Mdot
.78865 .33907 Mdot
.24002 .48633 Mdot
.5012 .61641 Mdot
.50383 .61285 Mdot
.51222 .60154 Mdot
.53891 .56583 Mdot
.62338 .46257 Mdot
.87492 .35819 Mdot
.29536 .49978 Mdot
.4867 .5121 Mdot
.6581 .38847 Mdot
.02954 .4157 Mdot
.35692 .53119 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50976 .60486 Mdot
.53108 .57623 Mdot
.59872 .49047 Mdot
.80513 .35168 Mdot
.23609 .49867 Mdot
.42923 .56213 Mdot
.51969 .54393 Mdot
.6396 .43048 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .0018 Mdot
.49576 .00573 Mdot
.48649 .01824 Mdot
.45696 .05766 Mdot
.36367 .16914 Mdot
.09 .2482 Mdot
.68841 .11157 Mdot
.50789 .10425 Mdot
.3392 .22923 Mdot
.96831 .20004 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50628 .60954 Mdot
.52002 .59103 Mdot
.56371 .53353 Mdot
.70044 .39309 Mdot
.06441 .45118 Mdot
.33438 .57847 Mdot
.39841 .04835 Mdot
.32018 .18178 Mdot
.02605 .20582 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.49219 .01055 Mdot
.47511 .03353 Mdot
.42085 .10392 Mdot
.2527 .25145 Mdot
.84585 .12986 Mdot
.63573 .01874 Mdot
.60541 .54604 Mdot
.7219 .40079 Mdot
.07342 .46646 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49007 .0134 Mdot
.46838 .04252 Mdot
.39958 .12956 Mdot
.18996 .26673 Mdot
.75838 .11939 Mdot
.56521 .06061 Mdot
.46715 .09084 Mdot
.32016 .22428 Mdot
.95726 .18514 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .0142 Mdot
.46651 .04502 Mdot
.39366 .13643 Mdot
.17291 .267 Mdot
.74089 .1197 Mdot
.54721 .07657 Mdot
.42331 .14495 Mdot
.18879 .28171 Mdot
.73297 .13501 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47454 .03429 Mdot
.41906 .10613 Mdot
.24733 .25366 Mdot
.83691 .12757 Mdot
.6305 .0197 Mdot
.59862 .55204 Mdot
.7054 .41025 Mdot
.04159 .44838 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .00279 Mdot
.49341 .0089 Mdot
.47901 .02831 Mdot
.43321 .08842 Mdot
.29014 .2313 Mdot
.91588 .1569 Mdot
.66201 .03133 Mdot
.61131 .55438 Mdot
.7143 .41054 Mdot
.05004 .45616 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50927 .60552 Mdot
.52952 .57831 Mdot
.5938 .4963 Mdot
.79077 .35357 Mdot
.21868 .49827 Mdot
.41247 .57538 Mdot
.48148 .59252 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48811 .01606 Mdot
.46213 .05083 Mdot
.37988 .15191 Mdot
.13408 .26202 Mdot
.71012 .11909 Mdot
.51743 .10296 Mdot
.35084 .22186 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60224 Mdot
.53725 .56803 Mdot
.61816 .46827 Mdot
.86048 .35487 Mdot
.28628 .4986 Mdot
.47953 .51752 Mdot
.64216 .40257 Mdot
.99079 .39404 Mdot
.50129 .61629 Mdot
.50411 .61249 Mdot
.51308 .60037 Mdot
.54167 .56218 Mdot
.63203 .45334 Mdot
.89851 .3655 Mdot
.30711 .50365 Mdot
.49218 .5109 Mdot
.66553 .38365 Mdot
.04478 .42461 Mdot
.35774 .53962 Mdot
.50045 .61742 Mdot
.50144 .61609 Mdot
.50459 .61184 Mdot
.51462 .5983 Mdot
.54654 .55577 Mdot
.64728 .43791 Mdot
.93873 .3825 Mdot
.31983 .51607 Mdot
.48482 .53012 Mdot
.62706 .42445 Mdot
.94029 .37038 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51666 .59556 Mdot
.55303 .5473 Mdot
.66748 .41915 Mdot
.98928 .40922 Mdot
.32715 .53977 Mdot
.45379 .58201 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49613 .00522 Mdot
.48768 .01663 Mdot
.46077 .05263 Mdot
.37562 .15655 Mdot
.12232 .25911 Mdot
.70308 .11793 Mdot
.51226 .10657 Mdot
.33983 .23123 Mdot
.96568 .19967 Mdot
.64262 .08445 Mdot
.50032 .6176 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51038 .60401 Mdot
.53308 .57357 Mdot
.60503 .48312 Mdot
.82333 .35096 Mdot
.25547 .49841 Mdot
.44902 .54487 Mdot
.5674 .48424 Mdot
.78388 .34003 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49587 .00557 Mdot
.48686 .01775 Mdot
.45814 .0561 Mdot
.36737 .16532 Mdot
.09988 .25195 Mdot
.69222 .11402 Mdot
.50772 .10687 Mdot
.33481 .23396 Mdot
.95626 .19391 Mdot
.6425 .07877 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.51179 .60211 Mdot
.53756 .56761 Mdot
.61914 .46719 Mdot
.86321 .35543 Mdot
.28811 .49876 Mdot
.4811 .51624 Mdot
.64582 .39919 Mdot
.99991 .39911 Mdot
.35414 .51618 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.5092 .6056 Mdot
.52932 .57857 Mdot
.59317 .49705 Mdot
.78892 .3539 Mdot
.2163 .49815 Mdot
.41029 .57698 Mdot
.47671 .5985 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49615 .0052 Mdot
.48775 .01655 Mdot
.46098 .05236 Mdot
.37625 .15587 Mdot
.12405 .25958 Mdot
.70405 .11814 Mdot
.5129 .10619 Mdot
.34109 .23022 Mdot
.96859 .20129 Mdot
.6429 .08591 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51294 .60056 Mdot
.54121 .56279 Mdot
.6306 .45485 Mdot
.89464 .36416 Mdot
.30543 .50284 Mdot
.49181 .51043 Mdot
.66591 .38301 Mdot
.04619 .42523 Mdot
.35815 .54 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.48691 .01767 Mdot
.45832 .05587 Mdot
.36791 .16474 Mdot
.10135 .25248 Mdot
.69283 .11435 Mdot
.50781 .10712 Mdot
.33449 .23435 Mdot
.9553 .19346 Mdot
.64228 .07844 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50395 .61269 Mdot
.5126 .60103 Mdot
.54011 .56424 Mdot
.62716 .4585 Mdot
.88528 .36113 Mdot
.30097 .50117 Mdot
.49006 .51038 Mdot
.66424 .38374 Mdot
.04333 .42342 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.46491 .04714 Mdot
.38863 .14217 Mdot
.1586 .26604 Mdot
.72813 .11989 Mdot
.53415 .08847 Mdot
.39099 .18181 Mdot
.09682 .26613 Mdot
.66621 .13857 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00483 Mdot
.48861 .01538 Mdot
.46372 .04872 Mdot
.38489 .14638 Mdot
.14805 .26467 Mdot
.7198 .11977 Mdot
.52601 .09576 Mdot
.37106 .20264 Mdot
.04318 .24218 Mdot
.50045 .61742 Mdot
.50145 .61608 Mdot
.50461 .61181 Mdot
.51467 .59823 Mdot
.54672 .55553 Mdot
.64786 .43734 Mdot
.94022 .38322 Mdot
.32016 .51666 Mdot
.48419 .53129 Mdot
.62454 .42726 Mdot
.93322 .36716 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51112 .60301 Mdot
.53542 .57045 Mdot
.61242 .47468 Mdot
.84438 .35232 Mdot
.27431 .49815 Mdot
.46828 .52736 Mdot
.615 .42978 Mdot
.9196 .35838 Mdot
.33973 .48309 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .60419 Mdot
.53265 .57414 Mdot
.60367 .48468 Mdot
.81944 .35096 Mdot
.25157 .4985 Mdot
.44499 .54849 Mdot
.55751 .49632 Mdot
.75445 .34883 Mdot
.19002 .48603 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00301 Mdot
.4929 .0096 Mdot
.47737 .0305 Mdot
.42802 .09498 Mdot
.27433 .24081 Mdot
.8847 .14302 Mdot
.65328 .02189 Mdot
.61785 .54039 Mdot
.74349 .39297 Mdot
.10765 .48533 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50531 .61085 Mdot
.51693 .59519 Mdot
.55389 .54618 Mdot
.67016 .41681 Mdot
.99575 .41287 Mdot
.32771 .54317 Mdot
.44884 .58978 Mdot
.49456 .59483 Mdot
.50056 .61728 Mdot
.50178 .61563 Mdot
.50566 .61039 Mdot
.51803 .59371 Mdot
.55739 .54165 Mdot
.68098 .40776 Mdot
.02121 .42736 Mdot
.32972 .55679 Mdot
.42882 .00256 Mdot
.42467 .06982 Mdot
.3117 .20641 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61346 Mdot
.51079 .60347 Mdot
.53435 .57187 Mdot
.60906 .47849 Mdot
.83484 .35142 Mdot
.26623 .4982 Mdot
.46013 .53477 Mdot
.59484 .45196 Mdot
.86356 .34041 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61069 Mdot
.51732 .59466 Mdot
.55514 .54455 Mdot
.67404 .4135 Mdot
.00498 .41812 Mdot
.32846 .54809 Mdot
.44162 .60101 Mdot
.46917 .01138 Mdot
.45075 .05631 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49667 .0045 Mdot
.48939 .01433 Mdot
.46619 .04544 Mdot
.39267 .13757 Mdot
.17008 .2669 Mdot
.73823 .11976 Mdot
.54446 .07908 Mdot
.4165 .15298 Mdot
.16898 .28182 Mdot
.71299 .13824 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48854 .01548 Mdot
.46349 .04903 Mdot
.38415 .1472 Mdot
.14597 .26433 Mdot
.71827 .11971 Mdot
.52457 .09702 Mdot
.36759 .20609 Mdot
.03414 .23749 Mdot
.64987 .1182 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50375 .61296 Mdot
.51196 .60188 Mdot
.5381 .5669 Mdot
.62084 .46533 Mdot
.86791 .35646 Mdot
.29115 .4991 Mdot
.48358 .5143 Mdot
.65142 .39416 Mdot
.01365 .4068 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00534 Mdot
.4874 .01702 Mdot
.45986 .05383 Mdot
.37276 .15962 Mdot
.11449 .25684 Mdot
.69892 .11683 Mdot
.50989 .10767 Mdot
.33567 .23435 Mdot
.95649 .19451 Mdot
.64176 .07979 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50232 .61489 Mdot
.50741 .60803 Mdot
.52359 .58624 Mdot
.57503 .51923 Mdot
.73489 .37235 Mdot
.13241 .48143 Mdot
.35345 .59889 Mdot
.38443 .07882 Mdot
.25689 .22623 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00534 Mdot
.4874 .01701 Mdot
.45987 .05382 Mdot
.37278 .1596 Mdot
.11455 .25686 Mdot
.69895 .11684 Mdot
.5099 .10766 Mdot
.3357 .23433 Mdot
.95654 .19454 Mdot
.64177 .07982 Mdot
.4996 .00054 Mdot
.49872 .00172 Mdot
.49593 .00549 Mdot
.48704 .01749 Mdot
.45874 .05532 Mdot
.36922 .16337 Mdot
.10488 .25372 Mdot
.69436 .1151 Mdot
.50813 .10756 Mdot
.3341 .23498 Mdot
.9539 .19284 Mdot
.64189 .07805 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00548 Mdot
.48709 .01743 Mdot
.45888 .05513 Mdot
.36967 .16289 Mdot
.10611 .25413 Mdot
.69491 .11534 Mdot
.50829 .10766 Mdot
.33409 .23509 Mdot
.95371 .19278 Mdot
.64179 .07804 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50398 .61265 Mdot
.51269 .60089 Mdot
.54043 .56382 Mdot
.62815 .45744 Mdot
.88799 .36197 Mdot
.30232 .50161 Mdot
.49069 .51024 Mdot
.6651 .38319 Mdot
.04508 .42443 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49438 .0076 Mdot
.48208 .02417 Mdot
.44298 .07591 Mdot
.32015 .20935 Mdot
.98141 .19216 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60082 Mdot
.5406 .56359 Mdot
.62869 .45687 Mdot
.88947 .36244 Mdot
.30303 .50187 Mdot
.49099 .51022 Mdot
.66544 .38301 Mdot
.04572 .42481 Mdot
.35836 .53946 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.4876 .01674 Mdot
.46051 .05298 Mdot
.37479 .15744 Mdot
.12005 .25848 Mdot
.70183 .11764 Mdot
.51148 .107 Mdot
.33836 .23239 Mdot
.96235 .1978 Mdot
.64229 .08278 Mdot
.50036 .61755 Mdot
.50114 .6165 Mdot
.50362 .61314 Mdot
.51154 .60246 Mdot
.53674 .5687 Mdot
.61656 .47005 Mdot
.856 .35404 Mdot
.28315 .49839 Mdot
.47674 .51988 Mdot
.63555 .40887 Mdot
.97398 .38486 Mdot
.50093 .61678 Mdot
.50296 .61403 Mdot
.50945 .60528 Mdot
.53009 .57755 Mdot
.59559 .49416 Mdot
.79602 .35274 Mdot
.22527 .49851 Mdot
.41866 .57067 Mdot
.4953 .57503 Mdot
.56487 .51654 Mdot
.72909 .37027 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51031 .60411 Mdot
.53285 .57387 Mdot
.60431 .48395 Mdot
.82126 .35095 Mdot
.25342 .49846 Mdot
.44689 .54678 Mdot
.56218 .4906 Mdot
.76837 .34403 Mdot
.21171 .48733 Mdot
.50046 .61742 Mdot
.50145 .61607 Mdot
.50463 .61178 Mdot
.51475 .59813 Mdot
.54696 .55523 Mdot
.64858 .43664 Mdot
.94208 .38412 Mdot
.32056 .51741 Mdot
.48338 .53279 Mdot
.62131 .4309 Mdot
.92409 .36317 Mdot
.50123 .61637 Mdot
.50391 .61275 Mdot
.51247 .6012 Mdot
.53971 .56477 Mdot
.62589 .45986 Mdot
.88181 .36009 Mdot
.29917 .50065 Mdot
.4891 .51075 Mdot
.66269 .38486 Mdot
.03998 .42153 Mdot
.35793 .53643 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51178 .60213 Mdot
.53751 .56768 Mdot
.61898 .46737 Mdot
.86276 .35533 Mdot
.28782 .49873 Mdot
.48085 .51644 Mdot
.64523 .39972 Mdot
.99847 .3983 Mdot
.354 .51545 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00568 Mdot
.48661 .01808 Mdot
.45736 .05713 Mdot
.36492 .16786 Mdot
.09331 .24949 Mdot
.68962 .11244 Mdot
.50769 .10531 Mdot
.33729 .23122 Mdot
.96318 .19738 Mdot
.64381 .08148 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00233 Mdot
.49451 .00741 Mdot
.48252 .02358 Mdot
.44437 .07411 Mdot
.32446 .2058 Mdot
.99147 .19789 Mdot
.67127 .06804 Mdot
.56119 .0127 Mdot
.54064 .59347 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49735 .00358 Mdot
.49155 .01142 Mdot
.47307 .03627 Mdot
.41439 .11186 Mdot
.2334 .2586 Mdot
.81498 .12318 Mdot
.61567 .02515 Mdot
.57498 .57621 Mdot
.64264 .46098 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.4977 .00311 Mdot
.49266 .00991 Mdot
.47663 .0315 Mdot
.42567 .09793 Mdot
.26721 .24461 Mdot
.87142 .13796 Mdot
.64819 .01959 Mdot
.61649 .53902 Mdot
.74435 .39156 Mdot
.11078 .48617 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.46629 .04532 Mdot
.39297 .13723 Mdot
.17092 .26693 Mdot
.73901 .11974 Mdot
.54527 .07834 Mdot
.41852 .15062 Mdot
.17482 .282 Mdot
.50062 .6172 Mdot
.50198 .61536 Mdot
.50629 .60953 Mdot
.52005 .59099 Mdot
.56381 .53341 Mdot
.70074 .39287 Mdot
.06506 .45152 Mdot
.33449 .57876 Mdot
.39803 .04893 Mdot
.31886 .18287 Mdot
.02296 .20409 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00233 Mdot
.49451 .00742 Mdot
.4825 .02361 Mdot
.4443 .0742 Mdot
.32424 .20598 Mdot
.99096 .1976 Mdot
.67123 .06776 Mdot
.56159 .01208 Mdot
.54204 .5916 Mdot
.58481 .51664 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00395 Mdot
.49068 .01259 Mdot
.4703 .03997 Mdot
.40562 .12242 Mdot
.20754 .26475 Mdot
.77917 .11967 Mdot
.58553 .04414 Mdot
.5141 .03109 Mdot
.4638 .06435 Mdot
.35968 .17823 Mdot
.50063 .61719 Mdot
.502 .61533 Mdot
.50638 .60942 Mdot
.52032 .59064 Mdot
.56464 .53234 Mdot
.7033 .39111 Mdot
.07047 .45432 Mdot
.33536 .58115 Mdot
.39504 .05352 Mdot
.30844 .19123 Mdot
.99903 .19033 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61068 Mdot
.51735 .59463 Mdot
.55521 .54446 Mdot
.67425 .41332 Mdot
.00549 .41841 Mdot
.32849 .54837 Mdot
.44122 .60163 Mdot
.46775 .01329 Mdot
.44625 .06217 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50564 .61042 Mdot
.51796 .5938 Mdot
.55716 .54194 Mdot
.68028 .40833 Mdot
.01958 .42644 Mdot
.32959 .55592 Mdot
.43009 .00063 Mdot
.42907 .06423 Mdot
.32514 .19564 Mdot
.49969 .00043 Mdot
.499 .00135 Mdot
.49681 .00432 Mdot
.48982 .01374 Mdot
.46758 .04359 Mdot
.39706 .1325 Mdot
.18267 .26704 Mdot
.75059 .11949 Mdot
.55724 .06756 Mdot
.44793 .11498 Mdot
.26188 .26212 Mdot
.83777 .13644 Mdot
.50058 .61725 Mdot
.50185 .61554 Mdot
.50588 .61009 Mdot
.51874 .59276 Mdot
.55964 .53876 Mdot
.68791 .4023 Mdot
.03698 .43627 Mdot
.33108 .56508 Mdot
.41676 .02075 Mdot
.38319 .11957 Mdot
.18971 .25666 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.5049 .61141 Mdot
.51562 .59695 Mdot
.54974 .55158 Mdot
.65726 .42839 Mdot
.96411 .3954 Mdot
.32434 .52714 Mdot
.47141 .5535 Mdot
.57584 .48583 Mdot
.78975 .34286 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.4882 .01593 Mdot
.46242 .05045 Mdot
.38078 .15093 Mdot
.13658 .26256 Mdot
.71174 .11926 Mdot
.51878 .10189 Mdot
.35391 .2191 Mdot
.9994 .21854 Mdot
.64579 .10151 Mdot
.50033 .61759 Mdot
.50105 .61662 Mdot
.50333 .61353 Mdot
.51061 .6037 Mdot
.53381 .5726 Mdot
.60733 .48047 Mdot
.82991 .35114 Mdot
.26176 .49828 Mdot
.45553 .53897 Mdot
.58346 .4651 Mdot
.83092 .33621 Mdot
.50065 .61716 Mdot
.50207 .61524 Mdot
.50659 .60914 Mdot
.52098 .58974 Mdot
.56676 .52966 Mdot
.70976 .3868 Mdot
.0839 .46103 Mdot
.33794 .58662 Mdot
.38878 .0635 Mdot
.28603 .20728 Mdot
.95064 .16225 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51227 .60147 Mdot
.53907 .56562 Mdot
.62388 .46203 Mdot
.87631 .35855 Mdot
.29615 .49994 Mdot
.48723 .51176 Mdot
.65918 .38759 Mdot
.03204 .4171 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49803 .00266 Mdot
.49373 .00847 Mdot
.48003 .02694 Mdot
.43644 .08431 Mdot
.30002 .22463 Mdot
.93657 .16737 Mdot
.66576 .04001 Mdot
.60103 .57055 Mdot
.67786 .43791 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57436 .52007 Mdot
.73288 .37337 Mdot
.12875 .48013 Mdot
.35188 .59847 Mdot
.38354 .07902 Mdot
.25569 .22647 Mdot
.88926 .13189 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .6049 Mdot
.53098 .57636 Mdot
.59841 .49083 Mdot
.80424 .35177 Mdot
.23507 .49866 Mdot
.42821 .56298 Mdot
.51729 .54698 Mdot
.63225 .43801 Mdot
.92354 .36982 Mdot
.50125 .61635 Mdot
.50398 .61266 Mdot
.51267 .60092 Mdot
.54036 .5639 Mdot
.62795 .45765 Mdot
.88745 .3618 Mdot
.30205 .50152 Mdot
.49057 .51026 Mdot
.66496 .38328 Mdot
.04479 .42426 Mdot
.35832 .53893 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01347 Mdot
.46824 .04272 Mdot
.39912 .1301 Mdot
.18861 .26681 Mdot
.75691 .1194 Mdot
.56372 .0619 Mdot
.46357 .09537 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50902 .60586 Mdot
.52872 .57938 Mdot
.59126 .49933 Mdot
.78333 .35501 Mdot
.20891 .49766 Mdot
.40367 .58162 Mdot
.46259 .61598 Mdot
.46592 .0293 Mdot
.41851 .10159 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60498 Mdot
.53078 .57663 Mdot
.59778 .49158 Mdot
.80239 .35195 Mdot
.23292 .49865 Mdot
.42609 .56473 Mdot
.51233 .55332 Mdot
.61704 .45434 Mdot
.88191 .35463 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50957 .6051 Mdot
.5305 .577 Mdot
.59689 .49263 Mdot
.79979 .35225 Mdot
.22984 .49861 Mdot
.42307 .56718 Mdot
.50535 .56222 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48822 .01591 Mdot
.46248 .05038 Mdot
.38097 .15072 Mdot
.13709 .26267 Mdot
.71208 .11929 Mdot
.51906 .10166 Mdot
.35457 .21849 Mdot
.00104 .21946 Mdot
.64595 .10234 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50923 .60556 Mdot
.52941 .57845 Mdot
.59345 .49671 Mdot
.78975 .35375 Mdot
.21738 .4982 Mdot
.41127 .57627 Mdot
.47885 .59581 Mdot
.51481 .5821 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00202 Mdot
.49525 .00642 Mdot
.48485 .02044 Mdot
.45178 .06447 Mdot
.34747 .1852 Mdot
.04782 .22886 Mdot
.67751 .09636 Mdot
.52161 .07639 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.5081 .60709 Mdot
.52581 .58327 Mdot
.58207 .51051 Mdot
.75604 .36308 Mdot
.16857 .49172 Mdot
.37294 .5974 Mdot
.40633 .06127 Mdot
.30719 .19939 Mdot
.98457 .18511 Mdot
.50071 .61708 Mdot
.50225 .615 Mdot
.50716 .60836 Mdot
.52282 .58727 Mdot
.57259 .52229 Mdot
.72752 .37621 Mdot
.1188 .4764 Mdot
.34797 .59686 Mdot
.38224 .0783 Mdot
.25554 .22576 Mdot
.89026 .1319 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.4875 .01687 Mdot
.4602 .05338 Mdot
.37383 .15848 Mdot
.1174 .25771 Mdot
.70042 .11727 Mdot
.51067 .10739 Mdot
.33692 .23347 Mdot
.50065 .61715 Mdot
.50207 .61523 Mdot
.50661 .60911 Mdot
.52105 .58965 Mdot
.56699 .52936 Mdot
.71046 .38635 Mdot
.08534 .46172 Mdot
.33825 .58716 Mdot
.38821 .06444 Mdot
.28394 .20865 Mdot
.94634 .15984 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.4892 .01458 Mdot
.46562 .04621 Mdot
.39085 .13965 Mdot
.1649 .2666 Mdot
.73354 .11984 Mdot
.53963 .08348 Mdot
.40456 .16675 Mdot
.13475 .27727 Mdot
.68611 .14146 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00506 Mdot
.48807 .0161 Mdot
.46202 .05098 Mdot
.37952 .15231 Mdot
.13308 .2618 Mdot
.70948 .11901 Mdot
.51692 .10336 Mdot
.34969 .22289 Mdot
.98904 .21274 Mdot
.64482 .09626 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.49549 .00609 Mdot
.48564 .01939 Mdot
.45427 .0612 Mdot
.35525 .17764 Mdot
.06782 .23863 Mdot
.68171 .10446 Mdot
.5127 .0927 Mdot
.36271 .20476 Mdot
.0314 .23368 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .0054 Mdot
.48727 .01718 Mdot
.45947 .05435 Mdot
.37153 .16093 Mdot
.11115 .25579 Mdot
.69727 .11627 Mdot
.50913 .10781 Mdot
.33469 .23496 Mdot
.95452 .19337 Mdot
.64165 .07871 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49775 .00303 Mdot
.49284 .00967 Mdot
.4772 .03073 Mdot
.42749 .09564 Mdot
.27273 .24169 Mdot
.88168 .14182 Mdot
.6522 .02127 Mdot
.61778 .53981 Mdot
.74436 .39236 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54244 .56116 Mdot
.63446 .45082 Mdot
.90502 .3679 Mdot
.30974 .50517 Mdot
.49236 .51226 Mdot
.66351 .38597 Mdot
.03899 .42176 Mdot
.35657 .53744 Mdot
.50055 .61729 Mdot
.50176 .61565 Mdot
.50561 .61045 Mdot
.51789 .5939 Mdot
.55694 .54224 Mdot
.67958 .4089 Mdot
.01796 .42552 Mdot
.32946 .55505 Mdot
.43137 .61673 Mdot
.43348 .05858 Mdot
.3387 .1838 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49414 .00791 Mdot
.48133 .02518 Mdot
.44059 .07898 Mdot
.3128 .21519 Mdot
.96462 .18266 Mdot
.66907 .05378 Mdot
.58205 .59907 Mdot
.61274 .50308 Mdot
.79873 .3624 Mdot
.50072 .61705 Mdot
.50231 .61491 Mdot
.50736 .6081 Mdot
.52344 .58644 Mdot
.57455 .51983 Mdot
.73345 .37308 Mdot
.12979 .48051 Mdot
.35232 .5986 Mdot
.38377 .07899 Mdot
.25597 .22643 Mdot
.8896 .13209 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50184 .61555 Mdot
.50587 .61011 Mdot
.5187 .59281 Mdot
.5595 .53893 Mdot
.6875 .40262 Mdot
.03605 .43575 Mdot
.33099 .5646 Mdot
.41744 .01971 Mdot
.38555 .11691 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .6022 Mdot
.53735 .56788 Mdot
.6185 .4679 Mdot
.86142 .35506 Mdot
.28692 .49865 Mdot
.48009 .51706 Mdot
.64346 .40136 Mdot
.99404 .39584 Mdot
.35356 .51324 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.49321 .00917 Mdot
.47837 .02917 Mdot
.43117 .09101 Mdot
.28392 .23522 Mdot
.90333 .15101 Mdot
.659 .02693 Mdot
.61542 .5471 Mdot
.73019 .4007 Mdot
.5008 .61695 Mdot
.50255 .61458 Mdot
.50814 .60704 Mdot
.52592 .58312 Mdot
.58241 .51009 Mdot
.75706 .3627 Mdot
.1702 .49208 Mdot
.374 .59706 Mdot
.40793 .0597 Mdot
.31134 .19642 Mdot
.99352 .19042 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49666 .00451 Mdot
.48937 .01435 Mdot
.46614 .0455 Mdot
.39252 .13774 Mdot
.16964 .26688 Mdot
.73783 .11976 Mdot
.54404 .07945 Mdot
.41548 .15417 Mdot
.16603 .28165 Mdot
.7103 .13867 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00455 Mdot
.48926 .0145 Mdot
.46579 .04597 Mdot
.39141 .13901 Mdot
.16649 .2667 Mdot
.73495 .11982 Mdot
.54108 .08215 Mdot
.40815 .16265 Mdot
.14498 .27922 Mdot
.69319 .14098 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50529 .61089 Mdot
.51684 .59531 Mdot
.55361 .54655 Mdot
.66928 .41757 Mdot
.99363 .41167 Mdot
.32753 .54205 Mdot
.45048 .58723 Mdot
.50033 .58692 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49803 .00265 Mdot
.49374 .00846 Mdot
.48005 .0269 Mdot
.43653 .08419 Mdot
.30031 .22443 Mdot
.93718 .16769 Mdot
.66585 .04029 Mdot
.60067 .5711 Mdot
.67661 .43897 Mdot
.96634 .408 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.4877 .01661 Mdot
.46083 .05256 Mdot
.37579 .15637 Mdot
.12278 .25923 Mdot
.70333 .11798 Mdot
.51243 .10648 Mdot
.34014 .23098 Mdot
.96641 .20007 Mdot
.64269 .08481 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00805 Mdot
.48102 .0256 Mdot
.43961 .08025 Mdot
.30975 .21752 Mdot
.9578 .17886 Mdot
.66841 .05028 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .0048 Mdot
.48867 .01529 Mdot
.46393 .04845 Mdot
.38553 .14565 Mdot
.14986 .26494 Mdot
.72118 .11981 Mdot
.52732 .09461 Mdot
.37423 .19945 Mdot
.05151 .24637 Mdot
.65287 .12546 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.4971 .00391 Mdot
.49077 .01247 Mdot
.4706 .03957 Mdot
.40657 .12129 Mdot
.21032 .26427 Mdot
.78271 .11984 Mdot
.58882 .04171 Mdot
.52133 .02199 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49399 .00812 Mdot
.48085 .02583 Mdot
.43906 .08095 Mdot
.30807 .21878 Mdot
.95407 .1768 Mdot
.66801 .0484 Mdot
.5897 .58761 Mdot
.63892 .47457 Mdot
.87105 .36768 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48759 .01675 Mdot
.46049 .053 Mdot
.37473 .15751 Mdot
.11987 .25842 Mdot
.70173 .11761 Mdot
.51143 .10703 Mdot
.33825 .23247 Mdot
.9621 .19767 Mdot
.64227 .08265 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .0019 Mdot
.49552 .00605 Mdot
.48572 .01927 Mdot
.45454 .06085 Mdot
.35609 .17681 Mdot
.07 .23963 Mdot
.68227 .10525 Mdot
.51197 .09416 Mdot
.35961 .20807 Mdot
.02294 .22927 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.4638 .04862 Mdot
.38514 .14609 Mdot
.14876 .26478 Mdot
.72034 .11979 Mdot
.52652 .09532 Mdot
.37229 .20141 Mdot
.04639 .24382 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49246 .01018 Mdot
.47599 .03236 Mdot
.42364 .10046 Mdot
.26109 .24765 Mdot
.86038 .13419 Mdot
.64326 .0186 Mdot
.61316 .54035 Mdot
.73885 .39317 Mdot
.10268 .4819 Mdot
.50055 .61729 Mdot
.50174 .61568 Mdot
.50555 .61053 Mdot
.5177 .59416 Mdot
.55633 .54302 Mdot
.6777 .41044 Mdot
.0136 .42303 Mdot
.32912 .55272 Mdot
.43481 .61147 Mdot
.44542 .04305 Mdot
.37576 .14688 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .00221 Mdot
.49479 .00704 Mdot
.48341 .02239 Mdot
.44718 .07047 Mdot
.33316 .19833 Mdot
.01225 .20968 Mdot
.67299 .07907 Mdot
.54505 .03786 Mdot
.48379 .05286 Mdot
.39827 .14088 Mdot
.5012 .61642 Mdot
.50381 .61289 Mdot
.51213 .60165 Mdot
.53864 .56619 Mdot
.62253 .46349 Mdot
.87259 .35759 Mdot
.294 .49953 Mdot
.48574 .51274 Mdot
.65611 .39013 Mdot
.02486 .41308 Mdot
.35647 .52882 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00314 Mdot
.49259 .01001 Mdot
.47639 .03182 Mdot
.42491 .09888 Mdot
.26492 .24577 Mdot
.86725 .13649 Mdot
.64641 .01911 Mdot
.61548 .53924 Mdot
.74297 .39184 Mdot
.10896 .48514 Mdot
.50132 .61625 Mdot
.5042 .61235 Mdot
.51339 .59995 Mdot
.54265 .56089 Mdot
.63512 .45014 Mdot
.90678 .36857 Mdot
.31041 .50562 Mdot
.49231 .51275 Mdot
.66266 .38687 Mdot
.0367 .42059 Mdot
.35617 .5365 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.4872 .01729 Mdot
.45923 .05467 Mdot
.37077 .16174 Mdot
.10907 .25512 Mdot
.69628 .1159 Mdot
.50874 .1078 Mdot
.33431 .23512 Mdot
.95387 .19296 Mdot
.64166 .0783 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49728 .00368 Mdot
.49132 .01172 Mdot
.47235 .03722 Mdot
.41212 .11461 Mdot
.22667 .26058 Mdot
.80505 .12177 Mdot
.60802 .02914 Mdot
.56087 .59212 Mdot
.6028 .5033 Mdot
.78844 .36004 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51338 .59997 Mdot
.54262 .56092 Mdot
.63503 .45023 Mdot
.90653 .36848 Mdot
.31032 .50555 Mdot
.49232 .51268 Mdot
.66279 .38673 Mdot
.03704 .42076 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48821 .01592 Mdot
.46245 .0504 Mdot
.3809 .15079 Mdot
.13691 .26263 Mdot
.71196 .11928 Mdot
.51896 .10175 Mdot
.35433 .21871 Mdot
.00046 .21913 Mdot
.6459 .10204 Mdot
.50027 .61766 Mdot
.50087 .61685 Mdot
.50278 .61428 Mdot
.50886 .60606 Mdot
.52823 .58003 Mdot
.58973 .50118 Mdot
.7788 .35604 Mdot
.20271 .49712 Mdot
.39835 .58508 Mdot
.45166 .01118 Mdot
.43358 .07098 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48929 .01446 Mdot
.46588 .04585 Mdot
.3917 .13868 Mdot
.16731 .26675 Mdot
.73569 .11981 Mdot
.54184 .08146 Mdot
.41004 .16048 Mdot
.15037 .28005 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .61211 Mdot
.51398 .59917 Mdot
.5445 .55845 Mdot
.64091 .44423 Mdot
.92214 .37489 Mdot
.31555 .51009 Mdot
.4902 .51917 Mdot
.65017 .39971 Mdot
.50122 .61638 Mdot
.50389 .61277 Mdot
.5124 .60129 Mdot
.5395 .56504 Mdot
.62525 .46055 Mdot
.88007 .35959 Mdot
.29824 .50041 Mdot
.48855 .51101 Mdot
.66172 .38559 Mdot
.03781 .42032 Mdot
.35772 .53534 Mdot
.49962 .00052 Mdot
.49879 .00164 Mdot
.49613 .00523 Mdot
.48767 .01665 Mdot
.46073 .05268 Mdot
.37548 .1567 Mdot
.12194 .259 Mdot
.70287 .11788 Mdot
.51213 .10665 Mdot
.33957 .23144 Mdot
.96509 .19933 Mdot
.64256 .08415 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00448 Mdot
.48944 .01425 Mdot
.46638 .04519 Mdot
.39327 .13688 Mdot
.17178 .26697 Mdot
.73982 .11972 Mdot
.5461 .07758 Mdot
.42058 .14819 Mdot
.18081 .28201 Mdot
.72452 .13635 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50723 .60826 Mdot
.52305 .58697 Mdot
.5733 .52139 Mdot
.72967 .37505 Mdot
.12282 .47794 Mdot
.34949 .59759 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00372 Mdot
.49122 .01186 Mdot
.47203 .03766 Mdot
.41109 .11586 Mdot
.22362 .26139 Mdot
.80069 .12126 Mdot
.60449 .03121 Mdot
.55399 .60014 Mdot
.50123 .61638 Mdot
.50391 .61275 Mdot
.51245 .60123 Mdot
.53965 .56485 Mdot
.6257 .46007 Mdot
.88129 .35994 Mdot
.29889 .50058 Mdot
.48894 .51082 Mdot
.66241 .38506 Mdot
.03936 .42119 Mdot
.35787 .53612 Mdot
.50038 .61753 Mdot
.5012 .61642 Mdot
.50381 .61289 Mdot
.51213 .60165 Mdot
.53864 .56618 Mdot
.62254 .46348 Mdot
.87261 .35759 Mdot
.29401 .49954 Mdot
.48574 .51273 Mdot
.65612 .39012 Mdot
.02489 .4131 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00306 Mdot
.49278 .00975 Mdot
.477 .031 Mdot
.42684 .09646 Mdot
.27077 .24275 Mdot
.878 .1404 Mdot
.65082 .02059 Mdot
.61751 .53931 Mdot
.74489 .39184 Mdot
.11087 .48651 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49391 .00823 Mdot
.48059 .02618 Mdot
.43824 .08201 Mdot
.30555 .22066 Mdot
.94852 .17376 Mdot
.66737 .04566 Mdot
.5935 .58191 Mdot
.65195 .46149 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50348 .61334 Mdot
.51108 .60308 Mdot
.53528 .57064 Mdot
.61197 .47519 Mdot
.8431 .35218 Mdot
.27327 .49815 Mdot
.46726 .52829 Mdot
.61247 .43249 Mdot
.91268 .35554 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49392 .00821 Mdot
.48063 .02612 Mdot
.43837 .08183 Mdot
.30596 .22035 Mdot
.94942 .17425 Mdot
.66748 .0461 Mdot
.59289 .58282 Mdot
.64987 .46353 Mdot
.89987 .3767 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00557 Mdot
.48686 .01773 Mdot
.45817 .05607 Mdot
.36745 .16523 Mdot
.1001 .25203 Mdot
.69231 .11407 Mdot
.50773 .10691 Mdot
.33475 .23402 Mdot
.9561 .19384 Mdot
.64246 .07871 Mdot
.50059 .61724 Mdot
.50188 .6155 Mdot
.50599 .60995 Mdot
.51907 .59231 Mdot
.5607 .53738 Mdot
.6912 .3998 Mdot
.04431 .44035 Mdot
.33182 .56882 Mdot
.41144 .02872 Mdot
.36497 .13941 Mdot
.13939 .25274 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.4985 .00202 Mdot
.49523 .00644 Mdot
.48481 .02051 Mdot
.45163 .06466 Mdot
.347 .18564 Mdot
.04663 .22825 Mdot
.67731 .09583 Mdot
.52225 .07527 Mdot
.40045 .16166 Mdot
.13889 .27468 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00202 Mdot
.49524 .00643 Mdot
.48484 .02046 Mdot
.45175 .06451 Mdot
.34737 .18529 Mdot
.04756 .22873 Mdot
.67747 .09624 Mdot
.52174 .07615 Mdot
.39853 .16398 Mdot
.13321 .27355 Mdot
.50076 .61701 Mdot
.50243 .61476 Mdot
.50773 .60759 Mdot
.52462 .58486 Mdot
.57829 .51517 Mdot
.74473 .36771 Mdot
.14977 .48695 Mdot
.36187 .59952 Mdot
.39183 .07422 Mdot
.27175 .22039 Mdot
.91515 .1454 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50605 .60986 Mdot
.51927 .59205 Mdot
.56131 .53661 Mdot
.69306 .3984 Mdot
.04843 .44261 Mdot
.33227 .57088 Mdot
.40856 .03303 Mdot
.35513 .14954 Mdot
.11317 .24583 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49458 .00732 Mdot
.48274 .02329 Mdot
.44504 .07324 Mdot
.32655 .20404 Mdot
.9964 .20071 Mdot
.67165 .07068 Mdot
.55729 .01871 Mdot
.52702 .61181 Mdot
.5371 .57773 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49047 .01287 Mdot
.46964 .04085 Mdot
.40355 .12489 Mdot
.20147 .26563 Mdot
.77167 .11945 Mdot
.57839 .04968 Mdot
.49801 .05152 Mdot
.41465 .12691 Mdot
.20931 .26966 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49007 .01341 Mdot
.46838 .04252 Mdot
.39958 .12956 Mdot
.18995 .26673 Mdot
.75837 .11939 Mdot
.5652 .06062 Mdot
.46712 .09088 Mdot
.32007 .22435 Mdot
.95706 .18503 Mdot
.50043 .61745 Mdot
.50138 .61618 Mdot
.50438 .61211 Mdot
.51396 .59918 Mdot
.54446 .5585 Mdot
.64079 .44435 Mdot
.92181 .37475 Mdot
.31546 .50999 Mdot
.49028 .519 Mdot
.65052 .39935 Mdot
.00437 .40339 Mdot
.50052 .61733 Mdot
.50165 .61581 Mdot
.50525 .61094 Mdot
.51674 .59545 Mdot
.55328 .54698 Mdot
.66825 .41848 Mdot
.99114 .41026 Mdot
.32732 .54074 Mdot
.45238 .58423 Mdot
.50709 .57766 Mdot
.57241 .51282 Mdot
.50072 .61706 Mdot
.50229 .61495 Mdot
.50728 .60819 Mdot
.5232 .58676 Mdot
.57381 .52076 Mdot
.7312 .37424 Mdot
.12566 .47901 Mdot
.35061 .59804 Mdot
.38297 .07898 Mdot
.25517 .22645 Mdot
.88877 .13152 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50685 .60878 Mdot
.52183 .5886 Mdot
.56946 .52623 Mdot
.718 .38166 Mdot
.10046 .46873 Mdot
.34204 .59228 Mdot
.38371 .07271 Mdot
.26606 .21951 Mdot
.50054 .61731 Mdot
.5017 .61573 Mdot
.50543 .6107 Mdot
.51731 .59468 Mdot
.55509 .54463 Mdot
.67386 .41365 Mdot
.00455 .41787 Mdot
.32842 .54786 Mdot
.44196 .60049 Mdot
.47035 .00978 Mdot
.45452 .05137 Mdot
.50041 .61748 Mdot
.5013 .61628 Mdot
.50413 .61245 Mdot
.51316 .60027 Mdot
.5419 .56187 Mdot
.63278 .45256 Mdot
.90052 .36623 Mdot
.30795 .5041 Mdot
.4923 .51124 Mdot
.66509 .3842 Mdot
.04345 .42398 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .61211 Mdot
.51397 .59917 Mdot
.54449 .55846 Mdot
.64087 .44427 Mdot
.92204 .37485 Mdot
.31552 .51006 Mdot
.49023 .51912 Mdot
.65028 .3996 Mdot
.00371 .40304 Mdot
.49964 .00048 Mdot
.49886 .00153 Mdot
.49638 .00489 Mdot
.48847 .01556 Mdot
.46329 .04929 Mdot
.38353 .14789 Mdot
.14425 .26404 Mdot
.71702 .11965 Mdot
.52342 .09801 Mdot
.36483 .20879 Mdot
.027 .2337 Mdot
.64886 .11496 Mdot
.49978 .0003 Mdot
.49929 .00095 Mdot
.49775 .00303 Mdot
.49284 .00967 Mdot
.4772 .03073 Mdot
.42747 .09566 Mdot
.27269 .24171 Mdot
.88159 .14179 Mdot
.65217 .02125 Mdot
.61778 .5398 Mdot
.74437 .39234 Mdot
.10955 .48607 Mdot
.50051 .61735 Mdot
.50161 .61586 Mdot
.50513 .6111 Mdot
.51636 .59596 Mdot
.55208 .54854 Mdot
.66453 .42176 Mdot
.98211 .40521 Mdot
.32647 .53605 Mdot
.45912 .57353 Mdot
.53113 .54485 Mdot
.64954 .42574 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48712 .01738 Mdot
.459 .05498 Mdot
.37004 .16251 Mdot
.10709 .25447 Mdot
.69536 .11553 Mdot
.50842 .10773 Mdot
.33412 .23514 Mdot
.95366 .19278 Mdot
.64173 .07808 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50915 .60568 Mdot
.52914 .57882 Mdot
.59259 .49775 Mdot
.78721 .35422 Mdot
.21407 .49802 Mdot
.40826 .57844 Mdot
.47233 .60396 Mdot
.49511 .60849 Mdot
.51056 .59871 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60695 Mdot
.52615 .58281 Mdot
.58314 .5092 Mdot
.75924 .3619 Mdot
.17367 .4928 Mdot
.3763 .59627 Mdot
.41151 .05611 Mdot
.32072 .18933 Mdot
.01437 .20264 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.4882 .01593 Mdot
.46243 .05043 Mdot
.38084 .15087 Mdot
.13673 .26259 Mdot
.71184 .11927 Mdot
.51886 .10183 Mdot
.3541 .21892 Mdot
.99988 .21881 Mdot
.64584 .10175 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60904 Mdot
.5212 .58944 Mdot
.56746 .52876 Mdot
.71191 .38542 Mdot
.08829 .46314 Mdot
.33892 .58825 Mdot
.38712 .0663 Mdot
.27985 .21126 Mdot
.93802 .15524 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50883 .60611 Mdot
.52813 .58017 Mdot
.58939 .50159 Mdot
.7778 .35629 Mdot
.20131 .49698 Mdot
.39717 .58582 Mdot
.4493 .014 Mdot
.42665 .07961 Mdot
.29784 .22054 Mdot
.49965 .00047 Mdot
.49889 .00149 Mdot
.49647 .00476 Mdot
.48877 .01517 Mdot
.46423 .04805 Mdot
.38648 .14459 Mdot
.15252 .26532 Mdot
.72323 .11986 Mdot
.5293 .09285 Mdot
.37907 .19448 Mdot
.06439 .25256 Mdot
.65574 .13014 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52047 .59042 Mdot
.56515 .5317 Mdot
.70484 .39006 Mdot
.07371 .45597 Mdot
.33593 .58253 Mdot
.39337 .05612 Mdot
.30258 .19568 Mdot
.98596 .18268 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.4935 .00878 Mdot
.47928 .02794 Mdot
.43408 .08731 Mdot
.2928 .22955 Mdot
.92138 .1596 Mdot
.66315 .03348 Mdot
.60897 .5582 Mdot
.70578 .41632 Mdot
.49962 .00052 Mdot
.49878 .00164 Mdot
.49612 .00524 Mdot
.48765 .01668 Mdot
.46066 .05278 Mdot
.37527 .15693 Mdot
.12134 .25884 Mdot
.70253 .11781 Mdot
.51192 .10677 Mdot
.33916 .23176 Mdot
.96417 .19882 Mdot
.64247 .08369 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00517 Mdot
.48781 .01646 Mdot
.46119 .05208 Mdot
.37691 .15515 Mdot
.12587 .26005 Mdot
.7051 .11834 Mdot
.51362 .10573 Mdot
.34255 .22902 Mdot
.97198 .20318 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02203 Mdot
.44803 .06935 Mdot
.33582 .19597 Mdot
.01874 .2133 Mdot
.67362 .08242 Mdot
.54026 .04549 Mdot
.46666 .07618 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00806 Mdot
.481 .02563 Mdot
.43954 .08034 Mdot
.30955 .21768 Mdot
.95734 .1786 Mdot
.66836 .05004 Mdot
.58739 .59108 Mdot
.631 .48289 Mdot
.84968 .36334 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51103 .60314 Mdot
.53512 .57085 Mdot
.61147 .47576 Mdot
.84167 .35202 Mdot
.27209 .49815 Mdot
.46608 .52936 Mdot
.60956 .43562 Mdot
.90471 .35247 Mdot
.33441 .47974 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61095 Mdot
.51671 .59548 Mdot
.5532 .54707 Mdot
.66802 .41867 Mdot
.99059 .40996 Mdot
.32727 .54045 Mdot
.4528 .58357 Mdot
.50856 .57564 Mdot
.57715 .50689 Mdot
.50065 .61716 Mdot
.50207 .61524 Mdot
.50659 .60913 Mdot
.521 .58971 Mdot
.56683 .52957 Mdot
.70997 .38667 Mdot
.08433 .46124 Mdot
.33803 .58678 Mdot
.3886 .06379 Mdot
.28539 .2077 Mdot
.94933 .16152 Mdot
.50002 .61801 Mdot
.50006 .61795 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52128 .58934 Mdot
.5677 .52846 Mdot
.71264 .38496 Mdot
.08976 .46383 Mdot
.33927 .58877 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00194 Mdot
.49542 .00618 Mdot
.48541 .01969 Mdot
.45356 .06213 Mdot
.35303 .17982 Mdot
.06207 .23592 Mdot
.68035 .10228 Mdot
.51486 .08853 Mdot
.37161 .19505 Mdot
.05601 .24591 Mdot
.50131 .61627 Mdot
.50416 .61241 Mdot
.51327 .60012 Mdot
.54225 .56141 Mdot
.63386 .45144 Mdot
.90342 .3673 Mdot
.30912 .50478 Mdot
.49236 .51186 Mdot
.66416 .38525 Mdot
.04081 .42267 Mdot
.35691 .53816 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00466 Mdot
.48901 .01484 Mdot
.46499 .04703 Mdot
.38889 .14187 Mdot
.15934 .26612 Mdot
.72875 .11989 Mdot
.53477 .08791 Mdot
.39252 .18014 Mdot
.10105 .26765 Mdot
.66798 .13927 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50928 .60551 Mdot
.52954 .57828 Mdot
.59387 .49621 Mdot
.79099 .35353 Mdot
.21897 .49828 Mdot
.41273 .57519 Mdot
.48206 .59178 Mdot
.52454 .56913 Mdot
.60367 .47967 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47928 .02795 Mdot
.43406 .08734 Mdot
.29273 .2296 Mdot
.92123 .15952 Mdot
.66312 .03342 Mdot
.60904 .5581 Mdot
.70601 .41615 Mdot
.03266 .44622 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50697 .60862 Mdot
.52221 .5881 Mdot
.57065 .52473 Mdot
.72161 .37953 Mdot
.10752 .47179 Mdot
.34414 .59427 Mdot
.38259 .07548 Mdot
.26046 .2227 Mdot
.90012 .13607 Mdot
.49992 .00011 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49149 .0115 Mdot
.47288 .03652 Mdot
.41378 .1126 Mdot
.2316 .25916 Mdot
.81228 .12276 Mdot
.61364 .02614 Mdot
.57135 .58022 Mdot
.63253 .47108 Mdot
.50086 .61688 Mdot
.50273 .61435 Mdot
.5087 .60629 Mdot
.52771 .58073 Mdot
.58806 .50319 Mdot
.77388 .35731 Mdot
.19574 .49636 Mdot
.39261 .58853 Mdot
.44035 .02451 Mdot
.4007 .1107 Mdot
.22158 .2559 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00297 Mdot
.493 .00946 Mdot
.47769 .03008 Mdot
.42902 .09372 Mdot
.27737 .23909 Mdot
.89051 .14541 Mdot
.65524 .02326 Mdot
.61761 .54192 Mdot
.74077 .39462 Mdot
.5012 .61641 Mdot
.50383 .61285 Mdot
.51222 .60154 Mdot
.5389 .56583 Mdot
.62336 .46258 Mdot
.87489 .35818 Mdot
.29534 .49978 Mdot
.48669 .51211 Mdot
.65808 .38849 Mdot
.02948 .41567 Mdot
.35691 .53116 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.4862 .01862 Mdot
.45607 .05884 Mdot
.36087 .17201 Mdot
.08256 .24515 Mdot
.68589 .10942 Mdot
.50884 .10123 Mdot
.34506 .22323 Mdot
.98387 .2083 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48859 .01541 Mdot
.46366 .04881 Mdot
.38468 .14661 Mdot
.14746 .26458 Mdot
.71937 .11975 Mdot
.5256 .09612 Mdot
.37007 .20363 Mdot
.04059 .24085 Mdot
.65088 .12101 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50243 .61476 Mdot
.50773 .60759 Mdot
.52462 .58486 Mdot
.57831 .51515 Mdot
.74477 .36769 Mdot
.14984 .48697 Mdot
.36191 .59952 Mdot
.39187 .07419 Mdot
.27183 .22035 Mdot
.50098 .6167 Mdot
.50314 .6138 Mdot
.50999 .60454 Mdot
.53183 .57522 Mdot
.6011 .48767 Mdot
.81203 .35119 Mdot
.24379 .49863 Mdot
.43699 .55552 Mdot
.53814 .5205 Mdot
.69595 .38138 Mdot
.07886 .45154 Mdot
.50027 .61768 Mdot
.50085 .61689 Mdot
.5027 .61439 Mdot
.50859 .60643 Mdot
.52737 .58118 Mdot
.587 .50448 Mdot
.77074 .35819 Mdot
.19118 .49577 Mdot
.38901 .59052 Mdot
.43352 .03234 Mdot
.3812 .13253 Mdot
.5004 .61749 Mdot
.50128 .6163 Mdot
.50408 .61252 Mdot
.51301 .60047 Mdot
.54143 .5625 Mdot
.63128 .45414 Mdot
.89648 .36479 Mdot
.30624 .50322 Mdot
.49201 .51062 Mdot
.66581 .38324 Mdot
.04571 .42504 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56064 Mdot
.63571 .44953 Mdot
.90836 .36919 Mdot
.311 .50603 Mdot
.49223 .51323 Mdot
.6618 .38777 Mdot
.50004 .61799 Mdot
.50011 .61788 Mdot
.50037 .61754 Mdot
.50117 .61646 Mdot
.50371 .61302 Mdot
.51183 .60206 Mdot
.53767 .56746 Mdot
.61949 .46681 Mdot
.86418 .35563 Mdot
.28876 .49882 Mdot
.48164 .5158 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49085 .01236 Mdot
.47086 .03922 Mdot
.4074 .12031 Mdot
.21273 .26383 Mdot
.78585 .12001 Mdot
.59167 .03965 Mdot
.52752 .01426 Mdot
.50446 .01013 Mdot
.48807 .02117 Mdot
.49989 .00014 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49659 .0046 Mdot
.48914 .01466 Mdot
.46542 .04647 Mdot
.39024 .14035 Mdot
.16315 .26646 Mdot
.73201 .11986 Mdot
.53807 .08491 Mdot
.40069 .17111 Mdot
.12382 .27467 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50375 .61296 Mdot
.51195 .60189 Mdot
.53807 .56693 Mdot
.62076 .46542 Mdot
.86769 .35641 Mdot
.291 .49909 Mdot
.48347 .51438 Mdot
.65118 .39438 Mdot
.01305 .40647 Mdot
.50084 .61689 Mdot
.50269 .6144 Mdot
.50857 .60645 Mdot
.52731 .58126 Mdot
.58681 .50471 Mdot
.77018 .35835 Mdot
.19036 .49565 Mdot
.38837 .59086 Mdot
.43234 .03368 Mdot
.37784 .13613 Mdot
.15757 .25949 Mdot
.49993 .0001 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49271 .00985 Mdot
.47678 .0313 Mdot
.42614 .09733 Mdot
.26865 .24387 Mdot
.87406 .13893 Mdot
.64928 .01996 Mdot
.61699 .53904 Mdot
.7448 .39158 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50984 .60475 Mdot
.53134 .57588 Mdot
.59955 .48949 Mdot
.80754 .35148 Mdot
.23883 .49866 Mdot
.43197 .55983 Mdot
.52615 .53569 Mdot
.65939 .41142 Mdot
.9937 .40558 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02203 Mdot
.44803 .06935 Mdot
.33582 .19597 Mdot
.01874 .2133 Mdot
.67362 .08242 Mdot
.54026 .04549 Mdot
.46665 .07618 Mdot
.3434 .19904 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50876 .6062 Mdot
.5279 .58047 Mdot
.58869 .50244 Mdot
.77573 .35682 Mdot
.19838 .49667 Mdot
.39475 .58728 Mdot
.44451 .01965 Mdot
.41272 .09657 Mdot
.25646 .24399 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49525 .00642 Mdot
.48487 .02043 Mdot
.45182 .06442 Mdot
.34759 .18508 Mdot
.04811 .22901 Mdot
.67756 .09649 Mdot
.52145 .07667 Mdot
.3974 .16533 Mdot
.12989 .27282 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48711 .0174 Mdot
.45896 .05503 Mdot
.36991 .16264 Mdot
.10676 .25435 Mdot
.6952 .11547 Mdot
.50838 .1077 Mdot
.33411 .23512 Mdot
.95367 .19278 Mdot
.64175 .07806 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48793 .0163 Mdot
.46155 .0516 Mdot
.37807 .15389 Mdot
.12906 .26085 Mdot
.70699 .11866 Mdot
.51499 .10478 Mdot
.34545 .22658 Mdot
.97883 .20702 Mdot
.64387 .09107 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00495 Mdot
.48834 .01575 Mdot
.46285 .04988 Mdot
.38214 .14942 Mdot
.14038 .26333 Mdot
.7143 .11948 Mdot
.52098 .10009 Mdot
.35903 .21434 Mdot
.01222 .22566 Mdot
.6471 .1079 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51138 .60267 Mdot
.53623 .56937 Mdot
.61496 .47183 Mdot
.85153 .3533 Mdot
.27988 .49825 Mdot
.47369 .52254 Mdot
.62821 .41613 Mdot
.9549 .37487 Mdot
.34834 .49514 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01099 Mdot
.47409 .0349 Mdot
.41763 .1079 Mdot
.24304 .2553 Mdot
.82996 .12599 Mdot
.6261 .02094 Mdot
.59223 .55818 Mdot
.68908 .42131 Mdot
.00738 .42815 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.51141 .60263 Mdot
.53632 .56925 Mdot
.61526 .4715 Mdot
.85236 .35343 Mdot
.2805 .49827 Mdot
.47427 .52202 Mdot
.62963 .4147 Mdot
.95863 .37678 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48957 .01408 Mdot
.46679 .04465 Mdot
.39455 .13541 Mdot
.17546 .26706 Mdot
.74334 .11965 Mdot
.54975 .07427 Mdot
.42958 .13744 Mdot
.20719 .27968 Mdot
.75465 .1322 Mdot
.50022 .61773 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50718 .60834 Mdot
.52286 .58722 Mdot
.57272 .52212 Mdot
.72791 .37599 Mdot
.11954 .47669 Mdot
.34825 .597 Mdot
.38228 .07841 Mdot
.2554 .22587 Mdot
.49969 .00043 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48982 .01374 Mdot
.46759 .04358 Mdot
.39708 .13248 Mdot
.18273 .26704 Mdot
.75065 .11949 Mdot
.55731 .06751 Mdot
.44808 .11479 Mdot
.26234 .26189 Mdot
.83859 .13662 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.4877 .01661 Mdot
.46083 .05256 Mdot
.37579 .15636 Mdot
.12279 .25924 Mdot
.70334 .11799 Mdot
.51243 .10647 Mdot
.34016 .23097 Mdot
.96644 .20009 Mdot
.64269 .08483 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49303 .00941 Mdot
.4778 .02992 Mdot
.42939 .09325 Mdot
.2785 .23844 Mdot
.8927 .14633 Mdot
.65593 .02382 Mdot
.61739 .54263 Mdot
.7394 .39541 Mdot
.09961 .48184 Mdot
.50128 .6163 Mdot
.50408 .61252 Mdot
.51301 .60047 Mdot
.54143 .5625 Mdot
.63129 .45413 Mdot
.89649 .36479 Mdot
.30624 .50322 Mdot
.49201 .51062 Mdot
.66581 .38325 Mdot
.0457 .42503 Mdot
.35798 .5399 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00109 Mdot
.49744 .00346 Mdot
.49184 .01103 Mdot
.474 .03503 Mdot
.41732 .10828 Mdot
.24213 .25564 Mdot
.82849 .12568 Mdot
.62514 .02125 Mdot
.59075 .55964 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49445 .0075 Mdot
.48231 .02386 Mdot
.44371 .07497 Mdot
.32241 .2075 Mdot
.98667 .19516 Mdot
.6709 .06546 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50612 .60977 Mdot
.5195 .59173 Mdot
.56206 .53565 Mdot
.69535 .39672 Mdot
.05345 .44534 Mdot
.33287 .57333 Mdot
.4052 .03808 Mdot
.34358 .16085 Mdot
.08331 .23461 Mdot
.50086 .61688 Mdot
.50273 .61434 Mdot
.5087 .60628 Mdot
.52773 .5807 Mdot
.58813 .50311 Mdot
.77408 .35725 Mdot
.19603 .4964 Mdot
.39285 .5884 Mdot
.4408 .02399 Mdot
.40199 .10922 Mdot
.22527 .25498 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.49659 .0046 Mdot
.48915 .01465 Mdot
.46544 .04644 Mdot
.3903 .14027 Mdot
.16334 .26648 Mdot
.73217 .11986 Mdot
.53824 .08475 Mdot
.40111 .17064 Mdot
.125 .27497 Mdot
.68008 .14144 Mdot
.50094 .61677 Mdot
.50299 .61399 Mdot
.50953 .60516 Mdot
.53036 .57719 Mdot
.59644 .49316 Mdot
.79849 .35241 Mdot
.22828 .49858 Mdot
.42155 .5684 Mdot
.50186 .56667 Mdot
.58497 .49159 Mdot
.78957 .34858 Mdot
.50108 .61657 Mdot
.50345 .61337 Mdot
.511 .60318 Mdot
.53504 .57096 Mdot
.6112 .47605 Mdot
.84093 .35194 Mdot
.27148 .49815 Mdot
.46546 .52992 Mdot
.60804 .43728 Mdot
.90051 .35093 Mdot
.33269 .47901 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00333 Mdot
.49216 .01059 Mdot
.47501 .03366 Mdot
.42055 .1043 Mdot
.2518 .25183 Mdot
.84433 .12945 Mdot
.63487 .01885 Mdot
.60437 .54692 Mdot
.71944 .40208 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49276 .00977 Mdot
.47695 .03107 Mdot
.42667 .09667 Mdot
.27026 .24302 Mdot
.87705 .14004 Mdot
.65046 .02042 Mdot
.61741 .53922 Mdot
.74493 .39175 Mdot
.11106 .48656 Mdot
.50012 .61787 Mdot
.50038 .61753 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51218 .60159 Mdot
.53879 .56598 Mdot
.62302 .46296 Mdot
.87394 .35793 Mdot
.29479 .49967 Mdot
.4863 .51236 Mdot
.65729 .38915 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00475 Mdot
.48879 .01514 Mdot
.46429 .04797 Mdot
.38667 .14437 Mdot
.15307 .26539 Mdot
.72366 .11986 Mdot
.52972 .09247 Mdot
.38009 .19341 Mdot
.06715 .25383 Mdot
.65644 .13105 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.4965 .00473 Mdot
.48883 .01508 Mdot
.46444 .04777 Mdot
.38715 .14384 Mdot
.15441 .26556 Mdot
.72472 .11988 Mdot
.53076 .09154 Mdot
.38264 .19074 Mdot
.07402 .25691 Mdot
.65832 .13317 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01054 Mdot
.47515 .03348 Mdot
.42098 .10377 Mdot
.25307 .25129 Mdot
.84649 .13003 Mdot
.63609 .01869 Mdot
.60584 .54569 Mdot
.7229 .40027 Mdot
.07524 .46746 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49816 .00249 Mdot
.49413 .00793 Mdot
.4813 .02523 Mdot
.44048 .07913 Mdot
.31244 .21547 Mdot
.96381 .1822 Mdot
.669 .05336 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.487 .01755 Mdot
.4586 .0555 Mdot
.36879 .16382 Mdot
.10372 .25332 Mdot
.69385 .11486 Mdot
.50801 .10744 Mdot
.33417 .23482 Mdot
.95422 .19297 Mdot
.642 .07811 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49715 .00385 Mdot
.49091 .01227 Mdot
.47105 .03896 Mdot
.40801 .11957 Mdot
.21455 .26347 Mdot
.78825 .12016 Mdot
.59382 .03814 Mdot
.53211 .00857 Mdot
.51825 .60972 Mdot
.53171 .58051 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00556 Mdot
.48688 .01771 Mdot
.45822 .05601 Mdot
.36759 .16508 Mdot
.10049 .25217 Mdot
.69247 .11416 Mdot
.50775 .10697 Mdot
.33467 .23413 Mdot
.95584 .19371 Mdot
.6424 .07862 Mdot
.50095 .61674 Mdot
.50304 .61392 Mdot
.50969 .60494 Mdot
.53087 .5765 Mdot
.59807 .49123 Mdot
.80325 .35187 Mdot
.23392 .49866 Mdot
.42707 .56392 Mdot
.51462 .55038 Mdot
.62408 .44666 Mdot
.90138 .36097 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51088 .60334 Mdot
.53465 .57147 Mdot
.60999 .47744 Mdot
.83748 .35162 Mdot
.26854 .49817 Mdot
.46249 .53262 Mdot
.60069 .44538 Mdot
.88006 .34441 Mdot
.32278 .4768 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61518 Mdot
.50674 .60894 Mdot
.52146 .5891 Mdot
.56827 .52774 Mdot
.71436 .38388 Mdot
.09323 .46545 Mdot
.34012 .58997 Mdot
.38552 .06915 Mdot
.27364 .21507 Mdot
.50104 .61664 Mdot
.5033 .61358 Mdot
.51051 .60384 Mdot
.53347 .57305 Mdot
.60625 .4817 Mdot
.82684 .35102 Mdot
.25887 .49834 Mdot
.45254 .54168 Mdot
.57608 .47381 Mdot
.80944 .33644 Mdot
.26508 .48332 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50854 .6065 Mdot
.5272 .58141 Mdot
.58646 .50514 Mdot
.76914 .35866 Mdot
.18882 .49543 Mdot
.38719 .59147 Mdot
.43017 .03612 Mdot
.37172 .14258 Mdot
.14102 .25687 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .6121 Mdot
.514 .59914 Mdot
.54456 .55837 Mdot
.64111 .44403 Mdot
.92266 .37512 Mdot
.31571 .51027 Mdot
.49008 .51946 Mdot
.64958 .40032 Mdot
.00186 .40204 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60702 Mdot
.52597 .58306 Mdot
.58256 .50991 Mdot
.7575 .36253 Mdot
.17091 .49223 Mdot
.37447 .59691 Mdot
.40865 .05899 Mdot
.31319 .19506 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49786 .00289 Mdot
.49317 .00922 Mdot
.47825 .02932 Mdot
.43081 .09146 Mdot
.28283 .23588 Mdot
.90117 .15003 Mdot
.65841 .02625 Mdot
.61594 .54606 Mdot
.7324 .39942 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49526 .00641 Mdot
.48489 .0204 Mdot
.45189 .06433 Mdot
.3478 .18488 Mdot
.04867 .22929 Mdot
.67766 .09673 Mdot
.52115 .07718 Mdot
.39627 .16668 Mdot
.12659 .27204 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .6022 Mdot
.53734 .5679 Mdot
.61846 .46794 Mdot
.86132 .35504 Mdot
.28686 .49865 Mdot
.48003 .51711 Mdot
.64333 .40149 Mdot
.99371 .39566 Mdot
.35353 .51307 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50731 .60816 Mdot
.52328 .58666 Mdot
.57405 .52046 Mdot
.73192 .37387 Mdot
.12699 .47949 Mdot
.35115 .59823 Mdot
.38319 .07902 Mdot
.25534 .22648 Mdot
.88889 .13164 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49525 .00641 Mdot
.48488 .02041 Mdot
.45186 .06436 Mdot
.34772 .18496 Mdot
.04845 .22918 Mdot
.67762 .09663 Mdot
.52127 .07697 Mdot
.39672 .16614 Mdot
.1279 .27235 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49168 .01124 Mdot
.4735 .03569 Mdot
.41575 .11019 Mdot
.23746 .25728 Mdot
.82117 .12424 Mdot
.62014 .02315 Mdot
.58269 .56792 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.496 .0054 Mdot
.48727 .01719 Mdot
.45947 .05436 Mdot
.37151 .16095 Mdot
.11109 .25578 Mdot
.69724 .11626 Mdot
.50912 .10781 Mdot
.33468 .23496 Mdot
.9545 .19335 Mdot
.64165 .0787 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49632 .00498 Mdot
.48826 .01585 Mdot
.46261 .05019 Mdot
.3814 .15024 Mdot
.1383 .26292 Mdot
.71289 .11937 Mdot
.51975 .1011 Mdot
.35617 .21702 Mdot
.00503 .22168 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48904 .0148 Mdot
.46508 .04692 Mdot
.38917 .14156 Mdot
.16013 .2662 Mdot
.72941 .11988 Mdot
.53544 .0873 Mdot
.39418 .17833 Mdot
.10563 .26922 Mdot
.67001 .13992 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .60259 Mdot
.53642 .56913 Mdot
.61555 .47117 Mdot
.85317 .35356 Mdot
.2811 .4983 Mdot
.47484 .52153 Mdot
.63099 .41335 Mdot
.96218 .37862 Mdot
.34957 .49822 Mdot
.50118 .61645 Mdot
.50375 .61297 Mdot
.51194 .60192 Mdot
.53802 .56701 Mdot
.62058 .46561 Mdot
.86721 .3563 Mdot
.2907 .49905 Mdot
.48323 .51457 Mdot
.65064 .39485 Mdot
.01175 .40574 Mdot
.35525 .52218 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00807 Mdot
.48097 .02567 Mdot
.43944 .08047 Mdot
.30924 .21791 Mdot
.95666 .17823 Mdot
.66829 .0497 Mdot
.58787 .59035 Mdot
.63265 .48113 Mdot
.85417 .36408 Mdot
.50101 .61666 Mdot
.50323 .61367 Mdot
.51029 .60414 Mdot
.53278 .57396 Mdot
.60409 .4842 Mdot
.82063 .35095 Mdot
.25278 .49847 Mdot
.44624 .54737 Mdot
.56057 .49256 Mdot
.76359 .34556 Mdot
.20447 .4871 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49414 .00791 Mdot
.48134 .02517 Mdot
.44062 .07894 Mdot
.31289 .21512 Mdot
.96483 .18277 Mdot
.66909 .05389 Mdot
.5819 .5993 Mdot
.61221 .50368 Mdot
.50113 .61651 Mdot
.5036 .61316 Mdot
.51149 .60253 Mdot
.53658 .56891 Mdot
.61606 .47061 Mdot
.8546 .3538 Mdot
.28214 .49834 Mdot
.47581 .52068 Mdot
.63333 .41104 Mdot
.96826 .38181 Mdot
.35048 .50091 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00438 Mdot
.48966 .01396 Mdot
.46707 .04427 Mdot
.39543 .13439 Mdot
.17798 .26709 Mdot
.74583 .11959 Mdot
.55233 .07195 Mdot
.4359 .12978 Mdot
.22592 .27564 Mdot
.77993 .13069 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60458 Mdot
.53172 .57537 Mdot
.60075 .48808 Mdot
.81102 .35125 Mdot
.24268 .49864 Mdot
.43587 .55649 Mdot
.53544 .52391 Mdot
.68774 .38751 Mdot
.06074 .44246 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50613 .60976 Mdot
.51952 .5917 Mdot
.56213 .53556 Mdot
.69558 .39656 Mdot
.05394 .44561 Mdot
.33293 .57357 Mdot
.40488 .03856 Mdot
.34248 .16189 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48715 .01735 Mdot
.45909 .05486 Mdot
.37033 .16221 Mdot
.10787 .25473 Mdot
.69572 .11568 Mdot
.50854 .10776 Mdot
.33418 .23515 Mdot
.9537 .19283 Mdot
.6417 .07815 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.501 .61668 Mdot
.50319 .61373 Mdot
.51016 .60432 Mdot
.53235 .57453 Mdot
.60274 .48577 Mdot
.81675 .35101 Mdot
.2488 .49855 Mdot
.44213 .55103 Mdot
.55055 .50495 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.51291 .60061 Mdot
.5411 .56293 Mdot
.63025 .45522 Mdot
.8937 .36383 Mdot
.305 .50266 Mdot
.49169 .51036 Mdot
.66591 .38293 Mdot
.04631 .42526 Mdot
.35822 .53999 Mdot
.50067 .61712 Mdot
.50215 .61513 Mdot
.50684 .6088 Mdot
.52178 .58866 Mdot
.56931 .52642 Mdot
.71753 .38194 Mdot
.09954 .46832 Mdot
.34178 .592 Mdot
.3839 .0723 Mdot
.26692 .21901 Mdot
.91255 .14196 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48794 .01629 Mdot
.46158 .05157 Mdot
.37814 .15381 Mdot
.12926 .2609 Mdot
.70712 .11868 Mdot
.51508 .10472 Mdot
.34565 .22641 Mdot
.9793 .20728 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.5119 .60197 Mdot
.53789 .56718 Mdot
.62017 .46607 Mdot
.86605 .35604 Mdot
.28997 .49896 Mdot
.48264 .51502 Mdot
.64931 .39603 Mdot
.00853 .40393 Mdot
.35495 .52054 Mdot
.50016 .61782 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61117 Mdot
.51619 .59619 Mdot
.55154 .54924 Mdot
.66284 .42328 Mdot
.97797 .40291 Mdot
.32604 .53394 Mdot
.46211 .56874 Mdot
.54187 .53037 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00806 Mdot
.48099 .02564 Mdot
.43952 .08037 Mdot
.30948 .21773 Mdot
.95718 .17851 Mdot
.66834 .04997 Mdot
.5875 .59091 Mdot
.63138 .48248 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49344 .00886 Mdot
.4791 .02818 Mdot
.43351 .08804 Mdot
.29106 .2307 Mdot
.91778 .15782 Mdot
.66242 .03206 Mdot
.61054 .55566 Mdot
.71146 .41242 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00376 Mdot
.49113 .01197 Mdot
.47176 .03802 Mdot
.41025 .11688 Mdot
.22113 .26201 Mdot
.7972 .1209 Mdot
.60158 .033 Mdot
.54818 .60704 Mdot
.56597 .54763 Mdot
.67989 .41417 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00302 Mdot
.49289 .00961 Mdot
.47734 .03054 Mdot
.42792 .09511 Mdot
.27403 .24097 Mdot
.88413 .1428 Mdot
.65308 .02177 Mdot
.61785 .54027 Mdot
.74368 .39284 Mdot
.10805 .48549 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.5124 .60129 Mdot
.53949 .56505 Mdot
.62521 .46059 Mdot
.87997 .35956 Mdot
.29818 .5004 Mdot
.48852 .51103 Mdot
.66166 .38564 Mdot
.03768 .42025 Mdot
.35771 .53527 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00376 Mdot
.49113 .01198 Mdot
.47175 .03803 Mdot
.41021 .11693 Mdot
.22102 .26203 Mdot
.79704 .12089 Mdot
.60145 .03308 Mdot
.54792 .60736 Mdot
.5652 .54859 Mdot
.50081 .61693 Mdot
.5026 .61453 Mdot
.50827 .60686 Mdot
.52635 .58254 Mdot
.58378 .50841 Mdot
.76116 .36123 Mdot
.17668 .49339 Mdot
.37836 .59549 Mdot
.41483 .0527 Mdot
.32956 .18219 Mdot
.03476 .21416 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46941 .04115 Mdot
.40282 .12575 Mdot
.19936 .26589 Mdot
.76915 .11941 Mdot
.57595 .05164 Mdot
.49238 .0587 Mdot
.3974 .14737 Mdot
.15896 .27142 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.48751 .01686 Mdot
.46023 .05334 Mdot
.37392 .15837 Mdot
.11767 .25779 Mdot
.70056 .11731 Mdot
.51075 .10735 Mdot
.33705 .23337 Mdot
.95944 .19618 Mdot
.64202 .08131 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48713 .01737 Mdot
.45903 .05494 Mdot
.37014 .16241 Mdot
.10736 .25456 Mdot
.69548 .11558 Mdot
.50846 .10774 Mdot
.33414 .23514 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50079 .61696 Mdot
.50252 .61462 Mdot
.50804 .60717 Mdot
.52561 .58353 Mdot
.58143 .51129 Mdot
.75415 .3638 Mdot
.16551 .49104 Mdot
.371 .59795 Mdot
.40349 .06401 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49356 .0087 Mdot
.47948 .02767 Mdot
.43471 .08651 Mdot
.29473 .22827 Mdot
.92538 .1616 Mdot
.66391 .03512 Mdot
.60708 .56121 Mdot
.69903 .42116 Mdot
.01757 .43742 Mdot
.50028 .61766 Mdot
.50088 .61684 Mdot
.5028 .61424 Mdot
.50894 .60597 Mdot
.52846 .57972 Mdot
.59046 .5003 Mdot
.78095 .35554 Mdot
.20567 .4974 Mdot
.40086 .58348 Mdot
.45678 .00502 Mdot
.44866 .05179 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50712 .60842 Mdot
.52267 .58748 Mdot
.57212 .52288 Mdot
.72607 .377 Mdot
.11606 .47532 Mdot
.34699 .5963 Mdot
.38215 .07781 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00314 Mdot
.4926 .01 Mdot
.47643 .03177 Mdot
.42502 .09873 Mdot
.26527 .2456 Mdot
.86788 .13671 Mdot
.64668 .01918 Mdot
.61565 .53919 Mdot
.74323 .39177 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49705 .00398 Mdot
.49061 .01268 Mdot
.4701 .04023 Mdot
.405 .12317 Mdot
.20571 .26504 Mdot
.77688 .11959 Mdot
.58338 .04578 Mdot
.5093 .03716 Mdot
.44918 .08348 Mdot
.49961 .00053 Mdot
.49876 .00167 Mdot
.49605 .00533 Mdot
.48743 .01697 Mdot
.45996 .0537 Mdot
.37307 .15929 Mdot
.11534 .2571 Mdot
.69935 .11696 Mdot
.5101 .1076 Mdot
.336 .23412 Mdot
.95718 .1949 Mdot
.64182 .08015 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50096 .61673 Mdot
.50307 .61388 Mdot
.50979 .60482 Mdot
.53117 .5761 Mdot
.59903 .49011 Mdot
.80602 .35161 Mdot
.23711 .49867 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51013 .60435 Mdot
.53227 .57464 Mdot
.60248 .48607 Mdot
.81599 .35103 Mdot
.24801 .49856 Mdot
.44132 .55174 Mdot
.54859 .50739 Mdot
.72761 .36131 Mdot
.14301 .47675 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49236 .01032 Mdot
.47566 .0328 Mdot
.42259 .10177 Mdot
.25792 .24913 Mdot
.85481 .13244 Mdot
.64051 .01845 Mdot
.61066 .54197 Mdot
.73373 .3952 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00805 Mdot
.48102 .0256 Mdot
.4396 .08026 Mdot
.30974 .21753 Mdot
.95776 .17883 Mdot
.6684 .05026 Mdot
.58708 .59153 Mdot
.62996 .484 Mdot
.84683 .36293 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00406 Mdot
.49043 .01293 Mdot
.46951 .04102 Mdot
.40314 .12537 Mdot
.20028 .26578 Mdot
.77024 .11942 Mdot
.57701 .05079 Mdot
.49484 .05557 Mdot
.40492 .13857 Mdot
.1807 .27235 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60225 Mdot
.53723 .56806 Mdot
.61809 .46835 Mdot
.86029 .35483 Mdot
.28615 .49859 Mdot
.47942 .51762 Mdot
.6419 .40282 Mdot
.99012 .39367 Mdot
.35316 .51129 Mdot
.50093 .61677 Mdot
.50297 .61402 Mdot
.50946 .60526 Mdot
.53014 .57749 Mdot
.59574 .49399 Mdot
.79646 .35268 Mdot
.2258 .49853 Mdot
.41917 .57028 Mdot
.49645 .57357 Mdot
.5684 .51209 Mdot
.73981 .36485 Mdot
.50092 .61679 Mdot
.50294 .61406 Mdot
.50937 .60538 Mdot
.52984 .57788 Mdot
.59482 .49508 Mdot
.79376 .35308 Mdot
.22247 .49842 Mdot
.416 .57273 Mdot
.48931 .58263 Mdot
.5466 .54004 Mdot
.67279 .40952 Mdot
.50059 .61724 Mdot
.50186 .61551 Mdot
.50594 .61001 Mdot
.51893 .59251 Mdot
.56023 .53799 Mdot
.68974 .40089 Mdot
.04108 .43856 Mdot
.33148 .56719 Mdot
.41375 .02525 Mdot
.37289 .13096 Mdot
.16099 .25603 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.5071 .60844 Mdot
.52262 .58754 Mdot
.57195 .52309 Mdot
.72558 .37728 Mdot
.11513 .47494 Mdot
.34666 .5961 Mdot
.38215 .07761 Mdot
.25657 .22503 Mdot
.89247 .13276 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50994 .60461 Mdot
.53166 .57545 Mdot
.60057 .4883 Mdot
.81048 .35128 Mdot
.2421 .49864 Mdot
.43528 .55701 Mdot
.53402 .52571 Mdot
.68341 .39089 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51042 .60396 Mdot
.53319 .57341 Mdot
.6054 .48269 Mdot
.82439 .35097 Mdot
.25651 .49839 Mdot
.4501 .5439 Mdot
.57006 .48103 Mdot
.79173 .33853 Mdot
.24398 .48597 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49852 .00201 Mdot
.49527 .00639 Mdot
.48493 .02034 Mdot
.45202 .06415 Mdot
.34823 .18447 Mdot
.04976 .22985 Mdot
.67786 .0972 Mdot
.52058 .07818 Mdot
.39407 .16929 Mdot
.12016 .2704 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51228 .60145 Mdot
.53911 .56556 Mdot
.62402 .46187 Mdot
.87669 .35866 Mdot
.29637 .49998 Mdot
.48738 .51168 Mdot
.65947 .38736 Mdot
.0327 .41747 Mdot
.35723 .53277 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00314 Mdot
.49258 .01002 Mdot
.47638 .03183 Mdot
.42487 .09893 Mdot
.2648 .24584 Mdot
.86703 .13641 Mdot
.64631 .01909 Mdot
.61542 .53926 Mdot
.50093 .61678 Mdot
.50297 .61402 Mdot
.50946 .60526 Mdot
.53012 .57751 Mdot
.59569 .49405 Mdot
.7963 .3527 Mdot
.22561 .49852 Mdot
.41899 .57042 Mdot
.49603 .57411 Mdot
.5671 .51373 Mdot
.73588 .36676 Mdot
.50098 .6167 Mdot
.50314 .6138 Mdot
.50999 .60454 Mdot
.53182 .57523 Mdot
.60108 .4877 Mdot
.81196 .3512 Mdot
.24371 .49863 Mdot
.43691 .55559 Mdot
.53795 .52075 Mdot
.69536 .38181 Mdot
.07757 .45091 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49374 .00846 Mdot
.48006 .02689 Mdot
.43654 .08417 Mdot
.30035 .2244 Mdot
.93727 .16773 Mdot
.66587 .04033 Mdot
.60061 .57118 Mdot
.67642 .43912 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00328 Mdot
.49226 .01046 Mdot
.47533 .03324 Mdot
.42156 .10305 Mdot
.25482 .25053 Mdot
.84946 .13086 Mdot
.63771 .01854 Mdot
.60771 .54418 Mdot
.72721 .39814 Mdot
.08301 .47165 Mdot
.49979 .00028 Mdot
.49933 .00091 Mdot
.49786 .00288 Mdot
.4932 .00919 Mdot
.47833 .02922 Mdot
.43105 .09116 Mdot
.28355 .23544 Mdot
.90261 .15068 Mdot
.6588 .0267 Mdot
.6156 .54675 Mdot
.73094 .40026 Mdot
.08331 .47401 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49584 .00562 Mdot
.48674 .01791 Mdot
.45776 .05661 Mdot
.36617 .16656 Mdot
.09667 .25077 Mdot
.69092 .11327 Mdot
.50764 .1062 Mdot
.3358 .23282 Mdot
.9591 .19531 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.4869 .01768 Mdot
.4583 .0559 Mdot
.36785 .16481 Mdot
.10119 .25242 Mdot
.69276 .11431 Mdot
.5078 .10709 Mdot
.33452 .23431 Mdot
.9554 .1935 Mdot
.6423 .07847 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50866 .60634 Mdot
.52757 .58091 Mdot
.58765 .5037 Mdot
.77265 .35764 Mdot
.19397 .49614 Mdot
.3912 .58933 Mdot
.43764 .02764 Mdot
.39292 .11958 Mdot
.19943 .25974 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01038 Mdot
.47552 .03298 Mdot
.42215 .10231 Mdot
.25662 .24972 Mdot
.85256 .13177 Mdot
.63936 .01846 Mdot
.60948 .54282 Mdot
.73118 .3963 Mdot
.08995 .47532 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.5092 .60561 Mdot
.52929 .57861 Mdot
.59308 .49716 Mdot
.78865 .35395 Mdot
.21595 .49813 Mdot
.40996 .57722 Mdot
.47601 .59937 Mdot
.5062 .59363 Mdot
.54569 .55186 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00414 Mdot
.49023 .0132 Mdot
.46887 .04187 Mdot
.40112 .12776 Mdot
.19441 .26639 Mdot
.76338 .11937 Mdot
.57024 .05634 Mdot
.47907 .07569 Mdot
.35661 .19135 Mdot
.047 .23429 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49236 .01032 Mdot
.47565 .03281 Mdot
.42256 .1018 Mdot
.25785 .24916 Mdot
.85469 .13241 Mdot
.64045 .01845 Mdot
.6106 .54201 Mdot
.7336 .39525 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .6022 Mdot
.53735 .56789 Mdot
.61847 .46793 Mdot
.86135 .35505 Mdot
.28688 .49865 Mdot
.48005 .5171 Mdot
.64337 .40145 Mdot
.99381 .39571 Mdot
.35354 .51312 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50531 .61086 Mdot
.51693 .59519 Mdot
.55389 .54618 Mdot
.67016 .41681 Mdot
.99574 .41286 Mdot
.32771 .54317 Mdot
.44885 .58977 Mdot
.49458 .5948 Mdot
.53217 .56519 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49749 .0034 Mdot
.49199 .01082 Mdot
.47449 .03436 Mdot
.41889 .10634 Mdot
.24682 .25386 Mdot
.83607 .12737 Mdot
.62998 .01982 Mdot
.59791 .55271 Mdot
.70361 .41139 Mdot
.03796 .44625 Mdot
.50016 .61782 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61117 Mdot
.51618 .5962 Mdot
.55151 .54927 Mdot
.66277 .42334 Mdot
.97779 .40282 Mdot
.32602 .53385 Mdot
.46223 .56854 Mdot
.54232 .52977 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .00471 Mdot
.4889 .01498 Mdot
.46466 .04748 Mdot
.38784 .14306 Mdot
.15637 .2658 Mdot
.7263 .11989 Mdot
.53232 .09013 Mdot
.38648 .18667 Mdot
.08445 .26133 Mdot
.6616 .13597 Mdot
.50126 .61633 Mdot
.50403 .61259 Mdot
.51283 .60072 Mdot
.54085 .56326 Mdot
.62947 .45605 Mdot
.89157 .36312 Mdot
.30403 .50225 Mdot
.49137 .51025 Mdot
.66577 .38289 Mdot
.04624 .42516 Mdot
.35832 .53982 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00224 Mdot
.49473 .00712 Mdot
.48321 .02266 Mdot
.44655 .07128 Mdot
.33121 .20004 Mdot
.00754 .20702 Mdot
.67257 .0766 Mdot
.54863 .03222 Mdot
.49649 .03547 Mdot
.50118 .61645 Mdot
.50374 .61298 Mdot
.51193 .60193 Mdot
.53799 .56705 Mdot
.62048 .46572 Mdot
.86694 .35624 Mdot
.29053 .49903 Mdot
.48309 .51467 Mdot
.65033 .39513 Mdot
.01101 .40532 Mdot
.35518 .5218 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01089 Mdot
.47431 .0346 Mdot
.41832 .10704 Mdot
.24512 .25452 Mdot
.8333 .12673 Mdot
.62825 .02029 Mdot
.59543 .55506 Mdot
.69733 .41552 Mdot
.02501 .43861 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.5041 .61249 Mdot
.51307 .60038 Mdot
.54163 .56223 Mdot
.63192 .45346 Mdot
.8982 .3654 Mdot
.30698 .50359 Mdot
.49216 .51085 Mdot
.66559 .38358 Mdot
.04494 .42469 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49511 .00661 Mdot
.48442 .02102 Mdot
.45041 .06626 Mdot
.34319 .18922 Mdot
.03702 .22324 Mdot
.67582 .09143 Mdot
.52788 .06572 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00107 Mdot
.49747 .00342 Mdot
.49192 .01091 Mdot
.47427 .03465 Mdot
.4182 .10719 Mdot
.24476 .25466 Mdot
.83272 .1266 Mdot
.62788 .02039 Mdot
.59489 .55558 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00172 Mdot
.49593 .00549 Mdot
.48705 .01749 Mdot
.45875 .0553 Mdot
.36927 .16332 Mdot
.10502 .25376 Mdot
.69442 .11512 Mdot
.50815 .10757 Mdot
.3341 .23499 Mdot
.95387 .19283 Mdot
.50075 .61703 Mdot
.50237 .61483 Mdot
.50757 .60781 Mdot
.5241 .58556 Mdot
.57665 .51722 Mdot
.73977 .36998 Mdot
.14114 .48433 Mdot
.35747 .5995 Mdot
.38747 .07731 Mdot
.26239 .2244 Mdot
.89929 .13715 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01616 Mdot
.46188 .05117 Mdot
.37908 .15279 Mdot
.13187 .26152 Mdot
.70872 .11891 Mdot
.51631 .10381 Mdot
.34834 .22408 Mdot
.98577 .21091 Mdot
.64452 .0946 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47927 .02795 Mdot
.43405 .08735 Mdot
.29271 .22961 Mdot
.92119 .1595 Mdot
.66311 .03341 Mdot
.60906 .55807 Mdot
.70608 .4161 Mdot
.03281 .44631 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48928 .01447 Mdot
.46587 .04587 Mdot
.39165 .13874 Mdot
.16716 .26675 Mdot
.73556 .11981 Mdot
.54171 .08159 Mdot
.4097 .16088 Mdot
.14939 .27991 Mdot
.69648 .14063 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49827 .00233 Mdot
.4945 .00743 Mdot
.48249 .02363 Mdot
.44426 .07426 Mdot
.32411 .20609 Mdot
.99064 .19742 Mdot
.67121 .06759 Mdot
.56184 .01169 Mdot
.54292 .59042 Mdot
.49962 .00052 Mdot
.49879 .00164 Mdot
.49613 .00523 Mdot
.48767 .01665 Mdot
.46074 .05268 Mdot
.37551 .15667 Mdot
.122 .25902 Mdot
.7029 .11789 Mdot
.51215 .10664 Mdot
.33961 .23141 Mdot
.96518 .19938 Mdot
.64257 .0842 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00072 Mdot
.49829 .00231 Mdot
.49456 .00735 Mdot
.48266 .0234 Mdot
.44479 .07356 Mdot
.32577 .2047 Mdot
.99457 .19966 Mdot
.67151 .0697 Mdot
.55873 .01648 Mdot
.53207 .60498 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51042 .60396 Mdot
.53319 .57341 Mdot
.60539 .48269 Mdot
.82438 .35097 Mdot
.2565 .49839 Mdot
.45008 .54391 Mdot
.57002 .48107 Mdot
.79162 .33855 Mdot
.24384 .48598 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50253 .61461 Mdot
.50807 .60713 Mdot
.52571 .5834 Mdot
.58174 .51091 Mdot
.75507 .36344 Mdot
.167 .49138 Mdot
.37194 .59769 Mdot
.40485 .06271 Mdot
.30339 .20203 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.5109 .60332 Mdot
.53471 .5714 Mdot
.61017 .47722 Mdot
.83801 .35167 Mdot
.269 .49816 Mdot
.46295 .5322 Mdot
.60184 .4441 Mdot
.88327 .34533 Mdot
.32451 .477 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.49599 .00541 Mdot
.48724 .01723 Mdot
.45936 .0545 Mdot
.37117 .16131 Mdot
.11016 .25547 Mdot
.69679 .1161 Mdot
.50894 .10782 Mdot
.33449 .23506 Mdot
.95416 .19314 Mdot
.64164 .07849 Mdot
.5012 .61642 Mdot
.50381 .61288 Mdot
.51215 .60163 Mdot
.53869 .56612 Mdot
.62269 .46331 Mdot
.87303 .3577 Mdot
.29426 .49958 Mdot
.48592 .51261 Mdot
.6565 .3898 Mdot
.02579 .4136 Mdot
.35656 .52929 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51067 .60362 Mdot
.53399 .57235 Mdot
.60792 .4798 Mdot
.83159 .35122 Mdot
.26331 .49825 Mdot
.45713 .53751 Mdot
.58741 .46049 Mdot
.84233 .33708 Mdot
.29692 .47826 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50545 .61067 Mdot
.51737 .5946 Mdot
.55529 .54437 Mdot
.67448 .41313 Mdot
.00603 .41871 Mdot
.32854 .54865 Mdot
.4408 .60228 Mdot
.46628 .01527 Mdot
.44157 .06823 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49083 .01239 Mdot
.47078 .03932 Mdot
.40716 .12059 Mdot
.21204 .26396 Mdot
.78494 .11996 Mdot
.59085 .04024 Mdot
.52574 .01647 Mdot
.50096 .61673 Mdot
.50307 .61388 Mdot
.50979 .60481 Mdot
.53118 .57609 Mdot
.59906 .49007 Mdot
.80611 .3516 Mdot
.23721 .49867 Mdot
.43034 .5612 Mdot
.5223 .54059 Mdot
.64761 .42254 Mdot
.96392 .38938 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.5113 .60278 Mdot
.53599 .5697 Mdot
.6142 .47269 Mdot
.84937 .35298 Mdot
.27824 .49821 Mdot
.47213 .52392 Mdot
.62441 .41997 Mdot
.94488 .36989 Mdot
.34639 .49119 Mdot
.4998 .00027 Mdot
.49937 .00084 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47978 .02727 Mdot
.43565 .08532 Mdot
.2976 .22631 Mdot
.93142 .16468 Mdot
.66495 .03771 Mdot
.60394 .56609 Mdot
.68799 .4296 Mdot
.99289 .42301 Mdot
.50006 .61795 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50198 .61535 Mdot
.50632 .6095 Mdot
.52013 .59089 Mdot
.56406 .53309 Mdot
.7015 .39235 Mdot
.06666 .45236 Mdot
.33474 .57948 Mdot
.39712 .05032 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.5044 .61209 Mdot
.51402 .59911 Mdot
.54465 .55826 Mdot
.64136 .44377 Mdot
.92332 .37541 Mdot
.3159 .51048 Mdot
.48992 .51982 Mdot
.64883 .40109 Mdot
.99985 .40096 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49374 .00845 Mdot
.48006 .02689 Mdot
.43656 .08415 Mdot
.3004 .22436 Mdot
.93738 .1678 Mdot
.66588 .04038 Mdot
.60054 .57128 Mdot
.67619 .43932 Mdot
.96535 .40745 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50759 .60778 Mdot
.52417 .58546 Mdot
.57687 .51694 Mdot
.74045 .36966 Mdot
.14233 .48471 Mdot
.35805 .59953 Mdot
.38799 .07698 Mdot
.26344 .224 Mdot
.901 .13803 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .0051 Mdot
.48796 .01625 Mdot
.46167 .05144 Mdot
.37844 .1535 Mdot
.13007 .2611 Mdot
.70761 .11876 Mdot
.51546 .10445 Mdot
.34645 .22572 Mdot
.98123 .20836 Mdot
.6441 .09229 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49843 .00212 Mdot
.49501 .00674 Mdot
.48411 .02144 Mdot
.44941 .06756 Mdot
.3401 .19208 Mdot
.02931 .2191 Mdot
.6748 .08772 Mdot
.53286 .05747 Mdot
.43987 .11189 Mdot
.25883 .25921 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00506 Mdot
.48806 .01612 Mdot
.46199 .05102 Mdot
.37944 .1524 Mdot
.13285 .26175 Mdot
.70933 .11899 Mdot
.5168 .10345 Mdot
.5006 .61722 Mdot
.50192 .61545 Mdot
.5061 .60979 Mdot
.51945 .5918 Mdot
.56189 .53586 Mdot
.69485 .39708 Mdot
.05236 .44475 Mdot
.33273 .5728 Mdot
.40592 .037 Mdot
.34605 .15848 Mdot
.08962 .23724 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50792 .60733 Mdot
.52524 .58403 Mdot
.58026 .51273 Mdot
.75064 .36519 Mdot
.15975 .48964 Mdot
.36749 .59878 Mdot
.39865 .06847 Mdot
.28786 .21186 Mdot
.94506 .16194 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00328 Mdot
.49228 .01043 Mdot
.47539 .03316 Mdot
.42174 .10282 Mdot
.25538 .25028 Mdot
.85043 .13114 Mdot
.63823 .01851 Mdot
.60828 .54373 Mdot
.72851 .39752 Mdot
.0853 .47287 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01633 Mdot
.46147 .0517 Mdot
.37782 .15417 Mdot
.12837 .26068 Mdot
.70657 .1186 Mdot
.51468 .105 Mdot
.34478 .22715 Mdot
.97724 .20613 Mdot
.64373 .09027 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51587 .59662 Mdot
.55051 .55058 Mdot
.65965 .42618 Mdot
.97008 .39861 Mdot
.32513 .53002 Mdot
.46754 .5599 Mdot
.56161 .5042 Mdot
.7458 .35671 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48782 .01644 Mdot
.46123 .05203 Mdot
.37704 .15501 Mdot
.12622 .26014 Mdot
.7053 .11838 Mdot
.51376 .10563 Mdot
.34285 .22878 Mdot
.97268 .20357 Mdot
.49985 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49531 .00634 Mdot
.48505 .02018 Mdot
.4524 .06365 Mdot
.34941 .18334 Mdot
.05277 .23136 Mdot
.67841 .09849 Mdot
.51905 .08088 Mdot
.38818 .17622 Mdot
.10306 .26522 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48805 .01613 Mdot
.46196 .05106 Mdot
.37934 .15251 Mdot
.13258 .26168 Mdot
.70916 .11897 Mdot
.51667 .10355 Mdot
.34912 .22339 Mdot
.50074 .61703 Mdot
.50237 .61484 Mdot
.50754 .60785 Mdot
.52401 .58568 Mdot
.57635 .51759 Mdot
.73887 .3704 Mdot
.13954 .48382 Mdot
.35671 .59943 Mdot
.38681 .0777 Mdot
.26109 .22489 Mdot
.89722 .13609 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00191 Mdot
.49549 .0061 Mdot
.48563 .0194 Mdot
.45423 .06125 Mdot
.35512 .17777 Mdot
.06748 .23847 Mdot
.68163 .10433 Mdot
.51281 .09247 Mdot
.3632 .20424 Mdot
.03273 .23437 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.48921 .01457 Mdot
.46563 .04619 Mdot
.3909 .13959 Mdot
.16504 .26661 Mdot
.73366 .11984 Mdot
.53975 .08337 Mdot
.40487 .1664 Mdot
.13562 .27746 Mdot
.50016 .61782 Mdot
.5005 .61735 Mdot
.5016 .61587 Mdot
.50511 .61113 Mdot
.51628 .59606 Mdot
.55184 .54884 Mdot
.66379 .42242 Mdot
.98031 .40421 Mdot
.32628 .53513 Mdot
.46043 .57143 Mdot
.53583 .5385 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04863 Mdot
.3851 .14614 Mdot
.14864 .26476 Mdot
.72025 .11979 Mdot
.52644 .09539 Mdot
.37209 .20161 Mdot
.04588 .24356 Mdot
.6518 .12322 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50985 .60474 Mdot
.53136 .57585 Mdot
.59961 .48942 Mdot
.80771 .35147 Mdot
.23902 .49866 Mdot
.43216 .55967 Mdot
.52661 .53511 Mdot
.66077 .41016 Mdot
.99713 .40749 Mdot
.50003 .618 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50894 .60596 Mdot
.52848 .57969 Mdot
.59052 .50022 Mdot
.78115 .35549 Mdot
.20595 .49742 Mdot
.4011 .58332 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50376 .61296 Mdot
.51198 .60186 Mdot
.53814 .56685 Mdot
.62096 .4652 Mdot
.86826 .35654 Mdot
.29136 .49913 Mdot
.48375 .51417 Mdot
.6518 .39383 Mdot
.01456 .40732 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60665 Mdot
.52686 .58186 Mdot
.58539 .50645 Mdot
.76593 .35964 Mdot
.18402 .49469 Mdot
.38359 .59324 Mdot
.42372 .04324 Mdot
.35375 .16053 Mdot
.094 .2427 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .00179 Mdot
.49577 .00572 Mdot
.48652 .0182 Mdot
.45708 .05751 Mdot
.36403 .16878 Mdot
.09094 .24857 Mdot
.68875 .11182 Mdot
.50782 .10457 Mdot
.33861 .22983 Mdot
.96674 .19922 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50933 .60543 Mdot
.52972 .57804 Mdot
.59442 .49555 Mdot
.7926 .35326 Mdot
.22101 .49837 Mdot
.41463 .57377 Mdot
.48626 .58649 Mdot
.53729 .55223 Mdot
.64376 .43635 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00464 Mdot
.48905 .01479 Mdot
.46512 .04687 Mdot
.38928 .14144 Mdot
.16043 .26622 Mdot
.72967 .11988 Mdot
.5357 .08707 Mdot
.39482 .17763 Mdot
.1074 .26981 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00535 Mdot
.48739 .01702 Mdot
.45985 .05386 Mdot
.3727 .15968 Mdot
.11434 .25679 Mdot
.69884 .1168 Mdot
.50985 .10768 Mdot
.33562 .23438 Mdot
.95638 .19445 Mdot
.64175 .07973 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .0024 Mdot
.49435 .00763 Mdot
.482 .02428 Mdot
.44272 .07624 Mdot
.31936 .21 Mdot
.97957 .19111 Mdot
.67035 .06166 Mdot
.57057 .6164 Mdot
.57322 .55089 Mdot
.68186 .41666 Mdot
.50009 .61792 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50876 .6062 Mdot
.52791 .58045 Mdot
.58872 .5024 Mdot
.77582 .35679 Mdot
.19852 .49669 Mdot
.39487 .58721 Mdot
.44473 .01939 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51039 .60401 Mdot
.53308 .57357 Mdot
.60503 .48311 Mdot
.82334 .35096 Mdot
.25548 .49841 Mdot
.44903 .54486 Mdot
.56742 .48422 Mdot
.78394 .34001 Mdot
.23378 .48679 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00223 Mdot
.49474 .00711 Mdot
.48324 .02261 Mdot
.44665 .07115 Mdot
.33152 .19976 Mdot
.00831 .20746 Mdot
.67263 .077 Mdot
.54804 .03314 Mdot
.49442 .03832 Mdot
.43242 .0991 Mdot
.5 0 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01653 Mdot
.46101 .05231 Mdot
.37637 .15574 Mdot
.12437 .25966 Mdot
.70423 .11817 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49513 .00657 Mdot
.4845 .02092 Mdot
.45064 .06595 Mdot
.34394 .18853 Mdot
.03889 .22423 Mdot
.67609 .09231 Mdot
.52673 .06765 Mdot
.41727 .14094 Mdot
.18923 .27786 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50903 .60584 Mdot
.52876 .57932 Mdot
.5914 .49917 Mdot
.78372 .35493 Mdot
.20944 .49771 Mdot
.40413 .5813 Mdot
.46357 .61478 Mdot
.46882 .02547 Mdot
.42761 .09029 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50321 .61369 Mdot
.51024 .60421 Mdot
.53261 .57418 Mdot
.60357 .4848 Mdot
.81914 .35096 Mdot
.25127 .4985 Mdot
.44467 .54877 Mdot
.55674 .49727 Mdot
.75214 .34974 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00414 Mdot
.49025 .01317 Mdot
.46894 .04178 Mdot
.40134 .1275 Mdot
.19504 .26633 Mdot
.7641 .11937 Mdot
.57096 .05574 Mdot
.48077 .07352 Mdot
.36181 .18613 Mdot
.06065 .241 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51328 .60011 Mdot
.54229 .56136 Mdot
.63399 .45131 Mdot
.90375 .36742 Mdot
.30925 .50486 Mdot
.49237 .51194 Mdot
.66404 .3854 Mdot
.04045 .42249 Mdot
.35684 .53802 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48965 .01398 Mdot
.46704 .04432 Mdot
.39533 .1345 Mdot
.1777 .26708 Mdot
.74555 .1196 Mdot
.55204 .07221 Mdot
.43519 .13065 Mdot
.2238 .2762 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50913 .6057 Mdot
.52909 .57888 Mdot
.59243 .49793 Mdot
.78677 .3543 Mdot
.21349 .49798 Mdot
.40773 .57881 Mdot
.4712 .60536 Mdot
.49171 .61304 Mdot
.49979 .61324 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60694 Mdot
.52617 .58279 Mdot
.58319 .50913 Mdot
.75941 .36184 Mdot
.17393 .49285 Mdot
.37648 .59621 Mdot
.41179 .05582 Mdot
.32147 .18874 Mdot
.01608 .20362 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50321 .61369 Mdot
.51024 .60421 Mdot
.53261 .57419 Mdot
.60356 .48482 Mdot
.81911 .35096 Mdot
.25123 .4985 Mdot
.44464 .5488 Mdot
.55666 .49737 Mdot
.7519 .34984 Mdot
.50085 .61689 Mdot
.5027 .61439 Mdot
.5086 .60642 Mdot
.5274 .58114 Mdot
.58709 .50437 Mdot
.771 .35811 Mdot
.19157 .49582 Mdot
.38931 .59036 Mdot
.43409 .0317 Mdot
.3828 .13079 Mdot
.17117 .26061 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50705 .60851 Mdot
.52245 .58777 Mdot
.57142 .52375 Mdot
.72397 .37818 Mdot
.11207 .4737 Mdot
.34561 .59541 Mdot
.38222 .07686 Mdot
.25786 .22423 Mdot
.89505 .13383 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60207 Mdot
.53765 .56749 Mdot
.61943 .46687 Mdot
.86402 .3556 Mdot
.28865 .49881 Mdot
.48155 .51588 Mdot
.64685 .39825 Mdot
.00247 .40054 Mdot
.35438 .51747 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .0142 Mdot
.4665 .04503 Mdot
.39365 .13644 Mdot
.17288 .267 Mdot
.74086 .1197 Mdot
.54718 .0766 Mdot
.42323 .14504 Mdot
.18855 .28172 Mdot
.73271 .13505 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01163 Mdot
.47257 .03693 Mdot
.41281 .11378 Mdot
.22871 .26001 Mdot
.80801 .12215 Mdot
.61036 .02785 Mdot
.56529 .58704 Mdot
.61545 .48916 Mdot
.82398 .35726 Mdot
.50119 .61643 Mdot
.50379 .61292 Mdot
.51207 .60174 Mdot
.53844 .56645 Mdot
.6219 .46417 Mdot
.87087 .35716 Mdot
.29296 .49936 Mdot
.48498 .51327 Mdot
.65448 .39151 Mdot
.021 .41093 Mdot
.35611 .52688 Mdot
.50026 .61769 Mdot
.50082 .61693 Mdot
.5026 .61452 Mdot
.50828 .60685 Mdot
.52639 .5825 Mdot
.58388 .50828 Mdot
.76146 .36112 Mdot
.17716 .49348 Mdot
.37869 .59536 Mdot
.41537 .05214 Mdot
.331 .18098 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00271 Mdot
.49361 .00864 Mdot
.47963 .02746 Mdot
.4352 .08589 Mdot
.29622 .22726 Mdot
.9285 .16319 Mdot
.66446 .03644 Mdot
.6055 .56368 Mdot
.69344 .42535 Mdot
.00521 .43018 Mdot
.50082 .61693 Mdot
.5026 .61452 Mdot
.50828 .60685 Mdot
.52638 .58251 Mdot
.58386 .50831 Mdot
.76139 .36115 Mdot
.17704 .49346 Mdot
.37861 .5954 Mdot
.41524 .05228 Mdot
.33064 .18129 Mdot
.03731 .21556 Mdot
.50111 .61654 Mdot
.50352 .61327 Mdot
.51123 .60288 Mdot
.53575 .57001 Mdot
.61346 .47352 Mdot
.84729 .35269 Mdot
.27662 .49818 Mdot
.47056 .52531 Mdot
.62058 .42392 Mdot
.93467 .36504 Mdot
.34402 .48758 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .00221 Mdot
.49479 .00703 Mdot
.48342 .02238 Mdot
.44721 .07043 Mdot
.33325 .19825 Mdot
.01248 .2098 Mdot
.67301 .07919 Mdot
.54488 .03813 Mdot
.48318 .0537 Mdot
.3963 .14317 Mdot
.50061 .61721 Mdot
.50195 .61541 Mdot
.5062 .60966 Mdot
.51975 .5914 Mdot
.56284 .53465 Mdot
.69775 .39499 Mdot
.05865 .44813 Mdot
.33355 .57581 Mdot
.40187 .04309 Mdot
.33214 .17142 Mdot
.05477 .2212 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51135 .60271 Mdot
.53614 .56949 Mdot
.61469 .47213 Mdot
.85077 .35319 Mdot
.27931 .49824 Mdot
.47315 .52301 Mdot
.62689 .41745 Mdot
.95144 .37313 Mdot
.3477 .49373 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60499 Mdot
.53077 .57664 Mdot
.59775 .49161 Mdot
.8023 .35196 Mdot
.23282 .49865 Mdot
.42599 .56482 Mdot
.51209 .55362 Mdot
.61632 .45513 Mdot
.50082 .61692 Mdot
.50263 .61449 Mdot
.50837 .60673 Mdot
.52665 .58214 Mdot
.58473 .50724 Mdot
.76399 .36027 Mdot
.18107 .49419 Mdot
.38145 .59421 Mdot
.42 .04725 Mdot
.34354 .17004 Mdot
.06841 .23153 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49238 .01029 Mdot
.47574 .03269 Mdot
.42285 .10144 Mdot
.25872 .24876 Mdot
.85621 .13287 Mdot
.64122 .01847 Mdot
.61134 .5415 Mdot
.73517 .3946 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48887 .01503 Mdot
.46454 .04764 Mdot
.38746 .14348 Mdot
.1553 .26567 Mdot
.72544 .11988 Mdot
.53146 .0909 Mdot
.38438 .18891 Mdot
.07872 .25895 Mdot
.65974 .1345 Mdot
.50131 .61627 Mdot
.50417 .61241 Mdot
.51327 .60012 Mdot
.54226 .5614 Mdot
.6339 .4514 Mdot
.90353 .36734 Mdot
.30916 .50481 Mdot
.49237 .51188 Mdot
.66412 .3853 Mdot
.04069 .42261 Mdot
.35689 .53812 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61173 Mdot
.51486 .59797 Mdot
.54732 .55475 Mdot
.64971 .43554 Mdot
.94499 .38555 Mdot
.32115 .5186 Mdot
.48204 .53521 Mdot
.61604 .43692 Mdot
.90909 .35715 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .00299 Mdot
.49294 .00954 Mdot
.4775 .03033 Mdot
.42843 .09446 Mdot
.27558 .24011 Mdot
.88708 .14399 Mdot
.6541 .02243 Mdot
.61781 .54095 Mdot
.74254 .39357 Mdot
.50055 .61729 Mdot
.50175 .61567 Mdot
.50557 .61051 Mdot
.51774 .5941 Mdot
.55647 .54284 Mdot
.67813 .41009 Mdot
.01459 .4236 Mdot
.3292 .55325 Mdot
.43402 .61267 Mdot
.4427 .04662 Mdot
.36727 .15589 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49069 .01258 Mdot
.47033 .03992 Mdot
.40574 .12229 Mdot
.20787 .26469 Mdot
.77959 .11969 Mdot
.58592 .04385 Mdot
.51497 .03 Mdot
.46643 .06088 Mdot
.36792 .16975 Mdot
.50098 .61672 Mdot
.50311 .61383 Mdot
.5099 .60466 Mdot
.53155 .57561 Mdot
.6002 .48873 Mdot
.80941 .35135 Mdot
.24092 .49865 Mdot
.43408 .55803 Mdot
.53116 .52933 Mdot
.67469 .398 Mdot
.03072 .4263 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52556 .5836 Mdot
.58127 .51149 Mdot
.75366 .36399 Mdot
.16472 .49085 Mdot
.37051 .59809 Mdot
.40278 .06467 Mdot
.29814 .20552 Mdot
.9656 .17388 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51042 .60396 Mdot
.53319 .57341 Mdot
.60539 .4827 Mdot
.82436 .35097 Mdot
.25648 .49839 Mdot
.45007 .54393 Mdot
.56997 .48113 Mdot
.79149 .33857 Mdot
.24367 .486 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49074 .01251 Mdot
.47049 .03971 Mdot
.40623 .1217 Mdot
.20932 .26445 Mdot
.78143 .11977 Mdot
.58763 .04258 Mdot
.51874 .02524 Mdot
.4779 .04566 Mdot
.50114 .6165 Mdot
.50362 .61314 Mdot
.51153 .60246 Mdot
.53674 .5687 Mdot
.61656 .47005 Mdot
.85599 .35404 Mdot
.28315 .49839 Mdot
.47673 .51988 Mdot
.63554 .40888 Mdot
.97396 .38485 Mdot
.35127 .50352 Mdot
.5005 .61736 Mdot
.5016 .61588 Mdot
.50509 .61116 Mdot
.51621 .59616 Mdot
.55159 .54917 Mdot
.66302 .42311 Mdot
.97841 .40316 Mdot
.32608 .53417 Mdot
.46179 .56925 Mdot
.54072 .53191 Mdot
.68007 .39838 Mdot
.50055 .61729 Mdot
.50175 .61567 Mdot
.50558 .6105 Mdot
.51777 .59406 Mdot
.55656 .54272 Mdot
.67843 .40984 Mdot
.0153 .424 Mdot
.32925 .55363 Mdot
.43347 .61352 Mdot
.44077 .04914 Mdot
.36125 .16208 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49848 .00206 Mdot
.49514 .00656 Mdot
.48453 .02088 Mdot
.45075 .0658 Mdot
.34428 .18821 Mdot
.03975 .22468 Mdot
.67621 .09271 Mdot
.52621 .06853 Mdot
.41533 .14337 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49548 .0061 Mdot
.4856 .01943 Mdot
.45416 .06134 Mdot
.35491 .17797 Mdot
.06694 .23822 Mdot
.68149 .10413 Mdot
.513 .09209 Mdot
.364 .20338 Mdot
.03492 .23549 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00267 Mdot
.49371 .0085 Mdot
.47996 .02703 Mdot
.43623 .08458 Mdot
.29937 .22508 Mdot
.93518 .16664 Mdot
.66555 .03938 Mdot
.60183 .56933 Mdot
.68064 .43557 Mdot
.50106 .6166 Mdot
.50337 .61347 Mdot
.51075 .60352 Mdot
.53424 .57201 Mdot
.6087 .4789 Mdot
.83383 .35135 Mdot
.26534 .49821 Mdot
.45921 .53561 Mdot
.59258 .45454 Mdot
.85712 .33917 Mdot
.30833 .47692 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61708 Mdot
.50224 .615 Mdot
.50715 .60837 Mdot
.52279 .58732 Mdot
.57248 .52243 Mdot
.72718 .3764 Mdot
.11816 .47614 Mdot
.34774 .59673 Mdot
.38221 .0782 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.49599 .00541 Mdot
.48723 .01724 Mdot
.45934 .05452 Mdot
.37113 .16135 Mdot
.11006 .25544 Mdot
.69675 .11608 Mdot
.50892 .10782 Mdot
.33447 .23506 Mdot
.95413 .19312 Mdot
.64165 .07847 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50528 .6109 Mdot
.51683 .59533 Mdot
.55356 .54661 Mdot
.66914 .4177 Mdot
.99329 .41148 Mdot
.3275 .54187 Mdot
.45074 .58681 Mdot
.50125 .58565 Mdot
.55364 .53686 Mdot
.50127 .61632 Mdot
.50404 .61258 Mdot
.51286 .60068 Mdot
.54094 .56314 Mdot
.62976 .45574 Mdot
.89235 .36338 Mdot
.30439 .5024 Mdot
.49149 .51028 Mdot
.66584 .38289 Mdot
.04632 .42522 Mdot
.35829 .53991 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51113 .60301 Mdot
.53544 .57043 Mdot
.61246 .47463 Mdot
.84449 .35234 Mdot
.2744 .49815 Mdot
.46837 .52728 Mdot
.61522 .42955 Mdot
.92019 .35862 Mdot
.33992 .48324 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01037 Mdot
.47553 .03297 Mdot
.42219 .10226 Mdot
.25674 .24967 Mdot
.85276 .13183 Mdot
.63946 .01846 Mdot
.60959 .54274 Mdot
.73142 .3962 Mdot
.09035 .47553 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00245 Mdot
.49422 .00781 Mdot
.48158 .02485 Mdot
.44137 .07799 Mdot
.31518 .21333 Mdot
.97001 .18569 Mdot
.66956 .0566 Mdot
.57798 .60519 Mdot
.59876 .5194 Mdot
.75835 .37206 Mdot
.50104 .61663 Mdot
.50331 .61357 Mdot
.51054 .60381 Mdot
.53356 .57293 Mdot
.60654 .48137 Mdot
.82767 .35105 Mdot
.25966 .49832 Mdot
.45336 .54094 Mdot
.5781 .47141 Mdot
.81534 .33613 Mdot
.27148 .48233 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.51131 .60276 Mdot
.53601 .56966 Mdot
.61428 .47259 Mdot
.84962 .35302 Mdot
.27843 .49821 Mdot
.47231 .52375 Mdot
.62485 .41952 Mdot
.94606 .37046 Mdot
.34663 .49164 Mdot
.50011 .61789 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50353 .61326 Mdot
.51126 .60283 Mdot
.53585 .56988 Mdot
.61377 .47316 Mdot
.84819 .35281 Mdot
.27732 .49819 Mdot
.47124 .52471 Mdot
.62225 .4222 Mdot
.50097 .61672 Mdot
.5031 .61384 Mdot
.50989 .60468 Mdot
.5315 .57567 Mdot
.60004 .48892 Mdot
.80895 .35138 Mdot
.2404 .49866 Mdot
.43356 .55848 Mdot
.52992 .5309 Mdot
.6709 .40121 Mdot
.02174 .4213 Mdot
.49974 .00035 Mdot
.49916 .00113 Mdot
.49734 .0036 Mdot
.49151 .01146 Mdot
.47297 .0364 Mdot
.41407 .11225 Mdot
.23244 .2589 Mdot
.81354 .12296 Mdot
.61459 .02567 Mdot
.57306 .57832 Mdot
.63731 .46625 Mdot
.88291 .36723 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50717 .60835 Mdot
.52284 .58725 Mdot
.57264 .52223 Mdot
.72765 .37614 Mdot
.11905 .47649 Mdot
.34807 .59691 Mdot
.38225 .07834 Mdot
.25549 .2258 Mdot
.89014 .13185 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51484 .598 Mdot
.54726 .55483 Mdot
.64953 .43572 Mdot
.94451 .38532 Mdot
.32105 .5184 Mdot
.48226 .53481 Mdot
.61692 .43591 Mdot
.91161 .35811 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00491 Mdot
.48841 .01565 Mdot
.46309 .04956 Mdot
.3829 .14859 Mdot
.14248 .26372 Mdot
.71577 .11958 Mdot
.52228 .09899 Mdot
.36212 .21141 Mdot
.02005 .22995 Mdot
.64799 .11169 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00231 Mdot
.49455 .00737 Mdot
.48263 .02344 Mdot
.4447 .07368 Mdot
.32548 .20494 Mdot
.99388 .19927 Mdot
.67146 .06933 Mdot
.55928 .01563 Mdot
.53398 .6024 Mdot
.55928 .54871 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01453 Mdot
.46572 .04607 Mdot
.39118 .13927 Mdot
.16584 .26666 Mdot
.73437 .11983 Mdot
.54049 .0827 Mdot
.40668 .16434 Mdot
.14078 .27848 Mdot
.50065 .61716 Mdot
.50206 .61524 Mdot
.50658 .60915 Mdot
.52095 .58978 Mdot
.56667 .52976 Mdot
.7095 .38697 Mdot
.08337 .46077 Mdot
.33783 .58641 Mdot
.38899 .06315 Mdot
.28681 .20677 Mdot
.95226 .16317 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48973 .01387 Mdot
.4673 .04397 Mdot
.39615 .13356 Mdot
.18005 .26708 Mdot
.74791 .11955 Mdot
.55448 .07002 Mdot
.44118 .12332 Mdot
.24164 .27066 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50242 .61476 Mdot
.50772 .60761 Mdot
.52459 .5849 Mdot
.5782 .51529 Mdot
.74445 .36783 Mdot
.14929 .48681 Mdot
.36162 .59953 Mdot
.39155 .07443 Mdot
.27112 .22068 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.5116 .60237 Mdot
.53694 .56843 Mdot
.6172 .46934 Mdot
.8578 .35436 Mdot
.28443 .49847 Mdot
.47789 .5189 Mdot
.6383 .40622 Mdot
.98102 .38867 Mdot
.35214 .50686 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49249 .01015 Mdot
.47607 .03225 Mdot
.42389 .10015 Mdot
.26183 .24729 Mdot
.86171 .13462 Mdot
.64389 .01867 Mdot
.61367 .54006 Mdot
.73983 .39282 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.51221 .60155 Mdot
.53887 .56588 Mdot
.62326 .46269 Mdot
.87461 .35811 Mdot
.29518 .49975 Mdot
.48657 .51218 Mdot
.65785 .38868 Mdot
.02895 .41537 Mdot
.35686 .53089 Mdot
.5005 .61735 Mdot
.50161 .61586 Mdot
.50513 .61111 Mdot
.51633 .596 Mdot
.55198 .54866 Mdot
.66423 .42203 Mdot
.98138 .4048 Mdot
.32639 .53567 Mdot
.45966 .57267 Mdot
.53305 .54226 Mdot
.65566 .41988 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00109 Mdot
.49744 .00346 Mdot
.49185 .01101 Mdot
.47403 .03498 Mdot
.41743 .10814 Mdot
.24245 .25552 Mdot
.82901 .12579 Mdot
.62548 .02114 Mdot
.59128 .55912 Mdot
.6866 .42313 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49696 .00411 Mdot
.4903 .0131 Mdot
.4691 .04157 Mdot
.40184 .12691 Mdot
.1965 .26619 Mdot
.76579 .11937 Mdot
.57263 .05435 Mdot
.48469 .06852 Mdot
.37382 .17362 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49347 .00882 Mdot
.4792 .02805 Mdot
.43381 .08766 Mdot
.29198 .2301 Mdot
.91968 .15875 Mdot
.66281 .0328 Mdot
.60973 .55698 Mdot
.70851 .41442 Mdot
.03796 .44928 Mdot
.50056 .61727 Mdot
.5018 .61561 Mdot
.50572 .6103 Mdot
.51823 .59344 Mdot
.55803 .54082 Mdot
.68296 .40618 Mdot
.02575 .42995 Mdot
.33009 .5592 Mdot
.42527 .00793 Mdot
.41245 .08506 Mdot
.27482 .23081 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00317 Mdot
.49251 .01011 Mdot
.47616 .03213 Mdot
.42416 .09981 Mdot
.26267 .24689 Mdot
.8632 .13511 Mdot
.64458 .01877 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49118 .01191 Mdot
.47191 .03782 Mdot
.41072 .11631 Mdot
.22253 .26166 Mdot
.79915 .1211 Mdot
.60321 .03198 Mdot
.55147 .60313 Mdot
.57558 .53567 Mdot
.70886 .39302 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.51271 .60088 Mdot
.54046 .56377 Mdot
.62827 .45732 Mdot
.8883 .36207 Mdot
.30247 .50167 Mdot
.49075 .51023 Mdot
.66518 .38315 Mdot
.04523 .42452 Mdot
.35835 .53918 Mdot
.50085 .61688 Mdot
.50271 .61437 Mdot
.50864 .60636 Mdot
.52752 .58097 Mdot
.58749 .50389 Mdot
.77218 .35778 Mdot
.19328 .49605 Mdot
.39066 .58963 Mdot
.43662 .02882 Mdot
.38999 .12287 Mdot
.19118 .26045 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50191 .61545 Mdot
.5061 .60979 Mdot
.51943 .59183 Mdot
.56183 .53594 Mdot
.69467 .39722 Mdot
.05196 .44454 Mdot
.33269 .57261 Mdot
.40618 .03661 Mdot
.34695 .15762 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51124 .60286 Mdot
.53578 .56997 Mdot
.61356 .4734 Mdot
.84758 .35273 Mdot
.27685 .49818 Mdot
.47078 .52511 Mdot
.62113 .42335 Mdot
.93614 .36572 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48936 .01436 Mdot
.46613 .04553 Mdot
.39246 .13781 Mdot
.16948 .26687 Mdot
.73768 .11977 Mdot
.54389 .07959 Mdot
.41511 .15461 Mdot
.16493 .28158 Mdot
.70933 .13883 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60223 Mdot
.53727 .568 Mdot
.61823 .46819 Mdot
.86068 .35491 Mdot
.28642 .49861 Mdot
.47965 .51742 Mdot
.64245 .40231 Mdot
.9915 .39443 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.5082 .60696 Mdot
.52612 .58285 Mdot
.58305 .50931 Mdot
.75897 .362 Mdot
.17325 .49271 Mdot
.37602 .59638 Mdot
.41106 .05657 Mdot
.31953 .19026 Mdot
.01169 .20108 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .6014 Mdot
.53924 .56539 Mdot
.62442 .46144 Mdot
.8778 .35896 Mdot
.29699 .50012 Mdot
.48778 .51144 Mdot
.66026 .38673 Mdot
.03451 .41847 Mdot
.3574 .53368 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.4875 .01688 Mdot
.46019 .05339 Mdot
.3738 .15851 Mdot
.11733 .25769 Mdot
.70038 .11726 Mdot
.51065 .10739 Mdot
.33688 .23349 Mdot
.95908 .19598 Mdot
.64198 .08113 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.48621 .01861 Mdot
.45609 .0588 Mdot
.36095 .17192 Mdot
.08277 .24524 Mdot
.68596 .10949 Mdot
.50881 .10132 Mdot
.34486 .22343 Mdot
.98334 .20802 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49941 .0008 Mdot
.49812 .00253 Mdot
.49402 .00807 Mdot
.48096 .02568 Mdot
.4394 .08051 Mdot
.30913 .21799 Mdot
.9564 .17808 Mdot
.66826 .04957 Mdot
.58805 .59008 Mdot
.63329 .48046 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.49229 .01041 Mdot
.47544 .03309 Mdot
.4219 .10263 Mdot
.25584 .25007 Mdot
.85121 .13137 Mdot
.63865 .01849 Mdot
.60873 .54338 Mdot
.72953 .39705 Mdot
.08708 .47381 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61239 Mdot
.51331 .60007 Mdot
.54238 .56125 Mdot
.63426 .45102 Mdot
.90449 .3677 Mdot
.30954 .50504 Mdot
.49236 .51212 Mdot
.66374 .38572 Mdot
.03962 .42208 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60898 Mdot
.52135 .58924 Mdot
.56794 .52815 Mdot
.71338 .38449 Mdot
.09125 .46453 Mdot
.33963 .58929 Mdot
.38613 .06804 Mdot
.27603 .21362 Mdot
.93039 .15113 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47739 .03047 Mdot
.42809 .09489 Mdot
.27455 .24069 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.5081 .60709 Mdot
.52581 .58327 Mdot
.58206 .51052 Mdot
.75602 .36308 Mdot
.16854 .49172 Mdot
.37292 .5974 Mdot
.4063 .0613 Mdot
.30712 .19944 Mdot
.98442 .18502 Mdot
.50053 .61731 Mdot
.5017 .61573 Mdot
.50543 .61071 Mdot
.51728 .59471 Mdot
.55502 .54472 Mdot
.67364 .41383 Mdot
.00404 .41758 Mdot
.32838 .54759 Mdot
.44236 .59987 Mdot
.47175 .00789 Mdot
.45898 .0455 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01603 Mdot
.46218 .05077 Mdot
.38004 .15175 Mdot
.13451 .26212 Mdot
.71039 .11912 Mdot
.51766 .10278 Mdot
.35135 .22141 Mdot
.9931 .21502 Mdot
.6452 .09832 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48908 .01474 Mdot
.46523 .04672 Mdot
.38964 .14102 Mdot
.16146 .26632 Mdot
.73055 .11988 Mdot
.53658 .08626 Mdot
.39701 .17521 Mdot
.11352 .27175 Mdot
.67382 .14078 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.49769 .00312 Mdot
.49265 .00993 Mdot
.47658 .03156 Mdot
.42552 .09811 Mdot
.26677 .24484 Mdot
.87061 .13767 Mdot
.64785 .01949 Mdot
.61632 .53903 Mdot
.74415 .39159 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00645 Mdot
.48478 .02054 Mdot
.45155 .06477 Mdot
.34675 .18588 Mdot
.04598 .22792 Mdot
.6772 .09554 Mdot
.52261 .07466 Mdot
.40181 .16002 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .0056 Mdot
.48679 .01783 Mdot
.45795 .05636 Mdot
.36675 .16596 Mdot
.09823 .25135 Mdot
.69154 .11364 Mdot
.50766 .10655 Mdot
.33527 .23342 Mdot
.95759 .19456 Mdot
.50027 .61767 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50882 .60612 Mdot
.5281 .58021 Mdot
.58931 .50169 Mdot
.77756 .35635 Mdot
.20097 .49695 Mdot
.39689 .58599 Mdot
.44873 .01467 Mdot
.42499 .08166 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00294 Mdot
.49306 .00938 Mdot
.47788 .02982 Mdot
.42964 .09294 Mdot
.27926 .238 Mdot
.89418 .14696 Mdot
.65639 .02422 Mdot
.6172 .54315 Mdot
.73837 .396 Mdot
.09762 .48093 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49237 .01031 Mdot
.47568 .03277 Mdot
.42266 .10168 Mdot
.25814 .24903 Mdot
.8552 .13256 Mdot
.64071 .01846 Mdot
.61085 .54184 Mdot
.50007 .61795 Mdot
.50021 .61775 Mdot
.50067 .61713 Mdot
.50213 .61516 Mdot
.50678 .60887 Mdot
.52161 .5889 Mdot
.56875 .52713 Mdot
.71585 .38296 Mdot
.0962 .46681 Mdot
.34088 .59095 Mdot
.3847 .0707 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49605 .00534 Mdot
.4874 .01701 Mdot
.45988 .05381 Mdot
.37281 .15957 Mdot
.11461 .25688 Mdot
.69898 .11685 Mdot
.50992 .10766 Mdot
.33572 .23432 Mdot
.95659 .19457 Mdot
.64177 .07984 Mdot
.50029 .61764 Mdot
.50094 .61677 Mdot
.50298 .614 Mdot
.50951 .60519 Mdot
.53029 .57728 Mdot
.59624 .4934 Mdot
.79791 .35249 Mdot
.22757 .49857 Mdot
.42087 .56894 Mdot
.50031 .56865 Mdot
.58022 .49739 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48862 .01536 Mdot
.46377 .04866 Mdot
.38503 .14621 Mdot
.14846 .26473 Mdot
.72012 .11978 Mdot
.52631 .0955 Mdot
.37178 .20192 Mdot
.04506 .24314 Mdot
.50103 .61664 Mdot
.50328 .6136 Mdot
.51045 .60392 Mdot
.53328 .57329 Mdot
.60567 .48237 Mdot
.82517 .35098 Mdot
.25727 .49837 Mdot
.45088 .54319 Mdot
.57199 .4787 Mdot
.79743 .33766 Mdot
.25108 .4852 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.49769 .00311 Mdot
.49265 .00992 Mdot
.4766 .03154 Mdot
.42557 .09805 Mdot
.26692 .24476 Mdot
.87089 .13777 Mdot
.64797 .01952 Mdot
.61638 .53903 Mdot
.74422 .39158 Mdot
.11063 .48608 Mdot
.50041 .61749 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54177 .56204 Mdot
.63237 .453 Mdot
.8994 .36582 Mdot
.30748 .50385 Mdot
.49224 .51104 Mdot
.66536 .38387 Mdot
.04424 .42436 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49548 .00611 Mdot
.48558 .01946 Mdot
.4541 .06143 Mdot
.35471 .17817 Mdot
.06642 .23797 Mdot
.68137 .10394 Mdot
.51319 .09172 Mdot
.36478 .20253 Mdot
.03708 .23659 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50132 .61625 Mdot
.50422 .61234 Mdot
.51343 .5999 Mdot
.54276 .56073 Mdot
.63548 .44977 Mdot
.90774 .36895 Mdot
.31077 .50587 Mdot
.49226 .51304 Mdot
.66215 .3874 Mdot
.50079 .61697 Mdot
.50251 .61465 Mdot
.50798 .60725 Mdot
.52543 .58377 Mdot
.58087 .51198 Mdot
.75247 .36446 Mdot
.16276 .49039 Mdot
.3693 .59838 Mdot
.4011 .06625 Mdot
.2939 .20822 Mdot
.957 .16883 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.49482 .007 Mdot
.48349 .02229 Mdot
.44743 .07014 Mdot
.33393 .19764 Mdot
.01414 .21073 Mdot
.67317 .08005 Mdot
.54364 .0401 Mdot
.47876 .05973 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50475 .61161 Mdot
.51514 .5976 Mdot
.5482 .55359 Mdot
.65248 .43289 Mdot
.95204 .3891 Mdot
.32246 .52162 Mdot
.47847 .54152 Mdot
.60228 .45309 Mdot
.86916 .345 Mdot
.5008 .61696 Mdot
.50253 .61461 Mdot
.50807 .60713 Mdot
.52572 .58339 Mdot
.58177 .51087 Mdot
.75516 .36341 Mdot
.16716 .49141 Mdot
.37204 .59766 Mdot
.405 .06257 Mdot
.30376 .20177 Mdot
.97728 .18079 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00231 Mdot
.49455 .00736 Mdot
.48264 .02342 Mdot
.44475 .07362 Mdot
.32564 .20481 Mdot
.99425 .19948 Mdot
.67148 .06953 Mdot
.55899 .01608 Mdot
.53297 .60377 Mdot
.55604 .55289 Mdot
.50037 .61754 Mdot
.50117 .61645 Mdot
.50373 .613 Mdot
.51187 .60201 Mdot
.5378 .5673 Mdot
.61989 .46637 Mdot
.86528 .35587 Mdot
.28947 .4989 Mdot
.48223 .51534 Mdot
.6484 .39685 Mdot
.00628 .40267 Mdot
.50126 .61633 Mdot
.50401 .61261 Mdot
.51278 .60078 Mdot
.5407 .56346 Mdot
.62901 .45653 Mdot
.89032 .36271 Mdot
.30344 .50202 Mdot
.49115 .51022 Mdot
.6656 .38294 Mdot
.04598 .42498 Mdot
.35835 .53963 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.5065 .60926 Mdot
.52069 .59013 Mdot
.56584 .53082 Mdot
.70696 .38863 Mdot
.07814 .4582 Mdot
.33676 .58436 Mdot
.39125 .05948 Mdot
.295 .20117 Mdot
.96951 .17307 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47456 .03427 Mdot
.41912 .10606 Mdot
.2475 .25359 Mdot
.83718 .12763 Mdot
.63067 .01966 Mdot
.59886 .55183 Mdot
.70599 .40989 Mdot
.04277 .44906 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49258 .01003 Mdot
.47636 .03186 Mdot
.4248 .09901 Mdot
.2646 .24594 Mdot
.86666 .13629 Mdot
.64615 .01906 Mdot
.61531 .5393 Mdot
.74271 .39191 Mdot
.10859 .48494 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50839 .6067 Mdot
.52672 .58205 Mdot
.58495 .50698 Mdot
.76465 .36006 Mdot
.18206 .49436 Mdot
.38217 .59389 Mdot
.42123 .04593 Mdot
.49991 .00012 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .01211 Mdot
.47145 .03844 Mdot
.40926 .11808 Mdot
.2182 .26269 Mdot
.79317 .12054 Mdot
.59814 .03521 Mdot
.54116 .61552 Mdot
.54523 .57415 Mdot
.50027 .61767 Mdot
.50085 .61689 Mdot
.5027 .61439 Mdot
.5086 .60642 Mdot
.5274 .58114 Mdot
.5871 .50436 Mdot
.77103 .3581 Mdot
.19161 .49583 Mdot
.38935 .59034 Mdot
.43415 .03163 Mdot
.38297 .1306 Mdot
.50128 .61631 Mdot
.50407 .61253 Mdot
.51297 .60052 Mdot
.54132 .56265 Mdot
.63094 .4545 Mdot
.89555 .36447 Mdot
.30583 .50303 Mdot
.49191 .51052 Mdot
.66588 .38311 Mdot
.046 .42516 Mdot
.35808 .53997 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01603 Mdot
.46218 .05077 Mdot
.38004 .15174 Mdot
.13452 .26212 Mdot
.7104 .11912 Mdot
.51766 .10278 Mdot
.35136 .2214 Mdot
.99313 .21503 Mdot
.6452 .09833 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60457 Mdot
.53176 .57532 Mdot
.60088 .48793 Mdot
.81139 .35123 Mdot
.24309 .49863 Mdot
.43629 .55613 Mdot
.53644 .52264 Mdot
.69079 .38519 Mdot
.06753 .44594 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50185 .61554 Mdot
.50588 .61009 Mdot
.51873 .59276 Mdot
.55962 .53878 Mdot
.68786 .40234 Mdot
.03687 .43621 Mdot
.33107 .56502 Mdot
.41684 .02063 Mdot
.38346 .11926 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00468 Mdot
.48896 .0149 Mdot
.46485 .04723 Mdot
.38843 .1424 Mdot
.15802 .26598 Mdot
.72766 .11989 Mdot
.53367 .08891 Mdot
.38982 .18309 Mdot
.09358 .26492 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50515 .61108 Mdot
.5164 .5959 Mdot
.55222 .54835 Mdot
.66498 .42136 Mdot
.9832 .40581 Mdot
.32658 .53661 Mdot
.45833 .5748 Mdot
.52828 .54873 Mdot
.64042 .43479 Mdot
.50128 .61631 Mdot
.50407 .61253 Mdot
.51298 .60051 Mdot
.54132 .56263 Mdot
.63096 .45447 Mdot
.89561 .36449 Mdot
.30586 .50304 Mdot
.49192 .51053 Mdot
.66587 .38312 Mdot
.04598 .42515 Mdot
.35807 .53997 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49574 .00576 Mdot
.48642 .01833 Mdot
.45675 .05794 Mdot
.36301 .16982 Mdot
.08823 .24749 Mdot
.68778 .11108 Mdot
.50805 .10362 Mdot
.3404 .22799 Mdot
.9715 .20171 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50587 .6101 Mdot
.51871 .5928 Mdot
.55954 .53888 Mdot
.68763 .40252 Mdot
.03634 .43591 Mdot
.33102 .56475 Mdot
.41723 .02004 Mdot
.38481 .11774 Mdot
.1943 .25634 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48796 .01626 Mdot
.46164 .05148 Mdot
.37836 .15358 Mdot
.12985 .26105 Mdot
.70747 .11874 Mdot
.51535 .10452 Mdot
.34623 .22591 Mdot
.9807 .20806 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49427 .00775 Mdot
.48173 .02465 Mdot
.44185 .07736 Mdot
.31668 .21215 Mdot
.97342 .18762 Mdot
.66985 .05839 Mdot
.57536 .60914 Mdot
.58975 .53028 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51225 .60149 Mdot
.53902 .56568 Mdot
.62372 .4622 Mdot
.87587 .35844 Mdot
.2959 .49989 Mdot
.48707 .51187 Mdot
.65885 .38786 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49405 .00804 Mdot
.48103 .02559 Mdot
.43963 .08022 Mdot
.30982 .21747 Mdot
.95795 .17894 Mdot
.66842 .05035 Mdot
.58695 .59173 Mdot
.62951 .48449 Mdot
.84558 .36276 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.50492 .61138 Mdot
.51568 .59687 Mdot
.54992 .55135 Mdot
.65782 .42787 Mdot
.96552 .39615 Mdot
.32454 .52781 Mdot
.47052 .55498 Mdot
.57255 .49003 Mdot
.77966 .34504 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.51141 .60263 Mdot
.53633 .56924 Mdot
.61528 .47147 Mdot
.85243 .35344 Mdot
.28055 .49828 Mdot
.47432 .52198 Mdot
.62974 .41459 Mdot
.95892 .37693 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.4932 .00918 Mdot
.47834 .0292 Mdot
.43109 .09111 Mdot
.28368 .23536 Mdot
.90285 .15079 Mdot
.65887 .02678 Mdot
.61554 .54687 Mdot
.73069 .40041 Mdot
.08282 .47377 Mdot
.50037 .61753 Mdot
.50118 .61643 Mdot
.50377 .61293 Mdot
.51203 .6018 Mdot
.5383 .56663 Mdot
.62147 .46465 Mdot
.86965 .35687 Mdot
.29222 .49925 Mdot
.48442 .51368 Mdot
.65327 .39255 Mdot
.0181 .4093 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50559 .61048 Mdot
.51782 .59399 Mdot
.55673 .5425 Mdot
.67895 .40942 Mdot
.0165 .42468 Mdot
.32935 .55427 Mdot
.43252 .61497 Mdot
.43748 .05341 Mdot
.35107 .17219 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51054 .6038 Mdot
.53357 .57291 Mdot
.60657 .48134 Mdot
.82775 .35105 Mdot
.25974 .49832 Mdot
.45344 .54087 Mdot
.57829 .47118 Mdot
.81591 .33611 Mdot
.27208 .48223 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49615 .0052 Mdot
.48773 .01656 Mdot
.46093 .05242 Mdot
.37612 .15601 Mdot
.12369 .25948 Mdot
.70385 .11809 Mdot
.51277 .10627 Mdot
.34081 .23044 Mdot
.96795 .20093 Mdot
.64284 .08559 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.49281 .00972 Mdot
.47709 .03088 Mdot
.42711 .09612 Mdot
.27159 .24231 Mdot
.87953 .14099 Mdot
.65141 .02086 Mdot
.61765 .53949 Mdot
.74474 .39203 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00368 Mdot
.49131 .01173 Mdot
.47233 .03725 Mdot
.41206 .11469 Mdot
.22648 .26063 Mdot
.80477 .12174 Mdot
.6078 .02927 Mdot
.56044 .59261 Mdot
.60158 .5047 Mdot
.78496 .3607 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00444 Mdot
.48954 .01413 Mdot
.46667 .0448 Mdot
.39418 .13583 Mdot
.17439 .26704 Mdot
.74231 .11967 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49849 .00205 Mdot
.49518 .00652 Mdot
.48464 .02074 Mdot
.45108 .06538 Mdot
.3453 .18725 Mdot
.04233 .22603 Mdot
.67661 .0939 Mdot
.52468 .07111 Mdot
.40963 .15046 Mdot
.49995 7e-05 Mdot
.49982 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49433 .00765 Mdot
.48195 .02435 Mdot
.44255 .07646 Mdot
.31884 .21041 Mdot
.97838 .19044 Mdot
.67025 .06103 Mdot
.5715 .61498 Mdot
.57644 .54681 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48974 .01386 Mdot
.46731 .04396 Mdot
.39619 .13352 Mdot
.18015 .26708 Mdot
.74801 .11955 Mdot
.55458 .06993 Mdot
.44143 .12301 Mdot
.2424 .27039 Mdot
.80491 .13153 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51077 .60349 Mdot
.5343 .57194 Mdot
.60889 .47869 Mdot
.83435 .35139 Mdot
.2658 .4982 Mdot
.45969 .53518 Mdot
.59376 .4532 Mdot
.86046 .33979 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.51009 .6044 Mdot
.53215 .5748 Mdot
.60211 .48649 Mdot
.81495 .35107 Mdot
.24691 .49858 Mdot
.44019 .55273 Mdot
.54585 .51082 Mdot
.71933 .366 Mdot
.12712 .47171 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.49631 .00499 Mdot
.48823 .01589 Mdot
.46252 .05031 Mdot
.38112 .15056 Mdot
.13751 .26276 Mdot
.71236 .11932 Mdot
.5193 .10147 Mdot
.35512 .21799 Mdot
.00241 .22022 Mdot
.64609 .10302 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00265 Mdot
.49376 .00843 Mdot
.48011 .02682 Mdot
.43672 .08396 Mdot
.30087 .22403 Mdot
.93839 .16833 Mdot
.66603 .04085 Mdot
.59994 .5722 Mdot
.67411 .44111 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.51229 .60144 Mdot
.53914 .56553 Mdot
.62409 .46179 Mdot
.8769 .35871 Mdot
.29649 .50001 Mdot
.48745 .51163 Mdot
.65962 .38724 Mdot
.03305 .41766 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.5009 .61681 Mdot
.50288 .61414 Mdot
.50917 .60564 Mdot
.52922 .5787 Mdot
.59286 .49742 Mdot
.78801 .35407 Mdot
.21512 .49808 Mdot
.40921 .57776 Mdot
.47438 .6014 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01801 Mdot
.45753 .05691 Mdot
.36544 .16732 Mdot
.09471 .25003 Mdot
.69015 .11279 Mdot
.50765 .1057 Mdot
.33662 .23193 Mdot
.96134 .19644 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48837 .01571 Mdot
.46295 .04974 Mdot
.38246 .14907 Mdot
.14127 .2635 Mdot
.71492 .11952 Mdot
.52153 .09963 Mdot
.36032 .21312 Mdot
.01548 .22745 Mdot
.64745 .10949 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01053 Mdot
.47516 .03346 Mdot
.42102 .10372 Mdot
.2532 .25123 Mdot
.84669 .13009 Mdot
.6362 .01868 Mdot
.60597 .54557 Mdot
.72321 .40011 Mdot
.07582 .46777 Mdot
.5013 .61628 Mdot
.50413 .61246 Mdot
.51315 .60028 Mdot
.54188 .56191 Mdot
.63269 .45266 Mdot
.90028 .36614 Mdot
.30785 .50405 Mdot
.49229 .5112 Mdot
.66515 .38413 Mdot
.04362 .42406 Mdot
.35747 .53922 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46278 .04997 Mdot
.38194 .14965 Mdot
.1398 .26322 Mdot
.71391 .11945 Mdot
.52063 .10038 Mdot
.35822 .21511 Mdot
.01017 .22453 Mdot
.64688 .10689 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49903 .00131 Mdot
.4969 .00419 Mdot
.49012 .01334 Mdot
.46853 .04233 Mdot
.40005 .12901 Mdot
.1913 .26664 Mdot
.75987 .11938 Mdot
.56672 .05932 Mdot
.47074 .08629 Mdot
.33112 .21508 Mdot
.5002 .61776 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50662 .6091 Mdot
.52108 .58962 Mdot
.56706 .52928 Mdot
.71067 .38621 Mdot
.08577 .46193 Mdot
.33835 .58732 Mdot
.38805 .06472 Mdot
.28333 .20904 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.5065 .60926 Mdot
.52069 .59013 Mdot
.56585 .53081 Mdot
.70697 .38863 Mdot
.07816 .45821 Mdot
.33676 .58437 Mdot
.39124 .0595 Mdot
.29497 .20119 Mdot
.96944 .17303 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00271 Mdot
.49361 .00864 Mdot
.47964 .02746 Mdot
.4352 .08589 Mdot
.29623 .22726 Mdot
.92852 .16319 Mdot
.66447 .03645 Mdot
.60549 .5637 Mdot
.69341 .42538 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50476 .61161 Mdot
.51516 .59757 Mdot
.54827 .55351 Mdot
.65268 .4327 Mdot
.95256 .38937 Mdot
.32255 .52184 Mdot
.47819 .542 Mdot
.60122 .45436 Mdot
.86605 .34433 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.5159 .59657 Mdot
.55063 .55043 Mdot
.66002 .42584 Mdot
.97099 .3991 Mdot
.32524 .53046 Mdot
.46693 .56089 Mdot
.55939 .50711 Mdot
.73887 .35992 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50531 .61086 Mdot
.51692 .59521 Mdot
.55385 .54624 Mdot
.67002 .41693 Mdot
.9954 .41267 Mdot
.32768 .54299 Mdot
.44911 .58937 Mdot
.49549 .59355 Mdot
.5351 .56128 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01782 Mdot
.45796 .05635 Mdot
.36679 .16592 Mdot
.09833 .25138 Mdot
.69158 .11367 Mdot
.50766 .10657 Mdot
.33524 .23345 Mdot
.9575 .19452 Mdot
.64276 .07922 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01346 Mdot
.46825 .0427 Mdot
.39915 .13006 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00355 Mdot
.49164 .01129 Mdot
.47337 .03587 Mdot
.41533 .11071 Mdot
.23619 .2577 Mdot
.81922 .12389 Mdot
.61876 .02374 Mdot
.58035 .5704 Mdot
.65742 .44712 Mdot
.93396 .38764 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49337 .00896 Mdot
.47888 .02848 Mdot
.43279 .08895 Mdot
.28886 .23212 Mdot
.91327 .15564 Mdot
.66144 .03036 Mdot
.61231 .5527 Mdot
.71802 .40813 Mdot
.05766 .46042 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50203 .61529 Mdot
.50647 .6093 Mdot
.5206 .59026 Mdot
.56554 .5312 Mdot
.70604 .38925 Mdot
.07623 .45724 Mdot
.33639 .58358 Mdot
.39214 .05805 Mdot
.29821 .19888 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48981 .01377 Mdot
.46753 .04366 Mdot
.3969 .13269 Mdot
.1822 .26705 Mdot
.75011 .1195 Mdot
.55675 .068 Mdot
.44671 .11649 Mdot
.25823 .26384 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50546 .61066 Mdot
.51739 .59458 Mdot
.55534 .5443 Mdot
.67464 .41299 Mdot
.00642 .41893 Mdot
.32857 .54886 Mdot
.44049 .60276 Mdot
.4652 .01673 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48958 .01408 Mdot
.4668 .04463 Mdot
.39458 .13537 Mdot
.17555 .26706 Mdot
.74343 .11964 Mdot
.54984 .07419 Mdot
.42979 .13719 Mdot
.20782 .27958 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.5111 .60305 Mdot
.53535 .57055 Mdot
.61218 .47495 Mdot
.8437 .35224 Mdot
.27375 .49815 Mdot
.46773 .52786 Mdot
.5012 .61641 Mdot
.50383 .61285 Mdot
.51221 .60154 Mdot
.5389 .56584 Mdot
.62334 .4626 Mdot
.87483 .35817 Mdot
.29531 .49977 Mdot
.48666 .51212 Mdot
.65803 .38853 Mdot
.02938 .41561 Mdot
.3569 .5311 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.51131 .60276 Mdot
.53602 .56966 Mdot
.6143 .47257 Mdot
.84966 .35302 Mdot
.27846 .49821 Mdot
.47234 .52373 Mdot
.62492 .41945 Mdot
.94624 .37055 Mdot
.34667 .49171 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50928 .6055 Mdot
.52955 .57826 Mdot
.59391 .49617 Mdot
.79109 .35351 Mdot
.21909 .49829 Mdot
.41285 .5751 Mdot
.48232 .59145 Mdot
.52533 .56807 Mdot
.60617 .47678 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00378 Mdot
.49108 .01205 Mdot
.47157 .03827 Mdot
.40965 .1176 Mdot
.21938 .26242 Mdot
.79478 .12067 Mdot
.59952 .03431 Mdot
.54401 .61207 Mdot
.55366 .56326 Mdot
.64229 .44823 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51039 .604 Mdot
.5331 .57353 Mdot
.60511 .48302 Mdot
.82356 .35096 Mdot
.2557 .49841 Mdot
.44926 .54466 Mdot
.56798 .48354 Mdot
.7856 .33967 Mdot
.236 .48664 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50565 .6104 Mdot
.51801 .59374 Mdot
.55732 .54174 Mdot
.68077 .40794 Mdot
.02072 .42709 Mdot
.32968 .55652 Mdot
.4292 .00198 Mdot
.426 .06814 Mdot
.31575 .20327 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50958 .60509 Mdot
.53052 .57697 Mdot
.59696 .49255 Mdot
.8 .35222 Mdot
.23009 .49862 Mdot
.42331 .56699 Mdot
.50591 .56152 Mdot
.59736 .47679 Mdot
.8259 .3457 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00453 Mdot
.48931 .01444 Mdot
.46594 .04577 Mdot
.39189 .13846 Mdot
.16785 .26679 Mdot
.73618 .1198 Mdot
.54234 .081 Mdot
.41128 .15906 Mdot
.15391 .28052 Mdot
.70001 .14019 Mdot
.5 .61803 Mdot
.50001 .61802 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50041 .61749 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54175 .56207 Mdot
.6323 .45306 Mdot
.89923 .36576 Mdot
.49969 .00041 Mdot
.49903 .00131 Mdot
.4969 .00419 Mdot
.49012 .01334 Mdot
.46854 .04232 Mdot
.40007 .12899 Mdot
.19136 .26663 Mdot
.75994 .11937 Mdot
.56679 .05926 Mdot
.47091 .08608 Mdot
.33163 .21464 Mdot
.98434 .20014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .0044 Mdot
.48963 .014 Mdot
.46698 .0444 Mdot
.39514 .13472 Mdot
.17716 .26708 Mdot
.74501 .11961 Mdot
.55148 .07272 Mdot
.43382 .13232 Mdot
.21973 .2772 Mdot
.77121 .13096 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50477 .61159 Mdot
.51519 .59753 Mdot
.54836 .55339 Mdot
.65296 .43243 Mdot
.95328 .38973 Mdot
.32268 .52216 Mdot
.4778 .54267 Mdot
.59974 .45615 Mdot
.86168 .34346 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60624 Mdot
.52783 .58057 Mdot
.58844 .50274 Mdot
.77499 .35701 Mdot
.19734 .49655 Mdot
.39391 .58778 Mdot
.44285 .02159 Mdot
.40791 .10228 Mdot
.24243 .24966 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.49549 .00609 Mdot
.48564 .01939 Mdot
.45427 .0612 Mdot
.35524 .17765 Mdot
.06779 .23862 Mdot
.68171 .10445 Mdot
.51271 .09268 Mdot
.36275 .20473 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49291 .00957 Mdot
.47743 .03042 Mdot
.4282 .09475 Mdot
.27489 .2405 Mdot
.88576 .14345 Mdot
.65365 .02213 Mdot
.61784 .54063 Mdot
.74309 .39322 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50452 .61193 Mdot
.51439 .59861 Mdot
.54582 .55672 Mdot
.64502 .44013 Mdot
.93288 .37973 Mdot
.31846 .51384 Mdot
.48706 .52582 Mdot
.63626 .41437 Mdot
.96579 .3829 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00636 Mdot
.485 .02025 Mdot
.45223 .06387 Mdot
.34888 .18384 Mdot
.05142 .23069 Mdot
.67816 .09792 Mdot
.51972 .07968 Mdot
.3908 .17316 Mdot
.11063 .26765 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47927 .02796 Mdot
.43403 .08738 Mdot
.29266 .22965 Mdot
.92107 .15944 Mdot
.66308 .03336 Mdot
.60911 .55798 Mdot
.70628 .41597 Mdot
.03323 .44655 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49716 .00384 Mdot
.49095 .01222 Mdot
.47118 .03879 Mdot
.40842 .11908 Mdot
.21575 .26322 Mdot
.78986 .12028 Mdot
.59524 .03716 Mdot
.53512 .00486 Mdot
.52726 .59774 Mdot
.5601 .54334 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46507 .04693 Mdot
.38914 .14159 Mdot
.16003 .26619 Mdot
.72933 .11988 Mdot
.53536 .08737 Mdot
.39398 .17855 Mdot
.10508 .26904 Mdot
.66977 .13985 Mdot
.50118 .61644 Mdot
.50375 .61297 Mdot
.51194 .60191 Mdot
.53804 .56698 Mdot
.62065 .46554 Mdot
.86738 .35634 Mdot
.29081 .49906 Mdot
.48332 .5145 Mdot
.65084 .39468 Mdot
.01223 .40601 Mdot
.3553 .52242 Mdot
.50052 .61734 Mdot
.50164 .61581 Mdot
.50523 .61096 Mdot
.51667 .59554 Mdot
.55308 .54724 Mdot
.66763 .41902 Mdot
.98964 .40942 Mdot
.32718 .53995 Mdot
.45352 .58244 Mdot
.51112 .57214 Mdot
.58538 .49672 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50768 .60766 Mdot
.52446 .58507 Mdot
.57779 .51579 Mdot
.74322 .36838 Mdot
.14716 .48618 Mdot
.3605 .59957 Mdot
.39037 .07533 Mdot
.26849 .22188 Mdot
.90948 .14241 Mdot
.50021 .61775 Mdot
.50067 .61712 Mdot
.50214 .61514 Mdot
.50683 .60881 Mdot
.52176 .5887 Mdot
.56923 .52652 Mdot
.7173 .38208 Mdot
.09908 .46811 Mdot
.34166 .59186 Mdot
.38401 .07209 Mdot
.26736 .21876 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51318 .60024 Mdot
.54198 .56177 Mdot
.63303 .45231 Mdot
.90117 .36647 Mdot
.30822 .50425 Mdot
.49232 .51137 Mdot
.66491 .38441 Mdot
.04292 .42372 Mdot
.35733 .53897 Mdot
.50073 .61705 Mdot
.50232 .61491 Mdot
.50738 .60807 Mdot
.5235 .58636 Mdot
.57475 .51958 Mdot
.73405 .37278 Mdot
.13089 .48089 Mdot
.35279 .59872 Mdot
.38403 .07893 Mdot
.25631 .22636 Mdot
.89005 .13235 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51185 .60203 Mdot
.53775 .56736 Mdot
.61975 .46653 Mdot
.86489 .35579 Mdot
.28922 .49887 Mdot
.48202 .5155 Mdot
.64793 .39728 Mdot
.00512 .40202 Mdot
.35464 .51881 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00322 Mdot
.4924 .01027 Mdot
.47579 .03263 Mdot
.423 .10126 Mdot
.25915 .24856 Mdot
.85697 .13311 Mdot
.6416 .01848 Mdot
.61169 .54126 Mdot
.73591 .3943 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48934 .0144 Mdot
.46604 .04564 Mdot
.39218 .13812 Mdot
.1687 .26683 Mdot
.73695 .11978 Mdot
.54314 .08027 Mdot
.41326 .15677 Mdot
.1596 .28115 Mdot
.7047 .13954 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49632 .00497 Mdot
.48827 .01584 Mdot
.46265 .05015 Mdot
.3815 .15013 Mdot
.13859 .26298 Mdot
.71308 .11938 Mdot
.51992 .10097 Mdot
.35655 .21666 Mdot
.00599 .22221 Mdot
.64644 .10481 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00474 Mdot
.48882 .0151 Mdot
.46439 .04784 Mdot
.38699 .14402 Mdot
.15396 .26551 Mdot
.72436 .11987 Mdot
.5304 .09186 Mdot
.38178 .19165 Mdot
.07168 .25588 Mdot
.65766 .13248 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00218 Mdot
.49485 .00695 Mdot
.4836 .02213 Mdot
.4478 .06966 Mdot
.33509 .19661 Mdot
.01697 .21231 Mdot
.67344 .08151 Mdot
.54155 .04343 Mdot
.47128 .06991 Mdot
.35817 .18466 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50877 .6062 Mdot
.52792 .58044 Mdot
.58874 .50237 Mdot
.77589 .35677 Mdot
.19862 .4967 Mdot
.39495 .58717 Mdot
.44489 .01921 Mdot
.41381 .09526 Mdot
.50114 .61649 Mdot
.50364 .61311 Mdot
.5116 .60237 Mdot
.53695 .56842 Mdot
.61723 .46931 Mdot
.85787 .35438 Mdot
.28448 .49847 Mdot
.47794 .51886 Mdot
.63841 .40612 Mdot
.9813 .38882 Mdot
.35217 .50699 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51264 .60097 Mdot
.54025 .56405 Mdot
.62761 .45802 Mdot
.88651 .3615 Mdot
.30158 .50137 Mdot
.49036 .5103 Mdot
.66467 .38346 Mdot
.04422 .42393 Mdot
.35829 .53862 Mdot
.50035 .61756 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51128 .60281 Mdot
.53592 .56979 Mdot
.61398 .47293 Mdot
.84876 .35289 Mdot
.27777 .4982 Mdot
.47167 .52432 Mdot
.62329 .42112 Mdot
.94191 .36845 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50747 .60794 Mdot
.5238 .58597 Mdot
.57568 .51842 Mdot
.73686 .37138 Mdot
.13596 .48264 Mdot
.35503 .5992 Mdot
.3855 .07839 Mdot
.25866 .22572 Mdot
.89345 .13415 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00599 Mdot
.48588 .01907 Mdot
.45503 .0602 Mdot
.35761 .17529 Mdot
.074 .24144 Mdot
.68334 .10665 Mdot
.51078 .09666 Mdot
.50014 .61785 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50449 .61196 Mdot
.51432 .59871 Mdot
.54559 .55702 Mdot
.64432 .44082 Mdot
.93106 .37889 Mdot
.31801 .51317 Mdot
.48768 .52458 Mdot
.6389 .41155 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60119 Mdot
.53973 .56473 Mdot
.62597 .45977 Mdot
.88205 .36016 Mdot
.2993 .50069 Mdot
.48917 .51072 Mdot
.66281 .38477 Mdot
.04025 .42168 Mdot
.35795 .53656 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00172 Mdot
.49594 .00549 Mdot
.48706 .01747 Mdot
.45878 .05526 Mdot
.36937 .16321 Mdot
.1053 .25386 Mdot
.69455 .11518 Mdot
.50818 .1076 Mdot
.33409 .23502 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49262 .00997 Mdot
.47648 .0317 Mdot
.4252 .09852 Mdot
.26579 .24534 Mdot
.86882 .13704 Mdot
.64709 .01928 Mdot
.6159 .53912 Mdot
.74359 .39169 Mdot
.10982 .48561 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00405 Mdot
.49045 .01289 Mdot
.46959 .04091 Mdot
.40339 .12508 Mdot
.20101 .26569 Mdot
.77111 .11944 Mdot
.57786 .05011 Mdot
.49678 .05309 Mdot
.41088 .13145 Mdot
.50098 .6167 Mdot
.50314 .6138 Mdot
.50999 .60454 Mdot
.53182 .57524 Mdot
.60106 .48772 Mdot
.81191 .3512 Mdot
.24366 .49863 Mdot
.43686 .55564 Mdot
.53783 .5209 Mdot
.69499 .38208 Mdot
.07678 .45053 Mdot
.50002 .618 Mdot
.50007 .61793 Mdot
.50023 .61772 Mdot
.50075 .61702 Mdot
.50238 .61481 Mdot
.5076 .60777 Mdot
.5242 .58543 Mdot
.57696 .51683 Mdot
.74071 .36954 Mdot
.14279 .48485 Mdot
.35828 .59955 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.5085 .60655 Mdot
.52709 .58155 Mdot
.58612 .50555 Mdot
.76811 .35896 Mdot
.1873 .49521 Mdot
.38604 .59206 Mdot
.42807 .03846 Mdot
.50027 .61766 Mdot
.50087 .61686 Mdot
.50278 .61428 Mdot
.50885 .60608 Mdot
.5282 .58007 Mdot
.58963 .5013 Mdot
.7785 .35612 Mdot
.20229 .49708 Mdot
.39799 .58531 Mdot
.45094 .01204 Mdot
.43146 .07363 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49439 .00758 Mdot
.48213 .0241 Mdot
.44314 .07571 Mdot
.32064 .20895 Mdot
.98255 .19281 Mdot
.67058 .06325 Mdot
.56823 .00192 Mdot
.56513 .56125 Mdot
.657 .43818 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.5005 .61735 Mdot
.50161 .61586 Mdot
.50512 .61111 Mdot
.51632 .59601 Mdot
.55196 .54868 Mdot
.66417 .42208 Mdot
.98124 .40473 Mdot
.32638 .5356 Mdot
.45976 .57251 Mdot
.50068 .61711 Mdot
.50217 .6151 Mdot
.50691 .60869 Mdot
.52203 .58834 Mdot
.57007 .52546 Mdot
.71986 .38055 Mdot
.10412 .47034 Mdot
.3431 .59335 Mdot
.38304 .07424 Mdot
.26292 .2213 Mdot
.90485 .13825 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50438 .61212 Mdot
.51395 .5992 Mdot
.54442 .55856 Mdot
.64065 .44449 Mdot
.92145 .37459 Mdot
.31535 .50987 Mdot
.49036 .5188 Mdot
.65092 .39894 Mdot
.00541 .40396 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51023 .60422 Mdot
.53259 .57422 Mdot
.60349 .4849 Mdot
.81891 .35097 Mdot
.25104 .49851 Mdot
.44443 .54898 Mdot
.55616 .49799 Mdot
.7504 .35044 Mdot
.18337 .48525 Mdot
.49993 .0001 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49272 .00984 Mdot
.47679 .03128 Mdot
.42619 .09728 Mdot
.26879 .2438 Mdot
.87432 .13902 Mdot
.64938 .01999 Mdot
.61703 .53905 Mdot
.74483 .39158 Mdot
.50051 .61734 Mdot
.50163 .61583 Mdot
.50519 .61102 Mdot
.51653 .59572 Mdot
.55263 .54782 Mdot
.66624 .42024 Mdot
.98628 .40754 Mdot
.32687 .5382 Mdot
.45604 .57844 Mdot
.52011 .55984 Mdot
.61427 .46278 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58922 Mdot
.568 .52808 Mdot
.71356 .38438 Mdot
.09161 .4647 Mdot
.33971 .58942 Mdot
.38602 .06825 Mdot
.27559 .21389 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61543 Mdot
.50613 .60975 Mdot
.51954 .59168 Mdot
.56217 .5355 Mdot
.69571 .39646 Mdot
.05422 .44576 Mdot
.33297 .57371 Mdot
.40469 .03884 Mdot
.34184 .1625 Mdot
.50083 .61691 Mdot
.50264 .61446 Mdot
.50842 .60667 Mdot
.52681 .58193 Mdot
.58523 .50664 Mdot
.76547 .35979 Mdot
.18332 .49457 Mdot
.38308 .59347 Mdot
.42282 .04422 Mdot
.35126 .1629 Mdot
.08769 .24014 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50704 .60852 Mdot
.52243 .5878 Mdot
.57135 .52384 Mdot
.72376 .3783 Mdot
.11165 .47352 Mdot
.34547 .59531 Mdot
.38224 .07675 Mdot
.25806 .2241 Mdot
.89546 .13401 Mdot
.50029 .61765 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60547 Mdot
.52962 .57817 Mdot
.59412 .49591 Mdot
.79172 .35341 Mdot
.2199 .49832 Mdot
.4136 .57454 Mdot
.48397 .58938 Mdot
.53033 .56143 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51184 .60205 Mdot
.5377 .56742 Mdot
.6196 .46669 Mdot
.86447 .35569 Mdot
.28894 .49884 Mdot
.4818 .51568 Mdot
.64741 .39774 Mdot
.00384 .40131 Mdot
.35452 .51817 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49607 .0053 Mdot
.48749 .01689 Mdot
.46017 .05343 Mdot
.37373 .15859 Mdot
.11713 .25763 Mdot
.70027 .11723 Mdot
.51059 .10742 Mdot
.33678 .23357 Mdot
.95887 .19586 Mdot
.64196 .08102 Mdot
.49982 .00025 Mdot
.49941 .0008 Mdot
.49812 .00253 Mdot
.49402 .00807 Mdot
.48096 .02568 Mdot
.43941 .08051 Mdot
.30914 .21798 Mdot
.95643 .1781 Mdot
.66826 .04959 Mdot
.58803 .59011 Mdot
.63321 .48054 Mdot
.85568 .36435 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48805 .01613 Mdot
.46196 .05106 Mdot
.37934 .15251 Mdot
.13257 .26168 Mdot
.70916 .11897 Mdot
.51666 .10355 Mdot
.34912 .2234 Mdot
.98765 .21196 Mdot
.64469 .09555 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51282 .60073 Mdot
.54081 .56331 Mdot
.62935 .45617 Mdot
.89126 .36302 Mdot
.30388 .50219 Mdot
.49132 .51024 Mdot
.66573 .3829 Mdot
.04619 .42512 Mdot
.35833 .53978 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50708 .60847 Mdot
.52255 .58764 Mdot
.57174 .52336 Mdot
.72492 .37765 Mdot
.11387 .47443 Mdot
.34622 .59582 Mdot
.38216 .07732 Mdot
.25705 .22472 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01627 Mdot
.46163 .05149 Mdot
.37832 .15362 Mdot
.12975 .26102 Mdot
.70741 .11873 Mdot
.51531 .10456 Mdot
.34613 .226 Mdot
.98046 .20793 Mdot
.64403 .0919 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.5045 .61195 Mdot
.51435 .59866 Mdot
.5457 .55687 Mdot
.64466 .44049 Mdot
.93193 .37929 Mdot
.31823 .51349 Mdot
.48739 .52517 Mdot
.63765 .41288 Mdot
.96959 .38486 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49666 .00451 Mdot
.48937 .01435 Mdot
.46615 .0455 Mdot
.39253 .13773 Mdot
.16969 .26688 Mdot
.73787 .11976 Mdot
.54408 .07942 Mdot
.41558 .15406 Mdot
.16631 .28167 Mdot
.71056 .13863 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48853 .01548 Mdot
.46348 .04904 Mdot
.38413 .14722 Mdot
.14592 .26432 Mdot
.71823 .11971 Mdot
.52454 .09705 Mdot
.36751 .20618 Mdot
.03391 .23737 Mdot
.64983 .1181 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61024 Mdot
.51839 .59322 Mdot
.55853 .54018 Mdot
.68451 .40495 Mdot
.02929 .43195 Mdot
.33038 .56107 Mdot
.42255 .01204 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49632 .00497 Mdot
.48827 .01584 Mdot
.46265 .05014 Mdot
.38152 .15011 Mdot
.13863 .26298 Mdot
.71311 .11939 Mdot
.51994 .10095 Mdot
.35661 .21661 Mdot
.00612 .22228 Mdot
.64646 .10488 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60664 Mdot
.52686 .58186 Mdot
.5854 .50643 Mdot
.76597 .35963 Mdot
.18408 .4947 Mdot
.38364 .59321 Mdot
.4238 .04316 Mdot
.35397 .16032 Mdot
.09456 .24292 Mdot
.50015 .61784 Mdot
.50047 .61741 Mdot
.50148 .61603 Mdot
.50472 .61165 Mdot
.51505 .59773 Mdot
.5479 .55398 Mdot
.65154 .43379 Mdot
.94966 .38789 Mdot
.32204 .52058 Mdot
.47973 .53932 Mdot
.60709 .44737 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60843 Mdot
.52265 .58751 Mdot
.57204 .52299 Mdot
.72583 .37714 Mdot
.1156 .47513 Mdot
.34682 .5962 Mdot
.38215 .07771 Mdot
.25641 .22514 Mdot
.89213 .13262 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49155 .01141 Mdot
.47308 .03625 Mdot
.41443 .11181 Mdot
.23353 .25856 Mdot
.81517 .12321 Mdot
.61581 .02508 Mdot
.57522 .57595 Mdot
.64332 .46032 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51166 .6023 Mdot
.53712 .5682 Mdot
.61776 .46872 Mdot
.85936 .35465 Mdot
.28551 .49854 Mdot
.47886 .51808 Mdot
.64058 .40406 Mdot
.98681 .39184 Mdot
.3528 .50966 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49696 .00411 Mdot
.49031 .01308 Mdot
.46915 .0415 Mdot
.402 .12672 Mdot
.19696 .26615 Mdot
.76633 .11938 Mdot
.57317 .05391 Mdot
.48594 .06692 Mdot
.37766 .16949 Mdot
.10341 .25876 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48847 .01557 Mdot
.46326 .04933 Mdot
.38345 .14798 Mdot
.14402 .264 Mdot
.71686 .11964 Mdot
.52327 .09814 Mdot
.36448 .20914 Mdot
.02608 .23321 Mdot
.64874 .11453 Mdot
.50086 .61688 Mdot
.50273 .61435 Mdot
.5087 .60629 Mdot
.5277 .58074 Mdot
.58805 .50321 Mdot
.77383 .35732 Mdot
.19567 .49635 Mdot
.39256 .58856 Mdot
.44024 .02463 Mdot
.40038 .11107 Mdot
.22066 .25612 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48814 .01602 Mdot
.46222 .05071 Mdot
.38017 .1516 Mdot
.13488 .2622 Mdot
.71063 .11914 Mdot
.51785 .10263 Mdot
.3518 .22101 Mdot
.9942 .21563 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00197 Mdot
.49535 .00628 Mdot
.48519 .01999 Mdot
.45285 .06306 Mdot
.35082 .18198 Mdot
.05636 .23315 Mdot
.67912 .09999 Mdot
.51733 .08396 Mdot
.38148 .18396 Mdot
.08382 .25813 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02202 Mdot
.44805 .06933 Mdot
.33588 .19591 Mdot
.0189 .21339 Mdot
.67363 .0825 Mdot
.54014 .04568 Mdot
.46623 .07675 Mdot
.34204 .2003 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01037 Mdot
.47555 .03295 Mdot
.42223 .10221 Mdot
.25685 .24962 Mdot
.85295 .13188 Mdot
.63956 .01846 Mdot
.60969 .54266 Mdot
.73164 .3961 Mdot
.09074 .47574 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00907 Mdot
.4786 .02885 Mdot
.43192 .09006 Mdot
.2862 .23381 Mdot
.90789 .1531 Mdot
.66016 .02845 Mdot
.61414 .54951 Mdot
.72502 .40378 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49824 .00237 Mdot
.49441 .00756 Mdot
.48218 .02405 Mdot
.44327 .07554 Mdot
.32105 .20862 Mdot
.98349 .19334 Mdot
.67065 .06376 Mdot
.56749 .00305 Mdot
.56256 .56457 Mdot
.64906 .44572 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49605 .00534 Mdot
.4874 .01701 Mdot
.45988 .05381 Mdot
.37281 .15957 Mdot
.11462 .25688 Mdot
.69898 .11685 Mdot
.50992 .10766 Mdot
.33572 .23432 Mdot
.95659 .19457 Mdot
.64177 .07985 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49082 .01241 Mdot
.47074 .03938 Mdot
.40703 .12074 Mdot
.21167 .26403 Mdot
.78446 .11993 Mdot
.59041 .04055 Mdot
.5248 .01765 Mdot
.49625 .02112 Mdot
.46208 .05594 Mdot
.49995 6e-05 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49532 .00633 Mdot
.48508 .02014 Mdot
.45249 .06354 Mdot
.34968 .18308 Mdot
.05346 .23171 Mdot
.67855 .09878 Mdot
.51871 .08148 Mdot
.38687 .17774 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50564 .61042 Mdot
.51796 .5938 Mdot
.55717 .54194 Mdot
.68029 .40832 Mdot
.01961 .42646 Mdot
.32959 .55593 Mdot
.43007 .00066 Mdot
.429 .06432 Mdot
.32494 .19581 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.5129 .60062 Mdot
.54109 .56295 Mdot
.63022 .45526 Mdot
.89359 .3638 Mdot
.30495 .50264 Mdot
.49167 .51035 Mdot
.66591 .38293 Mdot
.04631 .42526 Mdot
.35823 .53999 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.49761 .00324 Mdot
.49237 .01031 Mdot
.4757 .03275 Mdot
.42271 .10162 Mdot
.25829 .24896 Mdot
.85546 .13264 Mdot
.64084 .01846 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.4957 .0058 Mdot
.48631 .01848 Mdot
.45642 .05837 Mdot
.36197 .17089 Mdot
.08546 .24636 Mdot
.68684 .11029 Mdot
.50839 .10251 Mdot
.34252 .22583 Mdot
.97712 .20469 Mdot
.50036 .61755 Mdot
.50115 .61649 Mdot
.50365 .6131 Mdot
.51163 .60233 Mdot
.53704 .5683 Mdot
.61752 .46899 Mdot
.85868 .35453 Mdot
.28504 .49851 Mdot
.47844 .51843 Mdot
.6396 .40498 Mdot
.98433 .39048 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01536 Mdot
.46378 .04865 Mdot
.38506 .14618 Mdot
.14853 .26474 Mdot
.72017 .11978 Mdot
.52636 .09546 Mdot
.3719 .2018 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49375 .00845 Mdot
.48008 .02686 Mdot
.43662 .08407 Mdot
.30059 .22423 Mdot
.93779 .16801 Mdot
.66594 .04057 Mdot
.6003 .57165 Mdot
.67536 .44003 Mdot
.50007 .61794 Mdot
.50023 .61773 Mdot
.50072 .61705 Mdot
.50231 .61491 Mdot
.50736 .60809 Mdot
.52344 .58644 Mdot
.57456 .51982 Mdot
.73348 .37307 Mdot
.12984 .48052 Mdot
.35234 .5986 Mdot
.38378 .07898 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00479 Mdot
.48871 .01524 Mdot
.46406 .04828 Mdot
.38594 .14519 Mdot
.15102 .26511 Mdot
.72206 .11983 Mdot
.52817 .09386 Mdot
.3763 .19733 Mdot
.05701 .24906 Mdot
.65402 .12754 Mdot
.50051 .61734 Mdot
.50164 .61582 Mdot
.50523 .61098 Mdot
.51665 .59557 Mdot
.55299 .54735 Mdot
.66737 .41925 Mdot
.98901 .40907 Mdot
.32713 .53962 Mdot
.454 .58168 Mdot
.51282 .56981 Mdot
.59084 .4901 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.49599 .00541 Mdot
.48724 .01723 Mdot
.45935 .0545 Mdot
.37116 .16132 Mdot
.11014 .25547 Mdot
.69678 .1161 Mdot
.50894 .10782 Mdot
.33448 .23506 Mdot
.95415 .19314 Mdot
.64164 .07849 Mdot
.50025 .6177 Mdot
.50079 .61696 Mdot
.50252 .61462 Mdot
.50804 .60717 Mdot
.52561 .58353 Mdot
.58143 .51129 Mdot
.75414 .3638 Mdot
.16551 .49103 Mdot
.371 .59796 Mdot
.40348 .06401 Mdot
.29991 .20436 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51185 .60203 Mdot
.53775 .56736 Mdot
.61974 .46653 Mdot
.86488 .35578 Mdot
.28921 .49887 Mdot
.48202 .51551 Mdot
.64791 .39729 Mdot
.00508 .402 Mdot
.35463 .51879 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50331 .61357 Mdot
.51053 .60381 Mdot
.53355 .57294 Mdot
.60651 .48141 Mdot
.82758 .35105 Mdot
.25958 .49832 Mdot
.45327 .54102 Mdot
.57788 .47167 Mdot
.81469 .33615 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49749 .0034 Mdot
.49199 .01081 Mdot
.4745 .03436 Mdot
.41891 .10632 Mdot
.24687 .25384 Mdot
.83615 .12739 Mdot
.63003 .01981 Mdot
.59798 .55264 Mdot
.70378 .41128 Mdot
.03832 .44646 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00306 Mdot
.49279 .00974 Mdot
.47704 .03095 Mdot
.42697 .0963 Mdot
.27115 .24255 Mdot
.8787 .14067 Mdot
.65109 .02071 Mdot
.61758 .53939 Mdot
.74483 .39192 Mdot
.11069 .48646 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61392 Mdot
.50971 .60492 Mdot
.53093 .57643 Mdot
.59826 .49101 Mdot
.80378 .35181 Mdot
.23453 .49866 Mdot
.42768 .56342 Mdot
.51605 .54857 Mdot
.62845 .442 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00213 Mdot
.49497 .00679 Mdot
.48399 .02161 Mdot
.44902 .06807 Mdot
.33888 .1932 Mdot
.02628 .21745 Mdot
.67444 .08622 Mdot
.53493 .0541 Mdot
.44738 .102 Mdot
.28235 .24651 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54179 .56202 Mdot
.63243 .45293 Mdot
.89958 .36589 Mdot
.30756 .50389 Mdot
.49225 .51107 Mdot
.66532 .38392 Mdot
.04412 .4243 Mdot
.35758 .5394 Mdot
.50082 .61692 Mdot
.50262 .61449 Mdot
.50835 .60675 Mdot
.52661 .58219 Mdot
.58461 .5074 Mdot
.76362 .36039 Mdot
.18049 .49409 Mdot
.38104 .59439 Mdot
.4193 .04801 Mdot
.34162 .17177 Mdot
.06369 .22925 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00204 Mdot
.49519 .0065 Mdot
.48467 .02069 Mdot
.4512 .06523 Mdot
.34566 .18692 Mdot
.04322 .22649 Mdot
.67675 .0943 Mdot
.52417 .07199 Mdot
.40769 .15284 Mdot
.16039 .27761 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .00249 Mdot
.49412 .00794 Mdot
.48126 .02527 Mdot
.44037 .07927 Mdot
.31211 .21572 Mdot
.96306 .18178 Mdot
.66893 .05297 Mdot
.58322 .59733 Mdot
.61672 .49857 Mdot
.81002 .36139 Mdot
.50087 .61686 Mdot
.50278 .61428 Mdot
.50886 .60607 Mdot
.52821 .58006 Mdot
.58965 .50127 Mdot
.77857 .3561 Mdot
.20239 .49709 Mdot
.39808 .58525 Mdot
.45111 .01183 Mdot
.43197 .073 Mdot
.31386 .20882 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .01561 Mdot
.46318 .04945 Mdot
.38317 .14829 Mdot
.14323 .26386 Mdot
.7163 .11961 Mdot
.52276 .09858 Mdot
.36326 .21031 Mdot
.02297 .23153 Mdot
.5003 .61763 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50957 .6051 Mdot
.5305 .577 Mdot
.59689 .49263 Mdot
.79979 .35225 Mdot
.22984 .49861 Mdot
.42307 .56718 Mdot
.50536 .56221 Mdot
.59568 .47876 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48302 .02291 Mdot
.44595 .07206 Mdot
.32936 .20164 Mdot
.00311 .20452 Mdot
.67219 .07425 Mdot
.55205 .02686 Mdot
.50859 .0189 Mdot
.478 .03924 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49564 .00589 Mdot
.4861 .01876 Mdot
.45574 .05927 Mdot
.35985 .17304 Mdot
.07987 .24401 Mdot
.68505 .10858 Mdot
.50936 .09991 Mdot
.3477 .22052 Mdot
.99088 .21208 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48721 .01726 Mdot
.45928 .0546 Mdot
.37093 .16157 Mdot
.10951 .25527 Mdot
.69648 .11598 Mdot
.50882 .10781 Mdot
.33438 .2351 Mdot
.95397 .19303 Mdot
.64165 .07837 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51281 .60074 Mdot
.54079 .56334 Mdot
.62928 .45624 Mdot
.89106 .36296 Mdot
.30379 .50216 Mdot
.49128 .51023 Mdot
.66571 .3829 Mdot
.04615 .42509 Mdot
.35834 .53976 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60555 Mdot
.52945 .5784 Mdot
.59357 .49657 Mdot
.7901 .35368 Mdot
.21783 .49823 Mdot
.41168 .57596 Mdot
.47976 .59467 Mdot
.51756 .57843 Mdot
.58164 .50602 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60311 Mdot
.5352 .57074 Mdot
.61173 .47546 Mdot
.84242 .3521 Mdot
.27271 .49815 Mdot
.4667 .52879 Mdot
.61109 .43397 Mdot
.90892 .35406 Mdot
.33603 .48057 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00255 Mdot
.49399 .00811 Mdot
.48087 .0258 Mdot
.43912 .08088 Mdot
.30825 .21865 Mdot
.95446 .17701 Mdot
.50105 .61662 Mdot
.50334 .61352 Mdot
.51064 .60367 Mdot
.53389 .57249 Mdot
.60759 .48017 Mdot
.83065 .35117 Mdot
.26245 .49826 Mdot
.45624 .53832 Mdot
.58521 .46305 Mdot
.83599 .33652 Mdot
.29149 .47908 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49704 .004 Mdot
.49057 .01274 Mdot
.46995 .04043 Mdot
.40453 .12373 Mdot
.20433 .26524 Mdot
.77517 .11954 Mdot
.58175 .04703 Mdot
.50565 .0418 Mdot
.43802 .09782 Mdot
.27975 .24279 Mdot
.50102 .61665 Mdot
.50325 .61364 Mdot
.51036 .60404 Mdot
.53301 .57366 Mdot
.60481 .48336 Mdot
.82271 .35095 Mdot
.25486 .49843 Mdot
.44839 .54544 Mdot
.56584 .48613 Mdot
.77927 .34107 Mdot
.22741 .48713 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51087 .60335 Mdot
.53463 .5715 Mdot
.60991 .47752 Mdot
.83728 .35161 Mdot
.26837 .49817 Mdot
.46231 .53278 Mdot
.60025 .44587 Mdot
.87882 .34407 Mdot
.3221 .47674 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51224 .60151 Mdot
.53898 .56573 Mdot
.62361 .46232 Mdot
.87556 .35836 Mdot
.29573 .49985 Mdot
.48695 .51194 Mdot
.65861 .38806 Mdot
.03072 .41636 Mdot
.35703 .53178 Mdot
.50007 .61794 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.52309 .58691 Mdot
.57346 .5212 Mdot
.73014 .3748 Mdot
.1237 .47828 Mdot
.34983 .59773 Mdot
.38268 .07887 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.50492 .61139 Mdot
.51566 .5969 Mdot
.54986 .55143 Mdot
.65763 .42804 Mdot
.96505 .3959 Mdot
.32447 .52758 Mdot
.47082 .55448 Mdot
.57365 .48861 Mdot
.78306 .34424 Mdot
.50046 .61742 Mdot
.50145 .61607 Mdot
.50463 .61178 Mdot
.51474 .59814 Mdot
.54692 .55527 Mdot
.64848 .43673 Mdot
.94183 .384 Mdot
.3205 .5173 Mdot
.48349 .53258 Mdot
.62175 .4304 Mdot
.92534 .3637 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49574 .00576 Mdot
.48642 .01833 Mdot
.45677 .05792 Mdot
.36305 .16978 Mdot
.08834 .24754 Mdot
.68782 .11111 Mdot
.50804 .10366 Mdot
.34032 .22808 Mdot
.97128 .2016 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.49229 .01042 Mdot
.47543 .03311 Mdot
.42186 .10267 Mdot
.25573 .25012 Mdot
.85103 .13132 Mdot
.63855 .01849 Mdot
.60863 .54346 Mdot
.72929 .39716 Mdot
.08666 .47359 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61095 Mdot
.51671 .59548 Mdot
.5532 .54708 Mdot
.668 .41869 Mdot
.99054 .40993 Mdot
.32726 .54042 Mdot
.45284 .58351 Mdot
.5087 .57544 Mdot
.57762 .5063 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50972 .6049 Mdot
.53098 .57637 Mdot
.5984 .49085 Mdot
.80419 .35177 Mdot
.23501 .49866 Mdot
.42816 .56303 Mdot
.51716 .54715 Mdot
.63185 .43843 Mdot
.92245 .36935 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.4871 .01742 Mdot
.45891 .05509 Mdot
.36977 .1628 Mdot
.10635 .25422 Mdot
.69502 .11539 Mdot
.50832 .10768 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07805 Mdot
.50114 .61649 Mdot
.50365 .61311 Mdot
.51162 .60234 Mdot
.53701 .56834 Mdot
.61742 .46909 Mdot
.85841 .35448 Mdot
.28486 .4985 Mdot
.47828 .51857 Mdot
.63921 .40536 Mdot
.98333 .38993 Mdot
.35241 .50797 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50984 .60474 Mdot
.53135 .57586 Mdot
.59959 .48945 Mdot
.80765 .35147 Mdot
.23895 .49866 Mdot
.4321 .55972 Mdot
.52645 .53532 Mdot
.66028 .4106 Mdot
.99591 .40681 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .0139 Mdot
.46721 .04409 Mdot
.39586 .13389 Mdot
.17923 .26708 Mdot
.74707 .11956 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00332 Mdot
.49218 .01057 Mdot
.47508 .03357 Mdot
.42076 .10404 Mdot
.25242 .25157 Mdot
.84538 .12973 Mdot
.63547 .01877 Mdot
.60509 .5463 Mdot
.72116 .40118 Mdot
.50034 .61757 Mdot
.5011 .61655 Mdot
.5035 .61331 Mdot
.51114 .60299 Mdot
.53549 .57036 Mdot
.61262 .47446 Mdot
.84493 .35239 Mdot
.27475 .49815 Mdot
.46872 .52697 Mdot
.61607 .42865 Mdot
.9225 .35961 Mdot
.50007 .61793 Mdot
.50024 .61772 Mdot
.50075 .61702 Mdot
.5024 .6148 Mdot
.50764 .60772 Mdot
.52432 .58526 Mdot
.57735 .51634 Mdot
.7419 .36899 Mdot
.14487 .48549 Mdot
.35932 .59958 Mdot
.38919 .07617 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49756 .0033 Mdot
.49222 .01051 Mdot
.47521 .0334 Mdot
.42117 .10352 Mdot
.25367 .25103 Mdot
.84749 .13031 Mdot
.63664 .01864 Mdot
.60649 .54515 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00245 Mdot
.49423 .00779 Mdot
.48163 .02478 Mdot
.44153 .07777 Mdot
.31569 .21293 Mdot
.97117 .18634 Mdot
.66966 .0572 Mdot
.5771 .60653 Mdot
.59572 .52304 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.50771 .60763 Mdot
.52455 .58496 Mdot
.57806 .51546 Mdot
.74404 .36801 Mdot
.14858 .4866 Mdot
.36124 .59955 Mdot
.39115 .07474 Mdot
.27021 .2211 Mdot
.91247 .14398 Mdot
.50031 .61761 Mdot
.50099 .6167 Mdot
.50315 .61377 Mdot
.51004 .60447 Mdot
.53199 .57501 Mdot
.60161 .48708 Mdot
.81349 .35112 Mdot
.24536 .49861 Mdot
.4386 .55412 Mdot
.54201 .51563 Mdot
.7077 .37327 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60083 Mdot
.54059 .56361 Mdot
.62865 .45691 Mdot
.88936 .3624 Mdot
.30298 .50185 Mdot
.49097 .51022 Mdot
.66542 .38302 Mdot
.04568 .42479 Mdot
.35836 .53944 Mdot
.5001 .6179 Mdot
.50032 .61761 Mdot
.501 .61668 Mdot
.5032 .61371 Mdot
.51019 .60427 Mdot
.53247 .57438 Mdot
.6031 .48535 Mdot
.81779 .35099 Mdot
.24988 .49853 Mdot
.44324 .55004 Mdot
.55326 .50159 Mdot
.50036 .61754 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51174 .60218 Mdot
.5374 .56782 Mdot
.61864 .46774 Mdot
.86182 .35514 Mdot
.28719 .49867 Mdot
.48032 .51687 Mdot
.644 .40086 Mdot
.99539 .39659 Mdot
.50062 .6172 Mdot
.50196 .61539 Mdot
.50624 .6096 Mdot
.51989 .59121 Mdot
.56329 .53407 Mdot
.69915 .39399 Mdot
.06165 .44973 Mdot
.33397 .57721 Mdot
.40003 .04587 Mdot
.32581 .177 Mdot
.03942 .21317 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .00491 Mdot
.48842 .01564 Mdot
.46312 .04952 Mdot
.38299 .14848 Mdot
.14274 .26377 Mdot
.71595 .11959 Mdot
.52245 .09885 Mdot
.3625 .21104 Mdot
.02103 .23048 Mdot
.6481 .11216 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60849 Mdot
.52251 .58769 Mdot
.57161 .52352 Mdot
.72453 .37786 Mdot
.11313 .47413 Mdot
.34597 .59565 Mdot
.38218 .07714 Mdot
.25737 .22452 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.49671 .00444 Mdot
.48952 .01416 Mdot
.46661 .04488 Mdot
.394 .13604 Mdot
.17388 .26703 Mdot
.74181 .11968 Mdot
.54817 .07571 Mdot
.42567 .14213 Mdot
.1957 .28117 Mdot
.74075 .13388 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.49619 .00514 Mdot
.48787 .01637 Mdot
.46138 .05182 Mdot
.37753 .15448 Mdot
.12757 .26048 Mdot
.7061 .11852 Mdot
.51433 .10525 Mdot
.34404 .22778 Mdot
.97549 .20514 Mdot
.64356 .08938 Mdot
.49991 .00011 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01184 Mdot
.47207 .03761 Mdot
.41122 .11571 Mdot
.22399 .26129 Mdot
.80121 .12132 Mdot
.60491 .03095 Mdot
.55483 .59915 Mdot
.58538 .52374 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49303 .00942 Mdot
.47778 .02995 Mdot
.42932 .09335 Mdot
.27828 .23857 Mdot
.89226 .14615 Mdot
.65579 .0237 Mdot
.61744 .54248 Mdot
.73968 .39525 Mdot
.10016 .48209 Mdot
.50105 .61661 Mdot
.50335 .6135 Mdot
.51069 .6036 Mdot
.53403 .5723 Mdot
.60804 .47966 Mdot
.83194 .35124 Mdot
.26363 .49824 Mdot
.45746 .53721 Mdot
.58823 .45955 Mdot
.84466 .33734 Mdot
.29883 .47799 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46025 .05332 Mdot
.37397 .15832 Mdot
.1178 .25783 Mdot
.70062 .11733 Mdot
.51079 .10734 Mdot
.33711 .23333 Mdot
.95959 .19626 Mdot
.5001 .6179 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50991 .60464 Mdot
.53158 .57556 Mdot
.6003 .48861 Mdot
.80971 .35133 Mdot
.24125 .49865 Mdot
.43441 .55775 Mdot
.53196 .52832 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49248 .01016 Mdot
.47603 .0323 Mdot
.42377 .1003 Mdot
.26147 .24747 Mdot
.86106 .13441 Mdot
.64358 .01864 Mdot
.61343 .5402 Mdot
.73936 .39298 Mdot
.1035 .48231 Mdot
.50123 .61637 Mdot
.50393 .61273 Mdot
.51252 .60113 Mdot
.53986 .56457 Mdot
.62638 .45934 Mdot
.88315 .36049 Mdot
.29987 .50085 Mdot
.48949 .51058 Mdot
.66335 .38437 Mdot
.04142 .42234 Mdot
.35806 .53716 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49006 .01343 Mdot
.46833 .04259 Mdot
.39941 .12976 Mdot
.18945 .26676 Mdot
.75783 .11939 Mdot
.56465 .06109 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49612 .00525 Mdot
.48762 .01671 Mdot
.46058 .05288 Mdot
.37502 .15719 Mdot
.12068 .25865 Mdot
.70217 .11772 Mdot
.51169 .10689 Mdot
.33874 .23209 Mdot
.96321 .19829 Mdot
.64238 .08321 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50838 .60671 Mdot
.52671 .58206 Mdot
.58491 .50703 Mdot
.76451 .3601 Mdot
.18186 .49433 Mdot
.38202 .59395 Mdot
.42098 .0462 Mdot
.34623 .16758 Mdot
.07508 .23463 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00599 Mdot
.48588 .01907 Mdot
.45502 .06021 Mdot
.3576 .1753 Mdot
.07397 .24143 Mdot
.68333 .10664 Mdot
.51079 .09665 Mdot
.35441 .21357 Mdot
.00885 .22177 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .6013 Mdot
.53947 .56508 Mdot
.62515 .46066 Mdot
.87979 .35951 Mdot
.29808 .50037 Mdot
.48846 .51106 Mdot
.66155 .38572 Mdot
.03743 .42011 Mdot
.35769 .53515 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50587 .6101 Mdot
.51871 .5928 Mdot
.55954 .53888 Mdot
.68762 .40252 Mdot
.03633 .43591 Mdot
.33102 .56475 Mdot
.41724 .02002 Mdot
.38484 .11771 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48961 .01402 Mdot
.46692 .04447 Mdot
.39497 .13492 Mdot
.17666 .26708 Mdot
.74452 .11962 Mdot
.55097 .07317 Mdot
.43258 .13382 Mdot
.21606 .27802 Mdot
.50013 .61786 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50419 .61238 Mdot
.51334 .60002 Mdot
.54249 .56109 Mdot
.63463 .45064 Mdot
.90548 .36808 Mdot
.30992 .50529 Mdot
.49235 .51238 Mdot
.6633 .38619 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45727 .05726 Mdot
.36462 .16817 Mdot
.09252 .24919 Mdot
.68933 .11223 Mdot
.50773 .10508 Mdot
.33771 .23078 Mdot
.9643 .19796 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.52589 .58315 Mdot
.58233 .51019 Mdot
.75683 .36278 Mdot
.16984 .492 Mdot
.37377 .59714 Mdot
.40758 .06005 Mdot
.31041 .19709 Mdot
.50091 .61681 Mdot
.50288 .61414 Mdot
.50919 .60562 Mdot
.52927 .57864 Mdot
.59302 .49723 Mdot
.78849 .35398 Mdot
.21574 .49812 Mdot
.40978 .57735 Mdot
.4756 .59988 Mdot
.50497 .59527 Mdot
.5418 .55697 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51108 .60307 Mdot
.5353 .57061 Mdot
.61202 .47513 Mdot
.84325 .35219 Mdot
.27339 .49815 Mdot
.46737 .52818 Mdot
.61276 .43218 Mdot
.91348 .35586 Mdot
.33768 .48157 Mdot
.5003 .61763 Mdot
.50094 .61676 Mdot
.503 .61398 Mdot
.50955 .60513 Mdot
.53043 .57709 Mdot
.59668 .49287 Mdot
.7992 .35232 Mdot
.22914 .4986 Mdot
.42239 .56773 Mdot
.50378 .56423 Mdot
.59083 .48452 Mdot
.50007 .61794 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50688 .60874 Mdot
.52193 .58848 Mdot
.56975 .52586 Mdot
.71889 .38113 Mdot
.10222 .4695 Mdot
.34254 .5928 Mdot
.38337 .07347 Mdot
.4998 .00027 Mdot
.49936 .00086 Mdot
.49797 .00275 Mdot
.49352 .00876 Mdot
.47935 .02784 Mdot
.4343 .08704 Mdot
.29347 .22911 Mdot
.92277 .16029 Mdot
.66342 .03404 Mdot
.60833 .55923 Mdot
.70349 .41794 Mdot
.02725 .44308 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50811 .60708 Mdot
.52584 .58323 Mdot
.58215 .51041 Mdot
.75629 .36298 Mdot
.16897 .49181 Mdot
.3732 .59732 Mdot
.40672 .06089 Mdot
.30819 .19869 Mdot
.98671 .18638 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50533 .61084 Mdot
.51697 .59514 Mdot
.55401 .54603 Mdot
.67052 .4165 Mdot
.9966 .41335 Mdot
.32778 .54362 Mdot
.44818 .59082 Mdot
.49221 .59804 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49685 .00425 Mdot
.48998 .01354 Mdot
.46807 .04294 Mdot
.3986 .13071 Mdot
.18712 .26688 Mdot
.75529 .11942 Mdot
.56207 .06333 Mdot
.4596 .10038 Mdot
.29718 .24149 Mdot
.90645 .15967 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45873 .05533 Mdot
.3692 .16339 Mdot
.10483 .2537 Mdot
.69434 .11508 Mdot
.50813 .10755 Mdot
.3341 .23497 Mdot
.95391 .19284 Mdot
.64189 .07805 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51088 .60334 Mdot
.53465 .57147 Mdot
.60999 .47743 Mdot
.83749 .35162 Mdot
.26855 .49817 Mdot
.4625 .53261 Mdot
.60071 .44536 Mdot
.8801 .34443 Mdot
.32281 .4768 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00334 Mdot
.49214 .01062 Mdot
.47495 .03375 Mdot
.42033 .10456 Mdot
.25115 .2521 Mdot
.84324 .12916 Mdot
.63425 .01895 Mdot
.60359 .54758 Mdot
.71759 .40309 Mdot
.06538 .46201 Mdot
.50024 .61771 Mdot
.50077 .61699 Mdot
.50245 .61472 Mdot
.50782 .60747 Mdot
.5249 .58448 Mdot
.57919 .51406 Mdot
.74743 .36653 Mdot
.15438 .48824 Mdot
.36439 .59928 Mdot
.39474 .07187 Mdot
.27845 .21706 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52554 .58363 Mdot
.58121 .51157 Mdot
.75348 .36406 Mdot
.16442 .49078 Mdot
.37032 .59813 Mdot
.40252 .06492 Mdot
.29748 .20595 Mdot
.96425 .17308 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60208 Mdot
.53763 .56752 Mdot
.61937 .46695 Mdot
.86383 .35556 Mdot
.28853 .4988 Mdot
.48145 .51596 Mdot
.64661 .39847 Mdot
.00188 .40021 Mdot
.35433 .51717 Mdot
.50058 .61725 Mdot
.50185 .61553 Mdot
.5059 .61007 Mdot
.51879 .59269 Mdot
.55979 .53856 Mdot
.68838 .40194 Mdot
.03803 .43686 Mdot
.33118 .56562 Mdot
.41598 .02191 Mdot
.38053 .12256 Mdot
.18222 .25692 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .61211 Mdot
.51398 .59916 Mdot
.54451 .55843 Mdot
.64095 .44419 Mdot
.92224 .37494 Mdot
.31559 .51013 Mdot
.49018 .51923 Mdot
.65005 .39984 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60037 Mdot
.54167 .56217 Mdot
.63206 .45332 Mdot
.89857 .36553 Mdot
.30714 .50367 Mdot
.49219 .51091 Mdot
.66552 .38366 Mdot
.04474 .4246 Mdot
.35773 .53961 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61426 Mdot
.50891 .606 Mdot
.52837 .57984 Mdot
.59017 .50065 Mdot
.7801 .35574 Mdot
.20451 .49729 Mdot
.39987 .58412 Mdot
.45475 .00747 Mdot
.44266 .05949 Mdot
.50069 .61711 Mdot
.50218 .61508 Mdot
.50696 .60864 Mdot
.52216 .58816 Mdot
.5705 .52492 Mdot
.72116 .37979 Mdot
.10664 .47142 Mdot
.34387 .59404 Mdot
.38269 .07517 Mdot
.26105 .22236 Mdot
.90126 .13659 Mdot
.50128 .61631 Mdot
.50408 .61253 Mdot
.51299 .6005 Mdot
.54136 .56259 Mdot
.63107 .45436 Mdot
.89591 .36459 Mdot
.30599 .5031 Mdot
.49195 .51056 Mdot
.66585 .38316 Mdot
.04589 .42512 Mdot
.35804 .53995 Mdot
.50028 .61765 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50922 .60559 Mdot
.52936 .57853 Mdot
.59328 .49691 Mdot
.78926 .35384 Mdot
.21674 .49817 Mdot
.41069 .57669 Mdot
.47758 .59741 Mdot
.51096 .58726 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01617 Mdot
.46187 .05118 Mdot
.37906 .15281 Mdot
.13181 .26151 Mdot
.70868 .11891 Mdot
.51629 .10383 Mdot
.34828 .22413 Mdot
.98563 .21083 Mdot
.64451 .09453 Mdot
.49993 .0001 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49272 .00984 Mdot
.4768 .03127 Mdot
.42621 .09725 Mdot
.26886 .24376 Mdot
.87445 .13907 Mdot
.64943 .02001 Mdot
.61705 .53906 Mdot
.74484 .39159 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49039 .01298 Mdot
.46938 .0412 Mdot
.40272 .12587 Mdot
.19907 .26592 Mdot
.7688 .1194 Mdot
.5756 .05192 Mdot
.49159 .05971 Mdot
.39498 .15016 Mdot
.5007 .61708 Mdot
.50225 .615 Mdot
.50716 .60837 Mdot
.5228 .58731 Mdot
.57252 .52238 Mdot
.72729 .37633 Mdot
.11837 .47623 Mdot
.34782 .59677 Mdot
.38222 .07823 Mdot
.25564 .22568 Mdot
.89047 .13197 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46942 .04115 Mdot
.40284 .12573 Mdot
.19941 .26588 Mdot
.76921 .11941 Mdot
.576 .0516 Mdot
.49252 .05853 Mdot
.39781 .14689 Mdot
.16014 .27154 Mdot
.5008 .61695 Mdot
.50256 .61457 Mdot
.50817 .607 Mdot
.52602 .58298 Mdot
.58274 .50968 Mdot
.75805 .36233 Mdot
.17179 .49242 Mdot
.37505 .59671 Mdot
.40954 .0581 Mdot
.31554 .19331 Mdot
.00276 .19587 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50976 .60485 Mdot
.53108 .57622 Mdot
.59874 .49045 Mdot
.80517 .35168 Mdot
.23614 .49867 Mdot
.42928 .56209 Mdot
.5198 .54378 Mdot
.63996 .43012 Mdot
.94401 .37928 Mdot
.50002 .61801 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50059 .61724 Mdot
.50186 .61551 Mdot
.50594 .61001 Mdot
.51893 .5925 Mdot
.56024 .53798 Mdot
.68977 .40088 Mdot
.04113 .43859 Mdot
.33148 .56721 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49574 .00575 Mdot
.48643 .01832 Mdot
.45679 .05788 Mdot
.36314 .16969 Mdot
.08859 .24763 Mdot
.68791 .11118 Mdot
.50802 .10375 Mdot
.34015 .22825 Mdot
.97083 .20136 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49782 .00295 Mdot
.49304 .0094 Mdot
.47784 .02987 Mdot
.42951 .09311 Mdot
.27886 .23823 Mdot
.89339 .14662 Mdot
.65614 .024 Mdot
.61731 .54287 Mdot
.73893 .39568 Mdot
.0987 .48143 Mdot
.50062 .61719 Mdot
.50199 .61535 Mdot
.50633 .60949 Mdot
.52016 .59085 Mdot
.56415 .53297 Mdot
.70179 .39214 Mdot
.06729 .45268 Mdot
.33484 .57976 Mdot
.39677 .05085 Mdot
.31448 .18645 Mdot
.01279 .1983 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00425 Mdot
.48999 .01352 Mdot
.46811 .04289 Mdot
.3987 .13059 Mdot
.1874 .26687 Mdot
.7556 .11942 Mdot
.56238 .06305 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00228 Mdot
.49463 .00725 Mdot
.4829 .02307 Mdot
.44558 .07255 Mdot
.32819 .20264 Mdot
.00032 .20293 Mdot
.67197 .07277 Mdot
.55422 .02348 Mdot
.51623 .00845 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48746 .01694 Mdot
.46005 .05358 Mdot
.37335 .15899 Mdot
.1161 .25732 Mdot
.69974 .11708 Mdot
.5103 .10753 Mdot
.33632 .2339 Mdot
.95785 .19529 Mdot
.64187 .0805 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46949 .04105 Mdot
.40307 .12546 Mdot
.20007 .2658 Mdot
.76999 .11942 Mdot
.57677 .05098 Mdot
.49428 .05629 Mdot
.4032 .14059 Mdot
.17571 .27236 Mdot
.50051 .61735 Mdot
.50161 .61586 Mdot
.50513 .61111 Mdot
.51633 .59599 Mdot
.552 .54864 Mdot
.66427 .42199 Mdot
.98147 .40486 Mdot
.3264 .53572 Mdot
.45959 .57279 Mdot
.5328 .5426 Mdot
.65485 .42065 Mdot
.5 0 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00647 Mdot
.48475 .02058 Mdot
.45145 .0649 Mdot
.34643 .18618 Mdot
.04519 .22751 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49843 .00212 Mdot
.49501 .00674 Mdot
.48411 .02145 Mdot
.44941 .06756 Mdot
.3401 .19209 Mdot
.02929 .21909 Mdot
.6748 .08771 Mdot
.53288 .05745 Mdot
.43992 .11184 Mdot
.25895 .25915 Mdot
.50025 .6177 Mdot
.50078 .61697 Mdot
.5025 .61466 Mdot
.50796 .60729 Mdot
.52535 .58389 Mdot
.5806 .51232 Mdot
.75165 .36478 Mdot
.16142 .49006 Mdot
.36849 .59857 Mdot
.39998 .06727 Mdot
.29114 .20992 Mdot
.50054 .6173 Mdot
.50172 .6157 Mdot
.50549 .61061 Mdot
.5175 .59442 Mdot
.55571 .54382 Mdot
.67578 .41203 Mdot
.0091 .42046 Mdot
.32877 .5503 Mdot
.43837 .60602 Mdot
.45781 .02664 Mdot
.4147 .10199 Mdot
.50105 .61662 Mdot
.50333 .61353 Mdot
.51061 .6037 Mdot
.5338 .57261 Mdot
.6073 .4805 Mdot
.82984 .35113 Mdot
.2617 .49828 Mdot
.45547 .53902 Mdot
.58331 .46527 Mdot
.83048 .33619 Mdot
.28651 .47987 Mdot
.50015 .61783 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50481 .61153 Mdot
.51533 .59735 Mdot
.5488 .55281 Mdot
.65433 .43113 Mdot
.95675 .39153 Mdot
.32325 .52372 Mdot
.47585 .54602 Mdot
.59237 .46511 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50296 .61403 Mdot
.50944 .60528 Mdot
.53007 .57757 Mdot
.59555 .49421 Mdot
.7959 .35276 Mdot
.22512 .49851 Mdot
.41852 .57079 Mdot
.49496 .57546 Mdot
.56384 .51786 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.49659 .0046 Mdot
.48915 .01466 Mdot
.46543 .04645 Mdot
.39028 .1403 Mdot
.16327 .26647 Mdot
.7321 .11986 Mdot
.53817 .08481 Mdot
.40094 .17084 Mdot
.12452 .27485 Mdot
.6798 .14142 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50913 .6057 Mdot
.52908 .57889 Mdot
.59242 .49794 Mdot
.78674 .35431 Mdot
.21345 .49798 Mdot
.4077 .57883 Mdot
.47113 .60545 Mdot
.49149 .61333 Mdot
.4991 .61416 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49697 .0041 Mdot
.49034 .01304 Mdot
.46924 .04139 Mdot
.40227 .1264 Mdot
.19776 .26606 Mdot
.76725 .11939 Mdot
.57408 .05316 Mdot
.48807 .06421 Mdot
.38417 .16236 Mdot
.12146 .26435 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49765 .00317 Mdot
.49253 .01009 Mdot
.47619 .03208 Mdot
.42428 .09966 Mdot
.26303 .24671 Mdot
.86385 .13533 Mdot
.64488 .01882 Mdot
.61443 .53967 Mdot
.74122 .39235 Mdot
.10638 .48379 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49857 .00193 Mdot
.49544 .00615 Mdot
.48549 .01959 Mdot
.45379 .06183 Mdot
.35374 .17913 Mdot
.0639 .23679 Mdot
.68077 .10299 Mdot
.51413 .0899 Mdot
.36866 .19831 Mdot
.04779 .24195 Mdot
.50052 .61733 Mdot
.50166 .6158 Mdot
.50528 .6109 Mdot
.51682 .59534 Mdot
.55354 .54664 Mdot
.66905 .41777 Mdot
.99309 .41136 Mdot
.32749 .54176 Mdot
.45089 .58657 Mdot
.5018 .5849 Mdot
.55542 .53455 Mdot
.49986 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49563 .00591 Mdot
.48606 .01881 Mdot
.45563 .05942 Mdot
.35949 .17341 Mdot
.07891 .2436 Mdot
.68476 .10828 Mdot
.50956 .09942 Mdot
.3487 .21949 Mdot
.99356 .21352 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .0051 Mdot
.48796 .01625 Mdot
.46167 .05145 Mdot
.37842 .15351 Mdot
.13004 .26109 Mdot
.70759 .11875 Mdot
.51544 .10446 Mdot
.34641 .22575 Mdot
.98114 .20831 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50871 .60626 Mdot
.52776 .58066 Mdot
.58823 .50299 Mdot
.77438 .35717 Mdot
.19647 .49645 Mdot
.3932 .58819 Mdot
.44148 .0232 Mdot
.40394 .10694 Mdot
.23091 .25343 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46026 .05331 Mdot
.37401 .15828 Mdot
.11791 .25786 Mdot
.70068 .11734 Mdot
.51082 .10732 Mdot
.33717 .23328 Mdot
.95971 .19633 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49659 .00461 Mdot
.48913 .01468 Mdot
.46537 .04653 Mdot
.39009 .14052 Mdot
.16273 .26643 Mdot
.73164 .11986 Mdot
.53769 .08525 Mdot
.39975 .17216 Mdot
.12119 .27396 Mdot
.67791 .1413 Mdot
.50033 .61759 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51067 .60363 Mdot
.53397 .57238 Mdot
.60785 .47988 Mdot
.83139 .35121 Mdot
.26312 .49825 Mdot
.45694 .53769 Mdot
.58694 .46103 Mdot
.84097 .33694 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00598 Mdot
.48589 .01905 Mdot
.45506 .06016 Mdot
.35772 .17518 Mdot
.07428 .24157 Mdot
.68342 .10675 Mdot
.5107 .09683 Mdot
.35402 .21397 Mdot
.0078 .2212 Mdot
.50111 .61654 Mdot
.50352 .61328 Mdot
.51122 .60288 Mdot
.53574 .57003 Mdot
.61342 .47356 Mdot
.84718 .35268 Mdot
.27654 .49817 Mdot
.47048 .52539 Mdot
.62038 .42413 Mdot
.93413 .36479 Mdot
.34388 .4874 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48822 .01591 Mdot
.46248 .05037 Mdot
.38098 .1507 Mdot
.13714 .26268 Mdot
.71212 .1193 Mdot
.51909 .10164 Mdot
.35463 .21843 Mdot
.0012 .21955 Mdot
.64597 .10242 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49465 .00723 Mdot
.48296 .023 Mdot
.44574 .07233 Mdot
.32871 .2022 Mdot
.00155 .20363 Mdot
.67206 .07343 Mdot
.55326 .02497 Mdot
.50038 .61752 Mdot
.50122 .61638 Mdot
.5039 .61277 Mdot
.51242 .60127 Mdot
.53955 .56498 Mdot
.62539 .46039 Mdot
.88046 .3597 Mdot
.29845 .50046 Mdot
.48868 .51095 Mdot
.66194 .38542 Mdot
.03832 .4206 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49304 .00941 Mdot
.47781 .02991 Mdot
.42942 .09321 Mdot
.2786 .23838 Mdot
.89289 .14641 Mdot
.65599 .02387 Mdot
.61737 .5427 Mdot
.73927 .39549 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60904 Mdot
.52122 .58942 Mdot
.56751 .5287 Mdot
.71206 .38533 Mdot
.08859 .46328 Mdot
.33899 .58835 Mdot
.38702 .06648 Mdot
.27945 .21151 Mdot
.93723 .15481 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51043 .60395 Mdot
.53322 .57338 Mdot
.60547 .4826 Mdot
.82461 .35097 Mdot
.25672 .49839 Mdot
.45032 .5437 Mdot
.57059 .48039 Mdot
.79331 .33827 Mdot
.24597 .48577 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51186 .60202 Mdot
.53776 .56734 Mdot
.61979 .46648 Mdot
.86501 .35581 Mdot
.28929 .49888 Mdot
.48209 .51545 Mdot
.64806 .39715 Mdot
.00546 .40221 Mdot
.35467 .51898 Mdot
.50006 .61795 Mdot
.50021 .61776 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60903 Mdot
.52122 .58942 Mdot
.56752 .52868 Mdot
.7121 .3853 Mdot
.08867 .46332 Mdot
.33901 .58838 Mdot
.38699 .06653 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00352 Mdot
.4917 .01122 Mdot
.47355 .03562 Mdot
.41591 .11 Mdot
.23793 .25712 Mdot
.82189 .12438 Mdot
.62065 .02294 Mdot
.58354 .56704 Mdot
.66605 .43954 Mdot
.95486 .39825 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48092 .02573 Mdot
.43929 .08066 Mdot
.30878 .21825 Mdot
.95564 .17766 Mdot
.66818 .04919 Mdot
.58859 .58927 Mdot
.63514 .4785 Mdot
.86091 .36536 Mdot
.50091 .6168 Mdot
.50291 .61411 Mdot
.50926 .60553 Mdot
.52949 .57835 Mdot
.5937 .49642 Mdot
.79047 .35362 Mdot
.21831 .49825 Mdot
.41212 .57564 Mdot
.48072 .59347 Mdot
.52047 .57454 Mdot
.59084 .49483 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51586 .59663 Mdot
.5505 .55059 Mdot
.65963 .42619 Mdot
.97004 .39858 Mdot
.32512 .52999 Mdot
.46757 .55985 Mdot
.56172 .50405 Mdot
.74615 .35655 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01634 Mdot
.46147 .05171 Mdot
.37781 .15418 Mdot
.12833 .26067 Mdot
.70655 .11859 Mdot
.51467 .10501 Mdot
.34475 .22718 Mdot
.97717 .20608 Mdot
.64372 .09023 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01616 Mdot
.46188 .05116 Mdot
.37911 .15276 Mdot
.13194 .26154 Mdot
.70876 .11892 Mdot
.51635 .10379 Mdot
.34842 .22401 Mdot
.98596 .21101 Mdot
.64454 .09469 Mdot
.50004 .61799 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50365 .61311 Mdot
.51162 .60235 Mdot
.537 .56836 Mdot
.61738 .46914 Mdot
.85829 .35445 Mdot
.28478 .49849 Mdot
.4782 .51863 Mdot
.5013 .61628 Mdot
.50413 .61246 Mdot
.51315 .60028 Mdot
.54189 .56189 Mdot
.63273 .45262 Mdot
.90038 .36618 Mdot
.30789 .50407 Mdot
.49229 .51121 Mdot
.66513 .38416 Mdot
.04355 .42403 Mdot
.35746 .5392 Mdot
.50056 .61727 Mdot
.5018 .6156 Mdot
.50573 .61029 Mdot
.51825 .59341 Mdot
.55809 .54074 Mdot
.68315 .40602 Mdot
.02619 .43019 Mdot
.33012 .55943 Mdot
.42494 .00844 Mdot
.41129 .08649 Mdot
.27135 .23271 Mdot
.50052 .61733 Mdot
.50165 .6158 Mdot
.50526 .61092 Mdot
.51677 .59541 Mdot
.55338 .54684 Mdot
.66857 .41819 Mdot
.99192 .41071 Mdot
.32739 .54115 Mdot
.45178 .58517 Mdot
.50496 .58058 Mdot
.56557 .5215 Mdot
.5005 .61736 Mdot
.5016 .61587 Mdot
.5051 .61115 Mdot
.51624 .59611 Mdot
.55171 .54901 Mdot
.66339 .42279 Mdot
.9793 .40365 Mdot
.32618 .53462 Mdot
.46115 .57028 Mdot
.53843 .535 Mdot
.67278 .40448 Mdot
.50036 .61755 Mdot
.50114 .6165 Mdot
.50362 .61315 Mdot
.51152 .60247 Mdot
.5367 .56875 Mdot
.61644 .47018 Mdot
.85568 .35398 Mdot
.28293 .49838 Mdot
.47653 .52006 Mdot
.63506 .40935 Mdot
.97271 .38418 Mdot
.50031 .61762 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51003 .60449 Mdot
.53194 .57508 Mdot
.60144 .48728 Mdot
.81301 .35115 Mdot
.24484 .49861 Mdot
.43807 .55459 Mdot
.54072 .51725 Mdot
.70379 .37588 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01558 Mdot
.46325 .04934 Mdot
.38342 .14801 Mdot
.14392 .26398 Mdot
.71679 .11964 Mdot
.52321 .0982 Mdot
.36433 .20928 Mdot
.0257 .23301 Mdot
.64869 .11436 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49607 .0053 Mdot
.48749 .01689 Mdot
.46017 .05343 Mdot
.37371 .1586 Mdot
.11709 .25762 Mdot
.70025 .11722 Mdot
.51058 .10742 Mdot
.33677 .23358 Mdot
.95883 .19584 Mdot
.50058 .61726 Mdot
.50184 .61555 Mdot
.50585 .61013 Mdot
.51863 .5929 Mdot
.55931 .53918 Mdot
.6869 .40308 Mdot
.0347 .43499 Mdot
.33086 .5639 Mdot
.41845 .0182 Mdot
.389 .11296 Mdot
.20623 .25496 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50147 .61604 Mdot
.5047 .61169 Mdot
.51497 .59783 Mdot
.54765 .55431 Mdot
.65076 .43453 Mdot
.94767 .38689 Mdot
.32167 .51973 Mdot
.48073 .53755 Mdot
.61097 .44281 Mdot
.50024 .61771 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50778 .60752 Mdot
.52479 .58463 Mdot
.57885 .51449 Mdot
.74639 .36698 Mdot
.1526 .48775 Mdot
.36341 .59939 Mdot
.39357 .07284 Mdot
.27571 .21846 Mdot
.50055 .61728 Mdot
.50177 .61565 Mdot
.50563 .61043 Mdot
.51794 .59383 Mdot
.55709 .54203 Mdot
.68006 .40851 Mdot
.01909 .42616 Mdot
.32955 .55565 Mdot
.43048 4e-05 Mdot
.43042 .0625 Mdot
.32929 .19211 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49458 .00732 Mdot
.48274 .02329 Mdot
.44504 .07324 Mdot
.32655 .20404 Mdot
.9964 .20071 Mdot
.67165 .07068 Mdot
.55729 .01871 Mdot
.52702 .61181 Mdot
.53709 .57773 Mdot
.50081 .61693 Mdot
.50259 .61453 Mdot
.50827 .60687 Mdot
.52634 .58256 Mdot
.58373 .50847 Mdot
.76101 .36128 Mdot
.17645 .49335 Mdot
.3782 .59556 Mdot
.41456 .05298 Mdot
.32884 .18279 Mdot
.03308 .21323 Mdot
.50054 .61731 Mdot
.50172 .61572 Mdot
.50547 .61065 Mdot
.51742 .59453 Mdot
.55544 .54417 Mdot
.67497 .41272 Mdot
.00718 .41937 Mdot
.32863 .54927 Mdot
.43989 .60368 Mdot
.46311 .01954 Mdot
.43149 .08111 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50723 .60827 Mdot
.52302 .58701 Mdot
.57322 .5215 Mdot
.72942 .37519 Mdot
.12236 .47777 Mdot
.34931 .59751 Mdot
.38252 .07876 Mdot
.25509 .22623 Mdot
.88905 .1315 Mdot
.50073 .61705 Mdot
.50232 .61491 Mdot
.50738 .60807 Mdot
.52351 .58636 Mdot
.57476 .51957 Mdot
.73408 .37276 Mdot
.13095 .48091 Mdot
.35281 .59873 Mdot
.38405 .07893 Mdot
.25633 .22636 Mdot
.89008 .13236 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50993 .60462 Mdot
.53163 .57549 Mdot
.60048 .4884 Mdot
.81022 .3513 Mdot
.24181 .49865 Mdot
.43498 .55726 Mdot
.53332 .52659 Mdot
.68128 .39259 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49363 .0086 Mdot
.47971 .02736 Mdot
.43544 .08558 Mdot
.29697 .22675 Mdot
.93009 .164 Mdot
.66473 .03713 Mdot
.60466 .56498 Mdot
.6905 .42763 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51142 .60261 Mdot
.53638 .56918 Mdot
.61542 .47131 Mdot
.85283 .3535 Mdot
.28084 .49829 Mdot
.4746 .52174 Mdot
.63041 .41392 Mdot
.96067 .37783 Mdot
.34933 .49756 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48895 .01493 Mdot
.46479 .0473 Mdot
.38826 .14259 Mdot
.15755 .26593 Mdot
.72726 .11989 Mdot
.53328 .08926 Mdot
.38885 .18413 Mdot
.09093 .26391 Mdot
.66391 .13743 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50176 .61565 Mdot
.50561 .61045 Mdot
.51789 .5939 Mdot
.55693 .54224 Mdot
.67957 .40891 Mdot
.01795 .42551 Mdot
.32946 .55505 Mdot
.43137 .61671 Mdot
.43351 .05854 Mdot
.49989 .00015 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .00471 Mdot
.4889 .01499 Mdot
.46464 .0475 Mdot
.38779 .14311 Mdot
.15623 .26578 Mdot
.72619 .11989 Mdot
.53221 .09023 Mdot
.38621 .18696 Mdot
.0837 .26103 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49238 .01029 Mdot
.47573 .0327 Mdot
.42282 .10147 Mdot
.25863 .2488 Mdot
.85606 .13283 Mdot
.64115 .01847 Mdot
.61127 .54155 Mdot
.73502 .39466 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48925 .01452 Mdot
.46575 .04603 Mdot
.39126 .13918 Mdot
.16607 .26668 Mdot
.73458 .11982 Mdot
.5407 .08251 Mdot
.4072 .16375 Mdot
.14225 .27875 Mdot
.69123 .14115 Mdot
.50093 .61677 Mdot
.50298 .61401 Mdot
.50949 .60522 Mdot
.53022 .57738 Mdot
.59601 .49367 Mdot
.79723 .35258 Mdot
.22674 .49855 Mdot
.42008 .56957 Mdot
.4985 .57096 Mdot
.57466 .50426 Mdot
.75875 .35694 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61168 Mdot
.51499 .5978 Mdot
.54774 .5542 Mdot
.65103 .43427 Mdot
.94836 .38724 Mdot
.3218 .52002 Mdot
.48039 .53815 Mdot
.60964 .44437 Mdot
.89064 .35077 Mdot
.50059 .61724 Mdot
.50187 .6155 Mdot
.50596 .60998 Mdot
.519 .5924 Mdot
.56048 .53768 Mdot
.69049 .40033 Mdot
.04275 .43949 Mdot
.33165 .56804 Mdot
.41255 .02706 Mdot
.36877 .13539 Mdot
.14971 .2546 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49068 .01258 Mdot
.47032 .03994 Mdot
.40569 .12234 Mdot
.20775 .26471 Mdot
.77943 .11968 Mdot
.58577 .04396 Mdot
.51464 .03041 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00302 Mdot
.49289 .00961 Mdot
.47734 .03055 Mdot
.42791 .09512 Mdot
.274 .24099 Mdot
.88407 .14277 Mdot
.65306 .02176 Mdot
.61785 .54025 Mdot
.7437 .39283 Mdot
.1081 .48551 Mdot
.50027 .61766 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.50889 .60603 Mdot
.52832 .57991 Mdot
.59001 .50084 Mdot
.77963 .35585 Mdot
.20386 .49723 Mdot
.39931 .58447 Mdot
.45362 .00883 Mdot
.43933 .06373 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48865 .01533 Mdot
.46384 .04856 Mdot
.38526 .14595 Mdot
.14911 .26483 Mdot
.7206 .1198 Mdot
.52677 .0951 Mdot
.3729 .2008 Mdot
.048 .24462 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50669 .609 Mdot
.5213 .58931 Mdot
.56778 .52836 Mdot
.71287 .38481 Mdot
.09023 .46405 Mdot
.33938 .58894 Mdot
.38646 .06745 Mdot
.27732 .21283 Mdot
.93295 .15249 Mdot
.50048 .61739 Mdot
.50153 .61597 Mdot
.50487 .61146 Mdot
.5155 .59711 Mdot
.54935 .55209 Mdot
.65604 .42952 Mdot
.96106 .39378 Mdot
.32391 .5257 Mdot
.4733 .55034 Mdot
.58283 .47697 Mdot
.81108 .34016 Mdot
.49959 .00055 Mdot
.49871 .00174 Mdot
.49589 .00556 Mdot
.48689 .01769 Mdot
.45827 .05594 Mdot
.36775 .16491 Mdot
.10091 .25232 Mdot
.69265 .11425 Mdot
.50778 .10704 Mdot
.33458 .23424 Mdot
.95557 .19358 Mdot
.64234 .07853 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50426 .61228 Mdot
.51357 .59971 Mdot
.54322 .56013 Mdot
.63691 .44829 Mdot
.91155 .37046 Mdot
.31214 .5069 Mdot
.49197 .51434 Mdot
.65975 .38988 Mdot
.02891 .41654 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.49571 .0058 Mdot
.48632 .01847 Mdot
.45643 .05836 Mdot
.36199 .17086 Mdot
.08554 .24639 Mdot
.68686 .11031 Mdot
.50838 .10254 Mdot
.34246 .22589 Mdot
.50099 .6167 Mdot
.50315 .61377 Mdot
.51005 .60446 Mdot
.53201 .57498 Mdot
.60168 .487 Mdot
.81369 .35112 Mdot
.24557 .4986 Mdot
.43882 .55394 Mdot
.54253 .51498 Mdot
.70928 .37223 Mdot
.107 .46412 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48369 .02201 Mdot
.44807 .0693 Mdot
.33595 .19585 Mdot
.01906 .21347 Mdot
.67365 .08258 Mdot
.54003 .04586 Mdot
.46582 .07731 Mdot
.34073 .20153 Mdot
.50103 .61664 Mdot
.50329 .61359 Mdot
.51049 .60387 Mdot
.53341 .57313 Mdot
.60606 .48192 Mdot
.8263 .35101 Mdot
.25836 .49835 Mdot
.45201 .54217 Mdot
.57476 .47538 Mdot
.80559 .33674 Mdot
.26073 .48395 Mdot
.50047 .6174 Mdot
.50148 .61603 Mdot
.50473 .61165 Mdot
.51506 .59771 Mdot
.54795 .55392 Mdot
.65169 .43364 Mdot
.95005 .38809 Mdot
.32211 .52075 Mdot
.47952 .53967 Mdot
.60631 .44829 Mdot
.88097 .34794 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00276 Mdot
.49348 .00881 Mdot
.47923 .02801 Mdot
.43391 .08753 Mdot
.29229 .2299 Mdot
.9203 .15906 Mdot
.66293 .03305 Mdot
.60945 .55743 Mdot
.70751 .41511 Mdot
.03585 .44806 Mdot
.50102 .61666 Mdot
.50324 .61365 Mdot
.51033 .60408 Mdot
.53291 .57379 Mdot
.60451 .48372 Mdot
.82183 .35095 Mdot
.25399 .49845 Mdot
.44748 .54625 Mdot
.56363 .48882 Mdot
.7727 .34278 Mdot
.21807 .48736 Mdot
.50123 .61637 Mdot
.50393 .61272 Mdot
.51252 .60113 Mdot
.53987 .56455 Mdot
.6264 .45931 Mdot
.88323 .36051 Mdot
.29991 .50086 Mdot
.48951 .51058 Mdot
.66338 .38435 Mdot
.04149 .42238 Mdot
.35807 .5372 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60802 Mdot
.52363 .58619 Mdot
.57515 .51909 Mdot
.73525 .37217 Mdot
.13306 .48165 Mdot
.35373 .59895 Mdot
.38461 .07876 Mdot
.25717 .22616 Mdot
.50051 .61735 Mdot
.50162 .61584 Mdot
.50517 .61105 Mdot
.51648 .5958 Mdot
.55246 .54805 Mdot
.6657 .42072 Mdot
.98496 .4068 Mdot
.32675 .53752 Mdot
.45703 .57687 Mdot
.52363 .55505 Mdot
.62554 .45037 Mdot
.50004 .61799 Mdot
.50011 .61788 Mdot
.50036 .61754 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51175 .60217 Mdot
.53742 .5678 Mdot
.6187 .46768 Mdot
.86198 .35517 Mdot
.2873 .49868 Mdot
.48041 .5168 Mdot
.50014 .61784 Mdot
.50046 .61742 Mdot
.50146 .61607 Mdot
.50464 .61176 Mdot
.51479 .59807 Mdot
.54709 .55505 Mdot
.64901 .43622 Mdot
.94319 .38467 Mdot
.32079 .51786 Mdot
.48287 .53371 Mdot
.61932 .43316 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .00509 Mdot
.48799 .01621 Mdot
.46177 .05131 Mdot
.37874 .15316 Mdot
.13092 .2613 Mdot
.70813 .11883 Mdot
.51585 .10416 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50914 .60569 Mdot
.52911 .57885 Mdot
.5925 .49785 Mdot
.78697 .35427 Mdot
.21376 .498 Mdot
.40797 .57864 Mdot
.47172 .60472 Mdot
.49326 .61096 Mdot
.50471 .6066 Mdot
.5009 .61682 Mdot
.50286 .61417 Mdot
.50911 .60573 Mdot
.52902 .57897 Mdot
.59222 .49818 Mdot
.78614 .35443 Mdot
.21266 .49793 Mdot
.40699 .57933 Mdot
.46962 .60732 Mdot
.48696 .00136 Mdot
.48476 .01547 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50895 .60595 Mdot
.5285 .57967 Mdot
.59057 .50017 Mdot
.78127 .35547 Mdot
.20612 .49744 Mdot
.40124 .58323 Mdot
.45757 .00407 Mdot
.45099 .04879 Mdot
.37204 .15504 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48709 .01743 Mdot
.4589 .05511 Mdot
.36973 .16283 Mdot
.10627 .25419 Mdot
.69498 .11537 Mdot
.50831 .10767 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07804 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50892 .60599 Mdot
.52841 .57979 Mdot
.59028 .50051 Mdot
.78044 .35566 Mdot
.20497 .49734 Mdot
.40026 .58386 Mdot
.45555 .0065 Mdot
.44504 .05644 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49776 .00303 Mdot
.49287 .00964 Mdot
.47727 .03063 Mdot
.42771 .09537 Mdot
.2734 .24132 Mdot
.88294 .14232 Mdot
.65266 .02152 Mdot
.61783 .54003 Mdot
.74404 .39259 Mdot
.10881 .48579 Mdot
.49997 4e-05 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46947 .04107 Mdot
.40302 .12552 Mdot
.19993 .26582 Mdot
.76982 .11942 Mdot
.5766 .05112 Mdot
.49389 .05678 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49807 .0026 Mdot
.49386 .00829 Mdot
.48044 .02638 Mdot
.43775 .08263 Mdot
.30405 .22175 Mdot
.94524 .17199 Mdot
.66696 .04407 Mdot
.59566 .57867 Mdot
.65936 .45441 Mdot
.9241 .38669 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51139 .60266 Mdot
.53627 .56933 Mdot
.61508 .4717 Mdot
.85186 .35335 Mdot
.28012 .49826 Mdot
.47392 .52233 Mdot
.62877 .41556 Mdot
.95639 .37563 Mdot
.34861 .49575 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00317 Mdot
.49252 .01011 Mdot
.47617 .03212 Mdot
.4242 .09976 Mdot
.26278 .24683 Mdot
.86341 .13518 Mdot
.64468 .01878 Mdot
.61428 .53975 Mdot
.74095 .39244 Mdot
.10597 .48358 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50825 .60689 Mdot
.52628 .58264 Mdot
.58355 .5087 Mdot
.76046 .36147 Mdot
.17559 .49318 Mdot
.3776 .59579 Mdot
.4136 .05398 Mdot
.32627 .1849 Mdot
.02709 .20989 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50866 .60634 Mdot
.52759 .58088 Mdot
.5877 .50363 Mdot
.7728 .3576 Mdot
.19419 .49617 Mdot
.39137 .58923 Mdot
.43798 .02725 Mdot
.39388 .1185 Mdot
.20215 .25942 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00514 Mdot
.48788 .01636 Mdot
.46141 .05179 Mdot
.37762 .15438 Mdot
.12782 .26055 Mdot
.70625 .11854 Mdot
.51444 .10517 Mdot
.34427 .22758 Mdot
.97603 .20545 Mdot
.64361 .08966 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51109 .60306 Mdot
.53533 .57057 Mdot
.61212 .47502 Mdot
.84352 .35222 Mdot
.27361 .49815 Mdot
.46759 .52798 Mdot
.6133 .4316 Mdot
.91495 .35646 Mdot
.33819 .48192 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .60289 Mdot
.53572 .57005 Mdot
.61335 .47363 Mdot
.84699 .35265 Mdot
.27639 .49817 Mdot
.47033 .52552 Mdot
.62003 .4245 Mdot
.93318 .36435 Mdot
.34364 .48709 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01286 Mdot
.46968 .0408 Mdot
.40367 .12475 Mdot
.20182 .26558 Mdot
.7721 .11946 Mdot
.57881 .04935 Mdot
.49896 .05031 Mdot
.41756 .12336 Mdot
.21796 .26793 Mdot
.50077 .61699 Mdot
.50247 .6147 Mdot
.50786 .60742 Mdot
.52503 .58432 Mdot
.57958 .51358 Mdot
.74859 .36604 Mdot
.15633 .48876 Mdot
.3655 .59913 Mdot
.39609 .07072 Mdot
.28167 .21535 Mdot
.93322 .15524 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48731 .01714 Mdot
.45957 .05421 Mdot
.37185 .16059 Mdot
.11202 .25607 Mdot
.69769 .11642 Mdot
.50931 .10779 Mdot
.3349 .23484 Mdot
.95492 .19361 Mdot
.64166 .07895 Mdot
.5012 .61642 Mdot
.50381 .61288 Mdot
.51215 .60163 Mdot
.53869 .56612 Mdot
.62269 .46331 Mdot
.87304 .3577 Mdot
.29427 .49958 Mdot
.48593 .51261 Mdot
.65651 .38979 Mdot
.02581 .41362 Mdot
.35656 .52931 Mdot
.50016 .61782 Mdot
.5005 .61735 Mdot
.50161 .61586 Mdot
.50512 .61112 Mdot
.51631 .59603 Mdot
.55192 .54875 Mdot
.66402 .42221 Mdot
.98087 .40452 Mdot
.32634 .53541 Mdot
.46002 .57208 Mdot
.53437 .54047 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00457 Mdot
.48923 .01454 Mdot
.4657 .0461 Mdot
.39111 .13935 Mdot
.16565 .26665 Mdot
.7342 .11983 Mdot
.54031 .08286 Mdot
.40624 .16484 Mdot
.13953 .27824 Mdot
.68932 .14129 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.5004 .6175 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.5128 .60075 Mdot
.54077 .56336 Mdot
.62924 .45629 Mdot
.89095 .36292 Mdot
.30373 .50213 Mdot
.49126 .51023 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00373 Mdot
.4912 .01189 Mdot
.47197 .03774 Mdot
.4109 .11609 Mdot
.22306 .26153 Mdot
.7999 .12118 Mdot
.60383 .0316 Mdot
.5527 .60167 Mdot
.57917 .53127 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48852 .0155 Mdot
.46345 .04908 Mdot
.38403 .14732 Mdot
.14566 .26428 Mdot
.71804 .1197 Mdot
.52436 .0972 Mdot
.36709 .20659 Mdot
.03282 .2368 Mdot
.64967 .11761 Mdot
.4998 .00027 Mdot
.49936 .00086 Mdot
.49797 .00274 Mdot
.49355 .00872 Mdot
.47944 .02773 Mdot
.43457 .08669 Mdot
.2943 .22856 Mdot
.92449 .16115 Mdot
.66374 .03475 Mdot
.60751 .56052 Mdot
.70057 .42004 Mdot
.02093 .43939 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50474 .61163 Mdot
.5151 .59766 Mdot
.54807 .55377 Mdot
.65206 .43329 Mdot
.95098 .38856 Mdot
.32228 .52115 Mdot
.47903 .54053 Mdot
.60443 .45052 Mdot
.87548 .3465 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50175 .61568 Mdot
.50556 .61052 Mdot
.51772 .59413 Mdot
.55639 .54294 Mdot
.6779 .41028 Mdot
.01405 .42329 Mdot
.32916 .55296 Mdot
.43445 .61202 Mdot
.44419 .04467 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .0051 Mdot
.48798 .01623 Mdot
.46171 .05139 Mdot
.37857 .15335 Mdot
.13043 .26118 Mdot
.70783 .11879 Mdot
.51562 .10433 Mdot
.34682 .2254 Mdot
.98211 .20885 Mdot
.64418 .09274 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51338 .59997 Mdot
.54261 .56093 Mdot
.635 .45026 Mdot
.90647 .36846 Mdot
.3103 .50554 Mdot
.49232 .51266 Mdot
.66282 .3867 Mdot
.03712 .42081 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .00681 Mdot
.48395 .02166 Mdot
.4489 .06823 Mdot
.33851 .19354 Mdot
.02535 .21694 Mdot
.67433 .08576 Mdot
.53556 .05307 Mdot
.4497 .09893 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01454 Mdot
.46572 .04607 Mdot
.39117 .13929 Mdot
.1658 .26666 Mdot
.73433 .11983 Mdot
.54045 .08273 Mdot
.40658 .16445 Mdot
.14049 .27843 Mdot
.68999 .14125 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50757 .60781 Mdot
.52412 .58553 Mdot
.57671 .51714 Mdot
.73995 .36989 Mdot
.14145 .48443 Mdot
.35762 .59951 Mdot
.3876 .07722 Mdot
.26265 .2243 Mdot
.89973 .13737 Mdot
.50062 .6172 Mdot
.50197 .61538 Mdot
.50627 .60957 Mdot
.51996 .59111 Mdot
.56353 .53377 Mdot
.69987 .39348 Mdot
.0632 .45055 Mdot
.3342 .57792 Mdot
.39911 .04728 Mdot
.32262 .17973 Mdot
.03181 .20902 Mdot
.49977 .00032 Mdot
.49926 .00101 Mdot
.49763 .0032 Mdot
.49245 .0102 Mdot
.47594 .03243 Mdot
.42347 .10067 Mdot
.26058 .24789 Mdot
.85948 .1339 Mdot
.64283 .01856 Mdot
.61279 .54057 Mdot
.73813 .39343 Mdot
.10154 .48131 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00236 Mdot
.49444 .00751 Mdot
.48229 .0239 Mdot
.44362 .07508 Mdot
.32213 .20773 Mdot
.98602 .19478 Mdot
.67085 .06511 Mdot
.5655 .00609 Mdot
.55564 .57359 Mdot
.62755 .4676 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51236 .60134 Mdot
.53937 .56521 Mdot
.62484 .46099 Mdot
.87894 .35927 Mdot
.29762 .50026 Mdot
.48818 .51121 Mdot
.66102 .38613 Mdot
.03624 .41944 Mdot
.35757 .53455 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50493 .61137 Mdot
.51571 .59684 Mdot
.55001 .55124 Mdot
.65808 .42762 Mdot
.96617 .3965 Mdot
.32462 .52812 Mdot
.4701 .55568 Mdot
.571 .49201 Mdot
.77491 .34627 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.49481 .00701 Mdot
.48346 .02232 Mdot
.44734 .07025 Mdot
.33367 .19788 Mdot
.0135 .21037 Mdot
.67311 .07972 Mdot
.54412 .03934 Mdot
.48047 .05739 Mdot
.38761 .15313 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.4663 .0453 Mdot
.393 .13719 Mdot
.17102 .26694 Mdot
.73911 .11974 Mdot
.54536 .07825 Mdot
.41875 .15034 Mdot
.17549 .28201 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60665 Mdot
.52685 .58188 Mdot
.58536 .50649 Mdot
.76584 .35967 Mdot
.18388 .49467 Mdot
.3835 .59328 Mdot
.42354 .04343 Mdot
.35327 .16099 Mdot
.09279 .24222 Mdot
.50104 .61663 Mdot
.5033 .61357 Mdot
.51053 .60382 Mdot
.53353 .57296 Mdot
.60646 .48147 Mdot
.82743 .35104 Mdot
.25943 .49833 Mdot
.45313 .54116 Mdot
.57752 .4721 Mdot
.81364 .3362 Mdot
.26966 .48262 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00252 Mdot
.49405 .00804 Mdot
.48104 .02557 Mdot
.43966 .08018 Mdot
.30992 .21739 Mdot
.95817 .17906 Mdot
.66844 .05047 Mdot
.58679 .59197 Mdot
.62896 .48508 Mdot
.84409 .36257 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49798 .00272 Mdot
.49358 .00868 Mdot
.47954 .0276 Mdot
.43488 .08629 Mdot
.29526 .22791 Mdot
.92649 .16216 Mdot
.66411 .03559 Mdot
.60653 .56208 Mdot
.69707 .42262 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49337 .00896 Mdot
.47887 .02849 Mdot
.43278 .08896 Mdot
.28884 .23214 Mdot
.91323 .15562 Mdot
.66143 .03034 Mdot
.61233 .55268 Mdot
.71808 .40809 Mdot
.05777 .46048 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50784 .60744 Mdot
.52499 .58437 Mdot
.57945 .51374 Mdot
.74821 .3662 Mdot
.15569 .48859 Mdot
.36513 .59918 Mdot
.39564 .07111 Mdot
.28058 .21594 Mdot
.93118 .15411 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60843 Mdot
.52264 .58752 Mdot
.57202 .52301 Mdot
.72577 .37717 Mdot
.1155 .47509 Mdot
.34679 .59618 Mdot
.38215 .07769 Mdot
.25644 .22511 Mdot
.8922 .13265 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.48729 .01716 Mdot
.45953 .05427 Mdot
.37172 .16072 Mdot
.11167 .25596 Mdot
.69752 .11636 Mdot
.50924 .1078 Mdot
.33481 .23489 Mdot
.95475 .1935 Mdot
.64165 .07885 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01163 Mdot
.47258 .03693 Mdot
.41283 .11376 Mdot
.22877 .25999 Mdot
.80809 .12217 Mdot
.61042 .02782 Mdot
.56542 .5869 Mdot
.6158 .48877 Mdot
.82496 .35729 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50084 .61689 Mdot
.50269 .6144 Mdot
.50857 .60646 Mdot
.5273 .58128 Mdot
.58677 .50476 Mdot
.77005 .35839 Mdot
.19017 .49563 Mdot
.38823 .59093 Mdot
.43208 .03397 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48891 .01497 Mdot
.46469 .04743 Mdot
.38794 .14295 Mdot
.15665 .26583 Mdot
.72653 .11989 Mdot
.53255 .08993 Mdot
.38704 .18607 Mdot
.08598 .26196 Mdot
.66213 .13633 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .0137 Mdot
.46769 .04345 Mdot
.39739 .13212 Mdot
.18362 .26701 Mdot
.75158 .11948 Mdot
.55826 .06666 Mdot
.45039 .11191 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46802 .04301 Mdot
.39844 .1309 Mdot
.18663 .2669 Mdot
.75477 .11943 Mdot
.56154 .06379 Mdot
.45833 .10198 Mdot
.29331 .2441 Mdot
.89835 .15614 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.5101 .6044 Mdot
.53216 .57478 Mdot
.60214 .48646 Mdot
.81504 .35106 Mdot
.24701 .49858 Mdot
.44029 .55265 Mdot
.54608 .51052 Mdot
.72004 .36559 Mdot
.12851 .47219 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54007 .56429 Mdot
.62702 .45864 Mdot
.88492 .36102 Mdot
.30078 .50111 Mdot
.48996 .51041 Mdot
.6641 .38384 Mdot
.04304 .42325 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49631 .00498 Mdot
.48825 .01587 Mdot
.46257 .05025 Mdot
.38127 .15039 Mdot
.13793 .26284 Mdot
.71264 .11934 Mdot
.51954 .10128 Mdot
.35566 .21748 Mdot
.00377 .22098 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00562 Mdot
.48675 .01788 Mdot
.45782 .05653 Mdot
.36635 .16637 Mdot
.09716 .25095 Mdot
.69111 .11339 Mdot
.50764 .10631 Mdot
.33562 .23302 Mdot
.9586 .19506 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49038 .013 Mdot
.46935 .04123 Mdot
.40263 .12597 Mdot
.19881 .26595 Mdot
.76849 .1194 Mdot
.5753 .05217 Mdot
.49089 .06061 Mdot
.39283 .15262 Mdot
.14589 .26971 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00264 Mdot
.49378 .0084 Mdot
.4802 .02671 Mdot
.43698 .08361 Mdot
.30169 .22345 Mdot
.94015 .16926 Mdot
.66628 .04166 Mdot
.59887 .57382 Mdot
.67042 .44433 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00491 Mdot
.48842 .01564 Mdot
.46311 .04953 Mdot
.38297 .14851 Mdot
.14268 .26376 Mdot
.71591 .11959 Mdot
.52241 .09888 Mdot
.36242 .21113 Mdot
.02081 .23036 Mdot
.64808 .11205 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00414 Mdot
.49023 .0132 Mdot
.46888 .04187 Mdot
.40113 .12774 Mdot
.19444 .26639 Mdot
.76342 .11937 Mdot
.57028 .05631 Mdot
.47917 .07556 Mdot
.35691 .19105 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01506 Mdot
.46449 .04771 Mdot
.38729 .14368 Mdot
.15482 .26561 Mdot
.72505 .11988 Mdot
.53108 .09125 Mdot
.38344 .1899 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48979 .01379 Mdot
.46747 .04374 Mdot
.3967 .13292 Mdot
.18164 .26706 Mdot
.74953 .11951 Mdot
.55615 .06853 Mdot
.44526 .11829 Mdot
.25386 .26579 Mdot
.82381 .13383 Mdot
.50051 .61734 Mdot
.50163 .61583 Mdot
.50519 .61102 Mdot
.51654 .59571 Mdot
.55266 .54778 Mdot
.66634 .42015 Mdot
.98653 .40767 Mdot
.3269 .53833 Mdot
.45586 .57873 Mdot
.51946 .56073 Mdot
.61218 .46513 Mdot
.50019 .61777 Mdot
.50061 .6172 Mdot
.50196 .61539 Mdot
.50624 .60961 Mdot
.51987 .59123 Mdot
.56324 .53413 Mdot
.699 .3941 Mdot
.06134 .44957 Mdot
.33393 .57707 Mdot
.40022 .04559 Mdot
.32645 .17644 Mdot
.50018 .61779 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50582 .61017 Mdot
.51855 .59301 Mdot
.55905 .53951 Mdot
.6861 .4037 Mdot
.0329 .43398 Mdot
.3307 .56296 Mdot
.41981 .01616 Mdot
.39366 .10758 Mdot
.50091 .61681 Mdot
.50289 .61414 Mdot
.50919 .60562 Mdot
.52928 .57863 Mdot
.59304 .4972 Mdot
.78855 .35396 Mdot
.21583 .49812 Mdot
.40985 .5773 Mdot
.47576 .59968 Mdot
.50547 .59461 Mdot
.54337 .5549 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49375 .00844 Mdot
.4801 .02683 Mdot
.43669 .08399 Mdot
.30078 .22409 Mdot
.9382 .16822 Mdot
.666 .04076 Mdot
.60006 .57202 Mdot
.67451 .44076 Mdot
.96135 .40528 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49514 .00657 Mdot
.4845 .02092 Mdot
.45066 .06593 Mdot
.34398 .18849 Mdot
.039 .22428 Mdot
.6761 .09236 Mdot
.52666 .06776 Mdot
.41703 .14124 Mdot
.1885 .2779 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.5237 .5861 Mdot
.57536 .51882 Mdot
.7359 .37185 Mdot
.13423 .48205 Mdot
.35425 .59906 Mdot
.38495 .07863 Mdot
.25772 .226 Mdot
.89204 .13342 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04863 Mdot
.38512 .14612 Mdot
.14869 .26477 Mdot
.72029 .11979 Mdot
.52647 .09536 Mdot
.37218 .20152 Mdot
.0461 .24367 Mdot
.65184 .12331 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49301 .00944 Mdot
.47773 .03002 Mdot
.42915 .09356 Mdot
.27776 .23887 Mdot
.89127 .14573 Mdot
.65548 .02345 Mdot
.61754 .54216 Mdot
.74031 .39488 Mdot
.10138 .48264 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49029 .01311 Mdot
.46907 .0416 Mdot
.40176 .127 Mdot
.19627 .26622 Mdot
.76552 .11937 Mdot
.57237 .05457 Mdot
.48407 .06931 Mdot
.37193 .17563 Mdot
.08775 .25292 Mdot
.49979 .00029 Mdot
.49932 .00091 Mdot
.49785 .00291 Mdot
.49314 .00927 Mdot
.47815 .02946 Mdot
.43048 .09189 Mdot
.2818 .23649 Mdot
.89915 .14913 Mdot
.65785 .02563 Mdot
.61637 .54515 Mdot
.7343 .39832 Mdot
.08981 .47723 Mdot
.5013 .61628 Mdot
.50413 .61245 Mdot
.51317 .60025 Mdot
.54194 .56182 Mdot
.6329 .45244 Mdot
.90085 .36635 Mdot
.30808 .50418 Mdot
.49231 .5113 Mdot
.665 .3843 Mdot
.04319 .42385 Mdot
.35738 .53907 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50746 .60795 Mdot
.52377 .586 Mdot
.5756 .51852 Mdot
.73662 .3715 Mdot
.13553 .48249 Mdot
.35484 .59917 Mdot
.38536 .07846 Mdot
.25841 .2258 Mdot
.89307 .13396 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00556 Mdot
.48688 .01772 Mdot
.45821 .05601 Mdot
.36758 .16509 Mdot
.10046 .25216 Mdot
.69246 .11415 Mdot
.50775 .10697 Mdot
.33467 .23412 Mdot
.95585 .19372 Mdot
.64241 .07862 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.4965 .00473 Mdot
.48884 .01507 Mdot
.46444 .04776 Mdot
.38716 .14382 Mdot
.15445 .26557 Mdot
.72475 .11988 Mdot
.53079 .09151 Mdot
.38273 .19065 Mdot
.07425 .25701 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .00179 Mdot
.49577 .00572 Mdot
.48652 .0182 Mdot
.45707 .05751 Mdot
.36402 .16879 Mdot
.09091 .24856 Mdot
.68873 .11181 Mdot
.50782 .10456 Mdot
.33863 .22981 Mdot
.96679 .19925 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.4977 .00311 Mdot
.49266 .00991 Mdot
.47662 .03151 Mdot
.42564 .09796 Mdot
.26713 .24465 Mdot
.87127 .13791 Mdot
.64813 .01957 Mdot
.61646 .53902 Mdot
.74431 .39157 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50449 .61197 Mdot
.5143 .59873 Mdot
.54553 .55709 Mdot
.64414 .441 Mdot
.93058 .37867 Mdot
.31788 .513 Mdot
.48784 .52426 Mdot
.63957 .41083 Mdot
.97484 .3876 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.4977 .00311 Mdot
.49266 .00991 Mdot
.47663 .03149 Mdot
.42567 .09792 Mdot
.26723 .2446 Mdot
.87146 .13798 Mdot
.64821 .0196 Mdot
.6165 .53902 Mdot
.74436 .39156 Mdot
.1108 .48618 Mdot
.5011 .61655 Mdot
.50351 .6133 Mdot
.51117 .60295 Mdot
.53559 .57023 Mdot
.61294 .4741 Mdot
.84583 .3525 Mdot
.27547 .49816 Mdot
.46943 .52633 Mdot
.61781 .42682 Mdot
.92721 .36166 Mdot
.34203 .48522 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.4867 .01796 Mdot
.45765 .05676 Mdot
.36581 .16694 Mdot
.0957 .25041 Mdot
.69054 .11304 Mdot
.50764 .10596 Mdot
.33618 .2324 Mdot
.96016 .19585 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49815 .0025 Mdot
.4941 .00797 Mdot
.48121 .02535 Mdot
.44019 .0795 Mdot
.31156 .21614 Mdot
.96184 .1811 Mdot
.66881 .05234 Mdot
.58412 .59598 Mdot
.61981 .49511 Mdot
.81871 .3611 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50722 .60829 Mdot
.52299 .58705 Mdot
.57313 .52161 Mdot
.72915 .37533 Mdot
.12185 .47757 Mdot
.34912 .59742 Mdot
.38247 .07871 Mdot
.25512 .22617 Mdot
.88917 .13153 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50793 .60732 Mdot
.52527 .58399 Mdot
.58035 .51263 Mdot
.7509 .36508 Mdot
.16019 .48975 Mdot
.36775 .59872 Mdot
.39899 .06817 Mdot
.28869 .21138 Mdot
.94668 .16286 Mdot
.5004 .61749 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51302 .60045 Mdot
.54146 .56245 Mdot
.6314 .45401 Mdot
.8968 .3649 Mdot
.30638 .50329 Mdot
.49204 .51066 Mdot
.66578 .3833 Mdot
.04559 .42498 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.5056 .61047 Mdot
.51783 .59397 Mdot
.55676 .54246 Mdot
.67904 .40934 Mdot
.01671 .4248 Mdot
.32936 .55438 Mdot
.43235 .61522 Mdot
.43691 .05416 Mdot
.34928 .17391 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01089 Mdot
.47431 .03461 Mdot
.41832 .10705 Mdot
.2451 .25453 Mdot
.83327 .12672 Mdot
.62824 .02029 Mdot
.59541 .55508 Mdot
.69726 .41556 Mdot
.02487 .43852 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.51219 .60157 Mdot
.53883 .56593 Mdot
.62314 .46282 Mdot
.87429 .35802 Mdot
.29499 .49971 Mdot
.48644 .51226 Mdot
.65758 .3889 Mdot
.02832 .41502 Mdot
.3568 .53057 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49005 .01343 Mdot
.46832 .04261 Mdot
.39938 .1298 Mdot
.18936 .26676 Mdot
.75773 .11939 Mdot
.56455 .06118 Mdot
.46556 .09286 Mdot
.31532 .22815 Mdot
.49991 .00012 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49047 .01287 Mdot
.46964 .04085 Mdot
.40353 .12491 Mdot
.20143 .26563 Mdot
.77162 .11945 Mdot
.57835 .04971 Mdot
.49791 .05165 Mdot
.41433 .12729 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49347 .00882 Mdot
.4792 .02804 Mdot
.43382 .08764 Mdot
.29202 .23007 Mdot
.91975 .15879 Mdot
.66282 .03283 Mdot
.6097 .55704 Mdot
.70839 .41451 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.51011 .60438 Mdot
.5322 .57474 Mdot
.60225 .48634 Mdot
.81534 .35105 Mdot
.24732 .49858 Mdot
.44061 .55236 Mdot
.54687 .50954 Mdot
.72242 .36421 Mdot
.13312 .47372 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46947 .04107 Mdot
.40302 .12552 Mdot
.19992 .26582 Mdot
.76982 .11942 Mdot
.5766 .05112 Mdot
.49389 .05679 Mdot
.402 .142 Mdot
.17224 .27228 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00286 Mdot
.49326 .0091 Mdot
.47854 .02894 Mdot
.43172 .09031 Mdot
.28559 .23418 Mdot
.90668 .15254 Mdot
.65986 .02803 Mdot
.6145 .54884 Mdot
.72646 .40291 Mdot
.07454 .46951 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00367 Mdot
.49136 .01167 Mdot
.47247 .03707 Mdot
.41249 .11417 Mdot
.22776 .26028 Mdot
.80662 .12197 Mdot
.60927 .02845 Mdot
.56324 .58939 Mdot
.60959 .49563 Mdot
.80765 .35766 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51039 .604 Mdot
.53309 .57354 Mdot
.60508 .48305 Mdot
.82348 .35096 Mdot
.25562 .49841 Mdot
.44917 .54473 Mdot
.56778 .48378 Mdot
.78501 .33979 Mdot
.23522 .4867 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48855 .01545 Mdot
.46355 .04895 Mdot
.38434 .14698 Mdot
.14653 .26442 Mdot
.71868 .11973 Mdot
.52496 .09669 Mdot
.36851 .20518 Mdot
.03652 .23874 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47748 .03035 Mdot
.42838 .09453 Mdot
.27542 .2402 Mdot
.88678 .14387 Mdot
.654 .02236 Mdot
.61782 .54087 Mdot
.74267 .39348 Mdot
.106 .48465 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50831 .6068 Mdot
.52649 .58236 Mdot
.5842 .50789 Mdot
.76242 .3608 Mdot
.17864 .49376 Mdot
.37972 .59494 Mdot
.41709 .05034 Mdot
.33563 .17705 Mdot
.04916 .2219 Mdot
.50012 .61788 Mdot
.50037 .61754 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51185 .60203 Mdot
.53774 .56737 Mdot
.61972 .46655 Mdot
.86483 .35577 Mdot
.28918 .49887 Mdot
.48199 .51553 Mdot
.64784 .39735 Mdot
.5012 .61641 Mdot
.50382 .61288 Mdot
.51216 .60161 Mdot
.53874 .56605 Mdot
.62286 .46313 Mdot
.87349 .35782 Mdot
.29453 .49963 Mdot
.48612 .51248 Mdot
.6569 .38947 Mdot
.02673 .41413 Mdot
.35665 .52977 Mdot
.50019 .61778 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50605 .60987 Mdot
.51926 .59205 Mdot
.5613 .53661 Mdot
.69305 .39841 Mdot
.0484 .44259 Mdot
.33227 .57086 Mdot
.40859 .03299 Mdot
.35521 .14945 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61507 Mdot
.507 .60858 Mdot
.52229 .58798 Mdot
.57092 .52439 Mdot
.72243 .37906 Mdot
.1091 .47246 Mdot
.34464 .59468 Mdot
.38243 .07599 Mdot
.25947 .22328 Mdot
.50034 .61758 Mdot
.50108 .61657 Mdot
.50345 .61338 Mdot
.51098 .6032 Mdot
.53499 .57103 Mdot
.61104 .47624 Mdot
.84047 .3519 Mdot
.27109 .49815 Mdot
.46507 .53027 Mdot
.60708 .43832 Mdot
.89786 .35 Mdot
.50028 .61765 Mdot
.50091 .61681 Mdot
.50289 .61414 Mdot
.50919 .60562 Mdot
.52929 .57862 Mdot
.59306 .49718 Mdot
.78861 .35395 Mdot
.2159 .49813 Mdot
.40992 .57725 Mdot
.47591 .5995 Mdot
.50591 .59402 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49434 .00764 Mdot
.48198 .02432 Mdot
.44263 .07636 Mdot
.31908 .21022 Mdot
.97894 .19075 Mdot
.6703 .06133 Mdot
.57107 .61564 Mdot
.57494 .54871 Mdot
.68711 .41253 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60664 Mdot
.52686 .58186 Mdot
.5854 .50643 Mdot
.76597 .35963 Mdot
.18407 .4947 Mdot
.38364 .59322 Mdot
.42379 .04316 Mdot
.35395 .16034 Mdot
.09452 .2429 Mdot
.50088 .61684 Mdot
.50282 .61423 Mdot
.50897 .60592 Mdot
.52857 .57958 Mdot
.59079 .4999 Mdot
.78194 .35531 Mdot
.20703 .49751 Mdot
.40204 .58271 Mdot
.4592 .00208 Mdot
.45582 .04251 Mdot
.38703 .13866 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51225 .60149 Mdot
.53902 .56568 Mdot
.62373 .46218 Mdot
.87591 .35845 Mdot
.29592 .49989 Mdot
.48708 .51186 Mdot
.65888 .38784 Mdot
.03134 .41671 Mdot
.35709 .53209 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50701 .60857 Mdot
.52232 .58795 Mdot
.571 .52429 Mdot
.72269 .37891 Mdot
.1096 .47267 Mdot
.3448 .59481 Mdot
.38238 .07615 Mdot
.25917 .22345 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50304 .61392 Mdot
.5097 .60494 Mdot
.53089 .57648 Mdot
.59813 .49116 Mdot
.80342 .35185 Mdot
.23412 .49866 Mdot
.42728 .56376 Mdot
.5151 .54978 Mdot
.62554 .4451 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51023 .60422 Mdot
.53258 .57423 Mdot
.60346 .48493 Mdot
.81883 .35097 Mdot
.25095 .49851 Mdot
.44435 .54906 Mdot
.55596 .49825 Mdot
.74978 .3507 Mdot
.18233 .48511 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50612 .60977 Mdot
.5195 .59174 Mdot
.56204 .53567 Mdot
.69531 .39675 Mdot
.05336 .44529 Mdot
.33286 .57329 Mdot
.40526 .03799 Mdot
.34378 .16065 Mdot
.49974 .00035 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49174 .01116 Mdot
.47368 .03545 Mdot
.41632 .1095 Mdot
.23914 .2567 Mdot
.82378 .12473 Mdot
.62196 .02241 Mdot
.58569 .56479 Mdot
.67184 .43468 Mdot
.96851 .40568 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00355 Mdot
.49164 .01129 Mdot
.47337 .03587 Mdot
.41533 .11071 Mdot
.2362 .2577 Mdot
.81923 .1239 Mdot
.61876 .02373 Mdot
.58036 .5704 Mdot
.65744 .44711 Mdot
.93401 .38767 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00565 Mdot
.48667 .018 Mdot
.45754 .05689 Mdot
.36549 .16727 Mdot
.09484 .25008 Mdot
.6902 .11283 Mdot
.50765 .10574 Mdot
.33656 .232 Mdot
.96118 .19636 Mdot
.64346 .08066 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00263 Mdot
.49379 .00839 Mdot
.48022 .02668 Mdot
.43705 .08353 Mdot
.30189 .22331 Mdot
.94057 .16948 Mdot
.66634 .04186 Mdot
.59862 .57421 Mdot
.66953 .44512 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51193 .60193 Mdot
.53799 .56705 Mdot
.62048 .46572 Mdot
.86693 .35624 Mdot
.29053 .49902 Mdot
.48309 .51468 Mdot
.65032 .39513 Mdot
.01098 .40531 Mdot
.35518 .52179 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00559 Mdot
.48683 .01778 Mdot
.45806 .05622 Mdot
.3671 .1656 Mdot
.09916 .25169 Mdot
.69192 .11386 Mdot
.50769 .10673 Mdot
.335 .23373 Mdot
.95681 .19418 Mdot
.64262 .07897 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48973 .01387 Mdot
.46729 .04398 Mdot
.39613 .13358 Mdot
.18 .26708 Mdot
.74785 .11955 Mdot
.55442 .07008 Mdot
.44104 .1235 Mdot
.24122 .27082 Mdot
.80303 .13138 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48819 .01595 Mdot
.46239 .05049 Mdot
.38069 .15103 Mdot
.13632 .26251 Mdot
.71157 .11924 Mdot
.51863 .10201 Mdot
.35358 .2194 Mdot
.99858 .21808 Mdot
.64572 .1011 Mdot
.50055 .6173 Mdot
.50174 .61568 Mdot
.50554 .61055 Mdot
.51765 .59421 Mdot
.55619 .5432 Mdot
.67729 .41078 Mdot
.01262 .42247 Mdot
.32905 .55219 Mdot
.43558 .61029 Mdot
.4481 .03952 Mdot
.38416 .13768 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49748 .00341 Mdot
.49197 .01085 Mdot
.47441 .03447 Mdot
.41864 .10665 Mdot
.24607 .25415 Mdot
.83485 .12708 Mdot
.62922 .02002 Mdot
.59683 .55372 Mdot
.70089 .41315 Mdot
.03241 .44298 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52047 .59043 Mdot
.56514 .53171 Mdot
.70482 .39007 Mdot
.07367 .45595 Mdot
.33592 .58251 Mdot
.39339 .05608 Mdot
.30265 .19563 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .01421 Mdot
.46649 .04505 Mdot
.3936 .1365 Mdot
.17274 .267 Mdot
.74072 .1197 Mdot
.54704 .07673 Mdot
.42289 .14545 Mdot
.18755 .28178 Mdot
.73162 .13522 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46875 .04203 Mdot
.40074 .1282 Mdot
.19332 .26648 Mdot
.76214 .11937 Mdot
.569 .05738 Mdot
.47615 .07941 Mdot
.34766 .20004 Mdot
.02399 .2222 Mdot
.50032 .6176 Mdot
.50101 .61667 Mdot
.50323 .61368 Mdot
.51028 .60416 Mdot
.53273 .57403 Mdot
.60393 .48439 Mdot
.82017 .35095 Mdot
.25232 .49848 Mdot
.44576 .5478 Mdot
.5594 .494 Mdot
.76009 .34675 Mdot
.50118 .61643 Mdot
.50377 .61294 Mdot
.51202 .6018 Mdot
.53829 .56665 Mdot
.62144 .46468 Mdot
.86957 .35685 Mdot
.29218 .49925 Mdot
.48438 .5137 Mdot
.65319 .39263 Mdot
.0179 .40919 Mdot
.35582 .5253 Mdot
.5 .61803 Mdot
.50001 .61801 Mdot
.50005 .61797 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50477 .61159 Mdot
.51521 .59751 Mdot
.54841 .55332 Mdot
.65313 .43227 Mdot
.9537 .38995 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60547 Mdot
.52963 .57816 Mdot
.59414 .4959 Mdot
.79176 .3534 Mdot
.21995 .49832 Mdot
.41364 .57451 Mdot
.48407 .58925 Mdot
.53063 .56103 Mdot
.62287 .45811 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50825 .6069 Mdot
.52627 .58266 Mdot
.58351 .50874 Mdot
.76035 .36151 Mdot
.17541 .49315 Mdot
.37748 .59583 Mdot
.4134 .05418 Mdot
.32574 .18533 Mdot
.02588 .20921 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .00441 Mdot
.4896 .01404 Mdot
.46688 .04453 Mdot
.39482 .13509 Mdot
.17624 .26707 Mdot
.74411 .11963 Mdot
.55055 .07355 Mdot
.43153 .13509 Mdot
.21296 .27865 Mdot
.76209 .13153 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50125 .61635 Mdot
.50397 .61266 Mdot
.51266 .60094 Mdot
.54032 .56395 Mdot
.62783 .45779 Mdot
.88712 .36169 Mdot
.30189 .50147 Mdot
.4905 .51027 Mdot
.66486 .38334 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47977 .02729 Mdot
.43561 .08536 Mdot
.29749 .22639 Mdot
.93118 .16456 Mdot
.66492 .0376 Mdot
.60407 .56589 Mdot
.68845 .42924 Mdot
.99392 .42361 Mdot
.49974 .00034 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49175 .01115 Mdot
.47371 .03541 Mdot
.41643 .10937 Mdot
.23946 .25659 Mdot
.82429 .12483 Mdot
.62231 .02228 Mdot
.58626 .5642 Mdot
.67336 .43344 Mdot
.97204 .40765 Mdot
.49978 .0003 Mdot
.49929 .00095 Mdot
.49775 .00304 Mdot
.49283 .00969 Mdot
.47714 .03081 Mdot
.42729 .09589 Mdot
.27214 .24201 Mdot
.88056 .14139 Mdot
.65179 .02105 Mdot
.61772 .53963 Mdot
.74458 .39217 Mdot
.11003 .48624 Mdot
.50126 .61633 Mdot
.50401 .61261 Mdot
.51278 .60078 Mdot
.5407 .56346 Mdot
.629 .45654 Mdot
.89031 .36271 Mdot
.30343 .50202 Mdot
.49115 .51022 Mdot
.66559 .38294 Mdot
.04598 .42498 Mdot
.35835 .53963 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01559 Mdot
.46324 .04936 Mdot
.38337 .14806 Mdot
.1438 .26396 Mdot
.7167 .11963 Mdot
.52313 .09826 Mdot
.36414 .20947 Mdot
.02521 .23274 Mdot
.64863 .11413 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01802 Mdot
.45751 .05694 Mdot
.36537 .16739 Mdot
.09452 .24996 Mdot
.69008 .11275 Mdot
.50765 .10565 Mdot
.3367 .23184 Mdot
.96158 .19657 Mdot
.64353 .08082 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.4927 .00985 Mdot
.47676 .03132 Mdot
.42607 .09742 Mdot
.26845 .24397 Mdot
.87369 .13879 Mdot
.64913 .0199 Mdot
.61693 .53903 Mdot
.74476 .39157 Mdot
.11119 .48646 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50406 .61254 Mdot
.51295 .60055 Mdot
.54124 .56275 Mdot
.6307 .45475 Mdot
.8949 .36424 Mdot
.30554 .5029 Mdot
.49184 .51046 Mdot
.6659 .38303 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00425 Mdot
.48998 .01353 Mdot
.4681 .0429 Mdot
.39868 .13062 Mdot
.18733 .26687 Mdot
.75552 .11942 Mdot
.5623 .06312 Mdot
.46016 .09967 Mdot
.29889 .24031 Mdot
.91007 .1613 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51328 .60011 Mdot
.54229 .56136 Mdot
.63399 .45131 Mdot
.90375 .36742 Mdot
.30925 .50486 Mdot
.49237 .51194 Mdot
.66404 .3854 Mdot
.04045 .42249 Mdot
.35684 .53802 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48952 .01415 Mdot
.46662 .04487 Mdot
.39402 .13602 Mdot
.17394 .26703 Mdot
.74187 .11968 Mdot
.54823 .07565 Mdot
.42582 .14195 Mdot
.19614 .28113 Mdot
.74126 .13381 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01605 Mdot
.46215 .05081 Mdot
.37994 .15185 Mdot
.13425 .26206 Mdot
.71023 .1191 Mdot
.51752 .10289 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.4933 .00905 Mdot
.47865 .02879 Mdot
.43206 .08988 Mdot
.28664 .23353 Mdot
.90878 .15352 Mdot
.66038 .02875 Mdot
.61386 .55001 Mdot
.72392 .40444 Mdot
.50077 .61699 Mdot
.50247 .6147 Mdot
.50786 .60742 Mdot
.52504 .5843 Mdot
.57961 .51354 Mdot
.74869 .366 Mdot
.15648 .4888 Mdot
.36559 .59911 Mdot
.3962 .07063 Mdot
.28193 .21521 Mdot
.93371 .15552 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50971 .60491 Mdot
.53094 .57641 Mdot
.5983 .49097 Mdot
.8039 .3518 Mdot
.23467 .49866 Mdot
.42782 .56331 Mdot
.51637 .54815 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48949 .0142 Mdot
.46652 .04501 Mdot
.39369 .1364 Mdot
.173 .26701 Mdot
.74097 .1197 Mdot
.5473 .07649 Mdot
.42353 .14469 Mdot
.18941 .28167 Mdot
.49982 .00024 Mdot
.49943 .00076 Mdot
.4982 .00244 Mdot
.49425 .00776 Mdot
.48169 .0247 Mdot
.44172 .07753 Mdot
.31628 .21246 Mdot
.9725 .1871 Mdot
.66977 .05791 Mdot
.57607 .60808 Mdot
.59218 .52732 Mdot
.73896 .38013 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49118 .01191 Mdot
.47191 .03782 Mdot
.41071 .11633 Mdot
.22249 .26167 Mdot
.7991 .12109 Mdot
.60317 .03201 Mdot
.55138 .60324 Mdot
.57531 .536 Mdot
.70806 .39354 Mdot
.50024 .61772 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.50761 .60776 Mdot
.52424 .58538 Mdot
.57708 .51668 Mdot
.74106 .36937 Mdot
.14341 .48504 Mdot
.35859 .59956 Mdot
.38848 .07665 Mdot
.26445 .22359 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.51011 .60438 Mdot
.5322 .57474 Mdot
.60225 .48634 Mdot
.81533 .35105 Mdot
.24732 .49858 Mdot
.44061 .55237 Mdot
.54686 .50955 Mdot
.72238 .36423 Mdot
.13305 .4737 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49841 .00215 Mdot
.49492 .00686 Mdot
.48381 .02184 Mdot
.44847 .06879 Mdot
.33717 .19475 Mdot
.02206 .21513 Mdot
.67397 .08411 Mdot
.53788 .04933 Mdot
.45806 .08776 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00488 Mdot
.48849 .01554 Mdot
.46335 .04921 Mdot
.38373 .14767 Mdot
.14479 .26413 Mdot
.71742 .11967 Mdot
.52378 .0977 Mdot
.3657 .20795 Mdot
.02922 .23489 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49324 .00914 Mdot
.47845 .02905 Mdot
.43144 .09066 Mdot
.28475 .2347 Mdot
.905 .15177 Mdot
.65943 .02747 Mdot
.61498 .54795 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.49541 .00621 Mdot
.48537 .01975 Mdot
.45341 .06233 Mdot
.35255 .1803 Mdot
.06082 .23532 Mdot
.68007 .10179 Mdot
.51537 .08756 Mdot
.37369 .19274 Mdot
.06183 .24863 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00369 Mdot
.4913 .01175 Mdot
.4723 .0373 Mdot
.41195 .11483 Mdot
.22615 .26072 Mdot
.80429 .12168 Mdot
.60742 .02949 Mdot
.5597 .59346 Mdot
.59946 .50714 Mdot
.77889 .36202 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49119 .0119 Mdot
.47193 .03779 Mdot
.41077 .11625 Mdot
.22268 .26162 Mdot
.79937 .12112 Mdot
.60339 .03187 Mdot
.55182 .60271 Mdot
.57662 .53439 Mdot
.71195 .39104 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00295 Mdot
.49305 .00938 Mdot
.47787 .02983 Mdot
.42961 .09297 Mdot
.27918 .23805 Mdot
.89401 .14689 Mdot
.65633 .02417 Mdot
.61723 .54309 Mdot
.73849 .39593 Mdot
.09786 .48104 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.48751 .01686 Mdot
.46023 .05335 Mdot
.3739 .1584 Mdot
.11761 .25777 Mdot
.70052 .1173 Mdot
.51073 .10736 Mdot
.33702 .2334 Mdot
.95938 .19614 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49667 .0045 Mdot
.48939 .01433 Mdot
.46621 .04541 Mdot
.39273 .1375 Mdot
.17026 .26691 Mdot
.7384 .11975 Mdot
.54463 .07892 Mdot
.41694 .15248 Mdot
.17022 .28187 Mdot
.71415 .13805 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00378 Mdot
.49108 .01205 Mdot
.47158 .03826 Mdot
.40968 .11757 Mdot
.21945 .2624 Mdot
.79488 .12068 Mdot
.59961 .03425 Mdot
.54418 .61185 Mdot
.55418 .56259 Mdot
.6439 .44663 Mdot
.49959 .00055 Mdot
.49871 .00174 Mdot
.49589 .00556 Mdot
.4869 .01769 Mdot
.45827 .05593 Mdot
.36778 .16489 Mdot
.10098 .25235 Mdot
.69268 .11427 Mdot
.50778 .10706 Mdot
.33456 .23426 Mdot
.95552 .19356 Mdot
.64233 .07851 Mdot
.50081 .61693 Mdot
.50259 .61453 Mdot
.50826 .60688 Mdot
.52631 .5826 Mdot
.58363 .50859 Mdot
.76072 .36138 Mdot
.17599 .49326 Mdot
.37789 .59568 Mdot
.41405 .05351 Mdot
.32748 .18391 Mdot
.02991 .21147 Mdot
.50127 .61632 Mdot
.50404 .61258 Mdot
.51286 .60067 Mdot
.54096 .56312 Mdot
.62981 .45568 Mdot
.8925 .36343 Mdot
.30446 .50243 Mdot
.49152 .51029 Mdot
.66585 .38289 Mdot
.04633 .42523 Mdot
.35829 .53992 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49725 .00371 Mdot
.49125 .01182 Mdot
.47213 .03752 Mdot
.41143 .11546 Mdot
.22461 .26113 Mdot
.80209 .12142 Mdot
.60563 .03052 Mdot
.55625 .59749 Mdot
.58949 .51883 Mdot
.75 .37129 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60341 Mdot
.53449 .57168 Mdot
.60949 .47799 Mdot
.83608 .35151 Mdot
.26733 .49818 Mdot
.46125 .53375 Mdot
.59763 .44881 Mdot
.87144 .34217 Mdot
.31779 .47653 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49517 .00652 Mdot
.48462 .02076 Mdot
.45102 .06545 Mdot
.34512 .18742 Mdot
.04187 .22579 Mdot
.67654 .09369 Mdot
.52495 .07066 Mdot
.41062 .14922 Mdot
.16917 .27815 Mdot
.50015 .61783 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50482 .61153 Mdot
.51534 .59732 Mdot
.54885 .55274 Mdot
.6545 .43097 Mdot
.95717 .39175 Mdot
.32331 .52391 Mdot
.47561 .54644 Mdot
.59146 .46624 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48995 .01357 Mdot
.46799 .04304 Mdot
.39835 .131 Mdot
.18639 .26692 Mdot
.75451 .11943 Mdot
.56127 .06402 Mdot
.45769 .10279 Mdot
.29138 .24537 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48859 .0154 Mdot
.46367 .04879 Mdot
.38472 .14656 Mdot
.14757 .26459 Mdot
.71945 .11976 Mdot
.52568 .09606 Mdot
.37025 .20345 Mdot
.04106 .2411 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51192 .60193 Mdot
.53798 .56706 Mdot
.62046 .46575 Mdot
.86686 .35622 Mdot
.29048 .49902 Mdot
.48305 .5147 Mdot
.65025 .3952 Mdot
.0108 .4052 Mdot
.35516 .52169 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49806 .00263 Mdot
.4938 .00837 Mdot
.48026 .02662 Mdot
.4372 .08334 Mdot
.30235 .22298 Mdot
.94156 .17001 Mdot
.66648 .04232 Mdot
.598 .57514 Mdot
.66741 .44701 Mdot
.94413 .39628 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49756 .0033 Mdot
.49221 .01052 Mdot
.47519 .03343 Mdot
.42111 .1036 Mdot
.25347 .25111 Mdot
.84716 .13022 Mdot
.63646 .01865 Mdot
.60628 .54532 Mdot
.72392 .39976 Mdot
.0771 .46847 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50749 .60792 Mdot
.52385 .5859 Mdot
.57584 .51822 Mdot
.73734 .37114 Mdot
.13683 .48293 Mdot
.35543 .59927 Mdot
.3858 .07825 Mdot
.25919 .22555 Mdot
.89425 .13457 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48836 .01571 Mdot
.46294 .04976 Mdot
.38243 .14911 Mdot
.14116 .26348 Mdot
.71485 .11952 Mdot
.52146 .09968 Mdot
.36017 .21327 Mdot
.01509 .22724 Mdot
.64741 .1093 Mdot
.50087 .61686 Mdot
.50278 .61428 Mdot
.50885 .60608 Mdot
.5282 .58007 Mdot
.58963 .5013 Mdot
.77852 .35611 Mdot
.20231 .49709 Mdot
.39801 .5853 Mdot
.45098 .01199 Mdot
.43158 .07348 Mdot
.31268 .20973 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50928 .6055 Mdot
.52955 .57827 Mdot
.5939 .49618 Mdot
.79106 .35352 Mdot
.21906 .49828 Mdot
.41282 .57512 Mdot
.48225 .59154 Mdot
.52512 .56835 Mdot
.6055 .47756 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49834 .00225 Mdot
.4947 .00716 Mdot
.48311 .02279 Mdot
.44623 .0717 Mdot
.33022 .2009 Mdot
.00516 .20568 Mdot
.67236 .07534 Mdot
.55046 .02935 Mdot
.50297 .02659 Mdot
.45995 .06332 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50641 .60937 Mdot
.52042 .59049 Mdot
.56498 .53191 Mdot
.70433 .3904 Mdot
.07265 .45543 Mdot
.33574 .58208 Mdot
.39391 .05528 Mdot
.30447 .19426 Mdot
.99015 .18513 Mdot
.5004 .61749 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60041 Mdot
.54156 .56232 Mdot
.63171 .45368 Mdot
.89764 .3652 Mdot
.30674 .50347 Mdot
.49212 .51077 Mdot
.66567 .38346 Mdot
.04522 .42482 Mdot
.50046 .61742 Mdot
.50146 .61607 Mdot
.50464 .61177 Mdot
.51477 .59809 Mdot
.54704 .55512 Mdot
.64884 .43639 Mdot
.94274 .38445 Mdot
.32069 .51767 Mdot
.48308 .53333 Mdot
.62013 .43224 Mdot
.92075 .36177 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48819 .01595 Mdot
.46239 .05049 Mdot
.38069 .15103 Mdot
.13632 .26251 Mdot
.71157 .11924 Mdot
.51863 .10201 Mdot
.35358 .2194 Mdot
.99859 .21809 Mdot
.64572 .1011 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49005 .01344 Mdot
.4683 .04263 Mdot
.39932 .12987 Mdot
.18919 .26677 Mdot
.75754 .11939 Mdot
.56436 .06134 Mdot
.46511 .09343 Mdot
.31393 .22923 Mdot
.50012 .61787 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.5127 .60089 Mdot
.54044 .5638 Mdot
.6282 .45739 Mdot
.88812 .36201 Mdot
.30238 .50164 Mdot
.49072 .51024 Mdot
.66514 .38317 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50033 .61758 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60341 Mdot
.53449 .57169 Mdot
.60948 .478 Mdot
.83606 .35151 Mdot
.2673 .49818 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48784 .01642 Mdot
.46127 .05197 Mdot
.37719 .15486 Mdot
.12662 .26024 Mdot
.70554 .11842 Mdot
.51393 .10552 Mdot
.34319 .22849 Mdot
.9735 .20403 Mdot
.64337 .08838 Mdot
.5002 .61776 Mdot
.50065 .61716 Mdot
.50207 .61523 Mdot
.5066 .60912 Mdot
.52103 .58967 Mdot
.56692 .52945 Mdot
.71026 .38648 Mdot
.08492 .46152 Mdot
.33816 .587 Mdot
.38837 .06418 Mdot
.28453 .20826 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50587 .6101 Mdot
.51871 .5928 Mdot
.55954 .53887 Mdot
.68763 .40252 Mdot
.03634 .43591 Mdot
.33102 .56475 Mdot
.41723 .02004 Mdot
.3848 .11775 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.4954 .00621 Mdot
.48534 .01978 Mdot
.45333 .06243 Mdot
.35232 .18051 Mdot
.06024 .23504 Mdot
.67994 .10156 Mdot
.51561 .08711 Mdot
.37466 .19166 Mdot
.06454 .24987 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49046 .01288 Mdot
.46962 .04087 Mdot
.40349 .12496 Mdot
.2013 .26565 Mdot
.77146 .11945 Mdot
.5782 .04984 Mdot
.49756 .0521 Mdot
.41327 .12858 Mdot
.20522 .27032 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49345 .00885 Mdot
.47912 .02815 Mdot
.43357 .08796 Mdot
.29124 .23058 Mdot
.91816 .15801 Mdot
.66249 .03221 Mdot
.61038 .55592 Mdot
.71088 .41281 Mdot
.04294 .45214 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00556 Mdot
.48688 .01772 Mdot
.45821 .05601 Mdot
.36759 .16508 Mdot
.10048 .25217 Mdot
.69247 .11416 Mdot
.50775 .10697 Mdot
.33467 .23413 Mdot
.95584 .19372 Mdot
.64241 .07862 Mdot
.50118 .61644 Mdot
.50377 .61294 Mdot
.51201 .60182 Mdot
.53824 .56671 Mdot
.62128 .46485 Mdot
.86914 .35675 Mdot
.29191 .49921 Mdot
.48417 .51386 Mdot
.65274 .39302 Mdot
.01682 .40858 Mdot
.35572 .52476 Mdot
.50074 .61704 Mdot
.50235 .61485 Mdot
.5075 .60791 Mdot
.52388 .58585 Mdot
.57596 .51808 Mdot
.73769 .37097 Mdot
.13745 .48313 Mdot
.35572 .59931 Mdot
.38602 .07814 Mdot
.25959 .22541 Mdot
.89487 .13488 Mdot
.49984 .00021 Mdot
.49951 .00067 Mdot
.49842 .00213 Mdot
.49498 .00679 Mdot
.48399 .0216 Mdot
.44904 .06805 Mdot
.33893 .19315 Mdot
.02641 .21752 Mdot
.67445 .08629 Mdot
.53484 .05425 Mdot
.44706 .10243 Mdot
.28133 .24712 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50653 .60922 Mdot
.52079 .59 Mdot
.56616 .53042 Mdot
.70792 .388 Mdot
.08012 .45918 Mdot
.33715 .58515 Mdot
.39036 .06091 Mdot
.29181 .20339 Mdot
.96272 .16914 Mdot
.50062 .61719 Mdot
.50199 .61534 Mdot
.50634 .60947 Mdot
.5202 .59079 Mdot
.56429 .5328 Mdot
.7022 .39186 Mdot
.06816 .45313 Mdot
.33498 .58014 Mdot
.39629 .05159 Mdot
.31281 .18779 Mdot
.00896 .19609 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48656 .01815 Mdot
.4572 .05735 Mdot
.3644 .16839 Mdot
.09193 .24896 Mdot
.68911 .11208 Mdot
.50776 .10489 Mdot
.33803 .23044 Mdot
.96518 .19841 Mdot
.64414 .08232 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49785 .0029 Mdot
.49316 .00924 Mdot
.4782 .02939 Mdot
.43066 .09165 Mdot
.28236 .23616 Mdot
.90024 .14962 Mdot
.65816 .02597 Mdot
.61614 .54563 Mdot
.73329 .3989 Mdot
.08785 .47627 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51113 .60301 Mdot
.53544 .57043 Mdot
.61247 .47463 Mdot
.8445 .35234 Mdot
.2744 .49815 Mdot
.46838 .52727 Mdot
.61523 .42954 Mdot
.92022 .35864 Mdot
.33993 .48325 Mdot
.50104 .61663 Mdot
.5033 .61357 Mdot
.51052 .60383 Mdot
.5335 .573 Mdot
.60636 .48158 Mdot
.82715 .35103 Mdot
.25917 .49833 Mdot
.45285 .54141 Mdot
.57683 .47292 Mdot
.81164 .3363 Mdot
.26749 .48295 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50531 .61086 Mdot
.51693 .59519 Mdot
.55389 .54618 Mdot
.67014 .41683 Mdot
.9957 .41284 Mdot
.32771 .54315 Mdot
.44888 .58973 Mdot
.49467 .59468 Mdot
.53246 .56479 Mdot
.50002 .61801 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50653 .60922 Mdot
.52079 .59 Mdot
.56615 .53043 Mdot
.70789 .38802 Mdot
.08007 .45915 Mdot
.33714 .58513 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49798 .00272 Mdot
.49358 .00868 Mdot
.47954 .0276 Mdot
.43488 .0863 Mdot
.29525 .22792 Mdot
.92648 .16215 Mdot
.6641 .03558 Mdot
.60653 .56207 Mdot
.69709 .4226 Mdot
.01331 .43493 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49243 .01023 Mdot
.47588 .03251 Mdot
.42328 .10091 Mdot
.25999 .24817 Mdot
.85845 .13357 Mdot
.64233 .01852 Mdot
.61235 .54084 Mdot
.73726 .39377 Mdot
.10013 .48059 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60224 Mdot
.53724 .56803 Mdot
.61814 .46829 Mdot
.86043 .35486 Mdot
.28625 .4986 Mdot
.4795 .51755 Mdot
.64209 .40263 Mdot
.99062 .39394 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48987 .01368 Mdot
.46774 .04338 Mdot
.39755 .13193 Mdot
.18407 .267 Mdot
.75206 .11947 Mdot
.55875 .06623 Mdot
.45159 .11042 Mdot
.27292 .25644 Mdot
.858 .14158 Mdot
.50057 .61726 Mdot
.50181 .61558 Mdot
.50578 .61023 Mdot
.51841 .5932 Mdot
.5586 .54009 Mdot
.68471 .40479 Mdot
.02975 .43221 Mdot
.33042 .56131 Mdot
.4222 .01256 Mdot
.40187 .09788 Mdot
.2435 .2453 Mdot
.50057 .61727 Mdot
.50181 .61558 Mdot
.50578 .61023 Mdot
.5184 .59321 Mdot
.55857 .54013 Mdot
.68461 .40487 Mdot
.02952 .43208 Mdot
.3304 .56119 Mdot
.42238 .0123 Mdot
.40248 .09716 Mdot
.24527 .24464 Mdot
.50023 .61772 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50757 .6078 Mdot
.52413 .58552 Mdot
.57674 .51711 Mdot
.74004 .36985 Mdot
.14161 .48448 Mdot
.3577 .59951 Mdot
.38767 .07718 Mdot
.26279 .22425 Mdot
.50012 .61787 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51272 .60086 Mdot
.54051 .56371 Mdot
.62842 .45716 Mdot
.88871 .3622 Mdot
.30267 .50174 Mdot
.49084 .51022 Mdot
.66528 .38309 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01285 Mdot
.46968 .04079 Mdot
.40368 .12473 Mdot
.20187 .26558 Mdot
.77215 .11946 Mdot
.57886 .04931 Mdot
.49908 .05016 Mdot
.41792 .12293 Mdot
.21901 .26769 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01324 Mdot
.46876 .04201 Mdot
.40078 .12815 Mdot
.19343 .26647 Mdot
.76227 .11937 Mdot
.56913 .05728 Mdot
.47645 .07903 Mdot
.34857 .19917 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49846 .00208 Mdot
.4951 .00663 Mdot
.48437 .02109 Mdot
.45025 .06646 Mdot
.34272 .18966 Mdot
.03584 .22261 Mdot
.67565 .09087 Mdot
.52861 .06449 Mdot
.42426 .13209 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .00239 Mdot
.49435 .00763 Mdot
.48201 .02427 Mdot
.44274 .07622 Mdot
.31941 .20996 Mdot
.97969 .19118 Mdot
.67035 .06172 Mdot
.57048 .61653 Mdot
.57291 .55128 Mdot
.68093 .41741 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .0133 Mdot
.46863 .0422 Mdot
.40035 .12866 Mdot
.19218 .26657 Mdot
.76085 .11937 Mdot
.56771 .05848 Mdot
.47309 .08331 Mdot
.33828 .20873 Mdot
.00055 .20924 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.4948 .00702 Mdot
.48344 .02235 Mdot
.44728 .07033 Mdot
.33349 .19804 Mdot
.01305 .21013 Mdot
.67306 .07949 Mdot
.54445 .03881 Mdot
.48165 .05578 Mdot
.50044 .61745 Mdot
.50139 .61616 Mdot
.50442 .61207 Mdot
.51407 .59904 Mdot
.54482 .55804 Mdot
.64189 .44324 Mdot
.92472 .37602 Mdot
.3163 .51095 Mdot
.48957 .52061 Mdot
.6472 .40279 Mdot
.99546 .39859 Mdot
.50126 .61633 Mdot
.50403 .61259 Mdot
.51283 .60071 Mdot
.54086 .56325 Mdot
.62951 .456 Mdot
.89168 .36316 Mdot
.30408 .50227 Mdot
.49139 .51025 Mdot
.66578 .38289 Mdot
.04625 .42517 Mdot
.35832 .53984 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49069 .01257 Mdot
.47034 .03991 Mdot
.40577 .12225 Mdot
.20798 .26468 Mdot
.77972 .1197 Mdot
.58605 .04376 Mdot
.51525 .02964 Mdot
.46728 .05976 Mdot
.50054 .6173 Mdot
.50172 .61571 Mdot
.50548 .61063 Mdot
.51746 .59447 Mdot
.55558 .54399 Mdot
.67539 .41236 Mdot
.00818 .41994 Mdot
.3287 .54981 Mdot
.43909 .60491 Mdot
.46033 .02327 Mdot
.42267 .09217 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50441 .61208 Mdot
.51404 .59908 Mdot
.5447 .55819 Mdot
.64153 .4436 Mdot
.92377 .3756 Mdot
.31603 .51063 Mdot
.48981 .52007 Mdot
.64832 .40163 Mdot
.99848 .40021 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50622 .60963 Mdot
.51981 .59131 Mdot
.56305 .53438 Mdot
.69841 .39452 Mdot
.06007 .44889 Mdot
.33375 .57648 Mdot
.40099 .04442 Mdot
.32911 .17411 Mdot
.04739 .2174 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.4981 .00256 Mdot
.49396 .00816 Mdot
.48076 .02595 Mdot
.43877 .08132 Mdot
.30719 .21944 Mdot
.95213 .17573 Mdot
.66779 .04743 Mdot
.59105 .58559 Mdot
.50083 .61691 Mdot
.50264 .61446 Mdot
.50842 .60667 Mdot
.52681 .58193 Mdot
.58524 .50663 Mdot
.76549 .35979 Mdot
.18334 .49458 Mdot
.3831 .59347 Mdot
.42285 .04419 Mdot
.35135 .16281 Mdot
.08791 .24023 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51255 .60109 Mdot
.53995 .56444 Mdot
.62667 .45903 Mdot
.88395 .36072 Mdot
.30028 .50096 Mdot
.48971 .5105 Mdot
.6637 .38412 Mdot
.04219 .42277 Mdot
.35813 .53755 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49256 .01004 Mdot
.47631 .03193 Mdot
.42465 .09919 Mdot
.26416 .24616 Mdot
.86587 .13601 Mdot
.64579 .01898 Mdot
.61508 .53939 Mdot
.74233 .39202 Mdot
.10804 .48465 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49237 .0103 Mdot
.47571 .03273 Mdot
.42275 .10156 Mdot
.25842 .2489 Mdot
.85568 .13271 Mdot
.64095 .01846 Mdot
.61108 .54167 Mdot
.73464 .39482 Mdot
.09581 .47837 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50808 .60712 Mdot
.52574 .58336 Mdot
.58184 .51079 Mdot
.75537 .36333 Mdot
.1675 .49149 Mdot
.37225 .5976 Mdot
.40531 .06226 Mdot
.30458 .20121 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00194 Mdot
.49542 .00618 Mdot
.48542 .01969 Mdot
.45356 .06213 Mdot
.35304 .17981 Mdot
.0621 .23593 Mdot
.68035 .10229 Mdot
.51484 .08855 Mdot
.37157 .19511 Mdot
.05588 .24585 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01453 Mdot
.46572 .04606 Mdot
.39119 .13926 Mdot
.16587 .26666 Mdot
.7344 .11983 Mdot
.54052 .08267 Mdot
.40676 .16425 Mdot
.141 .27852 Mdot
.69034 .14122 Mdot
.5 .61803 Mdot
.50002 .61801 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50051 .61735 Mdot
.50161 .61585 Mdot
.50514 .61108 Mdot
.51639 .59592 Mdot
.55217 .54842 Mdot
.66482 .4215 Mdot
.98281 .4056 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51021 .60424 Mdot
.53253 .57429 Mdot
.60331 .4851 Mdot
.81841 .35097 Mdot
.25052 .49852 Mdot
.4439 .54946 Mdot
.55486 .4996 Mdot
.74649 .35209 Mdot
.17679 .4843 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.5065 .60925 Mdot
.5207 .59011 Mdot
.56588 .53077 Mdot
.70708 .38856 Mdot
.07837 .45831 Mdot
.33681 .58445 Mdot
.39114 .05965 Mdot
.29463 .20143 Mdot
.9687 .1726 Mdot
.50014 .61784 Mdot
.50045 .61742 Mdot
.50144 .61609 Mdot
.50459 .61184 Mdot
.51461 .59832 Mdot
.54651 .55581 Mdot
.64719 .43799 Mdot
.93851 .38239 Mdot
.31978 .51598 Mdot
.48491 .52995 Mdot
.62743 .42404 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48762 .01672 Mdot
.46057 .0529 Mdot
.37498 .15724 Mdot
.12057 .25862 Mdot
.70211 .11771 Mdot
.51166 .10691 Mdot
.33867 .23214 Mdot
.96306 .1982 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49836 .00222 Mdot
.49477 .00707 Mdot
.48333 .02249 Mdot
.44693 .07078 Mdot
.33241 .19899 Mdot
.01044 .20866 Mdot
.67282 .07812 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49458 .00732 Mdot
.48275 .02328 Mdot
.44508 .07319 Mdot
.32666 .20395 Mdot
.99666 .20085 Mdot
.67167 .07082 Mdot
.55709 .01903 Mdot
.5263 .61279 Mdot
.53479 .5808 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49363 .0086 Mdot
.47971 .02736 Mdot
.43545 .08557 Mdot
.29699 .22673 Mdot
.93013 .16402 Mdot
.66474 .03715 Mdot
.60464 .56501 Mdot
.69043 .42769 Mdot
.99842 .42622 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.49251 .01012 Mdot
.47614 .03216 Mdot
.42411 .09987 Mdot
.26251 .24696 Mdot
.86292 .13502 Mdot
.64445 .01875 Mdot
.61411 .53983 Mdot
.74065 .39254 Mdot
.1055 .48334 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49624 .00508 Mdot
.48802 .01618 Mdot
.46183 .05122 Mdot
.37895 .15293 Mdot
.1315 .26144 Mdot
.70849 .11888 Mdot
.51614 .10395 Mdot
.34794 .22443 Mdot
.98482 .21037 Mdot
.64443 .09411 Mdot
.50036 .61755 Mdot
.50114 .6165 Mdot
.50362 .61314 Mdot
.51154 .60246 Mdot
.53674 .5687 Mdot
.61657 .47004 Mdot
.85603 .35404 Mdot
.28318 .49839 Mdot
.47676 .51986 Mdot
.6356 .40882 Mdot
.97411 .38493 Mdot
.49982 .00024 Mdot
.49943 .00076 Mdot
.4982 .00244 Mdot
.49425 .00776 Mdot
.4817 .02469 Mdot
.44174 .0775 Mdot
.31635 .21241 Mdot
.97266 .18719 Mdot
.66978 .05799 Mdot
.57595 .60826 Mdot
.59177 .52782 Mdot
.73774 .38071 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.5283 .57993 Mdot
.58995 .50091 Mdot
.77947 .35589 Mdot
.20363 .49721 Mdot
.39912 .58459 Mdot
.45323 .00929 Mdot
.4382 .06516 Mdot
.33277 .1932 Mdot
.49988 .00017 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48722 .01725 Mdot
.4593 .05457 Mdot
.371 .1615 Mdot
.10969 .25532 Mdot
.69657 .11602 Mdot
.50885 .10781 Mdot
.33441 .23509 Mdot
.95402 .19306 Mdot
.50125 .61635 Mdot
.50398 .61266 Mdot
.51267 .60093 Mdot
.54034 .56393 Mdot
.62789 .45773 Mdot
.88727 .36174 Mdot
.30196 .50149 Mdot
.49053 .51027 Mdot
.6649 .38331 Mdot
.04469 .4242 Mdot
.35832 .53887 Mdot
.50015 .61784 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50475 .61162 Mdot
.51512 .59763 Mdot
.54814 .55368 Mdot
.65226 .43309 Mdot
.95151 .38883 Mdot
.32237 .52138 Mdot
.47876 .54102 Mdot
.60337 .45178 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00168 Mdot
.49603 .00537 Mdot
.48734 .01709 Mdot
.45969 .05407 Mdot
.3722 .16021 Mdot
.11297 .25637 Mdot
.69816 .11658 Mdot
.50952 .10776 Mdot
.33517 .23468 Mdot
.95545 .19392 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51041 .60397 Mdot
.53316 .57346 Mdot
.60529 .48282 Mdot
.82407 .35096 Mdot
.2562 .4984 Mdot
.44977 .54419 Mdot
.56926 .48199 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00565 Mdot
.48667 .018 Mdot
.45755 .05689 Mdot
.3655 .16725 Mdot
.09488 .25009 Mdot
.69022 .11284 Mdot
.50765 .10575 Mdot
.33654 .23201 Mdot
.96113 .19634 Mdot
.64345 .08064 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49547 .00612 Mdot
.48557 .01947 Mdot
.45406 .06147 Mdot
.3546 .17828 Mdot
.06614 .23785 Mdot
.6813 .10384 Mdot
.51329 .09153 Mdot
.36519 .20209 Mdot
.03821 .23717 Mdot
.4997 .00041 Mdot
.49903 .0013 Mdot
.49692 .00416 Mdot
.4902 .01324 Mdot
.46878 .042 Mdot
.40082 .1281 Mdot
.19355 .26646 Mdot
.7624 .11937 Mdot
.56926 .05716 Mdot
.47677 .07862 Mdot
.34957 .19822 Mdot
.02884 .22481 Mdot
.50118 .61644 Mdot
.50375 .61297 Mdot
.51194 .60191 Mdot
.53804 .56698 Mdot
.62064 .46555 Mdot
.86736 .35634 Mdot
.2908 .49906 Mdot
.4833 .51451 Mdot
.65081 .3947 Mdot
.01217 .40598 Mdot
.35529 .52239 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.5047 .61168 Mdot
.51497 .59782 Mdot
.54767 .55429 Mdot
.65082 .43448 Mdot
.94782 .38696 Mdot
.3217 .51979 Mdot
.48066 .53767 Mdot
.61069 .44313 Mdot
.89369 .35174 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00306 Mdot
.49278 .00975 Mdot
.477 .031 Mdot
.42683 .09647 Mdot
.27075 .24276 Mdot
.87795 .14038 Mdot
.65081 .02058 Mdot
.61751 .53931 Mdot
.74489 .39184 Mdot
.11088 .48652 Mdot
.50035 .61755 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51148 .60254 Mdot
.53655 .56896 Mdot
.61596 .47072 Mdot
.85432 .35375 Mdot
.28194 .49833 Mdot
.47562 .52085 Mdot
.63288 .41148 Mdot
.96708 .38118 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49632 .00497 Mdot
.48828 .01583 Mdot
.46266 .05013 Mdot
.38155 .15008 Mdot
.13871 .263 Mdot
.71316 .11939 Mdot
.51999 .10091 Mdot
.35671 .21651 Mdot
.00639 .22243 Mdot
.64648 .10501 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51165 .6023 Mdot
.53712 .5682 Mdot
.61775 .46873 Mdot
.85933 .35465 Mdot
.28549 .49854 Mdot
.47884 .5181 Mdot
.64054 .40409 Mdot
.9867 .39178 Mdot
.35279 .50961 Mdot
.50047 .6174 Mdot
.5015 .616 Mdot
.50479 .61156 Mdot
.51527 .59742 Mdot
.54863 .55303 Mdot
.65381 .43162 Mdot
.95543 .39084 Mdot
.32303 .52312 Mdot
.47661 .54473 Mdot
.59521 .46164 Mdot
.84827 .34133 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00806 Mdot
.48099 .02564 Mdot
.43951 .08038 Mdot
.30945 .21775 Mdot
.95713 .17848 Mdot
.66834 .04994 Mdot
.58753 .59085 Mdot
.63151 .48234 Mdot
.85107 .36356 Mdot
.50019 .61778 Mdot
.50059 .61723 Mdot
.50189 .61548 Mdot
.50602 .6099 Mdot
.51919 .59215 Mdot
.56108 .5369 Mdot
.69235 .39893 Mdot
.04687 .44175 Mdot
.33209 .5701 Mdot
.40965 .0314 Mdot
.35883 .14578 Mdot
.50036 .61755 Mdot
.50113 .6165 Mdot
.50362 .61315 Mdot
.51152 .60248 Mdot
.53669 .56876 Mdot
.61642 .47021 Mdot
.8556 .35397 Mdot
.28287 .49838 Mdot
.47648 .52011 Mdot
.63493 .40947 Mdot
.97238 .384 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.49771 .0031 Mdot
.4927 .00986 Mdot
.47674 .03135 Mdot
.42601 .0975 Mdot
.26825 .24408 Mdot
.87333 .13866 Mdot
.64898 .01985 Mdot
.61686 .53902 Mdot
.74471 .39156 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49626 .00506 Mdot
.48807 .01611 Mdot
.46201 .051 Mdot
.3795 .15234 Mdot
.13301 .26178 Mdot
.70944 .119 Mdot
.51688 .10338 Mdot
.34961 .22296 Mdot
.98884 .21263 Mdot
.6448 .09616 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50042 .61746 Mdot
.50134 .61622 Mdot
.50428 .61226 Mdot
.51362 .59965 Mdot
.54337 .55993 Mdot
.63738 .44781 Mdot
.9128 .37096 Mdot
.31258 .50725 Mdot
.49183 .51481 Mdot
.50132 .61624 Mdot
.50422 .61233 Mdot
.51345 .59988 Mdot
.54283 .56065 Mdot
.63567 .44957 Mdot
.90824 .36914 Mdot
.31096 .506 Mdot
.49223 .5132 Mdot
.66187 .3877 Mdot
.03455 .41948 Mdot
.35582 .5356 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00424 Mdot
.49 .01351 Mdot
.46815 .04284 Mdot
.39883 .13044 Mdot
.18778 .26685 Mdot
.75601 .11941 Mdot
.5628 .06269 Mdot
.46137 .09815 Mdot
.30255 .23773 Mdot
.9179 .16495 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00312 Mdot
.49264 .00994 Mdot
.47655 .03161 Mdot
.42541 .09825 Mdot
.26644 .24501 Mdot
.87 .13745 Mdot
.64759 .01941 Mdot
.61618 .53906 Mdot
.74397 .39162 Mdot
.11032 .4859 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00383 Mdot
.49098 .01218 Mdot
.47126 .03868 Mdot
.40868 .11877 Mdot
.2165 .26306 Mdot
.79086 .12035 Mdot
.59613 .03655 Mdot
.53699 .00257 Mdot
.53283 .59039 Mdot
.57756 .5213 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00537 Mdot
.48733 .01711 Mdot
.45964 .05412 Mdot
.37207 .16036 Mdot
.1126 .25625 Mdot
.69798 .11652 Mdot
.50944 .10777 Mdot
.33506 .23474 Mdot
.95524 .19379 Mdot
.64168 .07912 Mdot
.50019 .61777 Mdot
.50062 .6172 Mdot
.50196 .61538 Mdot
.50626 .60958 Mdot
.51993 .59115 Mdot
.56344 .53389 Mdot
.69959 .39368 Mdot
.0626 .45023 Mdot
.33411 .57764 Mdot
.39947 .04673 Mdot
.32385 .17868 Mdot
.50099 .61669 Mdot
.50316 .61377 Mdot
.51007 .60444 Mdot
.53206 .57492 Mdot
.60182 .48683 Mdot
.81411 .3511 Mdot
.24602 .4986 Mdot
.43927 .55354 Mdot
.54363 .5136 Mdot
.71261 .3701 Mdot
.11377 .46682 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51085 .60338 Mdot
.53457 .57158 Mdot
.60974 .47771 Mdot
.83678 .35157 Mdot
.26794 .49817 Mdot
.46188 .53318 Mdot
.59917 .44708 Mdot
.87578 .34326 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.4872 .01727 Mdot
.45925 .05464 Mdot
.37085 .16165 Mdot
.10929 .25519 Mdot
.69638 .11594 Mdot
.50878 .10781 Mdot
.33434 .23511 Mdot
.95392 .19299 Mdot
.64166 .07833 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49304 .0094 Mdot
.47782 .0299 Mdot
.42945 .09318 Mdot
.27867 .23834 Mdot
.89303 .14647 Mdot
.65603 .02391 Mdot
.61735 .54274 Mdot
.73918 .39554 Mdot
.09918 .48165 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50641 .60937 Mdot
.52043 .59048 Mdot
.56502 .53186 Mdot
.70445 .39032 Mdot
.0729 .45556 Mdot
.33578 .58219 Mdot
.39378 .05547 Mdot
.30403 .1946 Mdot
.98916 .18456 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.50492 .61139 Mdot
.51567 .59689 Mdot
.54988 .5514 Mdot
.65769 .42799 Mdot
.96519 .39598 Mdot
.32449 .52765 Mdot
.47073 .55464 Mdot
.57331 .48905 Mdot
.78201 .34448 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48712 .01738 Mdot
.459 .05497 Mdot
.37005 .1625 Mdot
.10712 .25447 Mdot
.69537 .11554 Mdot
.50843 .10773 Mdot
.33412 .23514 Mdot
.95366 .19279 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.48681 .01781 Mdot
.45798 .05632 Mdot
.36686 .16584 Mdot
.09852 .25146 Mdot
.69166 .11371 Mdot
.50767 .10661 Mdot
.33518 .23352 Mdot
.95733 .19444 Mdot
.64273 .07916 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48936 .01437 Mdot
.46611 .04555 Mdot
.3924 .13788 Mdot
.16931 .26686 Mdot
.73752 .11977 Mdot
.54372 .07974 Mdot
.4147 .15509 Mdot
.16375 .2815 Mdot
.70828 .13899 Mdot
.50031 .61761 Mdot
.501 .61668 Mdot
.50319 .61373 Mdot
.51016 .60431 Mdot
.53236 .57452 Mdot
.60276 .48574 Mdot
.81681 .35101 Mdot
.24887 .49855 Mdot
.4422 .55097 Mdot
.55071 .50474 Mdot
.73402 .35794 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49776 .00303 Mdot
.49286 .00965 Mdot
.47725 .03067 Mdot
.42762 .09548 Mdot
.27314 .24147 Mdot
.88243 .14212 Mdot
.65248 .02142 Mdot
.61781 .53994 Mdot
.74417 .39249 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49546 .00613 Mdot
.48555 .01951 Mdot
.45399 .06157 Mdot
.35436 .17852 Mdot
.06552 .23755 Mdot
.68115 .1036 Mdot
.51352 .09108 Mdot
.36615 .20105 Mdot
.04084 .2385 Mdot
.50086 .61687 Mdot
.50276 .61431 Mdot
.50878 .60618 Mdot
.52796 .58039 Mdot
.58888 .50221 Mdot
.77629 .35667 Mdot
.19918 .49676 Mdot
.39541 .58689 Mdot
.4458 .01813 Mdot
.41647 .09206 Mdot
.2675 .23872 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00515 Mdot
.48784 .01641 Mdot
.46129 .05195 Mdot
.37723 .1548 Mdot
.12675 .26028 Mdot
.70562 .11843 Mdot
.51399 .10548 Mdot
.34331 .22839 Mdot
.97377 .20418 Mdot
.6434 .08852 Mdot
.50075 .61702 Mdot
.50238 .61481 Mdot
.5076 .60777 Mdot
.5242 .58543 Mdot
.57696 .51683 Mdot
.74071 .36954 Mdot
.14279 .48485 Mdot
.35828 .59955 Mdot
.3882 .07684 Mdot
.26386 .22383 Mdot
.9017 .13838 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .6029 Mdot
.5357 .57008 Mdot
.6133 .47369 Mdot
.84685 .35263 Mdot
.27628 .49817 Mdot
.47022 .52562 Mdot
.61976 .42478 Mdot
.93245 .36402 Mdot
.34345 .48685 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60823 Mdot
.52311 .58688 Mdot
.57351 .52113 Mdot
.7303 .37472 Mdot
.124 .47839 Mdot
.34995 .59778 Mdot
.38272 .07889 Mdot
.25507 .22636 Mdot
.88881 .13146 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60602 Mdot
.52835 .57988 Mdot
.59009 .50075 Mdot
.77986 .35579 Mdot
.20417 .49726 Mdot
.39958 .5843 Mdot
.45417 .00817 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.5076 .60777 Mdot
.52421 .58541 Mdot
.57701 .51677 Mdot
.74086 .36947 Mdot
.14304 .48493 Mdot
.35841 .59955 Mdot
.38831 .07677 Mdot
.26411 .22373 Mdot
.9021 .13859 Mdot
.50076 .617 Mdot
.50243 .61474 Mdot
.50776 .60756 Mdot
.52471 .58474 Mdot
.57858 .51482 Mdot
.74558 .36733 Mdot
.15122 .48736 Mdot
.36265 .59946 Mdot
.3927 .07353 Mdot
.27373 .21944 Mdot
.91866 .14728 Mdot
.50011 .61788 Mdot
.50036 .61754 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.5118 .6021 Mdot
.53758 .56759 Mdot
.61921 .46712 Mdot
.86339 .35546 Mdot
.28823 .49877 Mdot
.4812 .51616 Mdot
.64605 .39898 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .0048 Mdot
.48867 .0153 Mdot
.46392 .04846 Mdot
.3855 .14568 Mdot
.14978 .26493 Mdot
.72111 .11981 Mdot
.52726 .09467 Mdot
.37408 .19959 Mdot
.05113 .24619 Mdot
.50067 .61713 Mdot
.50214 .61514 Mdot
.50682 .60882 Mdot
.52173 .58874 Mdot
.56913 .52665 Mdot
.71699 .38227 Mdot
.09846 .46784 Mdot
.34149 .59167 Mdot
.38415 .0718 Mdot
.26797 .2184 Mdot
.91459 .14297 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00325 Mdot
.49234 .01035 Mdot
.47559 .03289 Mdot
.42239 .10202 Mdot
.25731 .24941 Mdot
.85376 .13213 Mdot
.63998 .01845 Mdot
.61012 .54235 Mdot
.73258 .39569 Mdot
.09234 .47657 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50455 .61189 Mdot
.5145 .59846 Mdot
.54616 .55627 Mdot
.6461 .43906 Mdot
.93569 .38105 Mdot
.31914 .51489 Mdot
.48603 .52783 Mdot
.63198 .41903 Mdot
.95397 .37695 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.50649 .60927 Mdot
.52068 .59015 Mdot
.5658 .53087 Mdot
.70683 .38872 Mdot
.07786 .45806 Mdot
.33671 .58425 Mdot
.39138 .05927 Mdot
.29547 .20084 Mdot
.9705 .17365 Mdot
.50061 .61721 Mdot
.50193 .61542 Mdot
.50616 .60971 Mdot
.51963 .59156 Mdot
.56247 .53512 Mdot
.69663 .39579 Mdot
.05623 .44684 Mdot
.33323 .57467 Mdot
.40339 .04079 Mdot
.33739 .16665 Mdot
.06774 .22757 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60081 Mdot
.54062 .56357 Mdot
.62874 .45681 Mdot
.8896 .36248 Mdot
.30309 .50189 Mdot
.49102 .51022 Mdot
.66547 .383 Mdot
.04576 .42484 Mdot
.35836 .53949 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51159 .60238 Mdot
.53691 .56847 Mdot
.61711 .46944 Mdot
.85754 .35431 Mdot
.28425 .49846 Mdot
.47773 .51904 Mdot
.63791 .4066 Mdot
.98003 .38813 Mdot
.35202 .50638 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46217 .05079 Mdot
.37999 .15179 Mdot
.13438 .26209 Mdot
.71031 .11911 Mdot
.51759 .10283 Mdot
.3512 .22154 Mdot
.99274 .21481 Mdot
.64516 .09814 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39525 .1346 Mdot
.17747 .26708 Mdot
.74532 .1196 Mdot
.5518 .07243 Mdot
.43461 .13135 Mdot
.22208 .27663 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.5125 .60116 Mdot
.53979 .56466 Mdot
.62616 .45957 Mdot
.88256 .36031 Mdot
.29957 .50076 Mdot
.48932 .51065 Mdot
.66307 .38458 Mdot
.04081 .422 Mdot
.35801 .53685 Mdot
.50086 .61687 Mdot
.50276 .61431 Mdot
.50878 .60618 Mdot
.52796 .58039 Mdot
.58887 .50222 Mdot
.77626 .35668 Mdot
.19915 .49675 Mdot
.39538 .58691 Mdot
.44574 .0182 Mdot
.41629 .09228 Mdot
.26697 .23899 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49485 .00695 Mdot
.48361 .02212 Mdot
.44781 .06964 Mdot
.33514 .19657 Mdot
.01708 .21238 Mdot
.67345 .08157 Mdot
.54147 .04356 Mdot
.47098 .07032 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51244 .60123 Mdot
.53963 .56487 Mdot
.62565 .46011 Mdot
.88117 .35991 Mdot
.29883 .50056 Mdot
.4889 .51084 Mdot
.66234 .38511 Mdot
.03922 .4211 Mdot
.35786 .53604 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.5114 .60264 Mdot
.5363 .56928 Mdot
.6152 .47157 Mdot
.85219 .3534 Mdot
.28037 .49827 Mdot
.47415 .52213 Mdot
.62933 .415 Mdot
.95785 .37638 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56064 Mdot
.63571 .44953 Mdot
.90835 .36918 Mdot
.31099 .50603 Mdot
.49223 .51323 Mdot
.66181 .38776 Mdot
.03439 .4194 Mdot
.35579 .53553 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00124 Mdot
.49709 .00394 Mdot
.49072 .01253 Mdot
.47044 .03978 Mdot
.40608 .12188 Mdot
.20886 .26453 Mdot
.78085 .11975 Mdot
.58709 .04298 Mdot
.51756 .02673 Mdot
.47431 .05045 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01162 Mdot
.47259 .03691 Mdot
.41287 .11371 Mdot
.22889 .25996 Mdot
.80827 .12219 Mdot
.61056 .02774 Mdot
.56567 .58661 Mdot
.61652 .48798 Mdot
.82695 .35735 Mdot
.50057 .61726 Mdot
.50183 .61557 Mdot
.50582 .61017 Mdot
.51855 .59301 Mdot
.55903 .53953 Mdot
.68605 .40374 Mdot
.03278 .43391 Mdot
.33069 .5629 Mdot
.4199 .01603 Mdot
.39397 .10721 Mdot
.22049 .25223 Mdot
.49978 .0003 Mdot
.49929 .00097 Mdot
.49772 .00308 Mdot
.49274 .0098 Mdot
.47689 .03115 Mdot
.42648 .09691 Mdot
.26967 .24333 Mdot
.87595 .13963 Mdot
.65003 .02025 Mdot
.61727 .53914 Mdot
.74493 .39167 Mdot
.1112 .48657 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60498 Mdot
.53078 .57662 Mdot
.59779 .49156 Mdot
.80243 .35195 Mdot
.23296 .49865 Mdot
.42613 .5647 Mdot
.51243 .55319 Mdot
.61735 .45399 Mdot
.88278 .35488 Mdot
.49991 .00011 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01184 Mdot
.47207 .03761 Mdot
.41122 .11571 Mdot
.224 .26129 Mdot
.80122 .12132 Mdot
.60492 .03094 Mdot
.55485 .59913 Mdot
.58545 .52367 Mdot
.50113 .6165 Mdot
.50362 .61315 Mdot
.51152 .60248 Mdot
.53669 .56877 Mdot
.6164 .47023 Mdot
.85554 .35396 Mdot
.28283 .49838 Mdot
.47644 .52014 Mdot
.63484 .40956 Mdot
.97215 .38388 Mdot
.35103 .50268 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50504 .61123 Mdot
.51604 .59638 Mdot
.55108 .54984 Mdot
.66142 .42456 Mdot
.97446 .40099 Mdot
.32565 .53218 Mdot
.46456 .56476 Mdot
.55077 .51849 Mdot
.71183 .37517 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49245 .0102 Mdot
.47595 .0324 Mdot
.42352 .1006 Mdot
.26075 .24781 Mdot
.85978 .134 Mdot
.64297 .01858 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60134 Mdot
.53938 .5652 Mdot
.62486 .46096 Mdot
.87901 .35929 Mdot
.29766 .50027 Mdot
.4882 .5112 Mdot
.66106 .3861 Mdot
.03634 .4195 Mdot
.50056 .61727 Mdot
.5018 .61561 Mdot
.50573 .6103 Mdot
.51824 .59342 Mdot
.55807 .54078 Mdot
.68307 .40609 Mdot
.026 .43009 Mdot
.33011 .55934 Mdot
.42508 .00822 Mdot
.41178 .08588 Mdot
.27283 .23191 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48703 .01751 Mdot
.4587 .05536 Mdot
.36912 .16348 Mdot
.10461 .25362 Mdot
.69424 .11504 Mdot
.5081 .10753 Mdot
.33411 .23495 Mdot
.95396 .19286 Mdot
.64191 .07806 Mdot
.50066 .61714 Mdot
.50211 .61518 Mdot
.50673 .60894 Mdot
.52144 .58913 Mdot
.56821 .52782 Mdot
.71418 .38399 Mdot
.09287 .46528 Mdot
.34002 .58985 Mdot
.38563 .06895 Mdot
.27407 .21481 Mdot
.92651 .14907 Mdot
.5011 .61655 Mdot
.50351 .6133 Mdot
.51117 .60295 Mdot
.53558 .57023 Mdot
.61293 .47411 Mdot
.84581 .3525 Mdot
.27545 .49816 Mdot
.46941 .52634 Mdot
.61777 .42685 Mdot
.92711 .36162 Mdot
.342 .48519 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52047 .59043 Mdot
.56514 .53171 Mdot
.70481 .39008 Mdot
.07366 .45595 Mdot
.33592 .58251 Mdot
.3934 .05607 Mdot
.30267 .19561 Mdot
.98617 .18281 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49651 .00471 Mdot
.4889 .015 Mdot
.46463 .04751 Mdot
.38775 .14316 Mdot
.15612 .26577 Mdot
.72609 .11989 Mdot
.53211 .09032 Mdot
.38598 .18721 Mdot
.08307 .26077 Mdot
.66114 .13563 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50516 .61107 Mdot
.51643 .59587 Mdot
.55229 .54826 Mdot
.66519 .42117 Mdot
.98372 .40611 Mdot
.32663 .53688 Mdot
.45794 .57541 Mdot
.5269 .55059 Mdot
.63602 .43929 Mdot
.5001 .6179 Mdot
.5003 .61762 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50985 .60474 Mdot
.53136 .57585 Mdot
.59961 .48942 Mdot
.8077 .35147 Mdot
.23901 .49866 Mdot
.43215 .55967 Mdot
.52659 .53514 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50738 .60806 Mdot
.52352 .58633 Mdot
.57482 .5195 Mdot
.73424 .37268 Mdot
.13124 .48102 Mdot
.35294 .59876 Mdot
.38412 .07891 Mdot
.25643 .22634 Mdot
.89021 .13244 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49357 .00868 Mdot
.47952 .02762 Mdot
.43483 .08636 Mdot
.29509 .22802 Mdot
.92614 .16198 Mdot
.66404 .03544 Mdot
.6067 .5618 Mdot
.69769 .42216 Mdot
.01462 .43569 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00283 Mdot
.49332 .00903 Mdot
.47871 .02871 Mdot
.43226 .08963 Mdot
.28724 .23315 Mdot
.91 .15409 Mdot
.66067 .02918 Mdot
.61346 .55071 Mdot
.72239 .40538 Mdot
.06647 .46523 Mdot
.50019 .61777 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.5063 .60952 Mdot
.52009 .59095 Mdot
.56392 .53327 Mdot
.70106 .39265 Mdot
.06575 .45188 Mdot
.33459 .57907 Mdot
.39764 .04952 Mdot
.3175 .184 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49035 .01303 Mdot
.46927 .04134 Mdot
.40238 .12627 Mdot
.19806 .26603 Mdot
.76761 .11939 Mdot
.57444 .05287 Mdot
.48889 .06316 Mdot
.3867 .15955 Mdot
.12855 .26617 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49357 .00868 Mdot
.47952 .02762 Mdot
.43484 .08635 Mdot
.29512 .22801 Mdot
.9262 .16201 Mdot
.66405 .03546 Mdot
.60667 .56185 Mdot
.69758 .42223 Mdot
.01439 .43556 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53084 .57654 Mdot
.59798 .49134 Mdot
.80297 .35189 Mdot
.2336 .49866 Mdot
.42676 .56418 Mdot
.51389 .55132 Mdot
.62184 .44909 Mdot
.8952 .3588 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49086 .01235 Mdot
.47087 .0392 Mdot
.40745 .12025 Mdot
.21288 .2638 Mdot
.78605 .12002 Mdot
.59185 .03952 Mdot
.52791 .01378 Mdot
.50561 .00858 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49798 .00272 Mdot
.49358 .00868 Mdot
.47954 .02759 Mdot
.43489 .08628 Mdot
.29529 .22789 Mdot
.92656 .1622 Mdot
.66412 .03562 Mdot
.60649 .56213 Mdot
.69694 .42271 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00535 Mdot
.48737 .01705 Mdot
.45979 .05393 Mdot
.37254 .15986 Mdot
.11388 .25665 Mdot
.69861 .11673 Mdot
.50974 .10771 Mdot
.33546 .23449 Mdot
.95605 .19426 Mdot
.64173 .07956 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48657 .01814 Mdot
.45722 .05732 Mdot
.36447 .16832 Mdot
.09212 .24903 Mdot
.68918 .11213 Mdot
.50775 .10495 Mdot
.33793 .23055 Mdot
.96489 .19826 Mdot
.64409 .0822 Mdot
.50131 .61626 Mdot
.50419 .61238 Mdot
.51334 .60003 Mdot
.54247 .56113 Mdot
.63454 .45073 Mdot
.90524 .36799 Mdot
.30983 .50523 Mdot
.49235 .51232 Mdot
.66341 .38608 Mdot
.03872 .42162 Mdot
.35653 .53733 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00354 Mdot
.49165 .01127 Mdot
.47341 .03581 Mdot
.41547 .11054 Mdot
.23662 .25756 Mdot
.81988 .12401 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00569 Mdot
.48659 .0181 Mdot
.4573 .05721 Mdot
.36474 .16804 Mdot
.09284 .24931 Mdot
.68944 .11232 Mdot
.50771 .10517 Mdot
.33754 .23096 Mdot
.96384 .19772 Mdot
.50002 .618 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60702 Mdot
.52596 .58306 Mdot
.58255 .50992 Mdot
.75749 .36254 Mdot
.17089 .49223 Mdot
.37445 .59692 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45943 .05441 Mdot
.3714 .16107 Mdot
.11078 .25567 Mdot
.69709 .11621 Mdot
.50906 .10782 Mdot
.33461 .235 Mdot
.95437 .19328 Mdot
.50075 .61702 Mdot
.5024 .61479 Mdot
.50765 .60771 Mdot
.52436 .58521 Mdot
.57747 .5162 Mdot
.74224 .36883 Mdot
.14546 .48567 Mdot
.35962 .59958 Mdot
.38948 .07597 Mdot
.26656 .22271 Mdot
.9062 .14071 Mdot
.49985 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49531 .00634 Mdot
.48505 .02018 Mdot
.45239 .06367 Mdot
.34937 .18337 Mdot
.05267 .23131 Mdot
.67839 .09845 Mdot
.5191 .08079 Mdot
.38838 .17599 Mdot
.10363 .26541 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50698 .60861 Mdot
.52223 .58807 Mdot
.5707 .52466 Mdot
.72178 .37943 Mdot
.10785 .47193 Mdot
.34424 .59436 Mdot
.38255 .07559 Mdot
.26024 .22283 Mdot
.8997 .13588 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00232 Mdot
.49453 .00739 Mdot
.48256 .02353 Mdot
.44449 .07395 Mdot
.32484 .20548 Mdot
.99237 .19841 Mdot
.67134 .06852 Mdot
.56047 .0138 Mdot
.53815 .5968 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48777 .01652 Mdot
.46104 .05227 Mdot
.37646 .15564 Mdot
.12463 .25973 Mdot
.70438 .1182 Mdot
.51313 .10605 Mdot
.34154 .22985 Mdot
.96963 .20187 Mdot
.643 .08643 Mdot
.49978 .00029 Mdot
.49931 .00094 Mdot
.49779 .00299 Mdot
.49296 .00951 Mdot
.47756 .03024 Mdot
.42863 .09421 Mdot
.27619 .23976 Mdot
.88825 .14447 Mdot
.65449 .0227 Mdot
.61776 .54126 Mdot
.74199 .3939 Mdot
.10464 .48407 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48837 .01571 Mdot
.46295 .04974 Mdot
.38246 .14907 Mdot
.14127 .2635 Mdot
.71492 .11952 Mdot
.52152 .09963 Mdot
.36032 .21313 Mdot
.01547 .22745 Mdot
.64745 .10948 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51077 .6035 Mdot
.53429 .57195 Mdot
.60885 .47873 Mdot
.83425 .35138 Mdot
.26571 .49821 Mdot
.4596 .53526 Mdot
.59353 .45346 Mdot
.85983 .33967 Mdot
.31023 .47677 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49384 .00833 Mdot
.48037 .02648 Mdot
.43752 .08293 Mdot
.30333 .22227 Mdot
.94369 .17115 Mdot
.66676 .04333 Mdot
.59666 .57716 Mdot
.6628 .45121 Mdot
.93272 .39068 Mdot
.50126 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.54089 .56321 Mdot
.6296 .45591 Mdot
.89193 .36324 Mdot
.30419 .50232 Mdot
.49142 .51026 Mdot
.6658 .38289 Mdot
.04628 .42519 Mdot
.35831 .53987 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.5085 .60655 Mdot
.52709 .58156 Mdot
.58611 .50557 Mdot
.76809 .35897 Mdot
.18726 .4952 Mdot
.38601 .59207 Mdot
.42802 .03852 Mdot
.3657 .14876 Mdot
.125 .25309 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00198 Mdot
.49533 .0063 Mdot
.48513 .02007 Mdot
.45266 .06331 Mdot
.35023 .18255 Mdot
.05485 .2324 Mdot
.67882 .09937 Mdot
.51804 .08269 Mdot
.38425 .18078 Mdot
.09174 .2612 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01346 Mdot
.46825 .04271 Mdot
.39915 .13007 Mdot
.18869 .2668 Mdot
.757 .1194 Mdot
.56381 .06182 Mdot
.46378 .09511 Mdot
.30989 .23233 Mdot
.93398 .17286 Mdot
.50057 .61726 Mdot
.50183 .61557 Mdot
.50581 .61018 Mdot
.51852 .59304 Mdot
.55896 .53963 Mdot
.68582 .40392 Mdot
.03227 .43363 Mdot
.33064 .56263 Mdot
.42029 .01545 Mdot
.39529 .10566 Mdot
.22433 .25129 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51227 .60146 Mdot
.53909 .56559 Mdot
.62395 .46195 Mdot
.8765 .35861 Mdot
.29626 .49996 Mdot
.48731 .51172 Mdot
.65933 .38747 Mdot
.03238 .41729 Mdot
.3572 .53261 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51166 .60229 Mdot
.53712 .56819 Mdot
.61778 .4687 Mdot
.85941 .35466 Mdot
.28555 .49854 Mdot
.47889 .51806 Mdot
.64065 .40399 Mdot
.98698 .39194 Mdot
.35282 .50975 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.5055 .6106 Mdot
.51752 .59439 Mdot
.55578 .54373 Mdot
.676 .41185 Mdot
.00961 .42076 Mdot
.32881 .55058 Mdot
.43796 .60664 Mdot
.45639 .02853 Mdot
.41023 .10741 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .6113 Mdot
.51589 .59659 Mdot
.55058 .55048 Mdot
.65988 .42597 Mdot
.97065 .39891 Mdot
.3252 .5303 Mdot
.46716 .56052 Mdot
.56021 .50602 Mdot
.74145 .35869 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51226 .60149 Mdot
.53903 .56567 Mdot
.62376 .46215 Mdot
.87599 .35847 Mdot
.29597 .4999 Mdot
.48711 .51184 Mdot
.65895 .38779 Mdot
.03149 .41679 Mdot
.35711 .53217 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51177 .60214 Mdot
.5375 .56769 Mdot
.61895 .4674 Mdot
.86268 .35532 Mdot
.28777 .49873 Mdot
.48081 .51647 Mdot
.64514 .39981 Mdot
.99823 .39817 Mdot
.35398 .51533 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49213 .01063 Mdot
.47492 .03379 Mdot
.42025 .10466 Mdot
.25091 .2522 Mdot
.84284 .12906 Mdot
.63402 .01898 Mdot
.60331 .54783 Mdot
.71689 .40347 Mdot
.06407 .46127 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49574 .00575 Mdot
.48643 .01832 Mdot
.4568 .05788 Mdot
.36315 .16968 Mdot
.0886 .24764 Mdot
.68791 .11118 Mdot
.50802 .10375 Mdot
.34014 .22826 Mdot
.97081 .20135 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49954 .00061 Mdot
.49855 .00196 Mdot
.49538 .00624 Mdot
.48528 .01987 Mdot
.45314 .06269 Mdot
.35171 .18112 Mdot
.05866 .23427 Mdot
.6796 .10093 Mdot
.5163 .08585 Mdot
.37739 .18859 Mdot
.50023 .61773 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50739 .60805 Mdot
.52354 .5863 Mdot
.57488 .51942 Mdot
.73445 .37257 Mdot
.13161 .48115 Mdot
.3531 .5988 Mdot
.38421 .07889 Mdot
.25657 .22631 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49935 .00088 Mdot
.49793 .00279 Mdot
.49342 .00889 Mdot
.47904 .02826 Mdot
.43331 .0883 Mdot
.29043 .23111 Mdot
.91649 .1572 Mdot
.66214 .03157 Mdot
.61107 .55479 Mdot
.71339 .41113 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00552 Mdot
.48698 .01758 Mdot
.45854 .05557 Mdot
.36862 .164 Mdot
.10326 .25315 Mdot
.69365 .11476 Mdot
.50796 .10738 Mdot
.33422 .23475 Mdot
.95439 .19304 Mdot
.64204 .07816 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50503 .61124 Mdot
.51602 .59642 Mdot
.55099 .54995 Mdot
.66115 .42481 Mdot
.9738 .40063 Mdot
.32557 .53185 Mdot
.46502 .56402 Mdot
.55241 .5163 Mdot
.71702 .37192 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .00399 Mdot
.49058 .01272 Mdot
.47001 .04036 Mdot
.4047 .12352 Mdot
.20485 .26516 Mdot
.7758 .11955 Mdot
.58236 .04656 Mdot
.50702 .04006 Mdot
.4422 .09248 Mdot
.29257 .23477 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48953 .01414 Mdot
.46666 .04482 Mdot
.39413 .13589 Mdot
.17426 .26704 Mdot
.74218 .11967 Mdot
.54855 .07536 Mdot
.42662 .141 Mdot
.19848 .28088 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50748 .60793 Mdot
.52382 .58593 Mdot
.57576 .51832 Mdot
.7371 .37126 Mdot
.1364 .48278 Mdot
.35523 .59924 Mdot
.38565 .07832 Mdot
.25892 .22563 Mdot
.89384 .13436 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51022 .60424 Mdot
.53254 .57428 Mdot
.60334 .48507 Mdot
.81848 .35097 Mdot
.2506 .49852 Mdot
.44398 .54938 Mdot
.55506 .49935 Mdot
.74709 .35183 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00285 Mdot
.49327 .00909 Mdot
.47856 .0289 Mdot
.4318 .09021 Mdot
.28584 .23403 Mdot
.90718 .15277 Mdot
.65999 .0282 Mdot
.61435 .54911 Mdot
.72587 .40326 Mdot
.07338 .4689 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48942 .01428 Mdot
.46631 .04528 Mdot
.39305 .13713 Mdot
.17117 .26694 Mdot
.73925 .11974 Mdot
.54551 .07812 Mdot
.41912 .14991 Mdot
.17656 .28202 Mdot
.72024 .13705 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.50809 .60711 Mdot
.52577 .58332 Mdot
.58195 .51066 Mdot
.75569 .3632 Mdot
.16802 .4916 Mdot
.37259 .5975 Mdot
.4058 .06178 Mdot
.30583 .20034 Mdot
.98167 .18339 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50816 .60702 Mdot
.52598 .58304 Mdot
.58261 .50984 Mdot
.75766 .36247 Mdot
.17117 .49229 Mdot
.37464 .59685 Mdot
.40891 .05873 Mdot
.31388 .19455 Mdot
.9991 .19371 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.51139 .60265 Mdot
.53628 .56931 Mdot
.61512 .47165 Mdot
.85197 .35337 Mdot
.28021 .49826 Mdot
.474 .52226 Mdot
.62897 .41536 Mdot
.95691 .3759 Mdot
.3487 .49597 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51285 .60069 Mdot
.54091 .56318 Mdot
.62966 .45584 Mdot
.8921 .3633 Mdot
.30427 .50235 Mdot
.49145 .51027 Mdot
.66582 .38289 Mdot
.0463 .4252 Mdot
.3583 .53988 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00474 Mdot
.48882 .01509 Mdot
.4644 .04782 Mdot
.38703 .14397 Mdot
.15407 .26552 Mdot
.72445 .11987 Mdot
.53049 .09178 Mdot
.382 .19142 Mdot
.07227 .25614 Mdot
.65783 .13266 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50934 .60543 Mdot
.52974 .57802 Mdot
.59449 .49548 Mdot
.79278 .35323 Mdot
.22124 .49838 Mdot
.41485 .5736 Mdot
.48675 .58587 Mdot
.53879 .55027 Mdot
.64843 .43177 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51319 .60023 Mdot
.542 .56175 Mdot
.63307 .45226 Mdot
.9013 .36651 Mdot
.30827 .50428 Mdot
.49233 .51139 Mdot
.66488 .38445 Mdot
.04282 .42367 Mdot
.35731 .53893 Mdot
.49981 .00026 Mdot
.4994 .00081 Mdot
.49808 .00259 Mdot
.49389 .00825 Mdot
.48054 .02624 Mdot
.43808 .08221 Mdot
.30506 .22101 Mdot
.94746 .17318 Mdot
.66724 .04514 Mdot
.5942 .58085 Mdot
.65436 .45915 Mdot
.91144 .38122 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00366 Mdot
.49136 .01166 Mdot
.47249 .03704 Mdot
.41256 .11408 Mdot
.22797 .26022 Mdot
.80693 .12201 Mdot
.60951 .02831 Mdot
.56371 .58885 Mdot
.61093 .49414 Mdot
.50104 .61663 Mdot
.50331 .61357 Mdot
.51053 .60381 Mdot
.53355 .57294 Mdot
.60652 .48139 Mdot
.82761 .35105 Mdot
.2596 .49832 Mdot
.4533 .541 Mdot
.57795 .47159 Mdot
.8149 .33614 Mdot
.27101 .4824 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48796 .01626 Mdot
.46166 .05146 Mdot
.37839 .15354 Mdot
.12996 .26107 Mdot
.70754 .11875 Mdot
.5154 .10449 Mdot
.34634 .22582 Mdot
.98095 .2082 Mdot
.64407 .09215 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46277 .04998 Mdot
.38191 .14968 Mdot
.13971 .2632 Mdot
.71385 .11945 Mdot
.52058 .10042 Mdot
.3581 .21522 Mdot
.00987 .22436 Mdot
.64684 .10674 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49626 .00505 Mdot
.48809 .01608 Mdot
.46208 .05089 Mdot
.37974 .15207 Mdot
.13368 .26193 Mdot
.70986 .11906 Mdot
.51722 .10312 Mdot
.35037 .22228 Mdot
.99071 .21367 Mdot
.64497 .0971 Mdot
.49995 6e-05 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49532 .00633 Mdot
.48508 .02014 Mdot
.45249 .06354 Mdot
.34968 .18307 Mdot
.05347 .23171 Mdot
.67855 .09879 Mdot
.51871 .08149 Mdot
.38686 .17776 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49711 .0039 Mdot
.4908 .01242 Mdot
.47071 .03942 Mdot
.40693 .12086 Mdot
.21137 .26408 Mdot
.78407 .11991 Mdot
.59006 .0408 Mdot
.52403 .01861 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.5122 .60156 Mdot
.53886 .56589 Mdot
.62324 .46271 Mdot
.87456 .35809 Mdot
.29515 .49974 Mdot
.48655 .51219 Mdot
.6578 .38872 Mdot
.02884 .41531 Mdot
.49962 .00052 Mdot
.49878 .00164 Mdot
.49613 .00523 Mdot
.48766 .01666 Mdot
.4607 .05273 Mdot
.37539 .1568 Mdot
.12167 .25893 Mdot
.70272 .11785 Mdot
.51203 .1067 Mdot
.33938 .23158 Mdot
.96467 .1991 Mdot
.64252 .08394 Mdot
.50069 .61711 Mdot
.50218 .61508 Mdot
.50696 .60864 Mdot
.52216 .58816 Mdot
.5705 .52492 Mdot
.72116 .37979 Mdot
.10665 .47143 Mdot
.34387 .59404 Mdot
.38269 .07518 Mdot
.26104 .22237 Mdot
.90124 .13658 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .0021 Mdot
.49506 .00668 Mdot
.48425 .02125 Mdot
.44986 .06697 Mdot
.3415 .1908 Mdot
.03277 .22097 Mdot
.67524 .08941 Mdot
.53058 .06123 Mdot
.4315 .1228 Mdot
.23281 .26948 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00269 Mdot
.49366 .00856 Mdot
.47981 .02723 Mdot
.43575 .08519 Mdot
.29791 .2261 Mdot
.93208 .16502 Mdot
.66506 .038 Mdot
.60358 .56664 Mdot
.68674 .4306 Mdot
.99001 .42135 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49364 .0086 Mdot
.47972 .02734 Mdot
.43548 .08553 Mdot
.29708 .22667 Mdot
.93032 .16412 Mdot
.66477 .03723 Mdot
.60454 .56517 Mdot
.69008 .42796 Mdot
.99762 .42576 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.4903 .01311 Mdot
.46909 .04158 Mdot
.40181 .12694 Mdot
.19642 .2662 Mdot
.76569 .11937 Mdot
.57254 .05443 Mdot
.48447 .06881 Mdot
.37314 .17435 Mdot
.09104 .25422 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00495 Mdot
.48833 .01576 Mdot
.46284 .04989 Mdot
.38211 .14946 Mdot
.14028 .26331 Mdot
.71423 .11947 Mdot
.52092 .10014 Mdot
.35889 .21447 Mdot
.01187 .22546 Mdot
.64706 .10772 Mdot
.49972 .00038 Mdot
.49909 .00123 Mdot
.49711 .00391 Mdot
.49078 .01245 Mdot
.47065 .03951 Mdot
.40673 .12111 Mdot
.21077 .26419 Mdot
.78329 .11987 Mdot
.58935 .04132 Mdot
.52249 .02054 Mdot
.48925 .0305 Mdot
.4399 .0849 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48983 .01374 Mdot
.4676 .04357 Mdot
.3971 .13245 Mdot
.1828 .26704 Mdot
.75072 .11949 Mdot
.55738 .06744 Mdot
.44826 .11457 Mdot
.49986 .00018 Mdot
.49957 .00059 Mdot
.49862 .00187 Mdot
.49559 .00595 Mdot
.48596 .01895 Mdot
.45529 .05986 Mdot
.35844 .17446 Mdot
.07617 .2424 Mdot
.68395 .10738 Mdot
.51021 .09793 Mdot
.35176 .21633 Mdot
.00173 .21793 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00407 Mdot
.49039 .01297 Mdot
.4694 .04117 Mdot
.40279 .12578 Mdot
.19927 .2659 Mdot
.76904 .11941 Mdot
.57584 .05173 Mdot
.49213 .05902 Mdot
.39663 .14826 Mdot
.15675 .27119 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01163 Mdot
.47258 .03692 Mdot
.41284 .11375 Mdot
.22879 .25998 Mdot
.80812 .12217 Mdot
.61045 .0278 Mdot
.56546 .58685 Mdot
.61593 .48863 Mdot
.82531 .3573 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00443 Mdot
.48955 .01411 Mdot
.46673 .04473 Mdot
.39436 .13563 Mdot
.1749 .26705 Mdot
.7428 .11966 Mdot
.54919 .07478 Mdot
.4282 .13911 Mdot
.20312 .2803 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49065 .01262 Mdot
.47023 .04006 Mdot
.40541 .12267 Mdot
.20692 .26485 Mdot
.77839 .11964 Mdot
.5848 .04469 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49066 .01262 Mdot
.47025 .04004 Mdot
.40546 .12262 Mdot
.20706 .26483 Mdot
.77856 .11965 Mdot
.58496 .04457 Mdot
.51284 .03268 Mdot
.45995 .06942 Mdot
.34763 .19006 Mdot
.50108 .61658 Mdot
.50344 .61339 Mdot
.51095 .60324 Mdot
.53488 .57116 Mdot
.61072 .4766 Mdot
.83957 .35181 Mdot
.27033 .49815 Mdot
.4643 .53097 Mdot
.60518 .44041 Mdot
.89258 .34821 Mdot
.32915 .47788 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51289 .60064 Mdot
.54103 .56302 Mdot
.63005 .45543 Mdot
.89315 .36365 Mdot
.30475 .50255 Mdot
.49161 .51032 Mdot
.66589 .38291 Mdot
.04633 .42526 Mdot
.35825 .53997 Mdot
.50026 .61768 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50838 .60671 Mdot
.5267 .58207 Mdot
.58489 .50705 Mdot
.76446 .36012 Mdot
.18178 .49431 Mdot
.38196 .59398 Mdot
.42088 .04631 Mdot
.34596 .16784 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01452 Mdot
.46575 .04603 Mdot
.39126 .13918 Mdot
.16606 .26668 Mdot
.73457 .11982 Mdot
.54069 .08251 Mdot
.40718 .16377 Mdot
.1422 .27874 Mdot
.69119 .14116 Mdot
.50091 .61681 Mdot
.50288 .61414 Mdot
.50919 .60563 Mdot
.52927 .57865 Mdot
.59299 .49726 Mdot
.78841 .35399 Mdot
.21564 .49811 Mdot
.40968 .57742 Mdot
.4754 .60013 Mdot
.50437 .59608 Mdot
.53989 .55949 Mdot
.50112 .61652 Mdot
.50356 .61323 Mdot
.51134 .60272 Mdot
.53611 .56954 Mdot
.61458 .47226 Mdot
.85045 .35314 Mdot
.27906 .49823 Mdot
.47291 .52322 Mdot
.62632 .41803 Mdot
.94993 .37237 Mdot
.34741 .49313 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49706 .00397 Mdot
.49065 .01263 Mdot
.47021 .04009 Mdot
.40534 .12276 Mdot
.20672 .26488 Mdot
.77813 .11963 Mdot
.58456 .04488 Mdot
.51195 .03381 Mdot
.45724 .07297 Mdot
.33917 .19796 Mdot
.50036 .61755 Mdot
.50113 .61651 Mdot
.5036 .61316 Mdot
.51148 .60253 Mdot
.53658 .56892 Mdot
.61605 .47062 Mdot
.85458 .35379 Mdot
.28213 .49834 Mdot
.47579 .52069 Mdot
.63329 .41107 Mdot
.96816 .38176 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.4919 .01094 Mdot
.47421 .03474 Mdot
.418 .10744 Mdot
.24415 .25489 Mdot
.83173 .12637 Mdot
.62725 .02058 Mdot
.59395 .55649 Mdot
.69354 .41813 Mdot
.01699 .43385 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51022 .60423 Mdot
.53257 .57425 Mdot
.60342 .48498 Mdot
.81871 .35097 Mdot
.25082 .49851 Mdot
.44421 .54918 Mdot
.55563 .49865 Mdot
.7488 .35111 Mdot
.1807 .48488 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49714 .00386 Mdot
.4909 .01229 Mdot
.47102 .039 Mdot
.40791 .11969 Mdot
.21425 .26353 Mdot
.78786 .12014 Mdot
.59347 .03838 Mdot
.53137 .00949 Mdot
.51602 .61269 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49846 .00208 Mdot
.49509 .00663 Mdot
.48437 .02109 Mdot
.45024 .06648 Mdot
.34267 .18971 Mdot
.03571 .22254 Mdot
.67563 .09081 Mdot
.5287 .06435 Mdot
.42457 .13169 Mdot
.21149 .27494 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60224 Mdot
.53725 .56803 Mdot
.61816 .46828 Mdot
.86047 .35487 Mdot
.28628 .4986 Mdot
.47953 .51752 Mdot
.64216 .40258 Mdot
.99078 .39403 Mdot
.35322 .51161 Mdot
.50031 .61762 Mdot
.50098 .6167 Mdot
.50314 .6138 Mdot
.50999 .60454 Mdot
.53182 .57524 Mdot
.60106 .48772 Mdot
.81191 .3512 Mdot
.24366 .49863 Mdot
.43686 .55564 Mdot
.53783 .5209 Mdot
.695 .38207 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.49339 .00892 Mdot
.47896 .02837 Mdot
.43305 .08862 Mdot
.28965 .23161 Mdot
.91489 .15642 Mdot
.6618 .03096 Mdot
.6117 .55374 Mdot
.71573 .4096 Mdot
.05299 .45782 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.49331 .00904 Mdot
.47868 .02874 Mdot
.43218 .08973 Mdot
.28699 .23331 Mdot
.90949 .15385 Mdot
.66055 .029 Mdot
.61363 .55042 Mdot
.72303 .40499 Mdot
.06775 .46591 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50746 .60796 Mdot
.52376 .58602 Mdot
.57555 .51858 Mdot
.73647 .37157 Mdot
.13526 .4824 Mdot
.35472 .59915 Mdot
.38527 .0785 Mdot
.25827 .22584 Mdot
.89285 .13384 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49068 .01258 Mdot
.47033 .03993 Mdot
.40571 .12232 Mdot
.20779 .26471 Mdot
.77949 .11969 Mdot
.58583 .04392 Mdot
.51477 .03025 Mdot
.46583 .06168 Mdot
.36602 .17173 Mdot
.50111 .61654 Mdot
.50353 .61326 Mdot
.51126 .60284 Mdot
.53585 .56988 Mdot
.61376 .47318 Mdot
.84814 .35281 Mdot
.27729 .49819 Mdot
.47121 .52474 Mdot
.62217 .42228 Mdot
.9389 .36702 Mdot
.34505 .48902 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48946 .01423 Mdot
.46643 .04512 Mdot
.39343 .13669 Mdot
.17226 .26698 Mdot
.74027 .11971 Mdot
.54657 .07716 Mdot
.42172 .14683 Mdot
.18415 .28193 Mdot
.72798 .13579 Mdot
.50026 .61769 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50832 .6068 Mdot
.52651 .58234 Mdot
.58426 .50782 Mdot
.7626 .36074 Mdot
.17892 .49381 Mdot
.37992 .59486 Mdot
.41741 .05 Mdot
.33651 .17628 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60802 Mdot
.52363 .58619 Mdot
.57514 .51909 Mdot
.73523 .37218 Mdot
.13303 .48164 Mdot
.35372 .59895 Mdot
.3846 .07877 Mdot
.25715 .22616 Mdot
.89121 .13298 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49392 .00822 Mdot
.48062 .02614 Mdot
.43833 .08189 Mdot
.30582 .22045 Mdot
.94912 .17408 Mdot
.66744 .04595 Mdot
.5931 .58251 Mdot
.65057 .46284 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51226 .60149 Mdot
.53903 .56566 Mdot
.62377 .46214 Mdot
.87601 .35848 Mdot
.29598 .4999 Mdot
.48712 .51183 Mdot
.65896 .38778 Mdot
.03153 .41681 Mdot
.35711 .53218 Mdot
.5005 .61735 Mdot
.5016 .61587 Mdot
.50511 .61113 Mdot
.51629 .59605 Mdot
.55185 .54883 Mdot
.66383 .42238 Mdot
.9804 .40426 Mdot
.32629 .53518 Mdot
.46036 .57154 Mdot
.53558 .53883 Mdot
.66374 .41243 Mdot
.50079 .61697 Mdot
.50251 .61465 Mdot
.50798 .60725 Mdot
.52544 .58377 Mdot
.58088 .51198 Mdot
.75248 .36445 Mdot
.16278 .49039 Mdot
.36931 .59838 Mdot
.40111 .06623 Mdot
.29394 .20819 Mdot
.95708 .16888 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50891 .606 Mdot
.52839 .57981 Mdot
.59024 .50057 Mdot
.7803 .35569 Mdot
.20478 .49732 Mdot
.4001 .58397 Mdot
.45522 .0069 Mdot
.44406 .0577 Mdot
.35069 .17669 Mdot
.50094 .61676 Mdot
.503 .61398 Mdot
.50956 .60513 Mdot
.53044 .57707 Mdot
.59672 .49283 Mdot
.7993 .35231 Mdot
.22926 .4986 Mdot
.4225 .56764 Mdot
.50404 .56389 Mdot
.59165 .48355 Mdot
.80924 .34611 Mdot
.50092 .61679 Mdot
.50294 .61406 Mdot
.50938 .60537 Mdot
.52987 .57783 Mdot
.59492 .49497 Mdot
.79405 .35304 Mdot
.22282 .49843 Mdot
.41634 .57247 Mdot
.49007 .58167 Mdot
.5489 .53705 Mdot
.67994 .40357 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.5101 .60439 Mdot
.53217 .57477 Mdot
.60218 .48642 Mdot
.81513 .35106 Mdot
.2471 .49858 Mdot
.44038 .55256 Mdot
.54632 .51023 Mdot
.72075 .36517 Mdot
.1299 .47266 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50481 .61153 Mdot
.51533 .59734 Mdot
.54882 .55279 Mdot
.65438 .43108 Mdot
.95687 .39159 Mdot
.32327 .52378 Mdot
.47578 .54614 Mdot
.5921 .46544 Mdot
.839 .34037 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.47611 .0322 Mdot
.42401 .1 Mdot
.2622 .24711 Mdot
.86236 .13484 Mdot
.64419 .01871 Mdot
.61391 .53993 Mdot
.74028 .39267 Mdot
.10493 .48305 Mdot
.5004 .6175 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51281 .60074 Mdot
.5408 .56332 Mdot
.62932 .4562 Mdot
.89118 .36299 Mdot
.30384 .50218 Mdot
.4913 .51024 Mdot
.66572 .3829 Mdot
.04618 .42511 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54245 .56115 Mdot
.63448 .4508 Mdot
.90508 .36793 Mdot
.30977 .50519 Mdot
.49235 .51227 Mdot
.66348 .386 Mdot
.03892 .42172 Mdot
.35656 .53741 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49818 .00245 Mdot
.49421 .00782 Mdot
.48157 .02487 Mdot
.44133 .07803 Mdot
.31507 .21342 Mdot
.96976 .18555 Mdot
.66953 .05646 Mdot
.57818 .6049 Mdot
.59943 .5186 Mdot
.76031 .37137 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60337 Mdot
.53459 .57156 Mdot
.60979 .47766 Mdot
.83691 .35158 Mdot
.26805 .49817 Mdot
.46199 .53308 Mdot
.59945 .44677 Mdot
.87656 .34347 Mdot
.32082 .47664 Mdot
.50057 .61726 Mdot
.50181 .61558 Mdot
.50578 .61023 Mdot
.51841 .59319 Mdot
.55861 .54008 Mdot
.68474 .40477 Mdot
.02981 .43224 Mdot
.33043 .56135 Mdot
.42215 .01264 Mdot
.4017 .09808 Mdot
.243 .24549 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48962 .01402 Mdot
.46693 .04446 Mdot
.39498 .13491 Mdot
.1767 .26708 Mdot
.74456 .11962 Mdot
.55101 .07314 Mdot
.43267 .13371 Mdot
.21632 .27796 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49603 .00536 Mdot
.48737 .01706 Mdot
.45976 .05396 Mdot
.37245 .15995 Mdot
.11365 .25658 Mdot
.6985 .11669 Mdot
.50968 .10772 Mdot
.33538 .23454 Mdot
.95589 .19417 Mdot
.64172 .07947 Mdot
.5004 .61749 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60041 Mdot
.54156 .56232 Mdot
.63172 .45368 Mdot
.89765 .3652 Mdot
.30674 .50347 Mdot
.49212 .51077 Mdot
.66567 .38346 Mdot
.04522 .42482 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51178 .60213 Mdot
.53751 .56768 Mdot
.61897 .46738 Mdot
.86274 .35533 Mdot
.28781 .49873 Mdot
.48084 .51645 Mdot
.64522 .39974 Mdot
.99842 .39828 Mdot
.35399 .51543 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00314 Mdot
.4926 .00999 Mdot
.47644 .03176 Mdot
.42505 .09869 Mdot
.26536 .24555 Mdot
.86805 .13677 Mdot
.64676 .01919 Mdot
.6157 .53917 Mdot
.7433 .39176 Mdot
.10942 .48539 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00443 Mdot
.48956 .01409 Mdot
.46676 .04469 Mdot
.39445 .13552 Mdot
.17518 .26706 Mdot
.74308 .11965 Mdot
.54947 .07452 Mdot
.42889 .13827 Mdot
.20517 .28 Mdot
.75212 .13247 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50376 .61295 Mdot
.51199 .60184 Mdot
.5382 .56677 Mdot
.62114 .465 Mdot
.86876 .35666 Mdot
.29167 .49917 Mdot
.48399 .51399 Mdot
.65233 .39337 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.49571 .00579 Mdot
.48634 .01845 Mdot
.45649 .05828 Mdot
.36219 .17066 Mdot
.08606 .24661 Mdot
.68704 .11046 Mdot
.50831 .10276 Mdot
.34203 .22632 Mdot
.97584 .20401 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.4862 .01862 Mdot
.45607 .05884 Mdot
.36087 .17201 Mdot
.08256 .24515 Mdot
.68589 .10942 Mdot
.50884 .10122 Mdot
.34506 .22323 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50493 .61138 Mdot
.5157 .59685 Mdot
.54997 .55128 Mdot
.65797 .42773 Mdot
.9659 .39635 Mdot
.32459 .52799 Mdot
.47028 .55538 Mdot
.57166 .49117 Mdot
.77693 .34573 Mdot
.50023 .61772 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50758 .6078 Mdot
.52414 .5855 Mdot
.57679 .51705 Mdot
.74019 .36978 Mdot
.14187 .48456 Mdot
.35783 .59952 Mdot
.38779 .07711 Mdot
.26303 .22416 Mdot
.5004 .61749 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.51291 .6006 Mdot
.54112 .56291 Mdot
.63032 .45515 Mdot
.89387 .36389 Mdot
.30508 .50269 Mdot
.49171 .51037 Mdot
.66591 .38295 Mdot
.04629 .42526 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.5131 .60035 Mdot
.5417 .56214 Mdot
.63214 .45323 Mdot
.8988 .36561 Mdot
.30723 .50372 Mdot
.4922 .51094 Mdot
.66548 .38372 Mdot
.04461 .42453 Mdot
.50093 .61677 Mdot
.50297 .61402 Mdot
.50947 .60525 Mdot
.53015 .57746 Mdot
.5958 .49392 Mdot
.79663 .35266 Mdot
.22602 .49853 Mdot
.41938 .57012 Mdot
.49691 .57299 Mdot
.5698 .51034 Mdot
.74405 .36289 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50627 .60956 Mdot
.51999 .59107 Mdot
.56361 .53366 Mdot
.70013 .3933 Mdot
.06376 .45084 Mdot
.33429 .57817 Mdot
.39878 .04778 Mdot
.32148 .18069 Mdot
.02912 .20753 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60706 Mdot
.52589 .58316 Mdot
.58232 .5102 Mdot
.7568 .36279 Mdot
.16979 .49199 Mdot
.37373 .59715 Mdot
.40752 .06011 Mdot
.31026 .1972 Mdot
.99119 .18903 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50746 .60795 Mdot
.52377 .58599 Mdot
.57562 .5185 Mdot
.73666 .37148 Mdot
.1356 .48252 Mdot
.35487 .59917 Mdot
.38538 .07845 Mdot
.25845 .22578 Mdot
.89313 .13399 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00373 Mdot
.4912 .01189 Mdot
.47197 .03774 Mdot
.41091 .11608 Mdot
.22309 .26152 Mdot
.79993 .12118 Mdot
.60386 .03158 Mdot
.55276 .6016 Mdot
.57934 .53106 Mdot
.72007 .38611 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50102 .61665 Mdot
.50326 .61362 Mdot
.5104 .60399 Mdot
.53312 .57351 Mdot
.60516 .48296 Mdot
.82372 .35096 Mdot
.25585 .49841 Mdot
.44941 .54452 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49065 .01262 Mdot
.47023 .04007 Mdot
.4054 .12269 Mdot
.20687 .26486 Mdot
.77833 .11964 Mdot
.58475 .04474 Mdot
.51236 .03329 Mdot
.45849 .07134 Mdot
.34306 .19437 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50759 .60779 Mdot
.52417 .58547 Mdot
.57686 .51695 Mdot
.74042 .36967 Mdot
.14228 .48469 Mdot
.35803 .59953 Mdot
.38797 .07699 Mdot
.26339 .22401 Mdot
.90093 .13799 Mdot
.50103 .61664 Mdot
.50328 .61361 Mdot
.51044 .60394 Mdot
.53325 .57333 Mdot
.60558 .48248 Mdot
.82492 .35098 Mdot
.25702 .49838 Mdot
.45063 .54342 Mdot
.57135 .47947 Mdot
.79556 .33793 Mdot
.24878 .48547 Mdot
.50029 .61765 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.50929 .60549 Mdot
.52959 .57821 Mdot
.59403 .49602 Mdot
.79146 .35345 Mdot
.21956 .49831 Mdot
.41329 .57478 Mdot
.48328 .59025 Mdot
.52824 .5642 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49947 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48301 .02292 Mdot
.44592 .0721 Mdot
.32927 .20172 Mdot
.00289 .20439 Mdot
.67217 .07414 Mdot
.55222 .02659 Mdot
.50919 .01808 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00352 Mdot
.49169 .01122 Mdot
.47353 .03565 Mdot
.41585 .11008 Mdot
.23773 .25719 Mdot
.8216 .12432 Mdot
.62044 .02302 Mdot
.58319 .5674 Mdot
.66512 .44034 Mdot
.50095 .61675 Mdot
.50302 .61395 Mdot
.50962 .60504 Mdot
.53065 .57681 Mdot
.59735 .49208 Mdot
.80115 .35209 Mdot
.23146 .49863 Mdot
.42466 .5659 Mdot
.509 .55756 Mdot
.60686 .46578 Mdot
.85322 .34819 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51227 .60146 Mdot
.53908 .56559 Mdot
.62394 .46196 Mdot
.87647 .3586 Mdot
.29624 .49996 Mdot
.48729 .51173 Mdot
.6593 .3875 Mdot
.03232 .41725 Mdot
.35719 .53258 Mdot
.5 .61803 Mdot
.5 .61803 Mdot
.5 .61803 Mdot
.50001 .61802 Mdot
.50004 .61799 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50113 .6165 Mdot
.50362 .61315 Mdot
.51152 .60248 Mdot
.53668 .56877 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49133 .0117 Mdot
.4724 .03716 Mdot
.41226 .11444 Mdot
.22709 .26046 Mdot
.80566 .12185 Mdot
.6085 .02887 Mdot
.56179 .59105 Mdot
.60545 .50029 Mdot
.79597 .35886 Mdot
.50065 .61716 Mdot
.50207 .61523 Mdot
.5066 .60911 Mdot
.52104 .58967 Mdot
.56694 .52942 Mdot
.71031 .38644 Mdot
.08503 .46158 Mdot
.33819 .58704 Mdot
.38833 .06425 Mdot
.28438 .20836 Mdot
.94724 .16034 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49247 .01017 Mdot
.47602 .03231 Mdot
.42375 .10032 Mdot
.26142 .24749 Mdot
.86097 .13438 Mdot
.64354 .01863 Mdot
.61339 .54022 Mdot
.7393 .39301 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49084 .01237 Mdot
.47082 .03928 Mdot
.40726 .12046 Mdot
.21235 .2639 Mdot
.78535 .11998 Mdot
.59122 .03997 Mdot
.52655 .01547 Mdot
.50151 .01407 Mdot
.47874 .03372 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60973 Mdot
.51959 .59162 Mdot
.56233 .5353 Mdot
.69619 .39611 Mdot
.05527 .44633 Mdot
.3331 .57421 Mdot
.40401 .03987 Mdot
.3395 .16469 Mdot
.07303 .23004 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .00499 Mdot
.48822 .0159 Mdot
.4625 .05035 Mdot
.38103 .15065 Mdot
.13727 .26271 Mdot
.7122 .1193 Mdot
.51916 .10158 Mdot
.3548 .21828 Mdot
.00161 .21978 Mdot
.64601 .10262 Mdot
.50086 .61687 Mdot
.50273 .61434 Mdot
.50871 .60627 Mdot
.52775 .58067 Mdot
.58822 .50301 Mdot
.77433 .35718 Mdot
.19639 .49644 Mdot
.39314 .58823 Mdot
.44136 .02333 Mdot
.40361 .10732 Mdot
.22996 .2537 Mdot
.50002 .618 Mdot
.50008 .61793 Mdot
.50024 .61771 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50774 .60758 Mdot
.52466 .58481 Mdot
.57841 .51503 Mdot
.74508 .36755 Mdot
.15037 .48712 Mdot
.36219 .5995 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48858 .01542 Mdot
.46364 .04883 Mdot
.38463 .14666 Mdot
.14734 .26456 Mdot
.71928 .11975 Mdot
.52552 .0962 Mdot
.36987 .20384 Mdot
.04005 .24058 Mdot
.65079 .12078 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49756 .0033 Mdot
.49221 .01052 Mdot
.47519 .03343 Mdot
.42109 .10362 Mdot
.25343 .25113 Mdot
.84709 .1302 Mdot
.63642 .01866 Mdot
.60623 .54536 Mdot
.72382 .39981 Mdot
.07692 .46837 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.46492 .04714 Mdot
.38865 .14215 Mdot
.15865 .26605 Mdot
.72817 .11989 Mdot
.53419 .08844 Mdot
.3911 .1817 Mdot
.0971 .26624 Mdot
.66632 .13862 Mdot
.50055 .61729 Mdot
.50175 .61567 Mdot
.50557 .61052 Mdot
.51773 .59411 Mdot
.55644 .54288 Mdot
.67804 .41016 Mdot
.01438 .42347 Mdot
.32918 .55313 Mdot
.43419 .61242 Mdot
.44328 .04586 Mdot
.36909 .15399 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49457 .00733 Mdot
.48271 .02332 Mdot
.44498 .07332 Mdot
.32635 .20421 Mdot
.99592 .20043 Mdot
.67162 .07042 Mdot
.55767 .01813 Mdot
.52834 .61002 Mdot
.5413 .57216 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48756 .0168 Mdot
.46037 .05316 Mdot
.37436 .1579 Mdot
.11887 .25814 Mdot
.70119 .11748 Mdot
.51111 .10719 Mdot
.33768 .2329 Mdot
.96083 .19696 Mdot
.64215 .08202 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50212 .61517 Mdot
.50674 .60892 Mdot
.52148 .58907 Mdot
.56835 .52763 Mdot
.71463 .38371 Mdot
.09378 .4657 Mdot
.34025 .59015 Mdot
.38536 .06944 Mdot
.27301 .21544 Mdot
.50014 .61784 Mdot
.50046 .61742 Mdot
.50146 .61606 Mdot
.50465 .61175 Mdot
.51481 .59804 Mdot
.54716 .55496 Mdot
.64921 .43603 Mdot
.9437 .38492 Mdot
.32089 .51807 Mdot
.48264 .53413 Mdot
.61841 .4342 Mdot
.50004 .61798 Mdot
.50014 .61785 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50448 .61198 Mdot
.51429 .59875 Mdot
.54549 .55715 Mdot
.644 .44113 Mdot
.93023 .37851 Mdot
.31779 .51287 Mdot
.48795 .52403 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49704 .004 Mdot
.49057 .01274 Mdot
.46996 .04041 Mdot
.40457 .12368 Mdot
.20446 .26522 Mdot
.77532 .11954 Mdot
.5819 .04692 Mdot
.50598 .04137 Mdot
.43904 .09651 Mdot
.28288 .24092 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51265 .60095 Mdot
.5403 .56399 Mdot
.62774 .45788 Mdot
.88689 .36162 Mdot
.30177 .50143 Mdot
.49044 .51028 Mdot
.66479 .38338 Mdot
.04446 .42407 Mdot
.3583 .53875 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00438 Mdot
.48968 .01394 Mdot
.46713 .0442 Mdot
.39561 .13418 Mdot
.17851 .26709 Mdot
.74635 .11958 Mdot
.55287 .07147 Mdot
.43723 .12816 Mdot
.22986 .27453 Mdot
.78567 .13067 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49673 .00441 Mdot
.4896 .01405 Mdot
.46686 .04455 Mdot
.39478 .13514 Mdot
.17612 .26707 Mdot
.74399 .11963 Mdot
.55042 .07367 Mdot
.43122 .13546 Mdot
.21205 .27883 Mdot
.76089 .13163 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49824 .00237 Mdot
.4944 .00756 Mdot
.48217 .02406 Mdot
.44325 .07556 Mdot
.32098 .20868 Mdot
.98334 .19326 Mdot
.67064 .06368 Mdot
.56761 .00287 Mdot
.56297 .56403 Mdot
.65035 .44448 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00554 Mdot
.48693 .01765 Mdot
.45837 .0558 Mdot
.36809 .16456 Mdot
.10182 .25264 Mdot
.69303 .11445 Mdot
.50784 .10719 Mdot
.33441 .23446 Mdot
.95505 .19334 Mdot
.64222 .07835 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60457 Mdot
.53176 .57533 Mdot
.60086 .48796 Mdot
.81133 .35123 Mdot
.24302 .49863 Mdot
.43622 .5562 Mdot
.53627 .52286 Mdot
.69026 .38559 Mdot
.50115 .61647 Mdot
.50368 .61307 Mdot
.51171 .60222 Mdot
.53731 .56794 Mdot
.61836 .46806 Mdot
.86102 .35498 Mdot
.28665 .49863 Mdot
.47985 .51726 Mdot
.64291 .40187 Mdot
.99268 .39508 Mdot
.35342 .51256 Mdot
.50012 .61787 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51272 .60086 Mdot
.54051 .5637 Mdot
.62842 .45716 Mdot
.88872 .3622 Mdot
.30267 .50174 Mdot
.49084 .51022 Mdot
.66528 .38309 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60623 Mdot
.52784 .58055 Mdot
.5885 .50267 Mdot
.77517 .35696 Mdot
.19759 .49658 Mdot
.39411 .58766 Mdot
.44325 .02113 Mdot
.40906 .10092 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.4882 .01594 Mdot
.46241 .05047 Mdot
.38075 .15096 Mdot
.13648 .26254 Mdot
.71168 .11925 Mdot
.51872 .10194 Mdot
.35379 .2192 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00334 Mdot
.49211 .01065 Mdot
.47488 .03385 Mdot
.42011 .10484 Mdot
.25048 .25238 Mdot
.84212 .12887 Mdot
.63361 .01905 Mdot
.60278 .54829 Mdot
.71563 .40417 Mdot
.06166 .45992 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00183 Mdot
.49569 .00582 Mdot
.48628 .01852 Mdot
.45631 .05851 Mdot
.36164 .17123 Mdot
.08459 .246 Mdot
.68655 .11003 Mdot
.50851 .10214 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50748 .60792 Mdot
.52384 .5859 Mdot
.57583 .51823 Mdot
.73731 .37116 Mdot
.13676 .48291 Mdot
.3554 .59926 Mdot
.38578 .07826 Mdot
.25915 .22556 Mdot
.89418 .13453 Mdot
.50119 .61643 Mdot
.50378 .61292 Mdot
.51205 .60176 Mdot
.53838 .56653 Mdot
.62172 .46437 Mdot
.87036 .35704 Mdot
.29266 .49932 Mdot
.48475 .51344 Mdot
.65399 .39194 Mdot
.01982 .41027 Mdot
.356 .52628 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .00421 Mdot
.49008 .0134 Mdot
.46839 .04251 Mdot
.3996 .12954 Mdot
.19 .26672 Mdot
.75843 .11939 Mdot
.56526 .06056 Mdot
.46727 .09069 Mdot
.32053 .22398 Mdot
.95811 .1856 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49391 .00823 Mdot
.4806 .02616 Mdot
.43827 .08197 Mdot
.30564 .22059 Mdot
.94872 .17387 Mdot
.6674 .04575 Mdot
.59336 .58212 Mdot
.65148 .46195 Mdot
.90403 .37828 Mdot
.5005 .61736 Mdot
.50158 .61589 Mdot
.50505 .61122 Mdot
.51608 .59634 Mdot
.55118 .5497 Mdot
.66174 .42427 Mdot
.97526 .40143 Mdot
.32574 .53258 Mdot
.46401 .56566 Mdot
.54875 .52118 Mdot
.70546 .37937 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49303 .00941 Mdot
.4778 .02992 Mdot
.42939 .09326 Mdot
.27849 .23844 Mdot
.89268 .14633 Mdot
.65592 .02381 Mdot
.61739 .54262 Mdot
.73941 .39541 Mdot
.09963 .48185 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50896 .60594 Mdot
.52853 .57964 Mdot
.59065 .50007 Mdot
.78153 .35541 Mdot
.20647 .49747 Mdot
.40155 .58303 Mdot
.45819 .0033 Mdot
.45285 .04638 Mdot
.3778 .14886 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47738 .03049 Mdot
.42806 .09493 Mdot
.27445 .24074 Mdot
.88493 .14312 Mdot
.65336 .02195 Mdot
.61785 .54044 Mdot
.7434 .39302 Mdot
.10748 .48526 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .01421 Mdot
.46648 .04506 Mdot
.39357 .13653 Mdot
.17266 .267 Mdot
.74066 .11971 Mdot
.54697 .07679 Mdot
.42271 .14566 Mdot
.18703 .28181 Mdot
.73106 .1353 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50503 .61124 Mdot
.51602 .59642 Mdot
.55099 .54995 Mdot
.66115 .42481 Mdot
.97379 .40062 Mdot
.32557 .53184 Mdot
.46503 .56401 Mdot
.55245 .51626 Mdot
.71712 .37185 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .0021 Mdot
.49506 .00667 Mdot
.48426 .02124 Mdot
.44989 .06694 Mdot
.34159 .19072 Mdot
.033 .22109 Mdot
.67527 .08951 Mdot
.53043 .06147 Mdot
.43097 .12348 Mdot
.23116 .27 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48888 .01502 Mdot
.46457 .04759 Mdot
.38757 .14337 Mdot
.15559 .26571 Mdot
.72567 .11988 Mdot
.53169 .0907 Mdot
.38494 .18831 Mdot
.08025 .25959 Mdot
.66022 .13491 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01313 Mdot
.46902 .04167 Mdot
.4016 .12719 Mdot
.19581 .26626 Mdot
.76499 .11937 Mdot
.57184 .05501 Mdot
.48283 .07089 Mdot
.36812 .17963 Mdot
.07747 .24865 Mdot
.50019 .61778 Mdot
.50059 .61723 Mdot
.50189 .61547 Mdot
.50604 .60988 Mdot
.51923 .59209 Mdot
.5612 .53674 Mdot
.69273 .39865 Mdot
.04771 .44222 Mdot
.33219 .57052 Mdot
.40906 .03228 Mdot
.35683 .14781 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47455 .03429 Mdot
.41907 .10613 Mdot
.24735 .25365 Mdot
.83694 .12758 Mdot
.63051 .01969 Mdot
.59865 .55202 Mdot
.70546 .41021 Mdot
.04172 .44845 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50793 .60733 Mdot
.52525 .58401 Mdot
.5803 .51269 Mdot
.75074 .36515 Mdot
.15991 .48968 Mdot
.36759 .59876 Mdot
.39878 .06836 Mdot
.28817 .21168 Mdot
.94566 .16228 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.46781 .04329 Mdot
.39777 .13168 Mdot
.18472 .26698 Mdot
.75273 .11946 Mdot
.55945 .06562 Mdot
.45327 .10832 Mdot
.27801 .25358 Mdot
.86771 .14458 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51222 .60154 Mdot
.53891 .56582 Mdot
.6234 .46254 Mdot
.87499 .35821 Mdot
.2954 .49979 Mdot
.48672 .51208 Mdot
.65816 .38843 Mdot
.02966 .41577 Mdot
.35693 .53125 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49375 .00844 Mdot
.48008 .02686 Mdot
.43662 .08407 Mdot
.30059 .22422 Mdot
.93779 .16801 Mdot
.66594 .04057 Mdot
.6003 .57165 Mdot
.67535 .44004 Mdot
.96335 .40636 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.49322 .00916 Mdot
.4784 .02912 Mdot
.43128 .09086 Mdot
.28426 .235 Mdot
.90401 .15132 Mdot
.65918 .02715 Mdot
.61524 .54744 Mdot
.72946 .40113 Mdot
.08043 .47255 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61543 Mdot
.50613 .60975 Mdot
.51954 .59169 Mdot
.56217 .53551 Mdot
.6957 .39647 Mdot
.05421 .44575 Mdot
.33296 .5737 Mdot
.4047 .03883 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49261 .00998 Mdot
.47647 .03171 Mdot
.42515 .09857 Mdot
.26566 .2454 Mdot
.86859 .13696 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48818 .01596 Mdot
.46236 .05053 Mdot
.38061 .15112 Mdot
.13609 .26246 Mdot
.71142 .11923 Mdot
.51851 .10211 Mdot
.3533 .21965 Mdot
.99789 .2177 Mdot
.64565 .10074 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.5071 .60845 Mdot
.52261 .58755 Mdot
.57193 .52312 Mdot
.72551 .37732 Mdot
.115 .47489 Mdot
.34661 .59607 Mdot
.38215 .07758 Mdot
.25662 .225 Mdot
.89257 .1328 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50657 .60915 Mdot
.52094 .5898 Mdot
.56663 .52981 Mdot
.70938 .38705 Mdot
.08312 .46065 Mdot
.33777 .58632 Mdot
.38909 .06298 Mdot
.28719 .20652 Mdot
.95304 .16361 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .61231 Mdot
.51351 .5998 Mdot
.54301 .56041 Mdot
.63624 .44899 Mdot
.90976 .36974 Mdot
.31151 .5064 Mdot
.49213 .5137 Mdot
.66095 .38865 Mdot
.50114 .6165 Mdot
.50363 .61313 Mdot
.51156 .60243 Mdot
.53681 .5686 Mdot
.6168 .46978 Mdot
.85667 .35416 Mdot
.28363 .49842 Mdot
.47718 .51951 Mdot
.6366 .40786 Mdot
.97667 .38631 Mdot
.35161 .50479 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00366 Mdot
.49136 .01166 Mdot
.47249 .03704 Mdot
.41256 .11409 Mdot
.22796 .26022 Mdot
.80692 .12201 Mdot
.6095 .02832 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00506 Mdot
.48807 .0161 Mdot
.46202 .05098 Mdot
.37953 .1523 Mdot
.1331 .2618 Mdot
.70949 .11901 Mdot
.51693 .10335 Mdot
.34971 .22287 Mdot
.9891 .21277 Mdot
.64483 .09629 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00697 Mdot
.48357 .02217 Mdot
.44771 .06978 Mdot
.33481 .19686 Mdot
.01627 .21193 Mdot
.67337 .08115 Mdot
.54206 .04261 Mdot
.47311 .06742 Mdot
.36402 .1787 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.49659 .0046 Mdot
.48915 .01465 Mdot
.46544 .04643 Mdot
.39031 .14026 Mdot
.16337 .26648 Mdot
.73219 .11986 Mdot
.53826 .08473 Mdot
.40116 .17058 Mdot
.12515 .27501 Mdot
.68017 .14144 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49338 .00894 Mdot
.47891 .02844 Mdot
.43288 .08884 Mdot
.28914 .23194 Mdot
.91385 .15592 Mdot
.66157 .03057 Mdot
.6121 .55307 Mdot
.71721 .40864 Mdot
.05601 .4595 Mdot
.50119 .61643 Mdot
.50378 .61292 Mdot
.51205 .60176 Mdot
.53838 .56653 Mdot
.62172 .46437 Mdot
.87036 .35704 Mdot
.29266 .49932 Mdot
.48475 .51344 Mdot
.65399 .39194 Mdot
.01982 .41027 Mdot
.356 .52628 Mdot
.50032 .6176 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51042 .60396 Mdot
.53319 .57341 Mdot
.60539 .4827 Mdot
.82437 .35097 Mdot
.25649 .49839 Mdot
.45008 .54392 Mdot
.57 .48109 Mdot
.79158 .33855 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50754 .60784 Mdot
.52403 .58565 Mdot
.57644 .51748 Mdot
.73915 .37027 Mdot
.14003 .48398 Mdot
.35694 .59945 Mdot
.38701 .07758 Mdot
.26148 .22475 Mdot
.89783 .1364 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49105 .01209 Mdot
.47149 .03838 Mdot
.40938 .11793 Mdot
.21857 .2626 Mdot
.79366 .12058 Mdot
.59856 .03493 Mdot
.54204 .61445 Mdot
.54784 .57076 Mdot
.62433 .46687 Mdot
.50082 .61693 Mdot
.50261 .6145 Mdot
.50832 .60679 Mdot
.52651 .58233 Mdot
.58429 .50779 Mdot
.76266 .36071 Mdot
.17902 .49382 Mdot
.37999 .59483 Mdot
.41753 .04988 Mdot
.33683 .176 Mdot
.05205 .2234 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48792 .01631 Mdot
.46154 .05162 Mdot
.37802 .15395 Mdot
.12892 .26082 Mdot
.70691 .11865 Mdot
.51493 .10483 Mdot
.34531 .2267 Mdot
.97849 .20683 Mdot
.64384 .0909 Mdot
.50021 .61776 Mdot
.50065 .61715 Mdot
.50208 .61522 Mdot
.50663 .60908 Mdot
.52112 .58955 Mdot
.56721 .52908 Mdot
.71115 .38591 Mdot
.08674 .46239 Mdot
.33857 .58768 Mdot
.38768 .06534 Mdot
.28197 .20991 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48909 .01474 Mdot
.46524 .0467 Mdot
.38968 .14098 Mdot
.16157 .26633 Mdot
.73064 .11987 Mdot
.53668 .08617 Mdot
.39724 .17495 Mdot
.11416 .27194 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51585 .59664 Mdot
.55046 .55064 Mdot
.65951 .42631 Mdot
.96974 .39842 Mdot
.32508 .52985 Mdot
.46777 .55952 Mdot
.56245 .5031 Mdot
.74842 .35556 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.4966 .0046 Mdot
.48916 .01464 Mdot
.46547 .04641 Mdot
.39038 .14019 Mdot
.16355 .26649 Mdot
.73235 .11986 Mdot
.53842 .08458 Mdot
.40156 .17013 Mdot
.12628 .2753 Mdot
.68084 .14147 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02202 Mdot
.44806 .06932 Mdot
.33589 .19589 Mdot
.01893 .2134 Mdot
.67364 .08252 Mdot
.54012 .04571 Mdot
.46615 .07686 Mdot
.3418 .20053 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.4899 .01364 Mdot
.46783 .04326 Mdot
.39784 .13159 Mdot
.18493 .26697 Mdot
.75296 .11945 Mdot
.55968 .06542 Mdot
.45383 .10762 Mdot
.2797 .2526 Mdot
.87099 .14567 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49092 .01227 Mdot
.47107 .03894 Mdot
.40806 .11951 Mdot
.21469 .26344 Mdot
.78844 .12018 Mdot
.59399 .03802 Mdot
.53248 .00812 Mdot
.51934 .60827 Mdot
.53514 .57596 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50855 .60649 Mdot
.52722 .58138 Mdot
.58654 .50504 Mdot
.76936 .35859 Mdot
.18915 .49548 Mdot
.38744 .59134 Mdot
.43063 .0356 Mdot
.37302 .14123 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49324 .00913 Mdot
.47848 .02902 Mdot
.43152 .09056 Mdot
.28498 .23456 Mdot
.90546 .15198 Mdot
.65955 .02763 Mdot
.61485 .54819 Mdot
.72786 .40207 Mdot
.0773 .47095 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00506 Mdot
.48807 .0161 Mdot
.46202 .05098 Mdot
.37953 .1523 Mdot
.13311 .26181 Mdot
.7095 .11901 Mdot
.51693 .10334 Mdot
.34972 .22286 Mdot
.98912 .21278 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00298 Mdot
.49298 .00948 Mdot
.47765 .03013 Mdot
.42889 .09388 Mdot
.27698 .23931 Mdot
.88977 .1451 Mdot
.65499 .02307 Mdot
.61767 .54169 Mdot
.74119 .39437 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01634 Mdot
.46146 .05172 Mdot
.37777 .15422 Mdot
.12825 .26065 Mdot
.7065 .11858 Mdot
.51463 .10504 Mdot
.34467 .22725 Mdot
.97698 .20598 Mdot
.6437 .09014 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49514 .00657 Mdot
.48451 .02091 Mdot
.45068 .0659 Mdot
.34406 .18842 Mdot
.03919 .22438 Mdot
.67613 .09245 Mdot
.52654 .06795 Mdot
.41659 .14179 Mdot
.18717 .27799 Mdot
.50098 .61671 Mdot
.50313 .6138 Mdot
.50998 .60456 Mdot
.53178 .57529 Mdot
.60094 .48787 Mdot
.81155 .35122 Mdot
.24327 .49863 Mdot
.43647 .55598 Mdot
.53687 .5221 Mdot
.69209 .38422 Mdot
.07041 .44738 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46216 .0508 Mdot
.37996 .15182 Mdot
.13431 .26207 Mdot
.71026 .1191 Mdot
.51755 .10287 Mdot
.35111 .22162 Mdot
.99251 .21469 Mdot
.50064 .61717 Mdot
.50204 .61527 Mdot
.50651 .60924 Mdot
.52073 .59008 Mdot
.56597 .53066 Mdot
.70734 .38838 Mdot
.07893 .45859 Mdot
.33691 .58467 Mdot
.39089 .06005 Mdot
.29373 .20206 Mdot
.96678 .17149 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.47622 .03205 Mdot
.42435 .09957 Mdot
.26324 .24661 Mdot
.86422 .13546 Mdot
.64505 .01885 Mdot
.61456 .53961 Mdot
.74144 .39228 Mdot
.10672 .48397 Mdot
.50031 .61762 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51002 .6045 Mdot
.53192 .57511 Mdot
.60138 .48735 Mdot
.81283 .35115 Mdot
.24465 .49862 Mdot
.43788 .55476 Mdot
.54026 .51783 Mdot
.7024 .37683 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00314 Mdot
.49258 .01002 Mdot
.47638 .03184 Mdot
.42486 .09893 Mdot
.26479 .24584 Mdot
.86701 .13641 Mdot
.6463 .01909 Mdot
.61541 .53926 Mdot
.74286 .39187 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46746 .04376 Mdot
.39666 .13297 Mdot
.18152 .26706 Mdot
.7494 .11952 Mdot
.55602 .06865 Mdot
.44494 .11868 Mdot
.25291 .2662 Mdot
.82219 .13358 Mdot
.49995 7e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .0021 Mdot
.49504 .0067 Mdot
.48419 .02133 Mdot
.44967 .06721 Mdot
.34092 .19133 Mdot
.03134 .2202 Mdot
.67505 .08871 Mdot
.53151 .05969 Mdot
.43493 .11834 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00183 Mdot
.49568 .00584 Mdot
.48623 .01859 Mdot
.45615 .05873 Mdot
.36113 .17175 Mdot
.08324 .24544 Mdot
.68611 .10963 Mdot
.50873 .10154 Mdot
.34444 .22386 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50893 .60597 Mdot
.52845 .57973 Mdot
.59043 .50034 Mdot
.78086 .35556 Mdot
.20555 .49739 Mdot
.40076 .58354 Mdot
.45657 .00527 Mdot
.44804 .05259 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.48841 .01565 Mdot
.46308 .04958 Mdot
.38286 .14862 Mdot
.14238 .26371 Mdot
.7157 .11957 Mdot
.52222 .09904 Mdot
.36197 .21155 Mdot
.01968 .22975 Mdot
.64794 .11151 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50982 .60478 Mdot
.53126 .57598 Mdot
.59931 .48978 Mdot
.80683 .35154 Mdot
.23803 .49867 Mdot
.43117 .5605 Mdot
.52425 .53811 Mdot
.65358 .41682 Mdot
.97915 .39755 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49643 .00483 Mdot
.48861 .01537 Mdot
.46374 .0487 Mdot
.38494 .14631 Mdot
.14821 .26469 Mdot
.71993 .11977 Mdot
.52613 .09566 Mdot
.37134 .20236 Mdot
.04392 .24256 Mdot
.65145 .12241 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51128 .6028 Mdot
.53593 .56977 Mdot
.61402 .47288 Mdot
.84889 .35291 Mdot
.27787 .4982 Mdot
.47176 .52424 Mdot
.62353 .42088 Mdot
.94253 .36875 Mdot
.34588 .49032 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.5127 .60088 Mdot
.54046 .56378 Mdot
.62824 .45735 Mdot
.88823 .36204 Mdot
.30243 .50165 Mdot
.49074 .51023 Mdot
.66516 .38316 Mdot
.0452 .4245 Mdot
.35834 .53916 Mdot
.50015 .61784 Mdot
.50047 .61741 Mdot
.50148 .61603 Mdot
.50472 .61165 Mdot
.51505 .59772 Mdot
.54793 .55396 Mdot
.65161 .43372 Mdot
.94983 .38798 Mdot
.32207 .52065 Mdot
.47964 .53948 Mdot
.60674 .44778 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51217 .60161 Mdot
.53875 .56604 Mdot
.62288 .46311 Mdot
.87356 .35784 Mdot
.29457 .49963 Mdot
.48614 .51246 Mdot
.65696 .38942 Mdot
.02687 .41421 Mdot
.35666 .52984 Mdot
.50068 .61711 Mdot
.50217 .6151 Mdot
.50691 .6087 Mdot
.52202 .58835 Mdot
.57004 .5255 Mdot
.71976 .38061 Mdot
.10393 .47025 Mdot
.34304 .59329 Mdot
.38308 .07416 Mdot
.26308 .22121 Mdot
.90515 .13839 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48906 .01477 Mdot
.46517 .0468 Mdot
.38945 .14124 Mdot
.16092 .26627 Mdot
.73008 .11988 Mdot
.53611 .08669 Mdot
.39585 .17649 Mdot
.11029 .27074 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49836 .00221 Mdot
.49479 .00704 Mdot
.48339 .02242 Mdot
.44711 .07055 Mdot
.33296 .1985 Mdot
.01179 .20942 Mdot
.67295 .07883 Mdot
.5454 .03731 Mdot
.48504 .05115 Mdot
.40227 .13616 Mdot
.50024 .61771 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50783 .60746 Mdot
.52494 .58444 Mdot
.57929 .51393 Mdot
.74773 .3664 Mdot
.15488 .48837 Mdot
.36468 .59924 Mdot
.39508 .07158 Mdot
.27926 .21664 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49566 .00586 Mdot
.48617 .01867 Mdot
.45596 .05898 Mdot
.36054 .17234 Mdot
.08168 .24479 Mdot
.68561 .10915 Mdot
.509 .10081 Mdot
.34589 .22238 Mdot
.98607 .20948 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48476 .02057 Mdot
.45147 .06487 Mdot
.34651 .1861 Mdot
.04539 .22762 Mdot
.6771 .09528 Mdot
.52294 .07409 Mdot
.40305 .15851 Mdot
.14658 .27598 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.5131 .60035 Mdot
.54172 .56211 Mdot
.6322 .45317 Mdot
.89896 .36567 Mdot
.3073 .50375 Mdot
.49221 .51097 Mdot
.66545 .38376 Mdot
.04451 .42449 Mdot
.35768 .53954 Mdot
.50058 .61724 Mdot
.50186 .61552 Mdot
.50593 .61002 Mdot
.5189 .59254 Mdot
.56016 .53809 Mdot
.68951 .40107 Mdot
.04056 .43827 Mdot
.33143 .56692 Mdot
.41413 .02469 Mdot
.37418 .12955 Mdot
.16457 .25634 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.5409 .5632 Mdot
.62962 .45588 Mdot
.89199 .36326 Mdot
.30422 .50233 Mdot
.49144 .51026 Mdot
.66581 .38289 Mdot
.04629 .42519 Mdot
.35831 .53987 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61511 Mdot
.50689 .60873 Mdot
.52194 .58845 Mdot
.56981 .52579 Mdot
.71907 .38102 Mdot
.10257 .46966 Mdot
.34265 .59291 Mdot
.3833 .07362 Mdot
.26419 .22058 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60842 Mdot
.52266 .58749 Mdot
.57209 .52292 Mdot
.72599 .37705 Mdot
.11591 .47526 Mdot
.34693 .59627 Mdot
.38215 .07778 Mdot
.25631 .2252 Mdot
.89192 .13253 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48933 .0144 Mdot
.46603 .04566 Mdot
.39215 .13816 Mdot
.1686 .26683 Mdot
.73686 .11978 Mdot
.54305 .08036 Mdot
.41302 .15704 Mdot
.15893 .28108 Mdot
.70414 .13962 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50172 .61572 Mdot
.50547 .61065 Mdot
.51742 .59453 Mdot
.55546 .54415 Mdot
.675 .41269 Mdot
.00726 .41941 Mdot
.32863 .54931 Mdot
.43982 .60378 Mdot
.46289 .01984 Mdot
.49997 4e-05 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48909 .01474 Mdot
.46524 .0467 Mdot
.38968 .14098 Mdot
.16158 .26633 Mdot
.73065 .11987 Mdot
.53668 .08617 Mdot
.39726 .17493 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48476 .02057 Mdot
.45148 .06485 Mdot
.34656 .18606 Mdot
.0455 .22767 Mdot
.67712 .09533 Mdot
.52288 .07419 Mdot
.40283 .15879 Mdot
.14591 .27588 Mdot
.50041 .61748 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.5132 .60021 Mdot
.54204 .56168 Mdot
.63322 .4521 Mdot
.9017 .36666 Mdot
.30843 .50437 Mdot
.49234 .51147 Mdot
.66475 .38459 Mdot
.04247 .4235 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60134 Mdot
.53938 .5652 Mdot
.62487 .46095 Mdot
.87903 .3593 Mdot
.29767 .50028 Mdot
.48821 .5112 Mdot
.66108 .38609 Mdot
.03637 .41951 Mdot
.35758 .53461 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49706 .00397 Mdot
.49065 .01263 Mdot
.47021 .04009 Mdot
.40534 .12277 Mdot
.20669 .26488 Mdot
.7781 .11963 Mdot
.58453 .0449 Mdot
.51188 .0339 Mdot
.45703 .07325 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49886 .00155 Mdot
.49635 .00493 Mdot
.48838 .01569 Mdot
.463 .04968 Mdot
.38262 .1489 Mdot
.1417 .26358 Mdot
.71522 .11954 Mdot
.52179 .0994 Mdot
.36095 .21252 Mdot
.5002 .61776 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50661 .6091 Mdot
.52107 .58963 Mdot
.56703 .52931 Mdot
.7106 .38626 Mdot
.08561 .46186 Mdot
.33832 .58726 Mdot
.3881 .06462 Mdot
.28354 .2089 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49612 .00525 Mdot
.48763 .0167 Mdot
.46061 .05285 Mdot
.3751 .15711 Mdot
.1209 .25871 Mdot
.70229 .11775 Mdot
.51177 .10685 Mdot
.33888 .23198 Mdot
.96352 .19846 Mdot
.64241 .08337 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49304 .00941 Mdot
.47781 .02991 Mdot
.42942 .09322 Mdot
.27859 .23839 Mdot
.89287 .14641 Mdot
.65598 .02386 Mdot
.61737 .54269 Mdot
.73928 .39548 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60341 Mdot
.53448 .5717 Mdot
.60946 .47804 Mdot
.83598 .3515 Mdot
.26723 .49818 Mdot
.46116 .53384 Mdot
.59739 .44908 Mdot
.87077 .34201 Mdot
.31738 .47653 Mdot
.50033 .61759 Mdot
.50106 .61661 Mdot
.50336 .61349 Mdot
.51071 .60357 Mdot
.53412 .57218 Mdot
.6083 .47935 Mdot
.8327 .35128 Mdot
.26431 .49823 Mdot
.45816 .53657 Mdot
.58998 .45753 Mdot
.84968 .33799 Mdot
.49982 .00024 Mdot
.49943 .00078 Mdot
.49817 .00247 Mdot
.49417 .00787 Mdot
.48144 .02504 Mdot
.44092 .07856 Mdot
.31381 .2144 Mdot
.96691 .18394 Mdot
.66928 .05497 Mdot
.58034 .60165 Mdot
.60686 .50986 Mdot
.78188 .36527 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00518 Mdot
.48779 .01648 Mdot
.46112 .05216 Mdot
.37672 .15536 Mdot
.12534 .25991 Mdot
.70479 .11828 Mdot
.51341 .10587 Mdot
.34211 .22938 Mdot
.97096 .20261 Mdot
.64313 .0871 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50824 .6069 Mdot
.52626 .58267 Mdot
.58348 .50877 Mdot
.76027 .36154 Mdot
.1753 .49312 Mdot
.37741 .59586 Mdot
.41328 .05431 Mdot
.32541 .1856 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48745 .01694 Mdot
.46004 .0536 Mdot
.37331 .15903 Mdot
.11599 .25729 Mdot
.69968 .11706 Mdot
.51028 .10754 Mdot
.33627 .23393 Mdot
.95776 .19523 Mdot
.64187 .08045 Mdot
.50118 .61644 Mdot
.50376 .61296 Mdot
.51197 .60187 Mdot
.53812 .56688 Mdot
.62089 .46528 Mdot
.86806 .3565 Mdot
.29124 .49912 Mdot
.48365 .51425 Mdot
.65158 .39403 Mdot
.01403 .40702 Mdot
.35546 .52334 Mdot
.50059 .61723 Mdot
.50189 .61548 Mdot
.50603 .60989 Mdot
.51921 .59212 Mdot
.56114 .53682 Mdot
.69255 .39878 Mdot
.0473 .44199 Mdot
.33214 .57032 Mdot
.40934 .03186 Mdot
.3578 .14683 Mdot
.12022 .24798 Mdot
.50029 .61764 Mdot
.50092 .61679 Mdot
.50294 .61406 Mdot
.50937 .60538 Mdot
.52983 .57789 Mdot
.59479 .49511 Mdot
.79368 .35309 Mdot
.22237 .49842 Mdot
.41591 .5728 Mdot
.48911 .58288 Mdot
.54599 .54084 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00213 Mdot
.49497 .00679 Mdot
.48398 .02162 Mdot
.449 .06809 Mdot
.33883 .19324 Mdot
.02616 .21739 Mdot
.67442 .08617 Mdot
.535 .05398 Mdot
.44767 .10162 Mdot
.28324 .24596 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54006 .5643 Mdot
.627 .45867 Mdot
.88485 .36099 Mdot
.30075 .5011 Mdot
.48995 .51042 Mdot
.66407 .38386 Mdot
.04298 .42322 Mdot
.3582 .53796 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49041 .01295 Mdot
.46947 .04108 Mdot
.40301 .12553 Mdot
.1999 .26582 Mdot
.76978 .11942 Mdot
.57656 .05114 Mdot
.49381 .05688 Mdot
.40177 .14227 Mdot
.17157 .27226 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50928 .6055 Mdot
.52956 .57826 Mdot
.59392 .49615 Mdot
.79113 .35351 Mdot
.21915 .49829 Mdot
.4129 .57506 Mdot
.48243 .59132 Mdot
.52565 .56765 Mdot
.60718 .47563 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.49218 .01056 Mdot
.4751 .03354 Mdot
.42083 .10395 Mdot
.25264 .25147 Mdot
.84575 .12983 Mdot
.63568 .01874 Mdot
.60535 .54609 Mdot
.72175 .40087 Mdot
.07314 .46631 Mdot
.49992 .00011 Mdot
.49974 .00034 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49175 .01115 Mdot
.47371 .03541 Mdot
.41641 .1094 Mdot
.2394 .25661 Mdot
.82419 .12481 Mdot
.62224 .02231 Mdot
.58615 .56432 Mdot
.67307 .43368 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50494 .61136 Mdot
.51575 .59678 Mdot
.55014 .55106 Mdot
.65851 .42722 Mdot
.96725 .39708 Mdot
.32477 .52864 Mdot
.46941 .55683 Mdot
.56844 .49531 Mdot
.76701 .34861 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.50061 .61721 Mdot
.50194 .61541 Mdot
.50618 .60969 Mdot
.51969 .59148 Mdot
.56266 .53488 Mdot
.6972 .39539 Mdot
.05745 .44749 Mdot
.33339 .57525 Mdot
.40262 .04196 Mdot
.50015 .61784 Mdot
.50047 .6174 Mdot
.50149 .61601 Mdot
.50476 .6116 Mdot
.51517 .59756 Mdot
.5483 .55347 Mdot
.65276 .43262 Mdot
.95277 .38948 Mdot
.32259 .52194 Mdot
.47808 .5422 Mdot
.60078 .45489 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00647 Mdot
.48474 .0206 Mdot
.45141 .06495 Mdot
.34633 .18628 Mdot
.04491 .22737 Mdot
.67702 .09507 Mdot
.5232 .07363 Mdot
.40406 .15728 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00236 Mdot
.49443 .00753 Mdot
.48224 .02396 Mdot
.44347 .07527 Mdot
.32168 .2081 Mdot
.98496 .19418 Mdot
.67077 .06455 Mdot
.56633 .00482 Mdot
.55853 .56981 Mdot
.63656 .45818 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.4883 .0158 Mdot
.46274 .05003 Mdot
.38179 .14982 Mdot
.13938 .26313 Mdot
.71362 .11943 Mdot
.52038 .10058 Mdot
.35764 .21565 Mdot
.00871 .22372 Mdot
.64672 .10616 Mdot
.50127 .61632 Mdot
.50404 .61258 Mdot
.51287 .60066 Mdot
.54099 .56307 Mdot
.62992 .45557 Mdot
.8928 .36353 Mdot
.30459 .50248 Mdot
.49156 .5103 Mdot
.66587 .3829 Mdot
.04633 .42525 Mdot
.35827 .53994 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49175 .01114 Mdot
.47373 .03538 Mdot
.41649 .10929 Mdot
.23966 .25652 Mdot
.8246 .12489 Mdot
.62252 .0222 Mdot
.5866 .56385 Mdot
.67427 .43269 Mdot
.50099 .61669 Mdot
.50316 .61377 Mdot
.51007 .60444 Mdot
.53206 .57492 Mdot
.60182 .48684 Mdot
.81409 .3511 Mdot
.246 .4986 Mdot
.43926 .55355 Mdot
.54359 .51364 Mdot
.7125 .37017 Mdot
.11355 .46673 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49093 .01225 Mdot
.4711 .0389 Mdot
.40816 .1194 Mdot
.21497 .26338 Mdot
.7888 .1202 Mdot
.59431 .0378 Mdot
.53316 .00728 Mdot
.52139 .60554 Mdot
.54161 .56741 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00533 Mdot
.48744 .01696 Mdot
.45999 .05366 Mdot
.37316 .15919 Mdot
.11559 .25717 Mdot
.69948 .117 Mdot
.51017 .10758 Mdot
.3361 .23405 Mdot
.9574 .19503 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46746 .04375 Mdot
.39667 .13295 Mdot
.18156 .26706 Mdot
.74944 .11952 Mdot
.55606 .06861 Mdot
.44505 .11855 Mdot
.25323 .26606 Mdot
.82273 .13366 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50882 .60612 Mdot
.52809 .58022 Mdot
.58928 .50172 Mdot
.77748 .35637 Mdot
.20086 .49694 Mdot
.3968 .58605 Mdot
.44856 .01488 Mdot
.42449 .08228 Mdot
.29135 .22488 Mdot
.50018 .6178 Mdot
.50056 .61727 Mdot
.50179 .61561 Mdot
.50571 .61032 Mdot
.5182 .59348 Mdot
.55794 .54095 Mdot
.68267 .40641 Mdot
.02508 .42957 Mdot
.33003 .55885 Mdot
.42579 .00714 Mdot
.41424 .08286 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49848 .00206 Mdot
.49515 .00655 Mdot
.48455 .02085 Mdot
.45082 .06572 Mdot
.34449 .18801 Mdot
.04028 .22496 Mdot
.67629 .09295 Mdot
.52589 .06906 Mdot
.41415 .14485 Mdot
.17978 .27826 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49726 .0037 Mdot
.49127 .01179 Mdot
.47219 .03744 Mdot
.41161 .11523 Mdot
.22516 .26098 Mdot
.80288 .12151 Mdot
.60628 .03015 Mdot
.5575 .59603 Mdot
.5931 .51456 Mdot
.76052 .36734 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48933 .0144 Mdot
.46603 .04566 Mdot
.39216 .13816 Mdot
.16861 .26683 Mdot
.73688 .11978 Mdot
.54307 .08035 Mdot
.41306 .15699 Mdot
.15905 .28109 Mdot
.70423 .13961 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.51231 .60142 Mdot
.53919 .56545 Mdot
.62428 .46159 Mdot
.8774 .35885 Mdot
.29677 .50007 Mdot
.48764 .51152 Mdot
.65998 .38695 Mdot
.03388 .41813 Mdot
.35734 .53337 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49583 .00563 Mdot
.48673 .01792 Mdot
.45773 .05665 Mdot
.36607 .16666 Mdot
.09641 .25067 Mdot
.69082 .11321 Mdot
.50763 .10614 Mdot
.3359 .23271 Mdot
.95937 .19545 Mdot
.64313 .07994 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01061 Mdot
.47498 .03371 Mdot
.42042 .10445 Mdot
.25142 .25199 Mdot
.84369 .12928 Mdot
.63451 .01891 Mdot
.60392 .5473 Mdot
.71838 .40266 Mdot
.06687 .46284 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.5394 .56517 Mdot
.62494 .46088 Mdot
.87921 .35935 Mdot
.29777 .5003 Mdot
.48827 .51116 Mdot
.66119 .386 Mdot
.03663 .41966 Mdot
.35761 .53475 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48957 .01408 Mdot
.46679 .04464 Mdot
.39456 .1354 Mdot
.17548 .26706 Mdot
.74336 .11965 Mdot
.54977 .07425 Mdot
.42963 .13738 Mdot
.20734 .27966 Mdot
.75484 .13218 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60724 Mdot
.52547 .58373 Mdot
.58098 .51185 Mdot
.75279 .36433 Mdot
.1633 .49051 Mdot
.36963 .59831 Mdot
.40155 .06583 Mdot
.29503 .20751 Mdot
.95927 .17016 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60697 Mdot
.52609 .5829 Mdot
.58294 .50944 Mdot
.75864 .36212 Mdot
.17272 .49261 Mdot
.37566 .5965 Mdot
.4105 .05713 Mdot
.31807 .19139 Mdot
.0084 .19917 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00814 Mdot
.48081 .02589 Mdot
.43892 .08113 Mdot
.30765 .2191 Mdot
.95314 .17628 Mdot
.66791 .04793 Mdot
.59035 .58664 Mdot
.64115 .47228 Mdot
.87699 .36926 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.50771 .60762 Mdot
.52455 .58496 Mdot
.57807 .51545 Mdot
.74406 .36801 Mdot
.14861 .48661 Mdot
.36126 .59955 Mdot
.39117 .07473 Mdot
.27026 .22108 Mdot
.49979 .00029 Mdot
.49932 .00093 Mdot
.49782 .00295 Mdot
.49305 .00939 Mdot
.47785 .02986 Mdot
.42953 .09308 Mdot
.27893 .23819 Mdot
.89353 .14669 Mdot
.65619 .02404 Mdot
.61729 .54292 Mdot
.73883 .39574 Mdot
.09851 .48134 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49624 .00508 Mdot
.48802 .01618 Mdot
.46183 .05123 Mdot
.37895 .15294 Mdot
.13149 .26143 Mdot
.70848 .11888 Mdot
.51613 .10395 Mdot
.34793 .22444 Mdot
.98478 .21035 Mdot
.50128 .6163 Mdot
.50408 .61252 Mdot
.513 .60048 Mdot
.54141 .56252 Mdot
.63123 .45419 Mdot
.89635 .36474 Mdot
.30618 .50319 Mdot
.492 .51061 Mdot
.66582 .38322 Mdot
.04575 .42506 Mdot
.358 .53992 Mdot
.50007 .61795 Mdot
.50021 .61775 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .60891 Mdot
.52152 .58901 Mdot
.56848 .52747 Mdot
.71501 .38348 Mdot
.09453 .46605 Mdot
.34044 .5904 Mdot
.38515 .06984 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49363 .00861 Mdot
.4797 .02738 Mdot
.4354 .08563 Mdot
.29685 .22683 Mdot
.92984 .16387 Mdot
.66469 .03702 Mdot
.60479 .56477 Mdot
.69097 .42726 Mdot
.99965 .42693 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51228 .60145 Mdot
.53911 .56556 Mdot
.62401 .46189 Mdot
.87666 .35865 Mdot
.29635 .49998 Mdot
.48737 .51168 Mdot
.65945 .38738 Mdot
.03265 .41744 Mdot
.35722 .53275 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48949 .0142 Mdot
.46651 .04502 Mdot
.39367 .13642 Mdot
.17294 .267 Mdot
.74091 .1197 Mdot
.54724 .07655 Mdot
.42337 .14487 Mdot
.18896 .2817 Mdot
.73316 .13498 Mdot
.49989 .00016 Mdot
.49963 .00049 Mdot
.49883 .00158 Mdot
.49628 .00502 Mdot
.48816 .01598 Mdot
.4623 .0506 Mdot
.38043 .15131 Mdot
.1356 .26236 Mdot
.7111 .1192 Mdot
.51824 .10232 Mdot
.35268 .22021 Mdot
.99638 .21685 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60315 Mdot
.53511 .57086 Mdot
.61145 .47578 Mdot
.84162 .35201 Mdot
.27205 .49815 Mdot
.46603 .5294 Mdot
.60944 .43575 Mdot
.90439 .35235 Mdot
.33428 .47968 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50904 .60582 Mdot
.5288 .57927 Mdot
.59153 .49902 Mdot
.7841 .35485 Mdot
.20995 .49774 Mdot
.40459 .58099 Mdot
.46452 .61361 Mdot
.47167 .0217 Mdot
.43656 .07896 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .00249 Mdot
.49412 .00794 Mdot
.48127 .02527 Mdot
.44038 .07925 Mdot
.31215 .21569 Mdot
.96315 .18183 Mdot
.66894 .05302 Mdot
.58315 .59743 Mdot
.61649 .49882 Mdot
.80939 .36143 Mdot
.50078 .61698 Mdot
.50249 .61466 Mdot
.50795 .6073 Mdot
.52531 .58394 Mdot
.58048 .51246 Mdot
.7513 .36492 Mdot
.16084 .48992 Mdot
.36814 .59864 Mdot
.39952 .0677 Mdot
.28998 .21061 Mdot
.94921 .16432 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.50771 .60762 Mdot
.52456 .58495 Mdot
.57809 .51542 Mdot
.74412 .36798 Mdot
.14872 .48664 Mdot
.36131 .59955 Mdot
.39123 .07468 Mdot
.27038 .22102 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50432 .6122 Mdot
.51376 .59946 Mdot
.54381 .55936 Mdot
.63874 .44642 Mdot
.91642 .37245 Mdot
.31378 .5083 Mdot
.49133 .51634 Mdot
.65588 .39385 Mdot
.01861 .41107 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00368 Mdot
.49133 .01171 Mdot
.47239 .03718 Mdot
.41224 .11448 Mdot
.22701 .26048 Mdot
.80554 .12183 Mdot
.60841 .02892 Mdot
.56161 .59125 Mdot
.60495 .50086 Mdot
.79454 .35906 Mdot
.5009 .61682 Mdot
.50285 .61418 Mdot
.50909 .60575 Mdot
.52896 .57905 Mdot
.59203 .49841 Mdot
.78559 .35454 Mdot
.21193 .49788 Mdot
.40634 .57978 Mdot
.46823 .60904 Mdot
.48279 .00693 Mdot
.47158 .03313 Mdot
.50022 .61774 Mdot
.5007 .61708 Mdot
.50224 .61501 Mdot
.50714 .60839 Mdot
.52273 .58739 Mdot
.57232 .52263 Mdot
.72668 .37667 Mdot
.11722 .47578 Mdot
.3474 .59654 Mdot
.38217 .07803 Mdot
.25592 .22547 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.487 .01754 Mdot
.45862 .05548 Mdot
.36885 .16376 Mdot
.10389 .25337 Mdot
.69392 .11489 Mdot
.50803 .10745 Mdot
.33416 .23485 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01025 Mdot
.47583 .03257 Mdot
.42313 .10109 Mdot
.25956 .24837 Mdot
.85768 .13333 Mdot
.64195 .0185 Mdot
.61202 .54105 Mdot
.73657 .39403 Mdot
.09901 .48002 Mdot
.5006 .61723 Mdot
.5019 .61546 Mdot
.50606 .60984 Mdot
.51932 .59197 Mdot
.56149 .53638 Mdot
.69361 .398 Mdot
.04963 .44327 Mdot
.33241 .57147 Mdot
.40775 .03425 Mdot
.35233 .15233 Mdot
.10586 .24339 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.5077 .60763 Mdot
.52453 .58499 Mdot
.57799 .51554 Mdot
.74383 .36811 Mdot
.14821 .48649 Mdot
.36105 .59956 Mdot
.39094 .0749 Mdot
.26975 .22131 Mdot
.91167 .14356 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50398 .61265 Mdot
.5127 .60089 Mdot
.54043 .56381 Mdot
.62816 .45743 Mdot
.88802 .36198 Mdot
.30233 .50162 Mdot
.49069 .51024 Mdot
.66511 .38319 Mdot
.04509 .42444 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.51189 .60198 Mdot
.53787 .5672 Mdot
.62011 .46613 Mdot
.8659 .35601 Mdot
.28987 .49895 Mdot
.48256 .51508 Mdot
.64914 .39619 Mdot
.00809 .40369 Mdot
.35491 .52032 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46876 .04202 Mdot
.40077 .12817 Mdot
.19338 .26648 Mdot
.76222 .11937 Mdot
.56908 .05732 Mdot
.47633 .07919 Mdot
.3482 .19953 Mdot
.02536 .22294 Mdot
.50012 .61787 Mdot
.50038 .61753 Mdot
.5012 .61642 Mdot
.50382 .61288 Mdot
.51216 .60161 Mdot
.53874 .56605 Mdot
.62284 .46315 Mdot
.87345 .35781 Mdot
.2945 .49962 Mdot
.4861 .51249 Mdot
.65687 .3895 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.49429 .00771 Mdot
.48182 .02453 Mdot
.44212 .07701 Mdot
.31752 .21148 Mdot
.97534 .18871 Mdot
.67001 .05941 Mdot
.57387 .6114 Mdot
.58461 .5366 Mdot
.71637 .39234 Mdot
.50122 .61639 Mdot
.50387 .6128 Mdot
.51234 .60137 Mdot
.5393 .56531 Mdot
.62461 .46124 Mdot
.87831 .3591 Mdot
.29727 .50018 Mdot
.48796 .51133 Mdot
.6606 .38646 Mdot
.0353 .41892 Mdot
.35748 .53408 Mdot
.50029 .61764 Mdot
.50094 .61677 Mdot
.50298 .61401 Mdot
.5095 .60521 Mdot
.53025 .57734 Mdot
.59609 .49357 Mdot
.79748 .35254 Mdot
.22705 .49856 Mdot
.42037 .56933 Mdot
.49917 .5701 Mdot
.57673 .50169 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .0025 Mdot
.49412 .00795 Mdot
.48126 .02529 Mdot
.44034 .0793 Mdot
.31203 .21578 Mdot
.96288 .18168 Mdot
.66891 .05288 Mdot
.58335 .59713 Mdot
.61717 .49806 Mdot
.8113 .36132 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49547 .00613 Mdot
.48555 .0195 Mdot
.454 .06155 Mdot
.35442 .17846 Mdot
.06566 .23762 Mdot
.68118 .10366 Mdot
.51347 .09119 Mdot
.36592 .2013 Mdot
.04022 .23818 Mdot
.50093 .61678 Mdot
.50295 .61405 Mdot
.5094 .60534 Mdot
.52995 .57774 Mdot
.59514 .4947 Mdot
.79471 .35293 Mdot
.22365 .49846 Mdot
.41712 .57187 Mdot
.49182 .57945 Mdot
.55424 .53014 Mdot
.69646 .39087 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49324 .00913 Mdot
.47847 .02903 Mdot
.4315 .09059 Mdot
.28492 .2346 Mdot
.90533 .15192 Mdot
.65952 .02758 Mdot
.61489 .54812 Mdot
.72801 .40198 Mdot
.07759 .4711 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00147 Mdot
.49655 .00467 Mdot
.48899 .01486 Mdot
.46494 .0471 Mdot
.38873 .14205 Mdot
.15889 .26607 Mdot
.72838 .11989 Mdot
.53439 .08825 Mdot
.3916 .18115 Mdot
.0985 .26674 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49961 .00053 Mdot
.49876 .00167 Mdot
.49605 .00534 Mdot
.48742 .01699 Mdot
.45993 .05375 Mdot
.37296 .15941 Mdot
.11504 .257 Mdot
.6992 .11691 Mdot
.50018 .61779 Mdot
.50057 .61726 Mdot
.50183 .61557 Mdot
.50582 .61017 Mdot
.51855 .59301 Mdot
.55903 .53953 Mdot
.68605 .40374 Mdot
.03278 .43392 Mdot
.33069 .5629 Mdot
.41989 .01603 Mdot
.39395 .10723 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48731 .01714 Mdot
.45958 .05421 Mdot
.37187 .16057 Mdot
.11206 .25608 Mdot
.69771 .11643 Mdot
.50932 .10779 Mdot
.33491 .23483 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50758 .6078 Mdot
.52415 .5855 Mdot
.57679 .51704 Mdot
.74021 .36977 Mdot
.14191 .48458 Mdot
.35785 .59952 Mdot
.38781 .07709 Mdot
.26306 .22414 Mdot
.90039 .13771 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50901 .60586 Mdot
.52871 .57939 Mdot
.59124 .49936 Mdot
.78327 .35502 Mdot
.20883 .49766 Mdot
.4036 .58166 Mdot
.46244 .61616 Mdot
.46548 .02987 Mdot
.41714 .10327 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .004 Mdot
.49057 .01273 Mdot
.46997 .0404 Mdot
.4046 .12364 Mdot
.20454 .26521 Mdot
.77542 .11954 Mdot
.582 .04684 Mdot
.5062 .0411 Mdot
.43971 .09566 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50991 .60465 Mdot
.53157 .57557 Mdot
.60029 .48863 Mdot
.80968 .35133 Mdot
.24121 .49865 Mdot
.43437 .55778 Mdot
.53187 .52844 Mdot
.67684 .39621 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49189 .01096 Mdot
.47415 .03482 Mdot
.41782 .10766 Mdot
.24362 .25509 Mdot
.83089 .12619 Mdot
.62671 .02075 Mdot
.59314 .55728 Mdot
.69144 .41961 Mdot
.0125 .43118 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48993 .0136 Mdot
.46793 .04313 Mdot
.39815 .13123 Mdot
.18582 .26694 Mdot
.7539 .11944 Mdot
.56064 .06457 Mdot
.45617 .10469 Mdot
.28677 .24832 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49117 .01192 Mdot
.47189 .03785 Mdot
.41065 .11639 Mdot
.22233 .26171 Mdot
.79887 .12107 Mdot
.60298 .03213 Mdot
.551 .60369 Mdot
.57422 .53735 Mdot
.70476 .39572 Mdot
.50103 .61664 Mdot
.5033 .61358 Mdot
.5105 .60385 Mdot
.53344 .57308 Mdot
.60619 .48178 Mdot
.82665 .35102 Mdot
.25869 .49834 Mdot
.45236 .54185 Mdot
.57562 .47435 Mdot
.80811 .33653 Mdot
.26359 .48354 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49248 .01015 Mdot
.47606 .03226 Mdot
.42386 .10019 Mdot
.26175 .24733 Mdot
.86156 .13457 Mdot
.64382 .01867 Mdot
.61361 .54009 Mdot
.73972 .39286 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.50631 .60951 Mdot
.5201 .59093 Mdot
.56396 .53322 Mdot
.70119 .39256 Mdot
.06602 .45202 Mdot
.33463 .57919 Mdot
.39748 .04976 Mdot
.31696 .18444 Mdot
.01853 .20158 Mdot
.49978 .0003 Mdot
.49928 .00097 Mdot
.49772 .00308 Mdot
.49274 .00981 Mdot
.47687 .03118 Mdot
.42641 .09699 Mdot
.26948 .24343 Mdot
.87559 .13949 Mdot
.64989 .02019 Mdot
.61722 .53911 Mdot
.74492 .39164 Mdot
.11122 .48656 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50685 .60877 Mdot
.52184 .58859 Mdot
.56947 .52621 Mdot
.71804 .38163 Mdot
.10054 .46877 Mdot
.34206 .59231 Mdot
.38369 .07275 Mdot
.26598 .21955 Mdot
.91074 .14107 Mdot
.50097 .61672 Mdot
.50311 .61384 Mdot
.5099 .60467 Mdot
.53152 .57564 Mdot
.60013 .48882 Mdot
.8092 .35136 Mdot
.24069 .49866 Mdot
.43385 .55823 Mdot
.53061 .53003 Mdot
.673 .39942 Mdot
.02673 .42408 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00194 Mdot
.49542 .00619 Mdot
.48541 .01969 Mdot
.45355 .06215 Mdot
.35299 .17987 Mdot
.06195 .23586 Mdot
.68032 .10223 Mdot
.5149 .08844 Mdot
.37181 .19484 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49385 .00831 Mdot
.48041 .02642 Mdot
.43767 .08274 Mdot
.30379 .22194 Mdot
.94469 .17169 Mdot
.66689 .0438 Mdot
.59602 .57813 Mdot
.66059 .45326 Mdot
.92721 .3881 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46949 .04105 Mdot
.40306 .12546 Mdot
.20006 .2658 Mdot
.76999 .11942 Mdot
.57676 .05099 Mdot
.49426 .05631 Mdot
.40316 .14065 Mdot
.17559 .27236 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50741 .60802 Mdot
.52362 .58621 Mdot
.57511 .51913 Mdot
.73513 .37223 Mdot
.13285 .48158 Mdot
.35364 .59893 Mdot
.38455 .07878 Mdot
.25707 .22618 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39525 .1346 Mdot
.17747 .26708 Mdot
.74532 .1196 Mdot
.5518 .07242 Mdot
.43462 .13135 Mdot
.22209 .27663 Mdot
.77449 .13083 Mdot
.49994 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00283 Mdot
.49332 .00902 Mdot
.47873 .02868 Mdot
.43232 .08956 Mdot
.28741 .23304 Mdot
.91034 .15425 Mdot
.66076 .0293 Mdot
.61335 .55091 Mdot
.72195 .40565 Mdot
.50105 .61662 Mdot
.50334 .61353 Mdot
.51063 .60368 Mdot
.53387 .57252 Mdot
.60752 .48025 Mdot
.83045 .35116 Mdot
.26226 .49827 Mdot
.45605 .5385 Mdot
.58474 .4636 Mdot
.83462 .33642 Mdot
.29028 .47927 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00325 Mdot
.49233 .01036 Mdot
.47556 .03293 Mdot
.42227 .10216 Mdot
.25697 .24956 Mdot
.85317 .13195 Mdot
.63967 .01846 Mdot
.60981 .54258 Mdot
.73189 .39599 Mdot
.09117 .47596 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51026 .60418 Mdot
.53267 .57411 Mdot
.60373 .48462 Mdot
.8196 .35096 Mdot
.25174 .49849 Mdot
.44516 .54833 Mdot
.55794 .49579 Mdot
.75573 .34834 Mdot
.50094 .61677 Mdot
.50299 .61399 Mdot
.50953 .60516 Mdot
.53036 .57719 Mdot
.59645 .49315 Mdot
.79851 .35241 Mdot
.2283 .49858 Mdot
.42158 .56838 Mdot
.50192 .5666 Mdot
.58514 .49138 Mdot
.79007 .34849 Mdot
.49995 7e-05 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00212 Mdot
.495 .00676 Mdot
.48406 .02151 Mdot
.44925 .06777 Mdot
.33959 .19255 Mdot
.02805 .21841 Mdot
.67465 .0871 Mdot
.53372 .05608 Mdot
.44299 .10781 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49427 .00774 Mdot
.48174 .02463 Mdot
.44189 .07731 Mdot
.31681 .21204 Mdot
.97372 .18779 Mdot
.66987 .05855 Mdot
.57513 .60949 Mdot
.58896 .53125 Mdot
.50075 .61701 Mdot
.5024 .61479 Mdot
.50766 .60769 Mdot
.5244 .58516 Mdot
.57759 .51604 Mdot
.74262 .36866 Mdot
.14612 .48587 Mdot
.35996 .59958 Mdot
.38982 .07572 Mdot
.2673 .2224 Mdot
.90745 .14135 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49021 .01322 Mdot
.46882 .04195 Mdot
.40094 .12796 Mdot
.1939 .26643 Mdot
.7628 .11937 Mdot
.56966 .05683 Mdot
.4777 .07743 Mdot
.50086 .61687 Mdot
.50275 .61431 Mdot
.50877 .60619 Mdot
.52794 .58041 Mdot
.58881 .50229 Mdot
.77609 .35672 Mdot
.1989 .49673 Mdot
.39518 .58703 Mdot
.44535 .01867 Mdot
.41515 .09365 Mdot
.26361 .24066 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49776 .00303 Mdot
.49286 .00964 Mdot
.47726 .03065 Mdot
.42766 .09543 Mdot
.27325 .2414 Mdot
.88265 .14221 Mdot
.65255 .02147 Mdot
.61782 .53998 Mdot
.74412 .39254 Mdot
.10898 .48585 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49737 .00356 Mdot
.49161 .01134 Mdot
.47326 .03601 Mdot
.41499 .11113 Mdot
.23518 .25803 Mdot
.81768 .12363 Mdot
.61764 .02423 Mdot
.57844 .57246 Mdot
.65218 .45191 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49824 .00237 Mdot
.49441 .00756 Mdot
.48218 .02404 Mdot
.44328 .07552 Mdot
.3211 .20858 Mdot
.9836 .19341 Mdot
.67066 .06382 Mdot
.5674 .00319 Mdot
.56224 .56498 Mdot
.64809 .44666 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .6022 Mdot
.53734 .5679 Mdot
.61846 .46795 Mdot
.86131 .35504 Mdot
.28685 .49865 Mdot
.48002 .51712 Mdot
.64331 .4015 Mdot
.99366 .39563 Mdot
.35352 .51305 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50867 .60632 Mdot
.52763 .58083 Mdot
.58782 .50348 Mdot
.77317 .3575 Mdot
.19472 .49624 Mdot
.3918 .58899 Mdot
.43879 .02631 Mdot
.39621 .11585 Mdot
.20876 .25847 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51437 .59864 Mdot
.54575 .5568 Mdot
.64482 .44032 Mdot
.93237 .37949 Mdot
.31833 .51365 Mdot
.48724 .52546 Mdot
.63702 .41356 Mdot
.96786 .38397 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48822 .01591 Mdot
.46247 .05038 Mdot
.38094 .15075 Mdot
.13703 .26266 Mdot
.71204 .11929 Mdot
.51903 .10169 Mdot
.35449 .21856 Mdot
.00084 .21935 Mdot
.64593 .10223 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.49731 .00364 Mdot
.49142 .01159 Mdot
.47266 .03682 Mdot
.41309 .11344 Mdot
.22954 .25977 Mdot
.80923 .12232 Mdot
.61131 .02734 Mdot
.56707 .58503 Mdot
.62047 .48371 Mdot
.83782 .35806 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51223 .60152 Mdot
.53895 .56577 Mdot
.62352 .46242 Mdot
.87531 .35829 Mdot
.29558 .49982 Mdot
.48685 .512 Mdot
.65841 .38822 Mdot
.03026 .4161 Mdot
.35699 .53155 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00318 Mdot
.49249 .01014 Mdot
.47609 .03222 Mdot
.42395 .10008 Mdot
.26202 .2472 Mdot
.86204 .13473 Mdot
.64404 .01869 Mdot
.61379 .54 Mdot
.74006 .39274 Mdot
.10459 .48287 Mdot
.50077 .61699 Mdot
.50245 .61472 Mdot
.50782 .60747 Mdot
.5249 .58448 Mdot
.57919 .51406 Mdot
.74742 .36654 Mdot
.15435 .48823 Mdot
.36438 .59928 Mdot
.39472 .07189 Mdot
.2784 .21709 Mdot
.92714 .15188 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48754 .01682 Mdot
.46033 .05322 Mdot
.37422 .15806 Mdot
.11848 .25803 Mdot
.70098 .11742 Mdot
.51099 .10724 Mdot
.33747 .23306 Mdot
.96037 .1967 Mdot
.6421 .08178 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .00151 Mdot
.49645 .0048 Mdot
.48869 .01527 Mdot
.46398 .04838 Mdot
.38571 .14546 Mdot
.15035 .26502 Mdot
.72155 .11982 Mdot
.52767 .0943 Mdot
.3751 .19856 Mdot
.05382 .24751 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49667 .0045 Mdot
.4894 .01432 Mdot
.46623 .04539 Mdot
.39278 .13744 Mdot
.1704 .26691 Mdot
.73853 .11975 Mdot
.54477 .07879 Mdot
.41728 .15208 Mdot
.17121 .28191 Mdot
.71508 .1379 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48872 .01523 Mdot
.46407 .04826 Mdot
.38599 .14515 Mdot
.15114 .26513 Mdot
.72215 .11984 Mdot
.52825 .09378 Mdot
.37651 .19712 Mdot
.05757 .24933 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00409 Mdot
.49036 .01301 Mdot
.4693 .04129 Mdot
.40249 .12614 Mdot
.19839 .266 Mdot
.76799 .11939 Mdot
.57481 .05257 Mdot
.48976 .06205 Mdot
.38936 .15656 Mdot
.13603 .26787 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49067 .0126 Mdot
.47028 .04 Mdot
.40557 .12249 Mdot
.20737 .26478 Mdot
.77895 .11967 Mdot
.58533 .0443 Mdot
.51365 .03166 Mdot
.46242 .06618 Mdot
.35534 .18256 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00505 Mdot
.48809 .01608 Mdot
.46207 .05092 Mdot
.37968 .15213 Mdot
.13353 .2619 Mdot
.70977 .11904 Mdot
.51715 .10318 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60134 Mdot
.53938 .5652 Mdot
.62488 .46095 Mdot
.87905 .3593 Mdot
.29768 .50028 Mdot
.48821 .51119 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61076 Mdot
.51716 .59487 Mdot
.55464 .54521 Mdot
.67247 .41483 Mdot
.00125 .41599 Mdot
.32816 .5461 Mdot
.44455 .59647 Mdot
.47944 .61548 Mdot
.48357 .01265 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50592 .61003 Mdot
.51887 .59259 Mdot
.56004 .53824 Mdot
.68916 .40134 Mdot
.03977 .43783 Mdot
.33135 .56652 Mdot
.4147 .02382 Mdot
.37616 .12739 Mdot
.17003 .2567 Mdot
.50053 .61731 Mdot
.5017 .61573 Mdot
.50543 .6107 Mdot
.51729 .59471 Mdot
.55503 .5447 Mdot
.67369 .41379 Mdot
.00416 .41765 Mdot
.32839 .54765 Mdot
.44227 .60001 Mdot
.47143 .00831 Mdot
.45798 .04682 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.48789 .01635 Mdot
.46144 .05174 Mdot
.37772 .15427 Mdot
.12811 .26062 Mdot
.70642 .11857 Mdot
.51457 .10508 Mdot
.34454 .22736 Mdot
.97666 .2058 Mdot
.64367 .08998 Mdot
.50099 .61669 Mdot
.50316 .61376 Mdot
.51007 .60444 Mdot
.53207 .5749 Mdot
.60186 .48679 Mdot
.81421 .35109 Mdot
.24613 .49859 Mdot
.43939 .55344 Mdot
.54391 .51325 Mdot
.71345 .36958 Mdot
.11546 .46747 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .01719 Mdot
.45944 .05439 Mdot
.37144 .16102 Mdot
.11091 .25572 Mdot
.69715 .11623 Mdot
.50908 .10781 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.49831 .00229 Mdot
.49461 .00729 Mdot
.48282 .02318 Mdot
.44531 .07289 Mdot
.32738 .20334 Mdot
.99837 .20183 Mdot
.67181 .07173 Mdot
.55574 .02111 Mdot
.52159 .00115 Mdot
.51973 .60094 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50694 .60866 Mdot
.52211 .58823 Mdot
.57033 .52513 Mdot
.72066 .38008 Mdot
.10567 .471 Mdot
.34357 .59378 Mdot
.38282 .07483 Mdot
.26175 .22197 Mdot
.90259 .1372 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.5118 .6021 Mdot
.53757 .5676 Mdot
.61918 .46715 Mdot
.86332 .35545 Mdot
.28819 .49877 Mdot
.48117 .51618 Mdot
.64597 .39905 Mdot
.00029 .39932 Mdot
.35418 .51637 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .61211 Mdot
.51397 .59917 Mdot
.5445 .55846 Mdot
.6409 .44424 Mdot
.9221 .37487 Mdot
.31554 .51008 Mdot
.49021 .51915 Mdot
.65021 .39967 Mdot
.00354 .40295 Mdot
.50035 .61756 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.51131 .60276 Mdot
.53604 .56963 Mdot
.61435 .47251 Mdot
.84981 .35304 Mdot
.27857 .49822 Mdot
.47244 .52364 Mdot
.62518 .41919 Mdot
.94693 .37089 Mdot
.50052 .61733 Mdot
.50165 .6158 Mdot
.50527 .61091 Mdot
.51679 .59537 Mdot
.55346 .54674 Mdot
.66881 .41798 Mdot
.99251 .41104 Mdot
.32744 .54146 Mdot
.45134 .58587 Mdot
.50338 .58274 Mdot
.56048 .52802 Mdot
.50068 .61711 Mdot
.50217 .6151 Mdot
.50693 .60868 Mdot
.52207 .58828 Mdot
.5702 .52529 Mdot
.72027 .38031 Mdot
.1049 .47068 Mdot
.34334 .59357 Mdot
.38292 .07454 Mdot
.26231 .22164 Mdot
.90369 .13771 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50561 .61046 Mdot
.51787 .59393 Mdot
.55688 .54231 Mdot
.6794 .40905 Mdot
.01754 .42528 Mdot
.32943 .55483 Mdot
.4317 .61622 Mdot
.43463 .05709 Mdot
.34226 .18054 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49237 .01031 Mdot
.47568 .03277 Mdot
.42266 .10168 Mdot
.25813 .24903 Mdot
.85519 .13256 Mdot
.6407 .01846 Mdot
.61084 .54184 Mdot
.73412 .39503 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.51091 .6033 Mdot
.53474 .57135 Mdot
.61027 .47711 Mdot
.83829 .35169 Mdot
.26924 .49816 Mdot
.4632 .53198 Mdot
.60244 .44343 Mdot
.88496 .34583 Mdot
.3254 .47712 Mdot
.50058 .61724 Mdot
.50186 .61552 Mdot
.50593 .61002 Mdot
.51889 .59255 Mdot
.56013 .53812 Mdot
.68945 .40112 Mdot
.04042 .43819 Mdot
.33141 .56685 Mdot
.41423 .02453 Mdot
.37454 .12916 Mdot
.16555 .25642 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.4957 .0058 Mdot
.48631 .01848 Mdot
.45642 .05837 Mdot
.36197 .17088 Mdot
.08548 .24637 Mdot
.68684 .11029 Mdot
.50839 .10252 Mdot
.3425 .22584 Mdot
.97709 .20467 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00222 Mdot
.49475 .00709 Mdot
.48328 .02256 Mdot
.44679 .07097 Mdot
.33195 .19938 Mdot
.00934 .20804 Mdot
.67273 .07755 Mdot
.54725 .03438 Mdot
.49162 .04215 Mdot
.42342 .11044 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.5101 .6044 Mdot
.53216 .57479 Mdot
.60214 .48647 Mdot
.81501 .35106 Mdot
.24698 .49858 Mdot
.44026 .55267 Mdot
.54601 .51061 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61518 Mdot
.50674 .60894 Mdot
.52146 .58911 Mdot
.56826 .52774 Mdot
.71435 .38389 Mdot
.09321 .46544 Mdot
.34011 .58996 Mdot
.38553 .06914 Mdot
.27366 .21505 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49158 .01137 Mdot
.47318 .03611 Mdot
.41475 .11142 Mdot
.23447 .25826 Mdot
.81659 .12344 Mdot
.61685 .02459 Mdot
.57706 .57395 Mdot
.6484 .45546 Mdot
.91145 .37754 Mdot
.50084 .61689 Mdot
.50269 .6144 Mdot
.50858 .60645 Mdot
.52732 .58125 Mdot
.58683 .50469 Mdot
.77023 .35833 Mdot
.19043 .49566 Mdot
.38843 .59083 Mdot
.43244 .03356 Mdot
.37814 .13581 Mdot
.15839 .25958 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48716 .01734 Mdot
.45911 .05483 Mdot
.37039 .16214 Mdot
.10804 .25478 Mdot
.6958 .11571 Mdot
.50857 .10777 Mdot
.33419 .23515 Mdot
.95371 .19284 Mdot
.64169 .07816 Mdot
.501 .61668 Mdot
.5032 .61372 Mdot
.51018 .60429 Mdot
.53242 .57443 Mdot
.60297 .4855 Mdot
.81742 .35099 Mdot
.2495 .49854 Mdot
.44285 .55039 Mdot
.55231 .50276 Mdot
.73882 .35558 Mdot
.16347 .48185 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00382 Mdot
.491 .01215 Mdot
.47134 .03858 Mdot
.40892 .11848 Mdot
.21722 .2629 Mdot
.79183 .12043 Mdot
.59698 .03598 Mdot
.53876 .00041 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49677 .00437 Mdot
.4897 .01392 Mdot
.46718 .04413 Mdot
.39578 .13399 Mdot
.17897 .26709 Mdot
.74682 .11957 Mdot
.55335 .07103 Mdot
.43842 .1267 Mdot
.23341 .27345 Mdot
.79096 .13076 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51272 .60086 Mdot
.5405 .56372 Mdot
.62839 .45719 Mdot
.88865 .36218 Mdot
.30263 .50173 Mdot
.49083 .51023 Mdot
.66526 .3831 Mdot
.04539 .42461 Mdot
.35835 .53927 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01801 Mdot
.45751 .05693 Mdot
.36539 .16737 Mdot
.09458 .24998 Mdot
.6901 .11276 Mdot
.50765 .10567 Mdot
.33668 .23187 Mdot
.9615 .19653 Mdot
.64351 .08079 Mdot
.50128 .61631 Mdot
.50407 .61254 Mdot
.51296 .60054 Mdot
.54127 .5627 Mdot
.63081 .45463 Mdot
.89519 .36434 Mdot
.30567 .50295 Mdot
.49187 .51048 Mdot
.66589 .38307 Mdot
.04608 .42519 Mdot
.35811 .53999 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50854 .6065 Mdot
.52721 .5814 Mdot
.58649 .50511 Mdot
.76921 .35863 Mdot
.18893 .49545 Mdot
.38727 .59143 Mdot
.43032 .03595 Mdot
.37215 .14213 Mdot
.14218 .25709 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00325 Mdot
.49233 .01037 Mdot
.47555 .03294 Mdot
.42225 .10219 Mdot
.25691 .24959 Mdot
.85307 .13192 Mdot
.63962 .01846 Mdot
.60975 .54262 Mdot
.73178 .39604 Mdot
.09097 .47586 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46278 .04997 Mdot
.38193 .14966 Mdot
.13976 .26321 Mdot
.71388 .11945 Mdot
.52061 .10039 Mdot
.35817 .21515 Mdot
.01005 .22446 Mdot
.64686 .10683 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49512 .00659 Mdot
.48446 .02098 Mdot
.45052 .06612 Mdot
.34354 .18891 Mdot
.03788 .22369 Mdot
.67594 .09184 Mdot
.52734 .06661 Mdot
.41957 .13804 Mdot
.19621 .27724 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49734 .00359 Mdot
.49154 .01143 Mdot
.47304 .03631 Mdot
.41429 .11197 Mdot
.23312 .25869 Mdot
.81455 .12311 Mdot
.61534 .0253 Mdot
.57441 .57684 Mdot
.64106 .46254 Mdot
.89266 .3704 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50516 .61106 Mdot
.51644 .59585 Mdot
.55234 .5482 Mdot
.66533 .42105 Mdot
.98406 .4063 Mdot
.32666 .53705 Mdot
.45769 .57581 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00697 Mdot
.48356 .02219 Mdot
.44766 .06983 Mdot
.33467 .19699 Mdot
.01594 .21174 Mdot
.67334 .08098 Mdot
.54231 .04222 Mdot
.47399 .06622 Mdot
.36685 .17576 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50297 .61403 Mdot
.50945 .60527 Mdot
.53011 .57753 Mdot
.59565 .4941 Mdot
.79618 .35272 Mdot
.22547 .49852 Mdot
.41885 .57053 Mdot
.49572 .57449 Mdot
.56617 .5149 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50739 .60806 Mdot
.52353 .58632 Mdot
.57484 .51947 Mdot
.73432 .37264 Mdot
.13137 .48106 Mdot
.35299 .59878 Mdot
.38415 .0789 Mdot
.25648 .22633 Mdot
.89028 .13248 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .60489 Mdot
.531 .57634 Mdot
.59847 .49076 Mdot
.8044 .35175 Mdot
.23525 .49866 Mdot
.42839 .56283 Mdot
.51771 .54645 Mdot
.63354 .43667 Mdot
.50023 .61772 Mdot
.50074 .61703 Mdot
.50236 .61484 Mdot
.50753 .60787 Mdot
.52398 .58572 Mdot
.57627 .51769 Mdot
.73864 .37052 Mdot
.13913 .48369 Mdot
.35651 .59941 Mdot
.38665 .07779 Mdot
.26078 .225 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49806 .00263 Mdot
.49381 .00836 Mdot
.48027 .02661 Mdot
.43723 .0833 Mdot
.30244 .22291 Mdot
.94176 .17012 Mdot
.66651 .04241 Mdot
.59788 .57532 Mdot
.66698 .4474 Mdot
.94307 .39574 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00353 Mdot
.49167 .01126 Mdot
.47345 .03575 Mdot
.41561 .11037 Mdot
.23702 .25743 Mdot
.8205 .12412 Mdot
.61967 .02335 Mdot
.58189 .56877 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00483 Mdot
.48861 .01539 Mdot
.46371 .04874 Mdot
.38486 .14641 Mdot
.14796 .26465 Mdot
.71974 .11977 Mdot
.52595 .09581 Mdot
.37092 .20278 Mdot
.04282 .242 Mdot
.65126 .12195 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01783 Mdot
.45795 .05636 Mdot
.36677 .16594 Mdot
.09827 .25136 Mdot
.69156 .11365 Mdot
.50766 .10655 Mdot
.33526 .23343 Mdot
.95756 .19455 Mdot
.64277 .07924 Mdot
.49965 .00047 Mdot
.49889 .00149 Mdot
.49648 .00476 Mdot
.48877 .01516 Mdot
.46424 .04803 Mdot
.38653 .14454 Mdot
.15266 .26534 Mdot
.72334 .11986 Mdot
.5294 .09275 Mdot
.37933 .19421 Mdot
.06509 .25288 Mdot
.65592 .13038 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51293 .60058 Mdot
.54117 .56284 Mdot
.63047 .45499 Mdot
.89429 .36403 Mdot
.30527 .50277 Mdot
.49176 .5104 Mdot
.66591 .38298 Mdot
.04625 .42525 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .00509 Mdot
.48799 .01621 Mdot
.46176 .05132 Mdot
.37873 .15317 Mdot
.13089 .26129 Mdot
.70811 .11883 Mdot
.51584 .10417 Mdot
.3473 .22499 Mdot
.98325 .20949 Mdot
.64429 .09332 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49007 .01341 Mdot
.46837 .04254 Mdot
.39953 .12962 Mdot
.1898 .26674 Mdot
.75821 .11939 Mdot
.56504 .06076 Mdot
.46673 .09138 Mdot
.31886 .22533 Mdot
.95427 .18352 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50992 .60464 Mdot
.53159 .57554 Mdot
.60034 .48856 Mdot
.80983 .35132 Mdot
.24138 .49865 Mdot
.43454 .55763 Mdot
.53227 .52792 Mdot
.67808 .39518 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50922 .60558 Mdot
.52938 .57849 Mdot
.59336 .49682 Mdot
.78949 .35379 Mdot
.21704 .49819 Mdot
.41096 .57649 Mdot
.47817 .59667 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48873 .01522 Mdot
.4641 .04822 Mdot
.38608 .14504 Mdot
.15141 .26517 Mdot
.72236 .11984 Mdot
.52845 .0936 Mdot
.377 .19661 Mdot
.05888 .24996 Mdot
.65444 .12822 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46801 .04301 Mdot
.39842 .13092 Mdot
.18658 .26691 Mdot
.75471 .11943 Mdot
.56148 .06384 Mdot
.45817 .10217 Mdot
.29286 .2444 Mdot
.89741 .15574 Mdot
.50036 .61755 Mdot
.50113 .61651 Mdot
.50361 .61316 Mdot
.51149 .60252 Mdot
.53659 .5689 Mdot
.61608 .47058 Mdot
.85466 .35381 Mdot
.28219 .49834 Mdot
.47585 .52064 Mdot
.63343 .41094 Mdot
.96853 .38195 Mdot
.50057 .61726 Mdot
.50183 .61557 Mdot
.50582 .61017 Mdot
.51855 .59302 Mdot
.55902 .53954 Mdot
.68602 .40376 Mdot
.03273 .43389 Mdot
.33068 .56287 Mdot
.41994 .01597 Mdot
.3941 .10706 Mdot
.22087 .25214 Mdot
.50097 .61672 Mdot
.50309 .61385 Mdot
.50986 .60472 Mdot
.53139 .57581 Mdot
.59972 .48929 Mdot
.80803 .35145 Mdot
.23938 .49866 Mdot
.43252 .55936 Mdot
.52746 .53402 Mdot
.66339 .40779 Mdot
.00357 .4111 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48819 .01594 Mdot
.46239 .05049 Mdot
.3807 .15101 Mdot
.13636 .26252 Mdot
.7116 .11925 Mdot
.51866 .10199 Mdot
.35363 .21935 Mdot
.99872 .21816 Mdot
.64573 .10117 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .00211 Mdot
.49503 .00671 Mdot
.48417 .02137 Mdot
.44959 .06732 Mdot
.34066 .19157 Mdot
.0307 .21985 Mdot
.67497 .0884 Mdot
.53194 .05899 Mdot
.4365 .11631 Mdot
.24831 .26384 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60664 Mdot
.52687 .58185 Mdot
.58541 .50641 Mdot
.76602 .35962 Mdot
.18415 .49471 Mdot
.38369 .59319 Mdot
.42389 .04306 Mdot
.49987 .00017 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.48692 .01766 Mdot
.45835 .05584 Mdot
.368 .16465 Mdot
.10158 .25256 Mdot
.69293 .1144 Mdot
.50782 .10715 Mdot
.33445 .23441 Mdot
.95517 .1934 Mdot
.50067 .61713 Mdot
.50214 .61515 Mdot
.50681 .60884 Mdot
.52168 .58881 Mdot
.56897 .52685 Mdot
.71651 .38256 Mdot
.09752 .46741 Mdot
.34123 .59137 Mdot
.38437 .07135 Mdot
.26893 .21785 Mdot
.91644 .14389 Mdot
.50054 .6173 Mdot
.50173 .61569 Mdot
.50552 .61058 Mdot
.51758 .59432 Mdot
.55595 .54351 Mdot
.67654 .4114 Mdot
.01088 .42148 Mdot
.32891 .55126 Mdot
.43696 .60818 Mdot
.45289 .03318 Mdot
.3992 .12051 Mdot
.50068 .61712 Mdot
.50217 .61511 Mdot
.5069 .60872 Mdot
.52198 .58841 Mdot
.56991 .52566 Mdot
.71938 .38083 Mdot
.10318 .46993 Mdot
.34282 .59308 Mdot
.3832 .07387 Mdot
.26368 .22087 Mdot
.9063 .13894 Mdot
.50062 .6172 Mdot
.50198 .61537 Mdot
.50629 .60953 Mdot
.52005 .59099 Mdot
.5638 .53341 Mdot
.70072 .39289 Mdot
.06502 .4515 Mdot
.33448 .57874 Mdot
.39805 .04888 Mdot
.31896 .1828 Mdot
.02319 .20421 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00382 Mdot
.49099 .01217 Mdot
.47129 .03864 Mdot
.40878 .11865 Mdot
.21679 .263 Mdot
.79126 .12038 Mdot
.59647 .03632 Mdot
.5377 .00169 Mdot
.53496 .58758 Mdot
.58424 .51308 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00236 Mdot
.49444 .00751 Mdot
.48229 .02389 Mdot
.44364 .07505 Mdot
.3222 .20767 Mdot
.98619 .19488 Mdot
.67086 .0652 Mdot
.56536 .0063 Mdot
.55517 .57421 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49427 .00775 Mdot
.48173 .02465 Mdot
.44185 .07736 Mdot
.31668 .21215 Mdot
.97342 .18762 Mdot
.66985 .05839 Mdot
.57536 .60914 Mdot
.58975 .53028 Mdot
.73173 .38371 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50423 .61231 Mdot
.51349 .59982 Mdot
.54296 .56048 Mdot
.63607 .44915 Mdot
.90933 .36957 Mdot
.31135 .50629 Mdot
.49216 .51355 Mdot
.66122 .38837 Mdot
.03282 .41858 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49074 .01251 Mdot
.4705 .0397 Mdot
.40627 .12165 Mdot
.20944 .26443 Mdot
.78158 .11978 Mdot
.58777 .04247 Mdot
.51905 .02486 Mdot
.47883 .04442 Mdot
.40695 .12585 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00168 Mdot
.49603 .00537 Mdot
.48735 .01708 Mdot
.45971 .05404 Mdot
.37228 .16013 Mdot
.11318 .25643 Mdot
.69826 .11662 Mdot
.50957 .10775 Mdot
.33523 .23464 Mdot
.95558 .19399 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51167 .60228 Mdot
.53716 .56815 Mdot
.61788 .46859 Mdot
.85969 .35472 Mdot
.28574 .49856 Mdot
.47906 .51792 Mdot
.64105 .40361 Mdot
.98799 .39249 Mdot
.50027 .61766 Mdot
.50087 .61685 Mdot
.50279 .61427 Mdot
.50888 .60604 Mdot
.52828 .57996 Mdot
.58988 .501 Mdot
.77924 .35594 Mdot
.20331 .49718 Mdot
.39885 .58476 Mdot
.45268 .00995 Mdot
.43658 .0672 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48722 .01726 Mdot
.45929 .05459 Mdot
.37097 .16152 Mdot
.10962 .2553 Mdot
.69654 .116 Mdot
.50884 .10781 Mdot
.33439 .2351 Mdot
.954 .19304 Mdot
.64165 .07839 Mdot
.50063 .61719 Mdot
.502 .61533 Mdot
.50637 .60943 Mdot
.52029 .59067 Mdot
.56457 .53243 Mdot
.70308 .39125 Mdot
.07002 .45409 Mdot
.33528 .58095 Mdot
.39528 .05314 Mdot
.3093 .19057 Mdot
.00095 .19145 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46592 .0458 Mdot
.39181 .13856 Mdot
.16762 .26677 Mdot
.73597 .1198 Mdot
.54213 .0812 Mdot
.41074 .15967 Mdot
.15239 .28033 Mdot
.69881 .14035 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50193 .61543 Mdot
.50613 .60975 Mdot
.51954 .59167 Mdot
.56219 .53547 Mdot
.69578 .39641 Mdot
.05438 .44584 Mdot
.33299 .57378 Mdot
.40459 .039 Mdot
.50106 .61661 Mdot
.50336 .61349 Mdot
.51071 .60357 Mdot
.53412 .57218 Mdot
.60832 .47934 Mdot
.83273 .35128 Mdot
.26434 .49823 Mdot
.4582 .53654 Mdot
.59006 .45744 Mdot
.84991 .33802 Mdot
.30298 .47747 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00453 Mdot
.48931 .01444 Mdot
.46595 .04576 Mdot
.39192 .13843 Mdot
.16794 .26679 Mdot
.73626 .1198 Mdot
.54243 .08093 Mdot
.41148 .15882 Mdot
.15451 .28059 Mdot
.7005 .14013 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00414 Mdot
.49023 .0132 Mdot
.46887 .04188 Mdot
.4011 .12778 Mdot
.19436 .26639 Mdot
.76332 .11937 Mdot
.57018 .05639 Mdot
.47894 .07586 Mdot
.35619 .19176 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51339 .59996 Mdot
.54263 .56091 Mdot
.63505 .45021 Mdot
.90659 .3685 Mdot
.31034 .50557 Mdot
.49231 .51269 Mdot
.66276 .38677 Mdot
.03696 .42072 Mdot
.50089 .61683 Mdot
.50285 .61419 Mdot
.50907 .60579 Mdot
.52888 .57916 Mdot
.59179 .4987 Mdot
.78488 .35468 Mdot
.21098 .49782 Mdot
.4055 .58037 Mdot
.46644 .61125 Mdot
.47742 .01408 Mdot
.45465 .05555 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50773 .60759 Mdot
.52464 .58484 Mdot
.57835 .5151 Mdot
.7449 .36763 Mdot
.15006 .48703 Mdot
.36203 .59951 Mdot
.392 .07408 Mdot
.27213 .2202 Mdot
.91583 .14576 Mdot
.50094 .61676 Mdot
.503 .61398 Mdot
.50956 .60513 Mdot
.53044 .57709 Mdot
.59669 .49286 Mdot
.79922 .35232 Mdot
.22916 .4986 Mdot
.42241 .56771 Mdot
.50383 .56417 Mdot
.59099 .48433 Mdot
.80732 .34626 Mdot
.49984 .00021 Mdot
.49949 .00069 Mdot
.49838 .00218 Mdot
.49485 .00695 Mdot
.4836 .02213 Mdot
.4478 .06965 Mdot
.3351 .19661 Mdot
.01698 .21232 Mdot
.67344 .08152 Mdot
.54154 .04344 Mdot
.47125 .06995 Mdot
.35806 .18478 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00475 Mdot
.48881 .01511 Mdot
.46436 .04788 Mdot
.38689 .14413 Mdot
.15369 .26547 Mdot
.72415 .11987 Mdot
.53019 .09205 Mdot
.38126 .19219 Mdot
.07029 .25526 Mdot
.65728 .13205 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48876 .01517 Mdot
.46421 .04807 Mdot
.38643 .14465 Mdot
.15238 .2653 Mdot
.72312 .11985 Mdot
.52919 .09295 Mdot
.3788 .19476 Mdot
.06367 .25222 Mdot
.65557 .1299 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.4892 .01458 Mdot
.46561 .04621 Mdot
.39084 .13966 Mdot
.16486 .26659 Mdot
.7335 .11984 Mdot
.53959 .08351 Mdot
.40447 .16685 Mdot
.1345 .27722 Mdot
.68595 .14146 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50642 .60937 Mdot
.52044 .59047 Mdot
.56503 .53185 Mdot
.70448 .3903 Mdot
.07297 .4556 Mdot
.3358 .58222 Mdot
.39375 .05553 Mdot
.30389 .1947 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51127 .60281 Mdot
.53591 .5698 Mdot
.61395 .47296 Mdot
.84868 .35288 Mdot
.2777 .4982 Mdot
.47161 .52438 Mdot
.62314 .42127 Mdot
.94151 .36826 Mdot
.34565 .48995 Mdot
.50039 .61751 Mdot
.50124 .61635 Mdot
.50396 .61268 Mdot
.51262 .601 Mdot
.54019 .56413 Mdot
.6274 .45824 Mdot
.88595 .36133 Mdot
.3013 .50128 Mdot
.49022 .51034 Mdot
.66448 .38358 Mdot
.04383 .4237 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50839 .6067 Mdot
.52673 .58204 Mdot
.58497 .50695 Mdot
.76471 .36004 Mdot
.18216 .49438 Mdot
.38224 .59386 Mdot
.42135 .0458 Mdot
.34725 .16665 Mdot
.0776 .23577 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51123 .60287 Mdot
.53578 .56998 Mdot
.61353 .47343 Mdot
.84751 .35272 Mdot
.2768 .49818 Mdot
.47073 .52516 Mdot
.621 .42349 Mdot
.93579 .36556 Mdot
.3443 .48795 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50708 .60847 Mdot
.52256 .58763 Mdot
.57176 .52333 Mdot
.725 .3776 Mdot
.11402 .47449 Mdot
.34628 .59586 Mdot
.38216 .07736 Mdot
.25699 .22476 Mdot
.89333 .13311 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49827 .00234 Mdot
.49448 .00746 Mdot
.48241 .02374 Mdot
.444 .07458 Mdot
.32332 .20675 Mdot
.9888 .19637 Mdot
.67106 .06661 Mdot
.56329 .00946 Mdot
.54798 .58369 Mdot
.60356 .49432 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49726 .0037 Mdot
.49128 .01178 Mdot
.47221 .03742 Mdot
.41167 .11517 Mdot
.22532 .26094 Mdot
.80311 .12154 Mdot
.60646 .03004 Mdot
.55786 .59561 Mdot
.59414 .51334 Mdot
.76354 .36633 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00212 Mdot
.49499 .00676 Mdot
.48405 .02153 Mdot
.44922 .06781 Mdot
.3395 .19264 Mdot
.0278 .21828 Mdot
.67462 .08698 Mdot
.53388 .0558 Mdot
.44359 .10701 Mdot
.27045 .25334 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50641 .60937 Mdot
.52042 .59049 Mdot
.56499 .53191 Mdot
.70434 .39039 Mdot
.07267 .45545 Mdot
.33574 .58209 Mdot
.3939 .05529 Mdot
.30443 .19429 Mdot
.99006 .18508 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51586 .59664 Mdot
.55048 .55062 Mdot
.65956 .42626 Mdot
.96985 .39848 Mdot
.3251 .5299 Mdot
.4677 .55964 Mdot
.56218 .50346 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48852 .0155 Mdot
.46345 .04909 Mdot
.38402 .14734 Mdot
.14561 .26427 Mdot
.71801 .1197 Mdot
.52433 .09723 Mdot
.36701 .20666 Mdot
.03262 .2367 Mdot
.64964 .11752 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50784 .60744 Mdot
.52498 .58437 Mdot
.57945 .51374 Mdot
.74819 .36621 Mdot
.15565 .48858 Mdot
.36511 .59918 Mdot
.39561 .07113 Mdot
.28052 .21597 Mdot
.93107 .15405 Mdot
.5009 .61682 Mdot
.50287 .61415 Mdot
.50915 .60567 Mdot
.52915 .5788 Mdot
.59263 .49769 Mdot
.78735 .35419 Mdot
.21426 .49803 Mdot
.40843 .57832 Mdot
.47269 .60351 Mdot
.49619 .60705 Mdot
.51396 .59412 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00518 Mdot
.48779 .01648 Mdot
.46113 .05216 Mdot
.37673 .15535 Mdot
.12538 .25992 Mdot
.70481 .11829 Mdot
.51342 .10586 Mdot
.34214 .22936 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50504 .61122 Mdot
.51607 .59635 Mdot
.55116 .54973 Mdot
.66167 .42433 Mdot
.97509 .40133 Mdot
.32572 .53249 Mdot
.46413 .56546 Mdot
.54919 .52058 Mdot
.70688 .37842 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46874 .04204 Mdot
.40072 .12823 Mdot
.19325 .26649 Mdot
.76206 .11937 Mdot
.56892 .05745 Mdot
.47596 .07966 Mdot
.34707 .2006 Mdot
.02248 .22138 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45743 .05705 Mdot
.36512 .16765 Mdot
.09385 .2497 Mdot
.68983 .11258 Mdot
.50767 .10547 Mdot
.33702 .2315 Mdot
.96244 .197 Mdot
.64368 .08118 Mdot
.50045 .61743 Mdot
.50142 .61612 Mdot
.50452 .61193 Mdot
.51439 .59861 Mdot
.54583 .55671 Mdot
.64505 .4401 Mdot
.93296 .37977 Mdot
.31848 .51387 Mdot
.48703 .52588 Mdot
.63615 .4145 Mdot
.96547 .38274 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50894 .60596 Mdot
.52849 .57969 Mdot
.59053 .50022 Mdot
.78116 .35549 Mdot
.20596 .49742 Mdot
.40112 .58331 Mdot
.4573 .00439 Mdot
.4502 .04981 Mdot
.3696 .15762 Mdot
.50087 .61686 Mdot
.50276 .61431 Mdot
.50879 .60616 Mdot
.52799 .58035 Mdot
.58897 .5021 Mdot
.77656 .3566 Mdot
.19956 .4968 Mdot
.39572 .5867 Mdot
.44642 .01741 Mdot
.41825 .08991 Mdot
.27278 .23594 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51127 .60281 Mdot
.53591 .5698 Mdot
.61395 .47297 Mdot
.84867 .35288 Mdot
.2777 .4982 Mdot
.4716 .52438 Mdot
.62314 .42128 Mdot
.9415 .36826 Mdot
.34565 .48995 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50733 .60813 Mdot
.52335 .58656 Mdot
.57428 .52018 Mdot
.73261 .37351 Mdot
.12826 .47996 Mdot
.35168 .5984 Mdot
.38344 .07902 Mdot
.25558 .22648 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50629 .60954 Mdot
.52003 .59103 Mdot
.56373 .53351 Mdot
.70048 .39305 Mdot
.06451 .45123 Mdot
.3344 .57851 Mdot
.39835 .04844 Mdot
.31998 .18195 Mdot
.02558 .20556 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00283 Mdot
.49332 .00902 Mdot
.47872 .02869 Mdot
.4323 .08958 Mdot
.28735 .23308 Mdot
.91022 .15419 Mdot
.66073 .02926 Mdot
.61339 .55084 Mdot
.72211 .40556 Mdot
.0659 .46492 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56063 Mdot
.63571 .44952 Mdot
.90837 .36919 Mdot
.311 .50603 Mdot
.49223 .51324 Mdot
.66179 .38778 Mdot
.03436 .41938 Mdot
.35579 .53552 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.51179 .60211 Mdot
.53756 .56761 Mdot
.61914 .46719 Mdot
.86321 .35543 Mdot
.28812 .49876 Mdot
.48111 .51623 Mdot
.64582 .39919 Mdot
.99993 .39912 Mdot
.35414 .51619 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51135 .60271 Mdot
.53614 .56949 Mdot
.61469 .47213 Mdot
.85076 .35318 Mdot
.2793 .49824 Mdot
.47314 .52302 Mdot
.62688 .41746 Mdot
.95141 .37311 Mdot
.3477 .49372 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49554 .00602 Mdot
.48579 .01918 Mdot
.45476 .06055 Mdot
.35679 .17611 Mdot
.07183 .24046 Mdot
.68275 .1059 Mdot
.5114 .09533 Mdot
.35715 .21069 Mdot
.01625 .22573 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49292 .00957 Mdot
.47744 .03041 Mdot
.42824 .09471 Mdot
.275 .24043 Mdot
.88597 .14354 Mdot
.65372 .02218 Mdot
.61784 .54068 Mdot
.74301 .39327 Mdot
.10668 .48493 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.5123 .60142 Mdot
.53918 .56546 Mdot
.62425 .46163 Mdot
.87732 .35883 Mdot
.29672 .50006 Mdot
.48761 .51154 Mdot
.65992 .387 Mdot
.03374 .41805 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50662 .60909 Mdot
.52109 .5896 Mdot
.5671 .52922 Mdot
.7108 .38613 Mdot
.08602 .46205 Mdot
.33841 .58741 Mdot
.38795 .06488 Mdot
.28296 .20928 Mdot
.94435 .15873 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48709 .01742 Mdot
.4589 .0551 Mdot
.36974 .16282 Mdot
.10629 .2542 Mdot
.69499 .11538 Mdot
.50831 .10767 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07804 Mdot
.5 0 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48745 .01694 Mdot
.46004 .05359 Mdot
.37332 .15902 Mdot
.11603 .2573 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01506 Mdot
.46448 .04772 Mdot
.38726 .14371 Mdot
.15473 .2656 Mdot
.72497 .11988 Mdot
.53101 .09131 Mdot
.38326 .19009 Mdot
.07568 .25764 Mdot
.65881 .13366 Mdot
.50046 .61742 Mdot
.50146 .61606 Mdot
.50464 .61176 Mdot
.51479 .59807 Mdot
.5471 .55503 Mdot
.64904 .43619 Mdot
.94328 .38471 Mdot
.3208 .51789 Mdot
.48284 .53377 Mdot
.61917 .43334 Mdot
.91802 .36065 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.4927 .00985 Mdot
.47676 .03132 Mdot
.42608 .09741 Mdot
.26846 .24397 Mdot
.87372 .1388 Mdot
.64914 .0199 Mdot
.61693 .53903 Mdot
.74476 .39157 Mdot
.11119 .48646 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50426 .61227 Mdot
.51359 .59969 Mdot
.54326 .56008 Mdot
.63703 .44818 Mdot
.91186 .37058 Mdot
.31225 .50698 Mdot
.49194 .51445 Mdot
.65953 .39011 Mdot
.02833 .41623 Mdot
.50035 .61757 Mdot
.5011 .61655 Mdot
.5035 .6133 Mdot
.51116 .60297 Mdot
.53554 .57029 Mdot
.61278 .47427 Mdot
.84539 .35245 Mdot
.27512 .49816 Mdot
.46909 .52663 Mdot
.61698 .42769 Mdot
.92495 .36067 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60041 Mdot
.54157 .56231 Mdot
.63173 .45367 Mdot
.89767 .36521 Mdot
.30675 .50347 Mdot
.49212 .51078 Mdot
.66567 .38346 Mdot
.04521 .42481 Mdot
.35785 .53976 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48906 .01477 Mdot
.46517 .0468 Mdot
.38944 .14125 Mdot
.1609 .26627 Mdot
.73007 .11988 Mdot
.5361 .0867 Mdot
.39582 .17652 Mdot
.1102 .27072 Mdot
.67217 .14046 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61239 Mdot
.51332 .60005 Mdot
.54241 .5612 Mdot
.63437 .45091 Mdot
.90478 .36781 Mdot
.30965 .50511 Mdot
.49236 .51219 Mdot
.66361 .38586 Mdot
.03928 .42191 Mdot
.50123 .61638 Mdot
.5039 .61276 Mdot
.51244 .60124 Mdot
.53961 .5649 Mdot
.62559 .46018 Mdot
.881 .35986 Mdot
.29874 .50054 Mdot
.48885 .51087 Mdot
.66225 .38518 Mdot
.03901 .42099 Mdot
.35784 .53594 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49066 .01262 Mdot
.47024 .04005 Mdot
.40544 .12264 Mdot
.20701 .26483 Mdot
.7785 .11965 Mdot
.5849 .04462 Mdot
.51271 .03285 Mdot
.45955 .06995 Mdot
.34636 .19127 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49803 .00266 Mdot
.49373 .00847 Mdot
.48002 .02694 Mdot
.43644 .08431 Mdot
.30001 .22463 Mdot
.93655 .16736 Mdot
.66576 .04 Mdot
.60104 .57054 Mdot
.67789 .43788 Mdot
.96938 .40967 Mdot
.50063 .61719 Mdot
.502 .61534 Mdot
.50636 .60944 Mdot
.52026 .59071 Mdot
.56447 .53257 Mdot
.70276 .39147 Mdot
.06934 .45374 Mdot
.33517 .58066 Mdot
.39565 .05258 Mdot
.31056 .18957 Mdot
.00383 .19312 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48944 .01427 Mdot
.46635 .04523 Mdot
.39317 .137 Mdot
.17151 .26696 Mdot
.73956 .11973 Mdot
.54584 .07782 Mdot
.41992 .14897 Mdot
.17888 .28203 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00294 Mdot
.49307 .00936 Mdot
.47792 .02976 Mdot
.42976 .09279 Mdot
.27963 .23778 Mdot
.8949 .14727 Mdot
.6566 .02441 Mdot
.6171 .54342 Mdot
.73784 .3963 Mdot
.4996 .00054 Mdot
.49871 .00174 Mdot
.49591 .00553 Mdot
.48696 .01761 Mdot
.45846 .05568 Mdot
.36837 .16427 Mdot
.10258 .25291 Mdot
.69335 .11462 Mdot
.5079 .10729 Mdot
.3343 .23462 Mdot
.95468 .19317 Mdot
.64212 .07824 Mdot
.50063 .61719 Mdot
.502 .61534 Mdot
.50636 .60944 Mdot
.52026 .59071 Mdot
.56447 .53257 Mdot
.70276 .39147 Mdot
.06935 .45375 Mdot
.33517 .58066 Mdot
.39564 .05259 Mdot
.31055 .18958 Mdot
.0038 .19311 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49834 .00224 Mdot
.49472 .00713 Mdot
.48319 .02268 Mdot
.4465 .07135 Mdot
.33106 .20016 Mdot
.00719 .20682 Mdot
.67254 .07641 Mdot
.5489 .03179 Mdot
.49746 .03415 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49277 .00977 Mdot
.47697 .03104 Mdot
.42674 .09659 Mdot
.27046 .24291 Mdot
.87742 .14018 Mdot
.50048 .61739 Mdot
.50153 .61597 Mdot
.50487 .61146 Mdot
.51551 .5971 Mdot
.54939 .55205 Mdot
.65616 .42942 Mdot
.96135 .39393 Mdot
.32395 .52584 Mdot
.47313 .55063 Mdot
.58219 .47778 Mdot
.80913 .3403 Mdot
.5 0 Mdot
.5 0 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45742 .05705 Mdot
.36511 .16766 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50794 .60731 Mdot
.52528 .58397 Mdot
.58039 .51258 Mdot
.75102 .36504 Mdot
.16038 .4898 Mdot
.36787 .5987 Mdot
.39915 .06803 Mdot
.28907 .21115 Mdot
.94743 .16329 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .6089 Mdot
.52155 .58898 Mdot
.56856 .52737 Mdot
.71525 .38333 Mdot
.09501 .46627 Mdot
.34057 .59056 Mdot
.38502 .07009 Mdot
.27161 .21628 Mdot
.92166 .14655 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50432 .6122 Mdot
.51377 .59945 Mdot
.54384 .55932 Mdot
.63884 .44632 Mdot
.91668 .37256 Mdot
.31387 .50838 Mdot
.49129 .51646 Mdot
.65564 .39409 Mdot
.01799 .41073 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48657 .01813 Mdot
.45724 .05729 Mdot
.36454 .16825 Mdot
.0923 .2491 Mdot
.68925 .11218 Mdot
.50774 .10501 Mdot
.33783 .23065 Mdot
.96462 .19812 Mdot
.64405 .08208 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50564 .61042 Mdot
.51796 .59381 Mdot
.55716 .54195 Mdot
.68026 .40834 Mdot
.01955 .42642 Mdot
.32958 .5559 Mdot
.43012 .00059 Mdot
.42916 .06412 Mdot
.3254 .19542 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48867 .0153 Mdot
.46391 .04848 Mdot
.38547 .14573 Mdot
.14967 .26492 Mdot
.72103 .11981 Mdot
.52718 .09474 Mdot
.37389 .19979 Mdot
.05062 .24593 Mdot
.65269 .12512 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49415 .00791 Mdot
.48135 .02516 Mdot
.44064 .07893 Mdot
.31293 .21509 Mdot
.96491 .18282 Mdot
.6691 .05393 Mdot
.58184 .5994 Mdot
.61199 .50394 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .0018 Mdot
.49576 .00573 Mdot
.4865 .01823 Mdot
.457 .05761 Mdot
.36378 .16903 Mdot
.09028 .24831 Mdot
.68851 .11164 Mdot
.50787 .10435 Mdot
.33902 .22941 Mdot
.96782 .19978 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49645 .0048 Mdot
.48868 .01528 Mdot
.46395 .04842 Mdot
.3856 .14557 Mdot
.15006 .26497 Mdot
.72133 .11982 Mdot
.52746 .09448 Mdot
.37459 .19908 Mdot
.05246 .24684 Mdot
.65306 .12583 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48907 .01476 Mdot
.46518 .04679 Mdot
.38948 .14121 Mdot
.161 .26628 Mdot
.73015 .11988 Mdot
.53618 .08662 Mdot
.39602 .1763 Mdot
.11076 .27089 Mdot
.67244 .14052 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49564 .00588 Mdot
.48612 .01873 Mdot
.45582 .05917 Mdot
.36008 .1728 Mdot
.08048 .24427 Mdot
.68524 .10878 Mdot
.50923 .10022 Mdot
.34707 .22117 Mdot
.98922 .21118 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50504 .61123 Mdot
.51604 .59639 Mdot
.55107 .54985 Mdot
.66139 .42459 Mdot
.9744 .40096 Mdot
.32564 .53215 Mdot
.46461 .56469 Mdot
.55091 .51829 Mdot
.7123 .37487 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49677 .00437 Mdot
.4897 .01392 Mdot
.46718 .04413 Mdot
.39578 .13398 Mdot
.179 .26709 Mdot
.74684 .11957 Mdot
.55337 .07101 Mdot
.43848 .12664 Mdot
.23357 .2734 Mdot
.79121 .13077 Mdot
.50117 .61645 Mdot
.50372 .613 Mdot
.51186 .60202 Mdot
.53778 .56732 Mdot
.61985 .46642 Mdot
.86516 .35584 Mdot
.28939 .49889 Mdot
.48217 .51539 Mdot
.64825 .39698 Mdot
.00593 .40247 Mdot
.35471 .51922 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01558 Mdot
.46325 .04935 Mdot
.38341 .14802 Mdot
.1439 .26398 Mdot
.71677 .11964 Mdot
.5232 .09821 Mdot
.36429 .20932 Mdot
.0256 .23295 Mdot
.64868 .11431 Mdot
.50119 .61642 Mdot
.50381 .61289 Mdot
.51213 .60166 Mdot
.53863 .5662 Mdot
.6225 .46352 Mdot
.87251 .35757 Mdot
.29395 .49952 Mdot
.4857 .51276 Mdot
.65603 .3902 Mdot
.02468 .41298 Mdot
.35646 .52874 Mdot
.50064 .61717 Mdot
.50203 .61529 Mdot
.50647 .6093 Mdot
.5206 .59026 Mdot
.56554 .5312 Mdot
.70604 .38925 Mdot
.07621 .45724 Mdot
.33639 .58357 Mdot
.39215 .05804 Mdot
.29823 .19886 Mdot
.97646 .17712 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50059 .61724 Mdot
.50186 .61551 Mdot
.50594 .61001 Mdot
.51893 .5925 Mdot
.56024 .53798 Mdot
.68977 .40087 Mdot
.04114 .43859 Mdot
.33149 .56722 Mdot
.41371 .02532 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48805 .01613 Mdot
.46195 .05107 Mdot
.37931 .15254 Mdot
.13249 .26166 Mdot
.70911 .11896 Mdot
.51662 .10358 Mdot
.34902 .22348 Mdot
.98743 .21184 Mdot
.64467 .09544 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01038 Mdot
.47552 .03298 Mdot
.42215 .10231 Mdot
.25662 .24972 Mdot
.85256 .13177 Mdot
.63936 .01846 Mdot
.60948 .54282 Mdot
.73118 .39631 Mdot
.08994 .47532 Mdot
.49984 .00022 Mdot
.49947 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48301 .02292 Mdot
.44592 .0721 Mdot
.32925 .20173 Mdot
.00285 .20437 Mdot
.67217 .07412 Mdot
.55225 .02654 Mdot
.5093 .01793 Mdot
.48029 .03616 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.4872 .01728 Mdot
.45924 .05465 Mdot
.37082 .16168 Mdot
.10921 .25517 Mdot
.69634 .11593 Mdot
.50877 .10781 Mdot
.33433 .23512 Mdot
.9539 .19298 Mdot
.64166 .07832 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48928 .01447 Mdot
.46587 .04587 Mdot
.39165 .13874 Mdot
.16716 .26675 Mdot
.73556 .11981 Mdot
.54171 .08159 Mdot
.4097 .16088 Mdot
.14938 .27991 Mdot
.50057 .61726 Mdot
.50181 .61558 Mdot
.50578 .61022 Mdot
.51842 .59318 Mdot
.55863 .54005 Mdot
.68482 .4047 Mdot
.03 .43235 Mdot
.33044 .56144 Mdot
.42201 .01285 Mdot
.40121 .09867 Mdot
.24157 .246 Mdot
.50002 .61801 Mdot
.50006 .61796 Mdot
.50018 .61778 Mdot
.50059 .61724 Mdot
.50187 .6155 Mdot
.50597 .60996 Mdot
.51903 .59236 Mdot
.56057 .53756 Mdot
.69077 .40011 Mdot
.04337 .43983 Mdot
.33172 .56835 Mdot
.49981 .00026 Mdot
.4994 .00081 Mdot
.49808 .00259 Mdot
.49389 .00825 Mdot
.48054 .02625 Mdot
.43807 .08223 Mdot
.30502 .22104 Mdot
.94737 .17314 Mdot
.66723 .0451 Mdot
.59426 .58076 Mdot
.65457 .45896 Mdot
.91196 .38144 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61024 Mdot
.51838 .59324 Mdot
.5585 .54022 Mdot
.6844 .40503 Mdot
.02905 .43181 Mdot
.33036 .56094 Mdot
.42274 .01176 Mdot
.40371 .09567 Mdot
.24891 .24321 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61026 Mdot
.51834 .59329 Mdot
.55838 .54038 Mdot
.68403 .40533 Mdot
.02819 .43133 Mdot
.33029 .56049 Mdot
.42339 .01077 Mdot
.40597 .09295 Mdot
.25558 .2404 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60723 Mdot
.52549 .5837 Mdot
.58105 .51176 Mdot
.753 .36424 Mdot
.16364 .4906 Mdot
.36984 .59825 Mdot
.40184 .06556 Mdot
.29577 .20704 Mdot
.96077 .17104 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49742 .00349 Mdot
.49177 .01112 Mdot
.47379 .03531 Mdot
.41666 .10909 Mdot
.24015 .25635 Mdot
.82537 .12504 Mdot
.62305 .022 Mdot
.58745 .56298 Mdot
.67652 .43089 Mdot
.97933 .41178 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49415 .0079 Mdot
.48137 .02513 Mdot
.44071 .07883 Mdot
.31316 .21491 Mdot
.96544 .18312 Mdot
.66915 .0542 Mdot
.58145 .59998 Mdot
.61065 .50547 Mdot
.79278 .36323 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.46491 .04715 Mdot
.38862 .14218 Mdot
.15857 .26604 Mdot
.72811 .11989 Mdot
.53412 .0885 Mdot
.39094 .18187 Mdot
.09666 .26607 Mdot
.50058 .61725 Mdot
.50184 .61555 Mdot
.50587 .61011 Mdot
.51869 .59282 Mdot
.55949 .53894 Mdot
.68747 .40264 Mdot
.03598 .43571 Mdot
.33098 .56457 Mdot
.41749 .01964 Mdot
.38571 .11672 Mdot
.19687 .25611 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00456 Mdot
.48925 .01452 Mdot
.46576 .04601 Mdot
.39131 .13912 Mdot
.1662 .26669 Mdot
.73469 .11982 Mdot
.54082 .0824 Mdot
.4075 .1634 Mdot
.14311 .2789 Mdot
.69184 .1411 Mdot
.50118 .61644 Mdot
.50375 .61296 Mdot
.51196 .60188 Mdot
.53809 .5669 Mdot
.62082 .46535 Mdot
.86788 .35645 Mdot
.29112 .4991 Mdot
.48356 .51431 Mdot
.65138 .3942 Mdot
.01356 .40675 Mdot
.35542 .5231 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50496 .61133 Mdot
.5158 .59671 Mdot
.55031 .55083 Mdot
.65905 .42673 Mdot
.96858 .39779 Mdot
.32494 .52928 Mdot
.46854 .55826 Mdot
.56526 .49943 Mdot
.75716 .35204 Mdot
.50027 .61767 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50866 .60634 Mdot
.52758 .5809 Mdot
.58768 .50366 Mdot
.77273 .35762 Mdot
.19408 .49615 Mdot
.39129 .58928 Mdot
.43782 .02744 Mdot
.39343 .11902 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00388 Mdot
.49084 .01237 Mdot
.47082 .03927 Mdot
.40728 .12045 Mdot
.2124 .26389 Mdot
.78541 .11998 Mdot
.59127 .03993 Mdot
.52667 .01532 Mdot
.50187 .01359 Mdot
.47988 .03219 Mdot
.50099 .6167 Mdot
.50315 .61377 Mdot
.51005 .60447 Mdot
.532 .575 Mdot
.60163 .48705 Mdot
.81356 .35112 Mdot
.24544 .4986 Mdot
.43868 .55406 Mdot
.54219 .5154 Mdot
.70826 .3729 Mdot
.10489 .46325 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50629 .60954 Mdot
.52002 .59103 Mdot
.56372 .53353 Mdot
.70045 .39308 Mdot
.06443 .45119 Mdot
.33439 .57848 Mdot
.39839 .04837 Mdot
.32012 .18183 Mdot
.02592 .20575 Mdot
.50096 .61674 Mdot
.50305 .61392 Mdot
.50971 .60493 Mdot
.53092 .57644 Mdot
.59821 .49107 Mdot
.80364 .35183 Mdot
.23438 .49866 Mdot
.42753 .56355 Mdot
.51569 .54902 Mdot
.62735 .44317 Mdot
.91029 .36434 Mdot
.50037 .61754 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60208 Mdot
.53763 .56752 Mdot
.61936 .46695 Mdot
.86381 .35555 Mdot
.28851 .4988 Mdot
.48144 .51597 Mdot
.64659 .39849 Mdot
.00182 .40017 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50854 .6065 Mdot
.52721 .5814 Mdot
.58649 .5051 Mdot
.76921 .35863 Mdot
.18893 .49545 Mdot
.38728 .59143 Mdot
.43033 .03594 Mdot
.37217 .14211 Mdot
.14224 .2571 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51666 .59555 Mdot
.55304 .54728 Mdot
.66753 .41911 Mdot
.9894 .40928 Mdot
.32716 .53983 Mdot
.45371 .58214 Mdot
.50016 .61782 Mdot
.5005 .61736 Mdot
.50159 .61589 Mdot
.50505 .61121 Mdot
.51609 .59632 Mdot
.55122 .54965 Mdot
.66187 .42415 Mdot
.97558 .4016 Mdot
.32577 .53274 Mdot
.46379 .56602 Mdot
.54795 .52224 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .6049 Mdot
.53098 .57636 Mdot
.59842 .49082 Mdot
.80425 .35177 Mdot
.23508 .49866 Mdot
.42823 .56297 Mdot
.51732 .54694 Mdot
.63236 .4379 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00667 Mdot
.48428 .02122 Mdot
.44995 .06686 Mdot
.34177 .19055 Mdot
.03345 .22133 Mdot
.67533 .08973 Mdot
.53014 .06196 Mdot
.42988 .12488 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60698 Mdot
.52608 .58291 Mdot
.58291 .50947 Mdot
.75856 .36214 Mdot
.1726 .49258 Mdot
.37559 .59653 Mdot
.41038 .05725 Mdot
.31775 .19163 Mdot
.00769 .19875 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01627 Mdot
.46161 .05152 Mdot
.37826 .15369 Mdot
.12959 .26098 Mdot
.70731 .11871 Mdot
.51523 .10461 Mdot
.34596 .22614 Mdot
.98006 .2077 Mdot
.64399 .0917 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.49571 .0058 Mdot
.48632 .01846 Mdot
.45645 .05833 Mdot
.36208 .17078 Mdot
.08575 .24648 Mdot
.68693 .11037 Mdot
.50835 .10264 Mdot
.34228 .22607 Mdot
.9765 .20436 Mdot
.5006 .61722 Mdot
.50193 .61543 Mdot
.50614 .60974 Mdot
.51955 .59167 Mdot
.56221 .53546 Mdot
.69582 .39638 Mdot
.05447 .44589 Mdot
.333 .57383 Mdot
.40453 .03909 Mdot
.34128 .16302 Mdot
.07751 .23207 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01489 Mdot
.46489 .04717 Mdot
.38856 .14225 Mdot
.1584 .26602 Mdot
.72797 .11989 Mdot
.53398 .08862 Mdot
.39059 .18225 Mdot
.09569 .26572 Mdot
.66575 .13836 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.4934 .00892 Mdot
.47897 .02836 Mdot
.43309 .08858 Mdot
.28976 .23154 Mdot
.91512 .15653 Mdot
.66185 .03104 Mdot
.61161 .55388 Mdot
.71541 .40981 Mdot
.05233 .45745 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01285 Mdot
.46969 .04079 Mdot
.40369 .12472 Mdot
.2019 .26557 Mdot
.77219 .11946 Mdot
.5789 .04928 Mdot
.49917 .05005 Mdot
.41819 .12259 Mdot
.21984 .26749 Mdot
.49995 6e-05 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49531 .00633 Mdot
.48507 .02015 Mdot
.45247 .06357 Mdot
.34961 .18314 Mdot
.05328 .23162 Mdot
.67851 .09871 Mdot
.5188 .08133 Mdot
.38721 .17736 Mdot
.50058 .61725 Mdot
.50185 .61554 Mdot
.50589 .61008 Mdot
.51876 .59273 Mdot
.5597 .53868 Mdot
.6881 .40215 Mdot
.0374 .43651 Mdot
.33112 .5653 Mdot
.41644 .02122 Mdot
.38211 .12079 Mdot
.18667 .2568 Mdot
.5001 .6179 Mdot
.50031 .61762 Mdot
.50098 .6167 Mdot
.50314 .61379 Mdot
.51 .60453 Mdot
.53185 .5752 Mdot
.60115 .48762 Mdot
.81216 .35119 Mdot
.24393 .49862 Mdot
.43714 .5554 Mdot
.53849 .52006 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49616 .00518 Mdot
.48778 .0165 Mdot
.46108 .05222 Mdot
.37659 .1555 Mdot
.12498 .25982 Mdot
.70458 .11824 Mdot
.51326 .10596 Mdot
.34182 .22962 Mdot
.97028 .20223 Mdot
.64306 .08676 Mdot
.5 .61803 Mdot
.50001 .61802 Mdot
.50002 .61801 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.50219 .61507 Mdot
.50699 .60859 Mdot
.52227 .58801 Mdot
.57084 .52448 Mdot
.72221 .37918 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00531 Mdot
.48747 .01691 Mdot
.46011 .05351 Mdot
.37353 .1588 Mdot
.11659 .25747 Mdot
.69999 .11715 Mdot
.51044 .10748 Mdot
.33654 .23375 Mdot
.95833 .19555 Mdot
.64192 .08074 Mdot
.50115 .61647 Mdot
.50368 .61306 Mdot
.51172 .60221 Mdot
.53733 .56792 Mdot
.61842 .46799 Mdot
.86119 .35501 Mdot
.28676 .49864 Mdot
.47995 .51718 Mdot
.64314 .40166 Mdot
.99325 .3954 Mdot
.35348 .51284 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51039 .604 Mdot
.5331 .57353 Mdot
.60511 .48302 Mdot
.82358 .35096 Mdot
.25572 .49841 Mdot
.44927 .54464 Mdot
.56802 .48348 Mdot
.78573 .33964 Mdot
.23618 .48663 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51092 .60328 Mdot
.53479 .57129 Mdot
.61042 .47694 Mdot
.83872 .35173 Mdot
.26961 .49816 Mdot
.46357 .53163 Mdot
.60337 .4424 Mdot
.88754 .34661 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49464 .00724 Mdot
.48293 .02303 Mdot
.44566 .07243 Mdot
.32847 .20241 Mdot
.00097 .2033 Mdot
.67202 .07312 Mdot
.55371 .02426 Mdot
.51446 .01088 Mdot
.49685 .0138 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48856 .01545 Mdot
.46357 .04893 Mdot
.38441 .14691 Mdot
.1467 .26445 Mdot
.71881 .11973 Mdot
.52507 .09658 Mdot
.3688 .2049 Mdot
.03726 .23913 Mdot
.65034 .11958 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49323 .00914 Mdot
.47844 .02907 Mdot
.4314 .09072 Mdot
.28461 .23479 Mdot
.90472 .15164 Mdot
.65936 .02738 Mdot
.61506 .5478 Mdot
.72869 .40158 Mdot
.07893 .47179 Mdot
.50082 .61692 Mdot
.50262 .6145 Mdot
.50834 .60677 Mdot
.52657 .58225 Mdot
.58446 .50757 Mdot
.76319 .36054 Mdot
.17983 .49397 Mdot
.38057 .59459 Mdot
.41851 .04884 Mdot
.33948 .17368 Mdot
.05845 .22666 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50758 .60779 Mdot
.52415 .58549 Mdot
.5768 .51702 Mdot
.74024 .36975 Mdot
.14197 .48459 Mdot
.35788 .59952 Mdot
.38783 .07708 Mdot
.26311 .22412 Mdot
.90047 .13775 Mdot
.50004 .61798 Mdot
.50013 .61785 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50436 .61214 Mdot
.5139 .59927 Mdot
.54426 .55876 Mdot
.64016 .44498 Mdot
.92017 .37404 Mdot
.31496 .50946 Mdot
.49063 .51814 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50363 .61313 Mdot
.51157 .60241 Mdot
.53686 .56854 Mdot
.61694 .46963 Mdot
.85706 .35423 Mdot
.28391 .49844 Mdot
.47742 .51929 Mdot
.63719 .40729 Mdot
.97819 .38713 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00482 Mdot
.48864 .01534 Mdot
.46383 .04858 Mdot
.38523 .14599 Mdot
.149 .26482 Mdot
.72052 .11979 Mdot
.52669 .09516 Mdot
.37272 .20098 Mdot
.04753 .24439 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51285 .60069 Mdot
.54091 .56318 Mdot
.62968 .45582 Mdot
.89214 .36331 Mdot
.30429 .50236 Mdot
.49146 .51027 Mdot
.66582 .38289 Mdot
.0463 .42521 Mdot
.3583 .53989 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .01331 Mdot
.46862 .04221 Mdot
.40032 .1287 Mdot
.19207 .26658 Mdot
.76074 .11937 Mdot
.56759 .05858 Mdot
.47281 .08366 Mdot
.49983 .00023 Mdot
.49946 .00074 Mdot
.49826 .00234 Mdot
.49447 .00747 Mdot
.48238 .02377 Mdot
.44393 .07468 Mdot
.3231 .20693 Mdot
.98827 .19607 Mdot
.67102 .06632 Mdot
.56371 .00882 Mdot
.54945 .58175 Mdot
.60816 .48902 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50375 .61296 Mdot
.51196 .60189 Mdot
.53809 .56692 Mdot
.6208 .46538 Mdot
.8678 .35644 Mdot
.29107 .49909 Mdot
.48352 .51434 Mdot
.6513 .39428 Mdot
.01335 .40663 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51042 .60396 Mdot
.53318 .57342 Mdot
.60537 .48272 Mdot
.8243 .35097 Mdot
.25642 .49839 Mdot
.45001 .54398 Mdot
.56983 .4813 Mdot
.79107 .33864 Mdot
.24313 .48605 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00332 Mdot
.49218 .01057 Mdot
.47508 .03358 Mdot
.42075 .10404 Mdot
.25241 .25157 Mdot
.84536 .12973 Mdot
.63546 .01877 Mdot
.60509 .54631 Mdot
.72113 .40119 Mdot
.072 .46568 Mdot
.49971 .0004 Mdot
.49907 .00126 Mdot
.49703 .00401 Mdot
.49053 .01278 Mdot
.46985 .04057 Mdot
.4042 .12411 Mdot
.20338 .26537 Mdot
.774 .1195 Mdot
.58064 .04791 Mdot
.50313 .04501 Mdot
.4303 .10757 Mdot
.25624 .25501 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49742 .00349 Mdot
.49177 .01112 Mdot
.47378 .03531 Mdot
.41665 .10909 Mdot
.24014 .25635 Mdot
.82535 .12504 Mdot
.62303 .02201 Mdot
.58743 .563 Mdot
.67647 .43093 Mdot
.97921 .41171 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00378 Mdot
.49108 .01205 Mdot
.47158 .03826 Mdot
.40967 .11758 Mdot
.21943 .26241 Mdot
.79485 .12068 Mdot
.59958 .03427 Mdot
.54413 .61192 Mdot
.55402 .5628 Mdot
.6434 .44713 Mdot
.50046 .61742 Mdot
.50146 .61606 Mdot
.50465 .61176 Mdot
.5148 .59805 Mdot
.54713 .555 Mdot
.64912 .43611 Mdot
.94348 .38481 Mdot
.32084 .51797 Mdot
.48275 .53394 Mdot
.61881 .43374 Mdot
.91701 .36024 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46592 .0458 Mdot
.39182 .13855 Mdot
.16765 .26677 Mdot
.736 .1198 Mdot
.54216 .08117 Mdot
.41081 .1596 Mdot
.15258 .28035 Mdot
.69896 .14033 Mdot
.50051 .61734 Mdot
.50163 .61583 Mdot
.5052 .61101 Mdot
.51658 .59567 Mdot
.55277 .54764 Mdot
.66667 .41986 Mdot
.98733 .40812 Mdot
.32697 .53874 Mdot
.45526 .57967 Mdot
.51733 .56364 Mdot
.60535 .47295 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .0133 Mdot
.46863 .0422 Mdot
.40035 .12866 Mdot
.19216 .26657 Mdot
.76084 .11937 Mdot
.56769 .05849 Mdot
.47305 .08335 Mdot
.33819 .20882 Mdot
.00032 .20911 Mdot
.50063 .61718 Mdot
.502 .61533 Mdot
.50638 .60942 Mdot
.52032 .59063 Mdot
.56466 .53232 Mdot
.70335 .39106 Mdot
.0706 .45439 Mdot
.33538 .5812 Mdot
.39497 .05362 Mdot
.30821 .19141 Mdot
.99851 .19003 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49236 .01032 Mdot
.47566 .03279 Mdot
.42261 .10175 Mdot
.25798 .24911 Mdot
.85492 .13247 Mdot
.64057 .01845 Mdot
.61071 .54194 Mdot
.73384 .39515 Mdot
.09447 .47768 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49633 .00495 Mdot
.48832 .01577 Mdot
.4628 .04994 Mdot
.382 .14958 Mdot
.13998 .26325 Mdot
.71403 .11946 Mdot
.52074 .10029 Mdot
.35847 .21487 Mdot
.01081 .22488 Mdot
.64694 .1072 Mdot
.50088 .61684 Mdot
.50281 .61423 Mdot
.50896 .60593 Mdot
.52855 .57961 Mdot
.59072 .49999 Mdot
.78173 .35536 Mdot
.20674 .49749 Mdot
.40178 .58287 Mdot
.45868 .00272 Mdot
.45428 .04453 Mdot
.38223 .14401 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50436 .61214 Mdot
.5139 .59927 Mdot
.54427 .55875 Mdot
.6402 .44495 Mdot
.92025 .37408 Mdot
.31499 .50949 Mdot
.49062 .51818 Mdot
.65218 .39764 Mdot
.00878 .40578 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54007 .56429 Mdot
.62703 .45864 Mdot
.88494 .36102 Mdot
.30079 .50112 Mdot
.48997 .51041 Mdot
.66411 .38383 Mdot
.04306 .42326 Mdot
.3582 .538 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49343 .00887 Mdot
.47908 .02821 Mdot
.43345 .08812 Mdot
.29086 .23083 Mdot
.91737 .15762 Mdot
.66233 .0319 Mdot
.61071 .55538 Mdot
.71208 .412 Mdot
.04545 .45357 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48793 .0163 Mdot
.46155 .0516 Mdot
.37806 .1539 Mdot
.12905 .26085 Mdot
.70699 .11866 Mdot
.51499 .10479 Mdot
.34543 .22659 Mdot
.9788 .207 Mdot
.64387 .09106 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01286 Mdot
.46968 .0408 Mdot
.40367 .12475 Mdot
.20182 .26558 Mdot
.77209 .11946 Mdot
.5788 .04935 Mdot
.49895 .05033 Mdot
.41751 .12342 Mdot
.21781 .26796 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.4955 .00608 Mdot
.48565 .01937 Mdot
.45432 .06114 Mdot
.35539 .1775 Mdot
.0682 .2388 Mdot
.68181 .1046 Mdot
.51257 .09296 Mdot
.36216 .20536 Mdot
.02989 .2329 Mdot
.50103 .61664 Mdot
.50328 .6136 Mdot
.51045 .60392 Mdot
.53329 .57328 Mdot
.6057 .48233 Mdot
.82527 .35099 Mdot
.25737 .49837 Mdot
.45098 .5431 Mdot
.57223 .47841 Mdot
.79814 .33757 Mdot
.25195 .4851 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48853 .01548 Mdot
.46348 .04904 Mdot
.38412 .14722 Mdot
.14591 .26432 Mdot
.71823 .11971 Mdot
.52453 .09706 Mdot
.36749 .20619 Mdot
.03388 .23736 Mdot
.64983 .11808 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.5049 .61141 Mdot
.51563 .59694 Mdot
.54975 .55157 Mdot
.65729 .42836 Mdot
.96419 .39544 Mdot
.32435 .52718 Mdot
.47137 .55358 Mdot
.57566 .48605 Mdot
.78921 .34296 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00527 Mdot
.48757 .01678 Mdot
.46042 .05309 Mdot
.37452 .15774 Mdot
.11929 .25826 Mdot
.70142 .11754 Mdot
.51124 .10712 Mdot
.33792 .23272 Mdot
.96136 .19725 Mdot
.6422 .08228 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00286 Mdot
.49325 .00912 Mdot
.47848 .02901 Mdot
.43154 .09054 Mdot
.28503 .23453 Mdot
.90556 .15203 Mdot
.65958 .02766 Mdot
.61482 .54824 Mdot
.72775 .40214 Mdot
.07708 .47083 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49157 .01139 Mdot
.47314 .03617 Mdot
.41461 .11159 Mdot
.23406 .25839 Mdot
.81597 .12334 Mdot
.6164 .0248 Mdot
.57627 .57481 Mdot
.64621 .45754 Mdot
.90591 .3753 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00313 Mdot
.49263 .00996 Mdot
.47652 .03165 Mdot
.42531 .09838 Mdot
.26613 .24517 Mdot
.86945 .13726 Mdot
.64736 .01935 Mdot
.61605 .53908 Mdot
.50103 .61664 Mdot
.50329 .61358 Mdot
.51049 .60386 Mdot
.53342 .57311 Mdot
.6061 .48187 Mdot
.82642 .35101 Mdot
.25847 .49835 Mdot
.45212 .54207 Mdot
.57504 .47505 Mdot
.8064 .33667 Mdot
.26166 .48382 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48802 .01617 Mdot
.46185 .0512 Mdot
.379 .15288 Mdot
.13165 .26147 Mdot
.70858 .11889 Mdot
.51621 .1039 Mdot
.3481 .22429 Mdot
.98519 .21058 Mdot
.64446 .0943 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45872 .05534 Mdot
.36917 .16342 Mdot
.10476 .25367 Mdot
.69431 .11507 Mdot
.50812 .10755 Mdot
.33411 .23496 Mdot
.95393 .19285 Mdot
.6419 .07805 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50808 .60712 Mdot
.52574 .58336 Mdot
.58186 .51077 Mdot
.75541 .36331 Mdot
.16756 .4915 Mdot
.37229 .59759 Mdot
.40537 .06221 Mdot
.30472 .20112 Mdot
.97931 .18199 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50774 .60758 Mdot
.52465 .58482 Mdot
.57839 .51505 Mdot
.74502 .36758 Mdot
.15026 .48709 Mdot
.36213 .5995 Mdot
.39212 .07399 Mdot
.2724 .22008 Mdot
.91631 .14602 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46217 .05078 Mdot
.38001 .15177 Mdot
.13445 .2621 Mdot
.71035 .11911 Mdot
.51762 .10281 Mdot
.35128 .22148 Mdot
.99292 .21491 Mdot
.50102 .61666 Mdot
.50325 .61365 Mdot
.51034 .60407 Mdot
.53294 .57375 Mdot
.60458 .48363 Mdot
.82205 .35095 Mdot
.2542 .49844 Mdot
.44771 .54605 Mdot
.56418 .48816 Mdot
.77432 .34233 Mdot
.22042 .48733 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49631 .00498 Mdot
.48825 .01587 Mdot
.46258 .05024 Mdot
.38128 .15037 Mdot
.13798 .26285 Mdot
.71267 .11935 Mdot
.51957 .10125 Mdot
.35573 .21742 Mdot
.00394 .22107 Mdot
.64624 .10379 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50613 .60975 Mdot
.51952 .5917 Mdot
.56213 .53555 Mdot
.6956 .39654 Mdot
.05398 .44563 Mdot
.33294 .57359 Mdot
.40485 .03861 Mdot
.34238 .16199 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49827 .00233 Mdot
.4945 .00743 Mdot
.48247 .02365 Mdot
.4442 .07433 Mdot
.32393 .20624 Mdot
.99022 .19718 Mdot
.67117 .06737 Mdot
.56217 .01118 Mdot
.54408 .58887 Mdot
.59126 .50883 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48793 .0163 Mdot
.46155 .05161 Mdot
.37804 .15392 Mdot
.12899 .26084 Mdot
.70695 .11866 Mdot
.51496 .10481 Mdot
.34538 .22664 Mdot
.97866 .20692 Mdot
.64386 .09099 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49916 .00113 Mdot
.49734 .0036 Mdot
.49152 .01145 Mdot
.47299 .03637 Mdot
.41415 .11216 Mdot
.23267 .25883 Mdot
.81388 .12301 Mdot
.61485 .02554 Mdot
.57352 .57781 Mdot
.6386 .46496 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60601 Mdot
.52836 .57986 Mdot
.59013 .5007 Mdot
.77999 .35576 Mdot
.20435 .49728 Mdot
.39974 .5842 Mdot
.45448 .0078 Mdot
.44186 .0605 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48761 .01673 Mdot
.46054 .05294 Mdot
.37489 .15734 Mdot
.12031 .25855 Mdot
.70197 .11767 Mdot
.51157 .10695 Mdot
.33851 .23226 Mdot
.9627 .198 Mdot
.64233 .08296 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54283 .56064 Mdot
.63569 .44955 Mdot
.90831 .36917 Mdot
.31098 .50602 Mdot
.49223 .51322 Mdot
.66183 .38774 Mdot
.03445 .41943 Mdot
.3558 .53555 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.4934 .00891 Mdot
.47899 .02833 Mdot
.43315 .0885 Mdot
.28996 .23142 Mdot
.91551 .15672 Mdot
.66193 .03119 Mdot
.61146 .55414 Mdot
.71484 .41018 Mdot
.05114 .45679 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49384 .00832 Mdot
.48039 .02645 Mdot
.43759 .08284 Mdot
.30354 .22212 Mdot
.94415 .1714 Mdot
.66682 .04355 Mdot
.59636 .57761 Mdot
.66177 .45216 Mdot
.93016 .38947 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49705 .00398 Mdot
.49061 .01268 Mdot
.47009 .04024 Mdot
.40498 .12319 Mdot
.20565 .26505 Mdot
.77679 .11959 Mdot
.5833 .04584 Mdot
.50913 .03739 Mdot
.44863 .08419 Mdot
.31242 .22053 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51146 .60255 Mdot
.53651 .569 Mdot
.61585 .47083 Mdot
.85403 .3537 Mdot
.28173 .49832 Mdot
.47542 .52102 Mdot
.6324 .41195 Mdot
.96586 .38054 Mdot
.35013 .49983 Mdot
.50019 .61777 Mdot
.50061 .61721 Mdot
.50195 .61539 Mdot
.50623 .60962 Mdot
.51983 .59129 Mdot
.56311 .5343 Mdot
.6986 .39438 Mdot
.06048 .44911 Mdot
.33381 .57666 Mdot
.40074 .0448 Mdot
.32826 .17486 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49775 .00305 Mdot
.49282 .0097 Mdot
.47712 .03084 Mdot
.42722 .09599 Mdot
.27191 .24213 Mdot
.88013 .14122 Mdot
.65163 .02097 Mdot
.6177 .53957 Mdot
.74465 .39211 Mdot
.1102 .4863 Mdot
.50107 .61659 Mdot
.5034 .61345 Mdot
.51082 .60342 Mdot
.53446 .57173 Mdot
.60939 .47812 Mdot
.83577 .35149 Mdot
.26706 .49819 Mdot
.46098 .534 Mdot
.59694 .44958 Mdot
.8695 .34171 Mdot
.3166 .47653 Mdot
.50063 .61718 Mdot
.50202 .6153 Mdot
.50644 .60933 Mdot
.52053 .59035 Mdot
.56532 .53149 Mdot
.70535 .38971 Mdot
.07478 .45652 Mdot
.33612 .58298 Mdot
.39284 .05695 Mdot
.30069 .19708 Mdot
.98182 .18026 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00457 Mdot
.48923 .01455 Mdot
.46569 .04611 Mdot
.39107 .13939 Mdot
.16553 .26664 Mdot
.73409 .11983 Mdot
.5402 .08296 Mdot
.40597 .16514 Mdot
.13876 .27809 Mdot
.68879 .14133 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48655 .01815 Mdot
.45718 .05737 Mdot
.36434 .16845 Mdot
.09178 .2489 Mdot
.68905 .11204 Mdot
.50776 .10485 Mdot
.33812 .23035 Mdot
.9654 .19853 Mdot
.50092 .61679 Mdot
.50293 .61407 Mdot
.50934 .60541 Mdot
.52977 .57798 Mdot
.59457 .49537 Mdot
.79304 .35319 Mdot
.22156 .49839 Mdot
.41515 .57337 Mdot
.48742 .58502 Mdot
.54083 .54759 Mdot
.65481 .42566 Mdot
.50059 .61724 Mdot
.50187 .61551 Mdot
.50595 .60999 Mdot
.51896 .59245 Mdot
.56036 .53783 Mdot
.69012 .40061 Mdot
.04193 .43903 Mdot
.33157 .56762 Mdot
.41314 .02617 Mdot
.3708 .13322 Mdot
.15524 .25538 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .00229 Mdot
.4946 .0073 Mdot
.48279 .02322 Mdot
.44522 .07301 Mdot
.32709 .20358 Mdot
.99769 .20144 Mdot
.67175 .07137 Mdot
.55628 .02028 Mdot
.52347 .61663 Mdot
.52574 .59287 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50476 .6116 Mdot
.51518 .59755 Mdot
.54832 .55344 Mdot
.65283 .43255 Mdot
.95295 .38957 Mdot
.32262 .52202 Mdot
.47798 .54236 Mdot
.60042 .45533 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49879 .00164 Mdot
.49613 .00523 Mdot
.48767 .01665 Mdot
.46073 .05268 Mdot
.37549 .15669 Mdot
.12197 .25901 Mdot
.70288 .11789 Mdot
.51214 .10664 Mdot
.50089 .61683 Mdot
.50285 .61419 Mdot
.50907 .60579 Mdot
.52888 .57916 Mdot
.59177 .49872 Mdot
.78482 .3547 Mdot
.21091 .49781 Mdot
.40543 .58042 Mdot
.4663 .61143 Mdot
.47699 .01465 Mdot
.45328 .05735 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00301 Mdot
.4929 .0096 Mdot
.47737 .03051 Mdot
.428 .095 Mdot
.27429 .24083 Mdot
.88462 .14299 Mdot
.65325 .02188 Mdot
.61785 .54037 Mdot
.74351 .39295 Mdot
.10771 .48535 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60045 Mdot
.54148 .56243 Mdot
.63144 .45396 Mdot
.89692 .36494 Mdot
.30643 .50331 Mdot
.49205 .51068 Mdot
.66576 .38332 Mdot
.04554 .42496 Mdot
.35794 .53986 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00353 Mdot
.49167 .01125 Mdot
.47346 .03575 Mdot
.41562 .11036 Mdot
.23705 .25742 Mdot
.82054 .12413 Mdot
.6197 .02333 Mdot
.58194 .56871 Mdot
.66175 .44328 Mdot
.94451 .39287 Mdot
.50076 .61701 Mdot
.50241 .61477 Mdot
.50769 .60765 Mdot
.52449 .58504 Mdot
.57788 .51569 Mdot
.74348 .36827 Mdot
.14761 .48632 Mdot
.36073 .59957 Mdot
.39061 .07515 Mdot
.26902 .22164 Mdot
.9104 .1429 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50901 .60586 Mdot
.5287 .5794 Mdot
.59121 .4994 Mdot
.78317 .35505 Mdot
.20869 .49765 Mdot
.40348 .58174 Mdot
.4622 .61646 Mdot
.46474 .03085 Mdot
.41483 .10608 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48973 .01387 Mdot
.46729 .04397 Mdot
.39614 .13357 Mdot
.18003 .26708 Mdot
.74789 .11955 Mdot
.55445 .07005 Mdot
.44112 .1234 Mdot
.24146 .27073 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00398 Mdot
.4906 .01269 Mdot
.47007 .04027 Mdot
.40491 .12327 Mdot
.20546 .26507 Mdot
.77656 .11958 Mdot
.58308 .04601 Mdot
.50863 .03802 Mdot
.44711 .08615 Mdot
.30771 .22411 Mdot
.50076 .61701 Mdot
.50241 .61477 Mdot
.50769 .60765 Mdot
.5245 .58503 Mdot
.5779 .51566 Mdot
.74355 .36824 Mdot
.14773 .48635 Mdot
.36079 .59957 Mdot
.39067 .0751 Mdot
.26916 .22158 Mdot
.91065 .14302 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50686 .60877 Mdot
.52184 .58859 Mdot
.56948 .52621 Mdot
.71806 .38162 Mdot
.10058 .46878 Mdot
.34207 .59232 Mdot
.38368 .07277 Mdot
.26594 .21957 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .01421 Mdot
.46649 .04504 Mdot
.39361 .13648 Mdot
.17278 .267 Mdot
.74076 .1197 Mdot
.54708 .07669 Mdot
.42299 .14533 Mdot
.18784 .28176 Mdot
.73194 .13517 Mdot
.50132 .61624 Mdot
.50422 .61233 Mdot
.51345 .59988 Mdot
.54282 .56066 Mdot
.63565 .44959 Mdot
.9082 .36913 Mdot
.31094 .50599 Mdot
.49224 .51318 Mdot
.66189 .38768 Mdot
.03462 .41952 Mdot
.35583 .53563 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53083 .57656 Mdot
.59793 .4914 Mdot
.80283 .35191 Mdot
.23343 .49865 Mdot
.42659 .56432 Mdot
.51351 .55181 Mdot
.62066 .45036 Mdot
.89196 .35772 Mdot
.49959 .00055 Mdot
.49869 .00176 Mdot
.49584 .00562 Mdot
.48674 .0179 Mdot
.45779 .05657 Mdot
.36626 .16647 Mdot
.0969 .25085 Mdot
.69101 .11333 Mdot
.50764 .10625 Mdot
.33572 .23291 Mdot
.95886 .1952 Mdot
.64303 .07974 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51012 .60437 Mdot
.53222 .57471 Mdot
.60233 .48625 Mdot
.81556 .35104 Mdot
.24756 .49857 Mdot
.44085 .55215 Mdot
.54745 .50881 Mdot
.72417 .36321 Mdot
.13649 .47479 Mdot
.49967 .00045 Mdot
.49893 .00144 Mdot
.4966 .00459 Mdot
.48917 .01462 Mdot
.46552 .04633 Mdot
.39055 .13999 Mdot
.16404 .26653 Mdot
.73278 .11985 Mdot
.53886 .08418 Mdot
.40265 .16891 Mdot
.12935 .27605 Mdot
.68269 .1415 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46745 .04376 Mdot
.39664 .13299 Mdot
.18146 .26706 Mdot
.74935 .11952 Mdot
.55596 .0687 Mdot
.4448 .11885 Mdot
.2525 .26638 Mdot
.82149 .13347 Mdot
.50108 .61657 Mdot
.50344 .61338 Mdot
.51097 .60322 Mdot
.53494 .57108 Mdot
.61091 .47639 Mdot
.8401 .35186 Mdot
.27078 .49815 Mdot
.46476 .53056 Mdot
.6063 .43918 Mdot
.89569 .34926 Mdot
.33059 .47829 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61684 Mdot
.50281 .61423 Mdot
.50896 .60593 Mdot
.52855 .57961 Mdot
.59072 .49999 Mdot
.78172 .35537 Mdot
.20672 .49749 Mdot
.40177 .58288 Mdot
.45864 .00276 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00907 Mdot
.4786 .02885 Mdot
.43192 .09005 Mdot
.28621 .2338 Mdot
.90792 .15312 Mdot
.66017 .02846 Mdot
.61413 .54952 Mdot
.72498 .4038 Mdot
.07162 .46798 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49134 .01169 Mdot
.47242 .03714 Mdot
.41233 .11436 Mdot
.22729 .26041 Mdot
.80594 .12188 Mdot
.60873 .02874 Mdot
.56222 .59055 Mdot
.60669 .49889 Mdot
.50029 .61765 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60547 Mdot
.52963 .57816 Mdot
.59414 .49589 Mdot
.79177 .3534 Mdot
.21996 .49832 Mdot
.41366 .5745 Mdot
.4841 .58921 Mdot
.53073 .5609 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.54089 .5632 Mdot
.62961 .45589 Mdot
.89196 .36325 Mdot
.3042 .50232 Mdot
.49143 .51026 Mdot
.66581 .38289 Mdot
.04629 .42519 Mdot
.35831 .53987 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50712 .60842 Mdot
.52268 .58747 Mdot
.57214 .52286 Mdot
.72613 .37697 Mdot
.11618 .47536 Mdot
.34703 .59633 Mdot
.38215 .07783 Mdot
.25622 .22526 Mdot
.89174 .13246 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61084 Mdot
.51695 .59516 Mdot
.55397 .54608 Mdot
.6704 .41661 Mdot
.99631 .41319 Mdot
.32776 .54347 Mdot
.4484 .59047 Mdot
.493 .59696 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48907 .01476 Mdot
.4652 .04677 Mdot
.38953 .14115 Mdot
.16114 .26629 Mdot
.73027 .11988 Mdot
.5363 .08651 Mdot
.39632 .17597 Mdot
.1116 .27116 Mdot
.50131 .61627 Mdot
.50417 .61241 Mdot
.51327 .60012 Mdot
.54226 .5614 Mdot
.63388 .45142 Mdot
.90348 .36732 Mdot
.30914 .50479 Mdot
.49237 .51187 Mdot
.66414 .38528 Mdot
.04075 .42264 Mdot
.3569 .53814 Mdot
.5002 .61777 Mdot
.50063 .61719 Mdot
.502 .61534 Mdot
.50636 .60944 Mdot
.52027 .5907 Mdot
.5645 .53253 Mdot
.70286 .39141 Mdot
.06955 .45385 Mdot
.33521 .58075 Mdot
.39553 .05276 Mdot
.31017 .18988 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.52369 .58611 Mdot
.57535 .51883 Mdot
.73586 .37187 Mdot
.13416 .48203 Mdot
.35422 .59905 Mdot
.38493 .07864 Mdot
.25768 .22602 Mdot
.89198 .13339 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50101 .61666 Mdot
.50323 .61367 Mdot
.51029 .60414 Mdot
.53278 .57396 Mdot
.60408 .48421 Mdot
.82062 .35095 Mdot
.25277 .49847 Mdot
.44623 .54738 Mdot
.56055 .4926 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53084 .57654 Mdot
.59797 .49135 Mdot
.80296 .35189 Mdot
.23358 .49865 Mdot
.42674 .5642 Mdot
.51385 .55137 Mdot
.62172 .44921 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49343 .00887 Mdot
.47908 .02821 Mdot
.43343 .08814 Mdot
.29082 .23086 Mdot
.91728 .15758 Mdot
.66231 .03187 Mdot
.61075 .55532 Mdot
.71222 .41192 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.5132 .60021 Mdot
.54204 .56169 Mdot
.6332 .45213 Mdot
.90163 .36664 Mdot
.3084 .50436 Mdot
.49234 .51146 Mdot
.66478 .38457 Mdot
.04253 .42353 Mdot
.35725 .53883 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .60141 Mdot
.53922 .56541 Mdot
.62436 .4615 Mdot
.87764 .35892 Mdot
.2969 .5001 Mdot
.48772 .51147 Mdot
.66015 .38682 Mdot
.03426 .41834 Mdot
.35738 .53356 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51088 .60335 Mdot
.53464 .57148 Mdot
.60996 .47746 Mdot
.83741 .35162 Mdot
.26848 .49817 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00278 Mdot
.49345 .00884 Mdot
.47914 .02812 Mdot
.43364 .08788 Mdot
.29145 .23045 Mdot
.91858 .15821 Mdot
.66258 .03237 Mdot
.6102 .55621 Mdot
.71023 .41325 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49007 .01341 Mdot
.46837 .04254 Mdot
.39953 .12962 Mdot
.1898 .26674 Mdot
.75821 .11939 Mdot
.56504 .06076 Mdot
.46673 .09138 Mdot
.31888 .22532 Mdot
.95431 .18354 Mdot
.50119 .61642 Mdot
.5038 .6129 Mdot
.51212 .60167 Mdot
.53859 .56625 Mdot
.62239 .46364 Mdot
.8722 .35749 Mdot
.29377 .49949 Mdot
.48557 .51286 Mdot
.65575 .39043 Mdot
.02401 .41261 Mdot
.35639 .5284 Mdot
.50034 .61758 Mdot
.50108 .61657 Mdot
.50344 .61338 Mdot
.51097 .60322 Mdot
.53494 .57108 Mdot
.61091 .47639 Mdot
.8401 .35186 Mdot
.27078 .49815 Mdot
.46476 .53055 Mdot
.6063 .43917 Mdot
.89571 .34926 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49532 .00633 Mdot
.48508 .02014 Mdot
.4525 .06352 Mdot
.34972 .18304 Mdot
.05355 .23175 Mdot
.67856 .09882 Mdot
.51867 .08156 Mdot
.3867 .17794 Mdot
.09879 .26376 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48683 .01777 Mdot
.45807 .05619 Mdot
.36715 .16554 Mdot
.0993 .25174 Mdot
.69198 .11389 Mdot
.5077 .10676 Mdot
.33496 .23378 Mdot
.95669 .19413 Mdot
.64259 .07892 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.48769 .01662 Mdot
.46081 .05258 Mdot
.37572 .15644 Mdot
.1226 .25918 Mdot
.70323 .11796 Mdot
.51236 .10651 Mdot
.34002 .23108 Mdot
.96612 .19991 Mdot
.64266 .08467 Mdot
.49966 .00046 Mdot
.49893 .00145 Mdot
.49658 .00462 Mdot
.48911 .01471 Mdot
.46531 .04662 Mdot
.38988 .14076 Mdot
.16213 .26638 Mdot
.73112 .11987 Mdot
.53717 .08573 Mdot
.39846 .1736 Mdot
.11756 .27295 Mdot
.67593 .14109 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48858 .01542 Mdot
.46363 .04884 Mdot
.3846 .1467 Mdot
.14723 .26454 Mdot
.7192 .11975 Mdot
.52544 .09626 Mdot
.36969 .20401 Mdot
.03959 .24034 Mdot
.65072 .12058 Mdot
.5003 .61763 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50957 .6051 Mdot
.5305 .577 Mdot
.59689 .49263 Mdot
.7998 .35225 Mdot
.22986 .49861 Mdot
.42309 .56717 Mdot
.50539 .56218 Mdot
.59576 .47866 Mdot
.49995 7e-05 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .0024 Mdot
.49435 .00763 Mdot
.48201 .02428 Mdot
.44273 .07623 Mdot
.31938 .20998 Mdot
.97962 .19114 Mdot
.67035 .06169 Mdot
.57053 .61645 Mdot
.57309 .55105 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48972 .01388 Mdot
.46725 .04403 Mdot
.39602 .13371 Mdot
.17967 .26708 Mdot
.74752 .11956 Mdot
.55408 .07038 Mdot
.4402 .12452 Mdot
.23873 .27169 Mdot
.79912 .13112 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00216 Mdot
.49492 .00687 Mdot
.4838 .02186 Mdot
.44843 .06884 Mdot
.33705 .19486 Mdot
.02176 .21497 Mdot
.67393 .08396 Mdot
.53809 .04898 Mdot
.45883 .08672 Mdot
.31852 .2208 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00514 Mdot
.48788 .01636 Mdot
.46141 .05179 Mdot
.37761 .1544 Mdot
.12778 .26054 Mdot
.70622 .11854 Mdot
.51442 .10518 Mdot
.34423 .22761 Mdot
.97595 .2054 Mdot
.6436 .08962 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.4882 .01593 Mdot
.46243 .05043 Mdot
.38083 .15088 Mdot
.13671 .26259 Mdot
.71183 .11927 Mdot
.51885 .10184 Mdot
.35407 .21895 Mdot
.9998 .21877 Mdot
.64583 .10171 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.4899 .01364 Mdot
.46784 .04325 Mdot
.39786 .13157 Mdot
.18499 .26697 Mdot
.75302 .11945 Mdot
.55974 .06536 Mdot
.45399 .10743 Mdot
.28016 .25233 Mdot
.87189 .14598 Mdot
.50063 .61719 Mdot
.502 .61533 Mdot
.50637 .60943 Mdot
.5203 .59066 Mdot
.5646 .5324 Mdot
.70315 .3912 Mdot
.07017 .45417 Mdot
.33531 .58102 Mdot
.3952 .05327 Mdot
.30901 .19079 Mdot
.00031 .19107 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49808 .00259 Mdot
.4939 .00824 Mdot
.48056 .02622 Mdot
.43814 .08214 Mdot
.30524 .22088 Mdot
.94784 .17339 Mdot
.66729 .04532 Mdot
.59395 .58123 Mdot
.6535 .45998 Mdot
.90923 .38033 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61716 Mdot
.50205 .61526 Mdot
.50653 .60921 Mdot
.52081 .58998 Mdot
.56621 .53035 Mdot
.70808 .3879 Mdot
.08045 .45934 Mdot
.33722 .58528 Mdot
.39022 .06114 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50101 .61667 Mdot
.50323 .61367 Mdot
.51028 .60415 Mdot
.53275 .57401 Mdot
.60398 .48432 Mdot
.82033 .35095 Mdot
.25248 .49848 Mdot
.44592 .54765 Mdot
.49984 .00021 Mdot
.49951 .00067 Mdot
.49842 .00213 Mdot
.49498 .00678 Mdot
.48401 .02159 Mdot
.44908 .06799 Mdot
.33907 .19303 Mdot
.02674 .2177 Mdot
.67449 .08645 Mdot
.53461 .05462 Mdot
.44622 .10354 Mdot
.2787 .24869 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49415 .0079 Mdot
.48137 .02514 Mdot
.44069 .07885 Mdot
.31311 .21495 Mdot
.96531 .18304 Mdot
.66914 .05414 Mdot
.58154 .59984 Mdot
.61098 .50509 Mdot
.79373 .36308 Mdot
.50018 .6178 Mdot
.50056 .61728 Mdot
.50178 .61563 Mdot
.50568 .61037 Mdot
.51808 .59364 Mdot
.55755 .54144 Mdot
.68148 .40736 Mdot
.02235 .42801 Mdot
.32981 .55739 Mdot
.42792 .00392 Mdot
.42159 .0737 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00561 Mdot
.48676 .01788 Mdot
.45783 .05651 Mdot
.3664 .16632 Mdot
.09729 .251 Mdot
.69116 .11342 Mdot
.50764 .10634 Mdot
.33558 .23306 Mdot
.95847 .195 Mdot
.64295 .07959 Mdot
.50103 .61664 Mdot
.50329 .61359 Mdot
.51049 .60387 Mdot
.53341 .57313 Mdot
.60606 .48192 Mdot
.8263 .35101 Mdot
.25836 .49835 Mdot
.45201 .54217 Mdot
.57476 .47539 Mdot
.80557 .33674 Mdot
.26071 .48395 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49063 .01266 Mdot
.47015 .04017 Mdot
.40515 .12298 Mdot
.20616 .26497 Mdot
.77744 .11961 Mdot
.58391 .04538 Mdot
.51048 .03567 Mdot
.45278 .0788 Mdot
.32527 .21015 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50993 .60462 Mdot
.53163 .57549 Mdot
.60047 .48842 Mdot
.81019 .3513 Mdot
.24178 .49865 Mdot
.43495 .55728 Mdot
.53325 .52668 Mdot
.68106 .39277 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .0139 Mdot
.46721 .04409 Mdot
.39587 .13388 Mdot
.17926 .26708 Mdot
.7471 .11956 Mdot
.55364 .07077 Mdot
.43914 .12583 Mdot
.23555 .27276 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50172 .61571 Mdot
.50547 .61064 Mdot
.51743 .59452 Mdot
.55548 .54412 Mdot
.67508 .41262 Mdot
.00745 .41952 Mdot
.32865 .54942 Mdot
.43967 .60402 Mdot
.46235 .02057 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49697 .0041 Mdot
.49034 .01305 Mdot
.46923 .04139 Mdot
.40226 .12641 Mdot
.19773 .26607 Mdot
.76722 .11939 Mdot
.57405 .05319 Mdot
.48799 .06431 Mdot
.38393 .16262 Mdot
.1208 .26417 Mdot
.50019 .61777 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50628 .60955 Mdot
.52 .59106 Mdot
.56364 .53363 Mdot
.70021 .39324 Mdot
.06394 .45093 Mdot
.33431 .57825 Mdot
.39868 .04793 Mdot
.32113 .18098 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49818 .00246 Mdot
.49421 .00782 Mdot
.48155 .02489 Mdot
.44127 .07811 Mdot
.31488 .21357 Mdot
.96933 .1853 Mdot
.6695 .05624 Mdot
.57851 .60441 Mdot
.60056 .51727 Mdot
.7636 .37026 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49678 .00434 Mdot
.48976 .01383 Mdot
.46737 .04387 Mdot
.39639 .13328 Mdot
.18074 .26707 Mdot
.7486 .11953 Mdot
.5552 .06938 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.50252 .61464 Mdot
.50801 .60721 Mdot
.52553 .58365 Mdot
.58117 .51162 Mdot
.75334 .36411 Mdot
.1642 .49073 Mdot
.37018 .59817 Mdot
.40233 .0651 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49029 .01311 Mdot
.46907 .04161 Mdot
.40174 .12702 Mdot
.19622 .26622 Mdot
.76546 .11937 Mdot
.57231 .05462 Mdot
.48394 .06948 Mdot
.37151 .17608 Mdot
.08661 .25246 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49103 .01211 Mdot
.47144 .03844 Mdot
.40924 .11809 Mdot
.21817 .26269 Mdot
.79312 .12053 Mdot
.5981 .03524 Mdot
.54108 .61561 Mdot
.545 .57444 Mdot
.61554 .4765 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00368 Mdot
.49131 .01173 Mdot
.47233 .03725 Mdot
.41206 .1147 Mdot
.22647 .26063 Mdot
.80476 .12174 Mdot
.60779 .02927 Mdot
.56043 .59263 Mdot
.60154 .50475 Mdot
.78484 .36073 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49446 .00748 Mdot
.48235 .02381 Mdot
.44383 .0748 Mdot
.3228 .20718 Mdot
.98758 .19568 Mdot
.67097 .06595 Mdot
.56426 .00798 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04863 Mdot
.38512 .14612 Mdot
.14869 .26477 Mdot
.72029 .11979 Mdot
.52647 .09536 Mdot
.37218 .20152 Mdot
.04611 .24367 Mdot
.65184 .12331 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49613 .00523 Mdot
.48768 .01664 Mdot
.46076 .05265 Mdot
.37558 .1566 Mdot
.12219 .25907 Mdot
.703 .11791 Mdot
.51222 .1066 Mdot
.33974 .23131 Mdot
.96547 .19955 Mdot
.6426 .08435 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00217 Mdot
.49489 .00691 Mdot
.48371 .02198 Mdot
.44815 .0692 Mdot
.33619 .19563 Mdot
.01966 .21381 Mdot
.67371 .08289 Mdot
.53959 .04657 Mdot
.46424 .07944 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00335 Mdot
.4921 .01067 Mdot
.47484 .03389 Mdot
.42 .10497 Mdot
.25015 .25252 Mdot
.84157 .12873 Mdot
.63328 .01911 Mdot
.60236 .54866 Mdot
.71461 .40475 Mdot
.05972 .45882 Mdot
.50014 .61784 Mdot
.50045 .61742 Mdot
.50144 .61609 Mdot
.5046 .61183 Mdot
.51464 .59827 Mdot
.54662 .55567 Mdot
.64753 .43766 Mdot
.93938 .38281 Mdot
.31998 .51632 Mdot
.48455 .53063 Mdot
.62597 .42566 Mdot
.50008 .61793 Mdot
.50026 .61769 Mdot
.50081 .61693 Mdot
.50259 .61453 Mdot
.50826 .60687 Mdot
.52632 .58258 Mdot
.58368 .50853 Mdot
.76086 .36133 Mdot
.17622 .4933 Mdot
.37804 .59562 Mdot
.41431 .05324 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46803 .043 Mdot
.39846 .13087 Mdot
.1867 .2669 Mdot
.75485 .11943 Mdot
.56161 .06372 Mdot
.4585 .10176 Mdot
.29385 .24374 Mdot
.89948 .15662 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.51141 .60263 Mdot
.53632 .56925 Mdot
.61526 .4715 Mdot
.85235 .35343 Mdot
.28049 .49827 Mdot
.47427 .52203 Mdot
.62961 .41472 Mdot
.95858 .37675 Mdot
.34898 .49667 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54176 .56206 Mdot
.63234 .45303 Mdot
.89932 .3658 Mdot
.30745 .50383 Mdot
.49223 .51103 Mdot
.66537 .38385 Mdot
.04428 .42438 Mdot
.35762 .53946 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50611 .60978 Mdot
.51946 .59179 Mdot
.56192 .53582 Mdot
.69495 .39702 Mdot
.05256 .44486 Mdot
.33276 .5729 Mdot
.40578 .0372 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47747 .03037 Mdot
.42833 .09459 Mdot
.27528 .24028 Mdot
.88651 .14376 Mdot
.65391 .0223 Mdot
.61783 .54081 Mdot
.74278 .39341 Mdot
.10623 .48474 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50732 .60814 Mdot
.52333 .58659 Mdot
.5742 .52027 Mdot
.73239 .37363 Mdot
.12785 .47981 Mdot
.35151 .59835 Mdot
.38336 .07902 Mdot
.25549 .22648 Mdot
.88904 .13175 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00147 Mdot
.49654 .00467 Mdot
.48899 .01487 Mdot
.46493 .04712 Mdot
.3887 .14209 Mdot
.15879 .26606 Mdot
.72829 .11989 Mdot
.53431 .08833 Mdot
.39139 .18138 Mdot
.09791 .26653 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49038 .01299 Mdot
.46936 .04123 Mdot
.40265 .12595 Mdot
.19885 .26594 Mdot
.76854 .1194 Mdot
.57535 .05213 Mdot
.491 .06046 Mdot
.39317 .15223 Mdot
.14685 .26986 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61173 Mdot
.51486 .59798 Mdot
.54732 .55475 Mdot
.64971 .43555 Mdot
.94498 .38555 Mdot
.32115 .51859 Mdot
.48204 .53521 Mdot
.61606 .4369 Mdot
.90915 .35717 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51124 .60285 Mdot
.53581 .56994 Mdot
.61362 .47333 Mdot
.84777 .35275 Mdot
.277 .49818 Mdot
.47092 .52499 Mdot
.62147 .423 Mdot
.93704 .36615 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52557 .58359 Mdot
.58131 .51144 Mdot
.75378 .36394 Mdot
.16492 .4909 Mdot
.37063 .59805 Mdot
.40296 .06451 Mdot
.29858 .20523 Mdot
.96651 .17441 Mdot
.50095 .61675 Mdot
.50302 .61395 Mdot
.50962 .60504 Mdot
.53066 .57679 Mdot
.59739 .49203 Mdot
.80127 .35208 Mdot
.2316 .49864 Mdot
.42479 .56579 Mdot
.50931 .55717 Mdot
.6078 .4647 Mdot
.8559 .34863 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49734 .00359 Mdot
.49153 .01144 Mdot
.47301 .03634 Mdot
.4142 .11208 Mdot
.23285 .25877 Mdot
.81414 .12305 Mdot
.61504 .02545 Mdot
.57387 .57743 Mdot
.63957 .464 Mdot
.88881 .3691 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48929 .01447 Mdot
.46587 .04586 Mdot
.39166 .13872 Mdot
.16721 .26675 Mdot
.73561 .11981 Mdot
.54175 .08154 Mdot
.40982 .16074 Mdot
.14973 .27996 Mdot
.69675 .1406 Mdot
.50042 .61746 Mdot
.50134 .61622 Mdot
.50429 .61224 Mdot
.51365 .5996 Mdot
.54347 .5598 Mdot
.63769 .4475 Mdot
.91363 .3713 Mdot
.31286 .50748 Mdot
.49173 .51514 Mdot
.65821 .39146 Mdot
.02481 .41437 Mdot
.50051 .61735 Mdot
.50161 .61586 Mdot
.50514 .6111 Mdot
.51636 .59595 Mdot
.55209 .54852 Mdot
.66458 .42172 Mdot
.98222 .40527 Mdot
.32648 .53611 Mdot
.45904 .57366 Mdot
.53084 .54525 Mdot
.6486 .42665 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00561 Mdot
.48676 .01787 Mdot
.45784 .05651 Mdot
.36641 .16631 Mdot
.09731 .25101 Mdot
.69117 .11343 Mdot
.50764 .10635 Mdot
.33557 .23308 Mdot
.95845 .19499 Mdot
.64295 .07958 Mdot
.50032 .6176 Mdot
.50103 .61664 Mdot
.50328 .6136 Mdot
.51047 .6039 Mdot
.53333 .57322 Mdot
.60584 .48218 Mdot
.82565 .35099 Mdot
.25773 .49836 Mdot
.45136 .54275 Mdot
.57317 .47729 Mdot
.8009 .33722 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50701 .60857 Mdot
.52232 .58794 Mdot
.57101 .52428 Mdot
.72271 .3789 Mdot
.10963 .47269 Mdot
.34481 .59482 Mdot
.38238 .07616 Mdot
.25915 .22346 Mdot
.50039 .6175 Mdot
.50126 .61634 Mdot
.504 .61262 Mdot
.51276 .60081 Mdot
.54063 .56355 Mdot
.62878 .45677 Mdot
.88971 .36252 Mdot
.30315 .50191 Mdot
.49104 .51022 Mdot
.66549 .38299 Mdot
.0458 .42487 Mdot
.50018 .61779 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.50579 .61021 Mdot
.51845 .59314 Mdot
.55872 .53993 Mdot
.6851 .40448 Mdot
.03064 .43271 Mdot
.3305 .56178 Mdot
.42152 .01358 Mdot
.39955 .10065 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49276 .00978 Mdot
.47694 .03107 Mdot
.42667 .09668 Mdot
.27023 .24303 Mdot
.877 .14002 Mdot
.65044 .02042 Mdot
.6174 .53922 Mdot
.74493 .39175 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00538 Mdot
.4873 .01714 Mdot
.45957 .05422 Mdot
.37183 .16061 Mdot
.11195 .25605 Mdot
.69766 .11641 Mdot
.5093 .1078 Mdot
.33488 .23485 Mdot
.95489 .19359 Mdot
.64166 .07893 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48974 .01386 Mdot
.46731 .04395 Mdot
.39619 .13351 Mdot
.18017 .26708 Mdot
.74803 .11954 Mdot
.5546 .06991 Mdot
.44149 .12294 Mdot
.24256 .27033 Mdot
.80517 .13156 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00216 Mdot
.49491 .00688 Mdot
.48378 .02189 Mdot
.44835 .06894 Mdot
.3368 .19508 Mdot
.02115 .21463 Mdot
.67387 .08365 Mdot
.53852 .04828 Mdot
.4604 .08462 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00306 Mdot
.49279 .00973 Mdot
.47704 .03094 Mdot
.42697 .09629 Mdot
.27117 .24254 Mdot
.87874 .14068 Mdot
.65111 .02072 Mdot
.49962 .00052 Mdot
.49878 .00164 Mdot
.49612 .00524 Mdot
.48764 .01669 Mdot
.46064 .0528 Mdot
.37521 .15699 Mdot
.1212 .2588 Mdot
.70245 .11779 Mdot
.51187 .10679 Mdot
.33907 .23183 Mdot
.96396 .19871 Mdot
.64245 .08359 Mdot
.50026 .61769 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50825 .60689 Mdot
.52627 .58265 Mdot
.58353 .50871 Mdot
.76042 .36148 Mdot
.17553 .49317 Mdot
.37757 .5958 Mdot
.41354 .05404 Mdot
.3261 .18503 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.4975 .00338 Mdot
.49202 .01078 Mdot
.47458 .03424 Mdot
.41917 .106 Mdot
.24766 .25353 Mdot
.83745 .1277 Mdot
.63083 .01962 Mdot
.59908 .55162 Mdot
.70654 .40954 Mdot
.04388 .44971 Mdot
.50058 .61725 Mdot
.50185 .61553 Mdot
.50591 .61005 Mdot
.51882 .59264 Mdot
.5599 .53841 Mdot
.68873 .40167 Mdot
.03882 .4373 Mdot
.33125 .56603 Mdot
.4154 .02278 Mdot
.37853 .12477 Mdot
.17664 .25692 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50455 .61188 Mdot
.5145 .59846 Mdot
.54617 .55626 Mdot
.64613 .43903 Mdot
.93576 .38108 Mdot
.31915 .51492 Mdot
.486 .52788 Mdot
.63187 .41915 Mdot
.95368 .37681 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00536 Mdot
.48737 .01705 Mdot
.45978 .05394 Mdot
.3725 .15989 Mdot
.11379 .25662 Mdot
.69857 .11672 Mdot
.50972 .10771 Mdot
.33543 .23451 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50822 .60694 Mdot
.52617 .58278 Mdot
.58321 .50911 Mdot
.75946 .36182 Mdot
.17402 .49287 Mdot
.37654 .59619 Mdot
.41189 .05573 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49652 .0047 Mdot
.48893 .01495 Mdot
.46473 .04739 Mdot
.38806 .14281 Mdot
.15698 .26587 Mdot
.7268 .11989 Mdot
.53282 .08968 Mdot
.38771 .18536 Mdot
.08779 .26268 Mdot
.66277 .13675 Mdot
.50098 .61671 Mdot
.50313 .6138 Mdot
.50998 .60456 Mdot
.53178 .57529 Mdot
.60093 .48787 Mdot
.81155 .35122 Mdot
.24326 .49863 Mdot
.43646 .55599 Mdot
.53685 .52213 Mdot
.69202 .38427 Mdot
.07026 .44731 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50258 .61454 Mdot
.50824 .60691 Mdot
.52623 .5827 Mdot
.58341 .50887 Mdot
.76004 .36162 Mdot
.17493 .49305 Mdot
.37715 .59596 Mdot
.41287 .05472 Mdot
.32433 .18647 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.48671 .01794 Mdot
.45767 .05672 Mdot
.3659 .16685 Mdot
.09593 .25049 Mdot
.69063 .1131 Mdot
.50763 .10602 Mdot
.33609 .2325 Mdot
.95989 .19571 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.5417 .56214 Mdot
.63213 .45324 Mdot
.89876 .3656 Mdot
.30722 .50371 Mdot
.4922 .51094 Mdot
.66549 .38371 Mdot
.04463 .42454 Mdot
.3577 .53957 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49756 .00329 Mdot
.49224 .01048 Mdot
.47528 .03331 Mdot
.42138 .10327 Mdot
.25428 .25076 Mdot
.84853 .1306 Mdot
.63721 .01858 Mdot
.60714 .54462 Mdot
.72593 .39876 Mdot
.08071 .47042 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.5109 .60331 Mdot
.53472 .57138 Mdot
.61022 .47717 Mdot
.83814 .35168 Mdot
.26911 .49816 Mdot
.46306 .5321 Mdot
.60212 .44379 Mdot
.88404 .34556 Mdot
.32492 .47705 Mdot
.49986 .00018 Mdot
.49957 .00058 Mdot
.49862 .00186 Mdot
.49561 .00592 Mdot
.48603 .01886 Mdot
.45551 .05957 Mdot
.35913 .17377 Mdot
.07797 .24319 Mdot
.68448 .10797 Mdot
.50977 .09892 Mdot
.34971 .21844 Mdot
.99626 .21498 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49886 .00155 Mdot
.49636 .00492 Mdot
.48839 .01568 Mdot
.46302 .04965 Mdot
.38268 .14883 Mdot
.14186 .26361 Mdot
.71533 .11955 Mdot
.52189 .09932 Mdot
.36119 .2123 Mdot
.01769 .22866 Mdot
.50034 .61757 Mdot
.5011 .61655 Mdot
.50349 .61331 Mdot
.51113 .603 Mdot
.53545 .57041 Mdot
.6125 .47459 Mdot
.84461 .35235 Mdot
.27449 .49815 Mdot
.46847 .5272 Mdot
.61545 .42931 Mdot
.9208 .35889 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49344 .00886 Mdot
.47911 .02816 Mdot
.43355 .08799 Mdot
.29117 .23063 Mdot
.918 .15793 Mdot
.66246 .03215 Mdot
.61045 .55582 Mdot
.71112 .41265 Mdot
.04343 .45242 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.5231 .5869 Mdot
.57347 .52118 Mdot
.73019 .37478 Mdot
.12378 .47831 Mdot
.34987 .59775 Mdot
.38269 .07888 Mdot
.25507 .22635 Mdot
.88883 .13146 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51208 .60172 Mdot
.53847 .5664 Mdot
.62201 .46405 Mdot
.87117 .35724 Mdot
.29315 .49939 Mdot
.48511 .51318 Mdot
.65478 .39126 Mdot
.0217 .41132 Mdot
.35618 .52723 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50872 .60626 Mdot
.52778 .58064 Mdot
.58828 .50293 Mdot
.77453 .35713 Mdot
.19668 .49647 Mdot
.39337 .5881 Mdot
.44181 .02282 Mdot
.40489 .10584 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00413 Mdot
.49025 .01316 Mdot
.46896 .04176 Mdot
.40139 .12744 Mdot
.19518 .26632 Mdot
.76427 .11937 Mdot
.57113 .0556 Mdot
.48116 .07303 Mdot
.36299 .18493 Mdot
.06377 .24248 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49855 .00195 Mdot
.4954 .00622 Mdot
.48533 .0198 Mdot
.45329 .06249 Mdot
.35219 .18065 Mdot
.05989 .23487 Mdot
.67986 .10142 Mdot
.51576 .08683 Mdot
.37527 .19098 Mdot
.06625 .25064 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00495 Mdot
.48832 .01577 Mdot
.46281 .04993 Mdot
.38203 .14955 Mdot
.14006 .26327 Mdot
.71408 .11946 Mdot
.52079 .10025 Mdot
.35859 .21476 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51666 .59555 Mdot
.55303 .5473 Mdot
.66749 .41914 Mdot
.9893 .40923 Mdot
.32715 .53978 Mdot
.45378 .58203 Mdot
.51203 .57088 Mdot
.50011 .61789 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51136 .6027 Mdot
.53617 .56946 Mdot
.61477 .47205 Mdot
.85098 .35322 Mdot
.27946 .49824 Mdot
.47329 .52288 Mdot
.62726 .41708 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48992 .01361 Mdot
.4679 .04317 Mdot
.39805 .13135 Mdot
.18552 .26695 Mdot
.75359 .11944 Mdot
.56032 .06485 Mdot
.45539 .10567 Mdot
.28442 .24977 Mdot
.88028 .14896 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.5064 .60939 Mdot
.52038 .59056 Mdot
.56483 .5321 Mdot
.70388 .39071 Mdot
.0717 .45495 Mdot
.33557 .58168 Mdot
.3944 .05451 Mdot
.30619 .19296 Mdot
.99398 .18738 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51054 .6038 Mdot
.53358 .57289 Mdot
.60662 .48128 Mdot
.82789 .35106 Mdot
.25987 .49832 Mdot
.45357 .54075 Mdot
.57862 .47079 Mdot
.81687 .33608 Mdot
.27308 .48207 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48891 .01498 Mdot
.46468 .04746 Mdot
.38789 .143 Mdot
.15651 .26581 Mdot
.72641 .11989 Mdot
.53243 .09003 Mdot
.38676 .18637 Mdot
.08521 .26165 Mdot
.66186 .13615 Mdot
.50025 .61769 Mdot
.50081 .61695 Mdot
.50257 .61457 Mdot
.50818 .60699 Mdot
.52604 .58296 Mdot
.5828 .50961 Mdot
.75824 .36226 Mdot
.17208 .49248 Mdot
.37524 .59665 Mdot
.40984 .0578 Mdot
.31632 .19272 Mdot
.5004 .6175 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60076 Mdot
.54075 .56339 Mdot
.62916 .45637 Mdot
.89073 .36285 Mdot
.30363 .5021 Mdot
.49122 .51023 Mdot
.66566 .38292 Mdot
.04609 .42505 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00546 Mdot
.48711 .0174 Mdot
.45896 .05502 Mdot
.36993 .16263 Mdot
.10679 .25437 Mdot
.69522 .11547 Mdot
.50838 .10771 Mdot
.33411 .23512 Mdot
.95367 .19278 Mdot
.64175 .07806 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49775 .00304 Mdot
.49282 .0097 Mdot
.47713 .03083 Mdot
.42725 .09595 Mdot
.27199 .24209 Mdot
.88029 .14128 Mdot
.65169 .021 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00907 Mdot
.4786 .02885 Mdot
.43193 .09005 Mdot
.28623 .23378 Mdot
.90796 .15313 Mdot
.66018 .02847 Mdot
.61412 .54955 Mdot
.72493 .40383 Mdot
.07153 .46793 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50438 .61212 Mdot
.51394 .59921 Mdot
.54439 .55859 Mdot
.64058 .44456 Mdot
.92126 .37451 Mdot
.31529 .50981 Mdot
.4904 .5187 Mdot
.65113 .39872 Mdot
.00598 .40426 Mdot
.50082 .61693 Mdot
.50261 .6145 Mdot
.50833 .60679 Mdot
.52653 .58231 Mdot
.58433 .50773 Mdot
.7628 .36067 Mdot
.17923 .49386 Mdot
.38014 .59477 Mdot
.41779 .04961 Mdot
.33752 .1754 Mdot
.05371 .22426 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60801 Mdot
.52364 .58617 Mdot
.5752 .51902 Mdot
.73541 .37209 Mdot
.13335 .48175 Mdot
.35386 .59898 Mdot
.38469 .07873 Mdot
.2573 .22612 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51112 .60301 Mdot
.53543 .57044 Mdot
.61243 .47467 Mdot
.8444 .35233 Mdot
.27432 .49815 Mdot
.4683 .52735 Mdot
.61503 .42975 Mdot
.91968 .35841 Mdot
.33976 .48311 Mdot
.49983 .00023 Mdot
.49946 .00072 Mdot
.49829 .0023 Mdot
.49457 .00734 Mdot
.48269 .02336 Mdot
.4449 .07342 Mdot
.32609 .20442 Mdot
.99533 .2001 Mdot
.67157 .07011 Mdot
.55813 .0174 Mdot
.52998 .60781 Mdot
.54652 .5653 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00366 Mdot
.49138 .01164 Mdot
.47254 .03697 Mdot
.41272 .11389 Mdot
.22845 .26008 Mdot
.80763 .1221 Mdot
.61006 .02801 Mdot
.56474 .58767 Mdot
.61386 .49089 Mdot
.81958 .35723 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49857 .00194 Mdot
.49543 .00617 Mdot
.48544 .01965 Mdot
.45366 .06201 Mdot
.35333 .17953 Mdot
.06284 .23629 Mdot
.68052 .10258 Mdot
.51455 .08911 Mdot
.37036 .19644 Mdot
.05252 .24425 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46948 .04106 Mdot
.40304 .12549 Mdot
.2 .26581 Mdot
.76991 .11942 Mdot
.57668 .05105 Mdot
.49408 .05653 Mdot
.40261 .14129 Mdot
.174 .27233 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49594 .00549 Mdot
.48706 .01747 Mdot
.4588 .05523 Mdot
.36944 .16314 Mdot
.10546 .25391 Mdot
.69462 .11521 Mdot
.5082 .10761 Mdot
.33409 .23504 Mdot
.95379 .1928 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52129 .58933 Mdot
.56773 .52842 Mdot
.71274 .3849 Mdot
.08996 .46392 Mdot
.33931 .58884 Mdot
.38655 .06729 Mdot
.27767 .21262 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00351 Mdot
.49172 .01118 Mdot
.47364 .03551 Mdot
.41619 .10966 Mdot
.23875 .25684 Mdot
.82317 .12462 Mdot
.62154 .02258 Mdot
.585 .56551 Mdot
.67 .43621 Mdot
.96419 .40329 Mdot
.50084 .61691 Mdot
.50266 .61444 Mdot
.50848 .60658 Mdot
.527 .58167 Mdot
.58584 .5059 Mdot
.76728 .35922 Mdot
.18604 .49501 Mdot
.38509 .59252 Mdot
.42638 .04033 Mdot
.36112 .15335 Mdot
.11299 .24952 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51054 .6038 Mdot
.53358 .57289 Mdot
.60662 .48128 Mdot
.82789 .35106 Mdot
.25987 .49832 Mdot
.45358 .54075 Mdot
.57863 .47079 Mdot
.81688 .33608 Mdot
.2731 .48207 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.487 .01755 Mdot
.45861 .05549 Mdot
.36883 .16378 Mdot
.10383 .25335 Mdot
.6939 .11488 Mdot
.50802 .10745 Mdot
.33416 .23484 Mdot
.95419 .19295 Mdot
.64198 .0781 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51293 .60057 Mdot
.54118 .56282 Mdot
.63052 .45493 Mdot
.89443 .36408 Mdot
.30533 .5028 Mdot
.49178 .51042 Mdot
.66591 .38299 Mdot
.04623 .42524 Mdot
.5005 .61735 Mdot
.5016 .61587 Mdot
.5051 .61114 Mdot
.51625 .5961 Mdot
.55174 .54897 Mdot
.66348 .4227 Mdot
.97954 .40378 Mdot
.3262 .53474 Mdot
.46098 .57055 Mdot
.53782 .53582 Mdot
.67084 .40615 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49069 .01257 Mdot
.47036 .03989 Mdot
.40582 .1222 Mdot
.2081 .26466 Mdot
.77988 .1197 Mdot
.58619 .04365 Mdot
.51557 .02924 Mdot
.46826 .05846 Mdot
.37367 .16366 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.48991 .01362 Mdot
.46787 .04321 Mdot
.39796 .13145 Mdot
.18527 .26696 Mdot
.75331 .11945 Mdot
.56004 .0651 Mdot
.45472 .10651 Mdot
.28238 .25101 Mdot
.87623 .14749 Mdot
.50017 .61781 Mdot
.50053 .61731 Mdot
.5017 .61574 Mdot
.5054 .61073 Mdot
.51722 .5948 Mdot
.55481 .54498 Mdot
.67301 .41437 Mdot
.00254 .41673 Mdot
.32826 .54679 Mdot
.44354 .59804 Mdot
.47589 .00228 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48908 .01474 Mdot
.46523 .04673 Mdot
.38962 .14104 Mdot
.16141 .26631 Mdot
.7305 .11988 Mdot
.53654 .0863 Mdot
.39691 .17533 Mdot
.11322 .27166 Mdot
.67367 .14076 Mdot
.50001 .61802 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50426 .61228 Mdot
.51358 .59971 Mdot
.54323 .56012 Mdot
.63694 .44827 Mdot
.91162 .37048 Mdot
.31217 .50691 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01439 Mdot
.46607 .0456 Mdot
.39228 .13802 Mdot
.16896 .26685 Mdot
.7372 .11978 Mdot
.5434 .08004 Mdot
.41388 .15604 Mdot
.1614 .28131 Mdot
.70623 .13931 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01558 Mdot
.46326 .04933 Mdot
.38344 .14799 Mdot
.144 .264 Mdot
.71684 .11964 Mdot
.52326 .09816 Mdot
.36444 .20917 Mdot
.02599 .23316 Mdot
.64873 .11449 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60554 Mdot
.52947 .57838 Mdot
.59364 .49649 Mdot
.7903 .35365 Mdot
.21808 .49824 Mdot
.41191 .57579 Mdot
.48026 .59405 Mdot
.51906 .57643 Mdot
.58638 .50022 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .6056 Mdot
.52934 .57855 Mdot
.59322 .49699 Mdot
.78906 .35387 Mdot
.21649 .49816 Mdot
.41045 .57686 Mdot
.47707 .59805 Mdot
.50941 .58932 Mdot
.55587 .53859 Mdot
.49983 .00023 Mdot
.49946 .00074 Mdot
.49827 .00234 Mdot
.49447 .00747 Mdot
.48239 .02376 Mdot
.44395 .07465 Mdot
.32316 .20688 Mdot
.98842 .19615 Mdot
.67103 .0664 Mdot
.5636 .009 Mdot
.54903 .5823 Mdot
.60685 .49052 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.4867 .01795 Mdot
.45765 .05675 Mdot
.36583 .16691 Mdot
.09577 .25043 Mdot
.69056 .11306 Mdot
.50764 .10598 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51158 .60239 Mdot
.53689 .5685 Mdot
.61703 .46953 Mdot
.85731 .35427 Mdot
.28409 .49845 Mdot
.47758 .51916 Mdot
.63757 .40692 Mdot
.97916 .38766 Mdot
.35192 .50597 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51207 .60173 Mdot
.53845 .56644 Mdot
.62193 .46414 Mdot
.87094 .35718 Mdot
.29301 .49937 Mdot
.48501 .51325 Mdot
.65455 .39145 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.467 .04437 Mdot
.39521 .13464 Mdot
.17735 .26708 Mdot
.7452 .11961 Mdot
.55168 .07253 Mdot
.43432 .13171 Mdot
.2212 .27685 Mdot
.77326 .13087 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00394 Mdot
.4907 .01256 Mdot
.47039 .03985 Mdot
.40591 .12208 Mdot
.20838 .26461 Mdot
.78023 .11972 Mdot
.58652 .0434 Mdot
.51629 .02833 Mdot
.47045 .05557 Mdot
.38054 .1562 Mdot
.50076 .61701 Mdot
.50242 .61476 Mdot
.50771 .60762 Mdot
.52456 .58494 Mdot
.57811 .5154 Mdot
.74417 .36796 Mdot
.1488 .48667 Mdot
.36136 .59955 Mdot
.39127 .07465 Mdot
.27049 .22097 Mdot
.91296 .14424 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.4918 .01108 Mdot
.47387 .0352 Mdot
.41691 .10878 Mdot
.2409 .25608 Mdot
.82655 .12528 Mdot
.62385 .02171 Mdot
.58873 .56168 Mdot
.67991 .42821 Mdot
.98704 .41622 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.5101 .60439 Mdot
.53218 .57476 Mdot
.6022 .48639 Mdot
.8152 .35106 Mdot
.24718 .49858 Mdot
.44047 .55249 Mdot
.54652 .50998 Mdot
.50122 .61638 Mdot
.5039 .61276 Mdot
.51243 .60125 Mdot
.53959 .56492 Mdot
.62554 .46024 Mdot
.88086 .35982 Mdot
.29866 .50052 Mdot
.4888 .51089 Mdot
.66217 .38525 Mdot
.03883 .42089 Mdot
.35782 .53585 Mdot
.50125 .61635 Mdot
.50398 .61265 Mdot
.51269 .60091 Mdot
.5404 .56385 Mdot
.62807 .45753 Mdot
.88777 .3619 Mdot
.30221 .50158 Mdot
.49064 .51025 Mdot
.66504 .38323 Mdot
.04497 .42436 Mdot
.35833 .53903 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49834 .00225 Mdot
.49471 .00715 Mdot
.48313 .02276 Mdot
.44631 .07159 Mdot
.33047 .20068 Mdot
.00576 .20602 Mdot
.67242 .07566 Mdot
.54999 .03008 Mdot
.50133 .02884 Mdot
.45466 .07031 Mdot
.50005 .61796 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50172 .61571 Mdot
.50547 .61064 Mdot
.51743 .59451 Mdot
.55549 .5441 Mdot
.67512 .41259 Mdot
.00754 .41957 Mdot
.32865 .54946 Mdot
.4396 .60412 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49841 .00215 Mdot
.49492 .00686 Mdot
.48382 .02184 Mdot
.44848 .06877 Mdot
.3372 .19472 Mdot
.02214 .21518 Mdot
.67397 .08415 Mdot
.53782 .04942 Mdot
.45786 .08802 Mdot
.31544 .22327 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49816 .00249 Mdot
.49413 .00793 Mdot
.48131 .02522 Mdot
.4405 .0791 Mdot
.31251 .21541 Mdot
.96397 .18229 Mdot
.66901 .05344 Mdot
.58254 .59834 Mdot
.61441 .50118 Mdot
.80349 .36189 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49704 .004 Mdot
.49056 .01275 Mdot
.46992 .04047 Mdot
.40445 .12382 Mdot
.2041 .26527 Mdot
.77487 .11953 Mdot
.58148 .04725 Mdot
.50502 .0426 Mdot
.4361 .10026 Mdot
.27387 .24615 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00382 Mdot
.49099 .01217 Mdot
.4713 .03863 Mdot
.40881 .11862 Mdot
.21688 .26298 Mdot
.79137 .12039 Mdot
.59658 .03625 Mdot
.53792 .00143 Mdot
.53561 .58673 Mdot
.50066 .61715 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52127 .58935 Mdot
.56769 .52848 Mdot
.71259 .38499 Mdot
.08967 .46379 Mdot
.33924 .58874 Mdot
.38665 .06712 Mdot
.27804 .21238 Mdot
.9344 .15327 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47323 .03605 Mdot
.4149 .11124 Mdot
.23492 .25812 Mdot
.81727 .12356 Mdot
.61735 .02436 Mdot
.57793 .573 Mdot
.65079 .45321 Mdot
.91749 .38009 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51236 .60134 Mdot
.53937 .56522 Mdot
.62483 .461 Mdot
.87892 .35927 Mdot
.29761 .50026 Mdot
.48817 .51122 Mdot
.66101 .38614 Mdot
.03621 .41943 Mdot
.49983 .00024 Mdot
.49945 .00075 Mdot
.49823 .00239 Mdot
.49437 .0076 Mdot
.48207 .02419 Mdot
.44293 .07597 Mdot
.32001 .20947 Mdot
.98109 .19198 Mdot
.67047 .06247 Mdot
.56938 .00017 Mdot
.5691 .55614 Mdot
.66926 .42718 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50476 .6116 Mdot
.51516 .59757 Mdot
.54828 .55349 Mdot
.65271 .43267 Mdot
.95263 .3894 Mdot
.32256 .52187 Mdot
.47815 .54206 Mdot
.60108 .45453 Mdot
.86562 .34424 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00568 Mdot
.48661 .01807 Mdot
.45738 .05711 Mdot
.36497 .16781 Mdot
.09345 .24955 Mdot
.68967 .11247 Mdot
.50769 .10535 Mdot
.33722 .23129 Mdot
.96299 .19728 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60706 Mdot
.52588 .58317 Mdot
.58229 .51024 Mdot
.75669 .36283 Mdot
.16962 .49196 Mdot
.37362 .59718 Mdot
.40736 .06027 Mdot
.30984 .1975 Mdot
.99028 .1885 Mdot
.50132 .61626 Mdot
.50419 .61237 Mdot
.51335 .60001 Mdot
.54252 .56106 Mdot
.63471 .45056 Mdot
.90569 .36816 Mdot
.31 .50534 Mdot
.49234 .51244 Mdot
.6632 .3863 Mdot
.03815 .42133 Mdot
.35642 .5371 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00351 Mdot
.49172 .01119 Mdot
.47361 .03554 Mdot
.41611 .10975 Mdot
.23853 .25692 Mdot
.82283 .12455 Mdot
.6213 .02267 Mdot
.58461 .56591 Mdot
.66896 .43708 Mdot
.96174 .40195 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49258 .01003 Mdot
.47636 .03186 Mdot
.4248 .09902 Mdot
.26459 .24594 Mdot
.86664 .13628 Mdot
.64614 .01905 Mdot
.61531 .5393 Mdot
.7427 .39191 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00276 Mdot
.49348 .00881 Mdot
.47923 .028 Mdot
.43392 .08752 Mdot
.29232 .22988 Mdot
.92037 .1591 Mdot
.66295 .03308 Mdot
.60942 .55748 Mdot
.70741 .41518 Mdot
.03563 .44794 Mdot
.50101 .61667 Mdot
.50322 .61368 Mdot
.51026 .60418 Mdot
.53268 .57409 Mdot
.60378 .48456 Mdot
.81974 .35096 Mdot
.25189 .49849 Mdot
.44531 .5482 Mdot
.5583 .49535 Mdot
.75681 .34794 Mdot
.19384 .48639 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.4961 .00528 Mdot
.48756 .0168 Mdot
.46038 .05315 Mdot
.37439 .15787 Mdot
.11895 .25816 Mdot
.70123 .11749 Mdot
.51113 .10718 Mdot
.33772 .23287 Mdot
.96093 .19701 Mdot
.64216 .08206 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51088 .60334 Mdot
.53465 .57148 Mdot
.60997 .47745 Mdot
.83745 .35162 Mdot
.26851 .49817 Mdot
.46246 .53264 Mdot
.60063 .44545 Mdot
.87987 .34436 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.49631 .00499 Mdot
.48823 .01589 Mdot
.46252 .05031 Mdot
.38111 .15056 Mdot
.13749 .26275 Mdot
.71235 .11932 Mdot
.51929 .10148 Mdot
.35509 .21801 Mdot
.00234 .22018 Mdot
.64608 .10299 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01802 Mdot
.4575 .05694 Mdot
.36537 .16739 Mdot
.09452 .24996 Mdot
.69008 .11275 Mdot
.50765 .10565 Mdot
.3367 .23184 Mdot
.96158 .19657 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48858 .01542 Mdot
.46363 .04884 Mdot
.3846 .1467 Mdot
.14723 .26454 Mdot
.7192 .11975 Mdot
.52544 .09626 Mdot
.36969 .20402 Mdot
.03958 .24033 Mdot
.65071 .12058 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61239 Mdot
.51332 .60005 Mdot
.54242 .56119 Mdot
.63439 .45089 Mdot
.90483 .36783 Mdot
.30967 .50513 Mdot
.49236 .51221 Mdot
.66359 .38588 Mdot
.03922 .42187 Mdot
.50069 .61711 Mdot
.50219 .61507 Mdot
.50698 .60861 Mdot
.52223 .58806 Mdot
.57073 .52463 Mdot
.72187 .37938 Mdot
.10802 .47201 Mdot
.3443 .5944 Mdot
.38253 .07565 Mdot
.26013 .22289 Mdot
.89948 .13578 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50873 .60625 Mdot
.5278 .58061 Mdot
.58835 .50285 Mdot
.77473 .35708 Mdot
.19696 .49651 Mdot
.3936 .58796 Mdot
.44225 .0223 Mdot
.40618 .10432 Mdot
.23737 .25141 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60842 Mdot
.52266 .58749 Mdot
.57209 .52292 Mdot
.72598 .37705 Mdot
.1159 .47525 Mdot
.34693 .59627 Mdot
.38215 .07777 Mdot
.25631 .2252 Mdot
.89193 .13254 Mdot
.49989 .00014 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.4966 .0046 Mdot
.48915 .01465 Mdot
.46545 .04643 Mdot
.39032 .14025 Mdot
.1634 .26648 Mdot
.73222 .11986 Mdot
.53829 .0847 Mdot
.40124 .1705 Mdot
.12536 .27507 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50297 .61402 Mdot
.50946 .60526 Mdot
.53012 .57751 Mdot
.59568 .49405 Mdot
.79629 .35271 Mdot
.2256 .49852 Mdot
.41898 .57043 Mdot
.496 .57414 Mdot
.56703 .51382 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49395 .00818 Mdot
.48071 .02602 Mdot
.43862 .08152 Mdot
.30672 .21979 Mdot
.95109 .17516 Mdot
.66767 .04692 Mdot
.59176 .58451 Mdot
.646 .46737 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00552 Mdot
.48698 .01757 Mdot
.45855 .05557 Mdot
.36863 .16399 Mdot
.10328 .25316 Mdot
.69366 .11476 Mdot
.50797 .10738 Mdot
.33422 .23475 Mdot
.95438 .19304 Mdot
.64204 .07815 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49735 .00359 Mdot
.49154 .01142 Mdot
.47307 .03627 Mdot
.41438 .11187 Mdot
.23337 .25861 Mdot
.81493 .12317 Mdot
.61563 .02516 Mdot
.57491 .57629 Mdot
.64246 .46116 Mdot
.89628 .37167 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56446 Mdot
.62661 .45908 Mdot
.8838 .36068 Mdot
.30021 .50094 Mdot
.48967 .51051 Mdot
.66364 .38416 Mdot
.04205 .4227 Mdot
.35812 .53749 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49027 .01314 Mdot
.46902 .04167 Mdot
.40159 .1272 Mdot
.19577 .26627 Mdot
.76494 .11937 Mdot
.5718 .05504 Mdot
.48274 .07102 Mdot
.36783 .17994 Mdot
.07668 .24831 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00183 Mdot
.49568 .00584 Mdot
.48622 .0186 Mdot
.45614 .05875 Mdot
.36108 .17179 Mdot
.08311 .24539 Mdot
.68607 .10959 Mdot
.50875 .10148 Mdot
.34455 .22375 Mdot
.98252 .20757 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.5092 .60561 Mdot
.5293 .5786 Mdot
.59312 .49711 Mdot
.78877 .35392 Mdot
.21611 .49814 Mdot
.41011 .57711 Mdot
.47632 .59898 Mdot
.50715 .59235 Mdot
.54872 .54789 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49716 .00383 Mdot
.49096 .01221 Mdot
.47121 .03875 Mdot
.40852 .11896 Mdot
.21604 .26316 Mdot
.79025 .12031 Mdot
.59559 .03692 Mdot
.53585 .00397 Mdot
.52943 .59487 Mdot
.56691 .53465 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49037 .013 Mdot
.46934 .04125 Mdot
.4026 .12601 Mdot
.19871 .26596 Mdot
.76838 .1194 Mdot
.57519 .05226 Mdot
.49064 .06093 Mdot
.39206 .1535 Mdot
.14369 .26933 Mdot
.49971 .0004 Mdot
.49906 .00126 Mdot
.49702 .00403 Mdot
.49051 .01282 Mdot
.46976 .04069 Mdot
.40392 .12445 Mdot
.20256 .26549 Mdot
.77299 .11948 Mdot
.57967 .04866 Mdot
.50093 .0478 Mdot
.42359 .11595 Mdot
.23599 .26292 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49808 .0026 Mdot
.49387 .00828 Mdot
.48047 .02635 Mdot
.43783 .08252 Mdot
.30431 .22156 Mdot
.94581 .17229 Mdot
.66704 .04434 Mdot
.59529 .57922 Mdot
.65809 .4556 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51094 .60327 Mdot
.53483 .57124 Mdot
.61055 .47679 Mdot
.83908 .35176 Mdot
.26992 .49815 Mdot
.46388 .53135 Mdot
.60414 .44155 Mdot
.88971 .34729 Mdot
.32778 .47756 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49357 .00869 Mdot
.47951 .02763 Mdot
.4348 .0864 Mdot
.29499 .22809 Mdot
.92593 .16188 Mdot
.66401 .03535 Mdot
.60681 .56163 Mdot
.69806 .42188 Mdot
.01545 .43618 Mdot
.49968 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48949 .01419 Mdot
.46653 .04499 Mdot
.39374 .13634 Mdot
.17315 .26701 Mdot
.74111 .1197 Mdot
.54744 .07636 Mdot
.42388 .14427 Mdot
.19045 .28161 Mdot
.73481 .13473 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60707 Mdot
.52585 .58321 Mdot
.58219 .51036 Mdot
.75641 .36293 Mdot
.16918 .49186 Mdot
.37333 .59728 Mdot
.40692 .0607 Mdot
.30871 .19831 Mdot
.98783 .18704 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60554 Mdot
.52946 .57838 Mdot
.59362 .49651 Mdot
.79026 .35366 Mdot
.21803 .49824 Mdot
.41187 .57583 Mdot
.48016 .59417 Mdot
.51877 .57681 Mdot
.58548 .50131 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .6029 Mdot
.5357 .57008 Mdot
.6133 .47369 Mdot
.84686 .35263 Mdot
.27628 .49817 Mdot
.47023 .52561 Mdot
.61977 .42477 Mdot
.93248 .36403 Mdot
.34346 .48686 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48746 .01693 Mdot
.46006 .05357 Mdot
.37338 .15895 Mdot
.11619 .25735 Mdot
.69979 .11709 Mdot
.51033 .10752 Mdot
.33636 .23387 Mdot
.95794 .19534 Mdot
.64188 .08055 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01286 Mdot
.46968 .0408 Mdot
.40367 .12475 Mdot
.20182 .26558 Mdot
.77209 .11946 Mdot
.5788 .04935 Mdot
.49895 .05033 Mdot
.41752 .12342 Mdot
.21782 .26796 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00474 Mdot
.48882 .0151 Mdot
.46438 .04784 Mdot
.38697 .14404 Mdot
.15391 .2655 Mdot
.72432 .11987 Mdot
.53036 .09189 Mdot
.38168 .19175 Mdot
.07142 .25576 Mdot
.65759 .1324 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46506 .04694 Mdot
.38911 .14163 Mdot
.15994 .26618 Mdot
.72926 .11988 Mdot
.53528 .08744 Mdot
.3938 .17875 Mdot
.10457 .26887 Mdot
.66953 .13978 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00263 Mdot
.4938 .00838 Mdot
.48024 .02664 Mdot
.43713 .08342 Mdot
.30215 .22312 Mdot
.94115 .16979 Mdot
.66642 .04213 Mdot
.59826 .57475 Mdot
.6683 .44622 Mdot
.94631 .39738 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57436 .52007 Mdot
.73288 .37337 Mdot
.12875 .48013 Mdot
.35188 .59847 Mdot
.38354 .07902 Mdot
.25569 .22647 Mdot
.88926 .13189 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47747 .03038 Mdot
.42832 .0946 Mdot
.27525 .2403 Mdot
.88644 .14373 Mdot
.65388 .02228 Mdot
.61783 .54079 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50438 .61211 Mdot
.51397 .59918 Mdot
.54448 .55848 Mdot
.64083 .44431 Mdot
.92193 .3748 Mdot
.31549 .51003 Mdot
.49025 .51906 Mdot
.6504 .39948 Mdot
.00403 .40321 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49336 .00897 Mdot
.47886 .02851 Mdot
.43273 .08903 Mdot
.28867 .23224 Mdot
.91289 .15546 Mdot
.66135 .03022 Mdot
.61245 .55247 Mdot
.71854 .40779 Mdot
.05872 .461 Mdot
.50023 .61772 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50746 .60796 Mdot
.52375 .58602 Mdot
.57555 .51858 Mdot
.73647 .37157 Mdot
.13525 .4824 Mdot
.35471 .59915 Mdot
.38527 .0785 Mdot
.25826 .22584 Mdot
.50002 .61801 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.50069 .61711 Mdot
.50219 .61507 Mdot
.50698 .60861 Mdot
.52223 .58806 Mdot
.57073 .52462 Mdot
.72187 .37938 Mdot
.10803 .47201 Mdot
.3443 .59441 Mdot
.50006 .61795 Mdot
.50021 .61776 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60903 Mdot
.52123 .58941 Mdot
.56754 .52866 Mdot
.71214 .38527 Mdot
.08876 .46336 Mdot
.33903 .58841 Mdot
.38696 .06658 Mdot
.5011 .61655 Mdot
.5035 .61331 Mdot
.51114 .60299 Mdot
.53548 .57037 Mdot
.61261 .47447 Mdot
.84489 .35239 Mdot
.27472 .49815 Mdot
.46869 .52699 Mdot
.61601 .42872 Mdot
.92233 .35954 Mdot
.34059 .48382 Mdot
.50065 .61716 Mdot
.50207 .61524 Mdot
.50659 .60913 Mdot
.52101 .58971 Mdot
.56684 .52955 Mdot
.71002 .38663 Mdot
.08444 .46129 Mdot
.33806 .58682 Mdot
.38856 .06386 Mdot
.28524 .2078 Mdot
.94901 .16133 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00568 Mdot
.48661 .01807 Mdot
.45738 .05711 Mdot
.36497 .16781 Mdot
.09345 .24955 Mdot
.68967 .11247 Mdot
.50769 .10535 Mdot
.33722 .23129 Mdot
.96299 .19729 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.46781 .04329 Mdot
.39777 .13167 Mdot
.18472 .26698 Mdot
.75274 .11946 Mdot
.55945 .06561 Mdot
.45329 .1083 Mdot
.27806 .25356 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50718 .60833 Mdot
.52288 .5872 Mdot
.57277 .52206 Mdot
.72805 .37592 Mdot
.1198 .47679 Mdot
.34834 .59705 Mdot
.3823 .07845 Mdot
.25536 .22591 Mdot
.88982 .13174 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49506 .00667 Mdot
.48428 .02122 Mdot
.44994 .06686 Mdot
.34176 .19056 Mdot
.03343 .22132 Mdot
.67533 .08972 Mdot
.53015 .06194 Mdot
.42993 .12482 Mdot
.22796 .27096 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49464 .00724 Mdot
.48292 .02305 Mdot
.44562 .07249 Mdot
.32833 .20252 Mdot
.00064 .20312 Mdot
.67199 .07294 Mdot
.55397 .02387 Mdot
.51535 .00966 Mdot
.49968 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48981 .01377 Mdot
.46753 .04366 Mdot
.3969 .13269 Mdot
.18219 .26705 Mdot
.7501 .1195 Mdot
.55674 .06801 Mdot
.4467 .11651 Mdot
.25818 .26386 Mdot
.83125 .13513 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .61231 Mdot
.51349 .59982 Mdot
.54296 .56047 Mdot
.6361 .44912 Mdot
.90941 .3696 Mdot
.31138 .50631 Mdot
.49216 .51358 Mdot
.66117 .38842 Mdot
.03269 .41851 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51306 .6004 Mdot
.54159 .56228 Mdot
.6318 .45359 Mdot
.89789 .36528 Mdot
.30684 .50352 Mdot
.49214 .51081 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52558 .58357 Mdot
.58135 .5114 Mdot
.75388 .3639 Mdot
.16508 .49094 Mdot
.37073 .59803 Mdot
.40311 .06437 Mdot
.29895 .20499 Mdot
.49975 .00033 Mdot
.49922 .00106 Mdot
.4975 .00337 Mdot
.49205 .01074 Mdot
.47468 .03412 Mdot
.41948 .10562 Mdot
.24857 .25316 Mdot
.83895 .12807 Mdot
.63174 .01942 Mdot
.60032 .55049 Mdot
.70961 .40767 Mdot
.04999 .45325 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51059 .60374 Mdot
.53372 .57272 Mdot
.60704 .4808 Mdot
.8291 .3511 Mdot
.26101 .49829 Mdot
.45475 .53968 Mdot
.58153 .46735 Mdot
.82534 .33603 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48875 .01519 Mdot
.46418 .04812 Mdot
.38632 .14477 Mdot
.15207 .26526 Mdot
.72287 .11985 Mdot
.52895 .09316 Mdot
.37822 .19535 Mdot
.06214 .2515 Mdot
.50002 .618 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50808 .60712 Mdot
.52575 .58335 Mdot
.58186 .51076 Mdot
.75544 .3633 Mdot
.1676 .49151 Mdot
.37232 .59758 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48957 .01409 Mdot
.46677 .04467 Mdot
.39448 .13548 Mdot
.17527 .26706 Mdot
.74316 .11965 Mdot
.54956 .07444 Mdot
.42911 .13801 Mdot
.20581 .2799 Mdot
.75292 .13238 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00531 Mdot
.48748 .01691 Mdot
.46012 .05349 Mdot
.37357 .15875 Mdot
.11671 .25751 Mdot
.70005 .11717 Mdot
.51047 .10747 Mdot
.33659 .23371 Mdot
.95844 .19562 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50258 .61454 Mdot
.50823 .60691 Mdot
.52623 .5827 Mdot
.58339 .50888 Mdot
.76 .36163 Mdot
.17488 .49304 Mdot
.37712 .59597 Mdot
.41282 .05478 Mdot
.32418 .18659 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49607 .0053 Mdot
.48749 .01689 Mdot
.46017 .05343 Mdot
.37373 .15859 Mdot
.11713 .25763 Mdot
.70027 .11723 Mdot
.51059 .10742 Mdot
.33678 .23357 Mdot
.95887 .19586 Mdot
.64196 .08102 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49565 .00587 Mdot
.48616 .01869 Mdot
.45592 .05903 Mdot
.3604 .17248 Mdot
.08131 .24463 Mdot
.6855 .10904 Mdot
.50907 .10063 Mdot
.34624 .22201 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00456 Mdot
.48925 .01451 Mdot
.46577 .046 Mdot
.39134 .13909 Mdot
.16628 .26669 Mdot
.73477 .11982 Mdot
.54089 .08233 Mdot
.40769 .16319 Mdot
.14365 .279 Mdot
.69222 .14107 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .0056 Mdot
.48679 .01783 Mdot
.45794 .05638 Mdot
.36672 .16599 Mdot
.09814 .25131 Mdot
.6915 .11362 Mdot
.50766 .10653 Mdot
.3353 .23338 Mdot
.95767 .19461 Mdot
.64279 .07929 Mdot
.50007 .61794 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60801 Mdot
.52364 .58618 Mdot
.57518 .51905 Mdot
.73534 .37213 Mdot
.13322 .48171 Mdot
.3538 .59897 Mdot
.38465 .07875 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.53641 .56913 Mdot
.61554 .47118 Mdot
.85315 .35356 Mdot
.28108 .4983 Mdot
.47482 .52154 Mdot
.63095 .41338 Mdot
.96209 .37857 Mdot
.34955 .49818 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49157 .01139 Mdot
.47313 .03618 Mdot
.41459 .11161 Mdot
.234 .25841 Mdot
.81588 .12333 Mdot
.61633 .02483 Mdot
.57615 .57493 Mdot
.64589 .45785 Mdot
.90507 .37497 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47977 .02728 Mdot
.43562 .08535 Mdot
.29753 .22636 Mdot
.93126 .1646 Mdot
.66493 .03764 Mdot
.60403 .56595 Mdot
.68829 .42936 Mdot
.99357 .4234 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49148 .01151 Mdot
.47285 .03655 Mdot
.41371 .11269 Mdot
.23138 .25922 Mdot
.81194 .12271 Mdot
.61339 .02627 Mdot
.57089 .58073 Mdot
.63124 .47239 Mdot
.8669 .36289 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60225 Mdot
.53724 .56804 Mdot
.61812 .46831 Mdot
.86038 .35485 Mdot
.28621 .49859 Mdot
.47947 .51757 Mdot
.64202 .4027 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49784 .00292 Mdot
.49311 .0093 Mdot
.47806 .02958 Mdot
.4302 .09223 Mdot
.28098 .23699 Mdot
.89752 .14841 Mdot
.65738 .02516 Mdot
.61668 .54445 Mdot
.73573 .3975 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51204 .60178 Mdot
.53834 .56658 Mdot
.62159 .46451 Mdot
.87 .35695 Mdot
.29244 .49928 Mdot
.48458 .51356 Mdot
.65362 .39225 Mdot
.01894 .40977 Mdot
.35592 .52583 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50662 .6091 Mdot
.52107 .58962 Mdot
.56705 .52928 Mdot
.71066 .38622 Mdot
.08573 .46191 Mdot
.33834 .58731 Mdot
.38806 .0647 Mdot
.28337 .20901 Mdot
.94518 .15919 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00908 Mdot
.4786 .02886 Mdot
.4319 .09008 Mdot
.28616 .23383 Mdot
.90781 .15306 Mdot
.66014 .02842 Mdot
.61416 .54946 Mdot
.72512 .40372 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50706 .6085 Mdot
.52248 .58773 Mdot
.57152 .52363 Mdot
.72426 .37801 Mdot
.11263 .47392 Mdot
.3458 .59554 Mdot
.3822 .07701 Mdot
.2576 .22439 Mdot
.89453 .13361 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49818 .00246 Mdot
.4942 .00783 Mdot
.48153 .02491 Mdot
.44123 .07817 Mdot
.31475 .21367 Mdot
.96902 .18513 Mdot
.66947 .05608 Mdot
.57874 .60406 Mdot
.60135 .51632 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49064 .01264 Mdot
.47019 .04012 Mdot
.40528 .12284 Mdot
.20652 .26491 Mdot
.77789 .11963 Mdot
.58433 .04506 Mdot
.51143 .03447 Mdot
.45565 .07505 Mdot
.33422 .20241 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01028 Mdot
.47575 .03268 Mdot
.42287 .10141 Mdot
.25879 .24873 Mdot
.85633 .13291 Mdot
.64128 .01847 Mdot
.61139 .54146 Mdot
.73528 .39455 Mdot
.09689 .47893 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01313 Mdot
.46904 .04164 Mdot
.40166 .12712 Mdot
.19599 .26624 Mdot
.76519 .11937 Mdot
.57205 .05484 Mdot
.48331 .07028 Mdot
.3696 .17809 Mdot
.08144 .25034 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49631 .00498 Mdot
.48826 .01586 Mdot
.4626 .05021 Mdot
.38137 .15028 Mdot
.13821 .2629 Mdot
.71283 .11936 Mdot
.5197 .10115 Mdot
.35604 .21714 Mdot
.0047 .2215 Mdot
.64631 .10417 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51225 .6015 Mdot
.53901 .56569 Mdot
.62369 .46222 Mdot
.8758 .35842 Mdot
.29586 .49988 Mdot
.48704 .51188 Mdot
.6588 .38791 Mdot
.03115 .4166 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48937 .01436 Mdot
.46613 .04552 Mdot
.39248 .13778 Mdot
.16955 .26687 Mdot
.73774 .11977 Mdot
.54395 .07954 Mdot
.41526 .15444 Mdot
.16538 .28161 Mdot
.70972 .13877 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50767 .60768 Mdot
.52442 .58513 Mdot
.57766 .51596 Mdot
.74281 .36857 Mdot
.14645 .48597 Mdot
.36013 .59958 Mdot
.38999 .0756 Mdot
.26767 .22224 Mdot
.90808 .14168 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00376 Mdot
.49113 .01197 Mdot
.47176 .03802 Mdot
.41025 .11688 Mdot
.22113 .262 Mdot
.7972 .1209 Mdot
.60158 .033 Mdot
.54819 .60704 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50923 .60556 Mdot
.52941 .57846 Mdot
.59345 .49672 Mdot
.78974 .35375 Mdot
.21736 .4982 Mdot
.41125 .57628 Mdot
.47882 .59585 Mdot
.51471 .58224 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54246 .56114 Mdot
.63451 .45077 Mdot
.90515 .36795 Mdot
.30979 .50521 Mdot
.49235 .51229 Mdot
.66345 .38603 Mdot
.03883 .42168 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50496 .61133 Mdot
.5158 .59671 Mdot
.5503 .55086 Mdot
.65899 .42679 Mdot
.96844 .39772 Mdot
.32492 .52921 Mdot
.46863 .5581 Mdot
.5656 .49899 Mdot
.75821 .35165 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48866 .01532 Mdot
.46387 .04852 Mdot
.38537 .14584 Mdot
.1494 .26487 Mdot
.72082 .1198 Mdot
.52698 .09491 Mdot
.3734 .20028 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00479 Mdot
.48871 .01524 Mdot
.46405 .04828 Mdot
.38593 .14521 Mdot
.15098 .2651 Mdot
.72203 .11983 Mdot
.52813 .09389 Mdot
.37622 .19741 Mdot
.0568 .24896 Mdot
.65398 .12747 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.5062 .60965 Mdot
.51977 .59137 Mdot
.5629 .53456 Mdot
.69796 .39484 Mdot
.0591 .44838 Mdot
.33361 .57602 Mdot
.40159 .04352 Mdot
.33117 .17229 Mdot
.05241 .22 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00266 Mdot
.49372 .00849 Mdot
.47998 .027 Mdot
.4363 .08449 Mdot
.29959 .22493 Mdot
.93564 .16688 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00349 Mdot
.49178 .0111 Mdot
.47381 .03527 Mdot
.41674 .10898 Mdot
.2404 .25626 Mdot
.82576 .12512 Mdot
.62331 .0219 Mdot
.58788 .56254 Mdot
.67766 .42998 Mdot
.98194 .41327 Mdot
.50105 .61661 Mdot
.50335 .6135 Mdot
.51069 .6036 Mdot
.53404 .57228 Mdot
.60807 .47961 Mdot
.83204 .35124 Mdot
.26372 .49824 Mdot
.45755 .53713 Mdot
.58846 .45927 Mdot
.84534 .33742 Mdot
.29938 .47792 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47324 .03604 Mdot
.41493 .1112 Mdot
.235 .25809 Mdot
.8174 .12358 Mdot
.61744 .02432 Mdot
.57809 .57284 Mdot
.65122 .45281 Mdot
.91856 .38056 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48865 .01533 Mdot
.46384 .04856 Mdot
.38526 .14595 Mdot
.14911 .26483 Mdot
.7206 .1198 Mdot
.52677 .0951 Mdot
.3729 .2008 Mdot
.04801 .24463 Mdot
.65219 .12408 Mdot
.49979 .00028 Mdot
.49933 .00091 Mdot
.49786 .00289 Mdot
.49319 .00919 Mdot
.47832 .02923 Mdot
.43102 .09119 Mdot
.28348 .23548 Mdot
.90245 .15061 Mdot
.65876 .02665 Mdot
.61564 .54667 Mdot
.7311 .40017 Mdot
.08362 .47417 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00398 Mdot
.49062 .01267 Mdot
.47012 .0402 Mdot
.40507 .12308 Mdot
.20591 .265 Mdot
.77713 .1196 Mdot
.58361 .0456 Mdot
.50983 .0365 Mdot
.45077 .08141 Mdot
.31905 .21529 Mdot
.50071 .61708 Mdot
.50225 .615 Mdot
.50716 .60836 Mdot
.52281 .58728 Mdot
.57257 .52231 Mdot
.72746 .37624 Mdot
.11868 .47635 Mdot
.34793 .59683 Mdot
.38223 .07828 Mdot
.25557 .22574 Mdot
.89032 .13192 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .0021 Mdot
.49504 .0067 Mdot
.48421 .02131 Mdot
.44972 .06715 Mdot
.34107 .1912 Mdot
.0317 .22039 Mdot
.6751 .08889 Mdot
.53128 .06008 Mdot
.43407 .11947 Mdot
.24076 .26677 Mdot
.50083 .61691 Mdot
.50266 .61444 Mdot
.50847 .6066 Mdot
.52697 .58171 Mdot
.58575 .50601 Mdot
.767 .35931 Mdot
.18563 .49495 Mdot
.38479 .59267 Mdot
.42583 .04093 Mdot
.3596 .15486 Mdot
.10904 .24821 Mdot
.50132 .61625 Mdot
.50422 .61234 Mdot
.51343 .5999 Mdot
.54277 .56072 Mdot
.63551 .44973 Mdot
.90782 .36898 Mdot
.3108 .50589 Mdot
.49226 .51306 Mdot
.6621 .38745 Mdot
.03519 .41981 Mdot
.35592 .53587 Mdot
.50013 .61786 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.51341 .59994 Mdot
.54269 .56084 Mdot
.63524 .45002 Mdot
.9071 .3687 Mdot
.31053 .5057 Mdot
.49229 .51284 Mdot
.6625 .38704 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00369 Mdot
.49131 .01174 Mdot
.47231 .03728 Mdot
.412 .11477 Mdot
.2263 .26068 Mdot
.80451 .1217 Mdot
.60759 .02939 Mdot
.56003 .59308 Mdot
.6004 .50606 Mdot
.78159 .36141 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .60891 Mdot
.52152 .58901 Mdot
.56848 .52747 Mdot
.71502 .38347 Mdot
.09454 .46606 Mdot
.34045 .59041 Mdot
.38515 .06985 Mdot
.27213 .21597 Mdot
.92269 .14708 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49613 .00522 Mdot
.48769 .01663 Mdot
.46078 .05262 Mdot
.37565 .15652 Mdot
.12239 .25913 Mdot
.70312 .11794 Mdot
.51229 .10656 Mdot
.33987 .2312 Mdot
.96579 .19973 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48477 .02055 Mdot
.45151 .06481 Mdot
.34665 .18598 Mdot
.04572 .22779 Mdot
.67716 .09543 Mdot
.52275 .07441 Mdot
.40235 .15936 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.4971 .00392 Mdot
.49075 .01249 Mdot
.47053 .03965 Mdot
.40637 .12153 Mdot
.20973 .26438 Mdot
.78196 .1198 Mdot
.58812 .04222 Mdot
.51981 .0239 Mdot
.48114 .04134 Mdot
.49982 .00024 Mdot
.49943 .00078 Mdot
.49817 .00247 Mdot
.49418 .00787 Mdot
.48145 .02503 Mdot
.44095 .07853 Mdot
.31388 .21435 Mdot
.96707 .18403 Mdot
.6693 .05505 Mdot
.58022 .60183 Mdot
.60644 .51034 Mdot
.78069 .36553 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50669 .609 Mdot
.52132 .58929 Mdot
.56782 .52831 Mdot
.713 .38473 Mdot
.09049 .46417 Mdot
.33944 .58903 Mdot
.38638 .0676 Mdot
.27699 .21303 Mdot
.9323 .15214 Mdot
.50077 .617 Mdot
.50244 .61474 Mdot
.50777 .60754 Mdot
.52475 .58469 Mdot
.5787 .51467 Mdot
.74596 .36717 Mdot
.15186 .48754 Mdot
.363 .59943 Mdot
.3931 .07321 Mdot
.27464 .21899 Mdot
.9203 .14816 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50559 .61048 Mdot
.51781 .594 Mdot
.5567 .54254 Mdot
.67886 .40949 Mdot
.0163 .42457 Mdot
.32933 .55416 Mdot
.43268 .61473 Mdot
.43803 .0527 Mdot
.35275 .17055 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50875 .60622 Mdot
.52786 .58052 Mdot
.58856 .50259 Mdot
.77535 .35691 Mdot
.19785 .49661 Mdot
.39432 .58754 Mdot
.44366 .02065 Mdot
.41025 .09951 Mdot
.24924 .24705 Mdot
.50045 .61743 Mdot
.50142 .61612 Mdot
.50452 .61192 Mdot
.51441 .59858 Mdot
.5459 .55662 Mdot
.64527 .43988 Mdot
.93353 .38003 Mdot
.31862 .51407 Mdot
.48683 .52627 Mdot
.63531 .41541 Mdot
.96316 .38156 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48811 .01605 Mdot
.46214 .05083 Mdot
.3799 .1519 Mdot
.13412 .26203 Mdot
.71015 .11909 Mdot
.51746 .10294 Mdot
.35089 .22182 Mdot
.99199 .21439 Mdot
.64509 .09775 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01054 Mdot
.47515 .03348 Mdot
.42097 .10377 Mdot
.25307 .25129 Mdot
.84648 .13003 Mdot
.63608 .0187 Mdot
.60583 .54569 Mdot
.72289 .40028 Mdot
.07523 .46745 Mdot
.50035 .61757 Mdot
.5011 .61654 Mdot
.50351 .61329 Mdot
.5112 .60291 Mdot
.53566 .57013 Mdot
.61317 .47384 Mdot
.84648 .35258 Mdot
.27599 .49817 Mdot
.46994 .52587 Mdot
.61906 .42551 Mdot
.93058 .36317 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50729 .60819 Mdot
.52322 .58674 Mdot
.57386 .52069 Mdot
.73136 .37416 Mdot
.12596 .47911 Mdot
.35073 .59808 Mdot
.38301 .07899 Mdot
.2552 .22646 Mdot
.88878 .13154 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60458 Mdot
.53174 .57535 Mdot
.60081 .48801 Mdot
.81119 .35124 Mdot
.24287 .49864 Mdot
.43606 .55633 Mdot
.53589 .52334 Mdot
.68911 .38646 Mdot
.0638 .44404 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46846 .04242 Mdot
.39983 .12927 Mdot
.19066 .26668 Mdot
.75916 .11938 Mdot
.566 .05993 Mdot
.46902 .08847 Mdot
.32588 .21956 Mdot
.97062 .19248 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49001 .01349 Mdot
.46819 .04278 Mdot
.39898 .13026 Mdot
.18821 .26683 Mdot
.75648 .1194 Mdot
.56327 .06228 Mdot
.4625 .09672 Mdot
.30601 .23522 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .6042 Mdot
.53263 .57416 Mdot
.60363 .48473 Mdot
.81931 .35096 Mdot
.25144 .4985 Mdot
.44485 .54861 Mdot
.55719 .49673 Mdot
.75347 .34922 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01438 Mdot
.46608 .04559 Mdot
.39231 .13798 Mdot
.16905 .26685 Mdot
.73728 .11978 Mdot
.54348 .07997 Mdot
.41408 .15581 Mdot
.16199 .28136 Mdot
.70674 .13923 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.50851 .60654 Mdot
.52711 .58153 Mdot
.58616 .5055 Mdot
.76825 .35892 Mdot
.18749 .49524 Mdot
.38619 .59198 Mdot
.42834 .03816 Mdot
.36659 .14785 Mdot
.12736 .25372 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50185 .61553 Mdot
.5059 .61006 Mdot
.5188 .59267 Mdot
.55983 .5385 Mdot
.68852 .40183 Mdot
.03834 .43703 Mdot
.33121 .56578 Mdot
.41575 .02225 Mdot
.37975 .12342 Mdot
.50032 .6176 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51031 .60411 Mdot
.53284 .57388 Mdot
.60429 .48397 Mdot
.82121 .35095 Mdot
.25336 .49846 Mdot
.44684 .54683 Mdot
.56204 .49076 Mdot
.76798 .34416 Mdot
.50015 .61784 Mdot
.50047 .61741 Mdot
.50148 .61603 Mdot
.50472 .61165 Mdot
.51505 .59772 Mdot
.54792 .55396 Mdot
.6516 .43373 Mdot
.94981 .38797 Mdot
.32207 .52064 Mdot
.47965 .53946 Mdot
.60679 .44773 Mdot
.50037 .61754 Mdot
.50118 .61644 Mdot
.50375 .61297 Mdot
.51194 .60191 Mdot
.53802 .567 Mdot
.6206 .46559 Mdot
.86726 .35631 Mdot
.29073 .49905 Mdot
.48325 .51455 Mdot
.65069 .39481 Mdot
.01189 .40581 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50855 .60649 Mdot
.52723 .58136 Mdot
.58657 .50501 Mdot
.76945 .35856 Mdot
.18928 .4955 Mdot
.38755 .59129 Mdot
.43082 .03539 Mdot
.37355 .14067 Mdot
.14595 .25779 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47976 .02729 Mdot
.4356 .08538 Mdot
.29746 .22641 Mdot
.93112 .16453 Mdot
.66491 .03758 Mdot
.6041 .56584 Mdot
.68856 .42915 Mdot
.99417 .42375 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48953 .01414 Mdot
.46665 .04483 Mdot
.39411 .13591 Mdot
.1742 .26704 Mdot
.74213 .11967 Mdot
.54849 .07541 Mdot
.42647 .14118 Mdot
.19803 .28093 Mdot
.74348 .13351 Mdot
.49979 .00028 Mdot
.49933 .00091 Mdot
.49786 .00288 Mdot
.4932 .00919 Mdot
.47833 .02922 Mdot
.43105 .09116 Mdot
.28355 .23544 Mdot
.90259 .15067 Mdot
.6588 .0267 Mdot
.6156 .54674 Mdot
.73096 .40025 Mdot
.08334 .47403 Mdot
.50009 .61791 Mdot
.50029 .61764 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50934 .60543 Mdot
.52974 .57802 Mdot
.59448 .49548 Mdot
.79278 .35323 Mdot
.22123 .49838 Mdot
.41484 .57361 Mdot
.48673 .58589 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50041 .61748 Mdot
.50131 .61627 Mdot
.50417 .61241 Mdot
.51327 .60011 Mdot
.54227 .56139 Mdot
.63392 .45138 Mdot
.90358 .36736 Mdot
.30918 .50482 Mdot
.49237 .5119 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00647 Mdot
.48475 .02058 Mdot
.45145 .06489 Mdot
.34646 .18616 Mdot
.04525 .22754 Mdot
.67708 .09522 Mdot
.52301 .07395 Mdot
.40335 .15814 Mdot
.14747 .27612 Mdot
.5001 .61789 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50337 .61348 Mdot
.51075 .60352 Mdot
.53424 .57202 Mdot
.60869 .47892 Mdot
.83378 .35135 Mdot
.26529 .49821 Mdot
.45917 .53565 Mdot
.59247 .45467 Mdot
.50055 .61729 Mdot
.50177 .61565 Mdot
.50563 .61043 Mdot
.51792 .59385 Mdot
.55705 .54209 Mdot
.67994 .40861 Mdot
.0188 .426 Mdot
.32953 .5555 Mdot
.4307 .61773 Mdot
.43119 .06152 Mdot
.33165 .19007 Mdot
.50092 .61679 Mdot
.50293 .61407 Mdot
.50934 .60542 Mdot
.52975 .578 Mdot
.59453 .49543 Mdot
.79291 .35321 Mdot
.2214 .49838 Mdot
.415 .57349 Mdot
.48707 .58546 Mdot
.53977 .54898 Mdot
.65151 .42879 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47977 .02728 Mdot
.43563 .08535 Mdot
.29753 .22636 Mdot
.93127 .16461 Mdot
.66493 .03764 Mdot
.60402 .56596 Mdot
.68827 .42938 Mdot
.99353 .42338 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.49541 .00621 Mdot
.48536 .01976 Mdot
.4534 .06234 Mdot
.35253 .18032 Mdot
.06077 .23529 Mdot
.68006 .10177 Mdot
.51539 .08752 Mdot
.37377 .19266 Mdot
.06205 .24873 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48866 .01531 Mdot
.46388 .04851 Mdot
.38538 .14582 Mdot
.14943 .26488 Mdot
.72085 .1198 Mdot
.527 .09489 Mdot
.37347 .20022 Mdot
.04951 .24538 Mdot
.65248 .12468 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.4886 .0154 Mdot
.46368 .04877 Mdot
.38477 .14651 Mdot
.14771 .26461 Mdot
.71955 .11976 Mdot
.52578 .09597 Mdot
.37049 .20321 Mdot
.04169 .24142 Mdot
.65106 .12148 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49714 .00387 Mdot
.49088 .01231 Mdot
.47096 .03909 Mdot
.40772 .11992 Mdot
.21368 .26364 Mdot
.7871 .12009 Mdot
.5928 .03885 Mdot
.52994 .01126 Mdot
.51171 .00042 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49744 .00345 Mdot
.49185 .011 Mdot
.47405 .03495 Mdot
.4175 .10806 Mdot
.24265 .25545 Mdot
.82933 .12585 Mdot
.6257 .02107 Mdot
.5916 .55879 Mdot
.68746 .4225 Mdot
.00384 .42606 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61095 Mdot
.51671 .59548 Mdot
.55321 .54707 Mdot
.66803 .41866 Mdot
.99062 .40997 Mdot
.32727 .54047 Mdot
.45278 .58361 Mdot
.50848 .57575 Mdot
.5769 .5072 Mdot
.49996 5e-05 Mdot
.49989 .00016 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48818 .01597 Mdot
.46234 .05055 Mdot
.38054 .15119 Mdot
.13592 .26242 Mdot
.71131 .11922 Mdot
.51841 .10219 Mdot
.35307 .21986 Mdot
.49982 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49434 .00765 Mdot
.48195 .02435 Mdot
.44256 .07645 Mdot
.31886 .2104 Mdot
.97842 .19046 Mdot
.67025 .06105 Mdot
.57147 .61503 Mdot
.57633 .54695 Mdot
.69136 .4093 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.499 .00136 Mdot
.4968 .00433 Mdot
.4898 .01377 Mdot
.46751 .04368 Mdot
.39683 .13277 Mdot
.182 .26705 Mdot
.74991 .11951 Mdot
.55654 .06819 Mdot
.44621 .11712 Mdot
.25671 .26453 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48994 .01359 Mdot
.46796 .04309 Mdot
.39824 .13113 Mdot
.18607 .26693 Mdot
.75417 .11943 Mdot
.56092 .06433 Mdot
.45682 .10387 Mdot
.28876 .24706 Mdot
.88901 .15231 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52884 .57922 Mdot
.59164 .49889 Mdot
.78442 .35478 Mdot
.21038 .49777 Mdot
.40496 .58074 Mdot
.46531 .61264 Mdot
.47404 .01857 Mdot
.44399 .06943 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.50631 .60951 Mdot
.52009 .59094 Mdot
.56393 .53325 Mdot
.70111 .39261 Mdot
.06585 .45193 Mdot
.33461 .57911 Mdot
.39758 .04961 Mdot
.31731 .18416 Mdot
.01934 .20204 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.50651 .60925 Mdot
.52072 .59009 Mdot
.56594 .53069 Mdot
.70726 .38843 Mdot
.07876 .45851 Mdot
.33688 .58461 Mdot
.39096 .05993 Mdot
.29399 .20188 Mdot
.96734 .17182 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00696 Mdot
.48358 .02216 Mdot
.44771 .06977 Mdot
.33482 .19685 Mdot
.01631 .21195 Mdot
.67338 .08117 Mdot
.54203 .04266 Mdot
.47302 .06755 Mdot
.36371 .17901 Mdot
.50019 .61777 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50622 .60964 Mdot
.51981 .59132 Mdot
.56303 .53441 Mdot
.69834 .39457 Mdot
.05992 .44881 Mdot
.33373 .57641 Mdot
.40108 .04428 Mdot
.32943 .17383 Mdot
.50033 .61759 Mdot
.50104 .61662 Mdot
.50332 .61354 Mdot
.51059 .60374 Mdot
.53372 .5727 Mdot
.60707 .48076 Mdot
.82918 .3511 Mdot
.26108 .49829 Mdot
.45483 .53961 Mdot
.58172 .46714 Mdot
.82588 .33604 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00636 Mdot
.48501 .02024 Mdot
.45226 .06383 Mdot
.34899 .18374 Mdot
.05169 .23082 Mdot
.67821 .09803 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50738 .60807 Mdot
.52351 .58635 Mdot
.57477 .51956 Mdot
.73409 .37276 Mdot
.13096 .48092 Mdot
.35282 .59873 Mdot
.38405 .07893 Mdot
.25634 .22636 Mdot
.89008 .13237 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00505 Mdot
.48809 .01609 Mdot
.46206 .05092 Mdot
.37966 .15215 Mdot
.13348 .26189 Mdot
.70973 .11904 Mdot
.51712 .1032 Mdot
.35014 .22249 Mdot
.99014 .21336 Mdot
.64492 .09682 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49466 .00722 Mdot
.48297 .02298 Mdot
.4458 .07226 Mdot
.32888 .20205 Mdot
.00196 .20386 Mdot
.6721 .07364 Mdot
.55294 .02547 Mdot
.51173 .0146 Mdot
.48811 .02562 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51225 .6015 Mdot
.53901 .56569 Mdot
.6237 .46222 Mdot
.87581 .35842 Mdot
.29587 .49988 Mdot
.48705 .51188 Mdot
.65881 .3879 Mdot
.03118 .41662 Mdot
.35708 .53201 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.4883 .0158 Mdot
.46273 .05003 Mdot
.38178 .14982 Mdot
.13936 .26313 Mdot
.71361 .11943 Mdot
.52037 .10059 Mdot
.35761 .21567 Mdot
.00864 .22368 Mdot
.64672 .10613 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01053 Mdot
.47516 .03347 Mdot
.42099 .10375 Mdot
.25313 .25126 Mdot
.84658 .13006 Mdot
.63614 .01869 Mdot
.6059 .54564 Mdot
.72304 .4002 Mdot
.0755 .4676 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48755 .01681 Mdot
.46036 .05318 Mdot
.37431 .15796 Mdot
.11874 .2581 Mdot
.70112 .11746 Mdot
.51107 .10721 Mdot
.33761 .23296 Mdot
.96067 .19687 Mdot
.64213 .08193 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.5108 .60345 Mdot
.53439 .57181 Mdot
.60918 .47835 Mdot
.83519 .35144 Mdot
.26654 .49819 Mdot
.46045 .53448 Mdot
.59565 .45105 Mdot
.86583 .34089 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.5417 .56214 Mdot
.63213 .45324 Mdot
.89877 .3656 Mdot
.30722 .50371 Mdot
.4922 .51094 Mdot
.66548 .38371 Mdot
.04462 .42454 Mdot
.3577 .53957 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .0133 Mdot
.46863 .0422 Mdot
.40035 .12867 Mdot
.19216 .26657 Mdot
.76084 .11937 Mdot
.56769 .05849 Mdot
.47304 .08336 Mdot
.33816 .20885 Mdot
.00024 .20907 Mdot
.50038 .61752 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .6014 Mdot
.53924 .56539 Mdot
.62441 .46145 Mdot
.87777 .35895 Mdot
.29698 .50012 Mdot
.48777 .51144 Mdot
.66024 .38675 Mdot
.03447 .41845 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.4994 .00081 Mdot
.49808 .00259 Mdot
.49389 .00826 Mdot
.48053 .02626 Mdot
.43803 .08227 Mdot
.30491 .22112 Mdot
.94712 .173 Mdot
.6672 .04497 Mdot
.59443 .58051 Mdot
.65514 .45841 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49439 .00757 Mdot
.48214 .02409 Mdot
.44315 .07568 Mdot
.3207 .2089 Mdot
.98269 .19289 Mdot
.67059 .06333 Mdot
.56812 .00209 Mdot
.56474 .56175 Mdot
.65581 .4393 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50477 .61159 Mdot
.51519 .59753 Mdot
.54837 .55337 Mdot
.653 .43239 Mdot
.95337 .38978 Mdot
.32269 .5222 Mdot
.47775 .54276 Mdot
.59954 .45638 Mdot
.8611 .34335 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.4875 .01687 Mdot
.4602 .05338 Mdot
.37383 .15847 Mdot
.11742 .25772 Mdot
.70042 .11727 Mdot
.51067 .10738 Mdot
.33692 .23346 Mdot
.95917 .19603 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48783 .01643 Mdot
.46124 .05201 Mdot
.37709 .15496 Mdot
.12635 .26017 Mdot
.70538 .11839 Mdot
.51382 .1056 Mdot
.34296 .22868 Mdot
.97294 .20372 Mdot
.64332 .0881 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00382 Mdot
.491 .01216 Mdot
.47133 .03859 Mdot
.4089 .11851 Mdot
.21714 .26292 Mdot
.79173 .12042 Mdot
.59689 .03604 Mdot
.53857 .00064 Mdot
.53753 .5842 Mdot
.59228 .50337 Mdot
.5009 .61681 Mdot
.50288 .61415 Mdot
.50917 .60565 Mdot
.52921 .57872 Mdot
.59282 .49747 Mdot
.78789 .35409 Mdot
.21496 .49807 Mdot
.40906 .57786 Mdot
.47406 .60181 Mdot
.50031 .60152 Mdot
.52703 .57658 Mdot
.50032 .6176 Mdot
.50101 .61667 Mdot
.50323 .61368 Mdot
.51028 .60416 Mdot
.53273 .57403 Mdot
.60394 .48438 Mdot
.8202 .35095 Mdot
.25235 .49848 Mdot
.44579 .54777 Mdot
.55948 .49391 Mdot
.76031 .34667 Mdot
.49984 .00022 Mdot
.49949 .0007 Mdot
.49836 .00221 Mdot
.49478 .00706 Mdot
.48336 .02245 Mdot
.44704 .07065 Mdot
.33272 .19871 Mdot
.0112 .20908 Mdot
.67289 .07852 Mdot
.54585 .0366 Mdot
.48662 .04899 Mdot
.40734 .13012 Mdot
.50095 .61675 Mdot
.50302 .61396 Mdot
.50961 .60506 Mdot
.53061 .57686 Mdot
.59724 .49222 Mdot
.80081 .35213 Mdot
.23106 .49863 Mdot
.42426 .56622 Mdot
.50809 .55873 Mdot
.60405 .46899 Mdot
.84521 .34707 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00264 Mdot
.49376 .00842 Mdot
.48014 .02679 Mdot
.43679 .08386 Mdot
.30109 .22387 Mdot
.93886 .16858 Mdot
.6661 .04106 Mdot
.59966 .57263 Mdot
.67312 .44196 Mdot
.95801 .40349 Mdot
.50132 .61626 Mdot
.50419 .61237 Mdot
.51336 .6 Mdot
.54253 .56105 Mdot
.63474 .45053 Mdot
.90577 .36819 Mdot
.31003 .50536 Mdot
.49234 .51246 Mdot
.66316 .38634 Mdot
.03806 .42128 Mdot
.35641 .53706 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50838 .60672 Mdot
.52668 .5821 Mdot
.58483 .50712 Mdot
.76429 .36017 Mdot
.18152 .49427 Mdot
.38177 .59406 Mdot
.42056 .04666 Mdot
.34506 .16866 Mdot
.07217 .23329 Mdot
.49965 .00047 Mdot
.49889 .00149 Mdot
.49648 .00476 Mdot
.48878 .01516 Mdot
.46426 .04801 Mdot
.38657 .14449 Mdot
.15277 .26535 Mdot
.72342 .11986 Mdot
.52949 .09268 Mdot
.37953 .194 Mdot
.06564 .25314 Mdot
.65606 .13056 Mdot
.49976 .00032 Mdot
.49923 .00103 Mdot
.49756 .0033 Mdot
.49222 .0105 Mdot
.47523 .03338 Mdot
.42123 .10346 Mdot
.25383 .25096 Mdot
.84777 .13039 Mdot
.63679 .01862 Mdot
.60666 .54501 Mdot
.72482 .39931 Mdot
.07873 .46935 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61095 Mdot
.51672 .59548 Mdot
.55321 .54706 Mdot
.66804 .41865 Mdot
.99065 .40999 Mdot
.32727 .54048 Mdot
.45275 .58364 Mdot
.5084 .57586 Mdot
.57664 .50753 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50958 .60509 Mdot
.53052 .57697 Mdot
.59696 .49255 Mdot
.8 .35222 Mdot
.23009 .49861 Mdot
.42331 .56699 Mdot
.5059 .56152 Mdot
.59734 .4768 Mdot
.82586 .3457 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48702 .01752 Mdot
.45868 .05539 Mdot
.36905 .16355 Mdot
.10442 .25355 Mdot
.69416 .115 Mdot
.50808 .10751 Mdot
.33412 .23492 Mdot
.95401 .19288 Mdot
.64193 .07807 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48657 .01813 Mdot
.45723 .0573 Mdot
.36452 .16827 Mdot
.09224 .24908 Mdot
.68922 .11216 Mdot
.50774 .10499 Mdot
.33786 .23062 Mdot
.96471 .19817 Mdot
.64406 .08212 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .6123 Mdot
.51351 .59979 Mdot
.54303 .56039 Mdot
.6363 .44892 Mdot
.90993 .36981 Mdot
.31157 .50645 Mdot
.49212 .51375 Mdot
.66085 .38876 Mdot
.03182 .41806 Mdot
.49978 .0003 Mdot
.49928 .00097 Mdot
.49772 .00308 Mdot
.49274 .00981 Mdot
.47687 .03118 Mdot
.42642 .09699 Mdot
.26948 .24343 Mdot
.8756 .1395 Mdot
.64989 .02019 Mdot
.61722 .53911 Mdot
.74492 .39165 Mdot
.11122 .48656 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00535 Mdot
.48738 .01703 Mdot
.45982 .05388 Mdot
.37264 .15975 Mdot
.11415 .25673 Mdot
.69875 .11677 Mdot
.5098 .10769 Mdot
.33555 .23443 Mdot
.95624 .19437 Mdot
.64174 .07966 Mdot
.50097 .61672 Mdot
.5031 .61385 Mdot
.50987 .6047 Mdot
.53145 .57574 Mdot
.59989 .4891 Mdot
.80851 .35141 Mdot
.23992 .49866 Mdot
.43307 .5589 Mdot
.52875 .53238 Mdot
.66734 .4043 Mdot
.01317 .41649 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.48692 .01766 Mdot
.45835 .05583 Mdot
.36801 .16464 Mdot
.10162 .25257 Mdot
.69295 .11441 Mdot
.50783 .10716 Mdot
.33445 .23441 Mdot
.95515 .19339 Mdot
.64225 .07839 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50811 .60708 Mdot
.52584 .58323 Mdot
.58215 .51041 Mdot
.75628 .36298 Mdot
.16896 .49181 Mdot
.37319 .59732 Mdot
.40671 .06091 Mdot
.30816 .19871 Mdot
.98664 .18634 Mdot
.50063 .61718 Mdot
.50202 .6153 Mdot
.50644 .60933 Mdot
.52053 .59035 Mdot
.56531 .53149 Mdot
.70535 .38971 Mdot
.07478 .45651 Mdot
.33612 .58298 Mdot
.39285 .05694 Mdot
.30071 .19706 Mdot
.98185 .18028 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00354 Mdot
.49165 .01128 Mdot
.4734 .03582 Mdot
.41545 .11057 Mdot
.23654 .25759 Mdot
.81975 .12399 Mdot
.61914 .02357 Mdot
.581 .56972 Mdot
.65918 .44555 Mdot
.93826 .38974 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.5043 .61223 Mdot
.51369 .59956 Mdot
.54359 .55965 Mdot
.63805 .44713 Mdot
.91458 .37169 Mdot
.31318 .50776 Mdot
.49161 .51554 Mdot
.65745 .39224 Mdot
.02279 .4133 Mdot
.50067 .61713 Mdot
.50214 .61514 Mdot
.50683 .60881 Mdot
.52175 .58871 Mdot
.5692 .52656 Mdot
.71721 .38214 Mdot
.0989 .46803 Mdot
.34161 .5918 Mdot
.38405 .072 Mdot
.26754 .21865 Mdot
.91375 .14255 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50199 .61535 Mdot
.50634 .60947 Mdot
.52019 .59081 Mdot
.56425 .53285 Mdot
.70208 .39194 Mdot
.0679 .453 Mdot
.33493 .58003 Mdot
.39643 .05137 Mdot
.31331 .18739 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00172 Mdot
.49593 .00549 Mdot
.48705 .01749 Mdot
.45875 .0553 Mdot
.36928 .16331 Mdot
.10503 .25377 Mdot
.69443 .11512 Mdot
.50815 .10757 Mdot
.3341 .23499 Mdot
.95387 .19283 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48762 .01672 Mdot
.46057 .0529 Mdot
.37497 .15726 Mdot
.12052 .25861 Mdot
.70208 .1177 Mdot
.51164 .10692 Mdot
.33864 .23216 Mdot
.96299 .19816 Mdot
.64235 .0831 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.4986 .0019 Mdot
.49553 .00604 Mdot
.48575 .01924 Mdot
.45462 .06074 Mdot
.35634 .17656 Mdot
.07067 .23994 Mdot
.68244 .10549 Mdot
.51176 .09459 Mdot
.3587 .20904 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50583 .61015 Mdot
.51858 .59296 Mdot
.55915 .53938 Mdot
.68641 .40346 Mdot
.0336 .43438 Mdot
.33076 .56333 Mdot
.41927 .01697 Mdot
.39182 .10971 Mdot
.21432 .25356 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48872 .01524 Mdot
.46406 .04827 Mdot
.38596 .14518 Mdot
.15106 .26512 Mdot
.72209 .11983 Mdot
.5282 .09383 Mdot
.37637 .19726 Mdot
.05721 .24915 Mdot
.65406 .12761 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48772 .01659 Mdot
.46088 .05249 Mdot
.37594 .1562 Mdot
.12321 .25935 Mdot
.70357 .11804 Mdot
.51259 .10638 Mdot
.34046 .23073 Mdot
.96713 .20047 Mdot
.64276 .08517 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60223 Mdot
.53727 .568 Mdot
.61823 .4682 Mdot
.86066 .35491 Mdot
.28641 .49861 Mdot
.47964 .51743 Mdot
.64242 .40233 Mdot
.99143 .39439 Mdot
.50035 .61755 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51148 .60253 Mdot
.53656 .56894 Mdot
.616 .47067 Mdot
.85444 .35377 Mdot
.28203 .49834 Mdot
.4757 .52077 Mdot
.63307 .41129 Mdot
.96759 .38145 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50995 .6046 Mdot
.53168 .57543 Mdot
.60062 .48824 Mdot
.81063 .35127 Mdot
.24226 .49864 Mdot
.43544 .55686 Mdot
.53442 .52521 Mdot
.68462 .38994 Mdot
.05369 .43877 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48701 .01754 Mdot
.45863 .05546 Mdot
.36888 .16373 Mdot
.10397 .2534 Mdot
.69396 .11491 Mdot
.50803 .10746 Mdot
.33415 .23486 Mdot
.95414 .19293 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50755 .60784 Mdot
.52404 .58564 Mdot
.57644 .51747 Mdot
.73916 .37027 Mdot
.14005 .48398 Mdot
.35695 .59945 Mdot
.38702 .07758 Mdot
.26149 .22474 Mdot
.89785 .13641 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60459 Mdot
.53171 .57538 Mdot
.60073 .48811 Mdot
.81095 .35125 Mdot
.24261 .49864 Mdot
.43579 .55656 Mdot
.53525 .52415 Mdot
.68717 .38795 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50992 .60463 Mdot
.53161 .57552 Mdot
.60039 .48851 Mdot
.80996 .35131 Mdot
.24152 .49865 Mdot
.43469 .55751 Mdot
.53263 .52747 Mdot
.67916 .3943 Mdot
.04117 .43205 Mdot
.50051 .61735 Mdot
.50161 .61586 Mdot
.50514 .6111 Mdot
.51636 .59596 Mdot
.55208 .54853 Mdot
.66454 .42175 Mdot
.98213 .40522 Mdot
.32647 .53606 Mdot
.45911 .57355 Mdot
.53108 .54493 Mdot
.64936 .42591 Mdot
.50013 .61785 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.50431 .61221 Mdot
.51373 .59949 Mdot
.54373 .55946 Mdot
.63851 .44666 Mdot
.91581 .3722 Mdot
.31358 .50812 Mdot
.49142 .51607 Mdot
.65641 .39331 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50729 .60819 Mdot
.52322 .58674 Mdot
.57385 .5207 Mdot
.73134 .37417 Mdot
.12591 .4791 Mdot
.35071 .59807 Mdot
.38301 .07899 Mdot
.2552 .22646 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.4866 .01809 Mdot
.45732 .05719 Mdot
.36478 .168 Mdot
.09295 .24936 Mdot
.68949 .11235 Mdot
.50771 .10521 Mdot
.33748 .23102 Mdot
.96368 .19764 Mdot
.64389 .08169 Mdot
.50047 .6174 Mdot
.50149 .61601 Mdot
.50476 .6116 Mdot
.51517 .59756 Mdot
.54829 .55347 Mdot
.65276 .43262 Mdot
.95276 .38947 Mdot
.32259 .52193 Mdot
.47808 .54218 Mdot
.60081 .45485 Mdot
.86485 .34408 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56787 .52824 Mdot
.71316 .38463 Mdot
.09082 .46433 Mdot
.33952 .58914 Mdot
.38627 .06779 Mdot
.27657 .21329 Mdot
.93147 .1517 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60548 Mdot
.52962 .57818 Mdot
.59411 .49593 Mdot
.79168 .35342 Mdot
.21984 .49832 Mdot
.41354 .57458 Mdot
.48385 .58953 Mdot
.52996 .56193 Mdot
.62074 .46042 Mdot
.50083 .61692 Mdot
.50264 .61447 Mdot
.5084 .60669 Mdot
.52676 .582 Mdot
.58506 .50685 Mdot
.76495 .35996 Mdot
.18253 .49444 Mdot
.38251 .59374 Mdot
.42182 .0453 Mdot
.34853 .16546 Mdot
.08082 .2372 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48701 .01754 Mdot
.45864 .05545 Mdot
.36892 .16369 Mdot
.10406 .25343 Mdot
.694 .11493 Mdot
.50804 .10747 Mdot
.33415 .23487 Mdot
.95412 .19292 Mdot
.64196 .07809 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51332 .60005 Mdot
.54242 .56118 Mdot
.63441 .45087 Mdot
.90488 .36785 Mdot
.30969 .50514 Mdot
.49236 .51222 Mdot
.66357 .3859 Mdot
.03917 .42185 Mdot
.35661 .53751 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49386 .0083 Mdot
.48042 .0264 Mdot
.4377 .08269 Mdot
.30391 .22185 Mdot
.94494 .17182 Mdot
.66693 .04392 Mdot
.59586 .57837 Mdot
.66003 .45378 Mdot
.92581 .38746 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46802 .04301 Mdot
.39843 .13091 Mdot
.18661 .26691 Mdot
.75474 .11943 Mdot
.56151 .06381 Mdot
.45825 .10207 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51285 .60069 Mdot
.54091 .56318 Mdot
.62967 .45583 Mdot
.89213 .36331 Mdot
.30428 .50235 Mdot
.49146 .51027 Mdot
.66582 .38289 Mdot
.0463 .42521 Mdot
.3583 .53989 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50405 .61256 Mdot
.51292 .60059 Mdot
.54114 .56288 Mdot
.63039 .45508 Mdot
.89406 .36396 Mdot
.30516 .50273 Mdot
.49173 .51039 Mdot
.66591 .38296 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.5047 .61168 Mdot
.51498 .59782 Mdot
.54769 .55426 Mdot
.65088 .43442 Mdot
.94798 .38704 Mdot
.32173 .51986 Mdot
.48058 .53782 Mdot
.61038 .4435 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48994 .01359 Mdot
.46794 .04311 Mdot
.39819 .13119 Mdot
.18592 .26694 Mdot
.75401 .11944 Mdot
.56075 .06447 Mdot
.45644 .10436 Mdot
.28758 .24781 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51168 .60226 Mdot
.53719 .5681 Mdot
.618 .46846 Mdot
.86002 .35478 Mdot
.28597 .49857 Mdot
.47926 .51775 Mdot
.64152 .40317 Mdot
.98918 .39315 Mdot
.35306 .51083 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60311 Mdot
.5352 .57074 Mdot
.61173 .47545 Mdot
.84243 .3521 Mdot
.27272 .49815 Mdot
.4667 .52879 Mdot
.61111 .43395 Mdot
.90896 .35408 Mdot
.33605 .48058 Mdot
.50112 .61653 Mdot
.50356 .61323 Mdot
.51133 .60274 Mdot
.53607 .56958 Mdot
.61447 .47238 Mdot
.85014 .35309 Mdot
.27882 .49822 Mdot
.47268 .52342 Mdot
.62577 .41859 Mdot
.94848 .37166 Mdot
.34713 .49257 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50035 .61756 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51129 .60279 Mdot
.53594 .56975 Mdot
.61406 .47284 Mdot
.849 .35293 Mdot
.27795 .4982 Mdot
.47185 .52416 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58653 Mdot
.57435 .52008 Mdot
.73284 .3734 Mdot
.12867 .4801 Mdot
.35185 .59846 Mdot
.38352 .07902 Mdot
.25567 .22647 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49005 .01343 Mdot
.46832 .0426 Mdot
.39939 .12979 Mdot
.18939 .26676 Mdot
.75776 .11939 Mdot
.56458 .06115 Mdot
.46564 .09276 Mdot
.31555 .22797 Mdot
.94669 .17947 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00223 Mdot
.49475 .0071 Mdot
.48327 .02258 Mdot
.44673 .07105 Mdot
.33177 .19954 Mdot
.00891 .2078 Mdot
.67269 .07732 Mdot
.54758 .03386 Mdot
.49279 .04055 Mdot
.42717 .10573 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51236 .60134 Mdot
.53937 .56522 Mdot
.62482 .46101 Mdot
.8789 .35926 Mdot
.2976 .50026 Mdot
.48816 .51122 Mdot
.66099 .38615 Mdot
.03618 .41941 Mdot
.50105 .61662 Mdot
.50333 .61353 Mdot
.51062 .60369 Mdot
.53383 .57256 Mdot
.6074 .48038 Mdot
.83013 .35115 Mdot
.26196 .49827 Mdot
.45574 .53878 Mdot
.58398 .46448 Mdot
.83243 .33629 Mdot
.2883 .47958 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50687 .60876 Mdot
.52188 .58854 Mdot
.56961 .52605 Mdot
.71845 .38139 Mdot
.10134 .46912 Mdot
.34229 .59255 Mdot
.38353 .0731 Mdot
.26525 .21997 Mdot
.50058 .61725 Mdot
.50186 .61553 Mdot
.50591 .61004 Mdot
.51884 .59262 Mdot
.55996 .53834 Mdot
.68892 .40153 Mdot
.03923 .43753 Mdot
.3313 .56624 Mdot
.4151 .02324 Mdot
.37749 .12592 Mdot
.17375 .25685 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.5122 .60156 Mdot
.53886 .56589 Mdot
.62324 .46272 Mdot
.87454 .35809 Mdot
.29514 .49974 Mdot
.48655 .5122 Mdot
.65779 .38873 Mdot
.02882 .4153 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01026 Mdot
.47581 .03259 Mdot
.42307 .10117 Mdot
.25938 .24845 Mdot
.85738 .13323 Mdot
.6418 .01849 Mdot
.61188 .54114 Mdot
.73629 .39415 Mdot
.09855 .47978 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50891 .606 Mdot
.52839 .57981 Mdot
.59023 .50057 Mdot
.78028 .35569 Mdot
.20476 .49732 Mdot
.40008 .58398 Mdot
.45519 .00694 Mdot
.44395 .05783 Mdot
.35038 .17699 Mdot
.50099 .61669 Mdot
.50316 .61376 Mdot
.51007 .60444 Mdot
.53207 .5749 Mdot
.60186 .48679 Mdot
.81422 .35109 Mdot
.24614 .49859 Mdot
.43939 .55343 Mdot
.54392 .51323 Mdot
.71349 .36955 Mdot
.11555 .4675 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50888 .60603 Mdot
.5283 .57994 Mdot
.58995 .50092 Mdot
.77944 .35589 Mdot
.20359 .49721 Mdot
.39909 .58461 Mdot
.45317 .00937 Mdot
.438 .0654 Mdot
.33218 .19371 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01088 Mdot
.47433 .03458 Mdot
.41838 .10697 Mdot
.24531 .25445 Mdot
.8336 .1268 Mdot
.62844 .02023 Mdot
.59571 .55479 Mdot
.69804 .41504 Mdot
.02649 .43948 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50904 .60582 Mdot
.52881 .57926 Mdot
.59155 .49899 Mdot
.78418 .35483 Mdot
.21005 .49775 Mdot
.40467 .58093 Mdot
.4647 .61339 Mdot
.47222 .02097 Mdot
.43829 .07676 Mdot
.50027 .61767 Mdot
.50087 .61686 Mdot
.50276 .6143 Mdot
.50879 .60616 Mdot
.52801 .58032 Mdot
.58904 .50201 Mdot
.77676 .35655 Mdot
.19985 .49683 Mdot
.39596 .58656 Mdot
.4469 .01684 Mdot
.41965 .08821 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48859 .0154 Mdot
.46367 .04879 Mdot
.38473 .14655 Mdot
.14761 .2646 Mdot
.71948 .11976 Mdot
.52571 .09603 Mdot
.37032 .20338 Mdot
.04125 .24119 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01007 Mdot
.47626 .03199 Mdot
.4245 .09939 Mdot
.26368 .24639 Mdot
.86501 .13572 Mdot
.64541 .01891 Mdot
.61481 .5395 Mdot
.74188 .39215 Mdot
.10738 .48431 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49822 .00241 Mdot
.49432 .00768 Mdot
.4819 .02442 Mdot
.44238 .07668 Mdot
.31832 .21084 Mdot
.97718 .18975 Mdot
.67015 .06039 Mdot
.57245 .61355 Mdot
.5797 .54272 Mdot
.70155 .40196 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48783 .01643 Mdot
.46125 .052 Mdot
.3771 .15495 Mdot
.12639 .26019 Mdot
.7054 .1184 Mdot
.51384 .10558 Mdot
.343 .22865 Mdot
.97303 .20377 Mdot
.64333 .08814 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60044 Mdot
.5415 .5624 Mdot
.63152 .45389 Mdot
.89711 .36501 Mdot
.30651 .50335 Mdot
.49207 .5107 Mdot
.66574 .38335 Mdot
.04546 .42493 Mdot
.35791 .53984 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49822 .00241 Mdot
.49432 .00767 Mdot
.48191 .0244 Mdot
.44243 .07661 Mdot
.31847 .21071 Mdot
.97753 .18995 Mdot
.67018 .06057 Mdot
.57217 .61397 Mdot
.57875 .5439 Mdot
.6987 .40395 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00443 Mdot
.48954 .01412 Mdot
.4667 .04477 Mdot
.39425 .13575 Mdot
.17461 .26705 Mdot
.74252 .11966 Mdot
.5489 .07504 Mdot
.42747 .13998 Mdot
.20099 .28058 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46802 .04301 Mdot
.39842 .13092 Mdot
.18658 .26691 Mdot
.75472 .11943 Mdot
.56148 .06384 Mdot
.45819 .10215 Mdot
.29291 .24436 Mdot
.89753 .15579 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.49218 .01056 Mdot
.4751 .03355 Mdot
.42081 .10397 Mdot
.25258 .2515 Mdot
.84565 .12981 Mdot
.63562 .01875 Mdot
.60528 .54615 Mdot
.50054 .61731 Mdot
.50172 .61571 Mdot
.50547 .61064 Mdot
.51744 .59451 Mdot
.55551 .54408 Mdot
.67516 .41255 Mdot
.00764 .41963 Mdot
.32866 .54952 Mdot
.43952 .60425 Mdot
.46182 .02128 Mdot
.42739 .08628 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.49321 .00917 Mdot
.47837 .02917 Mdot
.43118 .091 Mdot
.28394 .2352 Mdot
.90337 .15103 Mdot
.65901 .02694 Mdot
.61541 .54712 Mdot
.73015 .40072 Mdot
.08177 .47323 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50866 .60633 Mdot
.5276 .58087 Mdot
.58773 .5036 Mdot
.77288 .35758 Mdot
.19431 .49618 Mdot
.39147 .58918 Mdot
.43815 .02705 Mdot
.39439 .11792 Mdot
.20359 .25924 Mdot
.50087 .61686 Mdot
.50276 .6143 Mdot
.5088 .60614 Mdot
.52804 .58028 Mdot
.58913 .5019 Mdot
.77704 .35648 Mdot
.20024 .49687 Mdot
.39628 .58636 Mdot
.44753 .01609 Mdot
.42149 .08596 Mdot
.28241 .23045 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50831 .60682 Mdot
.52646 .5824 Mdot
.58411 .508 Mdot
.76215 .36089 Mdot
.17822 .49368 Mdot
.37943 .59507 Mdot
.41659 .05086 Mdot
.3343 .17819 Mdot
.04598 .22023 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.50451 .61194 Mdot
.51436 .59865 Mdot
.54573 .55684 Mdot
.64475 .44039 Mdot
.93218 .37941 Mdot
.31829 .51358 Mdot
.4873 .52534 Mdot
.63729 .41327 Mdot
.96861 .38436 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46591 .04582 Mdot
.39178 .13859 Mdot
.16754 .26677 Mdot
.7359 .1198 Mdot
.54206 .08127 Mdot
.41056 .15988 Mdot
.15187 .28026 Mdot
.6984 .1404 Mdot
.49974 .00035 Mdot
.49916 .00113 Mdot
.49734 .0036 Mdot
.49152 .01145 Mdot
.47299 .03638 Mdot
.41413 .11218 Mdot
.23263 .25884 Mdot
.81381 .123 Mdot
.6148 .02557 Mdot
.57343 .57792 Mdot
.63833 .46522 Mdot
.88559 .36806 Mdot
.50024 .61771 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50779 .60751 Mdot
.52482 .5846 Mdot
.57891 .51441 Mdot
.74659 .36689 Mdot
.15294 .48784 Mdot
.36359 .59937 Mdot
.39379 .07266 Mdot
.27622 .2182 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52882 .57924 Mdot
.59159 .49894 Mdot
.7843 .3548 Mdot
.21021 .49776 Mdot
.40482 .58084 Mdot
.465 .61302 Mdot
.47312 .01979 Mdot
.44109 .07316 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.4977 .0031 Mdot
.49268 .00989 Mdot
.47668 .03142 Mdot
.42584 .09771 Mdot
.26773 .24434 Mdot
.87238 .13831 Mdot
.64859 .01972 Mdot
.61669 .53901 Mdot
.74455 .39155 Mdot
.11101 .48632 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48754 .01682 Mdot
.46032 .05323 Mdot
.37419 .15809 Mdot
.1184 .258 Mdot
.70094 .11741 Mdot
.51097 .10725 Mdot
.33743 .23309 Mdot
.96027 .19665 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00399 Mdot
.4906 .0127 Mdot
.47005 .0403 Mdot
.40485 .12335 Mdot
.20526 .2651 Mdot
.77632 .11957 Mdot
.58285 .04619 Mdot
.50811 .03868 Mdot
.44553 .0882 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48655 .01816 Mdot
.45717 .05738 Mdot
.36433 .16847 Mdot
.09174 .24888 Mdot
.68904 .11203 Mdot
.50777 .10483 Mdot
.33815 .23032 Mdot
.96548 .19857 Mdot
.64419 .08245 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50337 .61347 Mdot
.51075 .60351 Mdot
.53424 .57201 Mdot
.60871 .47889 Mdot
.83385 .35135 Mdot
.26535 .49821 Mdot
.45922 .5356 Mdot
.59261 .45451 Mdot
.85719 .33918 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54179 .56202 Mdot
.63242 .45294 Mdot
.89954 .36587 Mdot
.30754 .50388 Mdot
.49225 .51106 Mdot
.66533 .38391 Mdot
.04414 .42431 Mdot
.35759 .53941 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49105 .01209 Mdot
.47148 .03839 Mdot
.40937 .11794 Mdot
.21854 .26261 Mdot
.79362 .12057 Mdot
.59853 .03496 Mdot
.54196 .61454 Mdot
.54762 .57105 Mdot
.62365 .4676 Mdot
.50056 .61728 Mdot
.50178 .61562 Mdot
.50569 .61035 Mdot
.51812 .59359 Mdot
.55766 .5413 Mdot
.68181 .4071 Mdot
.02311 .42845 Mdot
.32987 .5578 Mdot
.42733 .00482 Mdot
.41952 .07629 Mdot
.29608 .2177 Mdot
.50021 .61776 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60904 Mdot
.52121 .58943 Mdot
.56749 .52872 Mdot
.71201 .38536 Mdot
.08848 .46322 Mdot
.33897 .58831 Mdot
.38706 .06641 Mdot
.2796 .21141 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49581 .00567 Mdot
.48664 .01804 Mdot
.45745 .05702 Mdot
.36519 .16758 Mdot
.09403 .24977 Mdot
.68989 .11262 Mdot
.50767 .10552 Mdot
.33693 .23159 Mdot
.96221 .19689 Mdot
.64364 .08108 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51018 .60429 Mdot
.53242 .57444 Mdot
.60295 .48552 Mdot
.81736 .35099 Mdot
.24944 .49854 Mdot
.44279 .55044 Mdot
.55215 .50295 Mdot
.73836 .3558 Mdot
.16266 .48168 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .0019 Mdot
.49551 .00606 Mdot
.48571 .01929 Mdot
.45449 .06091 Mdot
.35594 .17695 Mdot
.06963 .23946 Mdot
.68217 .10511 Mdot
.51209 .09392 Mdot
.36013 .20752 Mdot
.02435 .23001 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45726 .05726 Mdot
.36461 .16818 Mdot
.0925 .24918 Mdot
.68932 .11223 Mdot
.50773 .10507 Mdot
.33772 .23077 Mdot
.50008 .61792 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50873 .60624 Mdot
.52782 .58058 Mdot
.58843 .50275 Mdot
.77497 .35701 Mdot
.19731 .49655 Mdot
.39388 .5878 Mdot
.4428 .02166 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49725 .00371 Mdot
.49125 .01182 Mdot
.47213 .03752 Mdot
.41142 .11547 Mdot
.22459 .26114 Mdot
.80206 .12141 Mdot
.60561 .03054 Mdot
.55619 .59756 Mdot
.58933 .51903 Mdot
.74952 .37148 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01506 Mdot
.46449 .0477 Mdot
.38731 .14366 Mdot
.15486 .26562 Mdot
.72508 .11988 Mdot
.53112 .09122 Mdot
.38352 .18981 Mdot
.0764 .25795 Mdot
.65903 .13386 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60312 Mdot
.53519 .57076 Mdot
.61167 .47552 Mdot
.84226 .35208 Mdot
.27258 .49815 Mdot
.46656 .52892 Mdot
.61076 .43433 Mdot
.908 .35371 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.50551 .61059 Mdot
.51756 .59435 Mdot
.55588 .5436 Mdot
.67631 .41159 Mdot
.01035 .42118 Mdot
.32887 .55097 Mdot
.43738 .60754 Mdot
.45436 .03123 Mdot
.40383 .11506 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48853 .01549 Mdot
.46346 .04907 Mdot
.38406 .1473 Mdot
.14572 .26429 Mdot
.71809 .1197 Mdot
.52441 .09717 Mdot
.36719 .20649 Mdot
.03309 .23694 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00298 Mdot
.49298 .00948 Mdot
.47764 .03014 Mdot
.42886 .09392 Mdot
.2769 .23936 Mdot
.8896 .14503 Mdot
.65494 .02303 Mdot
.61768 .54164 Mdot
.74128 .39432 Mdot
.50007 .61794 Mdot
.50023 .61773 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50728 .6082 Mdot
.52318 .58679 Mdot
.57374 .52084 Mdot
.731 .37435 Mdot
.1253 .47887 Mdot
.35047 .59798 Mdot
.38291 .07897 Mdot
.50005 .61796 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50545 .61068 Mdot
.51735 .59462 Mdot
.55524 .54444 Mdot
.67432 .41326 Mdot
.00565 .4185 Mdot
.32851 .54845 Mdot
.44109 .60182 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50741 .60803 Mdot
.5236 .58623 Mdot
.57506 .5192 Mdot
.73497 .37231 Mdot
.13256 .48148 Mdot
.35351 .5989 Mdot
.38447 .07881 Mdot
.25695 .22621 Mdot
.89093 .13283 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50702 .60856 Mdot
.52235 .5879 Mdot
.57111 .52415 Mdot
.72301 .37873 Mdot
.11022 .47293 Mdot
.345 .59496 Mdot
.38234 .07634 Mdot
.25882 .22366 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49458 .00732 Mdot
.48274 .02329 Mdot
.44505 .07322 Mdot
.32658 .20401 Mdot
.99648 .20075 Mdot
.67166 .07072 Mdot
.55723 .0188 Mdot
.5268 .61211 Mdot
.5364 .57866 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00382 Mdot
.49099 .01216 Mdot
.47131 .03862 Mdot
.40883 .11859 Mdot
.21695 .26296 Mdot
.79146 .1204 Mdot
.59665 .0362 Mdot
.53808 .00123 Mdot
.53608 .5861 Mdot
.58775 .50882 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49014 .01332 Mdot
.46859 .04225 Mdot
.40023 .1288 Mdot
.19183 .2666 Mdot
.76046 .11937 Mdot
.56732 .05881 Mdot
.47216 .08449 Mdot
.33545 .21128 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.507 .60857 Mdot
.52231 .58796 Mdot
.57098 .52432 Mdot
.72261 .37895 Mdot
.10946 .47261 Mdot
.34475 .59477 Mdot
.3824 .07611 Mdot
.25925 .2234 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51485 .59799 Mdot
.54728 .5548 Mdot
.64961 .43564 Mdot
.94472 .38542 Mdot
.3211 .51849 Mdot
.48217 .53499 Mdot
.61654 .43635 Mdot
.91051 .35769 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00368 Mdot
.49132 .01172 Mdot
.47236 .03721 Mdot
.41216 .11457 Mdot
.22678 .26055 Mdot
.80521 .12179 Mdot
.60814 .02907 Mdot
.5611 .59184 Mdot
.60348 .50253 Mdot
.79037 .35971 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.4924 .01026 Mdot
.4758 .03261 Mdot
.42304 .1012 Mdot
.25929 .2485 Mdot
.85722 .13318 Mdot
.64172 .01849 Mdot
.61181 .54119 Mdot
.73614 .3942 Mdot
.09831 .47965 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60458 Mdot
.53174 .57534 Mdot
.60082 .488 Mdot
.81121 .35124 Mdot
.2429 .49864 Mdot
.43609 .55631 Mdot
.53596 .52325 Mdot
.68932 .38631 Mdot
.06426 .44427 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49658 .00461 Mdot
.48912 .0147 Mdot
.46534 .04657 Mdot
.38998 .14063 Mdot
.16243 .2664 Mdot
.73138 .11987 Mdot
.53743 .08549 Mdot
.39911 .17287 Mdot
.1194 .27347 Mdot
.67692 .14121 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01184 Mdot
.47208 .03759 Mdot
.41125 .11567 Mdot
.22409 .26127 Mdot
.80135 .12133 Mdot
.60503 .03088 Mdot
.55506 .59888 Mdot
.58605 .52294 Mdot
.7399 .3757 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00183 Mdot
.49568 .00584 Mdot
.48624 .01858 Mdot
.45617 .0587 Mdot
.36119 .17168 Mdot
.0834 .24551 Mdot
.68616 .10967 Mdot
.5087 .10161 Mdot
.34429 .22401 Mdot
.98184 .20721 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51013 .60435 Mdot
.53227 .57465 Mdot
.60247 .48608 Mdot
.81598 .35103 Mdot
.248 .49856 Mdot
.4413 .55175 Mdot
.54855 .50744 Mdot
.50038 .61752 Mdot
.50122 .61638 Mdot
.50389 .61277 Mdot
.51241 .60129 Mdot
.53951 .56504 Mdot
.62526 .46054 Mdot
.88009 .3596 Mdot
.29825 .50041 Mdot
.48856 .51101 Mdot
.66173 .38558 Mdot
.03784 .42033 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.51219 .60157 Mdot
.53884 .56592 Mdot
.62315 .46281 Mdot
.87431 .35803 Mdot
.295 .49971 Mdot
.48645 .51226 Mdot
.6576 .38889 Mdot
.02836 .41504 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00383 Mdot
.49098 .01219 Mdot
.47125 .03869 Mdot
.40864 .11881 Mdot
.2164 .26308 Mdot
.79073 .12034 Mdot
.59601 .03663 Mdot
.53674 .00288 Mdot
.53208 .59137 Mdot
.57522 .52421 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49584 .00562 Mdot
.48674 .01791 Mdot
.45776 .05661 Mdot
.36617 .16657 Mdot
.09666 .25076 Mdot
.69091 .11327 Mdot
.50764 .1062 Mdot
.33581 .23281 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00552 Mdot
.48697 .01759 Mdot
.45851 .05561 Mdot
.36853 .1641 Mdot
.10302 .25307 Mdot
.69355 .11471 Mdot
.50794 .10735 Mdot
.33424 .2347 Mdot
.95448 .19308 Mdot
.64207 .07818 Mdot
.50116 .61647 Mdot
.50369 .61304 Mdot
.51177 .60214 Mdot
.53749 .56771 Mdot
.61892 .46744 Mdot
.86258 .3553 Mdot
.2877 .49872 Mdot
.48075 .51652 Mdot
.645 .39994 Mdot
.99789 .39798 Mdot
.35394 .51516 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52558 .58357 Mdot
.58134 .51141 Mdot
.75386 .36391 Mdot
.16504 .49093 Mdot
.3707 .59803 Mdot
.40306 .06441 Mdot
.29885 .20506 Mdot
.96705 .17473 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48744 .01695 Mdot
.46001 .05364 Mdot
.37322 .15912 Mdot
.11576 .25722 Mdot
.69956 .11702 Mdot
.51021 .10756 Mdot
.33617 .23401 Mdot
.95754 .19511 Mdot
.64185 .08034 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00399 Mdot
.49059 .0127 Mdot
.47004 .04031 Mdot
.40482 .12338 Mdot
.20518 .26512 Mdot
.77621 .11957 Mdot
.58275 .04627 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47747 .03037 Mdot
.42834 .09458 Mdot
.2753 .24026 Mdot
.88655 .14377 Mdot
.65392 .02231 Mdot
.61783 .54082 Mdot
.74277 .39342 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48717 .01732 Mdot
.45914 .05479 Mdot
.37049 .16203 Mdot
.10832 .25487 Mdot
.69592 .11576 Mdot
.50861 .10778 Mdot
.33422 .23515 Mdot
.95375 .19287 Mdot
.64168 .0782 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00176 Mdot
.49584 .00562 Mdot
.48674 .01789 Mdot
.45779 .05657 Mdot
.36626 .16647 Mdot
.09691 .25086 Mdot
.69101 .11333 Mdot
.50764 .10626 Mdot
.33571 .23292 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49167 .01125 Mdot
.47348 .03572 Mdot
.41568 .11029 Mdot
.23722 .25736 Mdot
.82081 .12418 Mdot
.61988 .02325 Mdot
.58226 .56838 Mdot
.6626 .44253 Mdot
.94657 .39393 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49791 .00283 Mdot
.49333 .00901 Mdot
.47876 .02864 Mdot
.43243 .08942 Mdot
.28774 .23283 Mdot
.91101 .15457 Mdot
.66092 .02954 Mdot
.61312 .55132 Mdot
.72107 .4062 Mdot
.06382 .46379 Mdot
.50037 .61754 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51184 .60204 Mdot
.53772 .5674 Mdot
.61965 .46663 Mdot
.86463 .35573 Mdot
.28905 .49885 Mdot
.48188 .51561 Mdot
.6476 .39757 Mdot
.00432 .40158 Mdot
.50098 .61671 Mdot
.50312 .61381 Mdot
.50995 .6046 Mdot
.53169 .57541 Mdot
.60066 .48819 Mdot
.81075 .35127 Mdot
.24239 .49864 Mdot
.43557 .55675 Mdot
.53472 .52482 Mdot
.68555 .38921 Mdot
.0558 .43988 Mdot
.50005 .61797 Mdot
.50015 .61784 Mdot
.50047 .6174 Mdot
.50148 .61603 Mdot
.50473 .61165 Mdot
.51507 .5977 Mdot
.54797 .5539 Mdot
.65174 .43359 Mdot
.95017 .38815 Mdot
.32213 .5208 Mdot
.47946 .53979 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48856 .01545 Mdot
.46355 .04895 Mdot
.38435 .14698 Mdot
.14653 .26443 Mdot
.71868 .11973 Mdot
.52496 .09669 Mdot
.36852 .20518 Mdot
.03654 .23875 Mdot
.65023 .11926 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .00091 Mdot
.49786 .00289 Mdot
.49318 .00921 Mdot
.47828 .02929 Mdot
.43089 .09137 Mdot
.28305 .23574 Mdot
.90162 .15023 Mdot
.65854 .02639 Mdot
.61584 .54627 Mdot
.73195 .39968 Mdot
.50132 .61625 Mdot
.50422 .61234 Mdot
.51344 .59989 Mdot
.54279 .5607 Mdot
.63556 .44969 Mdot
.90795 .36903 Mdot
.31085 .50592 Mdot
.49225 .5131 Mdot
.66203 .38753 Mdot
.03501 .41972 Mdot
.35589 .53579 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00284 Mdot
.49329 .00906 Mdot
.47863 .02882 Mdot
.432 .08995 Mdot
.28645 .23365 Mdot
.90841 .15334 Mdot
.66029 .02862 Mdot
.61398 .5498 Mdot
.72438 .40416 Mdot
.50106 .6166 Mdot
.50338 .61346 Mdot
.51077 .60348 Mdot
.53432 .57192 Mdot
.60894 .47863 Mdot
.8345 .3514 Mdot
.26593 .4982 Mdot
.45983 .53505 Mdot
.5941 .45281 Mdot
.86143 .33998 Mdot
.31134 .4767 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48873 .01522 Mdot
.46409 .04823 Mdot
.38606 .14506 Mdot
.15135 .26516 Mdot
.72232 .11984 Mdot
.52841 .09364 Mdot
.3769 .19672 Mdot
.05861 .24983 Mdot
.65438 .12812 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48971 .0139 Mdot
.46722 .04408 Mdot
.3959 .13385 Mdot
.17933 .26708 Mdot
.74718 .11956 Mdot
.55372 .0707 Mdot
.43933 .12559 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50745 .60796 Mdot
.52375 .58603 Mdot
.57553 .51861 Mdot
.73641 .3716 Mdot
.13514 .48236 Mdot
.35466 .59914 Mdot
.38524 .07851 Mdot
.2582 .22586 Mdot
.89275 .13379 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47927 .02795 Mdot
.43405 .08736 Mdot
.2927 .22962 Mdot
.92116 .15949 Mdot
.6631 .03339 Mdot
.60907 .55804 Mdot
.70614 .41607 Mdot
.03292 .44637 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.5112 .6029 Mdot
.53569 .5701 Mdot
.61325 .47375 Mdot
.84671 .35261 Mdot
.27617 .49817 Mdot
.47011 .52571 Mdot
.61949 .42506 Mdot
.93174 .36369 Mdot
.34327 .48662 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48684 .01777 Mdot
.45809 .05617 Mdot
.3672 .16549 Mdot
.09944 .25179 Mdot
.69204 .11392 Mdot
.5077 .10679 Mdot
.33492 .23382 Mdot
.95659 .19407 Mdot
.64257 .07888 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50703 .60854 Mdot
.52239 .58785 Mdot
.57123 .524 Mdot
.72338 .37851 Mdot
.11093 .47323 Mdot
.34524 .59513 Mdot
.38229 .07655 Mdot
.25843 .22388 Mdot
.89618 .13432 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49849 .00205 Mdot
.49518 .00652 Mdot
.48463 .02074 Mdot
.45107 .06539 Mdot
.34527 .18728 Mdot
.04226 .22599 Mdot
.6766 .09386 Mdot
.52472 .07104 Mdot
.40978 .15026 Mdot
.16665 .27803 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48972 .01388 Mdot
.46726 .04402 Mdot
.39604 .13369 Mdot
.17972 .26708 Mdot
.74757 .11955 Mdot
.55413 .07034 Mdot
.44032 .12437 Mdot
.23908 .27157 Mdot
.79967 .13115 Mdot
.50127 .61632 Mdot
.50403 .61258 Mdot
.51285 .60069 Mdot
.54092 .56317 Mdot
.6297 .4558 Mdot
.89219 .36333 Mdot
.30431 .50237 Mdot
.49147 .51027 Mdot
.66583 .38289 Mdot
.04631 .42521 Mdot
.3583 .53989 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49807 .0026 Mdot
.49387 .00829 Mdot
.48046 .02636 Mdot
.43781 .08256 Mdot
.30422 .22162 Mdot
.94563 .17219 Mdot
.66701 .04425 Mdot
.59541 .57904 Mdot
.6585 .45522 Mdot
.92194 .38572 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51085 .60338 Mdot
.53456 .5716 Mdot
.60969 .47777 Mdot
.83664 .35155 Mdot
.26782 .49818 Mdot
.46175 .53329 Mdot
.59886 .44743 Mdot
.87491 .34304 Mdot
.31986 .47659 Mdot
.49966 .00046 Mdot
.49893 .00145 Mdot
.49658 .00462 Mdot
.4891 .01472 Mdot
.46528 .04665 Mdot
.38979 .14085 Mdot
.16189 .26636 Mdot
.73091 .11987 Mdot
.53695 .08592 Mdot
.39793 .17419 Mdot
.11609 .27252 Mdot
.67515 .14099 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50224 .61501 Mdot
.50713 .60841 Mdot
.52271 .58743 Mdot
.57223 .52274 Mdot
.72643 .37681 Mdot
.11674 .47558 Mdot
.34723 .59644 Mdot
.38216 .07794 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00478 Mdot
.48874 .01521 Mdot
.46413 .04818 Mdot
.38618 .14492 Mdot
.15169 .2652 Mdot
.72258 .11984 Mdot
.52867 .09341 Mdot
.37753 .19607 Mdot
.06028 .25063 Mdot
.65476 .12872 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50406 .61254 Mdot
.51294 .60056 Mdot
.54122 .56277 Mdot
.63064 .45481 Mdot
.89475 .36419 Mdot
.30548 .50287 Mdot
.49182 .51044 Mdot
.66591 .38302 Mdot
.04617 .42522 Mdot
.49996 5e-05 Mdot
.49989 .00016 Mdot
.49963 .00049 Mdot
.49883 .00157 Mdot
.49629 .00502 Mdot
.48817 .01597 Mdot
.46233 .05057 Mdot
.3805 .15124 Mdot
.13579 .2624 Mdot
.71123 .11921 Mdot
.51834 .10224 Mdot
.35292 .22 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.5134 .59994 Mdot
.54267 .56086 Mdot
.63519 .45006 Mdot
.90697 .36865 Mdot
.31048 .50567 Mdot
.4923 .5128 Mdot
.66256 .38697 Mdot
.03643 .42045 Mdot
.50017 .6178 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.5055 .6106 Mdot
.51752 .59439 Mdot
.55578 .54373 Mdot
.67601 .41184 Mdot
.00963 .42077 Mdot
.32882 .55059 Mdot
.43795 .60667 Mdot
.45634 .0286 Mdot
.5002 .61776 Mdot
.50064 .61716 Mdot
.50205 .61526 Mdot
.50654 .60919 Mdot
.52085 .58992 Mdot
.56634 .53019 Mdot
.70848 .38763 Mdot
.08128 .45975 Mdot
.33739 .58561 Mdot
.38986 .06172 Mdot
.28999 .20463 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46026 .05331 Mdot
.37401 .15828 Mdot
.1179 .25786 Mdot
.70068 .11734 Mdot
.51082 .10732 Mdot
.33716 .23329 Mdot
.9597 .19632 Mdot
.64204 .08144 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54283 .56064 Mdot
.6357 .44954 Mdot
.90833 .36918 Mdot
.31099 .50602 Mdot
.49223 .51322 Mdot
.66182 .38775 Mdot
.03443 .41942 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49038 .01299 Mdot
.46935 .04123 Mdot
.40264 .12597 Mdot
.19882 .26595 Mdot
.76851 .1194 Mdot
.57532 .05215 Mdot
.49093 .06055 Mdot
.39295 .15248 Mdot
.14624 .26976 Mdot
.50047 .6174 Mdot
.50149 .61603 Mdot
.50473 .61164 Mdot
.51508 .59768 Mdot
.54801 .55384 Mdot
.65187 .43347 Mdot
.95051 .38832 Mdot
.32219 .52095 Mdot
.47928 .5401 Mdot
.60538 .44939 Mdot
.87826 .34722 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51225 .6015 Mdot
.53901 .5657 Mdot
.62369 .46223 Mdot
.87579 .35842 Mdot
.29586 .49988 Mdot
.48704 .51188 Mdot
.65879 .38791 Mdot
.03114 .4166 Mdot
.35708 .53199 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49178 .0111 Mdot
.47382 .03526 Mdot
.41677 .10895 Mdot
.24049 .25623 Mdot
.8259 .12515 Mdot
.62341 .02187 Mdot
.58803 .56239 Mdot
.67807 .42966 Mdot
.98287 .41381 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01559 Mdot
.46324 .04936 Mdot
.38337 .14806 Mdot
.1438 .26396 Mdot
.7167 .11963 Mdot
.52313 .09827 Mdot
.36413 .20947 Mdot
.02521 .23274 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.4993 .00094 Mdot
.49779 .00299 Mdot
.49294 .00953 Mdot
.47752 .0303 Mdot
.4285 .09437 Mdot
.2758 .23999 Mdot
.88749 .14416 Mdot
.65424 .02252 Mdot
.6178 .54106 Mdot
.74235 .39368 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00526 Mdot
.48759 .01676 Mdot
.46048 .05302 Mdot
.3747 .15755 Mdot
.11978 .2584 Mdot
.70168 .1176 Mdot
.5114 .10704 Mdot
.3382 .23251 Mdot
.96199 .19761 Mdot
.64226 .0826 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49149 .0115 Mdot
.47289 .03651 Mdot
.41382 .11255 Mdot
.23171 .25912 Mdot
.81244 .12279 Mdot
.61376 .02608 Mdot
.57157 .57998 Mdot
.63315 .47044 Mdot
.87196 .36414 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50893 .60597 Mdot
.52844 .57975 Mdot
.59039 .50038 Mdot
.78076 .35558 Mdot
.20542 .49738 Mdot
.40065 .58362 Mdot
.45633 .00556 Mdot
.44735 .05348 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.4966 .0046 Mdot
.48916 .01464 Mdot
.46546 .04641 Mdot
.39036 .14021 Mdot
.1635 .26649 Mdot
.73231 .11986 Mdot
.53838 .08462 Mdot
.40146 .17025 Mdot
.12599 .27522 Mdot
.68066 .14146 Mdot
.50112 .61653 Mdot
.50355 .61323 Mdot
.51132 .60274 Mdot
.53606 .5696 Mdot
.61443 .47242 Mdot
.85004 .35308 Mdot
.27875 .49822 Mdot
.47261 .52349 Mdot
.6256 .41877 Mdot
.94802 .37143 Mdot
.34703 .49239 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00335 Mdot
.49209 .01068 Mdot
.47481 .03393 Mdot
.41991 .10509 Mdot
.24986 .25264 Mdot
.84109 .1286 Mdot
.633 .01916 Mdot
.602 .54898 Mdot
.71373 .40525 Mdot
.05803 .45786 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00192 Mdot
.49548 .0061 Mdot
.48561 .01943 Mdot
.45418 .06132 Mdot
.35496 .17793 Mdot
.06707 .23828 Mdot
.68153 .10418 Mdot
.51296 .09218 Mdot
.36381 .20359 Mdot
.0344 .23523 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49741 .00349 Mdot
.49176 .01113 Mdot
.47375 .03536 Mdot
.41654 .10923 Mdot
.2398 .25647 Mdot
.82482 .12493 Mdot
.62267 .02214 Mdot
.58685 .5636 Mdot
.67493 .43217 Mdot
.97567 .4097 Mdot
.50086 .61687 Mdot
.50275 .61431 Mdot
.50877 .60619 Mdot
.52794 .58042 Mdot
.5888 .50231 Mdot
.77605 .35673 Mdot
.19885 .49672 Mdot
.39513 .58706 Mdot
.44526 .01877 Mdot
.41488 .09398 Mdot
.26282 .24104 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50484 .61149 Mdot
.51543 .5972 Mdot
.54914 .55237 Mdot
.65539 .43013 Mdot
.95942 .39292 Mdot
.32366 .52494 Mdot
.47429 .54868 Mdot
.58651 .47237 Mdot
.82219 .33975 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49329 .00906 Mdot
.47863 .02882 Mdot
.432 .08996 Mdot
.28644 .23365 Mdot
.90839 .15333 Mdot
.66029 .02862 Mdot
.61398 .54979 Mdot
.72441 .40414 Mdot
.0705 .46738 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50366 .61308 Mdot
.51167 .60227 Mdot
.53718 .56811 Mdot
.61796 .4685 Mdot
.8599 .35476 Mdot
.28589 .49857 Mdot
.47919 .51781 Mdot
.64136 .40332 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00475 Mdot
.48879 .01513 Mdot
.4643 .04795 Mdot
.38672 .14432 Mdot
.1532 .26541 Mdot
.72376 .11986 Mdot
.52981 .09239 Mdot
.38033 .19316 Mdot
.06778 .25412 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00543 Mdot
.48718 .0173 Mdot
.45919 .05472 Mdot
.37065 .16186 Mdot
.10875 .25502 Mdot
.69613 .11584 Mdot
.50869 .1078 Mdot
.33427 .23514 Mdot
.95381 .19292 Mdot
.64167 .07825 Mdot
.50049 .61737 Mdot
.50158 .61591 Mdot
.50502 .61125 Mdot
.51599 .59646 Mdot
.5509 .55007 Mdot
.66087 .42507 Mdot
.9731 .40024 Mdot
.32549 .5315 Mdot
.4655 .56323 Mdot
.55418 .51397 Mdot
.72257 .36861 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51255 .60109 Mdot
.53997 .56443 Mdot
.6267 .45899 Mdot
.88404 .36075 Mdot
.30033 .50098 Mdot
.48973 .51049 Mdot
.66374 .38409 Mdot
.04227 .42282 Mdot
.35814 .5376 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.49551 .00607 Mdot
.48569 .01932 Mdot
.45442 .061 Mdot
.35572 .17717 Mdot
.06906 .2392 Mdot
.68202 .10491 Mdot
.51228 .09354 Mdot
.36093 .20667 Mdot
.02654 .23116 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48858 .01542 Mdot
.46364 .04884 Mdot
.38462 .14667 Mdot
.1473 .26455 Mdot
.71925 .11975 Mdot
.52549 .09622 Mdot
.3698 .20391 Mdot
.03986 .24048 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51204 .60177 Mdot
.53835 .56656 Mdot
.62163 .46446 Mdot
.87012 .35698 Mdot
.29251 .4993 Mdot
.48463 .51352 Mdot
.65374 .39215 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .00239 Mdot
.49436 .00762 Mdot
.48204 .02423 Mdot
.44284 .07609 Mdot
.31972 .2097 Mdot
.98042 .19159 Mdot
.67041 .06211 Mdot
.56991 .6174 Mdot
.57093 .55381 Mdot
.67485 .4224 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48953 .01415 Mdot
.46664 .04485 Mdot
.39407 .13596 Mdot
.17408 .26703 Mdot
.74201 .11968 Mdot
.54837 .07552 Mdot
.42618 .14153 Mdot
.19718 .28102 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49118 .01191 Mdot
.47191 .03782 Mdot
.41071 .11632 Mdot
.2225 .26167 Mdot
.79911 .12109 Mdot
.60317 .032 Mdot
.55139 .60322 Mdot
.57536 .53594 Mdot
.70818 .39346 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00367 Mdot
.49136 .01168 Mdot
.47246 .03708 Mdot
.41247 .11419 Mdot
.2277 .26029 Mdot
.80654 .12196 Mdot
.6092 .02848 Mdot
.56312 .58952 Mdot
.60925 .49601 Mdot
.8067 .35773 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51003 .60449 Mdot
.53195 .57507 Mdot
.60147 .48724 Mdot
.81311 .35114 Mdot
.24495 .49861 Mdot
.43818 .55449 Mdot
.54099 .51692 Mdot
.7046 .37533 Mdot
.0973 .46002 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.4862 .01863 Mdot
.45606 .05885 Mdot
.36083 .17204 Mdot
.08246 .24511 Mdot
.68586 .10939 Mdot
.50886 .10118 Mdot
.34515 .22314 Mdot
.98411 .20843 Mdot
.50129 .61628 Mdot
.50413 .61246 Mdot
.51314 .60029 Mdot
.54186 .56193 Mdot
.63264 .45271 Mdot
.90013 .36609 Mdot
.30779 .50401 Mdot
.49228 .51117 Mdot
.66519 .38408 Mdot
.04373 .42412 Mdot
.3575 .53926 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50639 .6094 Mdot
.52037 .59057 Mdot
.56481 .53213 Mdot
.7038 .39076 Mdot
.07153 .45486 Mdot
.33554 .5816 Mdot
.39449 .05438 Mdot
.30651 .19272 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60801 Mdot
.52364 .58617 Mdot
.5752 .51902 Mdot
.73541 .37209 Mdot
.13335 .48175 Mdot
.35386 .59898 Mdot
.38469 .07873 Mdot
.2573 .22612 Mdot
.89142 .1331 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00297 Mdot
.49299 .00947 Mdot
.47766 .03011 Mdot
.42894 .09382 Mdot
.27715 .23922 Mdot
.89008 .14523 Mdot
.6551 .02315 Mdot
.61764 .54179 Mdot
.74101 .39448 Mdot
.50075 .61702 Mdot
.50238 .61481 Mdot
.5076 .60777 Mdot
.52421 .58542 Mdot
.57698 .5168 Mdot
.74077 .36951 Mdot
.1429 .48489 Mdot
.35834 .59955 Mdot
.38825 .07681 Mdot
.26397 .22378 Mdot
.90188 .13847 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00294 Mdot
.49307 .00936 Mdot
.47792 .02976 Mdot
.42976 .09279 Mdot
.27963 .23778 Mdot
.8949 .14727 Mdot
.6566 .02441 Mdot
.6171 .54342 Mdot
.73784 .3963 Mdot
.0966 .48046 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50704 .60853 Mdot
.52242 .58781 Mdot
.57133 .52387 Mdot
.72369 .37834 Mdot
.11152 .47347 Mdot
.34543 .59528 Mdot
.38225 .07671 Mdot
.25813 .22407 Mdot
.50024 .6177 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.50791 .60735 Mdot
.5252 .58409 Mdot
.58012 .51291 Mdot
.75022 .36537 Mdot
.15904 .48946 Mdot
.36707 .59886 Mdot
.3981 .06897 Mdot
.28651 .21264 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46592 .0458 Mdot
.39181 .13855 Mdot
.16763 .26677 Mdot
.73598 .1198 Mdot
.54214 .08119 Mdot
.41078 .15964 Mdot
.15248 .28034 Mdot
.69888 .14034 Mdot
.5013 .61627 Mdot
.50415 .61242 Mdot
.51323 .60017 Mdot
.54214 .56156 Mdot
.63351 .45181 Mdot
.90247 .36695 Mdot
.30874 .50455 Mdot
.49235 .51164 Mdot
.6645 .38488 Mdot
.04176 .42315 Mdot
.35709 .53853 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48761 .01673 Mdot
.46053 .05295 Mdot
.37485 .15738 Mdot
.1202 .25852 Mdot
.70191 .11766 Mdot
.51153 .10697 Mdot
.33845 .23232 Mdot
.96255 .19792 Mdot
.64231 .08288 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01007 Mdot
.47626 .032 Mdot
.42448 .09941 Mdot
.26363 .24641 Mdot
.86493 .13569 Mdot
.64537 .0189 Mdot
.61479 .53951 Mdot
.74184 .39216 Mdot
.10731 .48427 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48866 .01531 Mdot
.46389 .0485 Mdot
.38541 .14579 Mdot
.14952 .26489 Mdot
.72092 .1198 Mdot
.52707 .09483 Mdot
.37362 .20006 Mdot
.04992 .24558 Mdot
.65256 .12484 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49836 .00222 Mdot
.49476 .00708 Mdot
.48331 .02253 Mdot
.44686 .07088 Mdot
.33217 .19919 Mdot
.00988 .20834 Mdot
.67277 .07783 Mdot
.54685 .03502 Mdot
.49018 .04412 Mdot
.41879 .11618 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00487 Mdot
.48851 .01552 Mdot
.4634 .04914 Mdot
.38389 .14749 Mdot
.14525 .26421 Mdot
.71775 .11969 Mdot
.52409 .09744 Mdot
.36643 .20724 Mdot
.03111 .23589 Mdot
.64943 .11684 Mdot
.50103 .61664 Mdot
.50329 .61358 Mdot
.51049 .60386 Mdot
.53342 .57311 Mdot
.60611 .48186 Mdot
.82644 .35101 Mdot
.25849 .49835 Mdot
.45215 .54204 Mdot
.5751 .47497 Mdot
.80658 .33665 Mdot
.26186 .48379 Mdot
.50056 .61728 Mdot
.50179 .61562 Mdot
.5057 .61034 Mdot
.51816 .59354 Mdot
.55779 .54114 Mdot
.68221 .40678 Mdot
.02402 .42897 Mdot
.32994 .55829 Mdot
.42662 .0059 Mdot
.41708 .07934 Mdot
.28871 .22254 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50703 .60854 Mdot
.52239 .58785 Mdot
.57122 .52401 Mdot
.72336 .37853 Mdot
.11089 .47321 Mdot
.34522 .59512 Mdot
.38229 .07653 Mdot
.25845 .22387 Mdot
.89622 .13434 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.5076 .60777 Mdot
.52421 .58541 Mdot
.577 .51678 Mdot
.74083 .36948 Mdot
.143 .48492 Mdot
.35839 .59955 Mdot
.38829 .07678 Mdot
.26407 .22375 Mdot
.90204 .13856 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51057 .60375 Mdot
.53368 .57276 Mdot
.60693 .48093 Mdot
.82877 .35109 Mdot
.2607 .4983 Mdot
.45444 .53997 Mdot
.5001 .61789 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.51081 .60344 Mdot
.53442 .57179 Mdot
.60925 .47827 Mdot
.83538 .35146 Mdot
.26671 .49819 Mdot
.46062 .53432 Mdot
.59607 .45057 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60848 Mdot
.52252 .58768 Mdot
.57164 .52348 Mdot
.72464 .3778 Mdot
.11333 .47421 Mdot
.34604 .5957 Mdot
.38218 .07719 Mdot
.25728 .22458 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60315 Mdot
.53511 .57087 Mdot
.61142 .4758 Mdot
.84156 .35201 Mdot
.272 .49815 Mdot
.46598 .52944 Mdot
.60932 .43588 Mdot
.90405 .35222 Mdot
.33414 .47962 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00373 Mdot
.4912 .01188 Mdot
.47198 .03772 Mdot
.41095 .11603 Mdot
.22321 .26149 Mdot
.80011 .1212 Mdot
.60401 .03149 Mdot
.55305 .60125 Mdot
.5802 .53001 Mdot
.72263 .38464 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50438 .61212 Mdot
.51394 .59922 Mdot
.54439 .5586 Mdot
.64056 .44458 Mdot
.92121 .37449 Mdot
.31528 .5098 Mdot
.49041 .51868 Mdot
.65117 .39868 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00561 Mdot
.48676 .01788 Mdot
.45783 .05651 Mdot
.3664 .16632 Mdot
.09729 .251 Mdot
.69116 .11342 Mdot
.50764 .10634 Mdot
.33558 .23306 Mdot
.95847 .195 Mdot
.64295 .07959 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .01331 Mdot
.46862 .04221 Mdot
.40031 .1287 Mdot
.19207 .26658 Mdot
.76073 .11937 Mdot
.56759 .05858 Mdot
.4728 .08368 Mdot
.33741 .20952 Mdot
.9984 .20804 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50686 .60877 Mdot
.52185 .58858 Mdot
.56952 .52616 Mdot
.71817 .38156 Mdot
.1008 .46888 Mdot
.34214 .59238 Mdot
.38364 .07286 Mdot
.26574 .21969 Mdot
.91028 .14085 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50723 .60827 Mdot
.52303 .58699 Mdot
.57325 .52146 Mdot
.72951 .37514 Mdot
.12253 .47783 Mdot
.34938 .59754 Mdot
.38254 .07877 Mdot
.25508 .22624 Mdot
.88901 .13149 Mdot
.5007 .61708 Mdot
.50224 .61501 Mdot
.50714 .60839 Mdot
.52275 .58736 Mdot
.57238 .52255 Mdot
.72688 .37656 Mdot
.11759 .47592 Mdot
.34753 .59662 Mdot
.38219 .0781 Mdot
.25582 .22554 Mdot
.89088 .13213 Mdot
.50014 .61785 Mdot
.50044 .61744 Mdot
.50139 .61615 Mdot
.50443 .61204 Mdot
.51413 .59897 Mdot
.54498 .55782 Mdot
.6424 .44273 Mdot
.92605 .37662 Mdot
.31667 .5114 Mdot
.48921 .5214 Mdot
.64557 .40449 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49092 .01226 Mdot
.47109 .03892 Mdot
.40811 .11945 Mdot
.21485 .26341 Mdot
.78865 .12019 Mdot
.59417 .03789 Mdot
.53286 .00764 Mdot
.52049 .60673 Mdot
.53878 .57114 Mdot
.50044 .61744 Mdot
.5014 .61614 Mdot
.50448 .61199 Mdot
.51426 .59879 Mdot
.5454 .55727 Mdot
.64372 .44142 Mdot
.92949 .37817 Mdot
.3176 .5126 Mdot
.48819 .52354 Mdot
.64108 .40922 Mdot
.97896 .38977 Mdot
.50073 .61705 Mdot
.50231 .61491 Mdot
.50736 .60809 Mdot
.52346 .58642 Mdot
.57462 .51975 Mdot
.73364 .37298 Mdot
.13014 .48063 Mdot
.35247 .59864 Mdot
.38385 .07897 Mdot
.25607 .22641 Mdot
.88973 .13217 Mdot
.50003 .61799 Mdot
.5001 .61789 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51075 .60351 Mdot
.53425 .57201 Mdot
.60872 .47888 Mdot
.83388 .35135 Mdot
.26538 .49821 Mdot
.45925 .53557 Mdot
.50117 .61646 Mdot
.50371 .61302 Mdot
.51183 .60206 Mdot
.53767 .56746 Mdot
.61951 .46679 Mdot
.86422 .35564 Mdot
.28878 .49883 Mdot
.48166 .51579 Mdot
.6471 .39802 Mdot
.00308 .40088 Mdot
.35444 .51778 Mdot
.50023 .61772 Mdot
.50074 .61703 Mdot
.50236 .61485 Mdot
.50752 .60788 Mdot
.52395 .58576 Mdot
.57618 .5178 Mdot
.73837 .37065 Mdot
.13865 .48353 Mdot
.35628 .59938 Mdot
.38647 .0779 Mdot
.26043 .22512 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00366 Mdot
.49137 .01166 Mdot
.47251 .03701 Mdot
.41263 .114 Mdot
.22816 .26016 Mdot
.80721 .12205 Mdot
.60973 .02819 Mdot
.56412 .58838 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.4948 .00702 Mdot
.48345 .02234 Mdot
.44731 .0703 Mdot
.33356 .19797 Mdot
.01324 .21023 Mdot
.67308 .07959 Mdot
.54431 .03904 Mdot
.48115 .05647 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00514 Mdot
.48788 .01636 Mdot
.46141 .05178 Mdot
.37762 .15438 Mdot
.12783 .26055 Mdot
.70625 .11854 Mdot
.51445 .10517 Mdot
.34428 .22757 Mdot
.97606 .20546 Mdot
.64361 .08967 Mdot
.501 .61669 Mdot
.50317 .61374 Mdot
.51012 .60437 Mdot
.53222 .57471 Mdot
.60232 .48626 Mdot
.81554 .35105 Mdot
.24753 .49857 Mdot
.44083 .55217 Mdot
.54739 .50889 Mdot
.72399 .36331 Mdot
.13614 .47468 Mdot
.50055 .61729 Mdot
.50175 .61567 Mdot
.50558 .6105 Mdot
.51776 .59407 Mdot
.55654 .54274 Mdot
.67837 .40989 Mdot
.01514 .42391 Mdot
.32924 .55354 Mdot
.43359 .61334 Mdot
.44118 .0486 Mdot
.36255 .16077 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56063 Mdot
.63573 .44951 Mdot
.90841 .36921 Mdot
.31102 .50604 Mdot
.49222 .51325 Mdot
.66177 .3878 Mdot
.0343 .41935 Mdot
.5001 .6179 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .60419 Mdot
.53265 .57413 Mdot
.60369 .48466 Mdot
.81949 .35096 Mdot
.25162 .4985 Mdot
.44504 .54844 Mdot
.55764 .49616 Mdot
.49986 .00018 Mdot
.49957 .00059 Mdot
.49862 .00187 Mdot
.4956 .00595 Mdot
.48597 .01894 Mdot
.45533 .05981 Mdot
.35856 .17434 Mdot
.07647 .24254 Mdot
.68404 .10748 Mdot
.51013 .0981 Mdot
.35141 .21669 Mdot
.00079 .21742 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.4899 .01364 Mdot
.46784 .04325 Mdot
.39787 .13156 Mdot
.18499 .26697 Mdot
.75302 .11945 Mdot
.55975 .06536 Mdot
.454 .10741 Mdot
.28021 .25231 Mdot
.87197 .14601 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50665 .60905 Mdot
.5212 .58945 Mdot
.56745 .52878 Mdot
.71186 .38545 Mdot
.08819 .46309 Mdot
.3389 .58821 Mdot
.38716 .06623 Mdot
.27999 .21117 Mdot
.93832 .1554 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48838 .0157 Mdot
.46298 .04971 Mdot
.38255 .14898 Mdot
.1415 .26354 Mdot
.71508 .11953 Mdot
.52167 .09951 Mdot
.36066 .2128 Mdot
.01634 .22792 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50768 .60766 Mdot
.52446 .58508 Mdot
.57778 .51581 Mdot
.74318 .3684 Mdot
.14709 .48616 Mdot
.36046 .59957 Mdot
.39033 .07536 Mdot
.2684 .22192 Mdot
.90933 .14234 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00437 Mdot
.48969 .01392 Mdot
.46716 .04415 Mdot
.39573 .13404 Mdot
.17886 .26709 Mdot
.7467 .11957 Mdot
.55323 .07114 Mdot
.43812 .12708 Mdot
.2325 .27373 Mdot
.7896 .13073 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .6049 Mdot
.53099 .57635 Mdot
.59843 .4908 Mdot
.8043 .35176 Mdot
.23513 .49866 Mdot
.42828 .56293 Mdot
.51744 .54679 Mdot
.63272 .43753 Mdot
.50029 .61764 Mdot
.50092 .61678 Mdot
.50295 .61405 Mdot
.50939 .60536 Mdot
.5299 .5778 Mdot
.595 .49486 Mdot
.7943 .353 Mdot
.22314 .49844 Mdot
.41664 .57224 Mdot
.49073 .58083 Mdot
.55094 .53441 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48699 .01756 Mdot
.45859 .05552 Mdot
.36875 .16386 Mdot
.10362 .25328 Mdot
.69381 .11484 Mdot
.508 .10742 Mdot
.33418 .23481 Mdot
.95426 .19298 Mdot
.64201 .07812 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45944 .0544 Mdot
.37142 .16105 Mdot
.11084 .25569 Mdot
.69712 .11622 Mdot
.50907 .10782 Mdot
.33462 .23499 Mdot
.9544 .19329 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48821 .01592 Mdot
.46245 .05041 Mdot
.38087 .15082 Mdot
.13684 .26262 Mdot
.71191 .11928 Mdot
.51892 .10178 Mdot
.35424 .21879 Mdot
.00022 .219 Mdot
.64587 .10192 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49857 .00193 Mdot
.49544 .00616 Mdot
.48548 .0196 Mdot
.45378 .06185 Mdot
.3537 .17916 Mdot
.06381 .23675 Mdot
.68075 .10295 Mdot
.51416 .08984 Mdot
.3688 .19815 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48717 .01732 Mdot
.45915 .05478 Mdot
.37051 .16201 Mdot
.10837 .25489 Mdot
.69595 .11577 Mdot
.50862 .10778 Mdot
.33423 .23515 Mdot
.95375 .19287 Mdot
.50021 .61776 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60903 Mdot
.52123 .58941 Mdot
.56755 .52865 Mdot
.71218 .38525 Mdot
.08883 .46339 Mdot
.33905 .58844 Mdot
.38694 .06662 Mdot
.27914 .2117 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .61231 Mdot
.51349 .59982 Mdot
.54297 .56046 Mdot
.63613 .4491 Mdot
.90947 .36963 Mdot
.3114 .50633 Mdot
.49215 .5136 Mdot
.66113 .38846 Mdot
.50002 .61801 Mdot
.50006 .61795 Mdot
.50019 .61777 Mdot
.50062 .6172 Mdot
.50197 .61538 Mdot
.50627 .60957 Mdot
.51997 .59111 Mdot
.56354 .53375 Mdot
.69991 .39346 Mdot
.06328 .45059 Mdot
.33421 .57796 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60849 Mdot
.52251 .58769 Mdot
.57162 .52351 Mdot
.72456 .37784 Mdot
.1132 .47416 Mdot
.34599 .59567 Mdot
.38218 .07715 Mdot
.25734 .22454 Mdot
.89402 .1334 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48949 .0142 Mdot
.46652 .04501 Mdot
.3937 .13639 Mdot
.17302 .26701 Mdot
.74099 .1197 Mdot
.54731 .07648 Mdot
.42357 .14464 Mdot
.18953 .28167 Mdot
.73378 .13489 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.49671 .00445 Mdot
.48951 .01417 Mdot
.46658 .04493 Mdot
.39388 .13618 Mdot
.17354 .26702 Mdot
.74149 .11969 Mdot
.54783 .07601 Mdot
.42485 .14312 Mdot
.19328 .28139 Mdot
.73798 .13427 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.4884 .01567 Mdot
.46305 .04962 Mdot
.38276 .14874 Mdot
.14209 .26365 Mdot
.7155 .11956 Mdot
.52204 .09919 Mdot
.36154 .21196 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51041 .60398 Mdot
.53314 .57348 Mdot
.60524 .48287 Mdot
.82394 .35096 Mdot
.25607 .4984 Mdot
.44964 .54432 Mdot
.56891 .48241 Mdot
.78836 .33913 Mdot
.23964 .48636 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49737 .00356 Mdot
.49161 .01134 Mdot
.47326 .036 Mdot
.41501 .1111 Mdot
.23524 .25801 Mdot
.81776 .12364 Mdot
.6177 .0242 Mdot
.57854 .57234 Mdot
.65247 .45164 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00544 Mdot
.48718 .01731 Mdot
.45917 .05475 Mdot
.37059 .16193 Mdot
.10858 .25496 Mdot
.69605 .11581 Mdot
.50866 .10779 Mdot
.33425 .23514 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.5113 .60277 Mdot
.53599 .56969 Mdot
.61421 .47267 Mdot
.84942 .35299 Mdot
.27827 .49821 Mdot
.47216 .52389 Mdot
.62449 .4199 Mdot
.94508 .36999 Mdot
.34643 .49127 Mdot
.50013 .61785 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50432 .6122 Mdot
.51376 .59946 Mdot
.54381 .55936 Mdot
.63876 .44641 Mdot
.91645 .37246 Mdot
.31379 .50831 Mdot
.49132 .51635 Mdot
.65585 .39388 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48091 .02575 Mdot
.43925 .0807 Mdot
.30868 .21833 Mdot
.9554 .17753 Mdot
.66815 .04907 Mdot
.58876 .58902 Mdot
.63571 .4779 Mdot
.86245 .36568 Mdot
.50055 .6173 Mdot
.50174 .61569 Mdot
.50554 .61055 Mdot
.51764 .59423 Mdot
.55615 .54326 Mdot
.67714 .4109 Mdot
.01228 .42228 Mdot
.32902 .55201 Mdot
.43585 .60988 Mdot
.44904 .03829 Mdot
.38707 .13442 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50477 .6116 Mdot
.51518 .59754 Mdot
.54834 .55342 Mdot
.65289 .43249 Mdot
.9531 .38964 Mdot
.32265 .52208 Mdot
.4779 .54251 Mdot
.6001 .4557 Mdot
.5007 .61708 Mdot
.50224 .61501 Mdot
.50713 .6084 Mdot
.52272 .58741 Mdot
.57227 .52269 Mdot
.72655 .37674 Mdot
.11696 .47567 Mdot
.34731 .59649 Mdot
.38217 .07798 Mdot
.25599 .22542 Mdot
.89125 .13227 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00387 Mdot
.49086 .01234 Mdot
.4709 .03917 Mdot
.40753 .12015 Mdot
.21311 .26375 Mdot
.78635 .12004 Mdot
.59212 .03933 Mdot
.52849 .01305 Mdot
.50737 .00622 Mdot
.4973 .00873 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46506 .04695 Mdot
.3891 .14164 Mdot
.15993 .26618 Mdot
.72925 .11988 Mdot
.53527 .08745 Mdot
.39377 .17879 Mdot
.10448 .26884 Mdot
.66949 .13977 Mdot
.50118 .61644 Mdot
.50377 .61294 Mdot
.512 .60183 Mdot
.53823 .56673 Mdot
.62124 .46489 Mdot
.86902 .35672 Mdot
.29184 .4992 Mdot
.48412 .5139 Mdot
.65261 .39312 Mdot
.01653 .40842 Mdot
.35569 .5246 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52129 .58933 Mdot
.56774 .5284 Mdot
.71277 .38488 Mdot
.09002 .46395 Mdot
.33933 .58886 Mdot
.38653 .06733 Mdot
.27759 .21266 Mdot
.93349 .15279 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50832 .6068 Mdot
.52649 .58236 Mdot
.58422 .50788 Mdot
.76245 .36078 Mdot
.17869 .49377 Mdot
.37976 .59493 Mdot
.41715 .05028 Mdot
.3358 .17689 Mdot
.04958 .22212 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00536 Mdot
.48737 .01705 Mdot
.45977 .05395 Mdot
.37248 .15992 Mdot
.11372 .2566 Mdot
.69853 .1167 Mdot
.5097 .10772 Mdot
.3354 .23453 Mdot
.95593 .19419 Mdot
.64172 .0795 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49788 .00286 Mdot
.49325 .00912 Mdot
.4785 .02898 Mdot
.43161 .09045 Mdot
.28525 .23439 Mdot
.49992 .00011 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49726 .00371 Mdot
.49126 .01181 Mdot
.47215 .03749 Mdot
.41149 .11538 Mdot
.22481 .26108 Mdot
.80237 .12145 Mdot
.60586 .03039 Mdot
.5567 .59697 Mdot
.59078 .5173 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49277 .00977 Mdot
.47697 .03104 Mdot
.42674 .09658 Mdot
.27047 .24291 Mdot
.87743 .14018 Mdot
.6506 .02049 Mdot
.61745 .53926 Mdot
.74492 .39179 Mdot
.11099 .48654 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00696 Mdot
.48357 .02216 Mdot
.44771 .06977 Mdot
.33482 .19686 Mdot
.0163 .21194 Mdot
.67337 .08117 Mdot
.54204 .04264 Mdot
.5013 .61627 Mdot
.50416 .61242 Mdot
.51324 .60016 Mdot
.54216 .56153 Mdot
.63358 .45173 Mdot
.90266 .36702 Mdot
.30882 .5046 Mdot
.49236 .51168 Mdot
.66444 .38495 Mdot
.04158 .42306 Mdot
.35706 .53846 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50364 .61311 Mdot
.51161 .60236 Mdot
.53697 .5684 Mdot
.61727 .46926 Mdot
.858 .3544 Mdot
.28457 .49848 Mdot
.47802 .51879 Mdot
.6386 .40593 Mdot
.98179 .38909 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48983 .01374 Mdot
.4676 .04356 Mdot
.39712 .13243 Mdot
.18283 .26703 Mdot
.75076 .11949 Mdot
.55742 .06741 Mdot
.44836 .11445 Mdot
.26318 .26148 Mdot
.84009 .13695 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48895 .01492 Mdot
.46481 .04728 Mdot
.38831 .14253 Mdot
.1577 .26595 Mdot
.72739 .11989 Mdot
.5334 .08915 Mdot
.38915 .1838 Mdot
.09176 .26423 Mdot
.50009 .61791 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50296 .61404 Mdot
.50943 .6053 Mdot
.53003 .57763 Mdot
.59541 .49438 Mdot
.79548 .35282 Mdot
.22461 .49849 Mdot
.41803 .57117 Mdot
.49387 .57685 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50669 .609 Mdot
.52132 .58929 Mdot
.56782 .52831 Mdot
.71299 .38474 Mdot
.09048 .46417 Mdot
.33944 .58902 Mdot
.38638 .0676 Mdot
.27701 .21302 Mdot
.93233 .15216 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50592 .61004 Mdot
.51885 .59261 Mdot
.55999 .5383 Mdot
.689 .40146 Mdot
.03943 .43764 Mdot
.33131 .56634 Mdot
.41495 .02345 Mdot
.37701 .12646 Mdot
.17239 .25681 Mdot
.50111 .61654 Mdot
.50353 .61326 Mdot
.51125 .60284 Mdot
.53583 .56991 Mdot
.61369 .47325 Mdot
.84795 .35278 Mdot
.27714 .49818 Mdot
.47106 .52486 Mdot
.62182 .42264 Mdot
.93797 .36658 Mdot
.34483 .4887 Mdot
.5003 .61762 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50982 .60477 Mdot
.53127 .57597 Mdot
.59934 .48974 Mdot
.80692 .35153 Mdot
.23813 .49867 Mdot
.43127 .56042 Mdot
.52449 .53781 Mdot
.65429 .41615 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49188 .01097 Mdot
.47414 .03484 Mdot
.41777 .10772 Mdot
.24348 .25514 Mdot
.83066 .12614 Mdot
.62656 .02079 Mdot
.59292 .55749 Mdot
.69088 .42001 Mdot
.01128 .43046 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00665 Mdot
.48431 .02118 Mdot
.45004 .06674 Mdot
.34206 .19028 Mdot
.03418 .22172 Mdot
.67542 .09008 Mdot
.52967 .06273 Mdot
.42817 .12709 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00328 Mdot
.49226 .01046 Mdot
.47534 .03323 Mdot
.42157 .10303 Mdot
.25487 .2505 Mdot
.84955 .13089 Mdot
.63777 .01854 Mdot
.60777 .54413 Mdot
.72735 .39808 Mdot
.08325 .47178 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48813 .01602 Mdot
.4622 .05073 Mdot
.38011 .15166 Mdot
.13473 .26217 Mdot
.71053 .11913 Mdot
.51777 .10269 Mdot
.35161 .22117 Mdot
.99375 .21538 Mdot
.64526 .09865 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49428 .00773 Mdot
.48176 .0246 Mdot
.44196 .07722 Mdot
.31701 .21189 Mdot
.97417 .18804 Mdot
.66991 .05879 Mdot
.57479 .61002 Mdot
.58776 .53272 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00249 Mdot
.49414 .00792 Mdot
.48132 .0252 Mdot
.44054 .07905 Mdot
.31265 .21531 Mdot
.96427 .18246 Mdot
.66904 .0536 Mdot
.58232 .59868 Mdot
.61364 .50205 Mdot
.8013 .36211 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48978 .01381 Mdot
.46743 .04379 Mdot
.39658 .13306 Mdot
.18128 .26706 Mdot
.74916 .11952 Mdot
.55577 .06887 Mdot
.44434 .11942 Mdot
.25111 .26696 Mdot
.81915 .13313 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48958 .01407 Mdot
.46682 .0446 Mdot
.39465 .13529 Mdot
.17574 .26707 Mdot
.74362 .11964 Mdot
.55004 .07401 Mdot
.43028 .1366 Mdot
.20926 .27934 Mdot
.75729 .13195 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50497 .61131 Mdot
.51585 .59665 Mdot
.55045 .55066 Mdot
.65947 .42635 Mdot
.96962 .39836 Mdot
.32507 .52979 Mdot
.46785 .5594 Mdot
.56273 .50274 Mdot
.74928 .35519 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00312 Mdot
.49263 .00995 Mdot
.47653 .03164 Mdot
.42534 .09834 Mdot
.26622 .24512 Mdot
.86961 .13732 Mdot
.64743 .01937 Mdot
.61609 .53907 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00468 Mdot
.48895 .01492 Mdot
.46482 .04727 Mdot
.38834 .1425 Mdot
.15777 .26595 Mdot
.72745 .11989 Mdot
.53346 .08909 Mdot
.38931 .18364 Mdot
.09217 .26439 Mdot
.66438 .13769 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50974 .60488 Mdot
.53103 .5763 Mdot
.59856 .49066 Mdot
.80465 .35173 Mdot
.23554 .49867 Mdot
.42868 .56259 Mdot
.51839 .54557 Mdot
.63564 .43451 Mdot
.49982 .00024 Mdot
.49943 .00076 Mdot
.4982 .00243 Mdot
.49426 .00775 Mdot
.48172 .02465 Mdot
.44183 .07738 Mdot
.31662 .21219 Mdot
.97329 .18755 Mdot
.66984 .05833 Mdot
.57546 .609 Mdot
.59009 .52987 Mdot
.73274 .38319 Mdot
.49979 .00029 Mdot
.49932 .00093 Mdot
.49782 .00295 Mdot
.49305 .00939 Mdot
.47786 .02985 Mdot
.42956 .09304 Mdot
.27903 .23813 Mdot
.89372 .14677 Mdot
.65625 .02409 Mdot
.61726 .54299 Mdot
.73869 .39582 Mdot
.09825 .48122 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.50292 .6141 Mdot
.50929 .60549 Mdot
.52959 .57822 Mdot
.59401 .49605 Mdot
.79138 .35346 Mdot
.21946 .4983 Mdot
.41319 .57484 Mdot
.48307 .59051 Mdot
.52762 .56503 Mdot
.50032 .6176 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51042 .60396 Mdot
.5332 .5734 Mdot
.60541 .48267 Mdot
.82444 .35097 Mdot
.25656 .49839 Mdot
.45015 .54386 Mdot
.57017 .48089 Mdot
.79207 .33847 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50407 .61253 Mdot
.51298 .60051 Mdot
.54134 .56261 Mdot
.63102 .45441 Mdot
.89576 .36454 Mdot
.30592 .50307 Mdot
.49194 .51054 Mdot
.66586 .38314 Mdot
.04594 .42513 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48977 .01382 Mdot
.46741 .04382 Mdot
.3965 .13315 Mdot
.18106 .26707 Mdot
.74894 .11953 Mdot
.55554 .06908 Mdot
.44377 .12013 Mdot
.2494 .26767 Mdot
.8163 .13274 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47747 .03036 Mdot
.42835 .09457 Mdot
.27533 .24025 Mdot
.88659 .14379 Mdot
.65394 .02232 Mdot
.61783 .54083 Mdot
.74275 .39344 Mdot
.10616 .48471 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49651 .00471 Mdot
.48889 .015 Mdot
.46461 .04754 Mdot
.38769 .14323 Mdot
.15594 .26575 Mdot
.72595 .11988 Mdot
.53198 .09044 Mdot
.38564 .18757 Mdot
.08215 .26039 Mdot
.66083 .1354 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51084 .6034 Mdot
.53452 .57165 Mdot
.60957 .47791 Mdot
.8363 .35153 Mdot
.26751 .49818 Mdot
.46144 .53358 Mdot
.5981 .44828 Mdot
.87276 .3425 Mdot
.31859 .47655 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.4973 .00364 Mdot
.49141 .0116 Mdot
.47264 .03684 Mdot
.41304 .1135 Mdot
.22939 .25981 Mdot
.80901 .12229 Mdot
.61114 .02743 Mdot
.56675 .58538 Mdot
.61959 .48465 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49513 .00657 Mdot
.4845 .02092 Mdot
.45064 .06595 Mdot
.34394 .18853 Mdot
.03888 .22422 Mdot
.67608 .0923 Mdot
.52673 .06764 Mdot
.41729 .14091 Mdot
.1893 .27785 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.47611 .0322 Mdot
.42402 .09999 Mdot
.26222 .2471 Mdot
.86241 .13485 Mdot
.64421 .01872 Mdot
.61393 .53993 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.5055 .6106 Mdot
.51753 .59438 Mdot
.5558 .54371 Mdot
.67606 .4118 Mdot
.00976 .42084 Mdot
.32883 .55066 Mdot
.43784 .60682 Mdot
.45598 .02908 Mdot
.40893 .10897 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.5123 .60142 Mdot
.53918 .56546 Mdot
.62425 .46163 Mdot
.87732 .35883 Mdot
.29672 .50006 Mdot
.48761 .51154 Mdot
.65992 .387 Mdot
.03375 .41805 Mdot
.35733 .5333 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01428 Mdot
.46631 .04529 Mdot
.39303 .13715 Mdot
.17112 .26694 Mdot
.7392 .11974 Mdot
.54546 .07816 Mdot
.41899 .15006 Mdot
.17619 .28202 Mdot
.71987 .13711 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49768 .00314 Mdot
.49259 .01001 Mdot
.4764 .0318 Mdot
.42495 .09882 Mdot
.26505 .24571 Mdot
.86749 .13657 Mdot
.64651 .01914 Mdot
.61554 .53922 Mdot
.74307 .39181 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49384 .00831 Mdot
.48039 .02645 Mdot
.4376 .08282 Mdot
.30359 .22209 Mdot
.94424 .17145 Mdot
.66684 .04359 Mdot
.5963 .5777 Mdot
.66157 .45235 Mdot
.92965 .38924 Mdot
.50046 .61741 Mdot
.50148 .61603 Mdot
.50471 .61167 Mdot
.51502 .59776 Mdot
.54782 .55409 Mdot
.65128 .43404 Mdot
.94899 .38756 Mdot
.32192 .52029 Mdot
.48007 .53872 Mdot
.60839 .44583 Mdot
.88703 .34967 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.5131 .60035 Mdot
.54172 .56212 Mdot
.6322 .45318 Mdot
.89894 .36566 Mdot
.30729 .50375 Mdot
.49221 .51097 Mdot
.66545 .38375 Mdot
.04452 .42449 Mdot
.35768 .53954 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49464 .00724 Mdot
.48292 .02305 Mdot
.44563 .07248 Mdot
.32835 .2025 Mdot
.0007 .20315 Mdot
.672 .07297 Mdot
.55392 .02394 Mdot
.51519 .00988 Mdot
.4992 .01062 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50741 .60803 Mdot
.5236 .58623 Mdot
.57506 .5192 Mdot
.73498 .37231 Mdot
.13257 .48148 Mdot
.35351 .5989 Mdot
.38447 .07881 Mdot
.25695 .22621 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49748 .0034 Mdot
.49199 .01082 Mdot
.47447 .03439 Mdot
.41883 .10642 Mdot
.24664 .25393 Mdot
.83577 .1273 Mdot
.6298 .01987 Mdot
.59765 .55295 Mdot
.70295 .41181 Mdot
.03664 .44547 Mdot
.50105 .61661 Mdot
.50336 .6135 Mdot
.51069 .60359 Mdot
.53406 .57226 Mdot
.60812 .47956 Mdot
.83217 .35125 Mdot
.26384 .49824 Mdot
.45768 .53701 Mdot
.58877 .45892 Mdot
.84622 .33753 Mdot
.30009 .47783 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50504 .61123 Mdot
.51604 .59638 Mdot
.55107 .54985 Mdot
.6614 .42458 Mdot
.97442 .40096 Mdot
.32564 .53216 Mdot
.4646 .56471 Mdot
.55088 .51834 Mdot
.71218 .37494 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.49831 .00229 Mdot
.49461 .00729 Mdot
.48282 .02318 Mdot
.44531 .07289 Mdot
.32738 .20334 Mdot
.99837 .20183 Mdot
.67181 .07173 Mdot
.55574 .0211 Mdot
.5216 .00114 Mdot
.51975 .60091 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .60131 Mdot
.53946 .5651 Mdot
.62511 .4607 Mdot
.87968 .35948 Mdot
.29802 .50036 Mdot
.48842 .51108 Mdot
.66148 .38578 Mdot
.03728 .42002 Mdot
.35767 .53507 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49822 .00241 Mdot
.49432 .00767 Mdot
.48192 .02439 Mdot
.44245 .07659 Mdot
.31851 .21068 Mdot
.97763 .19001 Mdot
.67019 .06063 Mdot
.57209 .61409 Mdot
.57848 .54425 Mdot
.69786 .40455 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46277 .04998 Mdot
.38189 .1497 Mdot
.13968 .26319 Mdot
.71382 .11944 Mdot
.52056 .10044 Mdot
.35805 .21527 Mdot
.00974 .22429 Mdot
.64683 .10667 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.5127 .60089 Mdot
.54045 .56379 Mdot
.62822 .45737 Mdot
.88817 .36203 Mdot
.3024 .50164 Mdot
.49073 .51024 Mdot
.66515 .38317 Mdot
.04517 .42448 Mdot
.5009 .61681 Mdot
.50288 .61415 Mdot
.50917 .60565 Mdot
.52921 .57873 Mdot
.59281 .49748 Mdot
.78786 .35409 Mdot
.21492 .49807 Mdot
.40903 .57789 Mdot
.47399 .60189 Mdot
.50011 .6018 Mdot
.52638 .57745 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49622 .00511 Mdot
.48794 .01628 Mdot
.4616 .05154 Mdot
.37821 .15375 Mdot
.12944 .26094 Mdot
.70722 .1187 Mdot
.51516 .10466 Mdot
.34582 .22627 Mdot
.97971 .20751 Mdot
.64396 .09152 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51287 .60065 Mdot
.541 .56306 Mdot
.62994 .45554 Mdot
.89286 .36355 Mdot
.30462 .50249 Mdot
.49157 .51031 Mdot
.66588 .3829 Mdot
.04634 .42525 Mdot
.35827 .53995 Mdot
.50065 .61716 Mdot
.50207 .61523 Mdot
.5066 .60911 Mdot
.52103 .58967 Mdot
.56693 .52944 Mdot
.71028 .38647 Mdot
.08496 .46154 Mdot
.33817 .58702 Mdot
.38836 .0642 Mdot
.28448 .2083 Mdot
.94745 .16046 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00215 Mdot
.49494 .00684 Mdot
.48387 .02177 Mdot
.44864 .06857 Mdot
.33769 .19428 Mdot
.02334 .21584 Mdot
.67411 .08475 Mdot
.53697 .05079 Mdot
.45479 .09214 Mdot
.50062 .6172 Mdot
.50197 .61538 Mdot
.50626 .60958 Mdot
.51995 .59113 Mdot
.56347 .53384 Mdot
.6997 .3936 Mdot
.06284 .45036 Mdot
.33415 .57776 Mdot
.39932 .04695 Mdot
.32335 .17911 Mdot
.03355 .20998 Mdot
.50002 .61801 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50051 .61735 Mdot
.50162 .61584 Mdot
.50517 .61105 Mdot
.51646 .59582 Mdot
.5524 .54812 Mdot
.66553 .42087 Mdot
.98454 .40656 Mdot
.32671 .5373 Mdot
.49962 .00052 Mdot
.49878 .00164 Mdot
.49612 .00524 Mdot
.48765 .01668 Mdot
.46066 .05278 Mdot
.37526 .15694 Mdot
.12133 .25883 Mdot
.70253 .1178 Mdot
.51191 .10677 Mdot
.33916 .23176 Mdot
.96416 .19881 Mdot
.64247 .08368 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49553 .00603 Mdot
.48577 .0192 Mdot
.4547 .06064 Mdot
.35659 .17631 Mdot
.07132 .24023 Mdot
.68261 .10572 Mdot
.51156 .09501 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61346 Mdot
.51079 .60347 Mdot
.53435 .57187 Mdot
.60905 .4785 Mdot
.83482 .35142 Mdot
.26621 .4982 Mdot
.46011 .53479 Mdot
.59481 .45201 Mdot
.86345 .34038 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46506 .04694 Mdot
.38911 .14162 Mdot
.15996 .26618 Mdot
.72927 .11988 Mdot
.5353 .08743 Mdot
.39383 .17872 Mdot
.10466 .2689 Mdot
.66957 .1398 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50726 .60823 Mdot
.52311 .58688 Mdot
.57352 .52112 Mdot
.73032 .37471 Mdot
.12403 .4784 Mdot
.34996 .59779 Mdot
.38273 .0789 Mdot
.25507 .22637 Mdot
.8888 .13146 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.5083 .60682 Mdot
.52644 .58243 Mdot
.58405 .50808 Mdot
.76197 .36095 Mdot
.17794 .49363 Mdot
.37924 .59514 Mdot
.41627 .0512 Mdot
.33343 .17893 Mdot
.04391 .21913 Mdot
.50037 .61754 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51191 .60195 Mdot
.53793 .56712 Mdot
.62032 .4659 Mdot
.86648 .35614 Mdot
.29024 .49899 Mdot
.48285 .51485 Mdot
.6498 .39559 Mdot
.00972 .4046 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50785 .60744 Mdot
.52499 .58436 Mdot
.57948 .51371 Mdot
.74828 .36617 Mdot
.15581 .48862 Mdot
.3652 .59917 Mdot
.39572 .07104 Mdot
.28078 .21583 Mdot
.93156 .15432 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49732 .00361 Mdot
.49148 .01151 Mdot
.47285 .03656 Mdot
.41369 .11271 Mdot
.23132 .25924 Mdot
.81186 .1227 Mdot
.61333 .0263 Mdot
.57078 .58085 Mdot
.63094 .4727 Mdot
.86609 .3627 Mdot
.50028 .61765 Mdot
.5009 .61682 Mdot
.50286 .61417 Mdot
.50911 .60573 Mdot
.52902 .57897 Mdot
.59223 .49818 Mdot
.78616 .35442 Mdot
.21269 .49793 Mdot
.40701 .57931 Mdot
.46966 .60727 Mdot
.48708 .0012 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.5065 .60925 Mdot
.5207 .59011 Mdot
.56588 .53077 Mdot
.70707 .38856 Mdot
.07837 .45831 Mdot
.3368 .58445 Mdot
.39114 .05965 Mdot
.29464 .20143 Mdot
.96872 .17262 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48936 .01437 Mdot
.4661 .04556 Mdot
.39238 .1379 Mdot
.16926 .26686 Mdot
.73747 .11977 Mdot
.54367 .07979 Mdot
.41457 .15524 Mdot
.16338 .28147 Mdot
.70795 .13904 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51032 .60409 Mdot
.53288 .57383 Mdot
.6044 .48384 Mdot
.82154 .35095 Mdot
.2537 .49845 Mdot
.44718 .54652 Mdot
.56289 .48973 Mdot
.77049 .34341 Mdot
.21485 .48737 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61273 Mdot
.5125 .60116 Mdot
.53981 .56464 Mdot
.62621 .45952 Mdot
.88269 .36035 Mdot
.29963 .50078 Mdot
.48936 .51064 Mdot
.66313 .38453 Mdot
.04094 .42207 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48702 .01753 Mdot
.45865 .05543 Mdot
.36896 .16365 Mdot
.10418 .25347 Mdot
.69405 .11495 Mdot
.50806 .10749 Mdot
.33414 .23489 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48759 .01675 Mdot
.46049 .053 Mdot
.37473 .15751 Mdot
.11986 .25842 Mdot
.70173 .11761 Mdot
.51142 .10703 Mdot
.33824 .23247 Mdot
.9621 .19766 Mdot
.64227 .08265 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00302 Mdot
.49288 .00961 Mdot
.47733 .03056 Mdot
.42787 .09516 Mdot
.27389 .24105 Mdot
.88386 .14269 Mdot
.65299 .02172 Mdot
.61785 .54021 Mdot
.74376 .39278 Mdot
.10823 .48556 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60695 Mdot
.52615 .58282 Mdot
.58313 .50921 Mdot
.75922 .36191 Mdot
.17364 .49279 Mdot
.37628 .59628 Mdot
.41148 .05615 Mdot
.32063 .1894 Mdot
.01418 .20253 Mdot
.49992 .00011 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49148 .01151 Mdot
.47286 .03655 Mdot
.41373 .11267 Mdot
.23143 .25921 Mdot
.81202 .12272 Mdot
.61345 .02624 Mdot
.57099 .58062 Mdot
.63153 .4721 Mdot
.49963 .00049 Mdot
.49883 .00157 Mdot
.49629 .00502 Mdot
.48817 .01597 Mdot
.46233 .05057 Mdot
.38051 .15122 Mdot
.13583 .2624 Mdot
.71125 .11921 Mdot
.51837 .10222 Mdot
.35297 .21995 Mdot
.99708 .21725 Mdot
.64557 .10034 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00365 Mdot
.49138 .01164 Mdot
.47255 .03697 Mdot
.41273 .11388 Mdot
.22848 .26007 Mdot
.80767 .12211 Mdot
.61009 .02799 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00494 Mdot
.48835 .01573 Mdot
.4629 .04981 Mdot
.3823 .14925 Mdot
.14082 .26341 Mdot
.71461 .1195 Mdot
.52125 .09986 Mdot
.35967 .21374 Mdot
.01383 .22655 Mdot
.50045 .61743 Mdot
.50142 .61612 Mdot
.50452 .61193 Mdot
.5144 .5986 Mdot
.54584 .55669 Mdot
.6451 .44005 Mdot
.93308 .37983 Mdot
.31851 .51391 Mdot
.48699 .52596 Mdot
.63596 .4147 Mdot
.96497 .38248 Mdot
.50014 .61784 Mdot
.50046 .61741 Mdot
.50147 .61605 Mdot
.50467 .61172 Mdot
.51488 .59795 Mdot
.54738 .55467 Mdot
.64992 .43534 Mdot
.94552 .38582 Mdot
.32125 .51882 Mdot
.48179 .53567 Mdot
.61506 .43805 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49565 .00588 Mdot
.48613 .01873 Mdot
.45582 .05916 Mdot
.36009 .17279 Mdot
.0805 .24428 Mdot
.68524 .10878 Mdot
.50923 .10023 Mdot
.34705 .22119 Mdot
.50101 .61667 Mdot
.50321 .61369 Mdot
.51024 .60421 Mdot
.53261 .57419 Mdot
.60355 .48483 Mdot
.81908 .35096 Mdot
.25121 .4985 Mdot
.44461 .54882 Mdot
.5566 .49745 Mdot
.7517 .34992 Mdot
.18552 .48552 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49613 .00522 Mdot
.48768 .01663 Mdot
.46077 .05264 Mdot
.37559 .15658 Mdot
.12224 .25909 Mdot
.70303 .11792 Mdot
.51223 .10659 Mdot
.33977 .23128 Mdot
.96555 .19959 Mdot
.6426 .08438 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49676 .00438 Mdot
.48966 .01396 Mdot
.46707 .04427 Mdot
.39544 .13438 Mdot
.17802 .26709 Mdot
.74587 .11959 Mdot
.55236 .07192 Mdot
.436 .12966 Mdot
.50048 .61739 Mdot
.50152 .61599 Mdot
.50483 .61151 Mdot
.51539 .59726 Mdot
.54901 .55254 Mdot
.65499 .43051 Mdot
.9584 .39239 Mdot
.32351 .52447 Mdot
.47489 .54765 Mdot
.58877 .46956 Mdot
.829 .33982 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00488 Mdot
.48848 .01555 Mdot
.46332 .04925 Mdot
.38364 .14777 Mdot
.14454 .26409 Mdot
.71723 .11966 Mdot
.52362 .09785 Mdot
.3653 .20834 Mdot
.02819 .23434 Mdot
.64902 .11551 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.49739 .00352 Mdot
.4917 .01121 Mdot
.47356 .03561 Mdot
.41595 .10996 Mdot
.23803 .25708 Mdot
.82206 .12441 Mdot
.62077 .02289 Mdot
.58373 .56683 Mdot
.66658 .43909 Mdot
.50045 .61742 Mdot
.50144 .61609 Mdot
.50459 .61183 Mdot
.51462 .5983 Mdot
.54656 .55575 Mdot
.64734 .43785 Mdot
.93889 .38258 Mdot
.31987 .51613 Mdot
.48475 .53024 Mdot
.6268 .42474 Mdot
.93955 .37004 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48985 .01371 Mdot
.46766 .04349 Mdot
.39729 .13223 Mdot
.18334 .26702 Mdot
.75129 .11948 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49064 .01264 Mdot
.47019 .04011 Mdot
.40529 .12282 Mdot
.20656 .26491 Mdot
.77793 .11963 Mdot
.58437 .04502 Mdot
.51152 .03435 Mdot
.50043 .61746 Mdot
.50137 .61619 Mdot
.50435 .61216 Mdot
.51386 .59933 Mdot
.54413 .55894 Mdot
.63975 .4454 Mdot
.91908 .37357 Mdot
.31463 .50912 Mdot
.49085 .51759 Mdot
.65337 .39642 Mdot
.01194 .40748 Mdot
.50018 .6178 Mdot
.50056 .61728 Mdot
.50178 .61563 Mdot
.50567 .61038 Mdot
.51806 .59367 Mdot
.55748 .54154 Mdot
.68126 .40754 Mdot
.02184 .42773 Mdot
.32977 .55712 Mdot
.42832 .00332 Mdot
.42295 .07199 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60499 Mdot
.53078 .57663 Mdot
.59776 .49159 Mdot
.80235 .35196 Mdot
.23287 .49865 Mdot
.42604 .56477 Mdot
.51221 .55346 Mdot
.61669 .45472 Mdot
.50085 .61689 Mdot
.5027 .61438 Mdot
.50861 .60641 Mdot
.52742 .58111 Mdot
.58717 .50428 Mdot
.77122 .35805 Mdot
.19189 .49587 Mdot
.38956 .59023 Mdot
.43455 .03117 Mdot
.38411 .12936 Mdot
.17479 .26074 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00332 Mdot
.49218 .01057 Mdot
.47507 .03358 Mdot
.42073 .10407 Mdot
.25235 .25159 Mdot
.84526 .1297 Mdot
.6354 .01878 Mdot
.60502 .54637 Mdot
.72098 .40127 Mdot
.07171 .46552 Mdot
.50007 .61794 Mdot
.50023 .61772 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50743 .60799 Mdot
.52368 .58612 Mdot
.57532 .51887 Mdot
.73577 .37191 Mdot
.134 .48198 Mdot
.35415 .59904 Mdot
.38488 .07866 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48947 .01421 Mdot
.46647 .04507 Mdot
.39356 .13655 Mdot
.17261 .26699 Mdot
.7406 .11971 Mdot
.54691 .07684 Mdot
.42258 .14581 Mdot
.18665 .28182 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00554 Mdot
.48695 .01762 Mdot
.45843 .05572 Mdot
.36828 .16436 Mdot
.10233 .25283 Mdot
.69325 .11456 Mdot
.50788 .10726 Mdot
.33433 .23457 Mdot
.95479 .19322 Mdot
.64215 .07827 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.5083 .60682 Mdot
.52645 .58241 Mdot
.58409 .50803 Mdot
.76207 .36091 Mdot
.1781 .49366 Mdot
.37935 .5951 Mdot
.41646 .05101 Mdot
.33393 .17851 Mdot
.0451 .21976 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49093 .01225 Mdot
.47111 .03889 Mdot
.40818 .11936 Mdot
.21505 .26336 Mdot
.78892 .12021 Mdot
.59441 .03773 Mdot
.53337 .00702 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51042 .60397 Mdot
.53318 .57343 Mdot
.60534 .48275 Mdot
.82424 .35097 Mdot
.25636 .49839 Mdot
.44994 .54404 Mdot
.56967 .48149 Mdot
.7906 .33872 Mdot
.24254 .4861 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51292 .60058 Mdot
.54116 .56285 Mdot
.63044 .45502 Mdot
.89421 .36401 Mdot
.30523 .50276 Mdot
.49175 .5104 Mdot
.66591 .38297 Mdot
.04626 .42525 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49697 .0041 Mdot
.49033 .01306 Mdot
.4692 .04143 Mdot
.40216 .12653 Mdot
.19743 .2661 Mdot
.76687 .11938 Mdot
.57371 .05347 Mdot
.48719 .06533 Mdot
.38148 .16533 Mdot
.11398 .26219 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51109 .60305 Mdot
.53533 .57057 Mdot
.61214 .475 Mdot
.84358 .35223 Mdot
.27366 .49815 Mdot
.46764 .52794 Mdot
.61342 .43147 Mdot
.91528 .35659 Mdot
.33831 .482 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00226 Mdot
.49468 .00719 Mdot
.48304 .02288 Mdot
.44602 .07197 Mdot
.32958 .20145 Mdot
.00363 .20481 Mdot
.67224 .07453 Mdot
.55164 .02749 Mdot
.50716 .02086 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50727 .60821 Mdot
.52317 .58681 Mdot
.5737 .5209 Mdot
.73086 .37442 Mdot
.12503 .47877 Mdot
.35036 .59794 Mdot
.38287 .07895 Mdot
.25512 .22642 Mdot
.88876 .13149 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.4892 .01459 Mdot
.46559 .04624 Mdot
.39078 .13973 Mdot
.16469 .26658 Mdot
.73336 .11984 Mdot
.53945 .08365 Mdot
.4041 .16727 Mdot
.13346 .27699 Mdot
.68527 .14148 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49573 .00577 Mdot
.48639 .01838 Mdot
.45665 .05808 Mdot
.36268 .17016 Mdot
.08735 .24713 Mdot
.68748 .11083 Mdot
.50815 .10328 Mdot
.34104 .22733 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50695 .60864 Mdot
.52215 .58818 Mdot
.57045 .52498 Mdot
.72102 .37987 Mdot
.10637 .4713 Mdot
.34378 .59397 Mdot
.38272 .07508 Mdot
.26124 .22226 Mdot
.90163 .13675 Mdot
.50053 .61732 Mdot
.50167 .61577 Mdot
.50534 .61083 Mdot
.517 .5951 Mdot
.55411 .5459 Mdot
.67082 .41624 Mdot
.99733 .41376 Mdot
.32784 .54401 Mdot
.44762 .5917 Mdot
.49022 .60076 Mdot
.51817 .58395 Mdot
.50052 .61733 Mdot
.50165 .61581 Mdot
.50526 .61093 Mdot
.51674 .59544 Mdot
.5533 .54694 Mdot
.66833 .4184 Mdot
.99135 .41038 Mdot
.32733 .54085 Mdot
.45222 .58448 Mdot
.50652 .57844 Mdot
.57059 .51513 Mdot
.50074 .61703 Mdot
.50236 .61484 Mdot
.50752 .60787 Mdot
.52397 .58574 Mdot
.57622 .51775 Mdot
.73848 .37059 Mdot
.13886 .4836 Mdot
.35638 .59939 Mdot
.38654 .07785 Mdot
.26058 .22507 Mdot
.8964 .13567 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00272 Mdot
.4936 .00865 Mdot
.4796 .02751 Mdot
.43508 .08604 Mdot
.29588 .22749 Mdot
.92778 .16282 Mdot
.66434 .03613 Mdot
.60587 .5631 Mdot
.69475 .42436 Mdot
.00813 .43189 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.4928 .00972 Mdot
.47707 .0309 Mdot
.42707 .09617 Mdot
.27147 .24237 Mdot
.87929 .1409 Mdot
.65132 .02082 Mdot
.61763 .53946 Mdot
.74477 .392 Mdot
.1105 .4864 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48745 .01694 Mdot
.46004 .0536 Mdot
.37332 .15902 Mdot
.11601 .2573 Mdot
.69969 .11706 Mdot
.51028 .10754 Mdot
.33628 .23393 Mdot
.95777 .19524 Mdot
.64187 .08046 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.49229 .01041 Mdot
.47544 .03309 Mdot
.42189 .10263 Mdot
.25584 .25008 Mdot
.8512 .13137 Mdot
.63865 .01849 Mdot
.60873 .54338 Mdot
.72952 .39706 Mdot
.08706 .4738 Mdot
.5004 .6175 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60075 Mdot
.54076 .56337 Mdot
.62921 .45632 Mdot
.89086 .36289 Mdot
.30369 .50212 Mdot
.49125 .51023 Mdot
.66568 .38291 Mdot
.04611 .42507 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.49251 .01012 Mdot
.47613 .03217 Mdot
.42408 .09991 Mdot
.26243 .247 Mdot
.86278 .13497 Mdot
.64439 .01874 Mdot
.61406 .53986 Mdot
.74056 .39257 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50873 .60624 Mdot
.52781 .58059 Mdot
.58839 .50279 Mdot
.77486 .35704 Mdot
.19715 .49653 Mdot
.39375 .58787 Mdot
.44255 .02195 Mdot
.40704 .10331 Mdot
.23987 .25056 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.50501 .61126 Mdot
.51597 .59649 Mdot
.55083 .55016 Mdot
.66066 .42526 Mdot
.97257 .39996 Mdot
.32543 .53124 Mdot
.46586 .56265 Mdot
.55548 .51225 Mdot
.72665 .36629 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49808 .0026 Mdot
.49387 .00828 Mdot
.48046 .02635 Mdot
.43783 .08253 Mdot
.30429 .22158 Mdot
.94577 .17227 Mdot
.66703 .04432 Mdot
.59532 .57918 Mdot
.65819 .45551 Mdot
.92115 .38537 Mdot
.49991 .00011 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01184 Mdot
.47207 .0376 Mdot
.41122 .1157 Mdot
.22401 .26129 Mdot
.80124 .12132 Mdot
.60494 .03093 Mdot
.55489 .59909 Mdot
.58554 .52355 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00552 Mdot
.48697 .01759 Mdot
.45852 .05561 Mdot
.36855 .16408 Mdot
.10306 .25308 Mdot
.69356 .11472 Mdot
.50794 .10736 Mdot
.33424 .23471 Mdot
.95447 .19308 Mdot
.64207 .07818 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49245 .0102 Mdot
.47595 .0324 Mdot
.42352 .10061 Mdot
.26073 .24782 Mdot
.85976 .13399 Mdot
.64296 .01857 Mdot
.6129 .5405 Mdot
.73835 .39335 Mdot
.1019 .48149 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49014 .01332 Mdot
.46859 .04225 Mdot
.40023 .1288 Mdot
.19183 .2666 Mdot
.76046 .11937 Mdot
.56731 .05881 Mdot
.47215 .0845 Mdot
.33543 .21129 Mdot
.50065 .61715 Mdot
.50209 .61522 Mdot
.50665 .60906 Mdot
.52117 .58949 Mdot
.56736 .52889 Mdot
.71159 .38563 Mdot
.08763 .46282 Mdot
.33877 .588 Mdot
.38736 .06589 Mdot
.28074 .21069 Mdot
.93983 .15624 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.5101 .6044 Mdot
.53216 .57479 Mdot
.60214 .48647 Mdot
.81501 .35106 Mdot
.24698 .49858 Mdot
.44026 .55267 Mdot
.54602 .5106 Mdot
.71985 .3657 Mdot
.12814 .47206 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.49481 .00701 Mdot
.48347 .02231 Mdot
.44737 .07021 Mdot
.33376 .19779 Mdot
.01373 .2105 Mdot
.67313 .07984 Mdot
.54395 .03961 Mdot
.47986 .05823 Mdot
.38565 .15534 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51203 .60179 Mdot
.53831 .56662 Mdot
.6215 .46461 Mdot
.86974 .35689 Mdot
.29228 .49926 Mdot
.48446 .51365 Mdot
.65336 .39248 Mdot
.01832 .40942 Mdot
.35586 .52552 Mdot
.50126 .61633 Mdot
.50403 .6126 Mdot
.51283 .60072 Mdot
.54084 .56327 Mdot
.62946 .45606 Mdot
.89154 .36311 Mdot
.30401 .50224 Mdot
.49136 .51025 Mdot
.66576 .38289 Mdot
.04623 .42515 Mdot
.35832 .53982 Mdot
.50073 .61704 Mdot
.50234 .61488 Mdot
.50745 .60798 Mdot
.52372 .58607 Mdot
.57544 .51872 Mdot
.73615 .37173 Mdot
.13467 .4822 Mdot
.35445 .5991 Mdot
.38509 .07858 Mdot
.25795 .22594 Mdot
.89237 .13359 Mdot
.50095 .61676 Mdot
.50302 .61396 Mdot
.50961 .60506 Mdot
.5306 .57687 Mdot
.5972 .49226 Mdot
.80071 .35214 Mdot
.23094 .49863 Mdot
.42414 .56632 Mdot
.50782 .55907 Mdot
.60322 .46995 Mdot
.84283 .3468 Mdot
.49974 .00035 Mdot
.49917 .00111 Mdot
.49737 .00355 Mdot
.49162 .01131 Mdot
.47332 .03593 Mdot
.41518 .1109 Mdot
.23573 .25785 Mdot
.81852 .12377 Mdot
.61825 .02396 Mdot
.57949 .57133 Mdot
.65506 .44927 Mdot
.92813 .38488 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00806 Mdot
.481 .02562 Mdot
.43954 .08033 Mdot
.30956 .21767 Mdot
.95737 .17862 Mdot
.66836 .05006 Mdot
.58736 .59111 Mdot
.63092 .48297 Mdot
.84946 .36331 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48874 .01521 Mdot
.46413 .04818 Mdot
.38616 .14494 Mdot
.15164 .2652 Mdot
.72254 .11984 Mdot
.52863 .09345 Mdot
.37743 .19617 Mdot
.06002 .2505 Mdot
.6547 .12863 Mdot
.49965 .00048 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04864 Mdot
.38509 .14615 Mdot
.14861 .26476 Mdot
.72023 .11978 Mdot
.52642 .09541 Mdot
.37204 .20166 Mdot
.04575 .24349 Mdot
.65177 .12316 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51148 .60253 Mdot
.53657 .56893 Mdot
.61602 .47065 Mdot
.85448 .35378 Mdot
.28206 .49834 Mdot
.47573 .52075 Mdot
.63314 .41122 Mdot
.96778 .38155 Mdot
.35042 .50069 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49616 .00518 Mdot
.48778 .0165 Mdot
.46109 .05222 Mdot
.3766 .15549 Mdot
.125 .25983 Mdot
.7046 .11824 Mdot
.51327 .10595 Mdot
.34184 .22961 Mdot
.97032 .20225 Mdot
.64307 .08678 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48783 .01643 Mdot
.46125 .052 Mdot
.3771 .15495 Mdot
.12639 .26019 Mdot
.7054 .1184 Mdot
.51383 .10559 Mdot
.34299 .22865 Mdot
.97303 .20377 Mdot
.64333 .08814 Mdot
.50096 .61673 Mdot
.50307 .61388 Mdot
.50979 .60481 Mdot
.53119 .57608 Mdot
.59908 .49004 Mdot
.80617 .35159 Mdot
.23728 .49867 Mdot
.43042 .56113 Mdot
.52249 .54035 Mdot
.64818 .42199 Mdot
.96539 .39015 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48092 .02574 Mdot
.43926 .08069 Mdot
.3087 .21831 Mdot
.95547 .17757 Mdot
.66816 .0491 Mdot
.58872 .58908 Mdot
.63556 .47807 Mdot
.86203 .36559 Mdot
.50035 .61756 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51142 .60261 Mdot
.53639 .56917 Mdot
.61545 .47128 Mdot
.8529 .35352 Mdot
.2809 .49829 Mdot
.47465 .52169 Mdot
.63054 .41379 Mdot
.96102 .37801 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01006 Mdot
.47628 .03197 Mdot
.42456 .09932 Mdot
.26386 .2463 Mdot
.86533 .13583 Mdot
.64555 .01893 Mdot
.61491 .53946 Mdot
.74205 .3921 Mdot
.10763 .48444 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00368 Mdot
.49133 .01171 Mdot
.47237 .0372 Mdot
.41219 .11453 Mdot
.22687 .26052 Mdot
.80534 .12181 Mdot
.60825 .02901 Mdot
.56131 .59161 Mdot
.60407 .50186 Mdot
.79205 .35943 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00564 Mdot
.48669 .01797 Mdot
.45761 .0568 Mdot
.3657 .16705 Mdot
.09541 .2503 Mdot
.69042 .11297 Mdot
.50764 .10589 Mdot
.33631 .23227 Mdot
.96049 .19602 Mdot
.64333 .08039 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00302 Mdot
.49288 .00961 Mdot
.47733 .03056 Mdot
.42789 .09514 Mdot
.27394 .24102 Mdot
.88396 .14273 Mdot
.65302 .02174 Mdot
.61785 .54023 Mdot
.74373 .3928 Mdot
.10816 .48553 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49213 .01064 Mdot
.47492 .03379 Mdot
.42024 .10468 Mdot
.25087 .25222 Mdot
.84278 .12904 Mdot
.63399 .01899 Mdot
.60326 .54787 Mdot
.71679 .40353 Mdot
.06387 .46116 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51233 .60139 Mdot
.53927 .56535 Mdot
.6245 .46135 Mdot
.87803 .35902 Mdot
.29712 .50015 Mdot
.48786 .51139 Mdot
.66041 .38661 Mdot
.03487 .41868 Mdot
.35744 .53386 Mdot
.50032 .6176 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51031 .60411 Mdot
.53285 .57387 Mdot
.60432 .48394 Mdot
.82129 .35095 Mdot
.25345 .49846 Mdot
.44692 .54676 Mdot
.56225 .4905 Mdot
.7686 .34397 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49006 .01342 Mdot
.46835 .04257 Mdot
.39947 .12969 Mdot
.18962 .26675 Mdot
.75802 .11939 Mdot
.56484 .06093 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00192 Mdot
.49548 .0061 Mdot
.48561 .01943 Mdot
.45418 .06132 Mdot
.35496 .17792 Mdot
.06707 .23828 Mdot
.68153 .10418 Mdot
.51296 .09218 Mdot
.3638 .20359 Mdot
.03439 .23522 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50407 .61254 Mdot
.51295 .60055 Mdot
.54125 .56274 Mdot
.63072 .45473 Mdot
.89495 .36426 Mdot
.30557 .50291 Mdot
.49185 .51046 Mdot
.6659 .38304 Mdot
.04613 .42521 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51485 .59799 Mdot
.54729 .55479 Mdot
.64962 .43563 Mdot
.94476 .38544 Mdot
.3211 .51851 Mdot
.48215 .53502 Mdot
.61646 .43644 Mdot
.91029 .35761 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50102 .61665 Mdot
.50325 .61364 Mdot
.51037 .60404 Mdot
.53301 .57365 Mdot
.60483 .48334 Mdot
.82277 .35095 Mdot
.25491 .49843 Mdot
.44844 .54539 Mdot
.50015 .61784 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50475 .61162 Mdot
.51513 .59761 Mdot
.54818 .55362 Mdot
.65241 .43296 Mdot
.95187 .38901 Mdot
.32243 .52154 Mdot
.47856 .54136 Mdot
.60263 .45267 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.50791 .60735 Mdot
.52521 .58407 Mdot
.58016 .51287 Mdot
.75032 .36532 Mdot
.15922 .48951 Mdot
.36718 .59884 Mdot
.39824 .06885 Mdot
.28684 .21246 Mdot
.94307 .1608 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48655 .01815 Mdot
.45719 .05737 Mdot
.36436 .16843 Mdot
.09184 .24892 Mdot
.68907 .11206 Mdot
.50776 .10487 Mdot
.49978 .0003 Mdot
.49929 .00095 Mdot
.49775 .00304 Mdot
.49283 .00969 Mdot
.47716 .03079 Mdot
.42734 .09584 Mdot
.27227 .24194 Mdot
.8808 .14148 Mdot
.65188 .0211 Mdot
.61774 .53967 Mdot
.74453 .39221 Mdot
.10992 .4862 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47738 .0305 Mdot
.42803 .09496 Mdot
.27438 .24078 Mdot
.8848 .14306 Mdot
.65332 .02192 Mdot
.61785 .54041 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50583 .61016 Mdot
.51857 .59298 Mdot
.55912 .53943 Mdot
.68631 .40354 Mdot
.03337 .43425 Mdot
.33074 .56321 Mdot
.41945 .0167 Mdot
.39243 .109 Mdot
.21606 .25321 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50496 .61133 Mdot
.5158 .59671 Mdot
.55031 .55083 Mdot
.65905 .42673 Mdot
.96858 .39779 Mdot
.32494 .52928 Mdot
.46854 .55826 Mdot
.56527 .49943 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47323 .03606 Mdot
.41489 .11125 Mdot
.23488 .25813 Mdot
.81722 .12355 Mdot
.61731 .02438 Mdot
.57786 .57308 Mdot
.6506 .45338 Mdot
.91701 .37989 Mdot
.49994 8e-05 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49802 .00268 Mdot
.49368 .00854 Mdot
.47986 .02716 Mdot
.43591 .08498 Mdot
.29842 .22575 Mdot
.93315 .16558 Mdot
.66523 .03847 Mdot
.60299 .56756 Mdot
.68466 .43227 Mdot
.50093 .61677 Mdot
.50298 .61401 Mdot
.50949 .60522 Mdot
.53023 .57736 Mdot
.59605 .49362 Mdot
.79735 .35256 Mdot
.22689 .49855 Mdot
.42022 .56945 Mdot
.49882 .57055 Mdot
.57566 .50302 Mdot
.76176 .35588 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49815 .0025 Mdot
.49409 .00798 Mdot
.48118 .02538 Mdot
.44011 .0796 Mdot
.31131 .21634 Mdot
.96127 .18079 Mdot
.66875 .05205 Mdot
.58453 .59535 Mdot
.62124 .49352 Mdot
.82271 .3611 Mdot
.50014 .61784 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51485 .59798 Mdot
.54729 .55478 Mdot
.64964 .43561 Mdot
.9448 .38546 Mdot
.32111 .51852 Mdot
.48213 .53505 Mdot
.6164 .43651 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47454 .0343 Mdot
.41905 .10615 Mdot
.2473 .25367 Mdot
.83686 .12756 Mdot
.63047 .01971 Mdot
.59858 .55208 Mdot
.7053 .41032 Mdot
.0414 .44826 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61167 Mdot
.51501 .59778 Mdot
.54778 .55415 Mdot
.65114 .43417 Mdot
.94864 .38738 Mdot
.32185 .52014 Mdot
.48024 .53841 Mdot
.60908 .44502 Mdot
.88902 .35027 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49395 .00817 Mdot
.48073 .02599 Mdot
.43867 .08145 Mdot
.30689 .21967 Mdot
.95146 .17536 Mdot
.66772 .0471 Mdot
.59151 .5849 Mdot
.64513 .46824 Mdot
.88751 .37242 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49513 .00659 Mdot
.48447 .02096 Mdot
.45056 .06606 Mdot
.34366 .18879 Mdot
.03819 .22386 Mdot
.67598 .09198 Mdot
.52715 .06693 Mdot
.41886 .13894 Mdot
.19405 .27746 Mdot
.50131 .61626 Mdot
.50419 .61238 Mdot
.51334 .60003 Mdot
.54246 .56113 Mdot
.63454 .45074 Mdot
.90523 .36798 Mdot
.30982 .50523 Mdot
.49235 .51231 Mdot
.66341 .38607 Mdot
.03874 .42163 Mdot
.35653 .53734 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50583 .61015 Mdot
.51859 .59296 Mdot
.55915 .53938 Mdot
.68642 .40345 Mdot
.03362 .43439 Mdot
.33077 .56334 Mdot
.41926 .01698 Mdot
.39179 .10975 Mdot
.21421 .25358 Mdot
.50041 .61748 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51328 .60011 Mdot
.54229 .56137 Mdot
.63398 .45132 Mdot
.90373 .36741 Mdot
.30924 .50486 Mdot
.49237 .51193 Mdot
.66404 .38539 Mdot
.04048 .42251 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.52831 .57993 Mdot
.58996 .5009 Mdot
.77949 .35588 Mdot
.20367 .49722 Mdot
.39915 .58457 Mdot
.45329 .00922 Mdot
.43838 .06493 Mdot
.33332 .19272 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.5044 .61209 Mdot
.51401 .59912 Mdot
.54462 .55829 Mdot
.6413 .44384 Mdot
.92315 .37533 Mdot
.31585 .51043 Mdot
.48996 .51973 Mdot
.64902 .4009 Mdot
.00036 .40123 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46279 .04996 Mdot
.38194 .14965 Mdot
.13981 .26322 Mdot
.71391 .11945 Mdot
.52064 .10037 Mdot
.35823 .2151 Mdot
.0102 .22454 Mdot
.64688 .1069 Mdot
.50128 .61631 Mdot
.50407 .61254 Mdot
.51296 .60054 Mdot
.54127 .56271 Mdot
.63079 .45465 Mdot
.89515 .36433 Mdot
.30565 .50295 Mdot
.49187 .51048 Mdot
.6659 .38306 Mdot
.04609 .42519 Mdot
.35811 .53999 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49511 .0066 Mdot
.48443 .02102 Mdot
.45042 .06624 Mdot
.34324 .18918 Mdot
.03715 .2233 Mdot
.67583 .09149 Mdot
.5278 .06585 Mdot
.42125 .13591 Mdot
.20135 .27661 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48945 .01424 Mdot
.46641 .04515 Mdot
.39336 .13678 Mdot
.17204 .26698 Mdot
.74007 .11972 Mdot
.54636 .07734 Mdot
.42121 .14744 Mdot
.18266 .28197 Mdot
.72642 .13604 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49386 .0083 Mdot
.48042 .0264 Mdot
.4377 .08269 Mdot
.3039 .22185 Mdot
.94494 .17182 Mdot
.66693 .04392 Mdot
.59586 .57837 Mdot
.66004 .45377 Mdot
.92582 .38747 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01089 Mdot
.47432 .03459 Mdot
.41836 .107 Mdot
.24523 .25448 Mdot
.83348 .12677 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00474 Mdot
.48883 .01508 Mdot
.46442 .04779 Mdot
.38709 .14391 Mdot
.15425 .26554 Mdot
.72459 .11987 Mdot
.53063 .09165 Mdot
.38233 .19107 Mdot
.07317 .25654 Mdot
.65808 .13292 Mdot
.50036 .61755 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.51149 .60251 Mdot
.53661 .56888 Mdot
.61614 .47051 Mdot
.85484 .35384 Mdot
.28232 .49835 Mdot
.47597 .52054 Mdot
.63372 .41066 Mdot
.96926 .38234 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61167 Mdot
.51501 .59777 Mdot
.5478 .55412 Mdot
.65121 .4341 Mdot
.94882 .38747 Mdot
.32188 .52022 Mdot
.48015 .53857 Mdot
.60873 .44543 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60208 Mdot
.53764 .56751 Mdot
.61939 .46692 Mdot
.86391 .35557 Mdot
.28858 .49881 Mdot
.48149 .51593 Mdot
.64671 .39838 Mdot
.00212 .40034 Mdot
.35435 .51729 Mdot
.50105 .61661 Mdot
.50335 .6135 Mdot
.51069 .6036 Mdot
.53404 .57229 Mdot
.60806 .47963 Mdot
.83201 .35124 Mdot
.26369 .49824 Mdot
.45752 .53716 Mdot
.58838 .45937 Mdot
.84511 .33739 Mdot
.2992 .47795 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01062 Mdot
.47495 .03374 Mdot
.42036 .10453 Mdot
.25122 .25207 Mdot
.84336 .12919 Mdot
.63432 .01894 Mdot
.60368 .54751 Mdot
.7178 .40297 Mdot
.06577 .46223 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61068 Mdot
.51734 .59464 Mdot
.55518 .5445 Mdot
.67416 .41339 Mdot
.00528 .41828 Mdot
.32848 .54825 Mdot
.44139 .60137 Mdot
.46835 .01248 Mdot
.44815 .0597 Mdot
.50042 .61747 Mdot
.50134 .61622 Mdot
.50427 .61226 Mdot
.51361 .59966 Mdot
.54334 .55998 Mdot
.63727 .44793 Mdot
.9125 .37084 Mdot
.31247 .50716 Mdot
.49187 .5147 Mdot
.65907 .39059 Mdot
.02709 .41558 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .00179 Mdot
.49577 .00571 Mdot
.48652 .01819 Mdot
.45709 .05749 Mdot
.36406 .16874 Mdot
.09103 .24861 Mdot
.68878 .11184 Mdot
.50781 .1046 Mdot
.33856 .22989 Mdot
.96659 .19915 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00565 Mdot
.48668 .01799 Mdot
.45757 .05686 Mdot
.36558 .16718 Mdot
.09508 .25017 Mdot
.69029 .11288 Mdot
.50764 .1058 Mdot
.33645 .23211 Mdot
.96089 .19622 Mdot
.64341 .08055 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.48728 .01718 Mdot
.45949 .05433 Mdot
.37158 .16088 Mdot
.11128 .25583 Mdot
.69733 .1163 Mdot
.50916 .10781 Mdot
.33472 .23494 Mdot
.95458 .1934 Mdot
.64165 .07875 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49002 .01348 Mdot
.4682 .04277 Mdot
.399 .13024 Mdot
.18826 .26682 Mdot
.75653 .1194 Mdot
.56333 .06223 Mdot
.46264 .09655 Mdot
.30642 .23492 Mdot
.4996 .00054 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.48719 .01729 Mdot
.45921 .05469 Mdot
.37071 .1618 Mdot
.10892 .25507 Mdot
.69621 .11588 Mdot
.50872 .1078 Mdot
.33429 .23513 Mdot
.95384 .19294 Mdot
.64166 .07828 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .0056 Mdot
.48679 .01783 Mdot
.45795 .05636 Mdot
.36675 .16596 Mdot
.09823 .25135 Mdot
.69154 .11364 Mdot
.50766 .10655 Mdot
.33527 .23342 Mdot
.95759 .19456 Mdot
.64278 .07925 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00216 Mdot
.4949 .00689 Mdot
.48375 .02194 Mdot
.44825 .06907 Mdot
.3365 .19535 Mdot
.02041 .21422 Mdot
.67379 .08327 Mdot
.53905 .04743 Mdot
.4623 .08206 Mdot
.32953 .21156 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60972 Mdot
.5196 .5916 Mdot
.56237 .53524 Mdot
.69633 .39601 Mdot
.05558 .44649 Mdot
.33314 .57436 Mdot
.40381 .04017 Mdot
.33882 .16533 Mdot
.07132 .22925 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49741 .00349 Mdot
.49176 .01113 Mdot
.47375 .03536 Mdot
.41653 .10924 Mdot
.23978 .25648 Mdot
.82479 .12493 Mdot
.62265 .02215 Mdot
.58681 .56363 Mdot
.67483 .43224 Mdot
.97546 .40958 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .00561 Mdot
.48677 .01786 Mdot
.45788 .05644 Mdot
.36655 .16616 Mdot
.0977 .25115 Mdot
.69133 .11352 Mdot
.50765 .10643 Mdot
.33544 .23322 Mdot
.95808 .1948 Mdot
.49979 .00029 Mdot
.49932 .00091 Mdot
.49784 .00291 Mdot
.49313 .00928 Mdot
.47811 .02951 Mdot
.43037 .09202 Mdot
.28148 .23669 Mdot
.8985 .14885 Mdot
.65767 .02544 Mdot
.6165 .54487 Mdot
.73488 .39799 Mdot
.09092 .47777 Mdot
.50065 .61715 Mdot
.50209 .61522 Mdot
.50665 .60906 Mdot
.52117 .58948 Mdot
.56737 .52888 Mdot
.71162 .38561 Mdot
.0877 .46285 Mdot
.33879 .58803 Mdot
.38733 .06594 Mdot
.28065 .21075 Mdot
.93964 .15613 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.5101 .60439 Mdot
.53217 .57477 Mdot
.60217 .48643 Mdot
.81511 .35106 Mdot
.24708 .49858 Mdot
.44036 .55258 Mdot
.54626 .5103 Mdot
.72058 .36527 Mdot
.12956 .47254 Mdot
.49978 .00029 Mdot
.4993 .00094 Mdot
.49778 .00299 Mdot
.49294 .00954 Mdot
.47751 .03031 Mdot
.42846 .09442 Mdot
.27569 .24005 Mdot
.88728 .14407 Mdot
.65417 .02247 Mdot
.6178 .541 Mdot
.74245 .39362 Mdot
.10555 .48446 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51273 .60085 Mdot
.54053 .56368 Mdot
.62848 .45709 Mdot
.88889 .36225 Mdot
.30275 .50177 Mdot
.49087 .51022 Mdot
.66532 .38307 Mdot
.04549 .42468 Mdot
.35835 .53933 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00285 Mdot
.49327 .00909 Mdot
.47856 .0289 Mdot
.43179 .09022 Mdot
.28582 .23404 Mdot
.90713 .15275 Mdot
.65998 .02819 Mdot
.61437 .54909 Mdot
.72593 .40323 Mdot
.07349 .46896 Mdot
.50077 .61699 Mdot
.50245 .61472 Mdot
.50782 .60747 Mdot
.5249 .58448 Mdot
.57919 .51406 Mdot
.74742 .36653 Mdot
.15436 .48823 Mdot
.36438 .59928 Mdot
.39472 .07188 Mdot
.27842 .21708 Mdot
.92717 .1519 Mdot
.50027 .61766 Mdot
.50087 .61685 Mdot
.50279 .61427 Mdot
.50888 .60604 Mdot
.52829 .57995 Mdot
.58991 .50097 Mdot
.77932 .35592 Mdot
.20343 .49719 Mdot
.39896 .5847 Mdot
.45289 .0097 Mdot
.4372 .06642 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00298 Mdot
.49298 .00949 Mdot
.47762 .03017 Mdot
.42881 .09398 Mdot
.27675 .23945 Mdot
.88931 .14491 Mdot
.65484 .02296 Mdot
.6177 .54156 Mdot
.74144 .39423 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00216 Mdot
.49491 .00688 Mdot
.48377 .0219 Mdot
.44833 .06896 Mdot
.33674 .19513 Mdot
.02101 .21456 Mdot
.67385 .08358 Mdot
.53862 .04813 Mdot
.46075 .08414 Mdot
.32461 .21577 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51058 .60374 Mdot
.53371 .57272 Mdot
.60702 .48082 Mdot
.82904 .3511 Mdot
.26095 .49829 Mdot
.4547 .53973 Mdot
.5814 .46752 Mdot
.82494 .33603 Mdot
.28124 .48074 Mdot
.49991 .00012 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00379 Mdot
.49107 .01207 Mdot
.47154 .03831 Mdot
.40955 .11772 Mdot
.21908 .26249 Mdot
.79436 .12064 Mdot
.59916 .03454 Mdot
.54327 .61295 Mdot
.55149 .56604 Mdot
.50057 .61726 Mdot
.50182 .61557 Mdot
.50581 .61019 Mdot
.5185 .59307 Mdot
.55889 .53972 Mdot
.6856 .40409 Mdot
.03177 .43335 Mdot
.3306 .56237 Mdot
.42066 .01488 Mdot
.39659 .10415 Mdot
.22807 .25029 Mdot
.5004 .61749 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51302 .60045 Mdot
.54148 .56243 Mdot
.63144 .45397 Mdot
.89691 .36494 Mdot
.30642 .50331 Mdot
.49205 .51067 Mdot
.66576 .38332 Mdot
.04554 .42496 Mdot
.50013 .61785 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50433 .61218 Mdot
.5138 .5994 Mdot
.54395 .55917 Mdot
.63919 .44597 Mdot
.9176 .37295 Mdot
.31416 .50866 Mdot
.49113 .51688 Mdot
.65479 .39496 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49065 .01262 Mdot
.47023 .04007 Mdot
.4054 .12269 Mdot
.20688 .26485 Mdot
.77834 .11964 Mdot
.58475 .04473 Mdot
.51237 .03327 Mdot
.45854 .07128 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61118 Mdot
.51617 .59621 Mdot
.55148 .54931 Mdot
.66268 .42342 Mdot
.97756 .40269 Mdot
.32599 .53373 Mdot
.46239 .56827 Mdot
.54291 .52897 Mdot
.68701 .39283 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00264 Mdot
.49377 .00842 Mdot
.48015 .02678 Mdot
.43682 .08382 Mdot
.30119 .2238 Mdot
.93907 .16869 Mdot
.66613 .04116 Mdot
.59953 .57282 Mdot
.67269 .44234 Mdot
.95697 .40294 Mdot
.50007 .61794 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50726 .60823 Mdot
.52312 .58688 Mdot
.57353 .52112 Mdot
.73034 .37469 Mdot
.12408 .47842 Mdot
.34998 .59779 Mdot
.38273 .0789 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .01369 Mdot
.46772 .04341 Mdot
.39747 .13202 Mdot
.18385 .26701 Mdot
.75182 .11947 Mdot
.55851 .06644 Mdot
.45101 .11115 Mdot
.27117 .25739 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00443 Mdot
.48956 .0141 Mdot
.46675 .04469 Mdot
.39444 .13553 Mdot
.17515 .26706 Mdot
.74304 .11965 Mdot
.54944 .07456 Mdot
.4288 .13838 Mdot
.2049 .28004 Mdot
.50011 .61789 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60338 Mdot
.53457 .57158 Mdot
.60975 .47771 Mdot
.8368 .35157 Mdot
.26795 .49817 Mdot
.46189 .53317 Mdot
.5992 .44705 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.4955 .00608 Mdot
.48567 .01934 Mdot
.45437 .06106 Mdot
.35557 .17732 Mdot
.06866 .23902 Mdot
.68192 .10477 Mdot
.51241 .09327 Mdot
.36149 .20607 Mdot
.02806 .23195 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46024 .05333 Mdot
.37396 .15834 Mdot
.11776 .25782 Mdot
.7006 .11732 Mdot
.51077 .10734 Mdot
.33709 .23334 Mdot
.95954 .19624 Mdot
.64203 .08136 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49014 .01332 Mdot
.4686 .04224 Mdot
.40025 .12878 Mdot
.19189 .26659 Mdot
.76053 .11937 Mdot
.56738 .05876 Mdot
.47231 .0843 Mdot
.33592 .21086 Mdot
.99474 .20599 Mdot
.50078 .61699 Mdot
.50247 .61469 Mdot
.50788 .60739 Mdot
.52509 .58423 Mdot
.57979 .51332 Mdot
.74922 .36578 Mdot
.15739 .48904 Mdot
.36611 .59903 Mdot
.39686 .07006 Mdot
.2835 .21435 Mdot
.93668 .15718 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49886 .00155 Mdot
.49636 .00492 Mdot
.48839 .01568 Mdot
.46302 .04966 Mdot
.38267 .14883 Mdot
.14186 .26361 Mdot
.71533 .11955 Mdot
.52189 .09932 Mdot
.36118 .2123 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52558 .58358 Mdot
.58132 .51143 Mdot
.75381 .36393 Mdot
.16497 .49091 Mdot
.37066 .59804 Mdot
.403 .06447 Mdot
.2987 .20516 Mdot
.96674 .17455 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00387 Mdot
.49087 .01234 Mdot
.47091 .03916 Mdot
.40755 .12012 Mdot
.21318 .26374 Mdot
.78644 .12005 Mdot
.59221 .03927 Mdot
.52867 .01284 Mdot
.5079 .00552 Mdot
.49897 .00647 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60224 Mdot
.53726 .56801 Mdot
.61819 .46824 Mdot
.86057 .35489 Mdot
.28634 .4986 Mdot
.47959 .51748 Mdot
.64229 .40245 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50449 .61196 Mdot
.51431 .59871 Mdot
.54557 .55704 Mdot
.64427 .44087 Mdot
.93092 .37883 Mdot
.31797 .51312 Mdot
.48773 .52448 Mdot
.6391 .41134 Mdot
.97354 .38692 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49179 .01109 Mdot
.47384 .03524 Mdot
.41683 .10888 Mdot
.24066 .25617 Mdot
.82617 .1252 Mdot
.62359 .0218 Mdot
.58832 .5621 Mdot
.67882 .42907 Mdot
.98458 .41479 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50653 .60922 Mdot
.52079 .59 Mdot
.56614 .53044 Mdot
.70787 .38803 Mdot
.08003 .45913 Mdot
.33713 .58511 Mdot
.3904 .06084 Mdot
.29196 .20329 Mdot
.96304 .16933 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00306 Mdot
.49279 .00974 Mdot
.47704 .03095 Mdot
.42697 .0963 Mdot
.27115 .24254 Mdot
.87871 .14067 Mdot
.65109 .02071 Mdot
.61758 .53939 Mdot
.74483 .39192 Mdot
.11069 .48646 Mdot
.50073 .61705 Mdot
.50231 .61491 Mdot
.50736 .60809 Mdot
.52345 .58642 Mdot
.5746 .51977 Mdot
.73359 .37301 Mdot
.13005 .4806 Mdot
.35243 .59863 Mdot
.38383 .07898 Mdot
.25604 .22641 Mdot
.8897 .13215 Mdot
.50079 .61696 Mdot
.50253 .61462 Mdot
.50805 .60717 Mdot
.52563 .58351 Mdot
.58149 .51122 Mdot
.75432 .36373 Mdot
.1658 .4911 Mdot
.37118 .59791 Mdot
.40375 .06376 Mdot
.30058 .20392 Mdot
.97064 .17685 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45944 .05439 Mdot
.37144 .16103 Mdot
.11089 .25571 Mdot
.69714 .11623 Mdot
.50908 .10782 Mdot
.33463 .23499 Mdot
.95442 .1933 Mdot
.64165 .07865 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50688 .60874 Mdot
.52191 .5885 Mdot
.5697 .52592 Mdot
.71874 .38121 Mdot
.10192 .46938 Mdot
.34246 .59272 Mdot
.38342 .07335 Mdot
.26474 .22026 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01006 Mdot
.47626 .03199 Mdot
.42451 .09938 Mdot
.26371 .24638 Mdot
.86506 .13574 Mdot
.64543 .01891 Mdot
.61483 .53949 Mdot
.74191 .39214 Mdot
.10742 .48433 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49212 .01065 Mdot
.47489 .03383 Mdot
.42014 .1048 Mdot
.25057 .25234 Mdot
.84227 .12891 Mdot
.6337 .01904 Mdot
.60289 .54819 Mdot
.7159 .40402 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49564 .00589 Mdot
.48611 .01875 Mdot
.45578 .05921 Mdot
.35998 .17291 Mdot
.08021 .24416 Mdot
.68515 .10869 Mdot
.50929 .10009 Mdot
.34735 .22088 Mdot
.98995 .21157 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00215 Mdot
.49494 .00684 Mdot
.48387 .02177 Mdot
.44865 .06855 Mdot
.33772 .19425 Mdot
.02343 .21589 Mdot
.67411 .0848 Mdot
.53691 .05088 Mdot
.45458 .09243 Mdot
.30503 .23124 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50529 .61089 Mdot
.51685 .5953 Mdot
.55363 .54652 Mdot
.66935 .41752 Mdot
.99379 .41176 Mdot
.32755 .54213 Mdot
.45035 .58742 Mdot
.49989 .58751 Mdot
.54928 .54256 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.496 .00541 Mdot
.48725 .01721 Mdot
.45941 .05443 Mdot
.37133 .16114 Mdot
.11061 .25562 Mdot
.69701 .11618 Mdot
.50902 .10782 Mdot
.33457 .23502 Mdot
.95431 .19324 Mdot
.64164 .07859 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.5394 .56518 Mdot
.62492 .4609 Mdot
.87916 .35934 Mdot
.29774 .50029 Mdot
.48825 .51117 Mdot
.66116 .38602 Mdot
.03656 .41962 Mdot
.3576 .53471 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50732 .60814 Mdot
.52332 .5866 Mdot
.57419 .52029 Mdot
.73234 .37365 Mdot
.12776 .47977 Mdot
.35147 .59834 Mdot
.38334 .07902 Mdot
.25548 .22648 Mdot
.88902 .13174 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46278 .04997 Mdot
.38192 .14967 Mdot
.13974 .26321 Mdot
.71387 .11945 Mdot
.5206 .1004 Mdot
.35814 .21518 Mdot
.00998 .22442 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51319 .60023 Mdot
.542 .56174 Mdot
.6331 .45224 Mdot
.90136 .36654 Mdot
.30829 .50429 Mdot
.49233 .5114 Mdot
.66486 .38447 Mdot
.04276 .42364 Mdot
.35729 .53891 Mdot
.50086 .61687 Mdot
.50275 .61431 Mdot
.50878 .60618 Mdot
.52796 .58039 Mdot
.58886 .50223 Mdot
.77624 .35668 Mdot
.19911 .49675 Mdot
.39535 .58692 Mdot
.44569 .01827 Mdot
.41613 .09247 Mdot
.26652 .23922 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.5129 .60062 Mdot
.54107 .56296 Mdot
.63018 .4553 Mdot
.89349 .36377 Mdot
.30491 .50262 Mdot
.49166 .51035 Mdot
.6659 .38292 Mdot
.04632 .42526 Mdot
.35823 .53998 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51093 .60328 Mdot
.53481 .57126 Mdot
.61049 .47686 Mdot
.83891 .35175 Mdot
.26977 .49816 Mdot
.46373 .53149 Mdot
.60377 .44196 Mdot
.88865 .34696 Mdot
.32727 .47745 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00352 Mdot
.49171 .0112 Mdot
.47359 .03557 Mdot
.41603 .10986 Mdot
.23827 .257 Mdot
.82244 .12448 Mdot
.62103 .02278 Mdot
.58416 .56638 Mdot
.66774 .43811 Mdot
.95887 .4004 Mdot
.50044 .61744 Mdot
.5014 .61614 Mdot
.50446 .61201 Mdot
.5142 .59887 Mdot
.54521 .55751 Mdot
.64314 .442 Mdot
.92798 .37748 Mdot
.3172 .51207 Mdot
.48866 .52258 Mdot
.64311 .40707 Mdot
.98445 .39268 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00072 Mdot
.49829 .00231 Mdot
.49456 .00735 Mdot
.48266 .02339 Mdot
.44482 .07353 Mdot
.32584 .20464 Mdot
.99472 .19975 Mdot
.67152 .06978 Mdot
.55861 .01666 Mdot
.53165 .60555 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00298 Mdot
.49298 .00948 Mdot
.47765 .03013 Mdot
.42889 .09389 Mdot
.27698 .23932 Mdot
.88976 .14509 Mdot
.65499 .02307 Mdot
.61767 .54169 Mdot
.7412 .39437 Mdot
.10309 .4834 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51337 .59998 Mdot
.54259 .56097 Mdot
.63492 .45034 Mdot
.90626 .36838 Mdot
.31022 .50549 Mdot
.49232 .5126 Mdot
.66292 .38659 Mdot
.03741 .42095 Mdot
.35629 .53679 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51139 .60266 Mdot
.53626 .56933 Mdot
.61506 .47172 Mdot
.8518 .35334 Mdot
.28008 .49826 Mdot
.47388 .52236 Mdot
.62868 .41565 Mdot
.95614 .3755 Mdot
.34856 .49565 Mdot
.49975 .00033 Mdot
.49922 .00106 Mdot
.4975 .00337 Mdot
.49205 .01074 Mdot
.47466 .03414 Mdot
.41943 .10568 Mdot
.24843 .25322 Mdot
.83871 .12801 Mdot
.63159 .01945 Mdot
.60012 .55067 Mdot
.70913 .40796 Mdot
.04904 .4527 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00398 Mdot
.4906 .01269 Mdot
.47007 .04027 Mdot
.40491 .12328 Mdot
.20544 .26508 Mdot
.77654 .11958 Mdot
.58306 .04603 Mdot
.50858 .03807 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01097 Mdot
.47412 .03486 Mdot
.41771 .1078 Mdot
.24328 .25521 Mdot
.83034 .12607 Mdot
.62635 .02086 Mdot
.59261 .5578 Mdot
.69006 .4206 Mdot
.00952 .42942 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51067 .60363 Mdot
.53398 .57237 Mdot
.60787 .47985 Mdot
.83146 .35121 Mdot
.26319 .49825 Mdot
.45701 .53762 Mdot
.58711 .46084 Mdot
.84146 .33699 Mdot
.2962 .47837 Mdot
.50033 .61759 Mdot
.50105 .61662 Mdot
.50334 .61352 Mdot
.51064 .60366 Mdot
.5339 .57247 Mdot
.60763 .48013 Mdot
.83076 .35118 Mdot
.26255 .49826 Mdot
.45634 .53823 Mdot
.58547 .46274 Mdot
.83674 .33657 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00294 Mdot
.49307 .00936 Mdot
.47793 .02976 Mdot
.42978 .09276 Mdot
.2797 .23774 Mdot
.89502 .14733 Mdot
.65664 .02445 Mdot
.61709 .54346 Mdot
.73774 .39636 Mdot
.09642 .48038 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.5078 .60749 Mdot
.52486 .58454 Mdot
.57905 .51424 Mdot
.74699 .36672 Mdot
.15362 .48803 Mdot
.36397 .59933 Mdot
.39423 .07229 Mdot
.27726 .21768 Mdot
.92506 .15074 Mdot
.50015 .61782 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.50501 .61126 Mdot
.51597 .59649 Mdot
.55083 .55016 Mdot
.66066 .42526 Mdot
.97257 .39996 Mdot
.32543 .53124 Mdot
.46586 .56265 Mdot
.55548 .51225 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00214 Mdot
.49495 .00682 Mdot
.48391 .02171 Mdot
.44878 .06838 Mdot
.33813 .19388 Mdot
.02443 .21644 Mdot
.67423 .0853 Mdot
.5362 .05203 Mdot
.45202 .09584 Mdot
.29695 .23701 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51256 .60107 Mdot
.54 .56438 Mdot
.62682 .45887 Mdot
.88435 .36085 Mdot
.30049 .50103 Mdot
.48982 .51046 Mdot
.66388 .384 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.5071 .60845 Mdot
.52261 .58756 Mdot
.57191 .52314 Mdot
.72545 .37735 Mdot
.11488 .47484 Mdot
.34657 .59605 Mdot
.38215 .07755 Mdot
.25666 .22497 Mdot
.89265 .13283 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50266 .61445 Mdot
.50846 .60661 Mdot
.52695 .58174 Mdot
.58567 .5061 Mdot
.76678 .35938 Mdot
.1853 .4949 Mdot
.38454 .59279 Mdot
.42539 .04142 Mdot
.35837 .15606 Mdot
.50011 .61789 Mdot
.50034 .61758 Mdot
.50108 .61657 Mdot
.50345 .61337 Mdot
.51099 .6032 Mdot
.53499 .57102 Mdot
.61107 .47621 Mdot
.84055 .3519 Mdot
.27115 .49815 Mdot
.46513 .53021 Mdot
.60723 .43815 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49732 .00362 Mdot
.49145 .01155 Mdot
.47277 .03667 Mdot
.41344 .11301 Mdot
.23059 .25946 Mdot
.81077 .12254 Mdot
.6125 .02672 Mdot
.56926 .58255 Mdot
.62667 .47713 Mdot
.85465 .36035 Mdot
.50072 .61705 Mdot
.50231 .61491 Mdot
.50736 .60809 Mdot
.52344 .58644 Mdot
.57456 .51982 Mdot
.73348 .37306 Mdot
.12985 .48053 Mdot
.35234 .5986 Mdot
.38378 .07898 Mdot
.25598 .22642 Mdot
.88962 .13211 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50733 .60813 Mdot
.52336 .58655 Mdot
.57429 .52015 Mdot
.73267 .37348 Mdot
.12836 .47999 Mdot
.35172 .59842 Mdot
.38346 .07902 Mdot
.2556 .22647 Mdot
.88916 .13183 Mdot
.50016 .61782 Mdot
.50051 .61734 Mdot
.50164 .61582 Mdot
.50522 .61098 Mdot
.51663 .5956 Mdot
.55292 .54744 Mdot
.66716 .41943 Mdot
.9885 .40878 Mdot
.32708 .53936 Mdot
.45438 .58107 Mdot
.51419 .56793 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00814 Mdot
.48081 .02589 Mdot
.43893 .08112 Mdot
.30766 .21909 Mdot
.95317 .1763 Mdot
.66791 .04795 Mdot
.59033 .58667 Mdot
.64108 .47234 Mdot
.87682 .36921 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61507 Mdot
.507 .60858 Mdot
.5223 .58798 Mdot
.57093 .52438 Mdot
.72247 .37903 Mdot
.10919 .4725 Mdot
.34467 .5947 Mdot
.38242 .07602 Mdot
.25941 .22331 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.46631 .04529 Mdot
.39303 .13715 Mdot
.17111 .26694 Mdot
.73919 .11974 Mdot
.54545 .07817 Mdot
.41896 .15009 Mdot
.17611 .28202 Mdot
.71979 .13712 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.4678 .04329 Mdot
.39775 .1317 Mdot
.18466 .26698 Mdot
.75268 .11946 Mdot
.55939 .06567 Mdot
.45314 .10849 Mdot
.2776 .25382 Mdot
.8669 .14432 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48754 .01682 Mdot
.46032 .05323 Mdot
.37419 .15809 Mdot
.1184 .258 Mdot
.70094 .11741 Mdot
.51096 .10725 Mdot
.33742 .2331 Mdot
.96027 .19664 Mdot
.64209 .08173 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.5231 .5869 Mdot
.57348 .52117 Mdot
.73021 .37476 Mdot
.12383 .47833 Mdot
.34989 .59775 Mdot
.3827 .07888 Mdot
.25507 .22635 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49149 .01149 Mdot
.47289 .03651 Mdot
.41382 .11255 Mdot
.23171 .25912 Mdot
.81245 .12279 Mdot
.61377 .02607 Mdot
.57158 .57996 Mdot
.63318 .47041 Mdot
.87204 .36416 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.5113 .60278 Mdot
.53599 .56969 Mdot
.6142 .47268 Mdot
.8494 .35298 Mdot
.27826 .49821 Mdot
.47214 .5239 Mdot
.62445 .41993 Mdot
.94499 .36994 Mdot
.34641 .49124 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50611 .60978 Mdot
.51948 .59176 Mdot
.56198 .53575 Mdot
.69512 .39689 Mdot
.05295 .44507 Mdot
.33281 .57309 Mdot
.40552 .03759 Mdot
.3447 .15977 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49027 .01314 Mdot
.46902 .04167 Mdot
.40159 .1272 Mdot
.19577 .26627 Mdot
.76494 .11937 Mdot
.5718 .05505 Mdot
.48273 .07103 Mdot
.3678 .17997 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49427 .00773 Mdot
.48176 .02461 Mdot
.44195 .07724 Mdot
.31697 .21191 Mdot
.97409 .188 Mdot
.6699 .05875 Mdot
.57484 .60993 Mdot
.58795 .53248 Mdot
.72639 .38656 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00233 Mdot
.49451 .00742 Mdot
.4825 .02362 Mdot
.44428 .07422 Mdot
.32419 .20602 Mdot
.99084 .19753 Mdot
.67122 .0677 Mdot
.56168 .01193 Mdot
.54237 .59115 Mdot
.58587 .51535 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49855 .00195 Mdot
.49539 .00622 Mdot
.48532 .01981 Mdot
.45327 .06251 Mdot
.35212 .18071 Mdot
.05972 .23479 Mdot
.67983 .10135 Mdot
.51583 .0867 Mdot
.37556 .19066 Mdot
.06706 .25101 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002=ooooo`030?l00?oooooooooo00Wooooo00<0o`00
ooooooooool00_ooool20?l00003ooooo`3o003ooooo00Cooooo00<0o`00ooooooooool01Oooool0
0`3o003oooooooooo`1^ooooo`009_oooomWo`0000030?l00?l0003o000000Co000000H0o`00o`00
0?l0003o00000?l00?l000020?l00004o`00003o0000o`00o`000080o`0000?o00000?l00?l00000
0_l000000`3o003o0000o`000004o`000080o`00I?l00003000000Wooooo000Vooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`03ooooo`030?l00?oo
oooooooo00Cooooo0P3o0002ooooo`050?l00?oooooooooo0?l00?ooool01@3o00000oooool0o`00
0?l00002ooooo`030?l00?oooooooooo00Cooooo0P3o0007ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0;Oooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`1Rooooo`80o`001Oooool20?l000;ooooo0P3o00000oooool0o`000?l000050?l00003ooooo`3o
0000o`0000;ooooo0P3o0006ooooo`030?l00?oooooooooo06Kooooo00<00000ooooooooool01ooo
ool002Kooooo00?o0000ooooooooool0H_ooool00`3o003oooooooooo`03ooooo`80o`000oooool0
0`3o003oooooooooo`090?l000;ooooo0P3o0006ooooo`80o`00J?ooool00`00003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`1Qooooo`80o`001?ooool20?l000?ooooo00<0o`00oooo
o`3o00001P3o0002ooooo`030?l00?oooooooooo0080o`001_ooool20?l000oooooo203o001Boooo
o`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo063ooooo0P3o0004ooooo`80
o`000oooool20?l00003ooooo`3o003ooooo00@0o`000_ooool20?l000;ooooo00<0o`00oooooooo
ool01Oooool00`3o003oooooooooo`0;ooooo`@0o`001_ooool20?l0057ooooo00<00000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0H?ooool00`3o003oooooooooo`03ooooo`040?l0
0?ooooooooooooooo`80o`0000?ooooo0?l00?ooool00P3o0002ooooo`040?l00?ooool0o`000?l0
00;ooooo00<0o`00ooooooooool01Oooool20?l000cooooo0P3o000:ooooo`80o`00D?ooool00`00
003oooooooooo`07ooooo`009_ooool2o`00063ooooo00<0o`00ooooooooool00oooool00`3o003o
ooooooooo`02ooooo`030?l00?ooool0o`0000H0o`0000?ooooo0?l0003o00000_ooool20?l000Ko
oooo0P3o000;ooooo`<0o`003?ooool00`3o003oooooooooo`1=ooooo`03o`000000003ooooo00So
oooo000Vooooo`03o`000?oooooooooo05kooooo0P3o0004ooooo`030?l00?oooooooooo00;ooooo
00D0o`00ooooooooool0o`00ooooo`030?l000?ooooo00<0o`00ooooooooool00P3o0007ooooo`03
0?l00?oooooooooo00Wooooo0P3o000>ooooo`80o`00Coooool00`00003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`1Nooooo`030?l00?oooooooooo00;ooooo0P3o0003ooooo`@0o`00
00?ooooo0?l0003o00000`3o00001?ooool0o`000?l00?ooool20?l000Oooooo0P3o0009ooooo`80
o`004Oooool00`3o003oooooooooo`1=ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo05gooooo0P3o0003ooooo`80o`000oooool20?l00004ooooo`3o0000o`00ooooo`80
o`0000Gooooo0?l00?oooooooooo0?l00002ooooo`030?l00?oooooooooo00Kooooo00<0o`00oooo
ooooool01oooool20?l001;ooooo00<0o`00ooooooooool0COooool00`00003oooooooooo`07oooo
o`009_ooool00ol0003oooooooooo`1Looooo`80o`000oooool20?l000Cooooo00D0o`00ooooo`3o
0000o`00ooooo`040?l000;ooooo00@0o`00ooooooooool0o`002?ooool20?l000Sooooo0P3o000C
ooooo`80o`00C_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Loooo
o`040?l00?ooooooooooooooo`80o`001?ooool00`3o003ooooo0?l000070?l00004ooooo`3o003o
ooooooooo`80o`001oooool20?l000Oooooo0P3o000Fooooo`030?l00?oooooooooo04cooooo00<0
0000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Foooool20?l000;ooooo0P3o0004
ooooo`030?l00?oooooooooo00L0o`0000Cooooo0?l0003o003ooooo0P3o0008ooooo`030?l00?oo
oooooooo00Gooooo0P3o000Gooooo`030?l00?oooooooooo04cooooo00<00000ooooooooool01ooo
ool002Kooooo0_l0001Kooooo`80o`000_ooool20?l000Cooooo0P3o00000oooool0o`000?l00005
0?l00004ooooo`3o0000o`00ooooo`80o`002?ooool20?l000Kooooo0P3o000Hooooo`030?l00?oo
oooooooo04_ooooo00?o000000000?ooool02?ooool002Kooooo00?o0000ooooooooool0F_ooool0
0`3o003oooooooooo`020?l000Cooooo0P3o00001?ooool0o`00ooooooooool20?l00005ooooo`3o
003oooooooooo`3o00000_ooool00`3o003oooooooooo`06ooooo`80o`001_ooool20?l001Wooooo
00<0o`00ooooooooool0C?ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`1Iooooo`80o`0000?ooooo0?l0003o00001Oooool00`3o003ooooo0?l000070?l00005ooooo`3o
003oooooooooo`3o00002Oooool00`3o003oooooooooo`04ooooo`80o`006_ooool00`3o003ooooo
ooooo`1<ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05Wooooo00@0
o`00ooooo`3o0000o`001Oooool20?l00003ooooo`3o0000o`0000D0o`0000Cooooo0?l00?oooooo
oooo0P3o0008ooooo`80o`001Oooool20?l001_ooooo00<0o`00ooooooooool0C?ooool00`00003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Iooooo`80o`001_ooool40?l00007oooo
o`3o0000o`000?l00?ooool0o`00ooooo`020?l00003ooooo`3o0000o`0000Wooooo00<0o`00oooo
ooooool00_ooool30?l001Gooooo00<0o`00ooooooooool01Oooool00`3o003oooooooooo`1;oooo
o`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo063ooooo0P3o00000oooool0
o`000?l000030?l00006ooooo`3o003oooooooooo`3o003ooooo0P3o0009ooooo`80o`000oooool2
0?l001Oooooo0P3o0006ooooo`030?l00?oooooooooo04_ooooo00<00000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool0H?ooool0103o003ooooo0?l00?ooool50?l000;ooooo0P3o0000
0oooool0o`00ooooo`09ooooo`040?l00?ooooooooooooooo`80o`006?ooool00`3o003ooooooooo
o`05ooooo`030?l00?oooooooooo04_ooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0Goooool01@3o003ooooo0?l0003o003ooooo0080o`0000Cooooo0?l0003o003ooooo
0P3o00000oooool0o`000?l00009ooooo`80o`000_ooool20?l001[ooooo00<0o`00ooooooooool0
1?ooool00`3o003oooooooooo`1;ooooo`0300000?oooooooooo00Oooooo000Vooooo`;o0000Gooo
ool00`3o003ooooo0?l000040?l00003ooooo`3o0000o`0000;ooooo00@0o`00ooooo`3o0000o`00
2_ooool00`3o003oooooooooo`020?l001_ooooo00<0o`00ooooooooool01?ooool20?l004_ooooo
00?o000000000?ooool02?ooool002Kooooo00?o0000ooooooooool0GOooool50?l00003ooooo`3o
003ooooo0080o`000_ooool0103o003ooooo0?l0003o000:ooooo`80o`0000?ooooo0?l0003o0000
7?ooool00`3o003oooooooooo`05ooooo`030?l00?oooooooooo04[ooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0G?ooool40?l00003ooooo`3o0000o`0000<0o`000_oo
ool40?l000_ooooo00@0o`00ooooo`3o0000o`007Oooool00`3o003oooooooooo`05ooooo`80o`00
Boooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1Kooooo`80o`0000?o
oooo0?l0003o00000`3o00001?ooool0o`000?l00?ooool20?l00003ooooo`3o003ooooo00_ooooo
0`3o000Nooooo`030?l00?oooooooooo00Kooooo0P3o001:ooooo`0300000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo05[ooooo0P3o00001?ooool0o`00ooooooooool20?l00003oooo
o`3o0000o`0000;ooooo00@0o`00ooooo`3o0000o`00;Oooool20?l000Sooooo0P3o0019ooooo`03
00000?oooooooooo00Oooooo000Cooooo`;o00001?ooool01?l0003oooooooooooooool5o`0000Co
oooo00?o0000ooooooooool0F_ooool00`3o003ooooo0?l000070?l000;ooooo00@0o`00ooooo`3o
0000o`00;oooool00`3o003oooooooooo`07ooooo`@0o`00A_ooool00`00003oooooooooo`07oooo
o`004_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0FOooool00`3o003ooooo0?l000040?l000;ooooo00D0o`00ooooooooool0o`00oooo
o`020?l0033ooooo00<0o`00ooooooooool02_oooolI0?l002kooooo00<00000ooooooooool01ooo
ool001;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`04ooooo`;o0000FOoo
ool0103o003ooooo0?l0003o0002ooooo`80o`0000Cooooo0?l00?oooooooooo103o000aooooo`80
o`008oooool70?l002Kooooo0`000009ooooo`004_ooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool30?l000?ooooo1@3o00001Oooool0
o`000?l00?ooool0o`0003?ooooo00<0o`00ooooooooool09oooool50?l002Cooooo00<00000oooo
ooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool0E_ooool20?l00003ooooo`3o003ooooo00<0o`0000?ooooo
0?l0003o00000_ooool0103o003ooooo0?l0003o000cooooo`80o`004_ooool30?l00003ooooo`3o
0000o`0000`0o`0000Cooooo0?l0003o0000o`001?ooool50?l000Gooooo0`3o000Hooooo`030000
0?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo05Kooooo00<0o`00ooooo`3o0000103o00000oooool0
o`00ooooo`02ooooo`040?l00?ooool0o`000?l003Gooooo0`3o000:ooooo`L0o`005_ooool30?l0
00Cooooo103o0004ooooo`<0o`005_ooool00`00003oooooooooo`07ooooo`004oooool2o`0000Wo
oooo0ol00005ooooo`03o`000?oooooooooo05Cooooo103o0002ooooo`D0o`000_ooool40?l003So
oooo303o000Qooooo`80o`000oooool30?l000Cooooo0`3o000Dooooo`0300000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo05?ooooo00D0o`00ooooo`3o0000o`00ooooo`060?l000;o
oooo103o001Yooooo`80o`000_ooool40?l000?ooooo0`3o000Booooo`0300000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo05;ooooo0P3o00000oooool0o`00ooooo`030?l000;ooooo
0P3o00000oooool0o`000?l000020?l006cooooo0`3o0002ooooo`<0o`000_ooool40?l0013ooooo
00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0DOooool40?l00003ooooo`3o
003ooooo00@0o`000oooool00`3o003ooooo0?l0001`ooooo`040?l00?ooooooooooooooo`<0o`00
0oooool30?l000kooooo00<00000ooooooooool01oooool002Kooooo0_l0001Aooooo`050?l00?oo
oooooooo0?l00?ooool0103o00000oooool0o`00ooooo`02ooooo`040?l00?ooool0o`000?l007?o
oooo0P3o00001?ooool0o`000?l0003o0002ooooo`@0o`002oooool00ol000000000ooooo`08oooo
o`009_ooool00ol0003oooooooooo`1?ooooo`@0o`0000?ooooo0?l00?ooool01@3o0002ooooo`@0
o`00M_ooool20?l00004ooooo`3o0000o`000?l000;ooooo103o000:ooooo`0300000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo04kooooo103o0003ooooo`D0o`000_ooool40?l007Wo
oooo00<0o`00ooooooooool00`3o0002ooooo`<0o`002Oooool00`00003oooooooooo`07ooooo`00
9_ooool00ol0003oooooooooo`1=ooooo`070?l00?ooool0o`000?l00?ooool0o`00ooooo`020?l0
0003ooooo`3o0000o`0000;ooooo103o001nooooo`@0o`000_ooool30?l000Oooooo00<00000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool0C?ooool40?l00003ooooo`3o003ooooo00D0
o`000oooool30?l007oooooo00<0o`00ooooooooool00`3o0002ooooo`80o`001_ooool00`00003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1:ooooo`80o`0000Gooooo0?l0003o0000
o`00ooooo`060?l000?ooooo0`3o0023ooooo`030?l00?ooool0o`000080o`0000Gooooo0?l0003o
003ooooo0?l00003ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Wo
oooo0P3o00000oooool0o`000?l000060?l000Gooooo0`3o0025ooooo`80o`0000?ooooo0?l0003o
00000_ooool30?l000;ooooo00<00000ooooooooool01oooool002Kooooo0_l00019ooooo`80o`00
00Cooooo0?l00?oooooooooo103o00000oooool0o`000?l00003ooooo`<0o`00R?ooool50?l00003
ooooo`3o0000o`000080o`0000<00000ooooooooool01oooool002Kooooo00<0o`00ooooooooool0
Aoooool40?l00004ooooo`3o0000o`00ooooo`80o`0000?ooooo0?l0003o00000oooool30?l008_o
oooo1@3o00001?ooool0o`000?l0003o0009ooooo`009_ooool00ol00000o`000?l00015ooooo`D0
o`0000?ooooo0?l0003o00001P3o0003ooooo`<0o`00ROooool30?l00004ooooo`3o003ooooooooo
o`80o`000_ooool00`3o003oooooooooo`07ooooo`009_ooool00ol00000o`000?l000020?l004;o
oooo1@3o0002ooooo`L0o`000oooool30?l008cooooo0`3o0002ooooo`050?l00?ooool0o`000?l0
000000002Oooool002Kooooo0P3o00000oooool0o`000?l000020?l003oooooo103o0002ooooo`03
0?l00?ooool0o`000080o`0000?ooooo0?l00?ooool00oooool30?l008kooooo103o0002ooooo`03
0?l00?ooool0o`0000Wooooo000Vooooo`@0o`0000?ooooo0?l0003o00000P3o000kooooo`D0o`00
0_ooool40?l00004ooooo`3o0000o`000?l000?ooooo0`3o002Aooooo`<0o`000_ooool20?l000Wo
oooo000Vooooo`030?l00?oooooooooo0080o`0000?ooooo0?l0003o00000P3o000hooooo`D0o`00
1?ooool70?l000?ooooo0`3o002Dooooo`<0o`0000?ooooo00000?ooool02?ooool002Kooooo00<0
o`00ooooooooool00_ooool20?l00003ooooo`3o0000o`000080o`00=Oooool40?l000Gooooo1`3o
0003ooooo`<0o`00Uoooool30?l000Wooooo000Vooooo`<0o`000_ooool40?l00003ooooo`3o0000
o`000080o`00<Oooool50?l000?ooooo1P3o00000oooool0o`00ooooo`03ooooo`<0o`00VOooool0
0ol00000o`00ooooo`08ooooo`009_ooool00ol00000o`000?l000020?l00003ooooo`3o0000o`00
00<0o`0000Cooooo0?l0003o0000o`00;_ooool50?l000;ooooo0`3o00000oooool0o`000?l00004
0?l000Cooooo0`3o002Kooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo
00@0o`0000?ooooo0?l00?ooool00`3o00000oooool0o`000?l000020?l002_ooooo0P3o0005oooo
o`D0o`000_ooool20?l000Cooooo0`3o002Looooo`0300000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo00;ooooo103o00000oooool0o`000?l000030?l00003ooooo`3o0000o`0000<0
o`00;?ooool60?l000;ooooo0P3o0005ooooo`<0o`00WOooool00`00003oooooooooo`07ooooo`00
4oooool2o`0000Cooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000ooooooooool0
1?ooool60?l00005ooooo`3o0000o`000?l00?ooool01@3o000Zooooo`030?l00?ooool0o`0000L0
o`001Oooool20?l009kooooo00<00000ooooooooool01oooool001;ooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo0`3o0002ooooo`D0
o`0000?ooooo0?l0003o00000P3o000Tooooo`T0o`0000Cooooo0?l0003o0000o`00Yoooool00`00
003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`Go00001?ooool00ol0
003oooooooooo`08ooooo`<0o`000_ooool00`3o003ooooo0?l000030?l00003ooooo`3o003ooooo
00<0o`007_ooool30?l00003ooooo`3o0000o`0000D0o`0000?ooooo0?l0003o0000Z?ooool00`00
003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Gooooo0_l0000;ooooo`@0o`0000?ooooo0?l0003o0000103o0002ooooo`@0o`006Oooool9
0?l00003ooooo`3o003ooooo00<0o`00Z?ooool3000000Wooooo000Booooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0<ooooo`@0o`0000?ooooo
0?l0003o00001@3o0002ooooo`<0o`0000Gooooo0?l00?oooooooooo0?l0000=ooooo`P0o`0000?o
oooo0?l0003o00000`3o00000oooool0o`000?l000020?l00:_ooooo00<00000ooooooooool01ooo
ool001;ooooo00Co0000oooooooooooo00002Oooool2o`0000Gooooo00?o0000ooooooooool03_oo
ool40?l000Cooooo1@3o0002ooooo`@0o`0000?ooooo0?l00?ooool0103o00000oooool0o`000?l0
00060?l00004ooooo`3o003oooooooooo`@0o`000_ooool00`3o003ooooo0?l000020?l00:gooooo
00<00000ooooooooool01oooool001?ooooo0_l0000;ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04?ooool50?l000;ooooo0P3o00000oooool0o`000?l000040?l000?ooooo00<0
o`00ooooo`3o00000P3o0002ooooo`D0o`000_ooool60?l000Cooooo0`3o002_ooooo`0300000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo01?ooooo1@3o0002ooooo`@0o`0000?ooooo
0?l0003o00004P3o00001_ooool0o`00ooooooooool0o`00ooooo`<0o`00/Oooool00`00003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`0Eooooo`H0o`000oooool30?l000;ooooo00<0
o`00ooooooooool01_ooool01@3o003ooooo0?l0003o003ooooo0080o`0000?ooooo0?l0003o0000
103o002cooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo01Sooooo2@3o
0004ooooo`@0o`001oooool00`3o003oooooooooo`040?l00;Kooooo00<00000ooooooooool01ooo
ool002Kooooo0_l0000Mooooo`L0o`0000?ooooo0?l0003o00000`3o00000oooool0o`000?l00008
0?l00;Sooooo00?o000000000?ooool02?ooool002Kooooo00?o0000ooooooooool08Oooool>0?l0
0;kooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00`00003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`0300000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo0>gooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0kOooool00`00003oooooooooo`07ooooo`001oooool3o`0001cooooo00?o0000oooo
ooooool0kOooool00`00003oooooooooo`07ooooo`002?ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo0>gooooo00<00000ooooooooool01oooool000Sooooo00?o0000ooooooooool0
6oooool2o`000>gooooo00?o000000000?ooool02?ooool000Sooooo0_l0000Looooo`03o`000?oo
oooooooo0>gooooo00<00000ooooooooool01oooool000Oooooo0_l000000ooooooo0000o`00000J
ooooo`03o`000?oooooooooo0>gooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0kOooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`03
00000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0>gooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0_?ooool>0?l002?ooooo00<00000ooooooooool01ooo
ool002Kooooo0_l0002hooooo`H0o`000_ooool20?l00007ooooo`3o0000o`000?l00?ooool0o`00
ooooo`070?l001gooooo00?o000000000?ooool02?ooool002Kooooo00?o0000ooooooooool0]?oo
ool60?l00003ooooo`3o003ooooo00;ooooo0P3o0002ooooo`030?l00?ooool0o`0000Kooooo1`3o
000Jooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo0;7ooooo1P3o0003
ooooo`80o`002oooool60?l000?ooooo1P3o000Gooooo`0300000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo0;3ooooo1@3o0002ooooo`030?l00?ooool0o`0001<0o`001?ooool00`3o
003ooooo0?l000050?l001Cooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool0[Oooool=0?l000;ooooo0P3o00001?ooool0o`00ooooooooool30?l00003ooooo`3o003ooooo
00Cooooo1@3o0002ooooo`80o`000_ooool40?l001;ooooo00<00000ooooooooool01oooool001?o
oooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol00005ooooo`03o`000?oooooooooo0:_o
oooo1P3o00000oooool0o`000?l000020?l000;ooooo303o00000oooool0o`000?l000040?l00003
ooooo`3o0000o`0000;ooooo103o00000oooool0o`00ooooo`02ooooo`@0o`004?ooool00`00003o
ooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooooooo`2Zooooo`<0o`0000?ooooo0?l0003o00000`3o00001?oo
ool0o`00ooooooooool40?l000kooooo103o00000oooool0o`000?l000020?l00003ooooo`3o0000
o`000080o`0000Cooooo0?l0003o003ooooo103o000>ooooo`0300000?oooooooooo00Oooooo000B
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo0:Sooooo2P3o0002ooooo`030?l00?oooooooooo01Oooooo1P3o0002ooooo`@0o`00
00?ooooo0?l00?ooool00_ooool30?l000_ooooo00<00000ooooooooool01oooool001;ooooo00Co
0000oooooooooooo00001oooool4o`0000Gooooo0_l0002Wooooo`D0o`0000?ooooo0?l0003o0000
0`3o0002ooooo`030?l00?oooooooooo01cooooo0`3o00001?ooool0o`000?l00?ooool30?l000Co
oooo103o0007ooooo`<000002Oooool001;ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0:Kooooo0P3o0002ooooo`<0o`000_ooool20?l002?o
oooo1P3o00001Oooool0o`000?l0003o003ooooo0080o`0000?ooooo0?l0003o00000P3o0007oooo
o`0300000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2Looooo`80o`001_ooool00`3o003ooooo0?l00002oooo
o`80o`000_ooool20?l002Sooooo103o0002ooooo`<0o`001?ooool40?l000Gooooo00<00000oooo
ooooool01oooool001?ooooo0_l0000:ooooo`;o00001Oooool00ol0003oooooooooo`2Kooooo`<0
o`001?ooool20?l000;ooooo0`3o00000oooool0o`000?l0000^ooooo`@0o`0000Kooooo0?l0003o
0000o`00ooooo`3o0002ooooo`<0o`001?ooool00`00003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`2Jooooo`<0o`001?ooool20?l00003ooooo`3o0000o`0000D0o`001?ooool20?l0
02_ooooo0`3o00000oooool0o`000?l000040?l000;ooooo0`3o0002ooooo`0300000?oooooooooo
00Oooooo000Vooooo`03o`000?oooooooooo09Wooooo0`3o0004ooooo`P0o`0000?ooooo0?l00?oo
ool00_ooool40?l002kooooo0`3o00001?ooool0o`000?l0003o0003ooooo`@0o`0000<00000oooo
ooooool01oooool002Kooooo0P3o002Iooooo`<0o`001?ooool20?l000;ooooo0P3o0006ooooo`@0
o`00<Oooool01@3o003ooooo0?l0003o003ooooo00T0o`002Oooool002Kooooo0`3o002Gooooo`<0
o`000oooool90?l000?ooooo103o000eooooo`@0o`0000?ooooo0?l0003o00000P3o00000ooooooo
00000?l00009ooooo`009_ooool00ol0003ooooo0?l000020?l009Cooooo0`3o0003ooooo`030?l0
0?ooool0o`0000<0o`000_ooool00`3o003oooooooooo`050?l003Sooooo103o00000oooool0o`00
0?l000030?l000Wooooo000Vooooo`04o`00003o003oooooooooo`<0o`00TOooool30?l000?ooooo
0P3o0002ooooo`80o`0000Cooooo0?l0003o003ooooo1@3o000looooo`<0o`000_ooool20?l00003
00000?oooooooooo00Oooooo000Vooooo`80o`0000?ooooo0?l00?ooool0103o002>ooooo`<0o`00
0oooool20?l000;ooooo103o0002ooooo`D0o`00@?ooool20?l00003ooooo`3o0000o`0000Wooooo
000Vooooo`06o`00003o0000o`000?l00?ooool0o`000_ooool30?l008_ooooo0`3o0003ooooo`80
o`0000?ooooo0?l0003o00000P3o00000oooool0o`000?l000040?l004;ooooo103o00000`00003o
ooooooooo`07ooooo`009_ooool00`3o003oooooooooo`020?l00004ooooo`3o0000o`00ooooo`<0
o`00ROooool30?l000?ooooo0`3o00000oooool0o`000?l000020?l00004ooooo`3o0000o`00oooo
o`80o`00AOooool20?l0000300000?oooooooooo00Oooooo000Vooooo`<0o`0000?ooooo0?l0003o
00000P3o00000oooool0o`00ooooo`29ooooo`<0o`000oooool00`3o003ooooo0?l000020?l000;o
oooo00@0o`00ooooo`3o003ooooo0P3o0019ooooo`030?l00?oooooooooo00Oooooo000Vooooo`03
o`00003o0000o`000080o`0000Kooooo0?l0003o0000o`00ooooo`3o0028ooooo`<0o`000oooool2
0?l00003ooooo`3o0000o`0000;ooooo00<0o`00ooooo`3o00000`3o0019ooooo`03o`000000003o
oooo00Sooooo000Vooooo`03o`000?oooooooooo00<0o`000_ooool40?l008Kooooo103o0002oooo
o`L0o`0000Cooooo0?l0003o003ooooo0P3o001;ooooo`0300000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo00;ooooo0`3o0002ooooo`80o`0000?ooooo0?l0003o0000P_ooool20?l0
00Cooooo1@3o00000oooool0o`00ooooo`020?l00003ooooo`3o003ooooo04cooooo00<00000oooo
ooooool01oooool002Kooooo00?o0000ooooooooool00oooool40?l000;ooooo0P3o00000oooool0
o`000?l0001oooooo`@0o`000_ooool20?l00006ooooo`3o0000o`00ooooo`3o003ooooo103o001>
ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Gooooo103o00001Ooo
ool0o`000?l0003o003ooooo0080o`00O?ooool40?l000;ooooo0P3o00000oooool0o`000?l00005
0?l00003ooooo`3o003ooooo04kooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool01oooool30?l000;ooooo0`3o00000oooool0o`00ooooo`1iooooo`@0o`000_ooool50?l0
00?ooooo103o001@ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Wo
oooo0`3o0002ooooo`<0o`000_ooool20?l007Gooooo0P3o00000oooool0o`00ooooo`02ooooo`03
0?l00?ooool0o`0000<0o`0000?ooooo0?l0003o00000P3o001Aooooo`0300000?oooooooooo00Oo
oooo000Vooooo`03o`000?oooooooooo00[ooooo103o0002ooooo`<0o`0000Cooooo0?l00?ooool0
o`00Loooool00`3o003ooooo0?l00003ooooo`@0o`000oooool40?l005;ooooo00<00000oooooooo
ool01oooool002Kooooo0_l0000=ooooo`@0o`000_ooool30?l00004ooooo`3o0000o`000?l0073o
oooo00@0o`00ooooo`3o0000o`000_ooool60?l00003ooooo`3o0000o`000080o`00D_ooool00ol0
00000000ooooo`08ooooo`009_ooool00ol0003oooooooooo`0>ooooo`@0o`000_ooool40?l00004
ooooo`3o0000o`000?l006cooooo0`3o0003ooooo`030?l00?ooool0o`0000P0o`00E?ooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0@ooooo`@0o`000oooool30?l000;o
oooo0`3o001Xooooo`80o`0000Cooooo0?l00?oooooooooo1P3o00000oooool0o`000?l000020?l0
05Gooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool04_ooool40?l000?o
oooo103o0002ooooo`@0o`007oooool<0?l003Sooooo0P3o00001_ooool0o`00ooooooooool0o`00
ooooo`T0o`00E_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Doooo
o`@0o`001?ooool40?l000;ooooo0`3o000Gooooo`@0o`0000?ooooo0?l0003o00002_ooool30?l0
03Gooooo0P3o00001Oooool0o`00ooooooooool0o`0000;ooooo0`3o00000oooool0o`00ooooo`02
0?l005Oooooo00<00000ooooooooool01oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo
00;ooooo0ol00005ooooo`03o`000?oooooooooo01Kooooo0`3o0006ooooo`@0o`001?ooool<0?l0
0003ooooo`3o0000o`0000H0o`004oooool20?l003?ooooo0P3o00000oooool0o`00ooooo`02oooo
o`040?l00?ooool0o`000?l000;ooooo0P3o00000oooool0o`00ooooo`1Gooooo`0300000?oooooo
oooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo02;ooooo1@3o000Yooooo`030?l00?oooooooooo037ooooo00D0
o`00ooooo`3o0000o`00ooooo`090?l00003ooooo`3o003ooooo05Sooooo00<00000ooooooooool0
1oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Co
oooo0_l0000Wooooo`L0o`008oooool20?l0037ooooo0P3o00001?ooool0o`00ooooooooool80?l0
0003ooooo`3o003ooooo05Oooooo0`000009ooooo`004_ooool01?l0003oooooooooool00008oooo
o`?o00001Oooool00ol0003oooooooooo`0/oooooaX0o`002oooool00`3o003oooooooooo`0^oooo
o`80o`0000Cooooo0?l00?oooooooooo1@3o00001Oooool0o`000?l00?ooool0o`0005_ooooo00<0
0000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0AOooool30?l000Wooooo00<0o`00ooooooooool0
;Oooool20?l00005ooooo`3o003oooooooooo`3o00000_ooool50?l00003ooooo`3o0000o`0005_o
oooo00<00000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool0Aoooool20?l000Sooooo0P3o000]oooo
o`80o`0000?ooooo0?l0003o00000_ooool50?l00003ooooo`3o003ooooo0080o`00G?ooool00`00
003oooooooooo`07ooooo`004oooool2o`0000Wooooo0ol00005ooooo`03o`000?oooooooooo04Wo
oooo00<0o`00ooooooooool01_ooool00`3o003oooooooooo`0Looooo`<0o`003?ooool01@3o003o
oooo0?l0003o003ooooo00D0o`000_ooool0103o003ooooo0?l0003o001Mooooo`0300000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo04Wooooo0P3o0007ooooo`030?l00?oooooooooo
01_ooooo0P3o00000oooool0o`00ooooo`0:ooooo`80o`0000Cooooo0?l00?oooooooooo2P3o001N
ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04[ooooo00<0o`00oooo
ooooool01Oooool00`3o003oooooooooo`0Jooooo`80o`0000?ooooo0?l0003o00002_ooool20?l0
0005ooooo`3o003oooooooooo`3o00000_ooool50?l00003ooooo`3o003ooooo05kooooo00<00000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0B_ooool20?l000Kooooo00<0o`00oooo
ooooool06Oooool20?l000;ooooo00<0o`00ooooooooool02?ooool20?l000;ooooo00@0o`00oooo
o`3o003ooooo0`3o00001Oooool0o`000?l00?ooool0o`00063ooooo00<00000ooooooooool01ooo
ool002Kooooo0_l0001<ooooo`030?l00?oooooooooo00Cooooo0P3o000Iooooo`80o`000oooool0
0`3o003oooooooooo`07ooooo`80o`0000?ooooo0?l00?ooool00_ooool40?l000Cooooo00<0o`00
ooooooooool0G_ooool00ol000000000ooooo`08ooooo`009_ooool00ol0003oooooooooo`1;oooo
o`030?l00?oooooooooo00Gooooo00<0o`00ooooooooool05_ooool20?l000?ooooo00<0o`00oooo
ooooool02?ooool0103o003oooooooooo`3o0002ooooo`L0o`0000?ooooo0?l0003o0000HOooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1;ooooo`030?l00?oooooooooo
00Cooooo0P3o000Gooooo`80o`000oooool20?l000Wooooo0P3o00001?ooool0o`00ooooooooool5
0?l00003ooooo`3o0000o`000080o`00H_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`1;ooooo`80o`001_ooool00`3o003oooooooooo`0Dooooo`80o`001?ooool00`3o
003oooooooooo`07ooooo`80o`0000Kooooo0?l0003o003ooooo0?l00?ooool20?l000;ooooo0P3o
0008ooooo`80o`00Foooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1<
ooooo`030?l00?oooooooooo01Wooooo0P3o0005ooooo`80o`002?ooool20?l00006ooooo`3o0000
o`00ooooo`3o003ooooo1P3o00000oooool0o`00ooooo`04ooooo`@0o`00Foooool00`00003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`1<ooooo`030?l00?oooooooooo01Sooooo0P3o
0006ooooo`030?l00?oooooooooo00Oooooo00D0o`00ooooooooool0o`00ooooo`020?l00008oooo
o`3o0000o`000?l00?ooool0o`00ooooo`3o0005ooooo`80o`0000?ooooo0?l0003o0000Foooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1<ooooo`030?l00?oooooooooo
01Oooooo0P3o0006ooooo`030?l00?oooooooooo00Oooooo00<0o`00ooooooooool00oooool60?l0
00;ooooo0P3o0004ooooo`80o`000_ooool00`3o003oooooooooo`1Jooooo`0300000?oooooooooo
00Oooooo000Vooooo`;o0000COooool00`3o003oooooooooo`0Fooooo`80o`001_ooool20?l000So
oooo0P3o00001?ooool0o`000?l00?ooool40?l000;ooooo00@0o`00ooooo`3o0000o`001?ooool2
0?l000;ooooo0P3o001Kooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`000?oooooooooo
04cooooo00<0o`00ooooooooool05Oooool20?l000Oooooo00<0o`00ooooooooool01_ooool20?l0
00;ooooo00D0o`00ooooo`3o0000o`00ooooo`020?l00005ooooo`3o003oooooooooo`3o00001?oo
ool20?l000;ooooo0P3o001Mooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo04cooooo0P3o000Eooooo`80o`001oooool20?l000Oooooo0P3o0002ooooo`030?l00?oooooo
oooo00L0o`0000?ooooo0?l00?ooool00oooool20?l000?ooooo00<0o`00ooooooooool0G?ooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`1=ooooo`030?l00?oooooooooo
017ooooo0P3o0009ooooo`030?l00?oooooooooo00Kooooo00@0o`00ooooooooool0o`000_ooool5
0?l00004ooooo`3o003ooooo0?l000Cooooo0P3o0003ooooo`80o`00G_ooool00`00003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`1=ooooo`030?l00?oooooooooo013ooooo0P3o0009
ooooo`80o`001oooool20?l00005ooooo`3o0000o`00ooooo`3o00000_ooool01@3o003ooooo0?l0
003o003ooooo0080o`000oooool20?l000Cooooo00<0o`00ooooooooool0GOooool00`00003ooooo
ooooo`07ooooo`009_ooool00ol0003oooooooooo`1=ooooo`030?l00?oooooooooo00oooooo0P3o
0009ooooo`80o`001oooool20?l000;ooooo00<0o`00ooooo`3o00001P3o00000oooool0o`000?l0
0003ooooo`80o`001?ooool00`3o003oooooooooo`1Nooooo`0300000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo04gooooo0P3o000>ooooo`80o`002oooool00`3o003oooooooooo`05
ooooo`80o`000_ooool00`3o003ooooo0?l000070?l00003ooooo`3o003ooooo00?ooooo00<0o`00
ooooooooool00_ooool20?l0063ooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0C_ooool00`3o003oooooooooo`0:ooooo`<0o`002oooool20?l000Oooooo00@0o`00oooo
ooooool0o`000_ooool40?l00003ooooo`3o0000o`0000Kooooo00<0o`00ooooooooool00oooool0
0`3o003oooooooooo`1Oooooo`0300000?oooooooooo00Oooooo000Vooooo`;o0000Coooool20?l0
00[ooooo0P3o000<ooooo`80o`001oooool0103o003oooooooooo`3o0002ooooo`80o`0000Kooooo
0?l00?oooooooooo0?l00?ooool20?l000?ooooo00<0o`00ooooooooool00oooool00`3o003ooooo
ooooo`1Oooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`000?oooooooooo04oooooo0P3o
0006ooooo`@0o`003Oooool00`3o003oooooooooo`05ooooo`80o`000_ooool00`3o003ooooo0?l0
00070?l00003ooooo`3o003ooooo00;ooooo0P3o0004ooooo`80o`00H_ooool00`00003ooooooooo
o`07ooooo`009_ooool00ol0003oooooooooo`1@ooooo`P0o`003oooool20?l000Kooooo0P3o0002
ooooo`030?l00?oooooooooo00;ooooo0P3o0002ooooo`030?l00?ooool0o`0000?ooooo0P3o0005
ooooo`030?l00?oooooooooo067ooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0Ioooool00`3o003oooooooooo`04ooooo`80o`000_ooool20?l00003ooooo`3o003ooooo
0080o`0000Gooooo0?l00?oooooooooo0?l00003ooooo`80o`001Oooool20?l006?ooooo00<00000
ooooooooool01oooool001kooooo0ol00005ooooo`03o`000?oooooooooo06Kooooo00<0o`00oooo
ooooool01Oooool0103o003oooooooooo`3o0002ooooo`@0o`0000Cooooo0?l0003o003ooooo0P3o
0003ooooo`030?l00?oooooooooo00?ooooo0P3o001Tooooo`0300000?oooooooooo00Oooooo000O
ooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0]
ooooo`0300000?oooooooooo00Gooooo0P3o0006ooooo`030?l00?oooooooooo00?ooooo00<0o`00
ooooooooool00P3o00000oooool0o`00ooooo`020?l000;ooooo0P3o0006ooooo`030?l00?oooooo
oooo00?ooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0]ooooo`0300000?oooooo
oooo00Oooooo000Oooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00`00
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`0300000?oooooooooo00Gooooo00D0o`00ooooooooooooooooo`000002
ooooo`80o`000_ooool01@3o003ooooo0?l0003o003ooooo00<0o`000oooool01`3o003ooooooooo
ooooool0o`00ooooool000001?ooool00`3o003oooooooooo`04ooooo`0300000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00<00000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00`00003oooooooooo`07ooooo`007oooool00ol0003ooooo
ooooo`04ooooofL0000000<0o`000000000000001@0000001@3o00000000000000000000o`0000@0
000000<0o`000000003o00001`0000000`3o0000000000000004000000030?l000000000000006D0
00002Oooool001oooooo00?o0000ooooooooool0o_ooool001kooooo0_l0003oooooo`7ooooo000O
ooooo`03o`000?oooooooooo0?kooooo003oooooob7ooooo0000\
\>"],
  ImageRangeCache->{{{73.4375, 302.812}, {548.312, 407}} -> {-0.54256, \
3.27218, 0.00417185, 0.0067502}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 0.618034 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -28 -6 ]
[-0.01875 .30902 -18 6 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(q) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.2 .61178 m
.2 .61803 L
s
.4 .61178 m
.4 .61803 L
s
.6 .61178 m
.6 .61803 L
s
.8 .61178 m
.8 .61803 L
s
.125 Mabswid
.05 .61428 m
.05 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.15 .61428 m
.15 .61803 L
s
.25 .61428 m
.25 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.35 .61428 m
.35 .61803 L
s
.45 .61428 m
.45 .61803 L
s
.5 .61428 m
.5 .61803 L
s
.55 .61428 m
.55 .61803 L
s
.65 .61428 m
.65 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.75 .61428 m
.75 .61803 L
s
.85 .61428 m
.85 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.95 .61428 m
.95 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .12361 m
1 .12361 L
s
.99375 .24721 m
1 .24721 L
s
.99375 .37082 m
1 .37082 L
s
.99375 .49443 m
1 .49443 L
s
.125 Mabswid
.99625 .0309 m
1 .0309 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .09271 m
1 .09271 L
s
.99625 .15451 m
1 .15451 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .21631 m
1 .21631 L
s
.99625 .27812 m
1 .27812 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .33992 m
1 .33992 L
s
.99625 .40172 m
1 .40172 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .46353 m
1 .46353 L
s
.99625 .52533 m
1 .52533 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .58713 m
1 .58713 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.5004 .00017 Mdot
.50127 .00054 Mdot
.50403 .00171 Mdot
.51285 .00545 Mdot
.54092 .01735 Mdot
.62968 .05486 Mdot
.89215 .16222 Mdot
.3043 .25472 Mdot
.49146 .11567 Mdot
.66583 .10776 Mdot
.0463 .23515 Mdot
.3583 .19283 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60744 Mdot
.42058 .58439 Mdot
.25189 .51378 Mdot
.84449 .36625 Mdot
.63497 .48854 Mdot
.60449 .5992 Mdot
.71972 .07122 Mdot
.06937 .2161 Mdot
.31823 .15381 Mdot
.4974 .61693 Mdot
.4917 .61451 Mdot
.47357 .60683 Mdot
.41596 .58243 Mdot
.23807 .50809 Mdot
.82212 .36096 Mdot
.6208 .49362 Mdot
.58379 .59516 Mdot
.66675 .05127 Mdot
.95651 .17908 Mdot
.3107 .2189 Mdot
.49773 .61707 Mdot
.49275 .61496 Mdot
.47692 .60825 Mdot
.42658 .58692 Mdot
.26997 .52125 Mdot
.87651 .37486 Mdot
.65025 .4782 Mdot
.61734 .5977 Mdot
.74494 .07886 Mdot
.11114 .22633 Mdot
.32386 .13147 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50277 .00117 Mdot
.50883 .00374 Mdot
.52811 .01192 Mdot
.58935 .03785 Mdot
.77768 .11639 Mdot
.20114 .26171 Mdot
.39703 .12107 Mdot
.44902 .03213 Mdot
.42583 .6037 Mdot
.29536 .5374 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50741 .00314 Mdot
.52362 .01002 Mdot
.57513 .03183 Mdot
.73519 .09892 Mdot
.13295 .24583 Mdot
.35368 .13642 Mdot
.38458 .01909 Mdot
.25712 .53926 Mdot
.89116 .39186 Mdot
.67604 .48508 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51269 .00538 Mdot
.5404 .01713 Mdot
.62808 .05419 Mdot
.88779 .16051 Mdot
.30222 .25613 Mdot
.49065 .11645 Mdot
.66505 .10779 Mdot
.04498 .23481 Mdot
.35833 .19366 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48938 .61353 Mdot
.46616 .60369 Mdot
.39257 .57255 Mdot
.1698 .48035 Mdot
.73797 .35115 Mdot
.54419 .49827 Mdot
.41584 .53871 Mdot
.16707 .46428 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51774 .00752 Mdot
.55647 .02394 Mdot
.67815 .0752 Mdot
.01464 .20796 Mdot
.3292 .19441 Mdot
.43398 .06476 Mdot
.44256 .0053 Mdot
.36682 .57123 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48037 .60971 Mdot
.43753 .59156 Mdot
.30337 .53512 Mdot
.94378 .39579 Mdot
.66677 .44684 Mdot
.5966 .57467 Mdot
.6626 .04079 Mdot
.93223 .16664 Mdot
.30047 .22759 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48243 .61058 Mdot
.44408 .59433 Mdot
.32356 .54355 Mdot
.98936 .41149 Mdot
.67111 .42134 Mdot
.56285 .55113 Mdot
.54643 .60789 Mdot
.59869 .03229 Mdot
.78967 .11803 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50971 .00412 Mdot
.53092 .01311 Mdot
.59822 .0416 Mdot
.80368 .12698 Mdot
.23442 .26621 Mdot
.42757 .11937 Mdot
.5158 .05452 Mdot
.62767 .06914 Mdot
.49965 .61788 Mdot
.49888 .61756 Mdot
.49642 .61652 Mdot
.48859 .6132 Mdot
.46366 .60263 Mdot
.3847 .56923 Mdot
.14753 .47145 Mdot
.71942 .35345 Mdot
.52565 .49828 Mdot
.37018 .52195 Mdot
.04087 .41451 Mdot
.49922 .6177 Mdot
.4975 .61697 Mdot
.49203 .61466 Mdot
.47462 .60727 Mdot
.41931 .58385 Mdot
.24809 .51221 Mdot
.83815 .36468 Mdot
.63125 .49016 Mdot
.59967 .59851 Mdot
.70799 .06695 Mdot
.04679 .20939 Mdot
.49932 .61775 Mdot
.49783 .61711 Mdot
.49309 .6151 Mdot
.47799 .6087 Mdot
.42999 .58837 Mdot
.28032 .52554 Mdot
.89625 .38066 Mdot
.65701 .47018 Mdot
.6169 .59324 Mdot
.73679 .0741 Mdot
.09458 .22113 Mdot
.49817 .61726 Mdot
.49416 .61556 Mdot
.48139 .61014 Mdot
.44078 .59293 Mdot
.31336 .53929 Mdot
.96588 .40328 Mdot
.66919 .43467 Mdot
.58111 .5636 Mdot
.60951 .01755 Mdot
.78951 .11125 Mdot
.20092 .25427 Mdot
.49827 .6173 Mdot
.49448 .61569 Mdot
.48241 .61058 Mdot
.44402 .59431 Mdot
.32338 .54347 Mdot
.98893 .41133 Mdot
.67107 .42159 Mdot
.56319 .55136 Mdot
.54762 .60841 Mdot
.60241 .03386 Mdot
.80043 .12238 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50598 .00254 Mdot
.51905 .00808 Mdot
.56062 .02569 Mdot
.69094 .08054 Mdot
.04373 .21804 Mdot
.33175 .17801 Mdot
.41185 .0495 Mdot
.36638 .58993 Mdot
.14322 .48011 Mdot
.73307 .36455 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51075 .00456 Mdot
.53423 .01451 Mdot
.60868 .04601 Mdot
.83375 .13911 Mdot
.26527 .26669 Mdot
.45914 .11982 Mdot
.5924 .08236 Mdot
.8566 .16329 Mdot
.30796 .27895 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50814 .00345 Mdot
.52594 .011 Mdot
.58248 .03494 Mdot
.75727 .10803 Mdot
.17054 .25542 Mdot
.37422 .12588 Mdot
.40827 .02104 Mdot
.31221 .55867 Mdot
.99542 .42225 Mdot
.6855 .42649 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50773 .00328 Mdot
.52463 .01044 Mdot
.57831 .03318 Mdot
.74478 .10289 Mdot
.14986 .25035 Mdot
.36192 .13106 Mdot
.39188 .01852 Mdot
.27186 .54386 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.507 .00297 Mdot
.52228 .00945 Mdot
.57089 .03004 Mdot
.72236 .09361 Mdot
.10896 .23894 Mdot
.3446 .14563 Mdot
.38244 .02339 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .0024 Mdot
.51806 .00766 Mdot
.55749 .02437 Mdot
.6813 .07652 Mdot
.02195 .21053 Mdot
.32978 .19025 Mdot
.42824 .06085 Mdot
.42266 .61459 Mdot
.30559 .54568 Mdot
.96419 .40704 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48375 .61114 Mdot
.44826 .5961 Mdot
.33652 .54898 Mdot
.02047 .4227 Mdot
.6738 .40378 Mdot
.53901 .53473 Mdot
.46216 .57053 Mdot
.32907 .53578 Mdot
.9861 .40607 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51625 .00689 Mdot
.55172 .02192 Mdot
.66341 .06903 Mdot
.97936 .19527 Mdot
.32619 .21435 Mdot
.46111 .08339 Mdot
.53829 .0477 Mdot
.67233 .08285 Mdot
.01725 .21317 Mdot
.4999 .61799 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48984 .61373 Mdot
.46765 .60432 Mdot
.39725 .57453 Mdot
.18323 .48576 Mdot
.75117 .35101 Mdot
.55784 .49855 Mdot
.44938 .551 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.5056 .00237 Mdot
.51784 .00756 Mdot
.55677 .02406 Mdot
.67906 .07558 Mdot
.01676 .20871 Mdot
.32937 .1932 Mdot
.43231 .06362 Mdot
.43676 .00275 Mdot
.34883 .56369 Mdot
.06674 .44369 Mdot
.49805 .61721 Mdot
.49377 .61539 Mdot
.48017 .60962 Mdot
.43688 .59128 Mdot
.30138 .53429 Mdot
.93949 .39437 Mdot
.66619 .44912 Mdot
.59928 .57668 Mdot
.67181 .04483 Mdot
.95484 .17492 Mdot
.30471 .21623 Mdot
.4981 .61723 Mdot
.49396 .61547 Mdot
.48075 .60987 Mdot
.43875 .59207 Mdot
.30712 .53668 Mdot
.95198 .39854 Mdot
.66778 .44239 Mdot
.59115 .57068 Mdot
.64391 .0326 Mdot
.88429 .14856 Mdot
.28335 .24663 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50204 .00087 Mdot
.50651 .00276 Mdot
.52074 .0088 Mdot
.56601 .02797 Mdot
.70746 .08743 Mdot
.07918 .22973 Mdot
.33696 .15932 Mdot
.39078 .03326 Mdot
.29332 .5578 Mdot
.49788 .61713 Mdot
.49325 .61517 Mdot
.47848 .60891 Mdot
.43154 .58902 Mdot
.28505 .5275 Mdot
.90559 .38351 Mdot
.65959 .466 Mdot
.61482 .59037 Mdot
.72772 .06978 Mdot
.07702 .21588 Mdot
.31525 .14723 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50319 .00135 Mdot
.51017 .00431 Mdot
.53238 .01373 Mdot
.60284 .04354 Mdot
.81704 .13238 Mdot
.24911 .26703 Mdot
.44244 .11949 Mdot
.55132 .06729 Mdot
.73584 .11404 Mdot
.15814 .261 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.5059 .0025 Mdot
.5188 .00797 Mdot
.55983 .02536 Mdot
.6885 .07952 Mdot
.03831 .21619 Mdot
.3312 .18102 Mdot
.41578 .05227 Mdot
.37983 .59582 Mdot
.49951 .61783 Mdot
.49843 .61737 Mdot
.49501 .61592 Mdot
.48409 .61129 Mdot
.44936 .59657 Mdot
.33995 .55041 Mdot
.02892 .42581 Mdot
.67475 .39915 Mdot
.53313 .5305 Mdot
.44083 .56099 Mdot
.26182 .5074 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50713 .00302 Mdot
.52271 .00963 Mdot
.57226 .03062 Mdot
.72649 .09532 Mdot
.11687 .24126 Mdot
.34727 .1424 Mdot
.38216 .02156 Mdot
.25602 .54007 Mdot
.89131 .39263 Mdot
.67725 .48574 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48045 .60975 Mdot
.4378 .59167 Mdot
.30419 .53546 Mdot
.94555 .39639 Mdot
.667 .44588 Mdot
.59546 .57382 Mdot
.65866 .03906 Mdot
.92236 .16297 Mdot
.29795 .23213 Mdot
.49791 .61715 Mdot
.49333 .61521 Mdot
.47877 .60903 Mdot
.43244 .5894 Mdot
.2878 .52864 Mdot
.91112 .38524 Mdot
.66094 .46341 Mdot
.61308 .58845 Mdot
.72093 .06665 Mdot
.06353 .21174 Mdot
.31335 .1544 Mdot
.49767 .61704 Mdot
.49256 .61488 Mdot
.47631 .60799 Mdot
.42465 .58611 Mdot
.26413 .51883 Mdot
.86582 .37187 Mdot
.64577 .48203 Mdot
.61507 .59906 Mdot
.74231 .07864 Mdot
.108 .22601 Mdot
.32384 .1334 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00125 Mdot
.50942 .004 Mdot
.53001 .01272 Mdot
.59534 .04038 Mdot
.79529 .12357 Mdot
.22437 .26518 Mdot
.4178 .11955 Mdot
.49335 .04669 Mdot
.55892 .04052 Mdot
.5008 .00034 Mdot
.50253 .00107 Mdot
.50808 .00342 Mdot
.52573 .01091 Mdot
.58179 .03465 Mdot
.75522 .10719 Mdot
.16726 .25465 Mdot
.3721 .1266 Mdot
.40509 .02039 Mdot
.304 .55556 Mdot
.9778 .41643 Mdot
.68479 .43694 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00306 Mdot
.52302 .00976 Mdot
.57322 .03102 Mdot
.7294 .09653 Mdot
.12233 .24284 Mdot
.3493 .14028 Mdot
.38252 .02053 Mdot
.25509 .53928 Mdot
.88905 .39181 Mdot
.67628 .48653 Mdot
.49842 .61736 Mdot
.49495 .61589 Mdot
.48393 .61122 Mdot
.44882 .59634 Mdot
.33828 .54971 Mdot
.02479 .42429 Mdot
.67427 .4014 Mdot
.53596 .53255 Mdot
.45112 .5656 Mdot
.29413 .521 Mdot
.90751 .37909 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51888 .008 Mdot
.56007 .02546 Mdot
.68926 .07984 Mdot
.03999 .21677 Mdot
.33137 .18008 Mdot
.41454 .0514 Mdot
.3756 .59397 Mdot
.16849 .49003 Mdot
.75327 .36142 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.5083 .00352 Mdot
.52645 .01121 Mdot
.58408 .03562 Mdot
.76205 .10999 Mdot
.17807 .25711 Mdot
.37933 .12438 Mdot
.41642 .02293 Mdot
.33384 .56699 Mdot
.04489 .43945 Mdot
.68949 .39839 Mdot
.4994 .61778 Mdot
.49809 .61723 Mdot
.49393 .61546 Mdot
.48065 .60983 Mdot
.43842 .59193 Mdot
.30609 .53625 Mdot
.94972 .39778 Mdot
.66751 .44362 Mdot
.5927 .57179 Mdot
.64919 .03492 Mdot
.89811 .15384 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.5099 .0042 Mdot
.53155 .01338 Mdot
.6002 .04243 Mdot
.80941 .1293 Mdot
.24092 .26669 Mdot
.43408 .11938 Mdot
.53117 .06 Mdot
.67471 .08871 Mdot
.03076 .22005 Mdot
.49745 .61695 Mdot
.49188 .61459 Mdot
.47415 .60707 Mdot
.4178 .58321 Mdot
.24358 .51035 Mdot
.83081 .36293 Mdot
.62666 .49186 Mdot
.59307 .59727 Mdot
.69125 .06068 Mdot
.01208 .19829 Mdot
.31481 .18709 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50503 .00213 Mdot
.51604 .0068 Mdot
.55105 .02164 Mdot
.66135 .06816 Mdot
.97428 .1934 Mdot
.32563 .21714 Mdot
.46469 .08595 Mdot
.55122 .05348 Mdot
.71326 .10015 Mdot
.10771 .24378 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50435 .00184 Mdot
.51385 .00587 Mdot
.54411 .0187 Mdot
.6397 .05908 Mdot
.91895 .17259 Mdot
.31459 .24452 Mdot
.49088 .10895 Mdot
.6535 .1005 Mdot
.01229 .22175 Mdot
.49845 .61738 Mdot
.49505 .61594 Mdot
.48424 .61135 Mdot
.44981 .59676 Mdot
.34136 .551 Mdot
.03243 .4271 Mdot
.67519 .39725 Mdot
.5308 .5288 Mdot
.43233 .55717 Mdot
.23538 .49631 Mdot
.80071 .34939 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48298 .61082 Mdot
.44581 .59506 Mdot
.32892 .54579 Mdot
.00206 .41602 Mdot
.67211 .41411 Mdot
.55286 .54434 Mdot
.51146 .59245 Mdot
.48723 .60306 Mdot
.44386 .59123 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50289 .00123 Mdot
.50921 .0039 Mdot
.52932 .01243 Mdot
.59317 .03946 Mdot
.78893 .12098 Mdot
.21631 .26414 Mdot
.41029 .11989 Mdot
.47672 .04106 Mdot
.50837 .01956 Mdot
.55255 .02731 Mdot
.4997 .61791 Mdot
.49904 .61763 Mdot
.49693 .61673 Mdot
.49021 .61388 Mdot
.46882 .60481 Mdot
.40095 .57609 Mdot
.19391 .49008 Mdot
.76282 .3516 Mdot
.56968 .49867 Mdot
.47775 .56122 Mdot
.35254 .54065 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50278 .00118 Mdot
.50886 .00376 Mdot
.52823 .01197 Mdot
.58971 .038 Mdot
.77874 .11683 Mdot
.20262 .26197 Mdot
.39827 .12092 Mdot
.4515 .0329 Mdot
.4331 .60666 Mdot
.31728 .54645 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47783 .60863 Mdot
.42947 .58815 Mdot
.27875 .52488 Mdot
.89318 .37974 Mdot
.65608 .4715 Mdot
.61733 .59409 Mdot
.73907 .07524 Mdot
.09897 .22243 Mdot
.3198 .13648 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.5257 .0109 Mdot
.58172 .03462 Mdot
.75501 .1071 Mdot
.16691 .25457 Mdot
.37188 .12668 Mdot
.40476 .02032 Mdot
.30316 .55524 Mdot
.97603 .41585 Mdot
.68471 .43799 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50682 .00289 Mdot
.52174 .00922 Mdot
.56917 .02931 Mdot
.71712 .09144 Mdot
.09872 .23584 Mdot
.34156 .15008 Mdot
.38409 .02629 Mdot
.26772 .54611 Mdot
.9141 .39948 Mdot
.68316 .47531 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.48718 .6126 Mdot
.45919 .60073 Mdot
.37065 .56331 Mdot
.10875 .45617 Mdot
.69612 .36302 Mdot
.50869 .50219 Mdot
.33427 .51024 Mdot
.95381 .3829 Mdot
.64167 .42512 Mdot
.4982 .61727 Mdot
.49428 .61561 Mdot
.48178 .61031 Mdot
.44201 .59345 Mdot
.31716 .54087 Mdot
.97452 .40627 Mdot
.66994 .42979 Mdot
.57451 .55906 Mdot
.58682 .00761 Mdot
.72299 .08416 Mdot
.09446 .22958 Mdot
.50057 .00024 Mdot
.50183 .00078 Mdot
.50583 .00247 Mdot
.51859 .00788 Mdot
.55915 .02507 Mdot
.68642 .07865 Mdot
.03361 .21458 Mdot
.33076 .18365 Mdot
.41927 .0547 Mdot
.3918 .60106 Mdot
.21426 .50831 Mdot
.80398 .36447 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50512 .00217 Mdot
.51631 .00692 Mdot
.55192 .02201 Mdot
.66405 .0693 Mdot
.98093 .19584 Mdot
.32635 .21348 Mdot
.45998 .08259 Mdot
.53421 .04588 Mdot
.65935 .07734 Mdot
.98553 .20159 Mdot
.49844 .61737 Mdot
.49504 .61593 Mdot
.48421 .61134 Mdot
.44974 .59673 Mdot
.34111 .5509 Mdot
.03182 .42688 Mdot
.67511 .39758 Mdot
.5312 .52909 Mdot
.43378 .55783 Mdot
.23987 .49819 Mdot
.80772 .35095 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51749 .00742 Mdot
.55568 .0236 Mdot
.67568 .07417 Mdot
.00887 .20592 Mdot
.32876 .1977 Mdot
.43855 .06786 Mdot
.45844 .01229 Mdot
.41669 .59223 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50613 .0026 Mdot
.51952 .00828 Mdot
.56213 .02633 Mdot
.69559 .08248 Mdot
.05396 .22149 Mdot
.33293 .17242 Mdot
.40486 .04445 Mdot
.34243 .57945 Mdot
.08041 .4561 Mdot
.70284 .38468 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51996 .00846 Mdot
.56351 .02692 Mdot
.69981 .08424 Mdot
.06308 .22451 Mdot
.33418 .16755 Mdot
.39918 .04017 Mdot
.32287 .57087 Mdot
.03242 .43853 Mdot
.69367 .40867 Mdot
.4974 .61693 Mdot
.49172 .61452 Mdot
.47362 .60685 Mdot
.41614 .58251 Mdot
.23862 .50832 Mdot
.82297 .36115 Mdot
.6214 .49346 Mdot
.58478 .5954 Mdot
.66939 .05229 Mdot
.96276 .18131 Mdot
.31148 .21552 Mdot
.50041 .00017 Mdot
.50131 .00055 Mdot
.50417 .00177 Mdot
.51328 .00563 Mdot
.54229 .01793 Mdot
.634 .05668 Mdot
.90379 .16674 Mdot
.30927 .25059 Mdot
.49237 .11316 Mdot
.66402 .10609 Mdot
.04041 .23262 Mdot
.35683 .19556 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.5062 .00263 Mdot
.51974 .00837 Mdot
.56282 .02662 Mdot
.69769 .08336 Mdot
.05852 .223 Mdot
.33353 .16997 Mdot
.40195 .04228 Mdot
.33242 .57506 Mdot
.05546 .44686 Mdot
.69698 .39649 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49798 .61718 Mdot
.49355 .6153 Mdot
.47945 .60932 Mdot
.43462 .59033 Mdot
.29445 .5314 Mdot
.92479 .38958 Mdot
.6638 .45673 Mdot
.60736 .58316 Mdot
.49905 .61763 Mdot
.49698 .61675 Mdot
.49038 .61396 Mdot
.46937 .60505 Mdot
.40269 .57682 Mdot
.19896 .49213 Mdot
.76867 .3521 Mdot
.57548 .49863 Mdot
.49131 .56601 Mdot
.3941 .55796 Mdot
.1495 .46686 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51247 .00529 Mdot
.53971 .01684 Mdot
.6259 .05327 Mdot
.88186 .15819 Mdot
.29919 .25793 Mdot
.48911 .11738 Mdot
.66271 .10729 Mdot
.04003 .23319 Mdot
.35793 .19648 Mdot
.49774 .61707 Mdot
.49279 .61498 Mdot
.47704 .6083 Mdot
.42696 .58708 Mdot
.27113 .52173 Mdot
.87867 .37548 Mdot
.65108 .47737 Mdot
.61758 .59733 Mdot
.74483 .07865 Mdot
.1107 .22611 Mdot
.32358 .13157 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.52168 .00919 Mdot
.56898 .02923 Mdot
.71654 .0912 Mdot
.09758 .2355 Mdot
.34125 .15059 Mdot
.38435 .02664 Mdot
.26886 .54665 Mdot
.9163 .40014 Mdot
.68359 .47421 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47948 .60933 Mdot
.43471 .59036 Mdot
.29472 .53152 Mdot
.92537 .38976 Mdot
.6639 .45644 Mdot
.60708 .58292 Mdot
.69905 .05684 Mdot
.01761 .19688 Mdot
.30981 .18059 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50283 .0012 Mdot
.509 .00382 Mdot
.52867 .01216 Mdot
.59113 .0386 Mdot
.78292 .11853 Mdot
.20835 .26293 Mdot
.40319 .12041 Mdot
.46159 .03609 Mdot
.46293 .00083 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48247 .6106 Mdot
.44421 .59439 Mdot
.32398 .54372 Mdot
.99033 .41183 Mdot
.67118 .42079 Mdot
.56208 .55061 Mdot
.54376 .60671 Mdot
.59025 .02873 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.4806 .60981 Mdot
.43827 .59187 Mdot
.30564 .53606 Mdot
.94872 .39744 Mdot
.6674 .44417 Mdot
.59337 .57228 Mdot
.6515 .03593 Mdot
.49973 .61792 Mdot
.49915 .61767 Mdot
.49729 .61688 Mdot
.49135 .61437 Mdot
.47246 .60636 Mdot
.41245 .58095 Mdot
.22765 .50382 Mdot
.80646 .35773 Mdot
.60914 .49608 Mdot
.563 .58952 Mdot
.60891 .02837 Mdot
.49984 .61796 Mdot
.49948 .61781 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48304 .61084 Mdot
.44601 .59515 Mdot
.32955 .54606 Mdot
.00356 .41656 Mdot
.67223 .41326 Mdot
.55169 .54354 Mdot
.50734 .59062 Mdot
.49955 .61784 Mdot
.49858 .61743 Mdot
.49546 .61611 Mdot
.48554 .6119 Mdot
.45395 .59851 Mdot
.35426 .55642 Mdot
.06524 .43941 Mdot
.68108 .38061 Mdot
.51362 .51454 Mdot
.36657 .52715 Mdot
.04201 .41744 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50301 .00128 Mdot
.5096 .00407 Mdot
.53058 .01297 Mdot
.59716 .04115 Mdot
.80058 .12572 Mdot
.23079 .26588 Mdot
.42399 .11941 Mdot
.50747 .05159 Mdot
.60216 .05852 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48343 .61101 Mdot
.44726 .59568 Mdot
.33343 .54768 Mdot
.01291 .41994 Mdot
.67305 .40799 Mdot
.54456 .53862 Mdot
.48204 .57939 Mdot
.39263 .56278 Mdot
.15412 .47062 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48988 .61374 Mdot
.46777 .60437 Mdot
.39765 .5747 Mdot
.18438 .48622 Mdot
.75238 .35104 Mdot
.55909 .49857 Mdot
.4524 .5521 Mdot
.27536 .50862 Mdot
.86262 .36295 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51129 .00479 Mdot
.53595 .01524 Mdot
.61408 .04829 Mdot
.84906 .14522 Mdot
.278 .2651 Mdot
.47189 .11983 Mdot
.62384 .09391 Mdot
.94337 .19748 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.5042 .00178 Mdot
.51337 .00567 Mdot
.54258 .01805 Mdot
.63489 .05705 Mdot
.90617 .16766 Mdot
.31018 .24969 Mdot
.49233 .11257 Mdot
.66297 .10546 Mdot
.03753 .23149 Mdot
.35632 .19702 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.52589 .01098 Mdot
.5823 .03487 Mdot
.75674 .10781 Mdot
.1697 .25522 Mdot
.37367 .12606 Mdot
.40743 .02087 Mdot
.31004 .55784 Mdot
.9907 .42067 Mdot
.6853 .42929 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51106 .00469 Mdot
.53523 .01494 Mdot
.61181 .04733 Mdot
.84263 .14266 Mdot
.27289 .26591 Mdot
.46687 .11989 Mdot
.61152 .0894 Mdot
.91008 .18452 Mdot
.33646 .26352 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51069 .00453 Mdot
.53404 .01443 Mdot
.60805 .04574 Mdot
.83197 .13839 Mdot
.26365 .2668 Mdot
.45748 .11979 Mdot
.5883 .08085 Mdot
.84487 .15857 Mdot
.299 .28067 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.5063 .00267 Mdot
.52008 .00851 Mdot
.56389 .02708 Mdot
.70099 .08473 Mdot
.06559 .22534 Mdot
.33457 .16623 Mdot
.39772 .03903 Mdot
.31781 .56864 Mdot
.0205 .43429 Mdot
.69253 .41533 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50804 .00341 Mdot
.5256 .01085 Mdot
.58139 .03448 Mdot
.75403 .10669 Mdot
.16531 .25419 Mdot
.37088 .12704 Mdot
.40331 .02005 Mdot
.29947 .55386 Mdot
.96834 .41338 Mdot
.68439 .44254 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52444 .01036 Mdot
.57774 .03294 Mdot
.74305 .10217 Mdot
.14687 .24957 Mdot
.36035 .13194 Mdot
.39021 .01846 Mdot
.26814 .54259 Mdot
.90889 .39601 Mdot
.67896 .47593 Mdot
.50054 .00023 Mdot
.50174 .00074 Mdot
.50553 .00234 Mdot
.51761 .00747 Mdot
.55606 .02376 Mdot
.67687 .07467 Mdot
.01166 .20691 Mdot
.32897 .19611 Mdot
.43635 .06636 Mdot
.45076 .00891 Mdot
.3925 .58202 Mdot
.18496 .48977 Mdot
.49941 .61779 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48103 .60999 Mdot
.43964 .59245 Mdot
.30987 .53783 Mdot
.95806 .4006 Mdot
.66843 .43904 Mdot
.58687 .56763 Mdot
.62924 .02619 Mdot
.84486 .13326 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50855 .00363 Mdot
.52724 .01155 Mdot
.58659 .03668 Mdot
.76951 .11305 Mdot
.18938 .25949 Mdot
.38762 .12252 Mdot
.43095 .02678 Mdot
.37392 .58279 Mdot
.14694 .47775 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.48531 .6118 Mdot
.45323 .5982 Mdot
.35199 .55546 Mdot
.05937 .43719 Mdot
.67975 .38342 Mdot
.51598 .51682 Mdot
.37615 .53161 Mdot
.06874 .42804 Mdot
.66139 .36628 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50437 .00185 Mdot
.51391 .0059 Mdot
.54429 .01878 Mdot
.64025 .05931 Mdot
.9204 .17314 Mdot
.31503 .2439 Mdot
.49059 .1085 Mdot
.65203 .09978 Mdot
.00839 .22024 Mdot
.35217 .21246 Mdot
.4999 .61799 Mdot
.4997 .6179 Mdot
.49903 .61762 Mdot
.49691 .61672 Mdot
.49016 .61386 Mdot
.46866 .60475 Mdot
.40046 .57588 Mdot
.19249 .4895 Mdot
.7612 .35149 Mdot
.56806 .49866 Mdot
.47393 .55986 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50766 .00325 Mdot
.5244 .01035 Mdot
.57761 .03288 Mdot
.74267 .10201 Mdot
.14622 .2494 Mdot
.36001 .13213 Mdot
.38987 .01845 Mdot
.2674 .54234 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50287 .00122 Mdot
.50915 .00388 Mdot
.52915 .01236 Mdot
.59264 .03924 Mdot
.78737 .12035 Mdot
.21429 .26385 Mdot
.40845 .12 Mdot
.47274 .03974 Mdot
.49635 .01459 Mdot
.5145 .01121 Mdot
.49928 .61773 Mdot
.49772 .61707 Mdot
.49274 .61496 Mdot
.47688 .60823 Mdot
.42645 .58687 Mdot
.26959 .52109 Mdot
.8758 .37466 Mdot
.64997 .47846 Mdot
.61725 .59781 Mdot
.74492 .07891 Mdot
.11121 .22638 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.47428 .60713 Mdot
.41822 .58339 Mdot
.2448 .51086 Mdot
.83279 .36339 Mdot
.62793 .49142 Mdot
.59495 .59765 Mdot
.69611 .06252 Mdot
.02243 .20168 Mdot
.31522 .18095 Mdot
.49788 .61713 Mdot
.49324 .61517 Mdot
.47845 .6089 Mdot
.43144 .58898 Mdot
.28476 .52737 Mdot
.905 .38333 Mdot
.65943 .46626 Mdot
.61498 .59056 Mdot
.72838 .07008 Mdot
.0783 .21627 Mdot
.31546 .14657 Mdot
.49844 .61737 Mdot
.49503 .61592 Mdot
.48416 .61132 Mdot
.44956 .59665 Mdot
.34055 .55066 Mdot
.03042 .42636 Mdot
.67494 .39833 Mdot
.53212 .52977 Mdot
.43717 .55935 Mdot
.2504 .5026 Mdot
.8249 .35506 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50752 .00319 Mdot
.52395 .01015 Mdot
.57616 .03227 Mdot
.7383 .10021 Mdot
.13853 .24735 Mdot
.35622 .13455 Mdot
.38642 .01866 Mdot
.26034 .54011 Mdot
.89603 .39288 Mdot
.67682 .48256 Mdot
.4998 .61795 Mdot
.49935 .61776 Mdot
.49793 .61716 Mdot
.4934 .61523 Mdot
.47897 .60912 Mdot
.43309 .58968 Mdot
.28979 .52947 Mdot
.91517 .38651 Mdot
.66186 .46148 Mdot
.61159 .58697 Mdot
.71533 .06412 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.52168 .00919 Mdot
.56898 .02923 Mdot
.71655 .0912 Mdot
.09759 .2355 Mdot
.34125 .15059 Mdot
.38435 .02664 Mdot
.26885 .54665 Mdot
.91629 .40014 Mdot
.68358 .47422 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50657 .00279 Mdot
.52094 .00888 Mdot
.56662 .02823 Mdot
.70935 .08821 Mdot
.08305 .23096 Mdot
.33776 .15742 Mdot
.38912 .03174 Mdot
.28728 .5551 Mdot
.95323 .41158 Mdot
.68833 .45431 Mdot
.49938 .61777 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60957 Mdot
.43652 .59113 Mdot
.30026 .53382 Mdot
.93708 .39358 Mdot
.66584 .4504 Mdot
.60072 .57779 Mdot
.67681 .04702 Mdot
.96682 .17924 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50352 .00149 Mdot
.51123 .00476 Mdot
.53575 .01516 Mdot
.61346 .04803 Mdot
.84731 .14453 Mdot
.27664 .26534 Mdot
.47057 .11986 Mdot
.62062 .09273 Mdot
.93476 .19415 Mdot
.34405 .25295 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52246 .00952 Mdot
.57145 .03028 Mdot
.72405 .09431 Mdot
.11222 .2399 Mdot
.34566 .14427 Mdot
.38222 .02259 Mdot
.25778 .54113 Mdot
.89491 .39376 Mdot
.67846 .48426 Mdot
.49835 .61733 Mdot
.49473 .6158 Mdot
.48321 .61092 Mdot
.44656 .59538 Mdot
.33124 .54676 Mdot
.00763 .41803 Mdot
.67258 .41096 Mdot
.54856 .54139 Mdot
.49625 .58571 Mdot
.43833 .58224 Mdot
.2902 .52649 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53096 .01313 Mdot
.59836 .04165 Mdot
.80407 .12714 Mdot
.23487 .26625 Mdot
.42802 .11937 Mdot
.51683 .05489 Mdot
.63084 .07046 Mdot
.91974 .17855 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50559 .00237 Mdot
.51781 .00755 Mdot
.5567 .02403 Mdot
.67884 .07549 Mdot
.01626 .20853 Mdot
.32933 .19349 Mdot
.43271 .06389 Mdot
.43813 .00335 Mdot
.35308 .56547 Mdot
.07763 .4478 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52353 .00998 Mdot
.57483 .03171 Mdot
.73428 .09855 Mdot
.1313 .24537 Mdot
.35296 .13699 Mdot
.38413 .01926 Mdot
.25646 .53913 Mdot
.89024 .3917 Mdot
.67592 .48558 Mdot
.49856 .61743 Mdot
.49543 .6161 Mdot
.48543 .61186 Mdot
.45362 .59837 Mdot
.35321 .55598 Mdot
.06254 .43839 Mdot
.68045 .38189 Mdot
.51467 .51557 Mdot
.37085 .52915 Mdot
.05387 .42213 Mdot
.65762 .37314 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51877 .00796 Mdot
.55975 .02533 Mdot
.68827 .07943 Mdot
.03778 .21601 Mdot
.33115 .18132 Mdot
.41616 .05254 Mdot
.38116 .5964 Mdot
.18399 .49618 Mdot
.76833 .36114 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49075 .61411 Mdot
.47055 .60555 Mdot
.40643 .5784 Mdot
.20989 .49657 Mdot
.78217 .35368 Mdot
.58831 .49823 Mdot
.52024 .57596 Mdot
.48244 .59467 Mdot
.49885 .61755 Mdot
.49633 .61648 Mdot
.48831 .61308 Mdot
.46277 .60225 Mdot
.38189 .56805 Mdot
.13965 .46833 Mdot
.71381 .35485 Mdot
.52055 .49859 Mdot
.35802 .51759 Mdot
.00967 .40274 Mdot
.64682 .39378 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47346 .60678 Mdot
.41563 .58229 Mdot
.23708 .50769 Mdot
.82058 .36063 Mdot
.61973 .4939 Mdot
.58199 .59471 Mdot
.66189 .04938 Mdot
.94485 .17488 Mdot
.30889 .22499 Mdot
.49785 .61712 Mdot
.49316 .61513 Mdot
.4782 .60879 Mdot
.43065 .58864 Mdot
.28232 .52637 Mdot
.90018 .38185 Mdot
.65814 .46845 Mdot
.61616 .59209 Mdot
.73335 .07243 Mdot
.08797 .21917 Mdot
.31725 .1417 Mdot
.50076 .00032 Mdot
.50244 .00103 Mdot
.50776 .00329 Mdot
.52473 .01049 Mdot
.57865 .03332 Mdot
.7458 .1033 Mdot
.15159 .2508 Mdot
.36286 .13057 Mdot
.39293 .01859 Mdot
.27425 .54469 Mdot
.91961 .39885 Mdot
.68049 .47025 Mdot
.50039 .00016 Mdot
.50124 .00053 Mdot
.50395 .00167 Mdot
.51257 .00533 Mdot
.54004 .01698 Mdot
.62694 .05371 Mdot
.88469 .1593 Mdot
.30067 .25709 Mdot
.4899 .11696 Mdot
.66401 .1076 Mdot
.04285 .23413 Mdot
.35819 .19489 Mdot
.49911 .61766 Mdot
.49717 .61683 Mdot
.49097 .61421 Mdot
.47124 .60584 Mdot
.4086 .57932 Mdot
.21629 .49917 Mdot
.79057 .35493 Mdot
.59588 .4977 Mdot
.53645 .58131 Mdot
.53122 .6148 Mdot
.57252 .02553 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.50381 .00161 Mdot
.51212 .00514 Mdot
.53861 .01637 Mdot
.62245 .05182 Mdot
.87238 .15446 Mdot
.29387 .2605 Mdot
.48565 .11852 Mdot
.65592 .10523 Mdot
.02441 .22774 Mdot
.35643 .2052 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.52379 .01009 Mdot
.57567 .03206 Mdot
.73682 .0996 Mdot
.13588 .24663 Mdot
.355 .13542 Mdot
.38548 .01884 Mdot
.25861 .53963 Mdot
.89337 .3923 Mdot
.67637 .48392 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50746 .00316 Mdot
.52375 .01007 Mdot
.57554 .03201 Mdot
.73643 .09944 Mdot
.13518 .24644 Mdot
.35468 .13566 Mdot
.38525 .01889 Mdot
.25822 .53953 Mdot
.89278 .39218 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48015 .60962 Mdot
.43683 .59126 Mdot
.30123 .53423 Mdot
.93917 .39426 Mdot
.66614 .4493 Mdot
.59947 .57683 Mdot
.67249 .04513 Mdot
.95648 .17552 Mdot
.30494 .21536 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51484 .00629 Mdot
.54726 .02003 Mdot
.64953 .06321 Mdot
.94452 .18232 Mdot
.32106 .23271 Mdot
.48226 .09963 Mdot
.6169 .08321 Mdot
.91155 .1821 Mdot
.33215 .25995 Mdot
.49992 .618 Mdot
.49975 .61793 Mdot
.4992 .61769 Mdot
.49744 .61695 Mdot
.49185 .61458 Mdot
.47404 .60703 Mdot
.41748 .58307 Mdot
.2426 .50995 Mdot
.82924 .36257 Mdot
.62564 .4922 Mdot
.59151 .59694 Mdot
.50038 .00016 Mdot
.50123 .00052 Mdot
.5039 .00166 Mdot
.51244 .00527 Mdot
.53961 .01679 Mdot
.62559 .05314 Mdot
.88101 .15786 Mdot
.29874 .25817 Mdot
.48885 .11749 Mdot
.66225 .10717 Mdot
.03902 .23285 Mdot
.35784 .19704 Mdot
.49861 .61744 Mdot
.49557 .61615 Mdot
.48588 .61204 Mdot
.45503 .59897 Mdot
.35762 .55783 Mdot
.074 .44275 Mdot
.68334 .37659 Mdot
.51078 .51138 Mdot
.35436 .52137 Mdot
.00873 .40442 Mdot
.65001 .39633 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49444 .61567 Mdot
.48228 .61052 Mdot
.44359 .59412 Mdot
.32204 .54291 Mdot
.9858 .41023 Mdot
.67083 .42337 Mdot
.56566 .55304 Mdot
.55622 .6122 Mdot
.62936 .0452 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51464 .00621 Mdot
.54661 .01976 Mdot
.64751 .06236 Mdot
.93932 .18035 Mdot
.31996 .23525 Mdot
.48457 .10173 Mdot
.62607 .08745 Mdot
.93751 .19248 Mdot
.34029 .24893 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50522 .00222 Mdot
.51664 .00706 Mdot
.55298 .02246 Mdot
.66733 .07067 Mdot
.98892 .19875 Mdot
.32712 .20902 Mdot
.45407 .07846 Mdot
.51307 .03647 Mdot
.59166 .04857 Mdot
.80026 .12892 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.476 .60786 Mdot
.42367 .58569 Mdot
.26118 .51761 Mdot
.86055 .37043 Mdot
.64334 .48379 Mdot
.61322 .59942 Mdot
.73898 .07772 Mdot
.10289 .22491 Mdot
.323 .13603 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50357 .00152 Mdot
.51139 .00483 Mdot
.53626 .01537 Mdot
.61506 .0487 Mdot
.85179 .14631 Mdot
.28007 .26469 Mdot
.47387 .11977 Mdot
.62866 .09566 Mdot
.95609 .20236 Mdot
.34855 .24256 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00313 Mdot
.52349 .00996 Mdot
.57472 .03166 Mdot
.73395 .09841 Mdot
.13069 .2452 Mdot
.3527 .13721 Mdot
.38398 .01933 Mdot
.25625 .53909 Mdot
.88996 .39166 Mdot
.67589 .48573 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51978 .00839 Mdot
.56295 .02668 Mdot
.69809 .08352 Mdot
.05939 .22329 Mdot
.33365 .16951 Mdot
.40141 .04188 Mdot
.33056 .57425 Mdot
.05092 .4452 Mdot
.69619 .3988 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50541 .00229 Mdot
.51723 .00731 Mdot
.55485 .02325 Mdot
.67312 .0731 Mdot
.00281 .20376 Mdot
.32828 .20115 Mdot
.44333 .0711 Mdot
.47514 .01966 Mdot
.46982 .61475 Mdot
.41951 .58694 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50605 .00257 Mdot
.51928 .00817 Mdot
.56135 .026 Mdot
.69317 .08147 Mdot
.04867 .21971 Mdot
.3323 .17529 Mdot
.4084 .04703 Mdot
.35456 .58476 Mdot
.11169 .46793 Mdot
.7147 .37268 Mdot
.49997 .61802 Mdot
.49991 .618 Mdot
.49973 .61792 Mdot
.49913 .61767 Mdot
.49723 .61686 Mdot
.49118 .61429 Mdot
.47191 .60612 Mdot
.41072 .58022 Mdot
.22252 .50172 Mdot
.79914 .35637 Mdot
.60321 .49694 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.5048 .00204 Mdot
.51531 .00649 Mdot
.54874 .02066 Mdot
.65414 .06514 Mdot
.95626 .18672 Mdot
.32317 .22676 Mdot
.47613 .09454 Mdot
.59343 .0725 Mdot
.84297 .15422 Mdot
.50053 .00022 Mdot
.50169 .00071 Mdot
.50537 .00228 Mdot
.51711 .00725 Mdot
.55446 .02308 Mdot
.67191 .07259 Mdot
.99992 .20272 Mdot
.32805 .2028 Mdot
.4456 .07265 Mdot
.48311 .02319 Mdot
.49535 .00756 Mdot
.50061 .00325 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.51441 .00611 Mdot
.54589 .01945 Mdot
.64524 .0614 Mdot
.93345 .17812 Mdot
.3186 .23804 Mdot
.48686 .10399 Mdot
.63542 .09182 Mdot
.96347 .20275 Mdot
.34584 .23632 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55363 .02273 Mdot
.66935 .07152 Mdot
.99381 .20052 Mdot
.32755 .20626 Mdot
.45034 .07589 Mdot
.49984 .03059 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50593 .00252 Mdot
.5189 .00801 Mdot
.56015 .02549 Mdot
.68948 .07993 Mdot
.04049 .21694 Mdot
.33142 .1798 Mdot
.41418 .05115 Mdot
.37436 .59342 Mdot
.16505 .48867 Mdot
.75021 .36165 Mdot
.49995 .61801 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.49831 .61732 Mdot
.4946 .61574 Mdot
.4828 .61074 Mdot
.44526 .59483 Mdot
.3272 .54507 Mdot
.99796 .41455 Mdot
.67178 .41644 Mdot
.55607 .54652 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47562 .6077 Mdot
.42247 .58519 Mdot
.25758 .51612 Mdot
.85422 .36875 Mdot
.64021 .48577 Mdot
.61036 .59958 Mdot
.73308 .07585 Mdot
.0932 .22256 Mdot
.32137 .14102 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51445 .00613 Mdot
.546 .0195 Mdot
.64558 .06155 Mdot
.93434 .17846 Mdot
.31882 .23762 Mdot
.48653 .10365 Mdot
.63407 .09118 Mdot
.95976 .20129 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48478 .61158 Mdot
.45153 .59749 Mdot
.3467 .55324 Mdot
.04586 .43211 Mdot
.67718 .39018 Mdot
.52267 .52254 Mdot
.40207 .54349 Mdot
.14365 .45833 Mdot
.69785 .34251 Mdot
.49928 .61773 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47659 .60811 Mdot
.42554 .58648 Mdot
.26683 .51994 Mdot
.87071 .37322 Mdot
.6479 .48032 Mdot
.61634 .59853 Mdot
.74417 .079 Mdot
.11058 .22645 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48744 .61271 Mdot
.46001 .60108 Mdot
.37323 .5644 Mdot
.11576 .45891 Mdot
.69957 .36081 Mdot
.51021 .50101 Mdot
.33617 .51047 Mdot
.95755 .38403 Mdot
.64185 .42292 Mdot
.4979 .61714 Mdot
.4933 .61519 Mdot
.47867 .60899 Mdot
.43214 .58928 Mdot
.28687 .52825 Mdot
.90924 .38465 Mdot
.66049 .4643 Mdot
.61371 .58912 Mdot
.72335 .06776 Mdot
.06838 .21324 Mdot
.31397 .15178 Mdot
.4999 .61799 Mdot
.49969 .6179 Mdot
.49901 .61761 Mdot
.49683 .61669 Mdot
.48991 .61375 Mdot
.46785 .6044 Mdot
.3979 .5748 Mdot
.18509 .48651 Mdot
.75313 .35107 Mdot
.55985 .49858 Mdot
.45426 .55277 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48011 .6096 Mdot
.4367 .59121 Mdot
.30083 .53406 Mdot
.9383 .39398 Mdot
.66602 .44976 Mdot
.6 .57723 Mdot
.6743 .04592 Mdot
.96085 .17709 Mdot
.30553 .21303 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50618 .00262 Mdot
.51967 .00834 Mdot
.5626 .02653 Mdot
.69704 .08309 Mdot
.05711 .22254 Mdot
.33334 .17072 Mdot
.40283 .04295 Mdot
.33546 .57639 Mdot
.06295 .44961 Mdot
.69846 .39277 Mdot
.49908 .61765 Mdot
.49708 .6168 Mdot
.4907 .61409 Mdot
.47037 .60547 Mdot
.40584 .57816 Mdot
.20817 .49587 Mdot
.77997 .35339 Mdot
.58628 .49833 Mdot
.51576 .57445 Mdot
.46884 .58904 Mdot
.37548 .56033 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50283 .0012 Mdot
.50903 .00383 Mdot
.52877 .0122 Mdot
.59142 .03872 Mdot
.78378 .11889 Mdot
.20952 .26312 Mdot
.4042 .12032 Mdot
.46371 .03678 Mdot
.46927 .00343 Mdot
.42901 .59315 Mdot
.49778 .61709 Mdot
.49292 .61503 Mdot
.47744 .60847 Mdot
.42825 .58763 Mdot
.27504 .52335 Mdot
.88605 .37762 Mdot
.65375 .47447 Mdot
.61784 .59584 Mdot
.74298 .07734 Mdot
.10661 .22474 Mdot
.32202 .13313 Mdot
.49819 .61727 Mdot
.49423 .61559 Mdot
.48162 .61024 Mdot
.44151 .59324 Mdot
.31561 .54023 Mdot
.97099 .40505 Mdot
.66964 .43179 Mdot
.57723 .56092 Mdot
.59618 .01171 Mdot
.75078 .09555 Mdot
.1441 .24309 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49387 .61543 Mdot
.48047 .60975 Mdot
.43786 .5917 Mdot
.30439 .53554 Mdot
.94599 .39653 Mdot
.66706 .44565 Mdot
.59517 .57361 Mdot
.65769 .03864 Mdot
.9199 .16206 Mdot
.50049 .00021 Mdot
.50157 .00066 Mdot
.505 .00212 Mdot
.51592 .00675 Mdot
.55067 .02148 Mdot
.66015 .06766 Mdot
.97133 .19232 Mdot
.32528 .21875 Mdot
.4667 .08741 Mdot
.55855 .05676 Mdot
.73626 .10983 Mdot
.15181 .25682 Mdot
.49871 .61749 Mdot
.49588 .61629 Mdot
.48688 .61247 Mdot
.45822 .60032 Mdot
.3676 .56203 Mdot
.1005 .45296 Mdot
.69248 .36586 Mdot
.50776 .50387 Mdot
.33466 .51106 Mdot
.95583 .3839 Mdot
.6424 .42433 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.48901 .61337 Mdot
.465 .6032 Mdot
.38892 .57101 Mdot
.15941 .47619 Mdot
.72881 .35191 Mdot
.53483 .49815 Mdot
.39268 .53018 Mdot
.10147 .43806 Mdot
.66816 .35023 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.52081 .00882 Mdot
.56621 .02806 Mdot
.7081 .08769 Mdot
.08049 .23015 Mdot
.33723 .15867 Mdot
.3902 .03274 Mdot
.29123 .55687 Mdot
.96149 .41424 Mdot
.68895 .4496 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48444 .61144 Mdot
.45047 .59704 Mdot
.34341 .55186 Mdot
.03756 .42901 Mdot
.67589 .39451 Mdot
.52754 .52635 Mdot
.4203 .55176 Mdot
.19845 .48092 Mdot
.75028 .34105 Mdot
.49965 .61789 Mdot
.49888 .61756 Mdot
.49644 .61652 Mdot
.48865 .61322 Mdot
.46387 .60271 Mdot
.38534 .5695 Mdot
.14933 .47217 Mdot
.72077 .35317 Mdot
.52693 .49823 Mdot
.37329 .52308 Mdot
.04904 .41763 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51288 .00546 Mdot
.54101 .01738 Mdot
.62997 .05498 Mdot
.89292 .16251 Mdot
.30465 .25446 Mdot
.49158 .11553 Mdot
.66588 .10772 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49248 .61485 Mdot
.47606 .60788 Mdot
.42385 .58577 Mdot
.26172 .51783 Mdot
.86151 .37069 Mdot
.64379 .48348 Mdot
.61359 .59937 Mdot
.73969 .07793 Mdot
.10401 .22516 Mdot
.49923 .61771 Mdot
.49756 .617 Mdot
.49221 .61473 Mdot
.47519 .60751 Mdot
.42111 .58461 Mdot
.25347 .51443 Mdot
.84716 .36692 Mdot
.63646 .48781 Mdot
.60628 .59938 Mdot
.72393 .07271 Mdot
.07711 .21828 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57518 .03185 Mdot
.73533 .09898 Mdot
.13321 .2459 Mdot
.3538 .13633 Mdot
.38465 .01907 Mdot
.25723 .53929 Mdot
.89133 .39189 Mdot
.67606 .48499 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48966 .61365 Mdot
.46707 .60407 Mdot
.39545 .57377 Mdot
.17803 .48366 Mdot
.74587 .35095 Mdot
.55237 .49844 Mdot
.43601 .54612 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54654 .01973 Mdot
.64729 .06227 Mdot
.93877 .18014 Mdot
.31984 .23552 Mdot
.4848 .10195 Mdot
.627 .08788 Mdot
.9401 .19351 Mdot
.34095 .24774 Mdot
.49811 .61723 Mdot
.49396 .61547 Mdot
.48077 .60988 Mdot
.4388 .5921 Mdot
.30727 .53675 Mdot
.95231 .39865 Mdot
.66781 .44221 Mdot
.59092 .57051 Mdot
.64312 .03226 Mdot
.88221 .14777 Mdot
.28229 .24726 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50136 .00057 Mdot
.50432 .00183 Mdot
.51376 .00584 Mdot
.54382 .01858 Mdot
.63879 .05869 Mdot
.91655 .17166 Mdot
.31382 .24553 Mdot
.49131 .10969 Mdot
.65576 .10164 Mdot
.0183 .22406 Mdot
.49851 .6174 Mdot
.49525 .61602 Mdot
.48487 .61162 Mdot
.45183 .59761 Mdot
.34763 .55364 Mdot
.04823 .43299 Mdot
.67758 .38896 Mdot
.52138 .5215 Mdot
.39717 .54126 Mdot
.12921 .45243 Mdot
.68803 .34538 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00124 Mdot
.50928 .00394 Mdot
.52957 .01254 Mdot
.59394 .03979 Mdot
.79119 .12191 Mdot
.21922 .26454 Mdot
.41297 .11974 Mdot
.48258 .04302 Mdot
.52612 .02691 Mdot
.60867 .05102 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00112 Mdot
.50843 .00358 Mdot
.52686 .01139 Mdot
.58537 .03617 Mdot
.7659 .11157 Mdot
.18397 .25838 Mdot
.38356 .12335 Mdot
.42365 .02478 Mdot
.35357 .57472 Mdot
.09354 .45733 Mdot
.49976 .61793 Mdot
.49923 .61771 Mdot
.49754 .61699 Mdot
.49218 .61472 Mdot
.47508 .60747 Mdot
.42074 .58445 Mdot
.25237 .51398 Mdot
.8453 .36645 Mdot
.63542 .48832 Mdot
.60504 .59926 Mdot
.72103 .07168 Mdot
.4992 .61769 Mdot
.49745 .61695 Mdot
.49186 .61458 Mdot
.47408 .60704 Mdot
.4176 .58312 Mdot
.24296 .5101 Mdot
.82982 .3627 Mdot
.62601 .49208 Mdot
.59209 .59707 Mdot
.68871 .05972 Mdot
.00658 .19646 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47425 .60712 Mdot
.41812 .58335 Mdot
.24453 .51075 Mdot
.83235 .36329 Mdot
.62765 .49152 Mdot
.59454 .59757 Mdot
.69505 .06212 Mdot
.02021 .20096 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52606 .01105 Mdot
.58287 .03511 Mdot
.75843 .1085 Mdot
.17239 .25584 Mdot
.37544 .1255 Mdot
.41016 .02145 Mdot
.31715 .56055 Mdot
.00634 .42595 Mdot
.68603 .42007 Mdot
.49935 .61776 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47908 .60916 Mdot
.43344 .58983 Mdot
.29084 .5299 Mdot
.91733 .38719 Mdot
.66232 .46043 Mdot
.61072 .58614 Mdot
.71213 .06267 Mdot
.04555 .20606 Mdot
.49838 .61735 Mdot
.49484 .61585 Mdot
.48358 .61107 Mdot
.44771 .59587 Mdot
.33482 .54827 Mdot
.01632 .42118 Mdot
.67338 .40609 Mdot
.54203 .53686 Mdot
.473 .57537 Mdot
.36367 .55046 Mdot
.07395 .43898 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50776 .00329 Mdot
.52471 .01048 Mdot
.57858 .03329 Mdot
.74559 .10322 Mdot
.15124 .2507 Mdot
.36266 .13067 Mdot
.39271 .01857 Mdot
.27375 .54451 Mdot
.9187 .3986 Mdot
.68037 .47074 Mdot
.49837 .61734 Mdot
.49482 .61584 Mdot
.48348 .61103 Mdot
.44742 .59575 Mdot
.33392 .54789 Mdot
.01411 .42038 Mdot
.67316 .40732 Mdot
.54366 .538 Mdot
.47884 .57797 Mdot
.38237 .55841 Mdot
.12507 .45902 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47989 .60951 Mdot
.436 .59091 Mdot
.29868 .53317 Mdot
.93372 .39247 Mdot
.66532 .45216 Mdot
.60267 .57931 Mdot
.68355 .04999 Mdot
.98266 .18486 Mdot
.30773 .20091 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00283 Mdot
.52123 .009 Mdot
.56755 .02862 Mdot
.71217 .08938 Mdot
.0888 .23278 Mdot
.33904 .15466 Mdot
.38694 .02961 Mdot
.27917 .55143 Mdot
.93666 .40635 Mdot
.68667 .46353 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47724 .60838 Mdot
.42759 .58735 Mdot
.27303 .52251 Mdot
.88224 .37651 Mdot
.65241 .47599 Mdot
.61781 .59665 Mdot
.74422 .07813 Mdot
.10921 .22558 Mdot
.32294 .13209 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.5257 .0109 Mdot
.58173 .03462 Mdot
.75502 .1071 Mdot
.16693 .25457 Mdot
.37189 .12667 Mdot
.40478 .02033 Mdot
.30322 .55526 Mdot
.97614 .41589 Mdot
.68472 .43793 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53222 .01366 Mdot
.60232 .04333 Mdot
.81556 .13179 Mdot
.24756 .26699 Mdot
.44085 .11946 Mdot
.54745 .06588 Mdot
.72417 .10922 Mdot
.13648 .25482 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.49329 .61519 Mdot
.47864 .60898 Mdot
.43204 .58923 Mdot
.28656 .52813 Mdot
.90863 .38446 Mdot
.66035 .46459 Mdot
.61391 .58933 Mdot
.72411 .06811 Mdot
.0699 .21371 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51142 .00484 Mdot
.53636 .01542 Mdot
.61539 .04884 Mdot
.85272 .14668 Mdot
.28076 .26455 Mdot
.47452 .11975 Mdot
.63023 .09623 Mdot
.96019 .20393 Mdot
.34925 .24045 Mdot
.50021 9e-05 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52175 .00922 Mdot
.5692 .02932 Mdot
.7172 .09147 Mdot
.09888 .23589 Mdot
.3416 .15001 Mdot
.38405 .02623 Mdot
.26756 .54604 Mdot
.91378 .39939 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50413 .00175 Mdot
.51314 .00557 Mdot
.54186 .01775 Mdot
.63264 .0561 Mdot
.90013 .16532 Mdot
.30779 .25195 Mdot
.49228 .11402 Mdot
.66519 .10687 Mdot
.04374 .23395 Mdot
.3575 .19392 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50659 .00279 Mdot
.52098 .0089 Mdot
.56675 .02829 Mdot
.70974 .08837 Mdot
.08387 .23122 Mdot
.33793 .15702 Mdot
.38879 .03143 Mdot
.28607 .55455 Mdot
.95072 .41078 Mdot
.68812 .45574 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00312 Mdot
.52346 .00995 Mdot
.57463 .03162 Mdot
.7337 .09831 Mdot
.13024 .24508 Mdot
.35251 .13737 Mdot
.38387 .01939 Mdot
.2561 .53907 Mdot
.88977 .39163 Mdot
.67588 .48584 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43731 .59146 Mdot
.3027 .53484 Mdot
.94232 .39531 Mdot
.66658 .44762 Mdot
.59752 .57535 Mdot
.49824 .61729 Mdot
.4944 .61566 Mdot
.48216 .61047 Mdot
.44321 .59396 Mdot
.32087 .54242 Mdot
.98308 .40927 Mdot
.67062 .42493 Mdot
.56782 .5545 Mdot
.56369 .61548 Mdot
.65256 .05493 Mdot
.9368 .17567 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00126 Mdot
.50944 .004 Mdot
.53008 .01275 Mdot
.59557 .04047 Mdot
.79594 .12384 Mdot
.22518 .26528 Mdot
.41857 .11953 Mdot
.49509 .04729 Mdot
.56424 .04274 Mdot
.72716 .10069 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.48752 .61274 Mdot
.46025 .60118 Mdot
.37398 .56471 Mdot
.11781 .45971 Mdot
.70063 .3602 Mdot
.51079 .50071 Mdot
.33712 .5107 Mdot
.9596 .38471 Mdot
.64203 .42177 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50553 .00235 Mdot
.51763 .00747 Mdot
.55611 .02378 Mdot
.67702 .07473 Mdot
.01201 .20703 Mdot
.329 .19591 Mdot
.43606 .06617 Mdot
.44978 .00848 Mdot
.38943 .58073 Mdot
.17623 .48627 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51128 .00478 Mdot
.53593 .01523 Mdot
.61401 .04826 Mdot
.84886 .14514 Mdot
.27784 .26513 Mdot
.47174 .11984 Mdot
.62347 .09377 Mdot
.94238 .1971 Mdot
.34584 .24935 Mdot
.4991 .61765 Mdot
.49715 .61682 Mdot
.49091 .61418 Mdot
.47105 .60576 Mdot
.40799 .57906 Mdot
.21449 .49844 Mdot
.78817 .35455 Mdot
.59375 .49788 Mdot
.53196 .57985 Mdot
.51779 .60928 Mdot
.53026 .0077 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52227 .00944 Mdot
.57084 .03002 Mdot
.72219 .09354 Mdot
.10864 .23884 Mdot
.34449 .14577 Mdot
.38247 .02347 Mdot
.25974 .54219 Mdot
.89873 .39492 Mdot
.67958 .48259 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51823 .00773 Mdot
.55802 .02459 Mdot
.68291 .07719 Mdot
.02565 .21182 Mdot
.33008 .18815 Mdot
.42536 .05889 Mdot
.41274 .61023 Mdot
.27569 .53333 Mdot
.903 .3877 Mdot
.49913 .61767 Mdot
.49723 .61686 Mdot
.49118 .61429 Mdot
.4719 .60612 Mdot
.41069 .5802 Mdot
.22244 .50169 Mdot
.79902 .35635 Mdot
.60311 .49695 Mdot
.55125 .58599 Mdot
.57496 .01465 Mdot
.70699 .0816 Mdot
.4981 .61723 Mdot
.49393 .61546 Mdot
.48067 .60984 Mdot
.43848 .59196 Mdot
.30629 .53634 Mdot
.95015 .39793 Mdot
.66757 .44339 Mdot
.5924 .57158 Mdot
.64818 .03447 Mdot
.89549 .15284 Mdot
.28853 .24292 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.5076 .00322 Mdot
.52422 .01027 Mdot
.57703 .03264 Mdot
.74092 .10129 Mdot
.14316 .2486 Mdot
.35847 .13307 Mdot
.38837 .01848 Mdot
.26422 .54131 Mdot
.90229 .39435 Mdot
.67789 .47935 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50808 .00343 Mdot
.52573 .01091 Mdot
.58181 .03466 Mdot
.75528 .10721 Mdot
.16735 .25467 Mdot
.37216 .12658 Mdot
.40517 .0204 Mdot
.30422 .55564 Mdot
.97825 .41657 Mdot
.49849 .61739 Mdot
.49517 .61599 Mdot
.48462 .61151 Mdot
.45105 .59728 Mdot
.34519 .55261 Mdot
.04205 .43068 Mdot
.67656 .39215 Mdot
.52484 .52427 Mdot
.41024 .5472 Mdot
.16802 .46833 Mdot
.71804 .33993 Mdot
.49863 .61745 Mdot
.49564 .61618 Mdot
.4861 .61214 Mdot
.45575 .59928 Mdot
.35988 .55878 Mdot
.07995 .44503 Mdot
.68507 .37399 Mdot
.50934 .50942 Mdot
.34761 .51808 Mdot
.99065 .39742 Mdot
.64771 .40608 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .0027 Mdot
.52032 .00862 Mdot
.56466 .0274 Mdot
.70335 .08571 Mdot
.07058 .22696 Mdot
.33538 .16365 Mdot
.39498 .03684 Mdot
.30824 .56443 Mdot
.99858 .42665 Mdot
.69105 .42797 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .0012 Mdot
.50904 .00383 Mdot
.52879 .01221 Mdot
.59149 .03875 Mdot
.78399 .11897 Mdot
.20979 .26316 Mdot
.40445 .1203 Mdot
.46422 .03694 Mdot
.47079 .00406 Mdot
.43378 .59516 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50375 .00159 Mdot
.51194 .00507 Mdot
.53804 .01613 Mdot
.62065 .05106 Mdot
.8674 .1525 Mdot
.29082 .26169 Mdot
.48332 .11897 Mdot
.65086 .10354 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50611 .00259 Mdot
.51948 .00826 Mdot
.56198 .02627 Mdot
.69512 .08229 Mdot
.05294 .22114 Mdot
.33281 .17297 Mdot
.40553 .04495 Mdot
.34473 .58046 Mdot
.08624 .45828 Mdot
.70463 .38219 Mdot
.49825 .61729 Mdot
.49442 .61567 Mdot
.48224 .6105 Mdot
.44346 .59407 Mdot
.32165 .54275 Mdot
.98489 .40991 Mdot
.67076 .42389 Mdot
.56639 .55353 Mdot
.55873 .6133 Mdot
.63717 .04848 Mdot
.89682 .16047 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47555 .60766 Mdot
.42223 .58508 Mdot
.25685 .51582 Mdot
.85296 .36841 Mdot
.63956 .48615 Mdot
.6097 .59958 Mdot
.73165 .07537 Mdot
.09075 .22194 Mdot
.32098 .14229 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.50461 .00196 Mdot
.5147 .00623 Mdot
.5468 .01984 Mdot
.64811 .06261 Mdot
.94087 .18094 Mdot
.3203 .2345 Mdot
.48391 .10112 Mdot
.62343 .08623 Mdot
.93008 .18952 Mdot
.33827 .25228 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52516 .01067 Mdot
.58 .0339 Mdot
.74987 .10498 Mdot
.15846 .25252 Mdot
.36673 .12872 Mdot
.39766 .01911 Mdot
.28543 .54867 Mdot
.94037 .40477 Mdot
.68267 .45877 Mdot
.49857 .61743 Mdot
.49543 .6161 Mdot
.48544 .61186 Mdot
.45363 .59838 Mdot
.35325 .55599 Mdot
.06263 .43842 Mdot
.68047 .38185 Mdot
.51463 .51554 Mdot
.37069 .52908 Mdot
.05345 .42196 Mdot
.65753 .37334 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50282 .0012 Mdot
.50898 .00381 Mdot
.52862 .01213 Mdot
.59094 .03852 Mdot
.78238 .11832 Mdot
.20763 .26282 Mdot
.40255 .12047 Mdot
.46027 .03567 Mdot
.45901 .61725 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50588 .00249 Mdot
.51872 .00794 Mdot
.55957 .02525 Mdot
.68771 .0792 Mdot
.03654 .21559 Mdot
.33104 .18201 Mdot
.41708 .05318 Mdot
.3843 .59777 Mdot
.19285 .49971 Mdot
.49892 .61758 Mdot
.49656 .61658 Mdot
.48905 .61339 Mdot
.46513 .60325 Mdot
.38933 .57118 Mdot
.16058 .47666 Mdot
.72979 .3518 Mdot
.53582 .49815 Mdot
.39513 .53108 Mdot
.10827 .44074 Mdot
.67124 .34794 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00327 Mdot
.52458 .01042 Mdot
.57818 .03312 Mdot
.74438 .10272 Mdot
.14916 .25017 Mdot
.36155 .13126 Mdot
.39148 .0185 Mdot
.27095 .54354 Mdot
.91376 .39728 Mdot
.67969 .47337 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51186 .00503 Mdot
.53777 .01601 Mdot
.6198 .0507 Mdot
.86504 .15157 Mdot
.28932 .26222 Mdot
.48211 .11915 Mdot
.64811 .1026 Mdot
.00557 .22092 Mdot
.35468 .21576 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52126 .00902 Mdot
.56764 .02867 Mdot
.71246 .0895 Mdot
.08941 .23296 Mdot
.33918 .15437 Mdot
.38674 .02939 Mdot
.27838 .55106 Mdot
.93507 .40586 Mdot
.68648 .4644 Mdot
.50077 .00033 Mdot
.50244 .00104 Mdot
.50779 .0033 Mdot
.52481 .01052 Mdot
.57888 .03342 Mdot
.7465 .10359 Mdot
.1528 .2511 Mdot
.36352 .13023 Mdot
.3937 .01865 Mdot
.27601 .5453 Mdot
.92278 .39972 Mdot
.68089 .46854 Mdot
.4976 .61702 Mdot
.49236 .61479 Mdot
.47565 .60771 Mdot
.42257 .58523 Mdot
.25786 .51624 Mdot
.85472 .36888 Mdot
.64047 .48562 Mdot
.61061 .59958 Mdot
.73363 .07603 Mdot
.09411 .22279 Mdot
.32152 .14054 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.5203 .00861 Mdot
.56459 .02737 Mdot
.70312 .08562 Mdot
.0701 .22681 Mdot
.3353 .1639 Mdot
.39524 .03705 Mdot
.30915 .56482 Mdot
.00061 .42735 Mdot
.69116 .42678 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50342 .00145 Mdot
.51088 .00462 Mdot
.53466 .0147 Mdot
.61002 .04658 Mdot
.83759 .14064 Mdot
.26864 .2664 Mdot
.46259 .11987 Mdot
.60093 .0855 Mdot
.88074 .17293 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50548 .00233 Mdot
.51747 .00741 Mdot
.55562 .02358 Mdot
.67551 .0741 Mdot
.00845 .20577 Mdot
.32872 .19794 Mdot
.43888 .06808 Mdot
.45958 .0128 Mdot
.42031 .59376 Mdot
.26643 .52293 Mdot
.49784 .61712 Mdot
.49312 .61512 Mdot
.47809 .60875 Mdot
.43031 .5885 Mdot
.2813 .52594 Mdot
.89817 .38124 Mdot
.65757 .46934 Mdot
.61656 .59269 Mdot
.73518 .07331 Mdot
.09149 .22021 Mdot
.318 .13999 Mdot
.49858 .61743 Mdot
.49547 .61611 Mdot
.48555 .61191 Mdot
.454 .59853 Mdot
.35441 .55648 Mdot
.06564 .43956 Mdot
.68118 .38043 Mdot
.51348 .51439 Mdot
.36597 .52687 Mdot
.04034 .41679 Mdot
.65485 .37979 Mdot
.49922 .6177 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.47491 .60739 Mdot
.42021 .58423 Mdot
.25078 .51332 Mdot
.84263 .36578 Mdot
.6339 .48903 Mdot
.60315 .59903 Mdot
.71652 .07007 Mdot
.06336 .21436 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.5047 .00199 Mdot
.51498 .00635 Mdot
.5477 .02022 Mdot
.6509 .06378 Mdot
.94802 .18363 Mdot
.32174 .23097 Mdot
.48056 .09816 Mdot
.61029 .08018 Mdot
.89252 .17443 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48444 .61144 Mdot
.45046 .59703 Mdot
.34335 .55184 Mdot
.03742 .42896 Mdot
.67587 .39458 Mdot
.52763 .52641 Mdot
.42061 .55189 Mdot
.19939 .48131 Mdot
.75141 .34116 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51014 .0043 Mdot
.53231 .0137 Mdot
.60261 .04345 Mdot
.81638 .13212 Mdot
.24842 .26701 Mdot
.44174 .11948 Mdot
.54961 .06667 Mdot
.73069 .11191 Mdot
.50054 .00023 Mdot
.50174 .00074 Mdot
.50553 .00234 Mdot
.51761 .00747 Mdot
.55607 .02377 Mdot
.67689 .07467 Mdot
.0117 .20692 Mdot
.32898 .19608 Mdot
.43631 .06634 Mdot
.45063 .00885 Mdot
.39209 .58185 Mdot
.18379 .4893 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51189 .00504 Mdot
.53788 .01606 Mdot
.62014 .05084 Mdot
.86598 .15194 Mdot
.28992 .26201 Mdot
.4826 .11908 Mdot
.64923 .10298 Mdot
.00831 .22193 Mdot
.35493 .21422 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47554 .60766 Mdot
.4222 .58507 Mdot
.25677 .51579 Mdot
.85282 .36838 Mdot
.63949 .48619 Mdot
.60962 .59957 Mdot
.73149 .07532 Mdot
.09047 .22186 Mdot
.32094 .14244 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00132 Mdot
.50988 .00419 Mdot
.53147 .01334 Mdot
.59997 .04233 Mdot
.80875 .12903 Mdot
.24018 .26664 Mdot
.43333 .11938 Mdot
.52938 .05936 Mdot
.49766 .61704 Mdot
.49254 .61487 Mdot
.47625 .60796 Mdot
.42446 .58603 Mdot
.26357 .5186 Mdot
.86482 .37159 Mdot
.64532 .48238 Mdot
.61475 .59914 Mdot
.74178 .07851 Mdot
.10722 .22586 Mdot
.32372 .1338 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00178 Mdot
.5134 .00568 Mdot
.54266 .01809 Mdot
.63516 .05716 Mdot
.90688 .16793 Mdot
.31045 .24942 Mdot
.4923 .11239 Mdot
.66261 .10526 Mdot
.03656 .23111 Mdot
.35615 .19752 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50526 .00223 Mdot
.51676 .00711 Mdot
.55337 .02262 Mdot
.66853 .07118 Mdot
.99183 .19981 Mdot
.32738 .20738 Mdot
.45186 .07693 Mdot
.50522 .03298 Mdot
.5664 .03781 Mdot
.72431 .0976 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50779 .0033 Mdot
.52482 .01052 Mdot
.57892 .03344 Mdot
.74662 .10364 Mdot
.15299 .25115 Mdot
.36362 .13018 Mdot
.39382 .01866 Mdot
.2763 .5454 Mdot
.9233 .39987 Mdot
.68095 .46825 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49057 .61403 Mdot
.46996 .6053 Mdot
.40455 .57761 Mdot
.20439 .49433 Mdot
.77523 .3528 Mdot
.58182 .4985 Mdot
.50579 .57105 Mdot
.43846 .57642 Mdot
.49977 .61794 Mdot
.49927 .61772 Mdot
.49768 .61705 Mdot
.4926 .61489 Mdot
.47642 .60803 Mdot
.42499 .58625 Mdot
.26518 .51926 Mdot
.86771 .37239 Mdot
.64661 .48138 Mdot
.61561 .59887 Mdot
.74316 .07883 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51885 .00799 Mdot
.55998 .02542 Mdot
.68897 .07972 Mdot
.03934 .21655 Mdot
.33131 .18044 Mdot
.41502 .05174 Mdot
.37722 .59467 Mdot
.17298 .49181 Mdot
.75743 .36121 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.48629 .61222 Mdot
.45636 .59953 Mdot
.36178 .55958 Mdot
.08496 .44695 Mdot
.68667 .37188 Mdot
.50846 .50789 Mdot
.34294 .51573 Mdot
.97824 .39264 Mdot
.64608 .41275 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50779 .0033 Mdot
.52482 .01052 Mdot
.57893 .03344 Mdot
.74663 .10365 Mdot
.15301 .25116 Mdot
.36364 .13017 Mdot
.39383 .01866 Mdot
.27634 .54542 Mdot
.49995 .61801 Mdot
.49985 .61797 Mdot
.49953 .61784 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48495 .61165 Mdot
.45209 .59772 Mdot
.34845 .55398 Mdot
.05031 .43377 Mdot
.67796 .38791 Mdot
.52029 .52059 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.50519 .0022 Mdot
.51653 .00701 Mdot
.55262 .02231 Mdot
.66621 .0702 Mdot
.98621 .19777 Mdot
.32687 .21054 Mdot
.4561 .07987 Mdot
.5203 .03968 Mdot
.61488 .05845 Mdot
.86719 .15594 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47663 .60812 Mdot
.42567 .58654 Mdot
.26721 .5201 Mdot
.87141 .37342 Mdot
.64819 .48007 Mdot
.61649 .59845 Mdot
.74435 .07902 Mdot
.11078 .22647 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.52569 .01089 Mdot
.58169 .03461 Mdot
.75493 .10706 Mdot
.16678 .25454 Mdot
.3718 .12671 Mdot
.40464 .0203 Mdot
.30285 .55513 Mdot
.97538 .41564 Mdot
.68469 .43838 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50274 .00116 Mdot
.50873 .0037 Mdot
.52781 .01179 Mdot
.58838 .03744 Mdot
.77481 .11522 Mdot
.19707 .26098 Mdot
.39369 .12151 Mdot
.44243 .03012 Mdot
.40669 .59595 Mdot
.23887 .51431 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51177 .00499 Mdot
.53748 .01589 Mdot
.6189 .05032 Mdot
.86255 .15058 Mdot
.28768 .26274 Mdot
.48073 .11932 Mdot
.64496 .1015 Mdot
.99779 .21806 Mdot
.35393 .22011 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48044 .60974 Mdot
.43777 .59166 Mdot
.3041 .53542 Mdot
.94536 .39632 Mdot
.66698 .44599 Mdot
.59558 .57391 Mdot
.6591 .03926 Mdot
.92346 .16338 Mdot
.29826 .23163 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50691 .00293 Mdot
.522 .00933 Mdot
.56999 .02966 Mdot
.71962 .09248 Mdot
.10365 .23734 Mdot
.34296 .1479 Mdot
.38312 .02482 Mdot
.2633 .54398 Mdot
.90557 .39695 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47736 .60843 Mdot
.42798 .58752 Mdot
.27423 .52301 Mdot
.88451 .37717 Mdot
.65322 .47508 Mdot
.61785 .59618 Mdot
.74355 .07769 Mdot
.10779 .22511 Mdot
.32242 .13265 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52144 .00909 Mdot
.56822 .02891 Mdot
.71424 .09024 Mdot
.09298 .23408 Mdot
.34005 .1527 Mdot
.3856 .02815 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51251 .00531 Mdot
.53984 .01689 Mdot
.62632 .05345 Mdot
.88301 .15864 Mdot
.2998 .25759 Mdot
.48945 .11721 Mdot
.66328 .10743 Mdot
.04127 .23361 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00212 Mdot
.51596 .00677 Mdot
.55081 .02154 Mdot
.66057 .06784 Mdot
.97237 .1927 Mdot
.3254 .21819 Mdot
.466 .08689 Mdot
.55598 .05561 Mdot
.7282 .10644 Mdot
.13692 .2526 Mdot
.49923 .61771 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.42031 .58427 Mdot
.25109 .51345 Mdot
.84313 .3659 Mdot
.63419 .4889 Mdot
.60352 .59908 Mdot
.71741 .07039 Mdot
.06505 .21485 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49846 .61738 Mdot
.4951 .61595 Mdot
.48438 .61141 Mdot
.45026 .59695 Mdot
.34276 .55159 Mdot
.03593 .4284 Mdot
.67566 .39538 Mdot
.52856 .52712 Mdot
.42407 .55346 Mdot
.49766 .61704 Mdot
.49256 .61488 Mdot
.47629 .60798 Mdot
.42458 .58608 Mdot
.26394 .51875 Mdot
.86549 .37177 Mdot
.64562 .48215 Mdot
.61496 .59909 Mdot
.74214 .0786 Mdot
.10775 .22596 Mdot
.32381 .13353 Mdot
.5004 .00017 Mdot
.50129 .00054 Mdot
.50409 .00174 Mdot
.51304 .00553 Mdot
.54154 .01761 Mdot
.63164 .05568 Mdot
.89743 .16427 Mdot
.30665 .25291 Mdot
.4921 .11461 Mdot
.6657 .10729 Mdot
.04532 .23462 Mdot
.35788 .19317 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51722 .0073 Mdot
.55481 .02323 Mdot
.673 .07305 Mdot
.00252 .20366 Mdot
.32826 .20132 Mdot
.44356 .07126 Mdot
.47595 .02002 Mdot
.4724 .61584 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50836 .00355 Mdot
.52664 .0113 Mdot
.5847 .03588 Mdot
.7639 .11075 Mdot
.18092 .25773 Mdot
.38135 .12387 Mdot
.41982 .02378 Mdot
.34306 .57059 Mdot
.06723 .44756 Mdot
.49785 .61712 Mdot
.49314 .61512 Mdot
.47813 .60876 Mdot
.43044 .58855 Mdot
.28168 .5261 Mdot
.89891 .38147 Mdot
.65778 .46901 Mdot
.61642 .59247 Mdot
.73452 .07299 Mdot
.09023 .21984 Mdot
.31773 .1406 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48934 .61351 Mdot
.46604 .60363 Mdot
.39217 .57238 Mdot
.16866 .4799 Mdot
.73692 .3512 Mdot
.54311 .49825 Mdot
.41318 .53773 Mdot
.15937 .46117 Mdot
.70451 .33691 Mdot
.49813 .61724 Mdot
.49406 .61551 Mdot
.48106 .61 Mdot
.43972 .59249 Mdot
.31012 .53793 Mdot
.95862 .40079 Mdot
.66849 .43873 Mdot
.58647 .56734 Mdot
.62785 .02558 Mdot
.84105 .13176 Mdot
.25497 .25581 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50508 .00215 Mdot
.51618 .00686 Mdot
.55152 .02184 Mdot
.66281 .06878 Mdot
.97788 .19473 Mdot
.32603 .21517 Mdot
.46216 .08414 Mdot
.54208 .04939 Mdot
.68439 .08795 Mdot
.04543 .22313 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00246 Mdot
.5185 .00785 Mdot
.55889 .02496 Mdot
.68562 .07832 Mdot
.03182 .21396 Mdot
.3306 .18466 Mdot
.42063 .05564 Mdot
.39646 .6031 Mdot
.22771 .51374 Mdot
.82256 .36764 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .0018 Mdot
.51356 .00575 Mdot
.54318 .0183 Mdot
.63677 .05784 Mdot
.91117 .16959 Mdot
.31201 .24773 Mdot
.49201 .11124 Mdot
.66002 .10384 Mdot
.02961 .22842 Mdot
.35504 .20113 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.5261 .01107 Mdot
.58298 .03515 Mdot
.75877 .10864 Mdot
.17292 .25596 Mdot
.3758 .12538 Mdot
.41072 .02158 Mdot
.31863 .56112 Mdot
.00967 .42708 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52632 .01116 Mdot
.58367 .03545 Mdot
.76083 .10949 Mdot
.17617 .25669 Mdot
.37801 .12474 Mdot
.41426 .0224 Mdot
.32802 .56474 Mdot
.03116 .43457 Mdot
.68786 .40586 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49917 .61768 Mdot
.49737 .61692 Mdot
.49161 .61447 Mdot
.47326 .6067 Mdot
.41499 .58202 Mdot
.23518 .5069 Mdot
.81767 .36 Mdot
.61764 .49441 Mdot
.57843 .5938 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51453 .00616 Mdot
.54626 .01961 Mdot
.64642 .0619 Mdot
.9365 .17928 Mdot
.31933 .2366 Mdot
.48572 .10283 Mdot
.63071 .08961 Mdot
.95045 .19761 Mdot
.34332 .24281 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52613 .01108 Mdot
.58307 .03519 Mdot
.75904 .10875 Mdot
.17335 .25606 Mdot
.37609 .1253 Mdot
.41117 .02168 Mdot
.31982 .56158 Mdot
.01234 .428 Mdot
.68637 .41657 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48789 .6129 Mdot
.46142 .60168 Mdot
.37764 .56626 Mdot
.12789 .46368 Mdot
.70629 .35747 Mdot
.51447 .49949 Mdot
.34433 .51288 Mdot
.97618 .3905 Mdot
.64363 .4125 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49206 .61467 Mdot
.47471 .60731 Mdot
.41959 .58397 Mdot
.24893 .51256 Mdot
.83955 .36502 Mdot
.63209 .48982 Mdot
.60079 .59869 Mdot
.71078 .06798 Mdot
.0523 .21107 Mdot
.49812 .61724 Mdot
.49402 .6155 Mdot
.48096 .60996 Mdot
.43939 .59235 Mdot
.3091 .53751 Mdot
.95635 .40002 Mdot
.66826 .43998 Mdot
.58809 .56849 Mdot
.63341 .02801 Mdot
.85623 .13771 Mdot
.26655 .25359 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50694 .00294 Mdot
.5221 .00937 Mdot
.57032 .0298 Mdot
.72061 .09289 Mdot
.10558 .23792 Mdot
.34354 .14707 Mdot
.38283 .02428 Mdot
.26181 .54324 Mdot
.90272 .3961 Mdot
.68063 .48077 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51389 .00589 Mdot
.54423 .01875 Mdot
.64006 .05923 Mdot
.91991 .17295 Mdot
.31488 .24411 Mdot
.49069 .10865 Mdot
.65254 .10003 Mdot
.00974 .22076 Mdot
.35234 .21174 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.5148 .00628 Mdot
.54713 .01998 Mdot
.64913 .06304 Mdot
.94351 .18193 Mdot
.32085 .23321 Mdot
.48273 .10005 Mdot
.61875 .08407 Mdot
.91683 .18422 Mdot
.33406 .25786 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47345 .60677 Mdot
.41558 .58227 Mdot
.23695 .50763 Mdot
.82038 .36058 Mdot
.61959 .49393 Mdot
.58176 .59465 Mdot
.66124 .04912 Mdot
.94327 .17431 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.5033 .0014 Mdot
.51053 .00446 Mdot
.53353 .01422 Mdot
.60646 .04507 Mdot
.82744 .13657 Mdot
.25944 .26699 Mdot
.45313 .11971 Mdot
.57754 .07689 Mdot
.81371 .14596 Mdot
.49889 .61756 Mdot
.49647 .61654 Mdot
.48876 .61327 Mdot
.46421 .60286 Mdot
.38641 .56995 Mdot
.15233 .47336 Mdot
.72307 .35274 Mdot
.52915 .49818 Mdot
.3787 .52505 Mdot
.06341 .42317 Mdot
.6555 .36593 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51185 .00503 Mdot
.53774 .016 Mdot
.61971 .05066 Mdot
.86479 .15147 Mdot
.28915 .26227 Mdot
.48197 .11917 Mdot
.6478 .10249 Mdot
.00481 .22064 Mdot
.35461 .21619 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55364 .02274 Mdot
.66936 .07152 Mdot
.99383 .20053 Mdot
.32755 .20625 Mdot
.45032 .07588 Mdot
.49979 .03057 Mdot
.54893 .03037 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52456 .01042 Mdot
.57812 .0331 Mdot
.7442 .10264 Mdot
.14886 .25009 Mdot
.36139 .13135 Mdot
.39131 .01849 Mdot
.27056 .54341 Mdot
.91308 .3971 Mdot
.67959 .47373 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50707 .003 Mdot
.52251 .00954 Mdot
.5716 .03034 Mdot
.72452 .09451 Mdot
.11311 .24016 Mdot
.34596 .14391 Mdot
.38218 .02238 Mdot
.25738 .5409 Mdot
.8941 .39352 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52246 .00952 Mdot
.57145 .03028 Mdot
.72405 .09431 Mdot
.11222 .2399 Mdot
.34566 .14428 Mdot
.38222 .02259 Mdot
.25779 .54113 Mdot
.89491 .39376 Mdot
.49894 .61759 Mdot
.49664 .61661 Mdot
.48928 .61349 Mdot
.46587 .60356 Mdot
.39165 .57216 Mdot
.16717 .4793 Mdot
.73556 .35129 Mdot
.54171 .49823 Mdot
.40971 .53645 Mdot
.14942 .45717 Mdot
.69651 .33812 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51684 .00714 Mdot
.55361 .02272 Mdot
.66927 .07148 Mdot
.99361 .20045 Mdot
.32753 .20638 Mdot
.45049 .076 Mdot
.50039 .03084 Mdot
.55087 .0312 Mdot
.67638 .07756 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50551 .00234 Mdot
.51755 .00744 Mdot
.55586 .02368 Mdot
.67624 .0744 Mdot
.01017 .20638 Mdot
.32886 .19696 Mdot
.43752 .06716 Mdot
.45485 .01071 Mdot
.40536 .58745 Mdot
.22214 .50479 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50478 .00202 Mdot
.51521 .00645 Mdot
.54844 .02053 Mdot
.6532 .06474 Mdot
.95387 .18583 Mdot
.32278 .228 Mdot
.47747 .09561 Mdot
.5985 .0748 Mdot
.85801 .16039 Mdot
.30336 .27524 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50762 .00323 Mdot
.52429 .0103 Mdot
.57725 .03273 Mdot
.74157 .10156 Mdot
.1443 .2489 Mdot
.35904 .13271 Mdot
.38891 .01846 Mdot
.26535 .54167 Mdot
.49822 .61728 Mdot
.49434 .61564 Mdot
.48198 .61039 Mdot
.44264 .59372 Mdot
.31912 .54169 Mdot
.97904 .40785 Mdot
.6703 .42723 Mdot
.57099 .55666 Mdot
.57467 .00227 Mdot
.68629 .06899 Mdot
.01777 .20487 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50562 .00238 Mdot
.51789 .00759 Mdot
.55695 .02414 Mdot
.67963 .07582 Mdot
.01808 .20917 Mdot
.32947 .19245 Mdot
.43127 .06292 Mdot
.43317 .00117 Mdot
.33773 .55905 Mdot
.03892 .43336 Mdot
.49895 .61759 Mdot
.49666 .61662 Mdot
.48937 .61353 Mdot
.46615 .60368 Mdot
.39253 .57254 Mdot
.16968 .48031 Mdot
.73786 .35115 Mdot
.54408 .49827 Mdot
.41558 .53861 Mdot
.1663 .46397 Mdot
.71055 .33636 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51453 .00616 Mdot
.54627 .01961 Mdot
.64644 .06191 Mdot
.93655 .1793 Mdot
.31934 .23658 Mdot
.48569 .10281 Mdot
.63062 .08957 Mdot
.95021 .19752 Mdot
.34327 .24292 Mdot
.49828 .6173 Mdot
.49451 .61571 Mdot
.48252 .61062 Mdot
.44435 .59444 Mdot
.32438 .54389 Mdot
.99129 .41217 Mdot
.67126 .42024 Mdot
.56132 .55009 Mdot
.54112 .60555 Mdot
.5819 .02521 Mdot
.74018 .09782 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50334 .00142 Mdot
.51064 .00451 Mdot
.5339 .01437 Mdot
.60761 .04556 Mdot
.83073 .13789 Mdot
.26252 .26686 Mdot
.45631 .11977 Mdot
.58539 .07978 Mdot
.83651 .1552 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52397 .01017 Mdot
.57625 .03231 Mdot
.73857 .10032 Mdot
.13901 .24749 Mdot
.35645 .13439 Mdot
.3866 .01863 Mdot
.26069 .54022 Mdot
.89659 .393 Mdot
.67691 .48227 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50691 .00293 Mdot
.52201 .00933 Mdot
.57001 .02967 Mdot
.71969 .0925 Mdot
.10377 .23738 Mdot
.343 .14785 Mdot
.3831 .02478 Mdot
.2632 .54393 Mdot
.90538 .39689 Mdot
.49873 .61749 Mdot
.49594 .61631 Mdot
.48708 .61255 Mdot
.45885 .60059 Mdot
.36957 .56286 Mdot
.10583 .45503 Mdot
.69479 .36399 Mdot
.50825 .50275 Mdot
.33409 .51039 Mdot
.95374 .38297 Mdot
.64181 .42525 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00215 Mdot
.51612 .00683 Mdot
.55131 .02175 Mdot
.66214 .0685 Mdot
.97625 .19413 Mdot
.32585 .21606 Mdot
.46332 .08496 Mdot
.54625 .05125 Mdot
.69757 .09352 Mdot
.07479 .23314 Mdot
.49828 .6173 Mdot
.49451 .61571 Mdot
.48251 .61062 Mdot
.44432 .59443 Mdot
.3243 .54386 Mdot
.99109 .4121 Mdot
.67124 .42036 Mdot
.56148 .5502 Mdot
.54167 .60579 Mdot
.58367 .02595 Mdot
.74545 .09999 Mdot
.49887 .61756 Mdot
.49641 .61651 Mdot
.48858 .61319 Mdot
.46361 .60261 Mdot
.38455 .56917 Mdot
.1471 .47128 Mdot
.7191 .35352 Mdot
.52535 .49829 Mdot
.36946 .52169 Mdot
.03899 .41379 Mdot
.65062 .37801 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50328 .00139 Mdot
.51044 .00443 Mdot
.53326 .0141 Mdot
.60559 .04471 Mdot
.82495 .13557 Mdot
.25705 .26705 Mdot
.45066 .11966 Mdot
.57143 .07464 Mdot
.7958 .13867 Mdot
.24908 .28014 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52227 .00944 Mdot
.57084 .03002 Mdot
.7222 .09354 Mdot
.10866 .23884 Mdot
.3445 .14576 Mdot
.38247 .02347 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49147 .61442 Mdot
.47284 .60652 Mdot
.41367 .58146 Mdot
.23125 .50529 Mdot
.81175 .35877 Mdot
.61325 .49535 Mdot
.57063 .5917 Mdot
.63051 .03701 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00133 Mdot
.50996 .00422 Mdot
.53171 .01344 Mdot
.60071 .04265 Mdot
.81091 .12991 Mdot
.24257 .26678 Mdot
.43575 .11939 Mdot
.53516 .06144 Mdot
.68687 .09377 Mdot
.05879 .22986 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51254 .00532 Mdot
.53994 .01693 Mdot
.62662 .05357 Mdot
.88381 .15895 Mdot
.30021 .25735 Mdot
.48967 .11709 Mdot
.66364 .10752 Mdot
.04206 .23387 Mdot
.35812 .19533 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52029 .0086 Mdot
.56456 .02736 Mdot
.70304 .08559 Mdot
.06994 .22676 Mdot
.33527 .16398 Mdot
.39532 .03711 Mdot
.30943 .56495 Mdot
.00126 .42757 Mdot
.6912 .4264 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00225 Mdot
.51694 .00718 Mdot
.55393 .02286 Mdot
.67027 .0719 Mdot
.99601 .20132 Mdot
.32773 .20502 Mdot
.44864 .07472 Mdot
.49383 .02793 Mdot
.52976 .02221 Mdot
.61007 .04964 Mdot
.49941 .61778 Mdot
.49812 .61724 Mdot
.494 .61549 Mdot
.48089 .60993 Mdot
.4392 .59226 Mdot
.30849 .53726 Mdot
.955 .39956 Mdot
.66811 .44073 Mdot
.58904 .56917 Mdot
.63668 .02944 Mdot
.86505 .14114 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52237 .00948 Mdot
.57115 .03015 Mdot
.72314 .09394 Mdot
.11048 .23939 Mdot
.34509 .145 Mdot
.38232 .02301 Mdot
.25867 .54162 Mdot
.89665 .39429 Mdot
.67899 .48351 Mdot
.49764 .61703 Mdot
.49249 .61485 Mdot
.47608 .60789 Mdot
.42392 .5858 Mdot
.26193 .51792 Mdot
.86188 .37079 Mdot
.64396 .48336 Mdot
.61373 .59935 Mdot
.73995 .078 Mdot
.10442 .22526 Mdot
.32326 .13525 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47506 .60746 Mdot
.42071 .58444 Mdot
.25227 .51393 Mdot
.84512 .3664 Mdot
.63532 .48837 Mdot
.60492 .59924 Mdot
.72074 .07158 Mdot
.07127 .21664 Mdot
.31843 .15275 Mdot
.50057 .00024 Mdot
.5018 .00076 Mdot
.50574 .00243 Mdot
.51828 .00775 Mdot
.55817 .02466 Mdot
.6834 .07739 Mdot
.02676 .21221 Mdot
.33017 .18752 Mdot
.4245 .0583 Mdot
.40978 .60894 Mdot
.26685 .5297 Mdot
.88653 .38298 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51372 .00582 Mdot
.54369 .01852 Mdot
.63839 .05852 Mdot
.91547 .17125 Mdot
.31347 .24598 Mdot
.49148 .11001 Mdot
.6567 .10211 Mdot
.0208 .22502 Mdot
.35379 .2058 Mdot
.49851 .6174 Mdot
.49524 .61602 Mdot
.48485 .61161 Mdot
.45176 .59758 Mdot
.34742 .55355 Mdot
.04769 .43279 Mdot
.67749 .38924 Mdot
.52167 .52173 Mdot
.39826 .54176 Mdot
.13243 .45374 Mdot
.6901 .34465 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00164 Mdot
.51236 .00524 Mdot
.53935 .01668 Mdot
.62478 .05279 Mdot
.87877 .15698 Mdot
.29753 .25881 Mdot
.48812 .11779 Mdot
.66091 .10679 Mdot
.03599 .23181 Mdot
.35755 .19873 Mdot
.49774 .61708 Mdot
.49281 .61498 Mdot
.47708 .60832 Mdot
.4271 .58714 Mdot
.27154 .5219 Mdot
.87944 .3757 Mdot
.65137 .47708 Mdot
.61765 .59719 Mdot
.74475 .07855 Mdot
.11045 .22602 Mdot
.32346 .13165 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50454 .00192 Mdot
.51446 .00613 Mdot
.54605 .01952 Mdot
.64574 .06161 Mdot
.93474 .17862 Mdot
.31891 .23743 Mdot
.48638 .1035 Mdot
.63345 .09089 Mdot
.95806 .20062 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52605 .01104 Mdot
.58282 .03509 Mdot
.75828 .10844 Mdot
.17215 .25579 Mdot
.37529 .12554 Mdot
.40992 .0214 Mdot
.31652 .56031 Mdot
.00494 .42547 Mdot
.50047 .0002 Mdot
.50148 .00063 Mdot
.50472 .002 Mdot
.51505 .00638 Mdot
.54791 .02031 Mdot
.65155 .06405 Mdot
.94969 .18426 Mdot
.32204 .23013 Mdot
.47971 .09744 Mdot
.60703 .07869 Mdot
.88306 .1706 Mdot
.31914 .26951 Mdot
.49969 .6179 Mdot
.49901 .61761 Mdot
.49684 .61669 Mdot
.48993 .61376 Mdot
.46792 .60443 Mdot
.39811 .57489 Mdot
.18568 .48675 Mdot
.75376 .35109 Mdot
.5605 .49859 Mdot
.45582 .55334 Mdot
.28571 .5129 Mdot
.49909 .61765 Mdot
.49711 .61681 Mdot
.49079 .61413 Mdot
.47067 .6056 Mdot
.40681 .57857 Mdot
.21103 .49703 Mdot
.78363 .35389 Mdot
.58966 .49815 Mdot
.52316 .57694 Mdot
.49129 .59834 Mdot
.44637 .59027 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50588 .00249 Mdot
.51873 .00794 Mdot
.5596 .02526 Mdot
.68779 .07923 Mdot
.03672 .21565 Mdot
.33105 .18191 Mdot
.41695 .05309 Mdot
.38385 .59758 Mdot
.19159 .49921 Mdot
.77649 .36149 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.51871 .00793 Mdot
.55955 .02524 Mdot
.68765 .07917 Mdot
.03639 .21553 Mdot
.33102 .18209 Mdot
.4172 .05326 Mdot
.38469 .59795 Mdot
.19396 .50016 Mdot
.49819 .61727 Mdot
.49422 .61558 Mdot
.4816 .61023 Mdot
.44142 .59321 Mdot
.31536 .54012 Mdot
.97041 .40484 Mdot
.66959 .43212 Mdot
.57768 .56123 Mdot
.59771 .01238 Mdot
.75528 .09738 Mdot
.15144 .24484 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52237 .00948 Mdot
.57115 .03015 Mdot
.72315 .09394 Mdot
.11049 .23939 Mdot
.34509 .14499 Mdot
.38232 .02301 Mdot
.25867 .54162 Mdot
.89664 .39429 Mdot
.49915 .61767 Mdot
.49729 .61689 Mdot
.49137 .61437 Mdot
.47251 .60638 Mdot
.41262 .58102 Mdot
.22815 .50402 Mdot
.80719 .35787 Mdot
.60972 .49599 Mdot
.56409 .58983 Mdot
.61201 .02962 Mdot
.81442 .12509 Mdot
.49822 .61728 Mdot
.49431 .61562 Mdot
.48188 .61035 Mdot
.44233 .59359 Mdot
.31816 .54129 Mdot
.97681 .40707 Mdot
.67012 .42849 Mdot
.57273 .55784 Mdot
.58067 .00491 Mdot
.7045 .07653 Mdot
.05737 .21809 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.49831 .61732 Mdot
.49461 .61575 Mdot
.48282 .61075 Mdot
.44532 .59486 Mdot
.32741 .54516 Mdot
.99844 .41472 Mdot
.67181 .41617 Mdot
.55569 .54626 Mdot
.52139 .59684 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50664 .00281 Mdot
.52115 .00897 Mdot
.56728 .02851 Mdot
.71135 .08904 Mdot
.08716 .23226 Mdot
.33866 .15544 Mdot
.38753 .0302 Mdot
.28138 .55243 Mdot
.94113 .40775 Mdot
.68718 .46108 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49775 .61708 Mdot
.49282 .61499 Mdot
.47713 .60834 Mdot
.42727 .58721 Mdot
.27205 .52211 Mdot
.8804 .37598 Mdot
.65173 .47671 Mdot
.61771 .59701 Mdot
.74461 .07842 Mdot
.49917 .61768 Mdot
.49737 .61692 Mdot
.49161 .61447 Mdot
.47326 .6067 Mdot
.415 .58203 Mdot
.23522 .50692 Mdot
.81774 .36001 Mdot
.61769 .4944 Mdot
.57852 .59382 Mdot
.6524 .04566 Mdot
.92151 .16632 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47764 .60855 Mdot
.42887 .58789 Mdot
.27691 .52412 Mdot
.88962 .37868 Mdot
.65495 .473 Mdot
.61768 .595 Mdot
.74127 .07638 Mdot
.10324 .22371 Mdot
.32098 .13457 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52544 .01079 Mdot
.5809 .03427 Mdot
.75255 .10609 Mdot
.1629 .25361 Mdot
.36939 .12761 Mdot
.40122 .01967 Mdot
.2942 .55189 Mdot
.9576 .41 Mdot
.68385 .44885 Mdot
.49951 .61783 Mdot
.49843 .61737 Mdot
.495 .61592 Mdot
.48408 .61129 Mdot
.44933 .59656 Mdot
.33985 .55037 Mdot
.02869 .42572 Mdot
.67472 .39927 Mdot
.53328 .53062 Mdot
.44141 .56125 Mdot
.26362 .50815 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48988 .61374 Mdot
.46776 .60436 Mdot
.39761 .57468 Mdot
.18426 .48617 Mdot
.75225 .35104 Mdot
.55895 .49857 Mdot
.45207 .55198 Mdot
.27439 .50822 Mdot
.86076 .3624 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48603 .61211 Mdot
.45551 .59917 Mdot
.35911 .55846 Mdot
.07792 .44425 Mdot
.68446 .37487 Mdot
.50978 .51008 Mdot
.34977 .51914 Mdot
.99642 .39965 Mdot
.64844 .40297 Mdot
.49853 .61741 Mdot
.49531 .61605 Mdot
.48506 .6117 Mdot
.45242 .59787 Mdot
.34948 .55441 Mdot
.05295 .43477 Mdot
.67845 .38658 Mdot
.51896 .51946 Mdot
.38783 .53699 Mdot
.10204 .44141 Mdot
.67346 .35316 Mdot
.49837 .61734 Mdot
.49482 .61584 Mdot
.48349 .61103 Mdot
.44744 .59575 Mdot
.33396 .5479 Mdot
.01421 .42042 Mdot
.67317 .40726 Mdot
.54359 .53794 Mdot
.47856 .57785 Mdot
.38149 .55804 Mdot
.12261 .45804 Mdot
.50013 5e-05 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50419 .00178 Mdot
.51335 .00566 Mdot
.54251 .01802 Mdot
.63467 .05696 Mdot
.90558 .16743 Mdot
.30996 .24992 Mdot
.49234 .11272 Mdot
.66325 .10563 Mdot
.0383 .23179 Mdot
.49825 .61729 Mdot
.49444 .61568 Mdot
.48228 .61052 Mdot
.4436 .59413 Mdot
.32208 .54293 Mdot
.98588 .41026 Mdot
.67084 .42333 Mdot
.5656 .55299 Mdot
.556 .6121 Mdot
.62868 .04492 Mdot
.87402 .15163 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50719 .00305 Mdot
.52289 .00971 Mdot
.57283 .03086 Mdot
.72822 .09604 Mdot
.12012 .24221 Mdot
.34846 .14112 Mdot
.38232 .02093 Mdot
.25531 .53954 Mdot
.8897 .39208 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00267 Mdot
.52009 .00852 Mdot
.56392 .02709 Mdot
.70108 .08477 Mdot
.06578 .2254 Mdot
.3346 .16614 Mdot
.39762 .03895 Mdot
.31745 .56849 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50496 .0021 Mdot
.51581 .0067 Mdot
.55033 .02134 Mdot
.65911 .06723 Mdot
.96873 .19136 Mdot
.32496 .22016 Mdot
.46844 .08868 Mdot
.5649 .05961 Mdot
.75602 .11812 Mdot
.1857 .26556 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.51211 .00514 Mdot
.53856 .01635 Mdot
.6223 .05175 Mdot
.87196 .1543 Mdot
.29362 .2606 Mdot
.48546 .11856 Mdot
.65553 .10511 Mdot
.02349 .22741 Mdot
.35634 .20571 Mdot
.49899 .6176 Mdot
.49677 .61667 Mdot
.48972 .61368 Mdot
.46727 .60416 Mdot
.39607 .57403 Mdot
.17982 .48438 Mdot
.74767 .35095 Mdot
.55423 .49848 Mdot
.44058 .54779 Mdot
.23984 .49397 Mdot
.80086 .34673 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.50992 .00421 Mdot
.5316 .0134 Mdot
.60036 .0425 Mdot
.80988 .12949 Mdot
.24144 .26672 Mdot
.43461 .11938 Mdot
.53242 .06045 Mdot
.67854 .09031 Mdot
.03973 .22323 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48327 .61094 Mdot
.44674 .59546 Mdot
.33181 .547 Mdot
.009 .41853 Mdot
.6727 .41019 Mdot
.54751 .54067 Mdot
.49254 .58406 Mdot
.42638 .57715 Mdot
.25369 .5113 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51225 .0052 Mdot
.53903 .01655 Mdot
.62375 .05236 Mdot
.87596 .15587 Mdot
.29596 .25957 Mdot
.4871 .11813 Mdot
.65892 .10619 Mdot
.03145 .23023 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50937 .00397 Mdot
.52985 .01266 Mdot
.59485 .04017 Mdot
.79385 .12299 Mdot
.22258 .26497 Mdot
.41611 .11961 Mdot
.48955 .04539 Mdot
.54733 .03571 Mdot
.67505 .07894 Mdot
.4992 .61769 Mdot
.49745 .61695 Mdot
.49188 .61459 Mdot
.47414 .60707 Mdot
.41777 .5832 Mdot
.24347 .51031 Mdot
.83065 .36289 Mdot
.62655 .4919 Mdot
.59291 .59724 Mdot
.69084 .06053 Mdot
.0112 .19799 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47472 .60732 Mdot
.41963 .58398 Mdot
.24904 .5126 Mdot
.83972 .36506 Mdot
.63219 .48978 Mdot
.60093 .59871 Mdot
.71112 .0681 Mdot
.05296 .21127 Mdot
.31681 .16307 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47887 .60908 Mdot
.43278 .58955 Mdot
.28882 .52906 Mdot
.9132 .38589 Mdot
.66142 .46243 Mdot
.61234 .5877 Mdot
.71812 .06538 Mdot
.05787 .20997 Mdot
.31271 .1575 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50467 .00198 Mdot
.51489 .00631 Mdot
.54741 .0201 Mdot
.65001 .06341 Mdot
.94576 .18278 Mdot
.3213 .2321 Mdot
.48167 .09911 Mdot
.61461 .08216 Mdot
.90498 .17946 Mdot
.32956 .26241 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.5208 .00882 Mdot
.56618 .02805 Mdot
.70801 .08765 Mdot
.0803 .23009 Mdot
.33719 .15877 Mdot
.39028 .03281 Mdot
.29153 .557 Mdot
.96212 .41445 Mdot
.689 .44923 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50978 .00415 Mdot
.53116 .01321 Mdot
.59897 .04191 Mdot
.80586 .12786 Mdot
.23693 .26641 Mdot
.43007 .11937 Mdot
.52165 .0566 Mdot
.64562 .07661 Mdot
.95878 .19355 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41914 .58378 Mdot
.24757 .512 Mdot
.83729 .36447 Mdot
.63073 .49037 Mdot
.59895 .59839 Mdot
.70621 .06629 Mdot
.04323 .20829 Mdot
.3162 .1687 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00214 Mdot
.51611 .00683 Mdot
.5513 .02174 Mdot
.6621 .06848 Mdot
.97614 .19409 Mdot
.32584 .21613 Mdot
.4634 .08502 Mdot
.54654 .05138 Mdot
.6985 .09392 Mdot
.07679 .2338 Mdot
.49991 .618 Mdot
.49973 .61792 Mdot
.49913 .61766 Mdot
.49723 .61686 Mdot
.49116 .61429 Mdot
.47185 .6061 Mdot
.41053 .58014 Mdot
.22198 .5015 Mdot
.79838 .35624 Mdot
.60257 .49702 Mdot
.55018 .58566 Mdot
.49933 .61775 Mdot
.49788 .61713 Mdot
.49324 .61517 Mdot
.47845 .6089 Mdot
.43144 .58898 Mdot
.28473 .52737 Mdot
.90496 .38332 Mdot
.65942 .46628 Mdot
.61499 .59057 Mdot
.72842 .07011 Mdot
.0784 .2163 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02052 Mdot
.65314 .06472 Mdot
.95372 .18577 Mdot
.32275 .22807 Mdot
.47756 .09568 Mdot
.59882 .07494 Mdot
.85895 .16077 Mdot
.30404 .27508 Mdot
.50014 6e-05 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51398 .00593 Mdot
.54452 .01887 Mdot
.64096 .0596 Mdot
.92226 .17385 Mdot
.31559 .24309 Mdot
.49017 .1079 Mdot
.65003 .0988 Mdot
.00305 .21818 Mdot
.49891 .61757 Mdot
.49654 .61657 Mdot
.48897 .61336 Mdot
.46488 .60314 Mdot
.38854 .57085 Mdot
.15834 .47576 Mdot
.72792 .35202 Mdot
.53393 .49815 Mdot
.39046 .52936 Mdot
.09535 .43565 Mdot
.66562 .35244 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50493 .00209 Mdot
.51571 .00666 Mdot
.55003 .02121 Mdot
.65815 .06683 Mdot
.96635 .19048 Mdot
.32465 .22144 Mdot
.46999 .08983 Mdot
.57058 .06217 Mdot
.77361 .12548 Mdot
.21276 .2714 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50626 .00265 Mdot
.51994 .00846 Mdot
.56346 .02689 Mdot
.69966 .08418 Mdot
.06274 .2244 Mdot
.33413 .16773 Mdot
.39938 .04032 Mdot
.32355 .57117 Mdot
.03404 .4391 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50749 .00318 Mdot
.52387 .01012 Mdot
.57591 .03216 Mdot
.73754 .09989 Mdot
.13717 .24699 Mdot
.35559 .13499 Mdot
.38592 .01874 Mdot
.25941 .53985 Mdot
.89459 .39256 Mdot
.67657 .48329 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50429 .00182 Mdot
.51366 .00579 Mdot
.54351 .01844 Mdot
.6378 .05828 Mdot
.91392 .17065 Mdot
.31296 .24662 Mdot
.49169 .11047 Mdot
.65798 .10277 Mdot
.02419 .22633 Mdot
.35426 .20399 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52657 .01126 Mdot
.58446 .03578 Mdot
.76318 .11045 Mdot
.17981 .25749 Mdot
.38055 .12407 Mdot
.41848 .02344 Mdot
.3394 .56916 Mdot
.05827 .44429 Mdot
.69167 .39147 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.52082 .00883 Mdot
.56623 .02807 Mdot
.70816 .08771 Mdot
.08061 .23019 Mdot
.33725 .15861 Mdot
.39014 .03269 Mdot
.29103 .55678 Mdot
.96107 .41411 Mdot
.68893 .44984 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52382 .0101 Mdot
.57576 .0321 Mdot
.73709 .09971 Mdot
.13636 .24677 Mdot
.35522 .13526 Mdot
.38564 .0188 Mdot
.2589 .53971 Mdot
.89381 .39239 Mdot
.49774 .61708 Mdot
.4928 .61498 Mdot
.47708 .60831 Mdot
.42709 .58714 Mdot
.27151 .52188 Mdot
.87938 .37568 Mdot
.65135 .4771 Mdot
.61764 .5972 Mdot
.74476 .07856 Mdot
.11048 .22603 Mdot
.32347 .13164 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50522 .00221 Mdot
.51663 .00705 Mdot
.55295 .02245 Mdot
.66724 .07063 Mdot
.9887 .19867 Mdot
.3271 .20914 Mdot
.45423 .07857 Mdot
.51365 .03673 Mdot
.59353 .04937 Mdot
.80578 .13117 Mdot
.49904 .61763 Mdot
.49696 .61674 Mdot
.4903 .61392 Mdot
.46911 .60494 Mdot
.40189 .57649 Mdot
.19664 .49118 Mdot
.76595 .35185 Mdot
.57279 .49866 Mdot
.48506 .56381 Mdot
.37497 .54999 Mdot
.09602 .44564 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50778 .0033 Mdot
.52477 .0105 Mdot
.57877 .03337 Mdot
.74615 .10345 Mdot
.1522 .25095 Mdot
.36319 .1304 Mdot
.39331 .01862 Mdot
.27513 .54499 Mdot
.92118 .39928 Mdot
.68069 .4694 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51186 .00503 Mdot
.53778 .01602 Mdot
.61983 .05071 Mdot
.86511 .15159 Mdot
.28936 .2622 Mdot
.48214 .11915 Mdot
.64819 .10262 Mdot
.00576 .22099 Mdot
.3547 .21565 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51524 .00646 Mdot
.54854 .02058 Mdot
.65351 .06488 Mdot
.95468 .18613 Mdot
.32291 .22758 Mdot
.47703 .09525 Mdot
.59681 .07403 Mdot
.853 .15834 Mdot
.29966 .27605 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48477 .61157 Mdot
.4515 .59747 Mdot
.34659 .5532 Mdot
.04559 .432 Mdot
.67713 .39031 Mdot
.52282 .52266 Mdot
.40263 .54375 Mdot
.14533 .45901 Mdot
.69909 .34224 Mdot
.49835 .61733 Mdot
.49473 .6158 Mdot
.48321 .61092 Mdot
.44656 .59538 Mdot
.33125 .54677 Mdot
.00766 .41804 Mdot
.67258 .41094 Mdot
.54854 .54137 Mdot
.49618 .58568 Mdot
.43811 .58214 Mdot
.28951 .5262 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50556 .00236 Mdot
.51773 .00752 Mdot
.55642 .02392 Mdot
.678 .07514 Mdot
.01428 .20784 Mdot
.32917 .19461 Mdot
.43427 .06495 Mdot
.44355 .00574 Mdot
.36992 .57253 Mdot
.12217 .46492 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.4788 .60904 Mdot
.43254 .58945 Mdot
.28809 .52876 Mdot
.91172 .38542 Mdot
.66108 .46313 Mdot
.61287 .58824 Mdot
.72013 .06629 Mdot
.06193 .21124 Mdot
.31316 .15527 Mdot
.49838 .61735 Mdot
.49483 .61584 Mdot
.48353 .61105 Mdot
.44758 .59581 Mdot
.3344 .54809 Mdot
.01527 .42081 Mdot
.67327 .40667 Mdot
.5428 .5374 Mdot
.47575 .5766 Mdot
.37247 .5542 Mdot
.09772 .44823 Mdot
.49939 .61777 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48014 .60961 Mdot
.43682 .59126 Mdot
.30118 .53421 Mdot
.93906 .39423 Mdot
.66613 .44935 Mdot
.59954 .57688 Mdot
.67271 .04522 Mdot
.95702 .17571 Mdot
.4992 .6177 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.47429 .60713 Mdot
.41826 .5834 Mdot
.24493 .51091 Mdot
.83299 .36344 Mdot
.62806 .49138 Mdot
.59514 .59769 Mdot
.69659 .0627 Mdot
.02346 .20201 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50384 .00163 Mdot
.51223 .00519 Mdot
.53894 .01651 Mdot
.62349 .05225 Mdot
.87523 .15558 Mdot
.29554 .25977 Mdot
.48682 .11822 Mdot
.65835 .10601 Mdot
.03011 .22976 Mdot
.35698 .20201 Mdot
.49951 .61782 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48405 .61127 Mdot
.44921 .5965 Mdot
.33948 .55022 Mdot
.02776 .42538 Mdot
.67461 .39978 Mdot
.53391 .53108 Mdot
.4437 .56228 Mdot
.27079 .51117 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51605 .0068 Mdot
.55109 .02166 Mdot
.66145 .06821 Mdot
.97455 .1935 Mdot
.32566 .217 Mdot
.4645 .08581 Mdot
.55054 .05318 Mdot
.71113 .09925 Mdot
.10337 .24242 Mdot
.49766 .61704 Mdot
.49256 .61488 Mdot
.47629 .60798 Mdot
.42459 .58608 Mdot
.26397 .51876 Mdot
.86553 .37178 Mdot
.64564 .48214 Mdot
.61497 .59908 Mdot
.74216 .0786 Mdot
.10778 .22597 Mdot
.32381 .13351 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57373 .03124 Mdot
.73095 .09717 Mdot
.1252 .24366 Mdot
.35043 .1392 Mdot
.3829 .02007 Mdot
.25513 .53907 Mdot
.88876 .3916 Mdot
.67599 .48654 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50483 .00205 Mdot
.5154 .00653 Mdot
.54903 .02079 Mdot
.65506 .06553 Mdot
.95859 .18759 Mdot
.32354 .22555 Mdot
.47478 .09347 Mdot
.58835 .07019 Mdot
.82775 .14796 Mdot
.27796 .27824 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51885 .00799 Mdot
.55998 .02542 Mdot
.68896 .07972 Mdot
.03934 .21654 Mdot
.33131 .18045 Mdot
.41502 .05174 Mdot
.37724 .59468 Mdot
.17303 .49183 Mdot
.75747 .3612 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.48929 .61349 Mdot
.4659 .60357 Mdot
.39174 .5722 Mdot
.16742 .4794 Mdot
.7358 .35127 Mdot
.54195 .49823 Mdot
.4103 .53667 Mdot
.15111 .45785 Mdot
.69781 .33788 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52328 .00987 Mdot
.57403 .03137 Mdot
.73188 .09755 Mdot
.12691 .24414 Mdot
.35112 .13857 Mdot
.38318 .01982 Mdot
.25533 .53902 Mdot
.88888 .39155 Mdot
.67589 .4864 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52125 .00901 Mdot
.56761 .02865 Mdot
.71236 .08946 Mdot
.0892 .2329 Mdot
.33913 .15447 Mdot
.38681 .02946 Mdot
.27865 .55119 Mdot
.93562 .40603 Mdot
.68655 .4641 Mdot
.49849 .61739 Mdot
.4952 .616 Mdot
.4847 .61155 Mdot
.45129 .59739 Mdot
.34596 .55294 Mdot
.04399 .43141 Mdot
.67687 .39114 Mdot
.52372 .52338 Mdot
.40603 .54529 Mdot
.15542 .46315 Mdot
.70701 .3409 Mdot
.49858 .61743 Mdot
.49546 .61611 Mdot
.48555 .61191 Mdot
.45399 .59853 Mdot
.35437 .55647 Mdot
.06555 .43953 Mdot
.68116 .38047 Mdot
.51351 .51442 Mdot
.3661 .52693 Mdot
.04071 .41693 Mdot
.65492 .3796 Mdot
.49803 .6172 Mdot
.49371 .61537 Mdot
.47998 .60954 Mdot
.43629 .59103 Mdot
.29955 .53353 Mdot
.93557 .39308 Mdot
.66561 .45119 Mdot
.60161 .57848 Mdot
.67988 .04837 Mdot
.97407 .18182 Mdot
.30699 .20575 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50428 .00181 Mdot
.51364 .00578 Mdot
.54342 .01841 Mdot
.63753 .05816 Mdot
.91321 .17038 Mdot
.31272 .24691 Mdot
.49178 .11067 Mdot
.65853 .10306 Mdot
.02566 .2269 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.4866 .61235 Mdot
.45732 .59994 Mdot
.36479 .56084 Mdot
.09296 .45004 Mdot
.68949 .36868 Mdot
.5077 .50568 Mdot
.33747 .51282 Mdot
.96366 .38701 Mdot
.64389 .4204 Mdot
.50001 0 Mdot
.50004 1e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50362 .00153 Mdot
.51153 .00489 Mdot
.53672 .01557 Mdot
.61651 .04931 Mdot
.85587 .14793 Mdot
.28306 .26402 Mdot
.47665 .11965 Mdot
.49915 .61767 Mdot
.4973 .61689 Mdot
.4914 .61439 Mdot
.4726 .60642 Mdot
.41291 .58114 Mdot
.229 .50437 Mdot
.80843 .35811 Mdot
.61069 .49582 Mdot
.56591 .59036 Mdot
.61719 .03169 Mdot
.8288 .13078 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.42751 .58731 Mdot
.27278 .52241 Mdot
.88177 .37637 Mdot
.65223 .47618 Mdot
.61779 .59675 Mdot
.74433 .07821 Mdot
.10946 .22566 Mdot
.49771 .61706 Mdot
.49269 .61493 Mdot
.47672 .60816 Mdot
.42595 .58666 Mdot
.26806 .52046 Mdot
.87298 .37386 Mdot
.64884 .4795 Mdot
.6168 .59823 Mdot
.74465 .07902 Mdot
.11111 .22648 Mdot
.32411 .13164 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.5093 .00394 Mdot
.52962 .01256 Mdot
.5941 .03985 Mdot
.79165 .12209 Mdot
.21981 .26462 Mdot
.41352 .11972 Mdot
.48379 .04343 Mdot
.52978 .02843 Mdot
.62018 .05587 Mdot
.49861 .61745 Mdot
.49559 .61616 Mdot
.48594 .61207 Mdot
.45522 .59905 Mdot
.3582 .55808 Mdot
.07554 .44334 Mdot
.68377 .37591 Mdot
.51037 .51086 Mdot
.35249 .52046 Mdot
.00371 .40247 Mdot
.64936 .39904 Mdot
.49829 .61731 Mdot
.49455 .61572 Mdot
.48265 .61068 Mdot
.44476 .59462 Mdot
.32568 .54444 Mdot
.99434 .41326 Mdot
.67149 .4185 Mdot
.55891 .54846 Mdot
.5327 .60183 Mdot
.55519 .0139 Mdot
.65881 .06404 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50962 .00408 Mdot
.53063 .01299 Mdot
.59731 .04121 Mdot
.80101 .1259 Mdot
.2313 .26593 Mdot
.42449 .1194 Mdot
.50863 .052 Mdot
.6057 .05999 Mdot
.84991 .15093 Mdot
.49908 .61765 Mdot
.49708 .6168 Mdot
.4907 .61409 Mdot
.47037 .60547 Mdot
.40587 .57817 Mdot
.20825 .4959 Mdot
.78006 .3534 Mdot
.58637 .49832 Mdot
.51595 .57452 Mdot
.46942 .58928 Mdot
.37731 .56111 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51216 .00515 Mdot
.53871 .01641 Mdot
.62277 .05195 Mdot
.87324 .1548 Mdot
.29438 .26028 Mdot
.48601 .11843 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51432 .00607 Mdot
.5456 .01933 Mdot
.64435 .06103 Mdot
.93114 .17724 Mdot
.31803 .23911 Mdot
.48766 .10484 Mdot
.63879 .0934 Mdot
.9727 .20637 Mdot
.34736 .23155 Mdot
.50063 .00027 Mdot
.50199 .00085 Mdot
.50635 .00269 Mdot
.52023 .00858 Mdot
.56439 .02729 Mdot
.70251 .08536 Mdot
.06881 .22639 Mdot
.33508 .16457 Mdot
.39593 .03761 Mdot
.31157 .56589 Mdot
.00612 .42925 Mdot
.69149 .42358 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48774 .61284 Mdot
.46097 .60149 Mdot
.37623 .56566 Mdot
.12398 .46214 Mdot
.70401 .35848 Mdot
.51288 .49991 Mdot
.34103 .51183 Mdot
.96845 .38777 Mdot
.64289 .41682 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50386 .00164 Mdot
.51231 .00522 Mdot
.53919 .01662 Mdot
.62427 .05258 Mdot
.87737 .15643 Mdot
.29675 .25919 Mdot
.48763 .11797 Mdot
.65996 .10651 Mdot
.03383 .23106 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .00341 Mdot
.52558 .01085 Mdot
.58135 .03446 Mdot
.75389 .10664 Mdot
.16509 .25414 Mdot
.37074 .1271 Mdot
.40311 .02001 Mdot
.29897 .55367 Mdot
.96731 .41306 Mdot
.68434 .44315 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47473 .60732 Mdot
.41963 .58398 Mdot
.24904 .5126 Mdot
.83973 .36506 Mdot
.6322 .48977 Mdot
.60094 .59871 Mdot
.71114 .06811 Mdot
.05299 .21128 Mdot
.31682 .16305 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50788 .00334 Mdot
.52511 .01065 Mdot
.57986 .03384 Mdot
.74944 .1048 Mdot
.15774 .25235 Mdot
.36631 .1289 Mdot
.39712 .01904 Mdot
.28413 .5482 Mdot
.93788 .40404 Mdot
.68246 .46018 Mdot
.50022 .0001 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50725 .00308 Mdot
.5231 .0098 Mdot
.57349 .03114 Mdot
.73023 .09687 Mdot
.12387 .24328 Mdot
.3499 .13969 Mdot
.38271 .02027 Mdot
.25507 .53915 Mdot
.88882 .39168 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47767 .60857 Mdot
.42897 .58793 Mdot
.27722 .52425 Mdot
.89021 .37885 Mdot
.65514 .47275 Mdot
.61763 .59485 Mdot
.74094 .07621 Mdot
.10259 .22351 Mdot
.32079 .13486 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51669 .00708 Mdot
.55312 .02252 Mdot
.66777 .07085 Mdot
.98998 .19914 Mdot
.32721 .20842 Mdot
.45327 .0779 Mdot
.51022 .0352 Mdot
.58249 .04466 Mdot
.77302 .11776 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50405 .00172 Mdot
.5129 .00547 Mdot
.54108 .01742 Mdot
.6302 .05508 Mdot
.89356 .16276 Mdot
.30494 .25425 Mdot
.49167 .1154 Mdot
.66591 .10768 Mdot
.04632 .23511 Mdot
.35823 .19277 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50617 .00262 Mdot
.51967 .00834 Mdot
.5626 .02653 Mdot
.69702 .08308 Mdot
.05707 .22252 Mdot
.33334 .17074 Mdot
.40286 .04297 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50585 .00248 Mdot
.51862 .0079 Mdot
.55927 .02512 Mdot
.68678 .07881 Mdot
.03443 .21486 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.51091 .00462 Mdot
.53473 .01473 Mdot
.61025 .04667 Mdot
.83823 .1409 Mdot
.26919 .26635 Mdot
.46315 .11987 Mdot
.60232 .08601 Mdot
.88461 .17447 Mdot
.49861 .61744 Mdot
.49557 .61615 Mdot
.48588 .61204 Mdot
.45503 .59897 Mdot
.35761 .55783 Mdot
.07399 .44275 Mdot
.68334 .3766 Mdot
.51078 .51139 Mdot
.35438 .52137 Mdot
.00877 .40444 Mdot
.65001 .39631 Mdot
.49828 .6173 Mdot
.49452 .61571 Mdot
.48254 .61063 Mdot
.44443 .59448 Mdot
.32464 .544 Mdot
.99191 .41239 Mdot
.6713 .41989 Mdot
.56084 .54976 Mdot
.53942 .6048 Mdot
.57655 .02294 Mdot
.72411 .0912 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48054 .60978 Mdot
.43808 .59179 Mdot
.30507 .53583 Mdot
.94747 .39703 Mdot
.66724 .44484 Mdot
.5942 .57289 Mdot
.65433 .03717 Mdot
.91136 .15885 Mdot
.29458 .23684 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.5004 .00017 Mdot
.50126 .00053 Mdot
.50401 .0017 Mdot
.51279 .00542 Mdot
.54073 .01727 Mdot
.6291 .05461 Mdot
.89056 .1616 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50325 .00138 Mdot
.51035 .00439 Mdot
.53295 .01397 Mdot
.60463 .0443 Mdot
.82218 .13446 Mdot
.25433 .26709 Mdot
.44784 .1196 Mdot
.56451 .0721 Mdot
.77532 .13028 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52327 .00987 Mdot
.57402 .03136 Mdot
.73184 .09754 Mdot
.12684 .24412 Mdot
.35109 .1386 Mdot
.38317 .01983 Mdot
.25532 .53902 Mdot
.88887 .39156 Mdot
.6759 .48641 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52456 .01041 Mdot
.57811 .03309 Mdot
.74416 .10263 Mdot
.14879 .25007 Mdot
.36135 .13137 Mdot
.39127 .01849 Mdot
.27048 .54338 Mdot
.91293 .39706 Mdot
.67957 .47381 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50536 .00227 Mdot
.51709 .00725 Mdot
.5544 .02306 Mdot
.67174 .07252 Mdot
.99953 .20258 Mdot
.32802 .20302 Mdot
.4459 .07285 Mdot
.48419 .02367 Mdot
.49882 .00904 Mdot
.51166 .00794 Mdot
.49861 .61744 Mdot
.49557 .61615 Mdot
.48588 .61205 Mdot
.45504 .59897 Mdot
.35765 .55784 Mdot
.07408 .44278 Mdot
.68336 .37656 Mdot
.51076 .51136 Mdot
.35427 .52132 Mdot
.00848 .40432 Mdot
.64998 .39647 Mdot
.49963 .61788 Mdot
.49882 .61753 Mdot
.49623 .61644 Mdot
.48799 .61294 Mdot
.46175 .60182 Mdot
.37867 .56669 Mdot
.13073 .4648 Mdot
.70801 .35678 Mdot
.51577 .49922 Mdot
.34713 .51381 Mdot
.98286 .3929 Mdot
.49838 .61735 Mdot
.49484 .61585 Mdot
.48357 .61107 Mdot
.44771 .59587 Mdot
.33482 .54826 Mdot
.01629 .42118 Mdot
.67337 .4061 Mdot
.54205 .53687 Mdot
.47306 .5754 Mdot
.36386 .55054 Mdot
.07446 .43917 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52352 .00997 Mdot
.57481 .0317 Mdot
.73423 .09853 Mdot
.1312 .24535 Mdot
.35292 .13703 Mdot
.38411 .01928 Mdot
.25642 .53912 Mdot
.8902 .39169 Mdot
.67592 .4856 Mdot
.50077 .00033 Mdot
.50244 .00104 Mdot
.50779 .0033 Mdot
.5248 .01052 Mdot
.57887 .03341 Mdot
.74645 .10357 Mdot
.1527 .25108 Mdot
.36346 .13026 Mdot
.39363 .01865 Mdot
.27587 .54525 Mdot
.92252 .39965 Mdot
.68085 .46868 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50597 .00253 Mdot
.51903 .00807 Mdot
.56058 .02568 Mdot
.69081 .08049 Mdot
.04346 .21795 Mdot
.33172 .17816 Mdot
.41205 .04964 Mdot
.36705 .59022 Mdot
.14502 .48081 Mdot
.73434 .36422 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48465 .61153 Mdot
.45114 .59732 Mdot
.34549 .55274 Mdot
.0428 .43096 Mdot
.67668 .39176 Mdot
.52441 .52392 Mdot
.4086 .54646 Mdot
.16312 .46631 Mdot
.7136 .34021 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50695 .00295 Mdot
.52213 .00938 Mdot
.57041 .02984 Mdot
.72088 .093 Mdot
.1061 .23808 Mdot
.3437 .14684 Mdot
.38276 .02414 Mdot
.26143 .54305 Mdot
.90199 .39589 Mdot
.68044 .48111 Mdot
.50081 .00035 Mdot
.5026 .0011 Mdot
.50827 .00351 Mdot
.52635 .01117 Mdot
.58377 .03549 Mdot
.76112 .10961 Mdot
.17663 .25679 Mdot
.37832 .12465 Mdot
.41476 .02252 Mdot
.32938 .56526 Mdot
.03434 .43569 Mdot
.68819 .4041 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48512 .61172 Mdot
.45261 .59794 Mdot
.35006 .55466 Mdot
.05443 .43532 Mdot
.67874 .38584 Mdot
.51824 .51884 Mdot
.38503 .53571 Mdot
.09399 .43816 Mdot
.67002 .356 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48032 .60969 Mdot
.43737 .59149 Mdot
.30288 .53491 Mdot
.94271 .39544 Mdot
.66663 .44741 Mdot
.59728 .57517 Mdot
.66493 .04181 Mdot
.93801 .16877 Mdot
.30174 .2248 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.47878 .60904 Mdot
.43249 .58942 Mdot
.28793 .52869 Mdot
.91139 .38532 Mdot
.661 .46329 Mdot
.61299 .58836 Mdot
.72057 .06649 Mdot
.06282 .21152 Mdot
.31327 .15478 Mdot
.4987 .61748 Mdot
.49585 .61628 Mdot
.48678 .61243 Mdot
.45792 .60019 Mdot
.36666 .56163 Mdot
.09798 .45198 Mdot
.69144 .36678 Mdot
.50765 .50445 Mdot
.33534 .51154 Mdot
.95781 .38471 Mdot
.64282 .42336 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51118 .00474 Mdot
.53559 .01509 Mdot
.61296 .04781 Mdot
.84588 .14396 Mdot
.27551 .26553 Mdot
.46947 .11987 Mdot
.61792 .09175 Mdot
.92751 .19134 Mdot
.34211 .25624 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50693 .00294 Mdot
.52207 .00936 Mdot
.57022 .02976 Mdot
.72032 .09277 Mdot
.10502 .23775 Mdot
.34337 .14731 Mdot
.38291 .02444 Mdot
.26223 .54345 Mdot
.90352 .39634 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50202 .00086 Mdot
.50645 .00273 Mdot
.52054 .00871 Mdot
.56536 .0277 Mdot
.70549 .08661 Mdot
.07508 .22842 Mdot
.33618 .16137 Mdot
.3927 .03493 Mdot
.30018 .56086 Mdot
.49746 .61696 Mdot
.49191 .61461 Mdot
.47425 .60711 Mdot
.41811 .58334 Mdot
.24449 .51073 Mdot
.83229 .36328 Mdot
.62761 .49154 Mdot
.59448 .59756 Mdot
.6949 .06206 Mdot
.01988 .20085 Mdot
.31512 .18247 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51996 .00846 Mdot
.5635 .02691 Mdot
.6998 .08424 Mdot
.06305 .2245 Mdot
.33418 .16757 Mdot
.3992 .04018 Mdot
.32292 .57089 Mdot
.49997 .61802 Mdot
.49991 .618 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49089 .61417 Mdot
.47099 .60573 Mdot
.40781 .57899 Mdot
.21396 .49822 Mdot
.78747 .35445 Mdot
.59312 .49792 Mdot
.49757 .617 Mdot
.49225 .61475 Mdot
.47532 .60757 Mdot
.42152 .58478 Mdot
.2547 .51494 Mdot
.84926 .36746 Mdot
.6376 .48723 Mdot
.60759 .59948 Mdot
.72694 .07376 Mdot
.08252 .21976 Mdot
.31979 .14664 Mdot
.49977 .61794 Mdot
.49927 .61772 Mdot
.49766 .61704 Mdot
.49255 .61488 Mdot
.47627 .60797 Mdot
.42453 .58606 Mdot
.26378 .51868 Mdot
.86519 .37169 Mdot
.64549 .48225 Mdot
.61487 .59911 Mdot
.74198 .07856 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50536 .00227 Mdot
.51708 .00724 Mdot
.55436 .02304 Mdot
.67161 .07246 Mdot
.99922 .20247 Mdot
.328 .2032 Mdot
.44614 .07302 Mdot
.48503 .02404 Mdot
.5015 .01018 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00246 Mdot
.5185 .00784 Mdot
.55888 .02496 Mdot
.68559 .07831 Mdot
.03174 .21393 Mdot
.3306 .18471 Mdot
.42069 .05568 Mdot
.39667 .60319 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.48489 .61163 Mdot
.4519 .59765 Mdot
.34786 .55373 Mdot
.04882 .43321 Mdot
.67769 .38866 Mdot
.52107 .52124 Mdot
.39597 .54072 Mdot
.12571 .451 Mdot
.68588 .34621 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48511 .61172 Mdot
.45261 .59794 Mdot
.35006 .55465 Mdot
.05442 .43532 Mdot
.67873 .38585 Mdot
.51825 .51885 Mdot
.38507 .53573 Mdot
.09409 .4382 Mdot
.67005 .35597 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48246 .6106 Mdot
.44418 .59437 Mdot
.32386 .54368 Mdot
.99007 .41174 Mdot
.67116 .42094 Mdot
.56229 .55075 Mdot
.54448 .60703 Mdot
.59252 .02969 Mdot
.77166 .11071 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47318 .60666 Mdot
.41474 .58191 Mdot
.23443 .5066 Mdot
.81653 .35976 Mdot
.6168 .4946 Mdot
.57698 .59342 Mdot
.64818 .044 Mdot
.91089 .16237 Mdot
.49882 .61753 Mdot
.49625 .61644 Mdot
.48804 .61296 Mdot
.46191 .60188 Mdot
.37917 .5669 Mdot
.13212 .46534 Mdot
.70887 .35646 Mdot
.51644 .4991 Mdot
.34861 .51431 Mdot
.98643 .39419 Mdot
.64458 .40676 Mdot
.49872 .61749 Mdot
.49591 .6163 Mdot
.48698 .61251 Mdot
.45853 .60045 Mdot
.36859 .56245 Mdot
.10319 .454 Mdot
.69362 .36491 Mdot
.50796 .50329 Mdot
.33423 .51066 Mdot
.95442 .3833 Mdot
.64205 .42498 Mdot
.49902 .61762 Mdot
.49689 .61672 Mdot
.49009 .61383 Mdot
.46845 .60466 Mdot
.39978 .5756 Mdot
.19053 .48871 Mdot
.75902 .35134 Mdot
.56585 .49865 Mdot
.46868 .55798 Mdot
.32482 .52913 Mdot
.96813 .39759 Mdot
.49806 .61721 Mdot
.4938 .61541 Mdot
.48026 .60966 Mdot
.43718 .59141 Mdot
.3023 .53467 Mdot
.94146 .39502 Mdot
.66646 .44807 Mdot
.59806 .57576 Mdot
.66762 .04299 Mdot
.94464 .17121 Mdot
.30303 .2215 Mdot
.49927 .61772 Mdot
.49767 .61705 Mdot
.49257 .61488 Mdot
.47634 .608 Mdot
.42474 .58615 Mdot
.26442 .51895 Mdot
.86634 .37201 Mdot
.646 .48186 Mdot
.61522 .59901 Mdot
.74256 .0787 Mdot
.10837 .22608 Mdot
.49875 .6175 Mdot
.49601 .61634 Mdot
.48729 .61265 Mdot
.45954 .60088 Mdot
.37173 .56377 Mdot
.11169 .45732 Mdot
.69753 .36207 Mdot
.50924 .50167 Mdot
.33482 .51023 Mdot
.95476 .38315 Mdot
.64165 .42452 Mdot
.49786 .61713 Mdot
.49319 .61515 Mdot
.47831 .60884 Mdot
.431 .58879 Mdot
.28341 .52682 Mdot
.90232 .38251 Mdot
.65873 .46748 Mdot
.61567 .59142 Mdot
.73124 .07143 Mdot
.08388 .21795 Mdot
.31645 .14373 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.5266 .01128 Mdot
.58458 .03583 Mdot
.76353 .1106 Mdot
.18035 .25761 Mdot
.38094 .12397 Mdot
.41913 .0236 Mdot
.34116 .56985 Mdot
.06257 .44586 Mdot
.69252 .38933 Mdot
.49873 .6175 Mdot
.49596 .61632 Mdot
.48713 .61257 Mdot
.459 .60065 Mdot
.37006 .56307 Mdot
.10716 .45555 Mdot
.69539 .36355 Mdot
.50843 .50249 Mdot
.33413 .51031 Mdot
.95366 .3829 Mdot
.64173 .42525 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47384 .60694 Mdot
.41684 .58281 Mdot
.24071 .50918 Mdot
.82625 .36188 Mdot
.62364 .49282 Mdot
.5884 .59625 Mdot
.67904 .05602 Mdot
.98507 .18914 Mdot
.31346 .20296 Mdot
.49939 .61778 Mdot
.49805 .61721 Mdot
.4938 .61541 Mdot
.48026 .60966 Mdot
.43718 .59141 Mdot
.30228 .53467 Mdot
.94143 .39501 Mdot
.66646 .44809 Mdot
.59808 .57578 Mdot
.6677 .04302 Mdot
.94483 .17128 Mdot
.49931 .61774 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47774 .60859 Mdot
.42918 .58802 Mdot
.27786 .52451 Mdot
.89145 .37922 Mdot
.65554 .47223 Mdot
.61752 .59454 Mdot
.7402 .07582 Mdot
.10116 .22308 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51177 .00499 Mdot
.53749 .01589 Mdot
.61891 .05033 Mdot
.86258 .15059 Mdot
.2877 .26274 Mdot
.48075 .11931 Mdot
.645 .10151 Mdot
.99788 .21809 Mdot
.35394 .22006 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50824 .0035 Mdot
.52626 .01114 Mdot
.5835 .03537 Mdot
.76031 .10928 Mdot
.17536 .25651 Mdot
.37745 .1249 Mdot
.41334 .02219 Mdot
.32559 .5638 Mdot
.02552 .43258 Mdot
.68734 .40903 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00246 Mdot
.5185 .00785 Mdot
.55889 .02496 Mdot
.68562 .07832 Mdot
.03182 .21396 Mdot
.3306 .18466 Mdot
.42062 .05563 Mdot
.39645 .60309 Mdot
.22767 .51372 Mdot
.82251 .36763 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51996 .00846 Mdot
.56352 .02692 Mdot
.69984 .08425 Mdot
.06314 .22453 Mdot
.33419 .16752 Mdot
.39915 .04015 Mdot
.32275 .57082 Mdot
.03213 .43842 Mdot
.69364 .40883 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50979 .00415 Mdot
.53117 .01322 Mdot
.59901 .04193 Mdot
.80598 .12791 Mdot
.23706 .26642 Mdot
.4302 .11937 Mdot
.52196 .05671 Mdot
.64656 .077 Mdot
.96121 .19447 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50617 .00262 Mdot
.51966 .00834 Mdot
.56258 .02652 Mdot
.69696 .08305 Mdot
.05693 .22248 Mdot
.33332 .17082 Mdot
.40295 .04303 Mdot
.33586 .57657 Mdot
.49867 .61747 Mdot
.49576 .61623 Mdot
.48648 .6123 Mdot
.45694 .59978 Mdot
.36359 .56034 Mdot
.08979 .44881 Mdot
.68833 .36992 Mdot
.50791 .50653 Mdot
.33934 .51385 Mdot
.96867 .38895 Mdot
.64469 .4178 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49147 .61442 Mdot
.47283 .60651 Mdot
.41363 .58145 Mdot
.23115 .50525 Mdot
.81161 .35874 Mdot
.61314 .49537 Mdot
.57043 .59164 Mdot
.62995 .03679 Mdot
.86346 .14431 Mdot
.49983 .61796 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49434 .61563 Mdot
.48197 .61039 Mdot
.44262 .59371 Mdot
.31906 .54167 Mdot
.97888 .40779 Mdot
.67029 .42731 Mdot
.57111 .55674 Mdot
.57509 .00246 Mdot
.49903 .61762 Mdot
.49691 .61672 Mdot
.49015 .61386 Mdot
.46864 .60474 Mdot
.40039 .57585 Mdot
.19228 .48942 Mdot
.76097 .35147 Mdot
.56782 .49866 Mdot
.47336 .55965 Mdot
.33912 .53507 Mdot
.0026 .41005 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42795 .5875 Mdot
.27412 .52297 Mdot
.8843 .37711 Mdot
.65314 .47517 Mdot
.61785 .59622 Mdot
.74362 .07773 Mdot
.10793 .22516 Mdot
.32247 .13259 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00353 Mdot
.52655 .01126 Mdot
.58442 .03576 Mdot
.76306 .1104 Mdot
.17962 .25745 Mdot
.38042 .1241 Mdot
.41825 .02338 Mdot
.33879 .56892 Mdot
.05679 .44375 Mdot
.6914 .39221 Mdot
.49838 .61735 Mdot
.49483 .61584 Mdot
.48352 .61104 Mdot
.44753 .59579 Mdot
.33426 .54803 Mdot
.01493 .42068 Mdot
.67324 .40686 Mdot
.54305 .53757 Mdot
.47665 .577 Mdot
.37535 .55543 Mdot
.10562 .45133 Mdot
.49769 .61705 Mdot
.49263 .61491 Mdot
.47651 .60807 Mdot
.42529 .58638 Mdot
.26607 .51963 Mdot
.86933 .37284 Mdot
.64731 .48082 Mdot
.61602 .5987 Mdot
.74376 .07895 Mdot
.11005 .22638 Mdot
.32411 .1323 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50437 .00185 Mdot
.51392 .0059 Mdot
.54433 .01879 Mdot
.64037 .05936 Mdot
.92071 .17326 Mdot
.31513 .24376 Mdot
.49052 .1084 Mdot
.65171 .09962 Mdot
.00753 .21991 Mdot
.35206 .21293 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51963 .00832 Mdot
.56247 .02648 Mdot
.69663 .08292 Mdot
.05623 .22224 Mdot
.33323 .17119 Mdot
.40339 .04337 Mdot
.33738 .57724 Mdot
.06773 .45138 Mdot
.69952 .39047 Mdot
.50054 .00023 Mdot
.50174 .00074 Mdot
.50553 .00234 Mdot
.51761 .00747 Mdot
.55606 .02376 Mdot
.67687 .07467 Mdot
.01166 .20691 Mdot
.32897 .19611 Mdot
.43634 .06636 Mdot
.45075 .0089 Mdot
.39245 .582 Mdot
.18482 .48971 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50498 .00211 Mdot
.51588 .00673 Mdot
.55056 .02143 Mdot
.65981 .06752 Mdot
.97048 .192 Mdot
.32518 .21921 Mdot
.46727 .08782 Mdot
.56063 .0577 Mdot
.74275 .11255 Mdot
.16335 .25995 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50894 .00379 Mdot
.52849 .01208 Mdot
.59053 .03834 Mdot
.78116 .11782 Mdot
.20596 .26254 Mdot
.40111 .12061 Mdot
.45729 .03472 Mdot
.45017 .61363 Mdot
.36951 .56819 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50618 .00262 Mdot
.51969 .00835 Mdot
.56266 .02656 Mdot
.69721 .08316 Mdot
.05748 .22266 Mdot
.33339 .17052 Mdot
.4026 .04277 Mdot
.33466 .57604 Mdot
.06097 .44888 Mdot
.69805 .39374 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51217 .00516 Mdot
.53875 .01643 Mdot
.62289 .052 Mdot
.87359 .15494 Mdot
.29458 .26019 Mdot
.48616 .1184 Mdot
.65699 .10558 Mdot
.02693 .22864 Mdot
.50048 .0002 Mdot
.50151 .00064 Mdot
.50483 .00205 Mdot
.51537 .00652 Mdot
.54895 .02075 Mdot
.65478 .06541 Mdot
.95789 .18733 Mdot
.32343 .22592 Mdot
.47519 .0938 Mdot
.5899 .07089 Mdot
.83239 .14987 Mdot
.28233 .27808 Mdot
.49886 .61755 Mdot
.49638 .6165 Mdot
.48847 .61314 Mdot
.46328 .60247 Mdot
.3835 .56873 Mdot
.14416 .47012 Mdot
.71696 .35401 Mdot
.52337 .49839 Mdot
.3647 .51997 Mdot
.02666 .40911 Mdot
.64882 .38451 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51215 .00515 Mdot
.53868 .0164 Mdot
.62267 .05191 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.51872 .00794 Mdot
.55957 .02525 Mdot
.68769 .07919 Mdot
.03649 .21557 Mdot
.33103 .18204 Mdot
.41712 .05321 Mdot
.38443 .59783 Mdot
.19323 .49986 Mdot
.77832 .36161 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50495 .0021 Mdot
.51577 .00669 Mdot
.55022 .02129 Mdot
.65875 .06707 Mdot
.96783 .19102 Mdot
.32484 .22064 Mdot
.46903 .08911 Mdot
.56706 .06058 Mdot
.76273 .12093 Mdot
.19636 .268 Mdot
.49967 .61789 Mdot
.49894 .61759 Mdot
.49663 .61661 Mdot
.48927 .61349 Mdot
.46584 .60355 Mdot
.39155 .57212 Mdot
.16688 .47918 Mdot
.7353 .35131 Mdot
.54144 .49822 Mdot
.40904 .53621 Mdot
.14752 .4564 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50211 .00089 Mdot
.50672 .00285 Mdot
.5214 .00908 Mdot
.56809 .02886 Mdot
.71384 .09008 Mdot
.09218 .23383 Mdot
.33985 .15307 Mdot
.38584 .02842 Mdot
.27489 .54947 Mdot
.92813 .40372 Mdot
.49825 .61729 Mdot
.49443 .61567 Mdot
.48226 .61051 Mdot
.44354 .5941 Mdot
.32191 .54286 Mdot
.98549 .41012 Mdot
.67081 .42355 Mdot
.56591 .5532 Mdot
.55707 .61257 Mdot
.63202 .04632 Mdot
.88306 .15515 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .61259 Mdot
.45914 .60071 Mdot
.37049 .56324 Mdot
.10831 .456 Mdot
.69592 .36316 Mdot
.50861 .50227 Mdot
.33422 .51025 Mdot
.95375 .38289 Mdot
.64168 .42517 Mdot
.49837 .61734 Mdot
.49482 .61584 Mdot
.48349 .61103 Mdot
.44744 .59575 Mdot
.33397 .54791 Mdot
.01423 .42042 Mdot
.67317 .40725 Mdot
.54358 .53794 Mdot
.47853 .57783 Mdot
.38137 .55799 Mdot
.12229 .45791 Mdot
.49887 .61756 Mdot
.49642 .61651 Mdot
.48858 .61319 Mdot
.46363 .60261 Mdot
.38458 .56918 Mdot
.1472 .47132 Mdot
.71917 .3535 Mdot
.52542 .49829 Mdot
.36963 .52175 Mdot
.03942 .41396 Mdot
.65069 .37778 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00143 Mdot
.51071 .00454 Mdot
.5341 .01446 Mdot
.60826 .04583 Mdot
.83257 .13863 Mdot
.2642 .26676 Mdot
.45804 .1198 Mdot
.58968 .08135 Mdot
.84882 .16016 Mdot
.30214 .28017 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52368 .01004 Mdot
.57531 .03191 Mdot
.73575 .09916 Mdot
.13396 .24611 Mdot
.35413 .13607 Mdot
.38487 .019 Mdot
.25759 .53937 Mdot
.89184 .39199 Mdot
.67613 .48472 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47947 .60933 Mdot
.43469 .59036 Mdot
.29466 .53149 Mdot
.92525 .38972 Mdot
.66388 .4565 Mdot
.60714 .58297 Mdot
.69925 .05693 Mdot
.01806 .19703 Mdot
.30984 .18033 Mdot
.49889 .61756 Mdot
.49645 .61653 Mdot
.48869 .61324 Mdot
.46397 .60276 Mdot
.38568 .56965 Mdot
.15027 .47255 Mdot
.72149 .35303 Mdot
.52761 .49821 Mdot
.37496 .52369 Mdot
.05344 .41933 Mdot
.65326 .37071 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55364 .02274 Mdot
.66936 .07152 Mdot
.99383 .20053 Mdot
.32755 .20625 Mdot
.45032 .07588 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52051 .0087 Mdot
.56525 .02765 Mdot
.70514 .08646 Mdot
.07435 .22818 Mdot
.33605 .16174 Mdot
.39305 .03523 Mdot
.30145 .56142 Mdot
.98348 .42152 Mdot
.69024 .43681 Mdot
.49923 .61771 Mdot
.49756 .617 Mdot
.49222 .61473 Mdot
.47522 .60753 Mdot
.42119 .58464 Mdot
.25371 .51453 Mdot
.84756 .36702 Mdot
.63668 .4877 Mdot
.60654 .5994 Mdot
.72452 .07292 Mdot
.07819 .21858 Mdot
.49958 .61786 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48638 .61226 Mdot
.45662 .59964 Mdot
.36259 .55992 Mdot
.08712 .44778 Mdot
.6874 .37099 Mdot
.50818 .50727 Mdot
.34122 .51485 Mdot
.97367 .39088 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.50301 .00127 Mdot
.50958 .00406 Mdot
.5305 .01293 Mdot
.5969 .04104 Mdot
.79984 .12542 Mdot
.2299 .26579 Mdot
.42313 .11942 Mdot
.50548 .0509 Mdot
.59604 .05597 Mdot
.82208 .1397 Mdot
.49783 .61711 Mdot
.49308 .6151 Mdot
.47796 .60869 Mdot
.42988 .58832 Mdot
.28 .5254 Mdot
.89561 .38047 Mdot
.65682 .47045 Mdot
.617 .59342 Mdot
.73729 .07435 Mdot
.09556 .22142 Mdot
.31894 .13806 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50995 .00422 Mdot
.53168 .01343 Mdot
.60062 .04261 Mdot
.81064 .1298 Mdot
.24227 .26676 Mdot
.43545 .11939 Mdot
.53444 .06118 Mdot
.6847 .09286 Mdot
.05387 .22816 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00115 Mdot
.5086 .00365 Mdot
.52741 .01162 Mdot
.58712 .03691 Mdot
.77109 .1137 Mdot
.1917 .25995 Mdot
.38942 .12219 Mdot
.43428 .02773 Mdot
.38335 .58656 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47909 .60917 Mdot
.43347 .58984 Mdot
.29094 .52994 Mdot
.91752 .38725 Mdot
.66236 .46034 Mdot
.61065 .58607 Mdot
.71185 .06255 Mdot
.04496 .20587 Mdot
.31152 .16475 Mdot
.49894 .61758 Mdot
.49663 .6166 Mdot
.48925 .61348 Mdot
.46577 .60352 Mdot
.39132 .57203 Mdot
.16625 .47893 Mdot
.73473 .35135 Mdot
.54086 .49821 Mdot
.4076 .53568 Mdot
.1434 .45475 Mdot
.69204 .33908 Mdot
.49949 .61782 Mdot
.49837 .61734 Mdot
.49481 .61583 Mdot
.48346 .61102 Mdot
.44733 .59571 Mdot
.33364 .54777 Mdot
.01342 .42013 Mdot
.6731 .4077 Mdot
.54418 .53836 Mdot
.48067 .57878 Mdot
.38823 .56091 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47602 .60787 Mdot
.42375 .58572 Mdot
.26141 .51771 Mdot
.86096 .37054 Mdot
.64353 .48366 Mdot
.61339 .5994 Mdot
.73929 .07781 Mdot
.10339 .22502 Mdot
.32308 .13578 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48704 .61254 Mdot
.45873 .60054 Mdot
.3692 .5627 Mdot
.10483 .45464 Mdot
.69434 .36433 Mdot
.50813 .50295 Mdot
.3341 .51048 Mdot
.95391 .38306 Mdot
.64189 .42519 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51502 .00637 Mdot
.54781 .02027 Mdot
.65125 .06393 Mdot
.94892 .18397 Mdot
.3219 .23052 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.5078 .00331 Mdot
.52484 .01053 Mdot
.57898 .03346 Mdot
.74681 .10372 Mdot
.15331 .25123 Mdot
.3638 .13009 Mdot
.39403 .01868 Mdot
.27679 .54558 Mdot
.92419 .40012 Mdot
.68105 .46777 Mdot
.4996 .61787 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48716 .61259 Mdot
.45912 .6007 Mdot
.37042 .56322 Mdot
.10814 .45593 Mdot
.69584 .36322 Mdot
.50859 .5023 Mdot
.3342 .51026 Mdot
.95372 .38289 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47811 .60875 Mdot
.43036 .58852 Mdot
.28146 .52601 Mdot
.89848 .38134 Mdot
.65766 .4692 Mdot
.6165 .5926 Mdot
.7349 .07317 Mdot
.09096 .22006 Mdot
.31789 .14025 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.48631 .61223 Mdot
.4564 .59955 Mdot
.36192 .55964 Mdot
.08533 .4471 Mdot
.68679 .37172 Mdot
.50841 .50778 Mdot
.34262 .51557 Mdot
.97741 .39232 Mdot
.64597 .41319 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.50461 .00195 Mdot
.51469 .00623 Mdot
.54676 .01982 Mdot
.64796 .06255 Mdot
.94049 .18079 Mdot
.32022 .23468 Mdot
.48407 .10127 Mdot
.62408 .08653 Mdot
.93191 .19025 Mdot
.33879 .25146 Mdot
.4981 .61723 Mdot
.49395 .61547 Mdot
.48072 .60986 Mdot
.43866 .59204 Mdot
.30684 .53657 Mdot
.95135 .39833 Mdot
.66771 .44273 Mdot
.59158 .57099 Mdot
.64537 .03325 Mdot
.88814 .15004 Mdot
.28522 .24541 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49407 .61552 Mdot
.48111 .61002 Mdot
.43988 .59255 Mdot
.3106 .53813 Mdot
.95968 .40115 Mdot
.6686 .43814 Mdot
.5857 .5668 Mdot
.62522 .02443 Mdot
.8338 .12891 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.48929 .61349 Mdot
.4659 .60358 Mdot
.39175 .57221 Mdot
.16746 .47942 Mdot
.73583 .35127 Mdot
.54199 .49823 Mdot
.41039 .5367 Mdot
.15138 .45795 Mdot
.69802 .33784 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50854 .00362 Mdot
.52722 .01154 Mdot
.58652 .03665 Mdot
.7693 .11297 Mdot
.18907 .25943 Mdot
.38738 .12256 Mdot
.43051 .02666 Mdot
.3727 .5823 Mdot
.14365 .47647 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.5187 .00793 Mdot
.55952 .02523 Mdot
.68756 .07913 Mdot
.0362 .21547 Mdot
.331 .1822 Mdot
.41734 .05336 Mdot
.38517 .59816 Mdot
.19533 .50071 Mdot
.7807 .36178 Mdot
.50063 .00027 Mdot
.50199 .00084 Mdot
.50635 .00269 Mdot
.52022 .00857 Mdot
.56433 .02726 Mdot
.70233 .08529 Mdot
.06844 .22627 Mdot
.33502 .16476 Mdot
.39614 .03777 Mdot
.31228 .56621 Mdot
.00774 .42982 Mdot
.69159 .42265 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49546 .61611 Mdot
.48552 .61189 Mdot
.45389 .59849 Mdot
.35408 .55634 Mdot
.06477 .43924 Mdot
.68097 .38083 Mdot
.5138 .51471 Mdot
.36729 .52749 Mdot
.04401 .41823 Mdot
.49898 .6176 Mdot
.49675 .61666 Mdot
.48966 .61365 Mdot
.46705 .60406 Mdot
.39538 .57374 Mdot
.17784 .48359 Mdot
.74569 .35095 Mdot
.55218 .49844 Mdot
.43555 .54595 Mdot
.22486 .48782 Mdot
.77841 .34211 Mdot
.49964 .61788 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48825 .61305 Mdot
.46257 .60216 Mdot
.38126 .56778 Mdot
.13791 .46764 Mdot
.71263 .35519 Mdot
.51953 .49869 Mdot
.35565 .51675 Mdot
.00372 .40053 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48397 .61124 Mdot
.44898 .59641 Mdot
.33876 .54992 Mdot
.02599 .42473 Mdot
.6744 .40074 Mdot
.53513 .53196 Mdot
.44811 .56425 Mdot
.28463 .517 Mdot
.88804 .37293 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49083 .61415 Mdot
.47079 .60565 Mdot
.40718 .57872 Mdot
.2121 .49747 Mdot
.78503 .35409 Mdot
.59093 .49807 Mdot
.52592 .57786 Mdot
.49961 .60177 Mdot
.47271 .60141 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .0027 Mdot
.52032 .00862 Mdot
.56466 .0274 Mdot
.70334 .08571 Mdot
.07057 .22696 Mdot
.33538 .16366 Mdot
.39499 .03684 Mdot
.30827 .56444 Mdot
.99864 .42667 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52028 .0086 Mdot
.56452 .02735 Mdot
.70292 .08554 Mdot
.06969 .22667 Mdot
.33523 .16411 Mdot
.39546 .03722 Mdot
.30991 .56516 Mdot
.00234 .42795 Mdot
.69126 .42578 Mdot
.49785 .61712 Mdot
.49316 .61513 Mdot
.47822 .6088 Mdot
.43071 .58867 Mdot
.28251 .52644 Mdot
.90054 .38196 Mdot
.65824 .46829 Mdot
.61608 .59198 Mdot
.73301 .07227 Mdot
.08731 .21897 Mdot
.31712 .14203 Mdot
.49753 .61699 Mdot
.49213 .61469 Mdot
.47491 .6074 Mdot
.42023 .58424 Mdot
.25084 .51334 Mdot
.84272 .3658 Mdot
.63395 .48901 Mdot
.60322 .59904 Mdot
.71668 .07012 Mdot
.06367 .21445 Mdot
.31768 .15699 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.4849 .61163 Mdot
.45193 .59766 Mdot
.34796 .55377 Mdot
.04905 .4333 Mdot
.67773 .38854 Mdot
.52095 .52114 Mdot
.3955 .5405 Mdot
.12431 .45043 Mdot
.68505 .34656 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50552 .00234 Mdot
.51759 .00746 Mdot
.55599 .02373 Mdot
.67665 .07457 Mdot
.01112 .20672 Mdot
.32893 .19641 Mdot
.43677 .06665 Mdot
.45223 .00955 Mdot
.39709 .58396 Mdot
.19814 .49507 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.5056 .00238 Mdot
.51784 .00757 Mdot
.5568 .02407 Mdot
.67915 .07562 Mdot
.01697 .20878 Mdot
.32938 .19308 Mdot
.43214 .06351 Mdot
.43618 .00249 Mdot
.34703 .56294 Mdot
.06215 .44197 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00194 Mdot
.51454 .00617 Mdot
.54631 .01963 Mdot
.64655 .06196 Mdot
.93686 .17942 Mdot
.31941 .23643 Mdot
.48557 .1027 Mdot
.63013 .08934 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48673 .61241 Mdot
.45774 .60012 Mdot
.36611 .5614 Mdot
.0965 .45141 Mdot
.69085 .36733 Mdot
.50763 .5048 Mdot
.33587 .51188 Mdot
.95928 .38529 Mdot
.64311 .42263 Mdot
.4995 .61782 Mdot
.49842 .61736 Mdot
.49495 .61589 Mdot
.48391 .61121 Mdot
.44879 .59633 Mdot
.33816 .54966 Mdot
.02451 .42418 Mdot
.67424 .40155 Mdot
.53615 .53269 Mdot
.45183 .56592 Mdot
.29636 .52195 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.5041 .00174 Mdot
.51307 .00554 Mdot
.54161 .01764 Mdot
.63187 .05578 Mdot
.89807 .16452 Mdot
.30692 .25268 Mdot
.49215 .11448 Mdot
.66561 .1072 Mdot
.04501 .23449 Mdot
.3578 .19331 Mdot
.49886 .61755 Mdot
.49638 .6165 Mdot
.48846 .61314 Mdot
.46323 .60245 Mdot
.38335 .56866 Mdot
.14374 .46995 Mdot
.71666 .35408 Mdot
.52309 .4984 Mdot
.36404 .51974 Mdot
.02497 .40847 Mdot
.6486 .38542 Mdot
.49987 .61798 Mdot
.4996 .61786 Mdot
.49871 .61749 Mdot
.4959 .61629 Mdot
.48693 .61249 Mdot
.45836 .60038 Mdot
.36806 .56222 Mdot
.10175 .45344 Mdot
.693 .36541 Mdot
.50784 .5036 Mdot
.33442 .51086 Mdot
.49877 .61751 Mdot
.4961 .61638 Mdot
.48756 .61276 Mdot
.46038 .60124 Mdot
.37439 .56489 Mdot
.11893 .46015 Mdot
.70122 .35988 Mdot
.51113 .50055 Mdot
.33771 .51086 Mdot
.96091 .38516 Mdot
.64215 .42103 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49233 .61478 Mdot
.47556 .60767 Mdot
.42229 .58511 Mdot
.25701 .51589 Mdot
.85324 .36849 Mdot
.63971 .48606 Mdot
.60985 .59958 Mdot
.73198 .07548 Mdot
.09132 .22208 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50811 .00344 Mdot
.52583 .01095 Mdot
.58211 .03479 Mdot
.75617 .10758 Mdot
.16879 .25501 Mdot
.37308 .12626 Mdot
.40654 .02068 Mdot
.30774 .55697 Mdot
.98574 .41903 Mdot
.6851 .43223 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50528 .00224 Mdot
.51684 .00714 Mdot
.55359 .02272 Mdot
.66923 .07147 Mdot
.9935 .20041 Mdot
.32752 .20644 Mdot
.45057 .07605 Mdot
.50067 .03096 Mdot
.55178 .03159 Mdot
.67919 .07875 Mdot
.49956 .61785 Mdot
.4986 .61744 Mdot
.49552 .61614 Mdot
.48574 .61199 Mdot
.45459 .59878 Mdot
.35625 .55726 Mdot
.07043 .44139 Mdot
.68238 .37821 Mdot
.51184 .51263 Mdot
.35903 .5236 Mdot
.02135 .40934 Mdot
.49988 .61798 Mdot
.49962 .61787 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.48761 .61278 Mdot
.46054 .6013 Mdot
.37489 .5651 Mdot
.1203 .46069 Mdot
.70196 .35949 Mdot
.51157 .50036 Mdot
.33851 .51108 Mdot
.50011 5e-05 Mdot
.50037 .00015 Mdot
.50116 .00049 Mdot
.50371 .00157 Mdot
.51181 .00501 Mdot
.53761 .01594 Mdot
.61929 .05048 Mdot
.86362 .15101 Mdot
.28839 .26252 Mdot
.48134 .11925 Mdot
.64635 .10198 Mdot
.00123 .21933 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.50519 .0022 Mdot
.51655 .00702 Mdot
.55268 .02233 Mdot
.66641 .07029 Mdot
.9867 .19795 Mdot
.32691 .21027 Mdot
.45573 .07962 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50812 .00344 Mdot
.52588 .01097 Mdot
.58227 .03486 Mdot
.75666 .10778 Mdot
.16957 .25519 Mdot
.37359 .12609 Mdot
.4073 .02084 Mdot
.3097 .55771 Mdot
.98997 .42043 Mdot
.68527 .42972 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .613 Mdot
.46222 .60202 Mdot
.38016 .56732 Mdot
.13486 .46643 Mdot
.71062 .35584 Mdot
.51784 .49889 Mdot
.35178 .5154 Mdot
.99415 .39701 Mdot
.6453 .40243 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.48621 .61219 Mdot
.45608 .59942 Mdot
.36091 .55922 Mdot
.08268 .44607 Mdot
.68593 .37283 Mdot
.50882 .50858 Mdot
.34495 .51675 Mdot
.98358 .39469 Mdot
.6468 .40989 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.5208 .00882 Mdot
.56618 .02805 Mdot
.708 .08765 Mdot
.08029 .23009 Mdot
.33719 .15877 Mdot
.39029 .03282 Mdot
.29155 .55701 Mdot
.96216 .41446 Mdot
.689 .44921 Mdot
.49792 .61715 Mdot
.49339 .61523 Mdot
.47894 .6091 Mdot
.43298 .58963 Mdot
.28944 .52932 Mdot
.91445 .38628 Mdot
.6617 .46182 Mdot
.61187 .58724 Mdot
.71636 .06458 Mdot
.05427 .20884 Mdot
.31234 .1595 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44669 .59544 Mdot
.33164 .54693 Mdot
.00859 .41838 Mdot
.67266 .41042 Mdot
.54783 .54088 Mdot
.49366 .58456 Mdot
.42998 .57868 Mdot
.26464 .51584 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48463 .61152 Mdot
.45106 .59729 Mdot
.34525 .55264 Mdot
.04219 .43073 Mdot
.67659 .39208 Mdot
.52476 .5242 Mdot
.40994 .54707 Mdot
.16711 .46796 Mdot
.7172 .33998 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50923 .00391 Mdot
.5294 .01247 Mdot
.59343 .03957 Mdot
.78969 .1213 Mdot
.2173 .26428 Mdot
.41119 .11983 Mdot
.47869 .04171 Mdot
.51431 .02201 Mdot
.57136 .03526 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48801 .61295 Mdot
.46182 .60185 Mdot
.37891 .56679 Mdot
.13139 .46506 Mdot
.70842 .35662 Mdot
.51608 .49916 Mdot
.34782 .51404 Mdot
.98453 .3935 Mdot
.6444 .40783 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47475 .60733 Mdot
.41972 .58402 Mdot
.24932 .51272 Mdot
.84018 .36517 Mdot
.63247 .48966 Mdot
.60129 .59877 Mdot
.71201 .06843 Mdot
.05469 .21179 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00131 Mdot
.50987 .00418 Mdot
.53142 .01332 Mdot
.59981 .04226 Mdot
.80828 .12885 Mdot
.23966 .26661 Mdot
.43281 .11937 Mdot
.52815 .05892 Mdot
.66549 .08488 Mdot
.00868 .21211 Mdot
.49959 .61786 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48672 .6124 Mdot
.45772 .60011 Mdot
.36605 .56138 Mdot
.09635 .45135 Mdot
.69079 .36738 Mdot
.50763 .50484 Mdot
.33592 .51191 Mdot
.95944 .38535 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50619 .00263 Mdot
.51973 .00837 Mdot
.56278 .02661 Mdot
.69758 .08331 Mdot
.05827 .22292 Mdot
.3335 .1701 Mdot
.4021 .0424 Mdot
.33295 .57529 Mdot
.05676 .44734 Mdot
.69722 .39583 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.51808 .00767 Mdot
.55755 .02439 Mdot
.68148 .07659 Mdot
.02235 .21067 Mdot
.32981 .19002 Mdot
.42792 .06064 Mdot
.42158 .61412 Mdot
.30232 .54433 Mdot
.49948 .61781 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44666 .59543 Mdot
.33157 .5469 Mdot
.00841 .41831 Mdot
.67264 .41052 Mdot
.54796 .54098 Mdot
.49414 .58477 Mdot
.43152 .57934 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.52379 .01009 Mdot
.57565 .03205 Mdot
.73677 .09958 Mdot
.1358 .24661 Mdot
.35496 .13545 Mdot
.38545 .01884 Mdot
.25857 .53962 Mdot
.8933 .39229 Mdot
.67636 .48396 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.5055 .00233 Mdot
.51753 .00743 Mdot
.5558 .02365 Mdot
.67605 .07432 Mdot
.00973 .20623 Mdot
.32882 .19721 Mdot
.43787 .06739 Mdot
.45605 .01124 Mdot
.40916 .58905 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48668 .61238 Mdot
.45758 .60005 Mdot
.3656 .56119 Mdot
.09513 .45088 Mdot
.69031 .36785 Mdot
.50764 .50514 Mdot
.33643 .51222 Mdot
.96083 .3859 Mdot
.64339 .42185 Mdot
.49956 .61785 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48592 .61206 Mdot
.45516 .59902 Mdot
.35802 .558 Mdot
.07505 .44315 Mdot
.68363 .37612 Mdot
.51049 .51103 Mdot
.35308 .52075 Mdot
.00527 .40308 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48029 .60967 Mdot
.43727 .59145 Mdot
.30256 .53478 Mdot
.94203 .39521 Mdot
.66654 .44777 Mdot
.59771 .57549 Mdot
.66639 .04245 Mdot
.94163 .1701 Mdot
.30247 .22301 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.48331 .61096 Mdot
.44687 .59551 Mdot
.33221 .54717 Mdot
.00996 .41887 Mdot
.67278 .40965 Mdot
.54678 .54016 Mdot
.48995 .58291 Mdot
.41806 .5736 Mdot
.22862 .50095 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50457 .00194 Mdot
.51457 .00618 Mdot
.54638 .01966 Mdot
.64678 .06205 Mdot
.93745 .17964 Mdot
.31955 .23615 Mdot
.48534 .10247 Mdot
.62917 .08889 Mdot
.94617 .19592 Mdot
.34239 .24488 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51854 .00786 Mdot
.55901 .02501 Mdot
.68598 .07847 Mdot
.03263 .21424 Mdot
.33068 .1842 Mdot
.42001 .05521 Mdot
.39435 .60217 Mdot
.22159 .51126 Mdot
.8139 .36606 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52052 .0087 Mdot
.5653 .02767 Mdot
.70531 .08653 Mdot
.07469 .22829 Mdot
.33611 .16156 Mdot
.39289 .03509 Mdot
.30085 .56115 Mdot
.98216 .42107 Mdot
.49843 .61737 Mdot
.49501 .61592 Mdot
.4841 .61129 Mdot
.44937 .59657 Mdot
.33998 .55043 Mdot
.029 .42584 Mdot
.67476 .3991 Mdot
.53307 .53046 Mdot
.44063 .5609 Mdot
.26119 .50713 Mdot
.84361 .35995 Mdot
.49998 .61802 Mdot
.49993 .618 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49228 .61476 Mdot
.4754 .6076 Mdot
.42175 .58488 Mdot
.25542 .51523 Mdot
.85048 .36777 Mdot
.63826 .48687 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .0024 Mdot
.51805 .00765 Mdot
.55746 .02435 Mdot
.68118 .07647 Mdot
.02167 .21043 Mdot
.32975 .19041 Mdot
.42846 .061 Mdot
.42342 .61492 Mdot
.30789 .54663 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50386 .00164 Mdot
.51231 .00522 Mdot
.5392 .01662 Mdot
.62429 .05259 Mdot
.87744 .15645 Mdot
.29679 .25917 Mdot
.48765 .11796 Mdot
.66001 .10652 Mdot
.03394 .2311 Mdot
.35735 .19988 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.4785 .60892 Mdot
.43159 .58904 Mdot
.28519 .52756 Mdot
.90587 .3836 Mdot
.65966 .46586 Mdot
.61474 .59027 Mdot
.72739 .06963 Mdot
.07638 .21568 Mdot
.31514 .14756 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48984 .61373 Mdot
.46764 .60431 Mdot
.39724 .57452 Mdot
.18318 .48574 Mdot
.75112 .35101 Mdot
.55779 .49855 Mdot
.44926 .55096 Mdot
.2659 .50471 Mdot
.845 .3579 Mdot
.49945 .6178 Mdot
.49823 .61728 Mdot
.49437 .61565 Mdot
.48206 .61043 Mdot
.44289 .59383 Mdot
.31988 .54201 Mdot
.98078 .40846 Mdot
.67044 .42623 Mdot
.56962 .55572 Mdot
.56993 .00019 Mdot
.6718 .06296 Mdot
.49768 .61705 Mdot
.4926 .61489 Mdot
.47641 .60803 Mdot
.42498 .58625 Mdot
.26513 .51924 Mdot
.86763 .37236 Mdot
.64657 .48141 Mdot
.61558 .59888 Mdot
.74313 .07883 Mdot
.10918 .22623 Mdot
.32401 .13277 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51715 .00727 Mdot
.55459 .02314 Mdot
.67233 .07277 Mdot
.00093 .20309 Mdot
.32814 .20222 Mdot
.44481 .07211 Mdot
.48033 .02196 Mdot
.48643 .00377 Mdot
.47221 .60924 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52443 .01036 Mdot
.57769 .03292 Mdot
.74293 .10212 Mdot
.14665 .24952 Mdot
.36024 .132 Mdot
.3901 .01846 Mdot
.2679 .54251 Mdot
.90847 .3959 Mdot
.6789 .47615 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51117 .00474 Mdot
.53558 .01509 Mdot
.61292 .0478 Mdot
.84577 .14391 Mdot
.27542 .26554 Mdot
.46938 .11987 Mdot
.6177 .09166 Mdot
.92691 .1911 Mdot
.34194 .25651 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50724 .00307 Mdot
.52308 .00979 Mdot
.57341 .03111 Mdot
.72999 .09677 Mdot
.12342 .24315 Mdot
.34973 .13986 Mdot
.38265 .02035 Mdot
.25506 .53918 Mdot
.88887 .39171 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50756 .00321 Mdot
.52409 .01021 Mdot
.5766 .03246 Mdot
.73964 .10076 Mdot
.14091 .248 Mdot
.35736 .13378 Mdot
.38737 .01855 Mdot
.26219 .54067 Mdot
.89898 .39356 Mdot
.67733 .48104 Mdot
.49922 .6177 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.4748 .60735 Mdot
.41988 .58409 Mdot
.24979 .51291 Mdot
.84097 .36537 Mdot
.63293 .48946 Mdot
.6019 .59886 Mdot
.7135 .06897 Mdot
.05758 .21265 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48976 .61369 Mdot
.46739 .60421 Mdot
.39644 .57419 Mdot
.1809 .48482 Mdot
.74877 .35096 Mdot
.55537 .4985 Mdot
.44334 .5488 Mdot
.24813 .49738 Mdot
.81419 .34985 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53224 .01367 Mdot
.6024 .04336 Mdot
.81578 .13188 Mdot
.24779 .267 Mdot
.44109 .11947 Mdot
.54803 .06609 Mdot
.72593 .10995 Mdot
.13984 .25581 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47426 .60712 Mdot
.41816 .58336 Mdot
.24463 .51079 Mdot
.83251 .36333 Mdot
.62775 .49148 Mdot
.5947 .5976 Mdot
.69545 .06227 Mdot
.02105 .20123 Mdot
.49791 .61715 Mdot
.49333 .6152 Mdot
.47875 .60902 Mdot
.43238 .58938 Mdot
.2876 .52856 Mdot
.91073 .38511 Mdot
.66085 .4636 Mdot
.61322 .5886 Mdot
.72144 .06689 Mdot
.06457 .21206 Mdot
.31348 .15383 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50654 .00278 Mdot
.52085 .00884 Mdot
.56634 .02811 Mdot
.70847 .08784 Mdot
.08126 .23039 Mdot
.33738 .1583 Mdot
.38987 .03244 Mdot
.29002 .55633 Mdot
.95896 .41342 Mdot
.68877 .45105 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53217 .01364 Mdot
.60216 .04326 Mdot
.8151 .1316 Mdot
.24707 .26697 Mdot
.44035 .11945 Mdot
.54623 .06544 Mdot
.72049 .1077 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48194 .61038 Mdot
.44253 .59367 Mdot
.31876 .54154 Mdot
.9782 .40756 Mdot
.67024 .4277 Mdot
.57165 .5571 Mdot
.57694 .00327 Mdot
.69318 .07185 Mdot
.03312 .21009 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49085 .61415 Mdot
.47084 .60567 Mdot
.40734 .57879 Mdot
.21257 .49766 Mdot
.78564 .35418 Mdot
.59148 .49804 Mdot
.52711 .57825 Mdot
.50321 .60326 Mdot
.48412 .60624 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47564 .60771 Mdot
.42254 .58521 Mdot
.25778 .51621 Mdot
.85458 .36884 Mdot
.6404 .48566 Mdot
.61054 .59958 Mdot
.73348 .07598 Mdot
.09386 .22273 Mdot
.32147 .14067 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50734 .00311 Mdot
.52339 .00992 Mdot
.57441 .03153 Mdot
.73301 .09802 Mdot
.12899 .24473 Mdot
.35198 .13782 Mdot
.38359 .01954 Mdot
.25575 .53902 Mdot
.88933 .39157 Mdot
.67586 .4861 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52451 .01039 Mdot
.57794 .03302 Mdot
.74368 .10243 Mdot
.14796 .24986 Mdot
.36091 .13161 Mdot
.3908 .01847 Mdot
.26944 .54303 Mdot
.91113 .39658 Mdot
.6793 .47476 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51775 .00753 Mdot
.5565 .02395 Mdot
.67825 .07524 Mdot
.01486 .20804 Mdot
.32922 .19428 Mdot
.43381 .06464 Mdot
.44195 .00503 Mdot
.36494 .57044 Mdot
.1088 .45973 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.4893 .6135 Mdot
.46593 .60359 Mdot
.39184 .57224 Mdot
.1677 .47951 Mdot
.73605 .35126 Mdot
.54221 .49824 Mdot
.41095 .53691 Mdot
.15297 .45859 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48442 .61143 Mdot
.4504 .59701 Mdot
.34317 .55177 Mdot
.03697 .42879 Mdot
.67581 .39482 Mdot
.52791 .52663 Mdot
.42166 .55237 Mdot
.20258 .48264 Mdot
.75529 .34159 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50607 .00258 Mdot
.51935 .0082 Mdot
.56158 .0261 Mdot
.69388 .08177 Mdot
.05023 .22024 Mdot
.33248 .17444 Mdot
.40734 .04627 Mdot
.35094 .58318 Mdot
.10223 .46432 Mdot
.71051 .37593 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51263 .00535 Mdot
.54021 .01705 Mdot
.62746 .05393 Mdot
.88612 .15986 Mdot
.30139 .25665 Mdot
.49026 .11673 Mdot
.66454 .10771 Mdot
.4976 .61701 Mdot
.49234 .61479 Mdot
.47561 .60769 Mdot
.42243 .58517 Mdot
.25746 .51607 Mdot
.85401 .36869 Mdot
.64011 .48583 Mdot
.61025 .59958 Mdot
.73286 .07578 Mdot
.09281 .22246 Mdot
.32131 .14122 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48134 .61012 Mdot
.44062 .59287 Mdot
.31289 .53909 Mdot
.96481 .40291 Mdot
.66909 .43527 Mdot
.58191 .56415 Mdot
.61224 .01875 Mdot
.79733 .11439 Mdot
.21067 .25546 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47553 .60766 Mdot
.42219 .58507 Mdot
.25674 .51578 Mdot
.85277 .36837 Mdot
.63947 .4862 Mdot
.6096 .59957 Mdot
.73143 .0753 Mdot
.09038 .22184 Mdot
.32093 .14249 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00147 Mdot
.51108 .0047 Mdot
.53529 .01496 Mdot
.61201 .04741 Mdot
.84321 .14289 Mdot
.27336 .26585 Mdot
.46734 .11989 Mdot
.61267 .08982 Mdot
.91324 .18576 Mdot
.49912 .61766 Mdot
.49721 .61685 Mdot
.4911 .61426 Mdot
.47166 .60602 Mdot
.40993 .57988 Mdot
.22019 .50077 Mdot
.79589 .3558 Mdot
.60047 .49726 Mdot
.54595 .58434 Mdot
.5594 .00831 Mdot
.65988 .0621 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00032 Mdot
.50244 .00104 Mdot
.50778 .0033 Mdot
.52478 .01051 Mdot
.5788 .03339 Mdot
.74625 .10349 Mdot
.15237 .25099 Mdot
.36328 .13035 Mdot
.39342 .01863 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47811 .60875 Mdot
.43036 .58852 Mdot
.28146 .52601 Mdot
.89848 .38134 Mdot
.65766 .4692 Mdot
.6165 .5926 Mdot
.7349 .07318 Mdot
.09096 .22006 Mdot
.31789 .14025 Mdot
.49849 .6174 Mdot
.4952 .616 Mdot
.48472 .61155 Mdot
.45135 .59741 Mdot
.34613 .55301 Mdot
.04443 .43157 Mdot
.67694 .39092 Mdot
.52348 .52319 Mdot
.4051 .54487 Mdot
.15265 .46202 Mdot
.70476 .34122 Mdot
.4975 .61698 Mdot
.49205 .61466 Mdot
.47468 .6073 Mdot
.41948 .58392 Mdot
.24859 .51242 Mdot
.83897 .36488 Mdot
.63175 .48996 Mdot
.60033 .59862 Mdot
.70965 .06756 Mdot
.05007 .21039 Mdot
.31662 .16474 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50543 .0023 Mdot
.51731 .00734 Mdot
.5551 .02336 Mdot
.6739 .07342 Mdot
.00467 .20442 Mdot
.32843 .2001 Mdot
.44187 .07011 Mdot
.47003 .0174 Mdot
.45349 .60781 Mdot
.36818 .56531 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54094 .01736 Mdot
.62977 .0549 Mdot
.89239 .16231 Mdot
.30441 .25464 Mdot
.4915 .11563 Mdot
.66584 .10775 Mdot
.04632 .23515 Mdot
.35829 .19281 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47931 .60926 Mdot
.43416 .59013 Mdot
.29305 .53082 Mdot
.92188 .38864 Mdot
.66324 .45819 Mdot
.60874 .58435 Mdot
.70495 .05946 Mdot
.0304 .20114 Mdot
.31052 .17313 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.48049 .60976 Mdot
.43792 .59172 Mdot
.30457 .53562 Mdot
.94638 .39666 Mdot
.66711 .44543 Mdot
.59492 .57342 Mdot
.6568 .03825 Mdot
.91765 .16121 Mdot
.29658 .23419 Mdot
.49877 .61751 Mdot
.49607 .61637 Mdot
.48747 .61272 Mdot
.46011 .60112 Mdot
.37353 .56452 Mdot
.11658 .45923 Mdot
.69999 .36057 Mdot
.51044 .50089 Mdot
.33653 .51055 Mdot
.95831 .38428 Mdot
.64191 .42249 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50133 .00057 Mdot
.50425 .0018 Mdot
.51353 .00574 Mdot
.54309 .01827 Mdot
.63649 .05773 Mdot
.91045 .16931 Mdot
.31175 .24802 Mdot
.49207 .11144 Mdot
.66051 .1041 Mdot
.03091 .22892 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51513 .00642 Mdot
.54817 .02042 Mdot
.65236 .06439 Mdot
.95174 .18503 Mdot
.32241 .22909 Mdot
.47863 .09655 Mdot
.60289 .0768 Mdot
.87097 .16568 Mdot
.31208 .27262 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47818 .60878 Mdot
.4306 .58862 Mdot
.28217 .5263 Mdot
.89988 .38176 Mdot
.65805 .46858 Mdot
.61622 .59218 Mdot
.73363 .07256 Mdot
.08852 .21933 Mdot
.31737 .14144 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49074 .61411 Mdot
.47052 .60553 Mdot
.40633 .57836 Mdot
.20959 .49645 Mdot
.78178 .35363 Mdot
.58796 .49824 Mdot
.51946 .5757 Mdot
.48007 .59369 Mdot
.41086 .57526 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.5064 .00271 Mdot
.5204 .00865 Mdot
.5649 .02751 Mdot
.70408 .08602 Mdot
.07212 .22746 Mdot
.33565 .16287 Mdot
.39418 .03618 Mdot
.30542 .56318 Mdot
.99226 .42449 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52404 .01019 Mdot
.57646 .0324 Mdot
.7392 .10058 Mdot
.14013 .24779 Mdot
.35699 .13402 Mdot
.38705 .01858 Mdot
.26155 .54047 Mdot
.89796 .39332 Mdot
.67715 .48157 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50821 .00348 Mdot
.52615 .01109 Mdot
.58313 .03522 Mdot
.75922 .10883 Mdot
.17364 .25613 Mdot
.37628 .12524 Mdot
.41148 .02175 Mdot
.32064 .56189 Mdot
.0142 .42864 Mdot
.498 .61718 Mdot
.49361 .61533 Mdot
.47966 .60941 Mdot
.43527 .5906 Mdot
.29645 .53224 Mdot
.92899 .39093 Mdot
.66455 .4546 Mdot
.60524 .58138 Mdot
.69254 .05395 Mdot
.00318 .19199 Mdot
.30905 .18904 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51372 .00582 Mdot
.54369 .01852 Mdot
.63837 .05852 Mdot
.91543 .17123 Mdot
.31346 .246 Mdot
.49148 .11003 Mdot
.65674 .10213 Mdot
.0209 .22506 Mdot
.3538 .20574 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49613 .61639 Mdot
.48768 .61281 Mdot
.46075 .60139 Mdot
.37555 .56538 Mdot
.12213 .46141 Mdot
.70297 .35898 Mdot
.51219 .50013 Mdot
.33969 .51142 Mdot
.96537 .38669 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50593 .00252 Mdot
.5189 .00802 Mdot
.56016 .0255 Mdot
.68954 .07996 Mdot
.04062 .21698 Mdot
.33143 .17973 Mdot
.41408 .05108 Mdot
.37403 .59328 Mdot
.16415 .48832 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00333 Mdot
.52498 .01059 Mdot
.57943 .03365 Mdot
.74814 .10427 Mdot
.15557 .25181 Mdot
.36507 .12948 Mdot
.39556 .01884 Mdot
.28039 .54686 Mdot
.93084 .40199 Mdot
.68179 .46411 Mdot
.50036 .00015 Mdot
.50113 .00048 Mdot
.50362 .00153 Mdot
.51152 .00489 Mdot
.53669 .01556 Mdot
.61642 .04927 Mdot
.85561 .14783 Mdot
.28287 .26406 Mdot
.47648 .11966 Mdot
.63494 .09793 Mdot
.97241 .20857 Mdot
.35106 .23402 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50606 .00257 Mdot
.51932 .00819 Mdot
.56149 .02606 Mdot
.69361 .08166 Mdot
.04963 .22004 Mdot
.33241 .17476 Mdot
.40775 .04656 Mdot
.35232 .58378 Mdot
.10582 .46569 Mdot
.71203 .37466 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48816 .61301 Mdot
.4623 .60205 Mdot
.38041 .56743 Mdot
.13556 .4667 Mdot
.71107 .35569 Mdot
.51822 .49884 Mdot
.35263 .51569 Mdot
.99624 .39777 Mdot
.64549 .40126 Mdot
.49976 .61793 Mdot
.49923 .61771 Mdot
.49755 .61699 Mdot
.49219 .61472 Mdot
.47511 .60748 Mdot
.42087 .58451 Mdot
.25275 .51413 Mdot
.84593 .36661 Mdot
.63578 .48815 Mdot
.60547 .5993 Mdot
.72203 .07204 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52148 .00911 Mdot
.56835 .02897 Mdot
.71463 .0904 Mdot
.09377 .23432 Mdot
.34025 .15233 Mdot
.38537 .02788 Mdot
.27302 .5486 Mdot
.92443 .40259 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52528 .01072 Mdot
.58038 .03406 Mdot
.75099 .10544 Mdot
.16033 .25299 Mdot
.36784 .12824 Mdot
.39911 .01933 Mdot
.28898 .54997 Mdot
.94724 .40683 Mdot
.4987 .61748 Mdot
.49586 .61628 Mdot
.48682 .61245 Mdot
.45803 .60024 Mdot
.36702 .56179 Mdot
.09896 .45236 Mdot
.69184 .36642 Mdot
.50768 .50422 Mdot
.33505 .51134 Mdot
.95697 .38437 Mdot
.64265 .42377 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50691 .00293 Mdot
.522 .00933 Mdot
.56999 .02966 Mdot
.7196 .09247 Mdot
.1036 .23733 Mdot
.34295 .14792 Mdot
.38313 .02483 Mdot
.26334 .544 Mdot
.90565 .39697 Mdot
.50064 .00027 Mdot
.50202 .00086 Mdot
.50645 .00274 Mdot
.52055 .00872 Mdot
.5654 .02772 Mdot
.7056 .08665 Mdot
.07531 .22849 Mdot
.33622 .16125 Mdot
.39258 .03483 Mdot
.29978 .56068 Mdot
.97982 .42029 Mdot
.69005 .43894 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50625 .00265 Mdot
.5199 .00844 Mdot
.56334 .02684 Mdot
.69928 .08402 Mdot
.06194 .22414 Mdot
.33402 .16815 Mdot
.39986 .04069 Mdot
.3252 .57189 Mdot
.498 .61718 Mdot
.49362 .61533 Mdot
.47966 .60941 Mdot
.43529 .59061 Mdot
.2965 .53226 Mdot
.9291 .39097 Mdot
.66457 .45454 Mdot
.60518 .58133 Mdot
.69234 .05387 Mdot
.00273 .19183 Mdot
.30903 .1893 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49276 .61497 Mdot
.47695 .60826 Mdot
.42667 .58696 Mdot
.27026 .52137 Mdot
.87705 .37501 Mdot
.65046 .47799 Mdot
.61741 .59761 Mdot
.74493 .07881 Mdot
.11106 .22628 Mdot
.49898 .6176 Mdot
.49675 .61665 Mdot
.48964 .61364 Mdot
.467 .60404 Mdot
.39521 .57367 Mdot
.17736 .48339 Mdot
.74521 .35095 Mdot
.55169 .49843 Mdot
.43434 .54551 Mdot
.22127 .48635 Mdot
.77335 .3412 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.5135 .00572 Mdot
.54299 .01823 Mdot
.63618 .0576 Mdot
.90962 .16899 Mdot
.31146 .24835 Mdot
.49214 .11167 Mdot
.66104 .10439 Mdot
.03235 .22948 Mdot
.35546 .1997 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.47482 .60736 Mdot
.41992 .58411 Mdot
.2499 .51296 Mdot
.84115 .36541 Mdot
.63304 .48941 Mdot
.60205 .59888 Mdot
.71385 .0691 Mdot
.05825 .21285 Mdot
.31721 .16005 Mdot
.49757 .617 Mdot
.49226 .61475 Mdot
.47535 .60758 Mdot
.42162 .58483 Mdot
.25503 .51507 Mdot
.84981 .3676 Mdot
.6379 .48707 Mdot
.60792 .5995 Mdot
.7277 .07403 Mdot
.08386 .22012 Mdot
.31998 .14593 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.50991 .0042 Mdot
.53155 .01338 Mdot
.60022 .04244 Mdot
.80946 .12932 Mdot
.24097 .26669 Mdot
.43414 .11938 Mdot
.5313 .06005 Mdot
.67512 .08888 Mdot
.03172 .22039 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00215 Mdot
.51612 .00684 Mdot
.55133 .02176 Mdot
.66221 .06853 Mdot
.97641 .19419 Mdot
.32587 .21597 Mdot
.4632 .08488 Mdot
.54583 .05107 Mdot
.69627 .09297 Mdot
.07196 .23219 Mdot
.49934 .61775 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47856 .60894 Mdot
.4318 .58913 Mdot
.28584 .52783 Mdot
.90718 .38401 Mdot
.65999 .46526 Mdot
.61435 .58983 Mdot
.72587 .06892 Mdot
.07337 .21477 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52236 .00948 Mdot
.57113 .03014 Mdot
.72308 .09391 Mdot
.11035 .23935 Mdot
.34504 .14505 Mdot
.38233 .02304 Mdot
.25875 .54166 Mdot
.89679 .39434 Mdot
.67903 .48345 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50717 .00304 Mdot
.52285 .00969 Mdot
.57269 .0308 Mdot
.7278 .09587 Mdot
.11934 .24198 Mdot
.34817 .14143 Mdot
.38227 .02107 Mdot
.25544 .53965 Mdot
.89002 .39219 Mdot
.67675 .48623 Mdot
.49934 .61776 Mdot
.4979 .61715 Mdot
.49332 .6152 Mdot
.47873 .60902 Mdot
.43234 .58936 Mdot
.28747 .5285 Mdot
.91046 .38503 Mdot
.66079 .46373 Mdot
.61331 .58869 Mdot
.72179 .06705 Mdot
.06527 .21228 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.5044 .00186 Mdot
.51401 .00594 Mdot
.5446 .01891 Mdot
.64121 .05971 Mdot
.92293 .17411 Mdot
.31579 .2428 Mdot
.49002 .10768 Mdot
.64928 .09843 Mdot
.00103 .2174 Mdot
.35124 .21644 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52404 .0102 Mdot
.57647 .0324 Mdot
.73924 .1006 Mdot
.14019 .2478 Mdot
.35702 .13401 Mdot
.38707 .01858 Mdot
.2616 .54049 Mdot
.89803 .39334 Mdot
.67716 .48153 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48466 .61153 Mdot
.45118 .59734 Mdot
.34559 .55278 Mdot
.04306 .43106 Mdot
.67672 .39162 Mdot
.52426 .5238 Mdot
.40803 .5462 Mdot
.16141 .46561 Mdot
.71209 .34034 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.5068 .00289 Mdot
.52168 .00919 Mdot
.56896 .02922 Mdot
.71648 .09117 Mdot
.09746 .23546 Mdot
.34121 .15065 Mdot
.38438 .02668 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49918 .61768 Mdot
.49737 .61692 Mdot
.49163 .61448 Mdot
.47334 .60673 Mdot
.41525 .58213 Mdot
.23594 .50722 Mdot
.81884 .36025 Mdot
.61848 .49421 Mdot
.57988 .59418 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49983 .61796 Mdot
.49946 .61781 Mdot
.49828 .61731 Mdot
.49453 .61572 Mdot
.48259 .61065 Mdot
.44457 .59454 Mdot
.32509 .54419 Mdot
.99296 .41277 Mdot
.67138 .41929 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54655 .01973 Mdot
.64732 .06228 Mdot
.93884 .18017 Mdot
.31986 .23548 Mdot
.48477 .10192 Mdot
.62688 .08783 Mdot
.93978 .19338 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00823 Mdot
.56174 .02617 Mdot
.6944 .08198 Mdot
.05136 .22062 Mdot
.33261 .17382 Mdot
.40658 .04571 Mdot
.34833 .58203 Mdot
.09547 .46176 Mdot
.70784 .37847 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48569 .61196 Mdot
.45442 .59871 Mdot
.35573 .55704 Mdot
.06907 .44087 Mdot
.68203 .37883 Mdot
.51228 .51312 Mdot
.36092 .52449 Mdot
.0265 .41135 Mdot
.65251 .3869 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.51959 .00831 Mdot
.56235 .02643 Mdot
.69626 .08276 Mdot
.05542 .22197 Mdot
.33312 .17163 Mdot
.40392 .04375 Mdot
.33918 .57803 Mdot
.07222 .45304 Mdot
.70061 .38837 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00142 Mdot
.5107 .00454 Mdot
.53409 .01445 Mdot
.60822 .04581 Mdot
.83244 .13858 Mdot
.26408 .26677 Mdot
.45793 .1198 Mdot
.58939 .08125 Mdot
.84801 .15983 Mdot
.3015 .28027 Mdot
.49909 .61765 Mdot
.4971 .61681 Mdot
.49077 .61412 Mdot
.47061 .60557 Mdot
.40662 .57848 Mdot
.21045 .4968 Mdot
.78289 .35378 Mdot
.58898 .49819 Mdot
.52168 .57645 Mdot
.48682 .59649 Mdot
.43221 .58428 Mdot
.49797 .61717 Mdot
.49352 .61529 Mdot
.47936 .60928 Mdot
.43432 .5902 Mdot
.29353 .53102 Mdot
.92288 .38896 Mdot
.66344 .45769 Mdot
.60828 .58394 Mdot
.7033 .05872 Mdot
.02684 .19996 Mdot
.31031 .1752 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51668 .00707 Mdot
.55311 .02251 Mdot
.66773 .07084 Mdot
.98988 .1991 Mdot
.3272 .20848 Mdot
.49945 .6178 Mdot
.49824 .61729 Mdot
.49439 .61566 Mdot
.48214 .61046 Mdot
.44316 .59394 Mdot
.32072 .54236 Mdot
.98272 .40914 Mdot
.67059 .42513 Mdot
.5681 .55469 Mdot
.56466 .61591 Mdot
.65556 .05618 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51256 .00533 Mdot
.54 .01696 Mdot
.62681 .05365 Mdot
.88432 .15916 Mdot
.30048 .2572 Mdot
.48981 .11701 Mdot
.66386 .10757 Mdot
.04253 .23403 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47788 .60865 Mdot
.42963 .58821 Mdot
.27922 .52508 Mdot
.89409 .38001 Mdot
.65636 .47111 Mdot
.61722 .59384 Mdot
.73843 .07491 Mdot
.09775 .22207 Mdot
.31949 .13704 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48115 .61004 Mdot
.44001 .59261 Mdot
.311 .5383 Mdot
.96057 .40146 Mdot
.66869 .43764 Mdot
.58505 .56634 Mdot
.62299 .02345 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00149 Mdot
.51116 .00473 Mdot
.53554 .01507 Mdot
.61278 .04774 Mdot
.84538 .14376 Mdot
.27511 .26559 Mdot
.46908 .11988 Mdot
.61695 .09139 Mdot
.92488 .19031 Mdot
.34135 .2574 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50455 .00193 Mdot
.51449 .00614 Mdot
.54612 .01955 Mdot
.64598 .06171 Mdot
.93537 .17885 Mdot
.31906 .23714 Mdot
.48615 .10327 Mdot
.63249 .09044 Mdot
.95538 .19956 Mdot
.34433 .24038 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51127 .00478 Mdot
.5359 .01522 Mdot
.61393 .04822 Mdot
.84863 .14505 Mdot
.27767 .26516 Mdot
.47157 .11984 Mdot
.62306 .09362 Mdot
.94128 .19667 Mdot
.3456 .24988 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.5078 .00331 Mdot
.52486 .01054 Mdot
.57906 .03349 Mdot
.74702 .10381 Mdot
.15367 .25132 Mdot
.364 .12999 Mdot
.39426 .0187 Mdot
.27734 .54577 Mdot
.50046 .0002 Mdot
.50147 .00063 Mdot
.5047 .00199 Mdot
.51497 .00635 Mdot
.54767 .02021 Mdot
.6508 .06374 Mdot
.94779 .18354 Mdot
.32169 .23109 Mdot
.48068 .09826 Mdot
.61075 .08039 Mdot
.89385 .17497 Mdot
.32463 .26624 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48245 .61059 Mdot
.44415 .59436 Mdot
.32379 .54364 Mdot
.98989 .41167 Mdot
.67115 .42104 Mdot
.56243 .55084 Mdot
.54498 .60725 Mdot
.59409 .03036 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50751 .00319 Mdot
.52393 .01015 Mdot
.57611 .03225 Mdot
.73816 .10015 Mdot
.13828 .24729 Mdot
.35611 .13463 Mdot
.38633 .01867 Mdot
.26016 .54006 Mdot
.89575 .39282 Mdot
.67677 .4827 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50507 .00215 Mdot
.51615 .00685 Mdot
.55142 .0218 Mdot
.6625 .06865 Mdot
.97712 .19445 Mdot
.32595 .21558 Mdot
.4627 .08452 Mdot
.54402 .05026 Mdot
.69054 .09055 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50364 .00154 Mdot
.5116 .00492 Mdot
.53693 .01566 Mdot
.61717 .04959 Mdot
.8577 .14866 Mdot
.28436 .26369 Mdot
.47783 .11957 Mdot
.63815 .09908 Mdot
.98064 .21167 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.52049 .00869 Mdot
.5652 .02763 Mdot
.70499 .08639 Mdot
.07402 .22808 Mdot
.33599 .1619 Mdot
.39322 .03537 Mdot
.30203 .56168 Mdot
.98475 .42194 Mdot
.69031 .43606 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49392 .61545 Mdot
.48062 .60982 Mdot
.43833 .5919 Mdot
.30583 .53614 Mdot
.94913 .39758 Mdot
.66745 .44394 Mdot
.59309 .57208 Mdot
.65054 .0355 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47857 .60895 Mdot
.43183 .58914 Mdot
.28592 .52786 Mdot
.90734 .38406 Mdot
.66003 .46519 Mdot
.6143 .58978 Mdot
.72567 .06883 Mdot
.07299 .21465 Mdot
.31462 .14933 Mdot
.5008 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.52571 .0109 Mdot
.58176 .03464 Mdot
.75512 .10714 Mdot
.1671 .25461 Mdot
.372 .12664 Mdot
.40494 .02036 Mdot
.30362 .55541 Mdot
.97698 .41616 Mdot
.68475 .43743 Mdot
.49748 .61697 Mdot
.49197 .61463 Mdot
.47442 .60719 Mdot
.41868 .58358 Mdot
.24619 .51143 Mdot
.83503 .36393 Mdot
.62934 .49091 Mdot
.597 .59804 Mdot
.7013 .06447 Mdot
.03326 .20516 Mdot
.31569 .17455 Mdot
.49859 .61744 Mdot
.49552 .61614 Mdot
.48574 .61199 Mdot
.45458 .59878 Mdot
.35623 .55725 Mdot
.07037 .44136 Mdot
.68236 .37823 Mdot
.51185 .51265 Mdot
.35911 .52363 Mdot
.02156 .40942 Mdot
.65177 .38949 Mdot
.49859 .61743 Mdot
.49549 .61612 Mdot
.48565 .61195 Mdot
.45429 .59866 Mdot
.35532 .55686 Mdot
.068 .44046 Mdot
.68176 .37932 Mdot
.51263 .51351 Mdot
.36244 .52521 Mdot
.03066 .41298 Mdot
.65317 .38473 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48835 .61309 Mdot
.46289 .6023 Mdot
.38227 .56821 Mdot
.14073 .46875 Mdot
.71455 .35464 Mdot
.5212 .49854 Mdot
.35955 .51813 Mdot
.01351 .40417 Mdot
.64724 .39166 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50324 .00137 Mdot
.51031 .00437 Mdot
.53285 .01393 Mdot
.60431 .04417 Mdot
.82128 .13409 Mdot
.25344 .26709 Mdot
.44691 .11958 Mdot
.56223 .07127 Mdot
.76854 .1275 Mdot
.21196 .27405 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.47971 .60943 Mdot
.43545 .59068 Mdot
.29699 .53246 Mdot
.93013 .3913 Mdot
.66474 .45401 Mdot
.60464 .58089 Mdot
.69042 .05302 Mdot
.99841 .19035 Mdot
.30878 .19182 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51215 .00515 Mdot
.5387 .01641 Mdot
.62272 .05193 Mdot
.87312 .15476 Mdot
.29431 .26031 Mdot
.48596 .11845 Mdot
.65658 .10545 Mdot
.02598 .2283 Mdot
.35658 .20432 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50647 .00274 Mdot
.52062 .00874 Mdot
.56561 .02781 Mdot
.70625 .08692 Mdot
.07666 .22893 Mdot
.33648 .16057 Mdot
.39194 .03428 Mdot
.29748 .55965 Mdot
.97482 .41862 Mdot
.68978 .44187 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.4797 .60943 Mdot
.43542 .59066 Mdot
.2969 .53243 Mdot
.92994 .39124 Mdot
.66471 .45411 Mdot
.60474 .58097 Mdot
.69078 .05317 Mdot
.99921 .19062 Mdot
.30883 .19136 Mdot
.49755 .617 Mdot
.49221 .61473 Mdot
.47517 .60751 Mdot
.42105 .58458 Mdot
.25329 .51435 Mdot
.84685 .36684 Mdot
.63629 .4879 Mdot
.60608 .59936 Mdot
.72346 .07255 Mdot
.07626 .21804 Mdot
.319 .15002 Mdot
.49875 .61751 Mdot
.49603 .61635 Mdot
.48734 .61267 Mdot
.45968 .60094 Mdot
.3722 .56396 Mdot
.11296 .45781 Mdot
.69815 .36167 Mdot
.50952 .50145 Mdot
.33516 .51028 Mdot
.95545 .38335 Mdot
.64169 .42412 Mdot
.49831 .61732 Mdot
.4946 .61574 Mdot
.4828 .61074 Mdot
.44524 .59482 Mdot
.32715 .54505 Mdot
.99782 .4145 Mdot
.67177 .41652 Mdot
.55617 .54659 Mdot
.5231 .59759 Mdot
.52455 .0009 Mdot
.56269 .02357 Mdot
.4992 .6177 Mdot
.49745 .61695 Mdot
.49189 .61459 Mdot
.47415 .60707 Mdot
.41782 .58322 Mdot
.24361 .51037 Mdot
.83086 .36294 Mdot
.62669 .49185 Mdot
.59311 .59728 Mdot
.69138 .06073 Mdot
.01236 .19838 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49056 .61403 Mdot
.46994 .60529 Mdot
.4045 .57759 Mdot
.20426 .49428 Mdot
.77507 .35278 Mdot
.58166 .4985 Mdot
.50545 .57093 Mdot
.4374 .57598 Mdot
.27786 .51943 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51156 .0049 Mdot
.53681 .01561 Mdot
.6168 .04943 Mdot
.85667 .14825 Mdot
.28363 .26388 Mdot
.47717 .11961 Mdot
.63659 .09853 Mdot
.97666 .21017 Mdot
.35161 .23173 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48245 .61059 Mdot
.44414 .59436 Mdot
.32375 .54363 Mdot
.9898 .41164 Mdot
.67114 .42109 Mdot
.5625 .55089 Mdot
.54523 .60736 Mdot
.59488 .03069 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50755 .0032 Mdot
.52406 .0102 Mdot
.57651 .03242 Mdot
.73937 .10065 Mdot
.14042 .24786 Mdot
.35713 .13393 Mdot
.38717 .01857 Mdot
.26179 .54054 Mdot
.89833 .3934 Mdot
.67721 .48138 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.4933 .61519 Mdot
.47865 .60898 Mdot
.43206 .58924 Mdot
.28663 .52816 Mdot
.90877 .3845 Mdot
.66038 .46452 Mdot
.61386 .58928 Mdot
.72394 .06803 Mdot
.06955 .2136 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47982 .60948 Mdot
.43579 .59082 Mdot
.29804 .5329 Mdot
.93236 .39203 Mdot
.66511 .45286 Mdot
.60343 .57991 Mdot
.68619 .05115 Mdot
.98876 .187 Mdot
.30817 .19741 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.5055 .00233 Mdot
.51752 .00743 Mdot
.55577 .02364 Mdot
.67596 .07429 Mdot
.00952 .20615 Mdot
.32881 .19733 Mdot
.43803 .0675 Mdot
.45663 .0115 Mdot
.41099 .58982 Mdot
.23867 .51154 Mdot
.49772 .61707 Mdot
.49275 .61496 Mdot
.4769 .60824 Mdot
.42654 .58691 Mdot
.26985 .52119 Mdot
.87628 .3748 Mdot
.65016 .47828 Mdot
.61731 .59774 Mdot
.74493 .07887 Mdot
.11117 .22634 Mdot
.32388 .13146 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50687 .00291 Mdot
.52187 .00927 Mdot
.56958 .02949 Mdot
.71838 .09196 Mdot
.10121 .2366 Mdot
.34225 .14897 Mdot
.38356 .02553 Mdot
.26538 .54499 Mdot
.90957 .39814 Mdot
.68223 .47753 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47459 .60726 Mdot
.41919 .5838 Mdot
.24772 .51206 Mdot
.83755 .36453 Mdot
.63089 .49031 Mdot
.59916 .59843 Mdot
.70674 .06649 Mdot
.04429 .20862 Mdot
.31626 .16808 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51847 .00783 Mdot
.55878 .02491 Mdot
.68528 .07818 Mdot
.03104 .21369 Mdot
.33053 .1851 Mdot
.42122 .05605 Mdot
.3985 .60399 Mdot
.23364 .51615 Mdot
.83131 .36938 Mdot
.49762 .61702 Mdot
.49241 .61481 Mdot
.47582 .60778 Mdot
.42309 .58545 Mdot
.25944 .51689 Mdot
.85748 .36961 Mdot
.64185 .48477 Mdot
.61192 .59954 Mdot
.73638 .07692 Mdot
.0987 .22392 Mdot
.32228 .13818 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50947 .00402 Mdot
.53016 .01279 Mdot
.59584 .04059 Mdot
.79673 .12416 Mdot
.22614 .26539 Mdot
.41949 .1195 Mdot
.49717 .04801 Mdot
.57061 .04539 Mdot
.74653 .10872 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.5049 .00208 Mdot
.5156 .00662 Mdot
.54968 .02106 Mdot
.65707 .06637 Mdot
.96365 .18947 Mdot
.32428 .22288 Mdot
.47171 .09112 Mdot
.57692 .06502 Mdot
.79307 .13359 Mdot
.23927 .27576 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00467 Mdot
.53505 .01486 Mdot
.61124 .04709 Mdot
.84104 .14202 Mdot
.27156 .26608 Mdot
.46554 .11989 Mdot
.60825 .08819 Mdot
.90108 .18098 Mdot
.49923 .61771 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47505 .60746 Mdot
.42067 .58442 Mdot
.25215 .51388 Mdot
.84491 .36635 Mdot
.63521 .48843 Mdot
.60478 .59923 Mdot
.72041 .07146 Mdot
.07066 .21647 Mdot
.5001 4e-05 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50309 .00131 Mdot
.50984 .00417 Mdot
.53135 .01329 Mdot
.59958 .04217 Mdot
.80762 .12858 Mdot
.23892 .26656 Mdot
.43206 .11937 Mdot
.52637 .05828 Mdot
.66005 .08262 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47679 .60819 Mdot
.42617 .58675 Mdot
.26873 .52073 Mdot
.87421 .37421 Mdot
.64934 .47905 Mdot
.61701 .59806 Mdot
.74482 .07899 Mdot
.11123 .22645 Mdot
.32405 .13153 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00126 Mdot
.5095 .00403 Mdot
.53026 .01283 Mdot
.59614 .04072 Mdot
.79763 .12453 Mdot
.22724 .26551 Mdot
.42055 .11947 Mdot
.49958 .04884 Mdot
.57796 .04845 Mdot
.76867 .11787 Mdot
.4986 .61744 Mdot
.49554 .61614 Mdot
.4858 .61201 Mdot
.45478 .59886 Mdot
.35683 .5575 Mdot
.07194 .44196 Mdot
.68278 .37752 Mdot
.51137 .5121 Mdot
.357 .52263 Mdot
.01585 .40719 Mdot
.65096 .39252 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50399 .00169 Mdot
.51272 .00539 Mdot
.5405 .01717 Mdot
.62836 .05431 Mdot
.88857 .16082 Mdot
.3026 .25588 Mdot
.49081 .11632 Mdot
.66525 .10781 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00214 Mdot
.51611 .00683 Mdot
.5513 .02174 Mdot
.6621 .06848 Mdot
.97614 .19409 Mdot
.32584 .21612 Mdot
.46339 .08501 Mdot
.54652 .05138 Mdot
.69844 .09389 Mdot
.07667 .23376 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50378 .0016 Mdot
.51203 .0051 Mdot
.53832 .01625 Mdot
.62155 .05143 Mdot
.86987 .15348 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52058 .00873 Mdot
.56548 .02775 Mdot
.70584 .08675 Mdot
.07581 .22865 Mdot
.33632 .161 Mdot
.39234 .03463 Mdot
.29892 .5603 Mdot
.97795 .41967 Mdot
.68995 .44004 Mdot
.49843 .61737 Mdot
.49498 .61591 Mdot
.48402 .61126 Mdot
.44913 .59647 Mdot
.33923 .55011 Mdot
.02713 .42515 Mdot
.67454 .40012 Mdot
.53434 .53139 Mdot
.44525 .56298 Mdot
.27565 .51322 Mdot
.87042 .36758 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47789 .60866 Mdot
.42966 .58823 Mdot
.27932 .52512 Mdot
.89428 .38007 Mdot
.65642 .47103 Mdot
.61719 .59379 Mdot
.73829 .07484 Mdot
.09748 .22199 Mdot
.31942 .13717 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47888 .60908 Mdot
.4328 .58955 Mdot
.28888 .52909 Mdot
.91333 .38593 Mdot
.66145 .46236 Mdot
.61229 .58765 Mdot
.71795 .0653 Mdot
.05751 .20986 Mdot
.31267 .1577 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57374 .03125 Mdot
.731 .09719 Mdot
.12529 .24368 Mdot
.35046 .13917 Mdot
.38291 .02005 Mdot
.25514 .53907 Mdot
.88876 .3916 Mdot
.67598 .48653 Mdot
.50054 .00023 Mdot
.50171 .00073 Mdot
.50546 .00231 Mdot
.51739 .00737 Mdot
.55536 .02346 Mdot
.6747 .07375 Mdot
.00654 .20509 Mdot
.32858 .19903 Mdot
.44039 .06911 Mdot
.46487 .01513 Mdot
.43708 .60086 Mdot
.31735 .54404 Mdot
.50076 .00032 Mdot
.50244 .00103 Mdot
.50776 .00329 Mdot
.52473 .01049 Mdot
.57864 .03332 Mdot
.74578 .1033 Mdot
.15156 .25079 Mdot
.36284 .13058 Mdot
.39291 .01859 Mdot
.27421 .54467 Mdot
.91952 .39883 Mdot
.68048 .47029 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48802 .61296 Mdot
.46186 .60186 Mdot
.37903 .56684 Mdot
.13173 .46519 Mdot
.70863 .35655 Mdot
.51625 .49913 Mdot
.34819 .51417 Mdot
.9854 .39382 Mdot
.64448 .40734 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51962 .00832 Mdot
.56242 .02646 Mdot
.69648 .08285 Mdot
.0559 .22213 Mdot
.33318 .17137 Mdot
.40361 .04353 Mdot
.33812 .57756 Mdot
.06958 .45206 Mdot
.69996 .3896 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50696 .00295 Mdot
.52218 .00941 Mdot
.57057 .0299 Mdot
.72137 .0932 Mdot
.10706 .23837 Mdot
.344 .14643 Mdot
.38264 .02388 Mdot
.26077 .54271 Mdot
.90071 .3955 Mdot
.68011 .4817 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00313 Mdot
.52348 .00996 Mdot
.57468 .03165 Mdot
.73385 .09837 Mdot
.13052 .24515 Mdot
.35263 .13727 Mdot
.38394 .01935 Mdot
.25619 .53908 Mdot
.88988 .39165 Mdot
.67589 .48578 Mdot
.49963 .61788 Mdot
.49881 .61753 Mdot
.49622 .61643 Mdot
.48796 .61293 Mdot
.46167 .60178 Mdot
.37843 .56659 Mdot
.13006 .46453 Mdot
.7076 .35694 Mdot
.51545 .49928 Mdot
.34644 .51358 Mdot
.9812 .3923 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51713 .00727 Mdot
.55454 .02312 Mdot
.67217 .0727 Mdot
.00054 .20295 Mdot
.3281 .20245 Mdot
.44511 .07231 Mdot
.4814 .02243 Mdot
.48987 .00523 Mdot
.48314 .61388 Mdot
.49863 .61745 Mdot
.49562 .61618 Mdot
.48605 .61212 Mdot
.45557 .5992 Mdot
.35932 .55854 Mdot
.07846 .44446 Mdot
.68462 .37463 Mdot
.50966 .5099 Mdot
.34918 .51885 Mdot
.99484 .39904 Mdot
.64824 .40382 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61007 Mdot
.4402 .59269 Mdot
.3116 .53855 Mdot
.96192 .40192 Mdot
.66882 .43689 Mdot
.58406 .56565 Mdot
.61961 .02197 Mdot
.81815 .1227 Mdot
.23387 .25693 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.5061 .00259 Mdot
.51944 .00824 Mdot
.56185 .02621 Mdot
.69473 .08212 Mdot
.05208 .22086 Mdot
.3327 .17343 Mdot
.4061 .04536 Mdot
.34668 .58131 Mdot
.09124 .46016 Mdot
.70631 .38013 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49458 .61573 Mdot
.48272 .61071 Mdot
.445 .59472 Mdot
.3264 .54474 Mdot
.99604 .41386 Mdot
.67162 .41753 Mdot
.55757 .54755 Mdot
.52801 .59976 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50963 .00408 Mdot
.53066 .013 Mdot
.59741 .04125 Mdot
.80132 .12602 Mdot
.23165 .26596 Mdot
.42484 .1194 Mdot
.50944 .05228 Mdot
.60819 .06103 Mdot
.85702 .15378 Mdot
.49781 .6171 Mdot
.49302 .61507 Mdot
.47776 .6086 Mdot
.42925 .58805 Mdot
.27807 .5246 Mdot
.89186 .37935 Mdot
.65567 .47206 Mdot
.61748 .59443 Mdot
.73994 .07569 Mdot
.10066 .22294 Mdot
.32025 .13572 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48327 .61094 Mdot
.44674 .59546 Mdot
.3318 .547 Mdot
.00897 .41851 Mdot
.67269 .4102 Mdot
.54754 .54068 Mdot
.49263 .5841 Mdot
.42667 .57727 Mdot
.25456 .51166 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48583 .61203 Mdot
.45489 .59891 Mdot
.35718 .55765 Mdot
.07286 .44231 Mdot
.68303 .3771 Mdot
.5111 .51178 Mdot
.3558 .52206 Mdot
.01261 .40593 Mdot
.65052 .39425 Mdot
.4982 .61727 Mdot
.49426 .6156 Mdot
.48171 .61028 Mdot
.44178 .59336 Mdot
.31644 .54057 Mdot
.97288 .4057 Mdot
.6698 .43072 Mdot
.57578 .55993 Mdot
.59119 .00952 Mdot
.73601 .08951 Mdot
.11864 .23648 Mdot
.49885 .61755 Mdot
.49633 .61648 Mdot
.48831 .61308 Mdot
.46278 .60225 Mdot
.38191 .56806 Mdot
.13972 .46835 Mdot
.71385 .35483 Mdot
.52058 .49859 Mdot
.35811 .51762 Mdot
.00989 .40282 Mdot
.64685 .39366 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.5099 .0042 Mdot
.53153 .01337 Mdot
.60016 .04241 Mdot
.80929 .12925 Mdot
.24078 .26668 Mdot
.43394 .11938 Mdot
.53084 .05989 Mdot
.67371 .0883 Mdot
.02842 .21922 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47426 .60712 Mdot
.41817 .58337 Mdot
.24468 .51081 Mdot
.83258 .36335 Mdot
.6278 .49147 Mdot
.59476 .59762 Mdot
.69562 .06233 Mdot
.0214 .20135 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50764 .00324 Mdot
.52435 .01032 Mdot
.57744 .03281 Mdot
.74215 .1018 Mdot
.14531 .24916 Mdot
.35955 .13241 Mdot
.38941 .01845 Mdot
.2664 .54201 Mdot
.90594 .39525 Mdot
.67849 .47747 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48376 .61115 Mdot
.44829 .59612 Mdot
.33662 .54902 Mdot
.02072 .42279 Mdot
.67382 .40364 Mdot
.53883 .53461 Mdot
.46151 .57025 Mdot
.32703 .53492 Mdot
.98123 .40432 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51387 .00588 Mdot
.54418 .01873 Mdot
.63991 .05916 Mdot
.9195 .1728 Mdot
.31476 .24428 Mdot
.49077 .10878 Mdot
.65295 .10023 Mdot
.01083 .22118 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48535 .61182 Mdot
.45337 .59826 Mdot
.35242 .55565 Mdot
.0605 .43761 Mdot
.68 .38287 Mdot
.5155 .51637 Mdot
.37423 .53072 Mdot
.06334 .42589 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48029 .60968 Mdot
.43729 .59146 Mdot
.30264 .53482 Mdot
.9422 .39527 Mdot
.66657 .44768 Mdot
.5976 .57541 Mdot
.66603 .04229 Mdot
.94072 .16977 Mdot
.30229 .22346 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48569 .61197 Mdot
.45444 .59872 Mdot
.35578 .55706 Mdot
.06921 .44092 Mdot
.68206 .37876 Mdot
.51223 .51307 Mdot
.36072 .52439 Mdot
.02595 .41113 Mdot
.65243 .38719 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48966 .61365 Mdot
.46707 .60407 Mdot
.39545 .57377 Mdot
.17803 .48366 Mdot
.74587 .35095 Mdot
.55237 .49844 Mdot
.43601 .54612 Mdot
.22624 .48839 Mdot
.78039 .34248 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50782 .00332 Mdot
.52491 .01056 Mdot
.57923 .03357 Mdot
.74753 .10402 Mdot
.15453 .25154 Mdot
.36448 .12976 Mdot
.39484 .01876 Mdot
.2787 .54625 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48478 .61158 Mdot
.45153 .59749 Mdot
.3467 .55325 Mdot
.04586 .43211 Mdot
.67718 .39017 Mdot
.52267 .52254 Mdot
.40206 .54349 Mdot
.14362 .45831 Mdot
.69783 .34252 Mdot
.4989 .61757 Mdot
.49651 .61655 Mdot
.48888 .61332 Mdot
.46457 .60301 Mdot
.38756 .57044 Mdot
.15557 .47466 Mdot
.72565 .35233 Mdot
.53168 .49815 Mdot
.38491 .52732 Mdot
.08015 .42969 Mdot
.66019 .35848 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.52011 .00853 Mdot
.56398 .02712 Mdot
.70126 .08485 Mdot
.06617 .22553 Mdot
.33466 .16593 Mdot
.39739 .03877 Mdot
.31666 .56814 Mdot
.01784 .43335 Mdot
.69231 .41685 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .0016 Mdot
.51199 .00508 Mdot
.53818 .01619 Mdot
.62109 .05124 Mdot
.86862 .15298 Mdot
.29159 .26141 Mdot
.48392 .11887 Mdot
.65219 .10399 Mdot
.0155 .22454 Mdot
.3556 .21019 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50797 .00338 Mdot
.52539 .01077 Mdot
.58074 .03421 Mdot
.75208 .10589 Mdot
.16213 .25342 Mdot
.36891 .1278 Mdot
.40056 .01956 Mdot
.29258 .55129 Mdot
.95435 .409 Mdot
.68366 .45074 Mdot
.49813 .61724 Mdot
.49404 .6155 Mdot
.481 .60998 Mdot
.43953 .5924 Mdot
.30951 .53768 Mdot
.95726 .40033 Mdot
.66835 .43948 Mdot
.58744 .56803 Mdot
.63119 .02704 Mdot
.85019 .13535 Mdot
.26216 .25461 Mdot
.49744 .61695 Mdot
.49184 .61457 Mdot
.47401 .60701 Mdot
.41736 .58302 Mdot
.24225 .50981 Mdot
.82868 .36244 Mdot
.62527 .49232 Mdot
.59095 .59682 Mdot
.68574 .05858 Mdot
6e-05 .19426 Mdot
.31429 .19421 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48702 .61253 Mdot
.45867 .60051 Mdot
.36903 .56263 Mdot
.10436 .45446 Mdot
.69413 .3645 Mdot
.50808 .50305 Mdot
.33413 .51053 Mdot
.95403 .38312 Mdot
.64193 .42515 Mdot
.49893 .61758 Mdot
.49658 .61658 Mdot
.4891 .61341 Mdot
.46529 .60332 Mdot
.38983 .5714 Mdot
.162 .47723 Mdot
.73101 .35167 Mdot
.53705 .49816 Mdot
.39818 .5322 Mdot
.11678 .44412 Mdot
.67551 .34532 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47657 .6081 Mdot
.42549 .58646 Mdot
.26669 .51989 Mdot
.87046 .37315 Mdot
.64779 .48042 Mdot
.61629 .59857 Mdot
.7441 .079 Mdot
.11049 .22644 Mdot
.32414 .13204 Mdot
.50054 .00023 Mdot
.50171 .00073 Mdot
.50546 .00232 Mdot
.5174 .00738 Mdot
.55539 .02348 Mdot
.67481 .0738 Mdot
.00681 .20519 Mdot
.3286 .19888 Mdot
.44018 .06896 Mdot
.46412 .0148 Mdot
.43471 .59985 Mdot
.31007 .54101 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47453 .60723 Mdot
.419 .58372 Mdot
.24715 .51183 Mdot
.83661 .36431 Mdot
.63032 .49054 Mdot
.59837 .59829 Mdot
.70477 .06576 Mdot
.04032 .20738 Mdot
.31604 .1704 Mdot
.4981 .61723 Mdot
.49395 .61547 Mdot
.48073 .60986 Mdot
.43868 .59204 Mdot
.30689 .53659 Mdot
.95147 .39837 Mdot
.66772 .44267 Mdot
.5915 .57093 Mdot
.6451 .03313 Mdot
.88743 .14977 Mdot
.28488 .24564 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51493 .00633 Mdot
.54753 .02015 Mdot
.65037 .06356 Mdot
.94668 .18313 Mdot
.32148 .23164 Mdot
.48122 .09873 Mdot
.61287 .08136 Mdot
.89999 .17745 Mdot
.32744 .26418 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48084 .60991 Mdot
.43901 .59219 Mdot
.30793 .53702 Mdot
.95376 .39914 Mdot
.66798 .44141 Mdot
.58992 .56979 Mdot
.63967 .03075 Mdot
.87306 .14424 Mdot
.2773 .24984 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00123 Mdot
.50927 .00393 Mdot
.52952 .01252 Mdot
.59381 .03973 Mdot
.79081 .12175 Mdot
.21873 .26447 Mdot
.41252 .11977 Mdot
.48158 .04269 Mdot
.52309 .02565 Mdot
.59911 .04698 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48304 .61084 Mdot
.44603 .59516 Mdot
.32959 .54607 Mdot
.00366 .4166 Mdot
.67224 .4132 Mdot
.55162 .54349 Mdot
.50707 .5905 Mdot
.47312 .59705 Mdot
.39904 .57225 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51435 .00608 Mdot
.54568 .01937 Mdot
.6446 .06113 Mdot
.93178 .17749 Mdot
.31819 .23881 Mdot
.48744 .1046 Mdot
.63787 .09297 Mdot
.97019 .20539 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50315 .00134 Mdot
.51003 .00425 Mdot
.53196 .01355 Mdot
.60149 .04298 Mdot
.81315 .13081 Mdot
.245 .2669 Mdot
.43823 .11942 Mdot
.54111 .06359 Mdot
.70499 .10128 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.4872 .61261 Mdot
.45923 .60075 Mdot
.37077 .56337 Mdot
.10909 .4563 Mdot
.69628 .36291 Mdot
.50874 .50213 Mdot
.33431 .51023 Mdot
.95388 .38291 Mdot
.64166 .42507 Mdot
.49764 .61703 Mdot
.49249 .61485 Mdot
.47609 .60789 Mdot
.42394 .58581 Mdot
.26201 .51795 Mdot
.86202 .37083 Mdot
.64403 .48331 Mdot
.61378 .59934 Mdot
.74004 .07803 Mdot
.10457 .22529 Mdot
.32328 .13517 Mdot
.49923 .61771 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47497 .60742 Mdot
.42041 .58431 Mdot
.25137 .51356 Mdot
.84361 .36602 Mdot
.63446 .48878 Mdot
.60386 .59912 Mdot
.71823 .07068 Mdot
.06659 .2153 Mdot
.4987 .61748 Mdot
.49586 .61628 Mdot
.48682 .61244 Mdot
.45802 .60024 Mdot
.36699 .56177 Mdot
.09888 .45233 Mdot
.6918 .36645 Mdot
.50768 .50424 Mdot
.33507 .51136 Mdot
.95704 .38439 Mdot
.64266 .42374 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53634 .01541 Mdot
.61532 .04881 Mdot
.85252 .1466 Mdot
.28062 .26458 Mdot
.47439 .11976 Mdot
.6299 .09611 Mdot
.95934 .2036 Mdot
.34911 .24089 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51797 .00762 Mdot
.55721 .02425 Mdot
.68042 .07615 Mdot
.01991 .20982 Mdot
.32961 .1914 Mdot
.42983 .06194 Mdot
.42817 .61701 Mdot
.32239 .55266 Mdot
.00214 .42011 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.4766 .60811 Mdot
.42558 .5865 Mdot
.26694 .51999 Mdot
.87092 .37328 Mdot
.64798 .48025 Mdot
.61639 .59851 Mdot
.74423 .07901 Mdot
.11064 .22646 Mdot
.32414 .13195 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49338 .61523 Mdot
.4789 .60909 Mdot
.43288 .58959 Mdot
.28913 .52919 Mdot
.91383 .38609 Mdot
.66156 .46212 Mdot
.61211 .58747 Mdot
.71724 .06498 Mdot
.05608 .20941 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.52609 .01106 Mdot
.58294 .03514 Mdot
.75864 .10859 Mdot
.17273 .25592 Mdot
.37567 .12543 Mdot
.41051 .02153 Mdot
.31809 .56091 Mdot
.00845 .42667 Mdot
.68614 .41884 Mdot
.5006 .00025 Mdot
.5019 .0008 Mdot
.50604 .00256 Mdot
.51924 .00816 Mdot
.56124 .02596 Mdot
.69286 .08134 Mdot
.04799 .21948 Mdot
.33222 .17567 Mdot
.40887 .04737 Mdot
.35618 .58547 Mdot
.11595 .46956 Mdot
.71677 .37133 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52227 .00944 Mdot
.57084 .03002 Mdot
.72219 .09354 Mdot
.10863 .23884 Mdot
.34449 .14577 Mdot
.38247 .02347 Mdot
.25975 .54219 Mdot
.89874 .39492 Mdot
.67958 .48259 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47677 .60818 Mdot
.4261 .58672 Mdot
.26852 .52064 Mdot
.87382 .3741 Mdot
.64918 .4792 Mdot
.61695 .59811 Mdot
.74477 .079 Mdot
.1112 .22647 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.5124 .00526 Mdot
.53949 .01674 Mdot
.62521 .05298 Mdot
.87996 .15744 Mdot
.29818 .25847 Mdot
.48852 .11764 Mdot
.66165 .107 Mdot
.03767 .23239 Mdot
.35771 .1978 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51107 .00469 Mdot
.53526 .01495 Mdot
.61191 .04737 Mdot
.84293 .14278 Mdot
.27313 .26588 Mdot
.46711 .11989 Mdot
.61212 .08962 Mdot
.91173 .18517 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50597 .00253 Mdot
.51903 .00807 Mdot
.56056 .02567 Mdot
.69075 .08046 Mdot
.04332 .2179 Mdot
.33171 .17824 Mdot
.41215 .04971 Mdot
.36739 .59037 Mdot
.14596 .48118 Mdot
.73501 .36405 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52002 .00849 Mdot
.56369 .02699 Mdot
.70038 .08448 Mdot
.06429 .22491 Mdot
.33437 .16692 Mdot
.39848 .03962 Mdot
.32042 .56979 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.5357 .01514 Mdot
.61331 .04796 Mdot
.84687 .14435 Mdot
.2763 .2654 Mdot
.47024 .11986 Mdot
.6198 .09243 Mdot
.93256 .1933 Mdot
.34348 .25396 Mdot
.49961 .61787 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.4875 .61273 Mdot
.4602 .60116 Mdot
.37382 .56465 Mdot
.11738 .45955 Mdot
.70041 .36033 Mdot
.51066 .50077 Mdot
.33691 .51065 Mdot
.95913 .38456 Mdot
.49778 .61709 Mdot
.49292 .61503 Mdot
.47744 .60847 Mdot
.42822 .58762 Mdot
.27495 .52331 Mdot
.88587 .37757 Mdot
.65369 .47454 Mdot
.61784 .59588 Mdot
.74305 .07738 Mdot
.10675 .22478 Mdot
.32207 .13307 Mdot
.49946 .6178 Mdot
.49826 .6173 Mdot
.49447 .61569 Mdot
.48238 .61056 Mdot
.4439 .59426 Mdot
.32301 .54332 Mdot
.98807 .41103 Mdot
.67101 .42208 Mdot
.56387 .55182 Mdot
.55 .60946 Mdot
.60989 .03701 Mdot
.49756 .617 Mdot
.49224 .61474 Mdot
.47528 .60755 Mdot
.42138 .58472 Mdot
.25429 .51477 Mdot
.84856 .36728 Mdot
.63723 .48742 Mdot
.60716 .59945 Mdot
.72596 .07342 Mdot
.08078 .21929 Mdot
.31956 .14758 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61225 Mdot
.45658 .59963 Mdot
.36248 .55988 Mdot
.08682 .44767 Mdot
.6873 .37111 Mdot
.50821 .50735 Mdot
.34144 .51496 Mdot
.97426 .39111 Mdot
.64552 .41486 Mdot
.49996 .61802 Mdot
.49987 .61798 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49592 .6163 Mdot
.48701 .61252 Mdot
.45863 .60049 Mdot
.36888 .56257 Mdot
.10396 .45431 Mdot
.69396 .36464 Mdot
.50803 .50313 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50565 .00239 Mdot
.51799 .00763 Mdot
.55725 .02427 Mdot
.68055 .0762 Mdot
.02021 .20992 Mdot
.32964 .19124 Mdot
.4296 .06178 Mdot
.42737 .61666 Mdot
.31995 .55164 Mdot
.99649 .41812 Mdot
.50046 .00019 Mdot
.50145 .00062 Mdot
.50463 .00196 Mdot
.51474 .00625 Mdot
.54695 .0199 Mdot
.64855 .06279 Mdot
.942 .18136 Mdot
.32054 .23395 Mdot
.48341 .10066 Mdot
.62145 .08531 Mdot
.9245 .18729 Mdot
.3366 .25469 Mdot
.49839 .61735 Mdot
.49486 .61585 Mdot
.48361 .61109 Mdot
.44784 .59592 Mdot
.33521 .54843 Mdot
.01726 .42153 Mdot
.67347 .40556 Mdot
.54134 .53637 Mdot
.47051 .57426 Mdot
.35571 .54708 Mdot
.05291 .4309 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.48079 .60989 Mdot
.43886 .59212 Mdot
.30746 .53682 Mdot
.95272 .39879 Mdot
.66786 .44198 Mdot
.59064 .57031 Mdot
.64215 .03183 Mdot
.87963 .14678 Mdot
.28095 .24802 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51434 .00608 Mdot
.54566 .01936 Mdot
.64455 .06111 Mdot
.93164 .17744 Mdot
.31815 .23888 Mdot
.48749 .10465 Mdot
.63807 .09306 Mdot
.97073 .2056 Mdot
.4977 .61706 Mdot
.49268 .61493 Mdot
.47667 .60814 Mdot
.42579 .58659 Mdot
.26758 .52026 Mdot
.87209 .37361 Mdot
.64847 .47983 Mdot
.61663 .59836 Mdot
.74449 .07902 Mdot
.11095 .22648 Mdot
.32413 .13176 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.4755 .60764 Mdot
.42207 .58502 Mdot
.25637 .51562 Mdot
.85213 .3682 Mdot
.63913 .48639 Mdot
.60925 .59956 Mdot
.73066 .07504 Mdot
.08905 .2215 Mdot
.49779 .61709 Mdot
.49294 .61504 Mdot
.47752 .6085 Mdot
.4285 .58773 Mdot
.27579 .52366 Mdot
.88748 .37804 Mdot
.65424 .47388 Mdot
.6178 .59551 Mdot
.74235 .07698 Mdot
.10537 .22436 Mdot
.32163 .13365 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48446 .61144 Mdot
.45051 .59705 Mdot
.34352 .55191 Mdot
.03783 .42911 Mdot
.67593 .39437 Mdot
.52737 .52622 Mdot
.41968 .55147 Mdot
.19655 .48013 Mdot
.74802 .34083 Mdot
.49776 .61708 Mdot
.49286 .615 Mdot
.47725 .60839 Mdot
.42762 .58736 Mdot
.27312 .52255 Mdot
.8824 .37656 Mdot
.65246 .47592 Mdot
.61781 .59662 Mdot
.74418 .0781 Mdot
.10912 .22555 Mdot
.32291 .13213 Mdot
.49997 .61802 Mdot
.49992 .618 Mdot
.49973 .61792 Mdot
.49914 .61767 Mdot
.49726 .61687 Mdot
.49128 .61434 Mdot
.47223 .60626 Mdot
.41173 .58064 Mdot
.2255 .50294 Mdot
.80337 .35714 Mdot
.60667 .49647 Mdot
.49822 .61728 Mdot
.49432 .61563 Mdot
.48192 .61037 Mdot
.44245 .59364 Mdot
.31854 .54145 Mdot
.97768 .40737 Mdot
.67019 .428 Mdot
.57205 .55738 Mdot
.57833 .00388 Mdot
.69743 .07361 Mdot
.04236 .21317 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50578 .00245 Mdot
.51841 .00781 Mdot
.55861 .02484 Mdot
.68475 .07796 Mdot
.02983 .21327 Mdot
.33043 .18578 Mdot
.42214 .05668 Mdot
.40165 .60537 Mdot
.24285 .51989 Mdot
.84556 .37249 Mdot
.49916 .61768 Mdot
.49734 .6169 Mdot
.49151 .61443 Mdot
.47296 .60657 Mdot
.41403 .58162 Mdot
.23233 .50574 Mdot
.81337 .3591 Mdot
.61447 .4951 Mdot
.57284 .59231 Mdot
.6367 .03947 Mdot
.88131 .15118 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.5072 .00305 Mdot
.52292 .00972 Mdot
.57291 .03089 Mdot
.72848 .09615 Mdot
.1206 .24234 Mdot
.34864 .14094 Mdot
.38236 .02084 Mdot
.25525 .53947 Mdot
.88953 .39201 Mdot
.67653 .48639 Mdot
.49897 .6176 Mdot
.49672 .61664 Mdot
.48956 .61361 Mdot
.46674 .60393 Mdot
.3944 .57332 Mdot
.17502 .48245 Mdot
.74291 .35098 Mdot
.54931 .49838 Mdot
.42848 .54336 Mdot
.20395 .47927 Mdot
.75061 .33786 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48978 .6137 Mdot
.46743 .60423 Mdot
.39659 .57425 Mdot
.1813 .48498 Mdot
.74918 .35097 Mdot
.55579 .49851 Mdot
.44439 .54918 Mdot
.25126 .49867 Mdot
.8194 .35113 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50697 .00296 Mdot
.5222 .00941 Mdot
.57062 .02993 Mdot
.72154 .09327 Mdot
.10737 .23846 Mdot
.34409 .1463 Mdot
.3826 .0238 Mdot
.26056 .5426 Mdot
.9003 .39538 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50576 .00244 Mdot
.51836 .00778 Mdot
.55843 .02476 Mdot
.68418 .07772 Mdot
.02855 .21283 Mdot
.33032 .18651 Mdot
.49857 .61743 Mdot
.49544 .6161 Mdot
.48546 .61187 Mdot
.45369 .5984 Mdot
.35345 .55608 Mdot
.06315 .43862 Mdot
.68059 .3816 Mdot
.51442 .51534 Mdot
.36986 .52869 Mdot
.05112 .42104 Mdot
.65701 .37446 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.5069 .00292 Mdot
.52197 .00932 Mdot
.56991 .02962 Mdot
.71936 .09237 Mdot
.10313 .23718 Mdot
.34281 .14813 Mdot
.38321 .02497 Mdot
.26372 .54419 Mdot
.90639 .39719 Mdot
.68152 .47905 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50503 .00213 Mdot
.51601 .00679 Mdot
.55098 .02161 Mdot
.66113 .06807 Mdot
.97374 .19321 Mdot
.32556 .21744 Mdot
.46506 .08621 Mdot
.55256 .05408 Mdot
.71749 .10193 Mdot
.49873 .6175 Mdot
.49597 .61632 Mdot
.48714 .61258 Mdot
.45906 .60068 Mdot
.37025 .56314 Mdot
.10766 .45575 Mdot
.69562 .36338 Mdot
.50851 .50239 Mdot
.33416 .51028 Mdot
.95368 .38289 Mdot
.64171 .42522 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51253 .00531 Mdot
.53989 .01691 Mdot
.62647 .05351 Mdot
.88341 .1588 Mdot
.30001 .25747 Mdot
.48956 .11715 Mdot
.66347 .10748 Mdot
.04168 .23375 Mdot
.35808 .19555 Mdot
.49777 .61709 Mdot
.49288 .61502 Mdot
.47732 .60842 Mdot
.42786 .58747 Mdot
.27387 .52286 Mdot
.88382 .37697 Mdot
.65297 .47536 Mdot
.61785 .59633 Mdot
.74378 .07783 Mdot
.10826 .22526 Mdot
.32259 .13246 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00226 Mdot
.51695 .00719 Mdot
.55396 .02287 Mdot
.67035 .07194 Mdot
.99621 .20139 Mdot
.32775 .2049 Mdot
.44849 .07462 Mdot
.49329 .02769 Mdot
.52804 .02147 Mdot
.60462 .04733 Mdot
.49772 .61707 Mdot
.49274 .61495 Mdot
.47687 .60822 Mdot
.42641 .58685 Mdot
.26947 .52104 Mdot
.87558 .3746 Mdot
.64988 .47855 Mdot
.61722 .59785 Mdot
.74492 .07892 Mdot
.11122 .22639 Mdot
.32395 .13147 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50507 .00215 Mdot
.51616 .00685 Mdot
.55144 .0218 Mdot
.66254 .06866 Mdot
.97721 .19448 Mdot
.32596 .21553 Mdot
.46264 .08448 Mdot
.54379 .05016 Mdot
.68981 .09025 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.49949 .61782 Mdot
.49837 .61734 Mdot
.49479 .61583 Mdot
.48341 .611 Mdot
.4472 .59565 Mdot
.33324 .5476 Mdot
.01246 .41978 Mdot
.67301 .40824 Mdot
.5449 .53886 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50427 .00181 Mdot
.51362 .00577 Mdot
.54336 .01838 Mdot
.63734 .05808 Mdot
.9127 .17018 Mdot
.31254 .24711 Mdot
.49184 .11082 Mdot
.65892 .10326 Mdot
.02669 .2273 Mdot
.35461 .20267 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50352 .00149 Mdot
.51122 .00476 Mdot
.53574 .01515 Mdot
.61343 .04801 Mdot
.84721 .14449 Mdot
.27657 .26535 Mdot
.4705 .11986 Mdot
.62044 .09267 Mdot
.93429 .19397 Mdot
.34393 .25317 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50896 .0038 Mdot
.52854 .0121 Mdot
.5907 .03842 Mdot
.78166 .11802 Mdot
.20664 .26266 Mdot
.4017 .12055 Mdot
.45851 .03511 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48836 .6131 Mdot
.46294 .60232 Mdot
.38243 .56828 Mdot
.14118 .46893 Mdot
.71486 .35455 Mdot
.52147 .49851 Mdot
.3602 .51836 Mdot
.01517 .40479 Mdot
.64742 .39075 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50971 .00412 Mdot
.53092 .01311 Mdot
.59821 .04159 Mdot
.80365 .12697 Mdot
.23439 .26621 Mdot
.42754 .11937 Mdot
.51571 .05449 Mdot
.62741 .06903 Mdot
.91045 .17493 Mdot
.4985 .6174 Mdot
.49524 .61601 Mdot
.48482 .6116 Mdot
.45168 .59755 Mdot
.34717 .55344 Mdot
.04706 .43256 Mdot
.67738 .38956 Mdot
.52201 .52201 Mdot
.39956 .54235 Mdot
.13625 .4553 Mdot
.69263 .34386 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61477 Mdot
.47546 .60763 Mdot
.42194 .58496 Mdot
.25599 .51547 Mdot
.85147 .36803 Mdot
.63878 .48659 Mdot
.60888 .59955 Mdot
.72984 .07476 Mdot
.08763 .22112 Mdot
.49967 .61789 Mdot
.49894 .61758 Mdot
.49662 .6166 Mdot
.48922 .61346 Mdot
.46566 .60348 Mdot
.391 .57189 Mdot
.16533 .47856 Mdot
.73392 .35141 Mdot
.54003 .4982 Mdot
.40554 .53492 Mdot
.13753 .4524 Mdot
.49917 .61768 Mdot
.49734 .61691 Mdot
.49153 .61444 Mdot
.47301 .60659 Mdot
.4142 .58169 Mdot
.23284 .50595 Mdot
.81414 .35926 Mdot
.61504 .49498 Mdot
.57386 .59259 Mdot
.63955 .0406 Mdot
.88875 .15401 Mdot
.49887 .61756 Mdot
.49641 .61651 Mdot
.48857 .61319 Mdot
.46359 .6026 Mdot
.38448 .56914 Mdot
.14689 .4712 Mdot
.71895 .35355 Mdot
.52521 .4983 Mdot
.36912 .52157 Mdot
.0381 .41345 Mdot
.65048 .37847 Mdot
.49764 .61703 Mdot
.49249 .61485 Mdot
.47607 .60789 Mdot
.4239 .58579 Mdot
.26188 .5179 Mdot
.86179 .37076 Mdot
.64392 .48339 Mdot
.6137 .59936 Mdot
.73989 .07799 Mdot
.10432 .22523 Mdot
.32324 .1353 Mdot
.49805 .61721 Mdot
.49378 .61539 Mdot
.48017 .60963 Mdot
.43691 .59129 Mdot
.30147 .53433 Mdot
.93966 .39443 Mdot
.66621 .44903 Mdot
.59917 .5766 Mdot
.67145 .04467 Mdot
.95396 .1746 Mdot
.30457 .21669 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50352 .00149 Mdot
.51123 .00476 Mdot
.53576 .01516 Mdot
.61348 .04803 Mdot
.84735 .14454 Mdot
.27667 .26534 Mdot
.47061 .11986 Mdot
.6207 .09276 Mdot
.93498 .19424 Mdot
.3441 .25285 Mdot
.50047 .0002 Mdot
.50148 .00063 Mdot
.50473 .002 Mdot
.51506 .00639 Mdot
.54794 .02032 Mdot
.65166 .0641 Mdot
.94997 .18436 Mdot
.32209 .22999 Mdot
.47957 .09732 Mdot
.60647 .07843 Mdot
.88144 .16994 Mdot
.31825 .26996 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51728 .00733 Mdot
.55501 .02332 Mdot
.6736 .0733 Mdot
.00396 .20417 Mdot
.32838 .2005 Mdot
.44243 .07049 Mdot
.47199 .01827 Mdot
.45974 .61047 Mdot
.38774 .57354 Mdot
.49851 .6174 Mdot
.49525 .61602 Mdot
.48486 .61162 Mdot
.45181 .59761 Mdot
.34758 .55361 Mdot
.04809 .43294 Mdot
.67756 .38904 Mdot
.52146 .52156 Mdot
.39745 .54139 Mdot
.13005 .45277 Mdot
.68857 .34518 Mdot
.49798 .61718 Mdot
.49358 .61531 Mdot
.47953 .60936 Mdot
.43488 .59044 Mdot
.29524 .53174 Mdot
.92646 .39011 Mdot
.6641 .45589 Mdot
.60654 .58246 Mdot
.69712 .05598 Mdot
.01338 .19546 Mdot
.30959 .18307 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51264 .00536 Mdot
.54026 .01707 Mdot
.62762 .05399 Mdot
.88655 .16002 Mdot
.3016 .25652 Mdot
.49036 .11666 Mdot
.66468 .10773 Mdot
.49784 .61712 Mdot
.49312 .61512 Mdot
.47809 .60874 Mdot
.43029 .58849 Mdot
.28124 .52592 Mdot
.89804 .3812 Mdot
.65753 .46939 Mdot
.61658 .59273 Mdot
.73529 .07336 Mdot
.0917 .22028 Mdot
.31805 .13989 Mdot
.49812 .61724 Mdot
.494 .61549 Mdot
.48088 .60993 Mdot
.43914 .59224 Mdot
.30833 .53719 Mdot
.95464 .39944 Mdot
.66807 .44093 Mdot
.5893 .56935 Mdot
.63756 .02983 Mdot
.86741 .14205 Mdot
.27392 .25124 Mdot
.49894 .61758 Mdot
.49663 .6166 Mdot
.48925 .61348 Mdot
.46576 .60352 Mdot
.39131 .57202 Mdot
.16621 .47891 Mdot
.73471 .35135 Mdot
.54083 .49821 Mdot
.40753 .53565 Mdot
.1432 .45467 Mdot
.6919 .33912 Mdot
.49977 .61794 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.49272 .61495 Mdot
.47681 .6082 Mdot
.42622 .58677 Mdot
.2689 .5208 Mdot
.87452 .3743 Mdot
.64946 .47894 Mdot
.61706 .59801 Mdot
.74485 .07898 Mdot
.49997 .61802 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49899 .61761 Mdot
.49678 .61667 Mdot
.48974 .61368 Mdot
.46733 .60418 Mdot
.39626 .57411 Mdot
.18037 .48461 Mdot
.74823 .35096 Mdot
.55481 .49849 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50806 .00342 Mdot
.52567 .01088 Mdot
.58161 .03458 Mdot
.75468 .10696 Mdot
.16637 .25444 Mdot
.37154 .1268 Mdot
.40427 .02023 Mdot
.30191 .55477 Mdot
.97339 .415 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .00991 Mdot
.57432 .03149 Mdot
.73273 .09791 Mdot
.12848 .24459 Mdot
.35177 .138 Mdot
.38349 .0196 Mdot
.25563 .53901 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54191 .01777 Mdot
.6328 .05617 Mdot
.90056 .16548 Mdot
.30796 .25179 Mdot
.4923 .11392 Mdot
.66508 .10679 Mdot
.04342 .23382 Mdot
.35743 .19407 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52546 .0108 Mdot
.58097 .0343 Mdot
.75276 .10617 Mdot
.16324 .25369 Mdot
.36959 .12753 Mdot
.4015 .01972 Mdot
.29491 .55216 Mdot
.95902 .41045 Mdot
.68393 .44802 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49302 .61508 Mdot
.47778 .60861 Mdot
.42931 .58808 Mdot
.27825 .52468 Mdot
.89221 .37945 Mdot
.65578 .47191 Mdot
.61744 .59434 Mdot
.73972 .07557 Mdot
.10023 .22281 Mdot
.5006 .00025 Mdot
.5019 .0008 Mdot
.50605 .00256 Mdot
.51926 .00817 Mdot
.5613 .02598 Mdot
.69304 .08142 Mdot
.04838 .21961 Mdot
.33226 .17545 Mdot
.4086 .04718 Mdot
.35526 .58506 Mdot
.11351 .46863 Mdot
.71557 .37209 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00225 Mdot
.51694 .00718 Mdot
.55392 .02285 Mdot
.67023 .07189 Mdot
.99591 .20128 Mdot
.32773 .20507 Mdot
.44872 .07478 Mdot
.4941 .02805 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50204 .00087 Mdot
.50651 .00276 Mdot
.52072 .00879 Mdot
.56594 .02795 Mdot
.70727 .08734 Mdot
.07877 .2296 Mdot
.33688 .15952 Mdot
.39096 .03342 Mdot
.29398 .5581 Mdot
.96733 .41615 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50724 .00307 Mdot
.52307 .00978 Mdot
.57339 .0311 Mdot
.72994 .09675 Mdot
.12333 .24313 Mdot
.34969 .1399 Mdot
.38264 .02036 Mdot
.25506 .53919 Mdot
.88888 .39172 Mdot
.67616 .48657 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.5034 .00144 Mdot
.51084 .0046 Mdot
.53454 .01464 Mdot
.60964 .04641 Mdot
.8365 .1402 Mdot
.26769 .26649 Mdot
.46162 .11986 Mdot
.59854 .08462 Mdot
.49866 .61747 Mdot
.49574 .61623 Mdot
.48643 .61228 Mdot
.4568 .59972 Mdot
.36315 .56016 Mdot
.08859 .44835 Mdot
.68791 .3704 Mdot
.50802 .50685 Mdot
.34014 .51428 Mdot
.97082 .38978 Mdot
.64502 .41668 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50377 .0016 Mdot
.512 .00509 Mdot
.53823 .01621 Mdot
.62125 .05131 Mdot
.86906 .15316 Mdot
.29186 .2613 Mdot
.48414 .11883 Mdot
.65266 .10415 Mdot
.01663 .22495 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51624 .00688 Mdot
.55169 .02191 Mdot
.66331 .06899 Mdot
.97911 .19518 Mdot
.32616 .21449 Mdot
.46129 .08351 Mdot
.53892 .04798 Mdot
.67434 .0837 Mdot
.02202 .21488 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.50518 .0022 Mdot
.51651 .007 Mdot
.55255 .02228 Mdot
.666 .07012 Mdot
.98571 .19759 Mdot
.32682 .21082 Mdot
.45647 .08013 Mdot
.52165 .04028 Mdot
.6192 .06029 Mdot
.87929 .16075 Mdot
.49981 .61795 Mdot
.49939 .61777 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48013 .60961 Mdot
.43676 .59123 Mdot
.301 .53413 Mdot
.93866 .3941 Mdot
.66607 .44956 Mdot
.59978 .57706 Mdot
.67355 .04559 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54189 .01776 Mdot
.63274 .05615 Mdot
.90041 .16543 Mdot
.3079 .25184 Mdot
.49229 .11396 Mdot
.66512 .10681 Mdot
.04353 .23387 Mdot
.35745 .19402 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.5047 .00199 Mdot
.51498 .00635 Mdot
.54771 .02022 Mdot
.65093 .06379 Mdot
.9481 .18366 Mdot
.32175 .23093 Mdot
.48052 .09812 Mdot
.61014 .08011 Mdot
.89209 .17425 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50324 .00137 Mdot
.51031 .00437 Mdot
.53283 .01392 Mdot
.60426 .04414 Mdot
.82113 .13403 Mdot
.25328 .26709 Mdot
.44675 .11957 Mdot
.56184 .07113 Mdot
.76736 .12702 Mdot
.2102 .27369 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00312 Mdot
.52346 .00995 Mdot
.57462 .03162 Mdot
.73367 .09829 Mdot
.13019 .24506 Mdot
.35249 .13739 Mdot
.38386 .01939 Mdot
.25608 .53906 Mdot
.88975 .39163 Mdot
.67588 .48585 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58508 .03604 Mdot
.76502 .11121 Mdot
.18263 .2581 Mdot
.38258 .12358 Mdot
.42194 .02433 Mdot
.34886 .57287 Mdot
.08163 .45288 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49716 .61683 Mdot
.49095 .61419 Mdot
.47116 .60581 Mdot
.40836 .57922 Mdot
.21556 .49888 Mdot
.78959 .35477 Mdot
.59501 .49778 Mdot
.53464 .58072 Mdot
.52581 .61258 Mdot
.49945 .6178 Mdot
.49824 .61729 Mdot
.49439 .61565 Mdot
.48212 .61045 Mdot
.4431 .59392 Mdot
.32055 .54229 Mdot
.98233 .409 Mdot
.67056 .42535 Mdot
.56841 .5549 Mdot
.56573 .61638 Mdot
.65887 .05756 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49068 .61408 Mdot
.47031 .60545 Mdot
.40567 .57808 Mdot
.20768 .49567 Mdot
.77934 .35331 Mdot
.58569 .49835 Mdot
.51447 .57401 Mdot
.49823 .61728 Mdot
.49437 .61564 Mdot
.48205 .61042 Mdot
.44287 .59382 Mdot
.31982 .54199 Mdot
.98064 .40841 Mdot
.67043 .42631 Mdot
.56973 .5558 Mdot
.57031 .00036 Mdot
.67296 .06344 Mdot
.98692 .19404 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50495 .0021 Mdot
.51577 .00669 Mdot
.5502 .02128 Mdot
.6587 .06706 Mdot
.96772 .19098 Mdot
.32483 .22071 Mdot
.4691 .08917 Mdot
.56733 .06071 Mdot
.76356 .12128 Mdot
.19766 .26829 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51875 .00795 Mdot
.55969 .0253 Mdot
.68807 .07935 Mdot
.03735 .21586 Mdot
.33111 .18156 Mdot
.41648 .05276 Mdot
.38225 .59688 Mdot
.18708 .49741 Mdot
.77159 .36125 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50395 .00168 Mdot
.51259 .00534 Mdot
.54009 .017 Mdot
.6271 .05377 Mdot
.88513 .15947 Mdot
.30089 .25695 Mdot
.49002 .11689 Mdot
.66418 .10764 Mdot
.04321 .23425 Mdot
.35821 .19468 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44668 .59543 Mdot
.33162 .54692 Mdot
.00853 .41836 Mdot
.67265 .41045 Mdot
.54787 .54091 Mdot
.49382 .58463 Mdot
.43049 .5789 Mdot
.26618 .51648 Mdot
.49961 .61787 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.4875 .61273 Mdot
.46019 .60116 Mdot
.37379 .56464 Mdot
.11731 .45952 Mdot
.70037 .36035 Mdot
.51064 .50078 Mdot
.33687 .51064 Mdot
.95905 .38453 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50821 .00348 Mdot
.52616 .01109 Mdot
.58316 .03523 Mdot
.7593 .10886 Mdot
.17376 .25615 Mdot
.37636 .12522 Mdot
.41161 .02178 Mdot
.32097 .56202 Mdot
.01496 .4289 Mdot
.68654 .41506 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48425 .61136 Mdot
.44987 .59678 Mdot
.34152 .55107 Mdot
.03284 .42726 Mdot
.67525 .39703 Mdot
.53054 .5286 Mdot
.43135 .55673 Mdot
.23235 .49505 Mdot
.79609 .34841 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50341 .00145 Mdot
.51087 .00461 Mdot
.53463 .01468 Mdot
.60993 .04654 Mdot
.83732 .14054 Mdot
.26841 .26642 Mdot
.46235 .11987 Mdot
.60035 .08529 Mdot
.8791 .17227 Mdot
.49997 .61802 Mdot
.4999 .61799 Mdot
.49967 .61789 Mdot
.49894 .61759 Mdot
.49663 .61661 Mdot
.48928 .61349 Mdot
.46585 .60355 Mdot
.39159 .57214 Mdot
.167 .47923 Mdot
.73541 .3513 Mdot
.54155 .49822 Mdot
.49984 .61797 Mdot
.49951 .61782 Mdot
.49842 .61737 Mdot
.49498 .6159 Mdot
.484 .61125 Mdot
.44905 .59644 Mdot
.33899 .55001 Mdot
.02655 .42493 Mdot
.67447 .40044 Mdot
.53474 .53168 Mdot
.44671 .56363 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52449 .01038 Mdot
.57787 .03299 Mdot
.74345 .10233 Mdot
.14756 .24975 Mdot
.3607 .13173 Mdot
.39058 .01846 Mdot
.26896 .54287 Mdot
.91029 .39637 Mdot
.67918 .4752 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52631 .01116 Mdot
.58364 .03543 Mdot
.76074 .10945 Mdot
.17603 .25666 Mdot
.37791 .12477 Mdot
.41409 .02236 Mdot
.32759 .56457 Mdot
.03015 .43421 Mdot
.68776 .40642 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53217 .01364 Mdot
.60218 .04326 Mdot
.81513 .13161 Mdot
.24711 .26697 Mdot
.44039 .11945 Mdot
.54633 .06548 Mdot
.7208 .10783 Mdot
.12999 .25289 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50269 .00114 Mdot
.50858 .00364 Mdot
.52734 .01159 Mdot
.58691 .03681 Mdot
.77045 .11344 Mdot
.19076 .25976 Mdot
.38868 .12232 Mdot
.43291 .02734 Mdot
.37947 .585 Mdot
.16203 .48365 Mdot
.49998 .61802 Mdot
.49993 .618 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49775 .61708 Mdot
.49284 .615 Mdot
.47719 .60836 Mdot
.42744 .58729 Mdot
.27259 .52233 Mdot
.8814 .37627 Mdot
.6521 .47632 Mdot
.49867 .61747 Mdot
.49576 .61624 Mdot
.48649 .61231 Mdot
.45698 .5998 Mdot
.36372 .5604 Mdot
.09013 .44894 Mdot
.68845 .36979 Mdot
.50788 .50643 Mdot
.33912 .51374 Mdot
.96809 .38872 Mdot
.6446 .41811 Mdot
.4979 .61715 Mdot
.49332 .6152 Mdot
.47873 .60902 Mdot
.43233 .58936 Mdot
.28746 .5285 Mdot
.91044 .38502 Mdot
.66078 .46374 Mdot
.61331 .5887 Mdot
.72182 .06706 Mdot
.06533 .2123 Mdot
.31357 .15342 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50783 .00332 Mdot
.52494 .01057 Mdot
.5793 .0336 Mdot
.74776 .10411 Mdot
.15493 .25164 Mdot
.36471 .12965 Mdot
.39512 .01879 Mdot
.27934 .54648 Mdot
.92888 .40144 Mdot
.68158 .4652 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00126 Mdot
.5095 .00403 Mdot
.53026 .01283 Mdot
.59614 .04072 Mdot
.79763 .12452 Mdot
.22724 .26551 Mdot
.42055 .11947 Mdot
.49957 .04884 Mdot
.57796 .04844 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51516 .00643 Mdot
.54826 .02046 Mdot
.65263 .06451 Mdot
.95245 .18529 Mdot
.32253 .22873 Mdot
.47825 .09624 Mdot
.60145 .07614 Mdot
.86674 .16395 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50824 .00349 Mdot
.52625 .01113 Mdot
.58345 .03535 Mdot
.76016 .10921 Mdot
.17512 .25646 Mdot
.37728 .12495 Mdot
.41308 .02212 Mdot
.32488 .56352 Mdot
.02389 .43201 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51238 .00525 Mdot
.53942 .01671 Mdot
.62499 .05288 Mdot
.87935 .15721 Mdot
.29785 .25864 Mdot
.48832 .11772 Mdot
.66128 .1069 Mdot
.03683 .2321 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47723 .60838 Mdot
.42758 .58735 Mdot
.27302 .52251 Mdot
.88221 .3765 Mdot
.65239 .476 Mdot
.61781 .59666 Mdot
.74423 .07813 Mdot
.10923 .22558 Mdot
.32295 .13208 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49604 .61635 Mdot
.48738 .61268 Mdot
.45981 .60099 Mdot
.37259 .56413 Mdot
.11402 .45823 Mdot
.69868 .36134 Mdot
.50977 .50128 Mdot
.33551 .51033 Mdot
.95615 .38358 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50601 .00255 Mdot
.51914 .00811 Mdot
.5609 .02581 Mdot
.69181 .0809 Mdot
.04567 .2187 Mdot
.33196 .17694 Mdot
.41049 .04853 Mdot
.36171 .58789 Mdot
.13063 .47522 Mdot
.72488 .36726 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.5037 .00157 Mdot
.5118 .005 Mdot
.53757 .01593 Mdot
.61918 .05044 Mdot
.86332 .15089 Mdot
.28819 .26258 Mdot
.48117 .11927 Mdot
.64597 .10185 Mdot
.00029 .21898 Mdot
.35418 .21872 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.49131 .61435 Mdot
.47232 .6063 Mdot
.41202 .58076 Mdot
.22636 .50329 Mdot
.8046 .35737 Mdot
.60766 .49632 Mdot
.56017 .58868 Mdot
.6008 .02511 Mdot
.78272 .11243 Mdot
.49863 .61745 Mdot
.49564 .61619 Mdot
.48612 .61215 Mdot
.45581 .5993 Mdot
.36005 .55885 Mdot
.0804 .4452 Mdot
.68521 .3738 Mdot
.50925 .50928 Mdot
.34716 .51785 Mdot
.98945 .39696 Mdot
.64756 .40673 Mdot
.49964 .61788 Mdot
.49887 .61755 Mdot
.49639 .6165 Mdot
.48851 .61316 Mdot
.4634 .60252 Mdot
.38387 .56888 Mdot
.14519 .47052 Mdot
.71771 .35383 Mdot
.52405 .49835 Mdot
.36634 .52056 Mdot
.03088 .41071 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50386 .00164 Mdot
.51231 .00522 Mdot
.53919 .01661 Mdot
.62426 .05258 Mdot
.87737 .15643 Mdot
.29675 .25919 Mdot
.48762 .11797 Mdot
.65996 .10651 Mdot
.03382 .23106 Mdot
.35734 .19994 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48039 .60972 Mdot
.4376 .59159 Mdot
.30358 .53521 Mdot
.94423 .39594 Mdot
.66683 .44659 Mdot
.59631 .57445 Mdot
.6616 .04035 Mdot
.92973 .16572 Mdot
.29988 .22876 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50938 .00398 Mdot
.52987 .01266 Mdot
.5949 .04019 Mdot
.79399 .12304 Mdot
.22275 .26499 Mdot
.41627 .1196 Mdot
.48991 .04551 Mdot
.54841 .03616 Mdot
.67842 .08035 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50734 .00311 Mdot
.52339 .00992 Mdot
.5744 .03152 Mdot
.73298 .09801 Mdot
.12892 .24471 Mdot
.35195 .13784 Mdot
.38358 .01955 Mdot
.25573 .53902 Mdot
.88931 .39157 Mdot
.67586 .48611 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48721 .61261 Mdot
.45928 .60077 Mdot
.37094 .56343 Mdot
.10953 .45648 Mdot
.69649 .36276 Mdot
.50882 .50205 Mdot
.33438 .51022 Mdot
.95398 .38293 Mdot
.64165 .42501 Mdot
.49828 .61731 Mdot
.49453 .61571 Mdot
.48257 .61064 Mdot
.44452 .59452 Mdot
.32491 .54412 Mdot
.99254 .41262 Mdot
.67135 .41953 Mdot
.56034 .54942 Mdot
.53768 .60403 Mdot
.57101 .0206 Mdot
.70736 .08427 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .0013 Mdot
.50973 .00413 Mdot
.531 .01314 Mdot
.59847 .0417 Mdot
.80439 .12727 Mdot
.23524 .26628 Mdot
.42838 .11937 Mdot
.51769 .0552 Mdot
.63348 .07156 Mdot
.92683 .1813 Mdot
.49868 .61748 Mdot
.4958 .61625 Mdot
.48662 .61236 Mdot
.4574 .59998 Mdot
.36505 .56096 Mdot
.09368 .45032 Mdot
.68976 .3684 Mdot
.50768 .5055 Mdot
.33711 .51262 Mdot
.96267 .38662 Mdot
.64372 .42091 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.51688 .00716 Mdot
.55375 .02278 Mdot
.66971 .07167 Mdot
.99465 .20083 Mdot
.32762 .20578 Mdot
.44969 .07544 Mdot
.49754 .02957 Mdot
.54169 .02729 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50946 .00401 Mdot
.53013 .01277 Mdot
.59572 .04054 Mdot
.79639 .12402 Mdot
.22572 .26534 Mdot
.41909 .11951 Mdot
.49626 .04769 Mdot
.56783 .04423 Mdot
.73808 .10522 Mdot
.49966 .61789 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48908 .6134 Mdot
.46523 .60329 Mdot
.38962 .57131 Mdot
.16141 .47699 Mdot
.73051 .35172 Mdot
.53654 .49816 Mdot
.39691 .53174 Mdot
.11324 .44272 Mdot
.49815 .61725 Mdot
.49411 .61554 Mdot
.48123 .61007 Mdot
.44025 .59271 Mdot
.31175 .53861 Mdot
.96225 .40203 Mdot
.66885 .4367 Mdot
.58381 .56548 Mdot
.61877 .0216 Mdot
.8158 .12177 Mdot
.23145 .25688 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00094 Mdot
.50703 .00298 Mdot
.52238 .00949 Mdot
.57119 .03017 Mdot
.72327 .09399 Mdot
.11073 .23946 Mdot
.34517 .14489 Mdot
.3823 .02295 Mdot
.25854 .54155 Mdot
.89639 .39421 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.47981 .60947 Mdot
.43575 .59081 Mdot
.29792 .53285 Mdot
.9321 .39194 Mdot
.66507 .453 Mdot
.60357 .58003 Mdot
.68669 .05137 Mdot
.98991 .1874 Mdot
.30825 .19674 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51848 .00784 Mdot
.55883 .02493 Mdot
.68542 .07824 Mdot
.03136 .2138 Mdot
.33056 .18492 Mdot
.42098 .05588 Mdot
.39766 .60363 Mdot
.23121 .51516 Mdot
.82768 .36864 Mdot
.49997 .61802 Mdot
.49989 .61799 Mdot
.49965 .61789 Mdot
.4989 .61757 Mdot
.49649 .61655 Mdot
.48883 .6133 Mdot
.46443 .60295 Mdot
.38712 .57025 Mdot
.15433 .47416 Mdot
.72466 .35248 Mdot
.5307 .49816 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47647 .60806 Mdot
.42517 .58633 Mdot
.26573 .51949 Mdot
.86871 .37266 Mdot
.64704 .48103 Mdot
.61587 .59877 Mdot
.74355 .07891 Mdot
.10976 .22633 Mdot
.32408 .13245 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47591 .60782 Mdot
.42339 .58557 Mdot
.26034 .51726 Mdot
.85906 .37003 Mdot
.64262 .48427 Mdot
.61261 .59949 Mdot
.73778 .07736 Mdot
.10098 .22447 Mdot
.32267 .13701 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49578 .61624 Mdot
.48655 .61233 Mdot
.45716 .59987 Mdot
.36428 .56063 Mdot
.09162 .44952 Mdot
.68899 .3692 Mdot
.50777 .50603 Mdot
.33821 .51324 Mdot
.96565 .38778 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50719 .00305 Mdot
.52289 .00971 Mdot
.57281 .03085 Mdot
.72818 .09602 Mdot
.12004 .24218 Mdot
.34843 .14116 Mdot
.38232 .02094 Mdot
.25532 .53955 Mdot
.88973 .39209 Mdot
.49915 .61767 Mdot
.49728 .61688 Mdot
.49134 .61436 Mdot
.47242 .60634 Mdot
.41234 .5809 Mdot
.22732 .50368 Mdot
.80598 .35763 Mdot
.60876 .49615 Mdot
.56228 .58931 Mdot
.60686 .02755 Mdot
.79994 .11933 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51127 .00478 Mdot
.53588 .01521 Mdot
.61386 .0482 Mdot
.84844 .14498 Mdot
.27752 .26519 Mdot
.47143 .11984 Mdot
.62272 .0935 Mdot
.94038 .19632 Mdot
.34539 .25031 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48299 .61082 Mdot
.44585 .59508 Mdot
.32904 .54584 Mdot
.00234 .41612 Mdot
.67213 .41395 Mdot
.55264 .54419 Mdot
.51068 .5921 Mdot
.48473 .60199 Mdot
.4359 .58786 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48412 .6113 Mdot
.44946 .59661 Mdot
.34024 .55054 Mdot
.02966 .42608 Mdot
.67484 .39874 Mdot
.53263 .53014 Mdot
.43902 .56018 Mdot
.25615 .50502 Mdot
.83473 .35758 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51818 .00771 Mdot
.55785 .02452 Mdot
.68241 .07698 Mdot
.02449 .21142 Mdot
.32998 .1888 Mdot
.42625 .0595 Mdot
.41582 .61159 Mdot
.28493 .53714 Mdot
.50013 6e-05 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00178 Mdot
.51341 .00569 Mdot
.5427 .0181 Mdot
.63527 .05721 Mdot
.90719 .16805 Mdot
.31057 .2493 Mdot
.49229 .11231 Mdot
.66245 .10516 Mdot
.03612 .23094 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .00121 Mdot
.50905 .00384 Mdot
.52884 .01223 Mdot
.59166 .03882 Mdot
.78448 .11917 Mdot
.21045 .26327 Mdot
.40503 .12025 Mdot
.49876 .61751 Mdot
.49604 .61636 Mdot
.4874 .61269 Mdot
.45987 .60102 Mdot
.37279 .56421 Mdot
.11457 .45844 Mdot
.69896 .36117 Mdot
.50991 .50119 Mdot
.3357 .51037 Mdot
.95655 .38371 Mdot
.64177 .42349 Mdot
.49919 .61769 Mdot
.49743 .61695 Mdot
.49182 .61457 Mdot
.47395 .60699 Mdot
.41718 .58295 Mdot
.24172 .50959 Mdot
.82784 .36225 Mdot
.62471 .49249 Mdot
.59008 .59663 Mdot
.68348 .05772 Mdot
.99505 .19256 Mdot
.4995 .61782 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48398 .61124 Mdot
.449 .59641 Mdot
.33882 .54994 Mdot
.02612 .42478 Mdot
.67442 .40067 Mdot
.53503 .53189 Mdot
.44777 .5641 Mdot
.28357 .51655 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51722 .0073 Mdot
.5548 .02323 Mdot
.67298 .07304 Mdot
.00247 .20364 Mdot
.32826 .20135 Mdot
.4436 .07129 Mdot
.4761 .02009 Mdot
.47289 .61605 Mdot
.42919 .59103 Mdot
.49745 .61695 Mdot
.49187 .61459 Mdot
.47411 .60706 Mdot
.41769 .58316 Mdot
.24323 .51021 Mdot
.83026 .3628 Mdot
.6263 .49198 Mdot
.59253 .59716 Mdot
.68985 .06015 Mdot
.00906 .19728 Mdot
.31469 .18889 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.51319 .00559 Mdot
.54201 .01781 Mdot
.63311 .0563 Mdot
.9014 .16581 Mdot
.30831 .25148 Mdot
.49233 .11373 Mdot
.66485 .10662 Mdot
.04274 .23355 Mdot
.35729 .1944 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51218 .00517 Mdot
.5388 .01645 Mdot
.62303 .05206 Mdot
.87396 .15509 Mdot
.2948 .26009 Mdot
.48631 .11836 Mdot
.65731 .10568 Mdot
.02768 .2289 Mdot
.35674 .20337 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.48081 .60989 Mdot
.43891 .59214 Mdot
.30763 .53689 Mdot
.95309 .39892 Mdot
.6679 .44178 Mdot
.59038 .57013 Mdot
.64127 .03145 Mdot
.87732 .14588 Mdot
.5006 .00026 Mdot
.50193 .00082 Mdot
.50614 .0026 Mdot
.51955 .00829 Mdot
.56221 .02637 Mdot
.69583 .08258 Mdot
.05448 .22166 Mdot
.333 .17213 Mdot
.40452 .0442 Mdot
.34125 .57893 Mdot
.07743 .45498 Mdot
.70199 .386 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.4795 .60934 Mdot
.43477 .59039 Mdot
.29492 .5316 Mdot
.92577 .38989 Mdot
.66398 .45624 Mdot
.60688 .58275 Mdot
.69833 .05652 Mdot
.01605 .19636 Mdot
.30973 .18151 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51818 .00771 Mdot
.55786 .02452 Mdot
.68242 .07699 Mdot
.02452 .21143 Mdot
.32998 .18879 Mdot
.42623 .05949 Mdot
.41576 .61156 Mdot
.28473 .53706 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50688 .00292 Mdot
.52191 .00929 Mdot
.56972 .02954 Mdot
.71879 .09213 Mdot
.10201 .23685 Mdot
.34248 .14862 Mdot
.38341 .02529 Mdot
.26467 .54465 Mdot
.49933 .61775 Mdot
.49787 .61713 Mdot
.49323 .61516 Mdot
.47842 .60888 Mdot
.43135 .58894 Mdot
.28447 .52726 Mdot
.90443 .38316 Mdot
.65929 .46652 Mdot
.61513 .59075 Mdot
.729 .07038 Mdot
.07953 .21664 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47636 .60801 Mdot
.42482 .58618 Mdot
.26465 .51904 Mdot
.86675 .37212 Mdot
.64619 .48172 Mdot
.61534 .59897 Mdot
.74275 .07874 Mdot
.10865 .22614 Mdot
.32394 .13306 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50997 .00423 Mdot
.53176 .01346 Mdot
.60086 .04271 Mdot
.81133 .13008 Mdot
.24302 .2668 Mdot
.43621 .1194 Mdot
.53627 .06184 Mdot
.69026 .09517 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.47972 .60943 Mdot
.43545 .59068 Mdot
.297 .53247 Mdot
.93015 .39131 Mdot
.66474 .454 Mdot
.60463 .58088 Mdot
.69039 .053 Mdot
.99834 .19032 Mdot
.30878 .19186 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50399 .00169 Mdot
.51271 .00539 Mdot
.54048 .01716 Mdot
.6283 .05428 Mdot
.88841 .16075 Mdot
.30252 .25593 Mdot
.49078 .11635 Mdot
.66521 .1078 Mdot
.04528 .2349 Mdot
.35835 .19348 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00156 Mdot
.51168 .00495 Mdot
.53721 .01578 Mdot
.61805 .04996 Mdot
.86018 .14964 Mdot
.28608 .26322 Mdot
.47935 .11945 Mdot
.64175 .10037 Mdot
.98975 .21508 Mdot
.35312 .22457 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51853 .00786 Mdot
.55898 .025 Mdot
.68588 .07843 Mdot
.03239 .21416 Mdot
.33065 .18434 Mdot
.42019 .05534 Mdot
.39496 .60244 Mdot
.22337 .51198 Mdot
.81638 .3665 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50734 .00311 Mdot
.52339 .00992 Mdot
.5744 .03152 Mdot
.73298 .09801 Mdot
.12893 .24471 Mdot
.35196 .13784 Mdot
.38358 .01954 Mdot
.25574 .53902 Mdot
.88932 .39157 Mdot
.67586 .48611 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50611 .00259 Mdot
.51947 .00826 Mdot
.56196 .02626 Mdot
.69507 .08226 Mdot
.05283 .22111 Mdot
.33279 .17303 Mdot
.4056 .045 Mdot
.34498 .58057 Mdot
.49796 .61717 Mdot
.49351 .61528 Mdot
.47931 .60926 Mdot
.43418 .59014 Mdot
.2931 .53084 Mdot
.92198 .38867 Mdot
.66326 .45814 Mdot
.6087 .58431 Mdot
.70479 .05939 Mdot
.03005 .20102 Mdot
.3105 .17333 Mdot
.49878 .61752 Mdot
.49613 .61639 Mdot
.48765 .6128 Mdot
.46068 .60137 Mdot
.37534 .56529 Mdot
.12154 .46118 Mdot
.70264 .35914 Mdot
.51199 .5002 Mdot
.33929 .5113 Mdot
.96447 .38638 Mdot
.6425 .41905 Mdot
.49965 .61789 Mdot
.49888 .61756 Mdot
.49645 .61653 Mdot
.48867 .61323 Mdot
.46393 .60274 Mdot
.38553 .56958 Mdot
.14987 .47238 Mdot
.72118 .35309 Mdot
.52732 .49822 Mdot
.37424 .52342 Mdot
.05154 .41859 Mdot
.4988 .61753 Mdot
.49619 .61642 Mdot
.48785 .61288 Mdot
.46131 .60163 Mdot
.3773 .56611 Mdot
.12693 .4633 Mdot
.70572 .35771 Mdot
.51406 .49958 Mdot
.34347 .5126 Mdot
.97413 .38977 Mdot
.64343 .41365 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51416 .006 Mdot
.54508 .01911 Mdot
.64271 .06034 Mdot
.92685 .17561 Mdot
.31689 .24106 Mdot
.48899 .10636 Mdot
.64457 .09616 Mdot
.98839 .21249 Mdot
.34961 .22325 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50607 .00258 Mdot
.51935 .0082 Mdot
.56158 .0261 Mdot
.69389 .08177 Mdot
.05024 .22024 Mdot
.33248 .17443 Mdot
.40733 .04626 Mdot
.3509 .58316 Mdot
.10213 .46429 Mdot
.71046 .37597 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.5059 .0025 Mdot
.51879 .00797 Mdot
.55979 .02534 Mdot
.68839 .07948 Mdot
.03804 .2161 Mdot
.33118 .18117 Mdot
.41597 .0524 Mdot
.38049 .5961 Mdot
.18211 .49543 Mdot
.49873 .61749 Mdot
.49594 .61631 Mdot
.48707 .61255 Mdot
.45884 .60058 Mdot
.36955 .56285 Mdot
.10577 .45501 Mdot
.69476 .36401 Mdot
.50824 .50276 Mdot
.33409 .5104 Mdot
.95375 .38297 Mdot
.64181 .42525 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.4743 .60714 Mdot
.41829 .58342 Mdot
.24502 .51095 Mdot
.83313 .36347 Mdot
.62815 .49135 Mdot
.59527 .59772 Mdot
.69693 .06282 Mdot
.02416 .20224 Mdot
.31529 .17993 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.4805 .60977 Mdot
.43795 .59174 Mdot
.30467 .53566 Mdot
.9466 .39673 Mdot
.66714 .44532 Mdot
.59478 .57331 Mdot
.65632 .03804 Mdot
.91643 .16076 Mdot
.29621 .23472 Mdot
.49855 .61742 Mdot
.49537 .61607 Mdot
.48525 .61178 Mdot
.45305 .59813 Mdot
.35143 .55523 Mdot
.05794 .43665 Mdot
.67945 .38411 Mdot
.51661 .5174 Mdot
.37865 .53277 Mdot
.0758 .43086 Mdot
.6635 .36322 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.49419 .61557 Mdot
.4815 .61019 Mdot
.44112 .59308 Mdot
.31441 .53973 Mdot
.96827 .4041 Mdot
.6694 .43333 Mdot
.57931 .56235 Mdot
.60333 .01484 Mdot
.77167 .10404 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50674 .00286 Mdot
.52146 .0091 Mdot
.56829 .02894 Mdot
.71443 .09032 Mdot
.09336 .23419 Mdot
.34015 .15252 Mdot
.38549 .02802 Mdot
.27349 .54882 Mdot
.92536 .40288 Mdot
.68513 .46956 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51486 .0063 Mdot
.54731 .02005 Mdot
.64967 .06327 Mdot
.94489 .18245 Mdot
.32113 .23253 Mdot
.48209 .09948 Mdot
.61622 .0829 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50306 .0013 Mdot
.50976 .00414 Mdot
.5311 .01318 Mdot
.59878 .04183 Mdot
.80529 .12763 Mdot
.23628 .26636 Mdot
.42942 .11937 Mdot
.52013 .05606 Mdot
.64094 .07467 Mdot
.94659 .1889 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.4743 .60714 Mdot
.41829 .58342 Mdot
.24503 .51095 Mdot
.83316 .36348 Mdot
.62816 .49134 Mdot
.5953 .59772 Mdot
.69699 .06285 Mdot
.02429 .20228 Mdot
.3153 .17985 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50579 .00245 Mdot
.51844 .00782 Mdot
.55868 .02487 Mdot
.68497 .07805 Mdot
.03033 .21345 Mdot
.33047 .1855 Mdot
.42175 .05641 Mdot
.40034 .6048 Mdot
.23901 .51833 Mdot
.83952 .37114 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.525 .0106 Mdot
.57949 .03368 Mdot
.74834 .10435 Mdot
.1559 .25189 Mdot
.36525 .12939 Mdot
.39579 .01887 Mdot
.28093 .54705 Mdot
.93184 .40228 Mdot
.68189 .46356 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50338 .00143 Mdot
.51077 .00457 Mdot
.53431 .01455 Mdot
.60891 .04611 Mdot
.83443 .13938 Mdot
.26587 .26664 Mdot
.45976 .11983 Mdot
.59393 .08292 Mdot
.86095 .16503 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48826 .61305 Mdot
.4626 .60218 Mdot
.38135 .56782 Mdot
.13816 .46773 Mdot
.7128 .35514 Mdot
.51967 .49868 Mdot
.35598 .51687 Mdot
.00455 .40084 Mdot
.6463 .39662 Mdot
.49804 .6172 Mdot
.49375 .61538 Mdot
.48009 .60959 Mdot
.43663 .59118 Mdot
.30062 .53397 Mdot
.93785 .39383 Mdot
.66595 .44999 Mdot
.60027 .57744 Mdot
.67522 .04633 Mdot
.96304 .17788 Mdot
.3058 .21184 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.4798 .60947 Mdot
.43574 .5908 Mdot
.29787 .53283 Mdot
.932 .39191 Mdot
.66505 .45305 Mdot
.60362 .58007 Mdot
.68688 .05146 Mdot
.99035 .18755 Mdot
.30828 .19649 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00282 Mdot
.5212 .00899 Mdot
.56746 .02859 Mdot
.71192 .08928 Mdot
.0883 .23262 Mdot
.33892 .15489 Mdot
.38712 .02979 Mdot
.27984 .55173 Mdot
.93801 .40677 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54142 .01756 Mdot
.63125 .05552 Mdot
.8964 .16387 Mdot
.3062 .25327 Mdot
.492 .11483 Mdot
.66582 .10742 Mdot
.04573 .2348 Mdot
.35799 .19299 Mdot
.49745 .61695 Mdot
.49187 .61459 Mdot
.47411 .60706 Mdot
.41769 .58316 Mdot
.24322 .51021 Mdot
.83024 .3628 Mdot
.62629 .49199 Mdot
.59251 .59716 Mdot
.6898 .06013 Mdot
.00896 .19725 Mdot
.31468 .18895 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.50591 .0025 Mdot
.51882 .00798 Mdot
.55988 .02538 Mdot
.68867 .0796 Mdot
.03869 .21632 Mdot
.33124 .18081 Mdot
.41549 .05207 Mdot
.37886 .59539 Mdot
.17757 .49363 Mdot
.76184 .3611 Mdot
.49838 .61735 Mdot
.49483 .61584 Mdot
.48354 .61106 Mdot
.44761 .59583 Mdot
.3345 .54813 Mdot
.01553 .4209 Mdot
.6733 .40652 Mdot
.54261 .53726 Mdot
.47508 .5763 Mdot
.37032 .55329 Mdot
.09186 .44594 Mdot
.49985 .61797 Mdot
.49953 .61783 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48464 .61152 Mdot
.45111 .59731 Mdot
.34537 .55269 Mdot
.04251 .43085 Mdot
.67664 .39191 Mdot
.52458 .52406 Mdot
.40924 .54675 Mdot
.49868 .61747 Mdot
.4958 .61625 Mdot
.48662 .61236 Mdot
.45739 .59997 Mdot
.365 .56093 Mdot
.09353 .45026 Mdot
.68971 .36845 Mdot
.50768 .50554 Mdot
.33718 .51266 Mdot
.96287 .3867 Mdot
.64375 .42081 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52613 .01108 Mdot
.58308 .03519 Mdot
.75905 .10876 Mdot
.17338 .25607 Mdot
.3761 .12529 Mdot
.4112 .02169 Mdot
.3199 .56161 Mdot
.01251 .42806 Mdot
.68638 .41647 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51374 .00583 Mdot
.54377 .01855 Mdot
.63861 .05862 Mdot
.91607 .17148 Mdot
.31367 .24573 Mdot
.49138 .10983 Mdot
.65618 .10185 Mdot
.01943 .2245 Mdot
.4985 .6174 Mdot
.49521 .616 Mdot
.48474 .61156 Mdot
.45143 .59744 Mdot
.34638 .55311 Mdot
.04506 .43181 Mdot
.67705 .39059 Mdot
.52312 .5229 Mdot
.40376 .54426 Mdot
.14867 .46038 Mdot
.70162 .34174 Mdot
.49859 .61743 Mdot
.4955 .61612 Mdot
.48565 .61195 Mdot
.45432 .59867 Mdot
.35541 .5569 Mdot
.06823 .44055 Mdot
.68182 .37922 Mdot
.51256 .51343 Mdot
.36211 .52505 Mdot
.02976 .41263 Mdot
.65303 .3852 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50595 .00252 Mdot
.51896 .00804 Mdot
.56035 .02558 Mdot
.69012 .0802 Mdot
.04192 .21743 Mdot
.33156 .17901 Mdot
.41314 .05042 Mdot
.37081 .59187 Mdot
.15529 .48483 Mdot
.74207 .36265 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47576 .60776 Mdot
.42292 .58538 Mdot
.25894 .51668 Mdot
.85659 .36937 Mdot
.64141 .48504 Mdot
.61152 .59956 Mdot
.73554 .07665 Mdot
.09732 .22359 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51722 .0073 Mdot
.55481 .02323 Mdot
.673 .07305 Mdot
.00252 .20366 Mdot
.32826 .20132 Mdot
.44355 .07125 Mdot
.47594 .02002 Mdot
.47239 .61584 Mdot
.42761 .59036 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49086 .61416 Mdot
.47087 .60568 Mdot
.40745 .57883 Mdot
.21289 .49779 Mdot
.78605 .35424 Mdot
.59185 .49801 Mdot
.52791 .57852 Mdot
.50562 .60426 Mdot
.49177 .60947 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49083 .61415 Mdot
.4708 .60565 Mdot
.40721 .57874 Mdot
.2122 .49751 Mdot
.78516 .35411 Mdot
.59104 .49807 Mdot
.52617 .57794 Mdot
.50038 .60209 Mdot
.47515 .60244 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.5093 .00394 Mdot
.52962 .01256 Mdot
.59411 .03986 Mdot
.79168 .12211 Mdot
.21984 .26462 Mdot
.41355 .11972 Mdot
.48386 .04345 Mdot
.52999 .02851 Mdot
.62084 .05615 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51625 .00689 Mdot
.55174 .02193 Mdot
.66348 .06906 Mdot
.97953 .19533 Mdot
.3262 .21425 Mdot
.46099 .0833 Mdot
.53784 .0475 Mdot
.67091 .08224 Mdot
.01383 .21194 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49072 .6141 Mdot
.47045 .60551 Mdot
.40612 .57827 Mdot
.20899 .4962 Mdot
.78102 .35353 Mdot
.58725 .49828 Mdot
.5179 .57517 Mdot
.49926 .61772 Mdot
.49765 .61704 Mdot
.4925 .61485 Mdot
.4761 .6079 Mdot
.424 .58583 Mdot
.26217 .51802 Mdot
.86232 .37091 Mdot
.64417 .48321 Mdot
.6139 .59932 Mdot
.74025 .07809 Mdot
.10489 .22536 Mdot
.49796 .61717 Mdot
.49349 .61527 Mdot
.47925 .60924 Mdot
.43398 .59005 Mdot
.29249 .53059 Mdot
.92073 .38827 Mdot
.66302 .45876 Mdot
.60926 .58481 Mdot
.70683 .0603 Mdot
.03439 .20245 Mdot
.31077 .17081 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .0018 Mdot
.51349 .00572 Mdot
.54296 .01821 Mdot
.63609 .05756 Mdot
.90938 .1689 Mdot
.31137 .24845 Mdot
.49216 .11173 Mdot
.66119 .10447 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49233 .61478 Mdot
.47557 .60768 Mdot
.42232 .58512 Mdot
.25711 .51593 Mdot
.85342 .36853 Mdot
.6398 .48601 Mdot
.60994 .59958 Mdot
.73218 .07555 Mdot
.09166 .22217 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48603 .61211 Mdot
.45551 .59917 Mdot
.35912 .55846 Mdot
.07794 .44426 Mdot
.68447 .37485 Mdot
.50978 .51007 Mdot
.34975 .51913 Mdot
.99635 .39962 Mdot
.64843 .40301 Mdot
.49993 .618 Mdot
.49977 .61794 Mdot
.49926 .61772 Mdot
.49765 .61704 Mdot
.4925 .61486 Mdot
.47612 .60791 Mdot
.42405 .58585 Mdot
.26233 .51808 Mdot
.86259 .37098 Mdot
.6443 .48312 Mdot
.61399 .59931 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51499 .00636 Mdot
.54773 .02023 Mdot
.651 .06382 Mdot
.94827 .18373 Mdot
.32178 .23084 Mdot
.48043 .09805 Mdot
.6098 .07996 Mdot
.89113 .17387 Mdot
.32332 .26711 Mdot
.49917 .61768 Mdot
.49735 .61691 Mdot
.49156 .61445 Mdot
.47311 .60663 Mdot
.41451 .58182 Mdot
.23376 .50632 Mdot
.81551 .35955 Mdot
.61606 .49477 Mdot
.57567 .59307 Mdot
.64457 .04258 Mdot
.9017 .15892 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.4805 .60976 Mdot
.43794 .59173 Mdot
.30462 .53564 Mdot
.94649 .3967 Mdot
.66712 .44537 Mdot
.59484 .57336 Mdot
.65656 .03814 Mdot
.91703 .16098 Mdot
.49892 .61758 Mdot
.49656 .61658 Mdot
.48905 .61339 Mdot
.46513 .60325 Mdot
.38931 .57118 Mdot
.16053 .47664 Mdot
.72976 .3518 Mdot
.53579 .49815 Mdot
.39504 .53105 Mdot
.10802 .44065 Mdot
.67113 .34802 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48984 .61372 Mdot
.46763 .60431 Mdot
.39719 .5745 Mdot
.18304 .48568 Mdot
.75097 .351 Mdot
.55764 .49855 Mdot
.44888 .55082 Mdot
.26476 .50424 Mdot
.84293 .35733 Mdot
.49786 .61713 Mdot
.49318 .61514 Mdot
.47827 .60882 Mdot
.43088 .58874 Mdot
.28303 .52666 Mdot
.90158 .38228 Mdot
.65852 .46782 Mdot
.61584 .59166 Mdot
.73199 .07178 Mdot
.08534 .21838 Mdot
.31673 .143 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.4822 .61049 Mdot
.44334 .59402 Mdot
.32126 .54259 Mdot
.98399 .40959 Mdot
.67069 .42441 Mdot
.5671 .55401 Mdot
.56119 .61438 Mdot
.64482 .05169 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53633 .0154 Mdot
.61526 .04878 Mdot
.85237 .14654 Mdot
.2805 .2646 Mdot
.47428 .11976 Mdot
.62964 .09602 Mdot
.95865 .20334 Mdot
.34899 .24124 Mdot
.49787 .61713 Mdot
.49323 .61516 Mdot
.47843 .60889 Mdot
.43136 .58895 Mdot
.2845 .52727 Mdot
.9045 .38318 Mdot
.6593 .4665 Mdot
.61512 .59073 Mdot
.72894 .07034 Mdot
.0794 .2166 Mdot
.31564 .14601 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50605 .00257 Mdot
.51928 .00818 Mdot
.56137 .02601 Mdot
.69325 .08151 Mdot
.04885 .21977 Mdot
.33232 .17519 Mdot
.40828 .04695 Mdot
.35415 .58458 Mdot
.1106 .46751 Mdot
.71419 .37304 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52147 .0091 Mdot
.56831 .02895 Mdot
.7145 .09035 Mdot
.09352 .23424 Mdot
.34019 .15245 Mdot
.38544 .02797 Mdot
.27331 .54874 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49234 .61479 Mdot
.47561 .60769 Mdot
.42244 .58517 Mdot
.25749 .51609 Mdot
.85407 .36871 Mdot
.64014 .48581 Mdot
.61028 .59958 Mdot
.73292 .0758 Mdot
.09292 .22249 Mdot
.49881 .61753 Mdot
.49619 .61642 Mdot
.48787 .61289 Mdot
.46138 .60166 Mdot
.37752 .56621 Mdot
.12754 .46354 Mdot
.70608 .35756 Mdot
.51432 .49952 Mdot
.34401 .51278 Mdot
.97542 .39023 Mdot
.64355 .41293 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51788 .00758 Mdot
.5569 .02412 Mdot
.67948 .07576 Mdot
.01774 .20905 Mdot
.32944 .19265 Mdot
.43154 .0631 Mdot
.4341 .00158 Mdot
.49848 .61739 Mdot
.49517 .61599 Mdot
.48461 .61151 Mdot
.45101 .59727 Mdot
.34509 .55257 Mdot
.04179 .43059 Mdot
.67652 .39228 Mdot
.52499 .52438 Mdot
.4108 .54746 Mdot
.16971 .46903 Mdot
.71962 .33987 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53094 .01312 Mdot
.5983 .04163 Mdot
.80391 .12707 Mdot
.23468 .26623 Mdot
.42783 .11937 Mdot
.5164 .05474 Mdot
.62952 .06991 Mdot
.91617 .17716 Mdot
.49983 .61796 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49454 .61572 Mdot
.48262 .61066 Mdot
.44467 .59458 Mdot
.3254 .54432 Mdot
.99369 .41303 Mdot
.67144 .41887 Mdot
.55943 .54881 Mdot
.5345 .60263 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47601 .60786 Mdot
.4237 .58571 Mdot
.26128 .51765 Mdot
.86073 .37048 Mdot
.64342 .48373 Mdot
.61329 .59941 Mdot
.73911 .07776 Mdot
.1031 .22496 Mdot
.32303 .13592 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.5059 .0025 Mdot
.51878 .00796 Mdot
.55978 .02534 Mdot
.68834 .07946 Mdot
.03794 .21607 Mdot
.33117 .18122 Mdot
.41604 .05245 Mdot
.38074 .59622 Mdot
.18283 .49572 Mdot
.76713 .36112 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.5121 .00513 Mdot
.53853 .01634 Mdot
.62221 .05171 Mdot
.8717 .1542 Mdot
.29347 .26067 Mdot
.48535 .11859 Mdot
.65528 .10503 Mdot
.02291 .22721 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00314 Mdot
.52362 .01002 Mdot
.57514 .03184 Mdot
.73522 .09893 Mdot
.133 .24584 Mdot
.35371 .1364 Mdot
.38459 .01909 Mdot
.25714 .53926 Mdot
.8912 .39187 Mdot
.67604 .48506 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50325 .00138 Mdot
.51034 .00439 Mdot
.53294 .01397 Mdot
.6046 .04429 Mdot
.82211 .13443 Mdot
.25427 .26709 Mdot
.44777 .11959 Mdot
.56434 .07204 Mdot
.7748 .13007 Mdot
.22111 .27583 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.51939 .00822 Mdot
.56172 .02616 Mdot
.69432 .08195 Mdot
.0512 .22056 Mdot
.33259 .17391 Mdot
.40669 .04579 Mdot
.3487 .58219 Mdot
.09642 .46212 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47787 .60865 Mdot
.4296 .5882 Mdot
.27914 .52504 Mdot
.89393 .37996 Mdot
.65631 .47118 Mdot
.61724 .59389 Mdot
.73854 .07497 Mdot
.09796 .22213 Mdot
.31954 .13694 Mdot
.49822 .61728 Mdot
.49434 .61563 Mdot
.48197 .61039 Mdot
.44261 .59371 Mdot
.31901 .54165 Mdot
.97878 .40776 Mdot
.67028 .42737 Mdot
.5712 .5568 Mdot
.57538 .00258 Mdot
.68845 .06988 Mdot
.02262 .20653 Mdot
.49922 .6177 Mdot
.49753 .61698 Mdot
.49212 .61469 Mdot
.47489 .60738 Mdot
.42014 .5842 Mdot
.25056 .51323 Mdot
.84226 .36569 Mdot
.63369 .48913 Mdot
.60288 .59899 Mdot
.71587 .06983 Mdot
.06212 .214 Mdot
.49858 .61743 Mdot
.49546 .61611 Mdot
.48554 .6119 Mdot
.45396 .59852 Mdot
.35428 .55643 Mdot
.06531 .43944 Mdot
.6811 .38058 Mdot
.51359 .51451 Mdot
.36646 .5271 Mdot
.0417 .41732 Mdot
.6551 .37911 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.51548 .00657 Mdot
.5493 .0209 Mdot
.65589 .06587 Mdot
.96067 .18837 Mdot
.32385 .22446 Mdot
.47354 .09251 Mdot
.58373 .0681 Mdot
.81379 .14218 Mdot
.26366 .27804 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.5059 .0025 Mdot
.5188 .00797 Mdot
.55983 .02536 Mdot
.6885 .07953 Mdot
.03831 .21619 Mdot
.3312 .18102 Mdot
.41577 .05227 Mdot
.37981 .59581 Mdot
.18023 .49468 Mdot
.76448 .36109 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.48718 .6126 Mdot
.45916 .60072 Mdot
.37057 .56328 Mdot
.10852 .45608 Mdot
.69602 .36309 Mdot
.50865 .50223 Mdot
.33424 .51025 Mdot
.95377 .38289 Mdot
.64167 .42515 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50559 .00237 Mdot
.5178 .00755 Mdot
.55664 .02401 Mdot
.67868 .07542 Mdot
.01586 .20839 Mdot
.3293 .19371 Mdot
.43302 .0641 Mdot
.43921 .00383 Mdot
.35642 .56687 Mdot
.0863 .45109 Mdot
.49777 .61709 Mdot
.49291 .61503 Mdot
.47741 .60846 Mdot
.42815 .58759 Mdot
.27474 .52322 Mdot
.88548 .37746 Mdot
.65355 .4747 Mdot
.61785 .59597 Mdot
.7432 .07747 Mdot
.10707 .22488 Mdot
.32218 .13294 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.51371 .00581 Mdot
.54365 .01851 Mdot
.63825 .05847 Mdot
.91511 .17111 Mdot
.31335 .24613 Mdot
.49153 .11012 Mdot
.65701 .10227 Mdot
.02162 .22534 Mdot
.3539 .20536 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48266 .61068 Mdot
.44482 .59464 Mdot
.32585 .54451 Mdot
.99474 .4134 Mdot
.67152 .41827 Mdot
.5586 .54824 Mdot
.5316 .60135 Mdot
.55169 .01242 Mdot
.49892 .61758 Mdot
.49655 .61657 Mdot
.48901 .61337 Mdot
.46501 .6032 Mdot
.38893 .57102 Mdot
.15946 .47621 Mdot
.72885 .3519 Mdot
.53487 .49815 Mdot
.39278 .53022 Mdot
.10174 .43816 Mdot
.66828 .35014 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50368 .00156 Mdot
.51173 .00498 Mdot
.53737 .01585 Mdot
.61856 .05017 Mdot
.86158 .15019 Mdot
.28703 .26294 Mdot
.48018 .11937 Mdot
.64367 .10104 Mdot
.99457 .21687 Mdot
.35361 .2219 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49917 .61768 Mdot
.49735 .61691 Mdot
.49155 .61445 Mdot
.47307 .60661 Mdot
.41438 .58177 Mdot
.23338 .50617 Mdot
.81495 .35943 Mdot
.61564 .49486 Mdot
.57493 .59288 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50611 .00259 Mdot
.51946 .00825 Mdot
.56194 .02625 Mdot
.69501 .08224 Mdot
.0527 .22106 Mdot
.33278 .1731 Mdot
.40569 .04506 Mdot
.34528 .5807 Mdot
.08765 .45881 Mdot
.70509 .3816 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47773 .60859 Mdot
.42917 .58802 Mdot
.27782 .5245 Mdot
.89138 .3792 Mdot
.65551 .47226 Mdot
.61753 .59456 Mdot
.74024 .07584 Mdot
.10124 .22311 Mdot
.32041 .13546 Mdot
.49757 .617 Mdot
.49226 .61475 Mdot
.47536 .60758 Mdot
.42163 .58483 Mdot
.25503 .51507 Mdot
.84983 .3676 Mdot
.63791 .48706 Mdot
.60793 .5995 Mdot
.72772 .07403 Mdot
.0839 .22013 Mdot
.31998 .14591 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47422 .6071 Mdot
.41802 .5833 Mdot
.24421 .51062 Mdot
.83183 .36317 Mdot
.62732 .49164 Mdot
.59405 .59747 Mdot
.6938 .06165 Mdot
.01754 .20009 Mdot
.31503 .18386 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50527 .00223 Mdot
.51679 .00712 Mdot
.55345 .02266 Mdot
.66878 .07128 Mdot
.99243 .20003 Mdot
.32743 .20704 Mdot
.45139 .07661 Mdot
.50357 .03225 Mdot
.56111 .03556 Mdot
.70809 .09084 Mdot
.49858 .61743 Mdot
.49549 .61612 Mdot
.48562 .61193 Mdot
.4542 .59862 Mdot
.35504 .55675 Mdot
.06726 .44018 Mdot
.68157 .37966 Mdot
.51289 .51378 Mdot
.36352 .52572 Mdot
.03362 .41414 Mdot
.65366 .38321 Mdot
.49982 .61796 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49434 .61563 Mdot
.48195 .61038 Mdot
.44256 .59369 Mdot
.31885 .54158 Mdot
.97841 .40763 Mdot
.67025 .42758 Mdot
.57148 .55699 Mdot
.57636 .00301 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47726 .60839 Mdot
.42765 .58738 Mdot
.27321 .52259 Mdot
.88258 .37661 Mdot
.65253 .47585 Mdot
.61782 .59658 Mdot
.74413 .07807 Mdot
.10902 .22551 Mdot
.32287 .13216 Mdot
.49801 .61719 Mdot
.49365 .61534 Mdot
.47978 .60946 Mdot
.43566 .59077 Mdot
.29765 .53274 Mdot
.93152 .39176 Mdot
.66497 .4533 Mdot
.60388 .58028 Mdot
.68779 .05186 Mdot
.99243 .18828 Mdot
.30842 .19529 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50195 .00082 Mdot
.5062 .00263 Mdot
.51974 .00837 Mdot
.56283 .02663 Mdot
.69773 .08337 Mdot
.0586 .22303 Mdot
.33354 .16992 Mdot
.4019 .04224 Mdot
.33224 .57498 Mdot
.05502 .4467 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47988 .6095 Mdot
.43599 .59091 Mdot
.29865 .53315 Mdot
.93364 .39245 Mdot
.66531 .4522 Mdot
.60271 .57934 Mdot
.6837 .05006 Mdot
.98301 .18498 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52195 .00931 Mdot
.56983 .02959 Mdot
.71914 .09227 Mdot
.1027 .23705 Mdot
.34268 .14832 Mdot
.38328 .02509 Mdot
.26408 .54436 Mdot
.90708 .3974 Mdot
.68168 .47872 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51433 .00608 Mdot
.54563 .01935 Mdot
.64445 .06107 Mdot
.93141 .17735 Mdot
.31809 .23898 Mdot
.48757 .10474 Mdot
.63841 .09322 Mdot
.97166 .20596 Mdot
.3472 .2321 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49399 .61548 Mdot
.48085 .60991 Mdot
.43904 .5922 Mdot
.30803 .53706 Mdot
.95397 .39922 Mdot
.668 .44129 Mdot
.58977 .56968 Mdot
.63916 .03053 Mdot
.87169 .14371 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00206 Mdot
.51551 .00658 Mdot
.54939 .02094 Mdot
.65617 .066 Mdot
.96139 .18863 Mdot
.32396 .22408 Mdot
.4731 .09218 Mdot
.58209 .06736 Mdot
.80882 .14013 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47649 .60806 Mdot
.42522 .58635 Mdot
.26585 .51954 Mdot
.86894 .37273 Mdot
.64714 .48095 Mdot
.61593 .59874 Mdot
.74363 .07892 Mdot
.10987 .22635 Mdot
.32409 .13239 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50495 .0021 Mdot
.51577 .00669 Mdot
.5502 .02128 Mdot
.65868 .06705 Mdot
.96766 .19096 Mdot
.32482 .22074 Mdot
.46914 .0892 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.50911 .00386 Mdot
.52902 .01231 Mdot
.59223 .03906 Mdot
.78616 .11986 Mdot
.21269 .26361 Mdot
.40702 .1201 Mdot
.46968 .03872 Mdot
.48712 .01078 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50079 .00033 Mdot
.50252 .00107 Mdot
.50802 .0034 Mdot
.52554 .01083 Mdot
.58121 .0344 Mdot
.75346 .10646 Mdot
.1644 .25397 Mdot
.37031 .12726 Mdot
.4025 .0199 Mdot
.49896 .61759 Mdot
.49669 .61663 Mdot
.48945 .61356 Mdot
.46638 .60378 Mdot
.39327 .57285 Mdot
.17179 .48115 Mdot
.73982 .35107 Mdot
.54611 .49831 Mdot
.42059 .54046 Mdot
.18083 .46986 Mdot
.72454 .33603 Mdot
.49796 .61717 Mdot
.49349 .61527 Mdot
.47926 .60924 Mdot
.43402 .59007 Mdot
.2926 .53064 Mdot
.92096 .38835 Mdot
.66306 .45864 Mdot
.60916 .58472 Mdot
.70645 .06013 Mdot
.0336 .20219 Mdot
.31072 .17127 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.48718 .6126 Mdot
.45917 .60072 Mdot
.37058 .56328 Mdot
.10857 .4561 Mdot
.69604 .36308 Mdot
.50866 .50222 Mdot
.33425 .51024 Mdot
.95378 .38289 Mdot
.64167 .42514 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51572 .00667 Mdot
.55006 .02122 Mdot
.65824 .06686 Mdot
.96658 .19056 Mdot
.32468 .22132 Mdot
.46984 .08972 Mdot
.57005 .06193 Mdot
.77197 .12479 Mdot
.21036 .27094 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00226 Mdot
.51695 .00719 Mdot
.55394 .02287 Mdot
.67031 .07192 Mdot
.99611 .20136 Mdot
.32774 .20496 Mdot
.44856 .07467 Mdot
.49355 .0278 Mdot
.52886 .02182 Mdot
.60722 .04843 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48646 .61229 Mdot
.45689 .59976 Mdot
.36345 .56028 Mdot
.08941 .44867 Mdot
.6882 .37007 Mdot
.50794 .50663 Mdot
.33959 .51399 Mdot
.96933 .3892 Mdot
.6448 .41746 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48278 .61073 Mdot
.44518 .5948 Mdot
.32698 .54498 Mdot
.99743 .41436 Mdot
.67173 .41674 Mdot
.55648 .5468 Mdot
.52419 .59807 Mdot
.52803 .00238 Mdot
.57371 .02823 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.5137 .00581 Mdot
.54364 .0185 Mdot
.6382 .05845 Mdot
.91499 .17106 Mdot
.31331 .24618 Mdot
.49155 .11015 Mdot
.65711 .10232 Mdot
.02187 .22544 Mdot
.35393 .20522 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51607 .00681 Mdot
.55115 .02168 Mdot
.66164 .06829 Mdot
.97501 .19367 Mdot
.32571 .21675 Mdot
.46419 .08558 Mdot
.54939 .05266 Mdot
.7075 .09772 Mdot
.09588 .24003 Mdot
.49964 .61788 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48834 .61309 Mdot
.46286 .60229 Mdot
.38219 .56817 Mdot
.14049 .46866 Mdot
.71438 .35468 Mdot
.52105 .49855 Mdot
.3592 .51801 Mdot
.01265 .40385 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52383 .0101 Mdot
.57578 .03211 Mdot
.73716 .09974 Mdot
.1365 .2468 Mdot
.35528 .13521 Mdot
.38569 .01879 Mdot
.25899 .53973 Mdot
.89394 .39242 Mdot
.67646 .48363 Mdot
.4989 .61757 Mdot
.49649 .61655 Mdot
.48881 .61329 Mdot
.46437 .60293 Mdot
.38693 .57017 Mdot
.1538 .47395 Mdot
.72423 .35255 Mdot
.53028 .49816 Mdot
.38147 .52606 Mdot
.07085 .42606 Mdot
.65743 .36253 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51215 .00515 Mdot
.53868 .0164 Mdot
.62267 .05191 Mdot
.87298 .1547 Mdot
.29423 .26034 Mdot
.4859 .11846 Mdot
.65646 .10541 Mdot
.02569 .2282 Mdot
.35655 .20449 Mdot
.499 .61761 Mdot
.49683 .61669 Mdot
.48989 .61375 Mdot
.4678 .60438 Mdot
.39775 .57474 Mdot
.18465 .48633 Mdot
.75267 .35105 Mdot
.55938 .49858 Mdot
.45311 .55236 Mdot
.27752 .50951 Mdot
.86675 .36417 Mdot
.49911 .61766 Mdot
.49716 .61683 Mdot
.49096 .6142 Mdot
.47122 .60583 Mdot
.40854 .5793 Mdot
.2161 .4991 Mdot
.79032 .35489 Mdot
.59565 .49772 Mdot
.53599 .58116 Mdot
.52984 .61424 Mdot
.56819 .0237 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50684 .0029 Mdot
.52179 .00924 Mdot
.56933 .02938 Mdot
.71761 .09164 Mdot
.0997 .23614 Mdot
.34183 .14964 Mdot
.38387 .02598 Mdot
.26676 .54566 Mdot
.91225 .39893 Mdot
.68279 .47622 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51686 .00715 Mdot
.55367 .02275 Mdot
.66948 .07157 Mdot
.99411 .20063 Mdot
.32757 .20609 Mdot
.45011 .07573 Mdot
.49903 .03023 Mdot
.5465 .02934 Mdot
.66272 .07183 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50223 .00094 Mdot
.5071 .00301 Mdot
.52261 .00959 Mdot
.57193 .03048 Mdot
.72552 .09492 Mdot
.11501 .24072 Mdot
.34662 .14314 Mdot
.38215 .02196 Mdot
.25662 .54045 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.5752 .03186 Mdot
.73539 .09901 Mdot
.13332 .24593 Mdot
.35385 .13629 Mdot
.38468 .01906 Mdot
.25728 .5393 Mdot
.8914 .39191 Mdot
.67607 .48495 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49026 .6139 Mdot
.46897 .60488 Mdot
.40143 .57629 Mdot
.1953 .49064 Mdot
.76441 .35172 Mdot
.57126 .49867 Mdot
.48148 .56254 Mdot
.36398 .54541 Mdot
.06639 .43412 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.51371 .00581 Mdot
.54365 .01851 Mdot
.63825 .05847 Mdot
.91511 .17111 Mdot
.31335 .24613 Mdot
.49153 .11012 Mdot
.65701 .10227 Mdot
.02161 .22534 Mdot
.3539 .20536 Mdot
.49754 .61699 Mdot
.49218 .61472 Mdot
.47508 .60747 Mdot
.42074 .58445 Mdot
.25238 .51398 Mdot
.8453 .36645 Mdot
.63543 .48832 Mdot
.60505 .59926 Mdot
.72104 .07169 Mdot
.07183 .2168 Mdot
.31849 .15245 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48126 .61009 Mdot
.44035 .59275 Mdot
.31205 .53874 Mdot
.96294 .40227 Mdot
.66892 .43632 Mdot
.5833 .56512 Mdot
.61702 .02084 Mdot
.81088 .11981 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00215 Mdot
.51614 .00684 Mdot
.55137 .02178 Mdot
.66233 .06858 Mdot
.9767 .19429 Mdot
.3259 .21582 Mdot
.463 .08473 Mdot
.5451 .05074 Mdot
.69394 .09199 Mdot
.06686 .23048 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49234 .61478 Mdot
.47558 .60768 Mdot
.42235 .58514 Mdot
.25722 .51598 Mdot
.8536 .36858 Mdot
.6399 .48596 Mdot
.61004 .59958 Mdot
.73239 .07562 Mdot
.5007 .00029 Mdot
.50221 .00094 Mdot
.50706 .00299 Mdot
.52248 .00953 Mdot
.5715 .0303 Mdot
.72421 .09438 Mdot
.11252 .23999 Mdot
.34577 .14415 Mdot
.3822 .02252 Mdot
.25764 .54105 Mdot
.89463 .39368 Mdot
.67837 .48438 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48027 .60967 Mdot
.43722 .59143 Mdot
.30243 .53473 Mdot
.94173 .39511 Mdot
.6665 .44793 Mdot
.59789 .57563 Mdot
.66704 .04274 Mdot
.94322 .17069 Mdot
.30277 .22222 Mdot
.49741 .61694 Mdot
.49176 .61454 Mdot
.47375 .6069 Mdot
.41654 .58268 Mdot
.23981 .50881 Mdot
.82483 .36156 Mdot
.62268 .4931 Mdot
.58686 .5959 Mdot
.67496 .05445 Mdot
.97575 .1859 Mdot
.31277 .20829 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.5023 .00097 Mdot
.50732 .0031 Mdot
.52331 .00988 Mdot
.57414 .03141 Mdot
.73219 .09768 Mdot
.12749 .24431 Mdot
.35136 .13836 Mdot
.38329 .01973 Mdot
.25543 .53901 Mdot
.88897 .39155 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50293 .00124 Mdot
.50935 .00396 Mdot
.52978 .01263 Mdot
.59462 .04007 Mdot
.79317 .12271 Mdot
.22172 .26486 Mdot
.4153 .11964 Mdot
.48775 .04478 Mdot
.54184 .03343 Mdot
.65798 .07178 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00322 Mdot
.52416 .01024 Mdot
.57683 .03255 Mdot
.74031 .10104 Mdot
.14209 .24831 Mdot
.35794 .1334 Mdot
.38788 .01851 Mdot
.26322 .54099 Mdot
.90065 .39395 Mdot
.67761 .48019 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48671 .6124 Mdot
.45768 .60009 Mdot
.36591 .56132 Mdot
.09597 .4512 Mdot
.69064 .36753 Mdot
.50763 .50493 Mdot
.33607 .512 Mdot
.95985 .38552 Mdot
.64322 .42234 Mdot
.50055 .00023 Mdot
.50177 .00075 Mdot
.50562 .00238 Mdot
.51792 .0076 Mdot
.55703 .02417 Mdot
.67986 .07592 Mdot
.01862 .20936 Mdot
.32951 .19214 Mdot
.43085 .06263 Mdot
.43168 .00052 Mdot
.33317 .55715 Mdot
.02778 .42929 Mdot
.49865 .61746 Mdot
.49571 .61622 Mdot
.48634 .61224 Mdot
.4565 .59959 Mdot
.36223 .55977 Mdot
.08616 .44742 Mdot
.68707 .37138 Mdot
.50829 .50754 Mdot
.34195 .51523 Mdot
.97563 .39163 Mdot
.64572 .41414 Mdot
.49741 .61693 Mdot
.49173 .61453 Mdot
.47367 .60687 Mdot
.41628 .58257 Mdot
.23902 .50848 Mdot
.8236 .36129 Mdot
.62184 .49334 Mdot
.58549 .59557 Mdot
.6713 .05303 Mdot
.96725 .18291 Mdot
.31198 .21305 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52456 .01041 Mdot
.57811 .03309 Mdot
.74417 .10263 Mdot
.1488 .25008 Mdot
.36136 .13137 Mdot
.39127 .01849 Mdot
.27049 .54339 Mdot
.91295 .39706 Mdot
.67957 .4738 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47911 .60917 Mdot
.43352 .58986 Mdot
.29108 .53 Mdot
.91782 .38734 Mdot
.66242 .46019 Mdot
.61052 .58596 Mdot
.7114 .06235 Mdot
.04403 .20557 Mdot
.31145 .16528 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52311 .0098 Mdot
.57352 .03115 Mdot
.73033 .09691 Mdot
.12405 .24333 Mdot
.34997 .13963 Mdot
.38273 .02025 Mdot
.25507 .53914 Mdot
.8888 .39167 Mdot
.67609 .48657 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50936 .00397 Mdot
.52983 .01265 Mdot
.59478 .04014 Mdot
.79364 .1229 Mdot
.22231 .26494 Mdot
.41586 .11962 Mdot
.48898 .0452 Mdot
.5456 .03499 Mdot
.66969 .07669 Mdot
.49765 .61704 Mdot
.4925 .61485 Mdot
.4761 .6079 Mdot
.424 .58583 Mdot
.26218 .51802 Mdot
.86232 .37091 Mdot
.64417 .48321 Mdot
.6139 .59932 Mdot
.74026 .07809 Mdot
.1049 .22536 Mdot
.32334 .13501 Mdot
.49891 .61757 Mdot
.49652 .61656 Mdot
.48891 .61333 Mdot
.46468 .60306 Mdot
.3879 .57058 Mdot
.15653 .47504 Mdot
.72643 .35222 Mdot
.53245 .49815 Mdot
.38681 .52802 Mdot
.08533 .43171 Mdot
.6619 .35634 Mdot
.49943 .61779 Mdot
.49819 .61726 Mdot
.49422 .61558 Mdot
.48159 .61023 Mdot
.4414 .59319 Mdot
.31527 .54009 Mdot
.97021 .40478 Mdot
.66957 .43223 Mdot
.57783 .56133 Mdot
.59823 .01261 Mdot
.7568 .098 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51239 .00525 Mdot
.53945 .01673 Mdot
.62508 .05292 Mdot
.87961 .15731 Mdot
.29799 .25857 Mdot
.4884 .11768 Mdot
.66144 .10694 Mdot
.03719 .23223 Mdot
.35766 .19806 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51251 .00531 Mdot
.53984 .01689 Mdot
.62632 .05344 Mdot
.88299 .15863 Mdot
.29979 .2576 Mdot
.48944 .11721 Mdot
.66327 .10743 Mdot
.04125 .23361 Mdot
.35805 .19579 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50596 .00253 Mdot
.51898 .00805 Mdot
.56042 .02561 Mdot
.69032 .08028 Mdot
.04236 .21757 Mdot
.33161 .17877 Mdot
.41283 .0502 Mdot
.36975 .59141 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49248 .61485 Mdot
.47604 .60788 Mdot
.42381 .58575 Mdot
.26161 .51779 Mdot
.86131 .37064 Mdot
.6437 .48354 Mdot
.61352 .59938 Mdot
.73954 .07789 Mdot
.10379 .22511 Mdot
.49917 .61768 Mdot
.49736 .61692 Mdot
.4916 .61447 Mdot
.47325 .60669 Mdot
.41495 .58201 Mdot
.23507 .50686 Mdot
.81751 .35997 Mdot
.61752 .49443 Mdot
.57823 .59375 Mdot
.65162 .04536 Mdot
.91956 .1656 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52304 .00977 Mdot
.57329 .03105 Mdot
.72962 .09662 Mdot
.12273 .24296 Mdot
.34946 .14012 Mdot
.38256 .02046 Mdot
.25508 .53924 Mdot
.88898 .39177 Mdot
.67623 .48655 Mdot
.49779 .6171 Mdot
.49297 .61505 Mdot
.47761 .60854 Mdot
.42877 .58785 Mdot
.27663 .524 Mdot
.88909 .37852 Mdot
.65477 .47322 Mdot
.61771 .59513 Mdot
.74156 .07654 Mdot
.1038 .22388 Mdot
.32115 .13433 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48939 .61353 Mdot
.46619 .6037 Mdot
.39267 .5726 Mdot
.17009 .48047 Mdot
.73823 .35114 Mdot
.54446 .49828 Mdot
.41653 .53896 Mdot
.16904 .46508 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48466 .61153 Mdot
.45117 .59733 Mdot
.34558 .55277 Mdot
.04302 .43104 Mdot
.67672 .39165 Mdot
.52428 .52382 Mdot
.40812 .54624 Mdot
.16168 .46572 Mdot
.71233 .34032 Mdot
.5007 .0003 Mdot
.50223 .00095 Mdot
.5071 .00301 Mdot
.52263 .00959 Mdot
.57198 .0305 Mdot
.72565 .09498 Mdot
.11527 .2408 Mdot
.34671 .14304 Mdot
.38215 .0219 Mdot
.25653 .5404 Mdot
.89237 .39297 Mdot
.67763 .48532 Mdot
.4997 .61791 Mdot
.49905 .61763 Mdot
.49696 .61674 Mdot
.49031 .61393 Mdot
.46914 .60495 Mdot
.40197 .57652 Mdot
.19687 .49128 Mdot
.76621 .35188 Mdot
.57306 .49866 Mdot
.48568 .56403 Mdot
.37685 .55077 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51399 .00593 Mdot
.54454 .01888 Mdot
.64104 .05964 Mdot
.92247 .17393 Mdot
.31565 .243 Mdot
.49013 .10783 Mdot
.6498 .09869 Mdot
.00244 .21794 Mdot
.35142 .21568 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .61259 Mdot
.45914 .60071 Mdot
.37051 .56325 Mdot
.10836 .45602 Mdot
.69594 .36315 Mdot
.50862 .50226 Mdot
.33423 .51025 Mdot
.95375 .38289 Mdot
.64168 .42516 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50925 .00392 Mdot
.52947 .0125 Mdot
.59364 .03966 Mdot
.79031 .12155 Mdot
.2181 .26439 Mdot
.41193 .1198 Mdot
.48029 .04225 Mdot
.51918 .02403 Mdot
.58675 .04176 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51819 .00771 Mdot
.5579 .02454 Mdot
.68255 .07704 Mdot
.02482 .21153 Mdot
.33001 .18862 Mdot
.426 .05933 Mdot
.41495 .6112 Mdot
.28231 .53606 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50995 .00422 Mdot
.53168 .01343 Mdot
.60063 .04261 Mdot
.81066 .12981 Mdot
.24229 .26676 Mdot
.43548 .11939 Mdot
.5345 .0612 Mdot
.4987 .61748 Mdot
.49587 .61628 Mdot
.48684 .61245 Mdot
.4581 .60027 Mdot
.36722 .56187 Mdot
.09948 .45256 Mdot
.69205 .36623 Mdot
.5077 .5041 Mdot
.33491 .51124 Mdot
.95655 .3842 Mdot
.64256 .42398 Mdot
.50035 .00015 Mdot
.50112 .00047 Mdot
.50356 .00151 Mdot
.51136 .00482 Mdot
.53617 .01533 Mdot
.61476 .04857 Mdot
.85096 .14598 Mdot
.27945 .26482 Mdot
.47328 .11979 Mdot
.62722 .09514 Mdot
.9523 .20091 Mdot
.34787 .24447 Mdot
.49999 .61803 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49937 .61777 Mdot
.498 .61719 Mdot
.49364 .61534 Mdot
.47973 .60944 Mdot
.43551 .5907 Mdot
.29718 .53254 Mdot
.93054 .39143 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51444 .00612 Mdot
.54597 .01949 Mdot
.6455 .06151 Mdot
.93413 .17838 Mdot
.31877 .23772 Mdot
.48661 .10373 Mdot
.63439 .09133 Mdot
.96064 .20163 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.5132 .0056 Mdot
.54205 .01783 Mdot
.63324 .05636 Mdot
.90175 .16595 Mdot
.30845 .25136 Mdot
.49234 .11365 Mdot
.66474 .10655 Mdot
.04243 .23343 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00114 Mdot
.50859 .00364 Mdot
.52735 .0116 Mdot
.58694 .03683 Mdot
.77056 .11348 Mdot
.19092 .2598 Mdot
.38881 .1223 Mdot
.43315 .0274 Mdot
.38014 .58527 Mdot
.16386 .48436 Mdot
.49846 .61738 Mdot
.49509 .61595 Mdot
.48436 .6114 Mdot
.45021 .59693 Mdot
.34258 .55152 Mdot
.03548 .42824 Mdot
.6756 .39561 Mdot
.52884 .52733 Mdot
.4251 .55392 Mdot
.21311 .48702 Mdot
.76877 .34342 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48364 .6111 Mdot
.44793 .59596 Mdot
.33549 .54854 Mdot
.01794 .42178 Mdot
.67354 .40518 Mdot
.54084 .53602 Mdot
.46872 .57347 Mdot
.35 .54466 Mdot
.03813 .42529 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50578 .00245 Mdot
.51842 .00781 Mdot
.55864 .02485 Mdot
.68484 .07799 Mdot
.03004 .21334 Mdot
.33045 .18566 Mdot
.42198 .05657 Mdot
.40111 .60514 Mdot
.24128 .51925 Mdot
.84307 .37193 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50714 .00303 Mdot
.52274 .00964 Mdot
.57234 .03065 Mdot
.72675 .09543 Mdot
.11734 .2414 Mdot
.34744 .14221 Mdot
.38218 .02147 Mdot
.25588 .53998 Mdot
.89102 .39254 Mdot
.67715 .48585 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50287 .00122 Mdot
.50916 .00388 Mdot
.52917 .01237 Mdot
.5927 .03926 Mdot
.78755 .12042 Mdot
.21451 .26388 Mdot
.40866 .11999 Mdot
.47319 .03988 Mdot
.49768 .01514 Mdot
.5187 .01299 Mdot
.50055 .00023 Mdot
.50176 .00074 Mdot
.5056 .00237 Mdot
.51783 .00756 Mdot
.55675 .02405 Mdot
.67901 .07556 Mdot
.01664 .20867 Mdot
.32936 .19327 Mdot
.43241 .06369 Mdot
.4371 .0029 Mdot
.34987 .56413 Mdot
.0694 .44469 Mdot
.5 0 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00213 Mdot
.51598 .00677 Mdot
.55086 .02156 Mdot
.66076 .06792 Mdot
.97282 .19287 Mdot
.32546 .21794 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52636 .01118 Mdot
.58382 .03551 Mdot
.76127 .10967 Mdot
.17685 .25685 Mdot
.37848 .12461 Mdot
.41502 .02259 Mdot
.33007 .56553 Mdot
.03596 .43627 Mdot
.68837 .40321 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51556 .0066 Mdot
.54953 .02099 Mdot
.65659 .06617 Mdot
.96244 .18902 Mdot
.32411 .22352 Mdot
.47246 .09169 Mdot
.57971 .06628 Mdot
.80158 .13713 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48246 .61059 Mdot
.44416 .59436 Mdot
.32381 .54365 Mdot
.98993 .41169 Mdot
.67115 .42102 Mdot
.5624 .55082 Mdot
.54486 .6072 Mdot
.59374 .0302 Mdot
.4989 .61757 Mdot
.49649 .61655 Mdot
.48882 .61329 Mdot
.46441 .60294 Mdot
.38704 .57022 Mdot
.1541 .47407 Mdot
.72447 .35251 Mdot
.53051 .49816 Mdot
.38205 .52628 Mdot
.07241 .42667 Mdot
.65787 .36183 Mdot
.49774 .61708 Mdot
.4928 .61498 Mdot
.47707 .60831 Mdot
.42708 .58713 Mdot
.27148 .52187 Mdot
.87932 .37567 Mdot
.65132 .47713 Mdot
.61763 .59721 Mdot
.74476 .07857 Mdot
.1105 .22604 Mdot
.32348 .13163 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48126 .61009 Mdot
.44035 .59275 Mdot
.31203 .53873 Mdot
.96289 .40225 Mdot
.66891 .43634 Mdot
.58334 .56515 Mdot
.61714 .02089 Mdot
.81122 .11995 Mdot
.22659 .25671 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50717 .00304 Mdot
.52285 .00969 Mdot
.5727 .0308 Mdot
.72783 .09588 Mdot
.11938 .24199 Mdot
.34819 .14141 Mdot
.38227 .02107 Mdot
.25543 .53964 Mdot
.89 .39218 Mdot
.49754 .61699 Mdot
.49215 .6147 Mdot
.47499 .60743 Mdot
.42047 .58434 Mdot
.25155 .51364 Mdot
.84391 .3661 Mdot
.63464 .4887 Mdot
.60408 .59915 Mdot
.71874 .07087 Mdot
.06755 .21558 Mdot
.31805 .15481 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48244 .61059 Mdot
.4441 .59434 Mdot
.32363 .54358 Mdot
.98951 .41154 Mdot
.67112 .42125 Mdot
.56273 .55105 Mdot
.54601 .6077 Mdot
.59736 .03174 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52247 .00953 Mdot
.57147 .03029 Mdot
.72413 .09434 Mdot
.11236 .23994 Mdot
.34571 .14422 Mdot
.38221 .02256 Mdot
.25772 .54109 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.47953 .60935 Mdot
.43486 .59043 Mdot
.29518 .53171 Mdot
.92632 .39007 Mdot
.66408 .45596 Mdot
.60661 .58252 Mdot
.69738 .05609 Mdot
.01394 .19565 Mdot
.30962 .18274 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.51481 .00628 Mdot
.54716 .01999 Mdot
.64922 .06308 Mdot
.94373 .18202 Mdot
.3209 .2331 Mdot
.48263 .09995 Mdot
.61835 .08388 Mdot
.91567 .18376 Mdot
.33365 .25833 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50308 .0013 Mdot
.5098 .00416 Mdot
.53122 .01324 Mdot
.59916 .04199 Mdot
.80641 .12809 Mdot
.23755 .26646 Mdot
.43069 .11937 Mdot
.52312 .05713 Mdot
.65012 .07849 Mdot
.97036 .19792 Mdot
.4976 .61701 Mdot
.49234 .61479 Mdot
.47561 .60769 Mdot
.42244 .58517 Mdot
.25747 .51608 Mdot
.85403 .3687 Mdot
.64012 .48583 Mdot
.61026 .59958 Mdot
.73287 .07578 Mdot
.09284 .22247 Mdot
.32131 .1412 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.5053 .00225 Mdot
.51687 .00716 Mdot
.55372 .02277 Mdot
.66961 .07163 Mdot
.99443 .20075 Mdot
.3276 .20591 Mdot
.44986 .07556 Mdot
.49814 .02984 Mdot
.49842 .61737 Mdot
.49498 .6159 Mdot
.484 .61125 Mdot
.44906 .59644 Mdot
.33902 .55002 Mdot
.02662 .42496 Mdot
.67448 .4004 Mdot
.53469 .53164 Mdot
.44653 .56355 Mdot
.27965 .5149 Mdot
.87818 .36991 Mdot
.49749 .61697 Mdot
.49201 .61465 Mdot
.47455 .60724 Mdot
.41908 .58375 Mdot
.24738 .51192 Mdot
.83699 .3644 Mdot
.63055 .49045 Mdot
.5987 .59835 Mdot
.70558 .06606 Mdot
.04196 .20789 Mdot
.31613 .16945 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50562 .00238 Mdot
.51791 .0076 Mdot
.55702 .02417 Mdot
.67984 .07591 Mdot
.01857 .20935 Mdot
.32951 .19217 Mdot
.43089 .06266 Mdot
.43184 .00058 Mdot
.33363 .55734 Mdot
.0289 .4297 Mdot
.49915 .61767 Mdot
.49729 .61688 Mdot
.49135 .61437 Mdot
.47245 .60635 Mdot
.41243 .58094 Mdot
.22759 .50379 Mdot
.80637 .35771 Mdot
.60907 .4961 Mdot
.56287 .58948 Mdot
.60853 .02822 Mdot
.80467 .12122 Mdot
.49924 .61771 Mdot
.49757 .617 Mdot
.49224 .61474 Mdot
.47529 .60756 Mdot
.42141 .58474 Mdot
.25439 .51481 Mdot
.84873 .36732 Mdot
.63732 .48737 Mdot
.60727 .59946 Mdot
.72621 .07351 Mdot
.08122 .21941 Mdot
.49788 .61713 Mdot
.49324 .61517 Mdot
.47847 .60891 Mdot
.43151 .58901 Mdot
.28496 .52746 Mdot
.9054 .38346 Mdot
.65954 .46608 Mdot
.61487 .59043 Mdot
.72793 .06987 Mdot
.07742 .216 Mdot
.31531 .14702 Mdot
.49824 .61729 Mdot
.49438 .61565 Mdot
.48209 .61044 Mdot
.44299 .59387 Mdot
.3202 .54215 Mdot
.98153 .40872 Mdot
.6705 .42581 Mdot
.56903 .55532 Mdot
.5679 .61733 Mdot
.66555 .06035 Mdot
.96912 .18761 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50612 .0026 Mdot
.5195 .00827 Mdot
.56205 .0263 Mdot
.69535 .08238 Mdot
.05344 .22131 Mdot
.33287 .1727 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51875 .00795 Mdot
.55969 .0253 Mdot
.68808 .07935 Mdot
.03735 .21586 Mdot
.33111 .18156 Mdot
.41648 .05276 Mdot
.38224 .59687 Mdot
.18705 .4974 Mdot
.77156 .36124 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.47877 .60903 Mdot
.43246 .58941 Mdot
.28785 .52866 Mdot
.91122 .38527 Mdot
.66097 .46336 Mdot
.61305 .58842 Mdot
.72079 .06659 Mdot
.06326 .21166 Mdot
.31332 .15454 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50387 .00164 Mdot
.51235 .00524 Mdot
.53932 .01667 Mdot
.62466 .05275 Mdot
.87846 .15686 Mdot
.29736 .25889 Mdot
.48801 .11783 Mdot
.66071 .10673 Mdot
.03554 .23166 Mdot
.49793 .61716 Mdot
.49342 .61524 Mdot
.47903 .60914 Mdot
.43328 .58976 Mdot
.29034 .5297 Mdot
.91631 .38687 Mdot
.6621 .46093 Mdot
.61114 .58654 Mdot
.71367 .06337 Mdot
.04874 .20708 Mdot
.31184 .1626 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.5104 .00441 Mdot
.53312 .01404 Mdot
.60517 .04453 Mdot
.82373 .13508 Mdot
.25586 .26707 Mdot
.44943 .11963 Mdot
.5684 .07353 Mdot
.78685 .13501 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60745 Mdot
.42061 .5844 Mdot
.25198 .51381 Mdot
.84463 .36628 Mdot
.63505 .4885 Mdot
.60458 .59921 Mdot
.71995 .0713 Mdot
.0698 .21622 Mdot
.31828 .15357 Mdot
.4996 .61786 Mdot
.49873 .6175 Mdot
.49595 .61632 Mdot
.4871 .61256 Mdot
.45892 .60062 Mdot
.36981 .56296 Mdot
.10648 .45529 Mdot
.69508 .36377 Mdot
.50834 .50262 Mdot
.3341 .51035 Mdot
.95368 .38292 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.485 .61167 Mdot
.45223 .59778 Mdot
.34888 .55416 Mdot
.05142 .43419 Mdot
.67816 .38735 Mdot
.51972 .52012 Mdot
.3908 .53835 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50513 .00218 Mdot
.51635 .00693 Mdot
.55204 .02206 Mdot
.66441 .06945 Mdot
.98181 .19617 Mdot
.32644 .21299 Mdot
.45934 .08214 Mdot
.53191 .04485 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50721 .00306 Mdot
.52297 .00974 Mdot
.57307 .03096 Mdot
.72895 .09634 Mdot
.12149 .2426 Mdot
.34898 .1406 Mdot
.38244 .02068 Mdot
.25515 .53937 Mdot
.88926 .3919 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.5064 .00272 Mdot
.5204 .00865 Mdot
.56493 .02752 Mdot
.70416 .08605 Mdot
.07229 .22752 Mdot
.33568 .16278 Mdot
.39409 .0361 Mdot
.30511 .56304 Mdot
.99157 .42425 Mdot
.69067 .43207 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49233 .61478 Mdot
.47556 .60767 Mdot
.42228 .5851 Mdot
.25699 .51588 Mdot
.8532 .36848 Mdot
.63969 .48608 Mdot
.60982 .59958 Mdot
.73193 .07547 Mdot
.09124 .22206 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .00179 Mdot
.51347 .00571 Mdot
.54288 .01818 Mdot
.63584 .05745 Mdot
.90871 .16864 Mdot
.31113 .24871 Mdot
.49221 .11191 Mdot
.6616 .10469 Mdot
.03383 .23005 Mdot
.3557 .19893 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50756 .0032 Mdot
.52407 .01021 Mdot
.57657 .03244 Mdot
.73953 .10072 Mdot
.1407 .24794 Mdot
.35726 .13384 Mdot
.38729 .01856 Mdot
.26202 .54062 Mdot
.89871 .39349 Mdot
.67728 .48118 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51813 .00769 Mdot
.55771 .02446 Mdot
.68195 .07679 Mdot
.02345 .21105 Mdot
.3299 .1894 Mdot
.42707 .06006 Mdot
.41863 .61282 Mdot
.29339 .54063 Mdot
.93823 .39853 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50544 .00231 Mdot
.51733 .00735 Mdot
.55517 .02339 Mdot
.67413 .07352 Mdot
.0052 .20461 Mdot
.32847 .19979 Mdot
.44144 .06982 Mdot
.46855 .01675 Mdot
.44879 .60582 Mdot
.35353 .55916 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.5028 .00119 Mdot
.50892 .00378 Mdot
.5284 .01204 Mdot
.59026 .03823 Mdot
.78036 .11749 Mdot
.20486 .26236 Mdot
.40017 .12071 Mdot
.45536 .03411 Mdot
.44445 .6113 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00304 Mdot
.52286 .00969 Mdot
.57272 .03081 Mdot
.7279 .09591 Mdot
.11951 .24203 Mdot
.34824 .14136 Mdot
.38228 .02104 Mdot
.25541 .53962 Mdot
.88994 .39216 Mdot
.67672 .48625 Mdot
.49739 .61693 Mdot
.4917 .61451 Mdot
.47355 .60682 Mdot
.41592 .58241 Mdot
.23795 .50804 Mdot
.82192 .36092 Mdot
.62067 .49365 Mdot
.58357 .59511 Mdot
.66615 .05104 Mdot
.95509 .17857 Mdot
.3105 .21966 Mdot
.49993 .61801 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47783 .60863 Mdot
.42947 .58814 Mdot
.27873 .52488 Mdot
.89315 .37973 Mdot
.65607 .47151 Mdot
.61734 .5941 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48389 .6112 Mdot
.44871 .59629 Mdot
.33791 .54956 Mdot
.02387 .42395 Mdot
.67416 .4019 Mdot
.5366 .53301 Mdot
.45344 .56664 Mdot
.30143 .52409 Mdot
.92305 .38418 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50556 .00236 Mdot
.51772 .00752 Mdot
.55642 .02391 Mdot
.67797 .07512 Mdot
.01422 .20781 Mdot
.32917 .19465 Mdot
.43432 .06499 Mdot
.44372 .00581 Mdot
.37046 .57275 Mdot
.12364 .46549 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51813 .00769 Mdot
.55769 .02445 Mdot
.68191 .07677 Mdot
.02335 .21102 Mdot
.32989 .18945 Mdot
.42714 .06011 Mdot
.41889 .61293 Mdot
.29417 .54095 Mdot
.93985 .39905 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00343 Mdot
.52579 .01094 Mdot
.582 .03474 Mdot
.75583 .10744 Mdot
.16824 .25488 Mdot
.37273 .12638 Mdot
.40601 .02057 Mdot
.30638 .55645 Mdot
.98282 .41807 Mdot
.68499 .43396 Mdot
.49919 .61769 Mdot
.49743 .61694 Mdot
.4918 .61456 Mdot
.47388 .60696 Mdot
.41694 .58285 Mdot
.24101 .5093 Mdot
.82672 .36199 Mdot
.62396 .49272 Mdot
.5889 .59637 Mdot
.68036 .05653 Mdot
.98807 .19017 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50386 .00164 Mdot
.51229 .00521 Mdot
.53913 .01659 Mdot
.62408 .0525 Mdot
.87685 .15622 Mdot
.29646 .25933 Mdot
.48743 .11803 Mdot
.65958 .10639 Mdot
.03297 .23076 Mdot
.35725 .20042 Mdot
.49878 .61752 Mdot
.4961 .61638 Mdot
.48758 .61277 Mdot
.46046 .60127 Mdot
.37463 .56499 Mdot
.1196 .46042 Mdot
.70158 .35969 Mdot
.51134 .50046 Mdot
.33809 .51096 Mdot
.96175 .38544 Mdot
.64223 .42056 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.5201 .00852 Mdot
.56395 .0271 Mdot
.70116 .0848 Mdot
.06596 .22546 Mdot
.33462 .16604 Mdot
.39752 .03887 Mdot
.31709 .56833 Mdot
.01882 .4337 Mdot
.69239 .41629 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.5152 .00645 Mdot
.54841 .02052 Mdot
.6531 .06471 Mdot
.95364 .18574 Mdot
.32274 .22812 Mdot
.4776 .09571 Mdot
.59899 .07502 Mdot
.85946 .16098 Mdot
.3044 .27499 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50332 .00141 Mdot
.51059 .00449 Mdot
.53372 .0143 Mdot
.60707 .04533 Mdot
.82918 .13727 Mdot
.26108 .26693 Mdot
.45483 .11974 Mdot
.58173 .07843 Mdot
.82589 .1509 Mdot
.28216 .28199 Mdot
.50057 .00024 Mdot
.5018 .00076 Mdot
.50574 .00244 Mdot
.5183 .00776 Mdot
.55824 .02469 Mdot
.68361 .07748 Mdot
.02725 .21238 Mdot
.33021 .18724 Mdot
.42412 .05804 Mdot
.40847 .60836 Mdot
.26297 .52811 Mdot
.87953 .38106 Mdot
.4995 .61782 Mdot
.4984 .61736 Mdot
.49491 .61587 Mdot
.48378 .61115 Mdot
.44835 .59614 Mdot
.3368 .54909 Mdot
.02114 .42295 Mdot
.67387 .40341 Mdot
.53853 .53439 Mdot
.46043 .56976 Mdot
.32357 .53345 Mdot
.49871 .61749 Mdot
.4959 .61629 Mdot
.48693 .61249 Mdot
.45836 .60038 Mdot
.36806 .56222 Mdot
.10175 .45345 Mdot
.693 .36541 Mdot
.50784 .5036 Mdot
.33442 .51086 Mdot
.95508 .38359 Mdot
.64223 .42468 Mdot
.49771 .61706 Mdot
.49269 .61493 Mdot
.47671 .60816 Mdot
.42593 .58665 Mdot
.26801 .52043 Mdot
.87288 .37383 Mdot
.64879 .47954 Mdot
.61678 .59825 Mdot
.74464 .07902 Mdot
.11109 .22648 Mdot
.32411 .13165 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52456 .01041 Mdot
.5781 .03309 Mdot
.74415 .10262 Mdot
.14876 .25007 Mdot
.36134 .13138 Mdot
.39125 .01849 Mdot
.27044 .54337 Mdot
.91287 .39704 Mdot
.67956 .47384 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47591 .60782 Mdot
.4234 .58558 Mdot
.26037 .51727 Mdot
.85911 .37004 Mdot
.64265 .48425 Mdot
.61264 .59949 Mdot
.73782 .07737 Mdot
.10104 .22448 Mdot
.32268 .13698 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50412 .00175 Mdot
.51314 .00557 Mdot
.54184 .01774 Mdot
.63258 .05608 Mdot
.89998 .16526 Mdot
.30773 .252 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.4793 .60926 Mdot
.43414 .59012 Mdot
.29299 .5308 Mdot
.92176 .3886 Mdot
.66322 .45825 Mdot
.6088 .5844 Mdot
.70516 .05955 Mdot
.03084 .20128 Mdot
.31055 .17287 Mdot
.49801 .61719 Mdot
.49365 .61534 Mdot
.47976 .60945 Mdot
.43561 .59075 Mdot
.29748 .53267 Mdot
.93117 .39164 Mdot
.66491 .45348 Mdot
.60408 .58043 Mdot
.68846 .05215 Mdot
.99395 .1888 Mdot
.30851 .19441 Mdot
.49855 .61742 Mdot
.49537 .61607 Mdot
.48525 .61178 Mdot
.45302 .59812 Mdot
.35135 .5552 Mdot
.05773 .43657 Mdot
.6794 .38421 Mdot
.51671 .51748 Mdot
.37902 .53294 Mdot
.07685 .43128 Mdot
.66383 .36278 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52399 .01017 Mdot
.57631 .03233 Mdot
.73876 .1004 Mdot
.13935 .24758 Mdot
.35661 .13428 Mdot
.38674 .01862 Mdot
.26094 .54029 Mdot
.89698 .39309 Mdot
.67698 .48207 Mdot
.49834 .61733 Mdot
.4947 .61579 Mdot
.48311 .61087 Mdot
.44622 .59524 Mdot
.33019 .54632 Mdot
.00509 .41711 Mdot
.67236 .41239 Mdot
.55051 .54273 Mdot
.50316 .58877 Mdot
.46055 .5917 Mdot
.35938 .5555 Mdot
.49799 .61718 Mdot
.49358 .61531 Mdot
.47955 .60936 Mdot
.43493 .59046 Mdot
.29539 .5318 Mdot
.92676 .39021 Mdot
.66416 .45573 Mdot
.60639 .58233 Mdot
.69658 .05574 Mdot
.01218 .19505 Mdot
.30953 .18377 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50395 .00168 Mdot
.5126 .00534 Mdot
.54012 .01701 Mdot
.62719 .05381 Mdot
.88538 .15957 Mdot
.30102 .25688 Mdot
.49008 .11685 Mdot
.66428 .10766 Mdot
.04341 .23432 Mdot
.35823 .19457 Mdot
.50042 .00018 Mdot
.50132 .00056 Mdot
.50422 .00179 Mdot
.51344 .0057 Mdot
.5428 .01815 Mdot
.6356 .05735 Mdot
.90807 .1684 Mdot
.31089 .24896 Mdot
.49224 .11208 Mdot
.66196 .10489 Mdot
.03482 .23044 Mdot
.35586 .19842 Mdot
.49922 .6177 Mdot
.4975 .61698 Mdot
.49205 .61466 Mdot
.47467 .60729 Mdot
.41945 .58391 Mdot
.24851 .51238 Mdot
.83884 .36485 Mdot
.63167 .49 Mdot
.60023 .5986 Mdot
.70938 .06746 Mdot
.04954 .21023 Mdot
.49883 .61754 Mdot
.49626 .61645 Mdot
.48809 .61298 Mdot
.46207 .60195 Mdot
.37968 .56712 Mdot
.13353 .4659 Mdot
.70976 .35613 Mdot
.51715 .49899 Mdot
.3502 .51485 Mdot
.99029 .3956 Mdot
.64494 .4046 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .00179 Mdot
.51347 .00571 Mdot
.5429 .01819 Mdot
.63592 .05748 Mdot
.90891 .16872 Mdot
.3112 .24863 Mdot
.49219 .11186 Mdot
.66148 .10462 Mdot
.03351 .22993 Mdot
.35565 .19909 Mdot
.4995 .61782 Mdot
.49842 .61737 Mdot
.49497 .6159 Mdot
.48399 .61124 Mdot
.44903 .59643 Mdot
.33891 .54998 Mdot
.02634 .42486 Mdot
.67445 .40055 Mdot
.53488 .53178 Mdot
.44722 .56386 Mdot
.28185 .51582 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.52048 .00869 Mdot
.56518 .02762 Mdot
.70494 .08637 Mdot
.07392 .22804 Mdot
.33597 .16196 Mdot
.39327 .03542 Mdot
.30221 .56176 Mdot
.98515 .42208 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47384 .60694 Mdot
.41683 .5828 Mdot
.24068 .50916 Mdot
.8262 .36187 Mdot
.62361 .49283 Mdot
.58835 .59624 Mdot
.67891 .05597 Mdot
.98479 .18904 Mdot
.31345 .20312 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50629 .00267 Mdot
.52004 .0085 Mdot
.56378 .02703 Mdot
.70064 .08459 Mdot
.06485 .22509 Mdot
.33445 .16662 Mdot
.39815 .03937 Mdot
.3193 .5693 Mdot
.02398 .43552 Mdot
.69283 .41337 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52051 .0087 Mdot
.56527 .02766 Mdot
.70522 .08649 Mdot
.07451 .22823 Mdot
.33607 .16166 Mdot
.39298 .03517 Mdot
.30117 .5613 Mdot
.98287 .42131 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50707 .003 Mdot
.52251 .00954 Mdot
.5716 .03034 Mdot
.7245 .0945 Mdot
.11307 .24015 Mdot
.34595 .14393 Mdot
.38218 .02239 Mdot
.2574 .54091 Mdot
.89414 .39353 Mdot
.67822 .48459 Mdot
.49825 .61729 Mdot
.49441 .61567 Mdot
.48221 .61049 Mdot
.44336 .59403 Mdot
.32134 .54262 Mdot
.98418 .40966 Mdot
.67071 .4243 Mdot
.56695 .55391 Mdot
.56067 .61415 Mdot
.6432 .05101 Mdot
.91271 .16656 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48445 .61144 Mdot
.4505 .59705 Mdot
.34348 .55189 Mdot
.03774 .42908 Mdot
.67592 .39441 Mdot
.52743 .52626 Mdot
.41988 .55156 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49284 .615 Mdot
.47721 .60837 Mdot
.4275 .58731 Mdot
.27275 .5224 Mdot
.88171 .37636 Mdot
.65221 .4762 Mdot
.61779 .59676 Mdot
.74435 .07822 Mdot
.10949 .22567 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00255 Mdot
.51913 .00811 Mdot
.56088 .0258 Mdot
.69175 .08088 Mdot
.04553 .21865 Mdot
.33195 .17702 Mdot
.41058 .0486 Mdot
.36204 .58803 Mdot
.1315 .47556 Mdot
.72541 .36705 Mdot
.49845 .61738 Mdot
.49508 .61595 Mdot
.48431 .61138 Mdot
.45005 .59686 Mdot
.3421 .55131 Mdot
.03428 .42779 Mdot
.67544 .39626 Mdot
.52961 .52791 Mdot
.42793 .5552 Mdot
.22182 .49065 Mdot
.7807 .34541 Mdot
.4996 .61786 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.4869 .61248 Mdot
.45829 .60035 Mdot
.36783 .56213 Mdot
.10112 .4532 Mdot
.69274 .36564 Mdot
.50779 .50373 Mdot
.33454 .51096 Mdot
.95544 .38374 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50608 .00258 Mdot
.51938 .00822 Mdot
.56169 .02615 Mdot
.69423 .08191 Mdot
.05099 .22049 Mdot
.33257 .17402 Mdot
.40683 .04589 Mdot
.34917 .5824 Mdot
.09765 .46258 Mdot
.70867 .37763 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54192 .01777 Mdot
.63282 .05618 Mdot
.90063 .16551 Mdot
.30799 .25176 Mdot
.4923 .11391 Mdot
.66506 .10677 Mdot
.04336 .2338 Mdot
.35742 .1941 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47788 .60866 Mdot
.42964 .58822 Mdot
.27925 .52509 Mdot
.89416 .38003 Mdot
.65638 .47108 Mdot
.61721 .59382 Mdot
.73838 .07489 Mdot
.09765 .22204 Mdot
.31946 .13709 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48398 .61124 Mdot
.44899 .59641 Mdot
.33878 .54992 Mdot
.02604 .42475 Mdot
.67441 .40072 Mdot
.53509 .53193 Mdot
.44799 .5642 Mdot
.28425 .51684 Mdot
.88729 .3727 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50692 .00294 Mdot
.52205 .00935 Mdot
.57016 .02973 Mdot
.72013 .09269 Mdot
.10465 .23764 Mdot
.34326 .14747 Mdot
.38296 .02454 Mdot
.26251 .54359 Mdot
.90406 .3965 Mdot
.68096 .48015 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.5108 .00458 Mdot
.53441 .01459 Mdot
.60922 .04624 Mdot
.8353 .13973 Mdot
.26664 .26658 Mdot
.46055 .11984 Mdot
.59588 .08364 Mdot
.8665 .16725 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.525 .0106 Mdot
.57949 .03368 Mdot
.74831 .10434 Mdot
.15586 .25188 Mdot
.36523 .1294 Mdot
.39576 .01887 Mdot
.28087 .54703 Mdot
.93172 .40225 Mdot
.68188 .46363 Mdot
.49981 .61795 Mdot
.49939 .61777 Mdot
.49805 .6172 Mdot
.49377 .61539 Mdot
.48016 .60962 Mdot
.43685 .59127 Mdot
.3013 .53426 Mdot
.93931 .39431 Mdot
.66616 .44922 Mdot
.59939 .57677 Mdot
.6722 .045 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48195 .61038 Mdot
.44254 .59368 Mdot
.3188 .54156 Mdot
.97829 .40759 Mdot
.67024 .42765 Mdot
.57157 .55705 Mdot
.57668 .00316 Mdot
.69241 .07153 Mdot
.03142 .20952 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48467 .61154 Mdot
.45121 .59735 Mdot
.34569 .55282 Mdot
.0433 .43115 Mdot
.67676 .3915 Mdot
.52412 .5237 Mdot
.40751 .54597 Mdot
.15986 .46497 Mdot
.71075 .34047 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00136 Mdot
.51024 .00434 Mdot
.53263 .01383 Mdot
.6036 .04387 Mdot
.81924 .13327 Mdot
.25138 .26707 Mdot
.44478 .11953 Mdot
.55702 .06937 Mdot
.75297 .1211 Mdot
.18761 .26862 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50353 .0015 Mdot
.51124 .00477 Mdot
.5358 .01518 Mdot
.6136 .04808 Mdot
.8477 .14468 Mdot
.27694 .26529 Mdot
.47087 .11985 Mdot
.62135 .093 Mdot
.93671 .19491 Mdot
.34453 .25204 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50428 .00182 Mdot
.51364 .00578 Mdot
.54343 .01841 Mdot
.63757 .05818 Mdot
.91331 .17042 Mdot
.31275 .24687 Mdot
.49177 .11064 Mdot
.65846 .10302 Mdot
.02547 .22682 Mdot
.35444 .20331 Mdot
.50015 6e-05 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51565 .00664 Mdot
.54983 .02112 Mdot
.65754 .06657 Mdot
.96481 .18991 Mdot
.32444 .22226 Mdot
.47097 .09056 Mdot
.5742 .0638 Mdot
.78475 .13012 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50306 .0013 Mdot
.50974 .00413 Mdot
.53102 .01315 Mdot
.59853 .04172 Mdot
.80456 .12734 Mdot
.23544 .2663 Mdot
.42858 .11937 Mdot
.51816 .05536 Mdot
.63493 .07217 Mdot
.9307 .1828 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51786 .00757 Mdot
.55686 .0241 Mdot
.67933 .0757 Mdot
.0174 .20893 Mdot
.32942 .19284 Mdot
.43181 .06328 Mdot
.43502 .00199 Mdot
.34346 .56144 Mdot
.05315 .43862 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48053 .60978 Mdot
.43805 .59178 Mdot
.30498 .53579 Mdot
.94727 .39696 Mdot
.66722 .44495 Mdot
.59433 .57298 Mdot
.65479 .03737 Mdot
.91253 .15929 Mdot
.29497 .23636 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50285 .00121 Mdot
.50907 .00385 Mdot
.5289 .01225 Mdot
.59183 .03889 Mdot
.78498 .11937 Mdot
.21112 .26337 Mdot
.40562 .12021 Mdot
.4667 .03775 Mdot
.47819 .0071 Mdot
.45706 .60498 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00117 Mdot
.50877 .00372 Mdot
.52794 .01185 Mdot
.5888 .03761 Mdot
.77605 .11573 Mdot
.19884 .2613 Mdot
.39513 .12131 Mdot
.44525 .03098 Mdot
.49928 .61773 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47683 .60821 Mdot
.4263 .58681 Mdot
.26914 .5209 Mdot
.87497 .37442 Mdot
.64964 .47877 Mdot
.61713 .59794 Mdot
.74488 .07895 Mdot
.11124 .22642 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50451 .00191 Mdot
.51436 .00609 Mdot
.54571 .01938 Mdot
.64469 .06117 Mdot
.93202 .17758 Mdot
.31825 .2387 Mdot
.48736 .10452 Mdot
.63753 .09281 Mdot
.96927 .20502 Mdot
.34682 .23334 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50521 .00221 Mdot
.51661 .00704 Mdot
.55287 .02241 Mdot
.66698 .07052 Mdot
.98807 .19845 Mdot
.32704 .20949 Mdot
.4547 .0789 Mdot
.51534 .03747 Mdot
.59895 .05167 Mdot
.8216 .1376 Mdot
.499 .61761 Mdot
.49683 .61669 Mdot
.48988 .61374 Mdot
.46778 .60437 Mdot
.39768 .57471 Mdot
.18444 .48625 Mdot
.75245 .35104 Mdot
.55915 .49857 Mdot
.45256 .55216 Mdot
.27586 .50883 Mdot
.86357 .36323 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.5235 .00997 Mdot
.57476 .03168 Mdot
.73406 .09846 Mdot
.13091 .24526 Mdot
.3528 .13713 Mdot
.38404 .01931 Mdot
.25632 .5391 Mdot
.89006 .39167 Mdot
.6759 .48568 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52164 .00917 Mdot
.56883 .02917 Mdot
.71609 .09101 Mdot
.09669 .23522 Mdot
.34101 .151 Mdot
.38458 .02693 Mdot
.26979 .54709 Mdot
.91811 .40069 Mdot
.68392 .47329 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47678 .60819 Mdot
.42614 .58674 Mdot
.26864 .5207 Mdot
.87405 .37416 Mdot
.64927 .47911 Mdot
.61699 .59808 Mdot
.7448 .07899 Mdot
.11122 .22646 Mdot
.32406 .13154 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48534 .61182 Mdot
.45331 .59824 Mdot
.35226 .55558 Mdot
.06007 .43745 Mdot
.6799 .38308 Mdot
.51568 .51654 Mdot
.37496 .53106 Mdot
.06537 .4267 Mdot
.66046 .36779 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54096 .01737 Mdot
.62982 .05492 Mdot
.89253 .16236 Mdot
.30447 .25459 Mdot
.49152 .1156 Mdot
.66585 .10775 Mdot
.04633 .23514 Mdot
.35829 .1928 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50824 .00349 Mdot
.52624 .01113 Mdot
.58344 .03535 Mdot
.76014 .10921 Mdot
.17509 .25645 Mdot
.37726 .12495 Mdot
.41305 .02212 Mdot
.3248 .56349 Mdot
.0237 .43195 Mdot
.68718 .41005 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51774 .00752 Mdot
.55648 .02394 Mdot
.67817 .07521 Mdot
.01468 .20798 Mdot
.49872 .61749 Mdot
.49592 .6163 Mdot
.487 .61252 Mdot
.45862 .60049 Mdot
.36885 .56255 Mdot
.10388 .45427 Mdot
.69392 .36467 Mdot
.50802 .50315 Mdot
.33416 .51058 Mdot
.95417 .38319 Mdot
.64198 .42509 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48815 .61301 Mdot
.46226 .60203 Mdot
.38028 .56737 Mdot
.13519 .46656 Mdot
.71083 .35577 Mdot
.51802 .49887 Mdot
.35217 .51554 Mdot
.99512 .39737 Mdot
.64539 .40188 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50554 .00235 Mdot
.51763 .00748 Mdot
.55613 .02379 Mdot
.67709 .07476 Mdot
.01216 .20709 Mdot
.32901 .19582 Mdot
.43594 .06609 Mdot
.44937 .0083 Mdot
.38812 .58018 Mdot
.17253 .48479 Mdot
.49889 .61756 Mdot
.49646 .61653 Mdot
.48871 .61325 Mdot
.46405 .60279 Mdot
.38591 .56974 Mdot
.15093 .47281 Mdot
.72199 .35294 Mdot
.5281 .4982 Mdot
.37615 .52412 Mdot
.0566 .42054 Mdot
.65393 .36917 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51093 .00463 Mdot
.5348 .01476 Mdot
.61047 .04676 Mdot
.83885 .14115 Mdot
.26972 .26629 Mdot
.46369 .11988 Mdot
.60366 .08651 Mdot
.88835 .17595 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.5114 .00483 Mdot
.5363 .01539 Mdot
.61519 .04876 Mdot
.85218 .14646 Mdot
.28036 .26463 Mdot
.47414 .11976 Mdot
.62932 .0959 Mdot
.95781 .20302 Mdot
.49777 .61709 Mdot
.49288 .61502 Mdot
.47733 .60842 Mdot
.42789 .58748 Mdot
.27393 .52289 Mdot
.88394 .37701 Mdot
.65301 .47531 Mdot
.61785 .5963 Mdot
.74374 .07781 Mdot
.10818 .22524 Mdot
.32256 .13249 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .00139 Mdot
.51047 .00444 Mdot
.53334 .01414 Mdot
.60586 .04482 Mdot
.82571 .13588 Mdot
.25779 .26704 Mdot
.45142 .11967 Mdot
.57331 .07533 Mdot
.80133 .14092 Mdot
.25577 .28086 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50639 .00271 Mdot
.52036 .00863 Mdot
.56478 .02745 Mdot
.70372 .08587 Mdot
.07136 .22722 Mdot
.33551 .16326 Mdot
.39457 .0365 Mdot
.30681 .56379 Mdot
.99536 .42555 Mdot
.69087 .42985 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51238 .00525 Mdot
.53943 .01672 Mdot
.62503 .0529 Mdot
.87946 .15725 Mdot
.29791 .25861 Mdot
.48835 .1177 Mdot
.66135 .10692 Mdot
.03698 .23216 Mdot
.35764 .19818 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50736 .00312 Mdot
.52346 .00995 Mdot
.57462 .03162 Mdot
.73364 .09828 Mdot
.13014 .24505 Mdot
.35247 .1374 Mdot
.38385 .0194 Mdot
.25607 .53906 Mdot
.88973 .39162 Mdot
.67588 .48586 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47473 .60732 Mdot
.41965 .58399 Mdot
.24911 .51263 Mdot
.83984 .36509 Mdot
.63226 .48975 Mdot
.60102 .59873 Mdot
.71135 .06819 Mdot
.0534 .2114 Mdot
.31685 .16282 Mdot
.49929 .61773 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47715 .60835 Mdot
.42732 .58724 Mdot
.27223 .52218 Mdot
.88073 .37607 Mdot
.65185 .47658 Mdot
.61773 .59695 Mdot
.74455 .07837 Mdot
.10995 .22583 Mdot
.49931 .61774 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47766 .60856 Mdot
.42892 .58791 Mdot
.27708 .52419 Mdot
.88994 .37877 Mdot
.65505 .47286 Mdot
.61765 .59492 Mdot
.74109 .07629 Mdot
.10289 .2236 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48244 .61059 Mdot
.4441 .59434 Mdot
.32364 .54358 Mdot
.98954 .41155 Mdot
.67112 .42124 Mdot
.56271 .55103 Mdot
.54596 .60768 Mdot
.59719 .03166 Mdot
.7853 .11626 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.48479 .61158 Mdot
.45157 .5975 Mdot
.34682 .5533 Mdot
.04617 .43222 Mdot
.67723 .39002 Mdot
.5225 .52241 Mdot
.40142 .5432 Mdot
.14173 .45754 Mdot
.69645 .34284 Mdot
.49766 .61704 Mdot
.49255 .61488 Mdot
.47628 .60798 Mdot
.42455 .58607 Mdot
.26385 .51871 Mdot
.86532 .37173 Mdot
.64554 .48221 Mdot
.61491 .5991 Mdot
.74205 .07858 Mdot
.10762 .22594 Mdot
.32379 .1336 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48773 .61283 Mdot
.46092 .60146 Mdot
.37607 .56559 Mdot
.12355 .46197 Mdot
.70376 .35859 Mdot
.51271 .49996 Mdot
.34071 .51173 Mdot
.9677 .3875 Mdot
.49877 .61751 Mdot
.49607 .61637 Mdot
.48747 .61272 Mdot
.46009 .60112 Mdot
.37348 .56451 Mdot
.11646 .45919 Mdot
.69993 .3606 Mdot
.5104 .5009 Mdot
.33648 .51054 Mdot
.9582 .38425 Mdot
.6419 .42255 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48135 .61012 Mdot
.44063 .59287 Mdot
.3129 .5391 Mdot
.96485 .40292 Mdot
.66909 .43525 Mdot
.58189 .56414 Mdot
.61216 .01871 Mdot
.79709 .11429 Mdot
.21037 .25543 Mdot
.50054 .00023 Mdot
.50173 .00074 Mdot
.50553 .00234 Mdot
.51761 .00747 Mdot
.55604 .02375 Mdot
.67681 .07464 Mdot
.01152 .20686 Mdot
.32896 .19619 Mdot
.43645 .06643 Mdot
.45114 .00908 Mdot
.39369 .58253 Mdot
.18836 .49114 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50995 .00422 Mdot
.53171 .01344 Mdot
.6007 .04264 Mdot
.81087 .12989 Mdot
.24252 .26678 Mdot
.43571 .11939 Mdot
.53506 .0614 Mdot
.68656 .09364 Mdot
.05809 .22962 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48789 .6129 Mdot
.46143 .60168 Mdot
.37767 .56627 Mdot
.12795 .4637 Mdot
.70632 .35745 Mdot
.5145 .49948 Mdot
.34439 .5129 Mdot
.97632 .39055 Mdot
.64364 .41243 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.5025 .00106 Mdot
.50796 .00337 Mdot
.52535 .01075 Mdot
.58061 .03415 Mdot
.75168 .10573 Mdot
.16148 .25327 Mdot
.36852 .12796 Mdot
.40003 .01947 Mdot
.29125 .5508 Mdot
.9517 .40819 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51254 .00532 Mdot
.53992 .01693 Mdot
.62656 .05355 Mdot
.88366 .1589 Mdot
.30014 .2574 Mdot
.48963 .11711 Mdot
.66358 .10751 Mdot
.04192 .23383 Mdot
.49952 .61783 Mdot
.49847 .61739 Mdot
.49514 .61597 Mdot
.48451 .61146 Mdot
.45067 .59712 Mdot
.34401 .55212 Mdot
.03908 .42957 Mdot
.67611 .39371 Mdot
.52662 .52564 Mdot
.41685 .5502 Mdot
.18797 .47658 Mdot
.4997 .61791 Mdot
.49903 .61762 Mdot
.49692 .61673 Mdot
.49019 .61387 Mdot
.46875 .60478 Mdot
.40073 .576 Mdot
.19329 .48982 Mdot
.7621 .35155 Mdot
.56896 .49867 Mdot
.47606 .56062 Mdot
.34739 .53851 Mdot
.49927 .61772 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47636 .60801 Mdot
.4248 .58617 Mdot
.26459 .51902 Mdot
.86665 .37209 Mdot
.64614 .48175 Mdot
.61531 .59898 Mdot
.7427 .07873 Mdot
.10858 .22612 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47384 .60694 Mdot
.41683 .5828 Mdot
.24067 .50916 Mdot
.82619 .36187 Mdot
.6236 .49283 Mdot
.58834 .59624 Mdot
.67888 .05596 Mdot
.98472 .18902 Mdot
.31344 .20316 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51823 .00773 Mdot
.55801 .02459 Mdot
.6829 .07718 Mdot
.02561 .21181 Mdot
.33007 .18817 Mdot
.42538 .05891 Mdot
.41283 .61027 Mdot
.27595 .53344 Mdot
.9035 .38785 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49293 .61503 Mdot
.47746 .60848 Mdot
.4283 .58765 Mdot
.2752 .52341 Mdot
.88636 .37771 Mdot
.65386 .47434 Mdot
.61783 .59577 Mdot
.74285 .07726 Mdot
.10636 .22466 Mdot
.50027 .00012 Mdot
.50086 .00037 Mdot
.50276 .00117 Mdot
.50878 .00372 Mdot
.52796 .01186 Mdot
.58888 .03765 Mdot
.7763 .11583 Mdot
.1992 .26137 Mdot
.39542 .12127 Mdot
.44583 .03115 Mdot
.41653 .59993 Mdot
.2677 .52605 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48015 .60962 Mdot
.43682 .59126 Mdot
.30119 .53421 Mdot
.93908 .39423 Mdot
.66613 .44934 Mdot
.59953 .57687 Mdot
.67268 .04521 Mdot
.95693 .17568 Mdot
.305 .21512 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47918 .60921 Mdot
.43375 .58996 Mdot
.29179 .5303 Mdot
.91929 .38781 Mdot
.66273 .45947 Mdot
.6099 .58538 Mdot
.70912 .06132 Mdot
.03924 .20403 Mdot
.3111 .16801 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49613 .61639 Mdot
.48767 .61281 Mdot
.46074 .60139 Mdot
.37552 .56536 Mdot
.12205 .46138 Mdot
.70292 .359 Mdot
.51216 .50014 Mdot
.33963 .5114 Mdot
.96524 .38665 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52352 .00997 Mdot
.57481 .0317 Mdot
.73421 .09852 Mdot
.13118 .24534 Mdot
.35291 .13704 Mdot
.3841 .01928 Mdot
.25641 .53912 Mdot
.89018 .39169 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51398 .00593 Mdot
.54453 .01888 Mdot
.641 .05962 Mdot
.92236 .17389 Mdot
.31562 .24305 Mdot
.49015 .10787 Mdot
.64992 .09874 Mdot
.00275 .21806 Mdot
.35146 .21551 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54095 .01736 Mdot
.62979 .05491 Mdot
.89244 .16233 Mdot
.30442 .25462 Mdot
.4915 .11562 Mdot
.66585 .10775 Mdot
.04632 .23515 Mdot
.35829 .19281 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48702 .61253 Mdot
.45868 .60052 Mdot
.36905 .56264 Mdot
.10441 .45448 Mdot
.69415 .36448 Mdot
.50808 .50304 Mdot
.33412 .51052 Mdot
.95402 .38311 Mdot
.64193 .42515 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48702 .61253 Mdot
.45866 .60051 Mdot
.369 .56262 Mdot
.10428 .45443 Mdot
.6941 .36452 Mdot
.50807 .50306 Mdot
.33413 .51054 Mdot
.95405 .38313 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51104 .00468 Mdot
.53516 .01491 Mdot
.61161 .04724 Mdot
.84207 .14243 Mdot
.27242 .26597 Mdot
.4664 .11989 Mdot
.61037 .08898 Mdot
.90694 .18329 Mdot
.33528 .26473 Mdot
.49902 .61762 Mdot
.49687 .61671 Mdot
.49004 .61381 Mdot
.46828 .60459 Mdot
.39926 .57538 Mdot
.18902 .4881 Mdot
.75736 .35125 Mdot
.56418 .49864 Mdot
.46467 .55653 Mdot
.31259 .52404 Mdot
.94 .38776 Mdot
.50081 .00034 Mdot
.50258 .0011 Mdot
.50823 .00349 Mdot
.52622 .01112 Mdot
.58336 .03531 Mdot
.75989 .10911 Mdot
.1747 .25637 Mdot
.377 .12503 Mdot
.41263 .02202 Mdot
.32368 .56306 Mdot
.02112 .43104 Mdot
.68698 .41152 Mdot
.49881 .61753 Mdot
.49621 .61643 Mdot
.48791 .61291 Mdot
.46151 .60171 Mdot
.37793 .56638 Mdot
.12867 .46399 Mdot
.70676 .35728 Mdot
.51482 .49941 Mdot
.34507 .51313 Mdot
.97794 .39113 Mdot
.64379 .41152 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.5201 .00852 Mdot
.56396 .02711 Mdot
.7012 .08482 Mdot
.06604 .22548 Mdot
.33464 .166 Mdot
.39747 .03883 Mdot
.31693 .56826 Mdot
.01845 .43357 Mdot
.69236 .4165 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50676 .00287 Mdot
.52153 .00913 Mdot
.56848 .02902 Mdot
.71503 .09057 Mdot
.09457 .23457 Mdot
.34045 .15197 Mdot
.38514 .02762 Mdot
.27211 .54818 Mdot
.92264 .40205 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50366 .00155 Mdot
.51167 .00495 Mdot
.53716 .01575 Mdot
.61789 .04989 Mdot
.85971 .14945 Mdot
.28576 .26331 Mdot
.47907 .11948 Mdot
.64108 .10013 Mdot
.98807 .21445 Mdot
.35294 .2255 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50662 .00281 Mdot
.5211 .00895 Mdot
.56714 .02845 Mdot
.71094 .08887 Mdot
.08631 .23199 Mdot
.33847 .15584 Mdot
.38784 .03051 Mdot
.28256 .55297 Mdot
.94353 .4085 Mdot
.49897 .6176 Mdot
.4967 .61664 Mdot
.4895 .61358 Mdot
.46655 .60385 Mdot
.39381 .57307 Mdot
.17333 .48177 Mdot
.74129 .35102 Mdot
.54762 .49834 Mdot
.42433 .54183 Mdot
.19176 .4743 Mdot
.73626 .33652 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48495 .61165 Mdot
.45209 .59772 Mdot
.34844 .55398 Mdot
.05029 .43377 Mdot
.67795 .38792 Mdot
.5203 .5206 Mdot
.39302 .53937 Mdot
.11709 .4475 Mdot
.68094 .34848 Mdot
.49883 .61754 Mdot
.49626 .61645 Mdot
.48808 .61298 Mdot
.46203 .60194 Mdot
.37958 .56707 Mdot
.13324 .46579 Mdot
.70958 .3562 Mdot
.517 .49901 Mdot
.34987 .51474 Mdot
.98948 .3953 Mdot
.64486 .40505 Mdot
.49876 .61751 Mdot
.49604 .61635 Mdot
.48738 .61268 Mdot
.4598 .60099 Mdot
.37257 .56412 Mdot
.11398 .45821 Mdot
.69866 .36135 Mdot
.50976 .50129 Mdot
.33549 .51033 Mdot
.95612 .38357 Mdot
.64173 .42373 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.48899 .61337 Mdot
.46495 .60317 Mdot
.38874 .57094 Mdot
.15892 .476 Mdot
.7284 .35196 Mdot
.53442 .49815 Mdot
.39166 .52981 Mdot
.09866 .43695 Mdot
.66697 .35123 Mdot
.49935 .61776 Mdot
.49793 .61715 Mdot
.49339 .61523 Mdot
.47895 .60911 Mdot
.43303 .58965 Mdot
.28958 .52938 Mdot
.91474 .38637 Mdot
.66176 .46168 Mdot
.61176 .58713 Mdot
.71595 .06439 Mdot
.05343 .20857 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .0029 Mdot
.52182 .00925 Mdot
.56942 .02942 Mdot
.71787 .09175 Mdot
.1002 .2363 Mdot
.34197 .14942 Mdot
.38376 .02583 Mdot
.2663 .54544 Mdot
.91135 .39866 Mdot
.68261 .47666 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50527 .00223 Mdot
.51678 .00712 Mdot
.55342 .02264 Mdot
.66869 .07124 Mdot
.99221 .19995 Mdot
.32741 .20716 Mdot
.45156 .07673 Mdot
.50418 .03252 Mdot
.56306 .03639 Mdot
.49824 .61729 Mdot
.49441 .61566 Mdot
.48218 .61048 Mdot
.44329 .594 Mdot
.32111 .54253 Mdot
.98364 .40947 Mdot
.67067 .4246 Mdot
.56737 .55419 Mdot
.56214 .6148 Mdot
.64777 .05292 Mdot
.92454 .17106 Mdot
.49877 .61751 Mdot
.49609 .61638 Mdot
.48755 .61275 Mdot
.46034 .60122 Mdot
.37427 .56484 Mdot
.11861 .46003 Mdot
.70105 .35997 Mdot
.51103 .50059 Mdot
.33754 .51081 Mdot
.96052 .38502 Mdot
.64212 .42125 Mdot
.4999 .61799 Mdot
.49969 .6179 Mdot
.49902 .61762 Mdot
.49688 .61671 Mdot
.49007 .61383 Mdot
.46839 .60463 Mdot
.39959 .57552 Mdot
.18998 .48848 Mdot
.75841 .35131 Mdot
.56524 .49865 Mdot
.4672 .55745 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50771 .00327 Mdot
.52455 .01041 Mdot
.57807 .03308 Mdot
.74405 .10258 Mdot
.1486 .25003 Mdot
.36125 .13142 Mdot
.39116 .01848 Mdot
.27024 .5433 Mdot
.91252 .39695 Mdot
.67951 .47402 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48364 .6111 Mdot
.44792 .59596 Mdot
.33548 .54854 Mdot
.01791 .42177 Mdot
.67353 .4052 Mdot
.54086 .53604 Mdot
.46881 .57351 Mdot
.35029 .54478 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50432 .00183 Mdot
.51377 .00584 Mdot
.54386 .01859 Mdot
.6389 .05874 Mdot
.91684 .17178 Mdot
.31392 .24541 Mdot
.49126 .1096 Mdot
.65549 .1015 Mdot
.49855 .61742 Mdot
.4954 .61608 Mdot
.48533 .61181 Mdot
.45329 .59823 Mdot
.35219 .55555 Mdot
.0599 .43739 Mdot
.67987 .38316 Mdot
.51576 .51661 Mdot
.37525 .53119 Mdot
.06619 .42703 Mdot
.66068 .36742 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50196 .00083 Mdot
.50624 .00265 Mdot
.51988 .00843 Mdot
.56326 .02681 Mdot
.69906 .08393 Mdot
.06146 .22398 Mdot
.33395 .1684 Mdot
.40014 .04091 Mdot
.32619 .57233 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .0014 Mdot
.51049 .00445 Mdot
.53342 .01417 Mdot
.60612 .04493 Mdot
.82645 .13617 Mdot
.2585 .26702 Mdot
.45216 .11969 Mdot
.57513 .076 Mdot
.80666 .14309 Mdot
.26195 .28139 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48465 .61152 Mdot
.45112 .59731 Mdot
.34541 .5527 Mdot
.04261 .43089 Mdot
.67665 .39186 Mdot
.52452 .52401 Mdot
.40903 .54665 Mdot
.16438 .46683 Mdot
.71472 .34013 Mdot
.4986 .61744 Mdot
.49554 .61614 Mdot
.48577 .612 Mdot
.45471 .59883 Mdot
.35661 .55741 Mdot
.07136 .44174 Mdot
.68262 .37778 Mdot
.51155 .5123 Mdot
.35777 .523 Mdot
.01793 .408 Mdot
.65125 .39141 Mdot
.49876 .61751 Mdot
.49604 .61635 Mdot
.48738 .61268 Mdot
.4598 .60099 Mdot
.37256 .56412 Mdot
.11395 .4582 Mdot
.69864 .36136 Mdot
.50975 .50129 Mdot
.33548 .51033 Mdot
.95609 .38356 Mdot
.64173 .42375 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51706 .00723 Mdot
.5543 .02302 Mdot
.67143 .07239 Mdot
.99879 .20232 Mdot
.32796 .20344 Mdot
.44648 .07325 Mdot
.48623 .02456 Mdot
.50533 .01181 Mdot
.53244 .01675 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51452 .00616 Mdot
.54624 .0196 Mdot
.64633 .06186 Mdot
.93629 .1792 Mdot
.31928 .2367 Mdot
.4858 .10291 Mdot
.63104 .08976 Mdot
.95137 .19797 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50787 .00334 Mdot
.52507 .01063 Mdot
.57972 .03378 Mdot
.74901 .10463 Mdot
.15703 .25217 Mdot
.3659 .12909 Mdot
.3966 .01897 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57519 .03186 Mdot
.73537 .099 Mdot
.13329 .24592 Mdot
.35383 .1363 Mdot
.38467 .01906 Mdot
.25727 .53929 Mdot
.89138 .3919 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .00121 Mdot
.50906 .00384 Mdot
.52886 .01224 Mdot
.59171 .03884 Mdot
.78464 .11924 Mdot
.21067 .2633 Mdot
.40522 .12024 Mdot
.46585 .03747 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49294 .61504 Mdot
.4775 .60849 Mdot
.42843 .58771 Mdot
.27558 .52357 Mdot
.88708 .37793 Mdot
.6541 .47405 Mdot
.61781 .59561 Mdot
.74254 .07709 Mdot
.10574 .22447 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48603 .61211 Mdot
.45551 .59917 Mdot
.35913 .55847 Mdot
.07797 .44427 Mdot
.68448 .37484 Mdot
.50977 .51006 Mdot
.34972 .51912 Mdot
.99628 .3996 Mdot
.64842 .40304 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47889 .60908 Mdot
.43284 .58957 Mdot
.28902 .52915 Mdot
.91361 .38602 Mdot
.66151 .46223 Mdot
.61219 .58755 Mdot
.71755 .06512 Mdot
.05669 .2096 Mdot
.49854 .61742 Mdot
.49536 .61607 Mdot
.48523 .61177 Mdot
.45297 .5981 Mdot
.3512 .55513 Mdot
.05735 .43642 Mdot
.67932 .3844 Mdot
.51688 .51764 Mdot
.37971 .53326 Mdot
.07879 .43206 Mdot
.66446 .36196 Mdot
.50081 .00034 Mdot
.50258 .0011 Mdot
.50823 .00349 Mdot
.52621 .01111 Mdot
.58332 .0353 Mdot
.7598 .10907 Mdot
.17455 .25633 Mdot
.3769 .12506 Mdot
.41246 .02198 Mdot
.32323 .56289 Mdot
.0201 .43069 Mdot
.6869 .41211 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49087 .61416 Mdot
.47093 .60571 Mdot
.40763 .57891 Mdot
.21343 .49801 Mdot
.78677 .35434 Mdot
.5925 .49797 Mdot
.52929 .57897 Mdot
.50976 .60597 Mdot
.50488 .61501 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50464 .00197 Mdot
.51478 .00627 Mdot
.54705 .01994 Mdot
.64886 .06293 Mdot
.9428 .18167 Mdot
.32071 .23356 Mdot
.48305 .10033 Mdot
.62002 .08465 Mdot
.92044 .18567 Mdot
.33529 .25639 Mdot
.49767 .61705 Mdot
.49259 .61489 Mdot
.47638 .60802 Mdot
.42488 .58621 Mdot
.26485 .51913 Mdot
.86712 .37222 Mdot
.64635 .48159 Mdot
.61544 .59893 Mdot
.74291 .07878 Mdot
.10888 .22618 Mdot
.32397 .13293 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50377 .0016 Mdot
.512 .00509 Mdot
.53821 .0162 Mdot
.62118 .05128 Mdot
.86887 .15308 Mdot
.29174 .26135 Mdot
.48405 .11885 Mdot
.65246 .10408 Mdot
.01615 .22477 Mdot
.35566 .20983 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00247 Mdot
.51852 .00785 Mdot
.55894 .02498 Mdot
.68577 .07839 Mdot
.03216 .21408 Mdot
.33063 .18447 Mdot
.42036 .05546 Mdot
.39556 .60271 Mdot
.22511 .51269 Mdot
.81884 .36695 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.51689 .00716 Mdot
.55377 .02279 Mdot
.66977 .0717 Mdot
.99482 .20089 Mdot
.32763 .20569 Mdot
.44956 .07535 Mdot
.49708 .02937 Mdot
.54024 .02667 Mdot
.6431 .06357 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52607 .01105 Mdot
.58288 .03511 Mdot
.75845 .10851 Mdot
.17243 .25585 Mdot
.37547 .12549 Mdot
.4102 .02147 Mdot
.31727 .5606 Mdot
.00662 .42604 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48397 .61124 Mdot
.44898 .5964 Mdot
.33875 .54991 Mdot
.02595 .42472 Mdot
.6744 .40076 Mdot
.53515 .53197 Mdot
.4482 .5643 Mdot
.28491 .51712 Mdot
.88861 .37311 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50652 .00277 Mdot
.52078 .00881 Mdot
.56612 .02802 Mdot
.70781 .08757 Mdot
.07989 .22996 Mdot
.33711 .15897 Mdot
.39046 .03298 Mdot
.29218 .55729 Mdot
.96349 .4149 Mdot
.49884 .61754 Mdot
.49632 .61647 Mdot
.48826 .61306 Mdot
.46263 .60219 Mdot
.38144 .56786 Mdot
.13841 .46783 Mdot
.71296 .35509 Mdot
.51981 .49866 Mdot
.35631 .51698 Mdot
.00538 .40115 Mdot
.64638 .39616 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50765 .00324 Mdot
.52435 .01033 Mdot
.57745 .03282 Mdot
.7422 .10182 Mdot
.14539 .24918 Mdot
.35959 .13238 Mdot
.38944 .01845 Mdot
.26649 .54204 Mdot
.90607 .39529 Mdot
.67851 .47739 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52599 .01102 Mdot
.58263 .03501 Mdot
.75773 .10822 Mdot
.17128 .25559 Mdot
.37471 .12573 Mdot
.40902 .0212 Mdot
.31416 .55941 Mdot
.99972 .4237 Mdot
.6857 .42396 Mdot
.49942 .61779 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48114 .61004 Mdot
.43997 .59259 Mdot
.31088 .53825 Mdot
.96031 .40137 Mdot
.66866 .43778 Mdot
.58524 .56648 Mdot
.62364 .02374 Mdot
.82941 .12717 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47422 .6071 Mdot
.41805 .58331 Mdot
.2443 .51065 Mdot
.83197 .3632 Mdot
.62741 .49161 Mdot
.59418 .5975 Mdot
.69413 .06177 Mdot
.01826 .20032 Mdot
.31506 .18343 Mdot
.49809 .61722 Mdot
.49392 .61546 Mdot
.48063 .60982 Mdot
.43836 .59191 Mdot
.30592 .53618 Mdot
.94934 .39765 Mdot
.66747 .44383 Mdot
.59295 .57198 Mdot
.65006 .0353 Mdot
.90036 .15469 Mdot
.29055 .24115 Mdot
.49948 .61782 Mdot
.49836 .61734 Mdot
.49477 .61582 Mdot
.48333 .61097 Mdot
.44694 .59554 Mdot
.33242 .54726 Mdot
.01048 .41906 Mdot
.67283 .40935 Mdot
.54639 .53989 Mdot
.48854 .58229 Mdot
.41353 .57167 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51997 .00847 Mdot
.56355 .02693 Mdot
.69995 .0843 Mdot
.06336 .2246 Mdot
.33423 .1674 Mdot
.39901 .04004 Mdot
.32228 .57061 Mdot
.03102 .43803 Mdot
.69352 .40945 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49347 .61526 Mdot
.47919 .60921 Mdot
.43378 .58997 Mdot
.29189 .53034 Mdot
.91949 .38788 Mdot
.66277 .45937 Mdot
.60981 .5853 Mdot
.7088 .06118 Mdot
.03858 .20381 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50641 .00272 Mdot
.52041 .00865 Mdot
.56493 .02752 Mdot
.70418 .08606 Mdot
.07234 .22753 Mdot
.33569 .16275 Mdot
.39407 .03608 Mdot
.30502 .563 Mdot
.99137 .42419 Mdot
.49755 .617 Mdot
.4922 .61473 Mdot
.47517 .6075 Mdot
.42103 .58458 Mdot
.25324 .51433 Mdot
.84676 .36682 Mdot
.63624 .48792 Mdot
.60602 .59936 Mdot
.72332 .0725 Mdot
.07601 .21797 Mdot
.31897 .15016 Mdot
.50022 .0001 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57373 .03124 Mdot
.73097 .09718 Mdot
.12523 .24367 Mdot
.35044 .13919 Mdot
.3829 .02006 Mdot
.25513 .53907 Mdot
.88876 .3916 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47343 .60677 Mdot
.41553 .58225 Mdot
.23679 .50757 Mdot
.82014 .36053 Mdot
.61941 .49398 Mdot
.58146 .59458 Mdot
.66043 .04881 Mdot
.94132 .1736 Mdot
.30825 .22677 Mdot
.49946 .6178 Mdot
.49828 .6173 Mdot
.49451 .6157 Mdot
.4825 .61061 Mdot
.4443 .59442 Mdot
.32423 .54383 Mdot
.99094 .41205 Mdot
.67123 .42044 Mdot
.56161 .55028 Mdot
.5421 .60598 Mdot
.58501 .02652 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47562 .6077 Mdot
.42247 .58518 Mdot
.25757 .51612 Mdot
.85421 .36874 Mdot
.64021 .48577 Mdot
.61035 .59958 Mdot
.73307 .07584 Mdot
.09317 .22256 Mdot
.32136 .14103 Mdot
.49899 .61761 Mdot
.49678 .61667 Mdot
.48973 .61368 Mdot
.4673 .60417 Mdot
.39616 .57407 Mdot
.18007 .48448 Mdot
.74792 .35095 Mdot
.55449 .49849 Mdot
.44121 .54802 Mdot
.24174 .49475 Mdot
.80385 .34741 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.48532 .61181 Mdot
.45325 .59822 Mdot
.35206 .5555 Mdot
.05957 .43726 Mdot
.67979 .38332 Mdot
.5159 .51674 Mdot
.37582 .53146 Mdot
.0678 .42767 Mdot
.66113 .3667 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49146 .61441 Mdot
.47279 .6065 Mdot
.41351 .5814 Mdot
.23079 .50511 Mdot
.81108 .35864 Mdot
.61273 .49545 Mdot
.56969 .59143 Mdot
.62788 .03596 Mdot
.85791 .14216 Mdot
.49904 .61763 Mdot
.49695 .61674 Mdot
.49029 .61392 Mdot
.46907 .60492 Mdot
.40173 .57642 Mdot
.19619 .491 Mdot
.76543 .35181 Mdot
.57228 .49866 Mdot
.48387 .56339 Mdot
.37131 .54846 Mdot
.08606 .44174 Mdot
.49979 .61795 Mdot
.49933 .61775 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.47849 .60891 Mdot
.43156 .58903 Mdot
.28509 .52752 Mdot
.90568 .38354 Mdot
.65961 .46595 Mdot
.61479 .59034 Mdot
.72761 .06973 Mdot
.49952 .61783 Mdot
.49846 .61738 Mdot
.49509 .61595 Mdot
.48437 .61141 Mdot
.45023 .59694 Mdot
.34265 .55155 Mdot
.03567 .42831 Mdot
.67563 .39552 Mdot
.52872 .52724 Mdot
.42467 .55373 Mdot
.21181 .48647 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50994 .00422 Mdot
.53168 .01343 Mdot
.60061 .0426 Mdot
.8106 .12978 Mdot
.24223 .26676 Mdot
.4354 .11939 Mdot
.53433 .06114 Mdot
.68435 .09272 Mdot
.05307 .22788 Mdot
.498 .61718 Mdot
.49361 .61533 Mdot
.47965 .6094 Mdot
.43524 .59059 Mdot
.29636 .5322 Mdot
.92881 .39087 Mdot
.66452 .45469 Mdot
.60534 .58146 Mdot
.69288 .0541 Mdot
.00394 .19225 Mdot
.30909 .1886 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51803 .00764 Mdot
.55737 .02432 Mdot
.68093 .07636 Mdot
.02108 .21023 Mdot
.32971 .19074 Mdot
.42892 .06131 Mdot
.42501 .61562 Mdot
.31273 .54864 Mdot
.98002 .41241 Mdot
.49805 .61721 Mdot
.49377 .61539 Mdot
.48016 .60962 Mdot
.43687 .59128 Mdot
.30135 .53428 Mdot
.93942 .39435 Mdot
.66618 .44916 Mdot
.59932 .57671 Mdot
.67197 .0449 Mdot
.95522 .17506 Mdot
.30476 .21603 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51226 .0052 Mdot
.53903 .01655 Mdot
.62376 .05237 Mdot
.87598 .15588 Mdot
.29597 .25957 Mdot
.48711 .11813 Mdot
.65894 .1062 Mdot
.03147 .23024 Mdot
.35711 .20125 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48032 .60969 Mdot
.43738 .5915 Mdot
.30292 .53493 Mdot
.9428 .39547 Mdot
.66665 .44736 Mdot
.59722 .57513 Mdot
.66473 .04172 Mdot
.93751 .16859 Mdot
.30164 .22504 Mdot
.49973 .61792 Mdot
.49915 .61767 Mdot
.49728 .61688 Mdot
.49133 .61436 Mdot
.47238 .60632 Mdot
.41219 .58084 Mdot
.22689 .50351 Mdot
.80536 .35752 Mdot
.60827 .49622 Mdot
.56133 .58903 Mdot
.60414 .02646 Mdot
.49796 .61717 Mdot
.49349 .61528 Mdot
.47927 .60925 Mdot
.43405 .59009 Mdot
.29272 .53068 Mdot
.9212 .38842 Mdot
.66311 .45853 Mdot
.60905 .58463 Mdot
.70608 .05996 Mdot
.0328 .20192 Mdot
.31067 .17174 Mdot
.50015 6e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50496 .0021 Mdot
.51579 .0067 Mdot
.55028 .02132 Mdot
.65895 .06716 Mdot
.96833 .19121 Mdot
.32491 .22037 Mdot
.4687 .08887 Mdot
.56585 .06004 Mdot
.75898 .11936 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50384 .00163 Mdot
.51222 .00518 Mdot
.53892 .0165 Mdot
.62342 .05223 Mdot
.87505 .15552 Mdot
.29544 .25981 Mdot
.48675 .11824 Mdot
.65821 .10597 Mdot
.02979 .22965 Mdot
.35694 .20219 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00169 Mdot
.51266 .00537 Mdot
.54032 .01709 Mdot
.62781 .05407 Mdot
.88707 .16023 Mdot
.30186 .25636 Mdot
.49048 .11658 Mdot
.66484 .10776 Mdot
.04457 .23468 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51247 .00529 Mdot
.53972 .01684 Mdot
.62593 .05328 Mdot
.88194 .15822 Mdot
.29924 .2579 Mdot
.48914 .11736 Mdot
.66275 .1073 Mdot
.04012 .23323 Mdot
.35794 .19642 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50792 .00336 Mdot
.52522 .01069 Mdot
.58018 .03397 Mdot
.7504 .1052 Mdot
.15935 .25274 Mdot
.36725 .12849 Mdot
.39834 .01921 Mdot
.28708 .54928 Mdot
.94355 .40572 Mdot
.68293 .45696 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.51039 .00441 Mdot
.5331 .01403 Mdot
.60509 .04449 Mdot
.8235 .13499 Mdot
.25564 .26708 Mdot
.4492 .11962 Mdot
.56783 .07332 Mdot
.78516 .13432 Mdot
.23543 .27828 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .00991 Mdot
.57431 .03149 Mdot
.73272 .0979 Mdot
.12845 .24458 Mdot
.35175 .13801 Mdot
.38348 .01961 Mdot
.25562 .53901 Mdot
.88918 .39156 Mdot
.67586 .48619 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51238 .00525 Mdot
.53943 .01671 Mdot
.62501 .05289 Mdot
.8794 .15722 Mdot
.29787 .25863 Mdot
.48833 .11771 Mdot
.66131 .1069 Mdot
.0369 .23213 Mdot
.35763 .19823 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00172 Mdot
.51289 .00546 Mdot
.54104 .0174 Mdot
.63007 .05502 Mdot
.89319 .16262 Mdot
.30477 .25437 Mdot
.49162 .11548 Mdot
.66589 .10771 Mdot
.04633 .23513 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50811 .00344 Mdot
.52582 .01095 Mdot
.58209 .03478 Mdot
.75611 .10755 Mdot
.16869 .25499 Mdot
.37302 .12628 Mdot
.40645 .02066 Mdot
.30749 .55687 Mdot
.9852 .41885 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50696 .00295 Mdot
.52219 .00941 Mdot
.57058 .02991 Mdot
.72141 .09322 Mdot
.10714 .23839 Mdot
.34402 .1464 Mdot
.38263 .02386 Mdot
.26071 .54269 Mdot
.90061 .39548 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50126 .00053 Mdot
.50401 .0017 Mdot
.51277 .00541 Mdot
.54065 .01724 Mdot
.62886 .05452 Mdot
.88993 .16135 Mdot
.30325 .25545 Mdot
.49108 .11608 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48592 .61206 Mdot
.45516 .59902 Mdot
.35803 .558 Mdot
.07507 .44316 Mdot
.68364 .37612 Mdot
.51049 .51102 Mdot
.35305 .52074 Mdot
.00521 .40306 Mdot
.64955 .39822 Mdot
.49913 .61766 Mdot
.49722 .61686 Mdot
.49115 .61428 Mdot
.4718 .60608 Mdot
.41038 .58007 Mdot
.22153 .50131 Mdot
.79775 .35612 Mdot
.60204 .49708 Mdot
.54912 .58533 Mdot
.5687 .01211 Mdot
.68818 .07384 Mdot
.49827 .6173 Mdot
.49448 .61569 Mdot
.48242 .61058 Mdot
.44403 .59431 Mdot
.32341 .54349 Mdot
.989 .41136 Mdot
.67108 .42155 Mdot
.56313 .55132 Mdot
.54743 .60833 Mdot
.60181 .03361 Mdot
.7987 .12169 Mdot
.4979 .61714 Mdot
.49329 .61519 Mdot
.47863 .60897 Mdot
.43203 .58923 Mdot
.28652 .52811 Mdot
.90855 .38443 Mdot
.66033 .46462 Mdot
.61393 .58936 Mdot
.72421 .06815 Mdot
.07009 .21377 Mdot
.3142 .15087 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.50842 .00357 Mdot
.52681 .01137 Mdot
.58522 .0361 Mdot
.76543 .11138 Mdot
.18325 .25823 Mdot
.38303 .12347 Mdot
.42274 .02454 Mdot
.35104 .57372 Mdot
.49851 .6174 Mdot
.49524 .61602 Mdot
.48483 .6116 Mdot
.45171 .59756 Mdot
.34725 .55348 Mdot
.04726 .43263 Mdot
.67742 .38946 Mdot
.5219 .52192 Mdot
.39914 .54216 Mdot
.13502 .4548 Mdot
.6918 .34411 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49106 .61424 Mdot
.47151 .60596 Mdot
.40947 .57969 Mdot
.21884 .50022 Mdot
.79403 .35549 Mdot
.59888 .49742 Mdot
.5427 .58331 Mdot
.54979 .00439 Mdot
.63036 .0498 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50789 .00335 Mdot
.52514 .01066 Mdot
.57993 .03386 Mdot
.74964 .10489 Mdot
.15809 .25243 Mdot
.36652 .12881 Mdot
.39738 .01907 Mdot
.28476 .54843 Mdot
.93908 .40439 Mdot
.68256 .4595 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51705 .00723 Mdot
.55429 .02301 Mdot
.67138 .07237 Mdot
.99865 .20227 Mdot
.32795 .20352 Mdot
.44658 .07332 Mdot
.48659 .02472 Mdot
.5065 .0123 Mdot
.53614 .01832 Mdot
.49782 .61711 Mdot
.49305 .61508 Mdot
.47784 .60864 Mdot
.42952 .58817 Mdot
.27889 .52494 Mdot
.89345 .37982 Mdot
.65616 .47138 Mdot
.6173 .59402 Mdot
.73888 .07514 Mdot
.09862 .22233 Mdot
.31971 .13664 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50642 .00272 Mdot
.52045 .00867 Mdot
.56506 .02757 Mdot
.70456 .08622 Mdot
.07314 .22779 Mdot
.33583 .16235 Mdot
.39366 .03574 Mdot
.3036 .56237 Mdot
.98821 .42311 Mdot
.69049 .43403 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50603 .00256 Mdot
.5192 .00814 Mdot
.5611 .0259 Mdot
.69242 .08116 Mdot
.04701 .21915 Mdot
.33211 .1762 Mdot
.40955 .04786 Mdot
.35849 .58648 Mdot
.12206 .47191 Mdot
.71997 .36952 Mdot
.49856 .61743 Mdot
.49543 .61609 Mdot
.48543 .61186 Mdot
.45361 .59837 Mdot
.35317 .55596 Mdot
.06243 .43835 Mdot
.68043 .38194 Mdot
.51471 .51561 Mdot
.37103 .52923 Mdot
.05437 .42233 Mdot
.65774 .3729 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61476 Mdot
.47543 .60762 Mdot
.42188 .58493 Mdot
.25579 .51538 Mdot
.85112 .36794 Mdot
.6386 .48669 Mdot
.60868 .59954 Mdot
.72941 .07461 Mdot
.08688 .22093 Mdot
.499 .61761 Mdot
.4968 .61668 Mdot
.48981 .61371 Mdot
.46753 .60427 Mdot
.39688 .57437 Mdot
.18216 .48533 Mdot
.75006 .35098 Mdot
.5567 .49853 Mdot
.4466 .54999 Mdot
.25791 .50141 Mdot
.83077 .35405 Mdot
.49804 .6172 Mdot
.49374 .61538 Mdot
.48006 .60958 Mdot
.43655 .59114 Mdot
.30037 .53387 Mdot
.9373 .39365 Mdot
.66587 .45028 Mdot
.60059 .57769 Mdot
.67635 .04682 Mdot
.96573 .17885 Mdot
.30612 .21037 Mdot
.49871 .61749 Mdot
.49588 .61629 Mdot
.48688 .61247 Mdot
.45821 .60032 Mdot
.36758 .56202 Mdot
.10045 .45294 Mdot
.69245 .36588 Mdot
.50775 .50388 Mdot
.33468 .51107 Mdot
.95587 .38392 Mdot
.64241 .42431 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50269 .00114 Mdot
.50857 .00363 Mdot
.52729 .01157 Mdot
.58674 .03674 Mdot
.76996 .11323 Mdot
.19003 .25962 Mdot
.38812 .12243 Mdot
.43188 .02704 Mdot
.37655 .58384 Mdot
.15405 .48052 Mdot
.49932 .61775 Mdot
.49784 .61712 Mdot
.49311 .61511 Mdot
.47804 .60872 Mdot
.43015 .58843 Mdot
.28081 .52574 Mdot
.8972 .38095 Mdot
.65729 .46976 Mdot
.61674 .59297 Mdot
.736 .07371 Mdot
.09308 .22069 Mdot
.49944 .6178 Mdot
.49823 .61728 Mdot
.49435 .61564 Mdot
.48199 .6104 Mdot
.44268 .59374 Mdot
.31925 .54175 Mdot
.97932 .40795 Mdot
.67033 .42707 Mdot
.57077 .55651 Mdot
.57391 .00194 Mdot
.68398 .06803 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00126 Mdot
.5095 .00403 Mdot
.53026 .01283 Mdot
.59614 .04072 Mdot
.79763 .12452 Mdot
.22723 .26551 Mdot
.42054 .11947 Mdot
.49956 .04884 Mdot
.57793 .04843 Mdot
.76856 .11782 Mdot
.49742 .61694 Mdot
.49177 .61455 Mdot
.4738 .60692 Mdot
.4167 .58274 Mdot
.24026 .50899 Mdot
.82555 .36172 Mdot
.62317 .49296 Mdot
.58764 .59608 Mdot
.67704 .05525 Mdot
.98052 .18756 Mdot
.31315 .20557 Mdot
.5004 .00017 Mdot
.50126 .00054 Mdot
.50402 .00171 Mdot
.51281 .00543 Mdot
.5408 .0173 Mdot
.62932 .05471 Mdot
.89117 .16183 Mdot
.30384 .25504 Mdot
.4913 .11586 Mdot
.66572 .1078 Mdot
.04617 .23513 Mdot
.35833 .19293 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50647 .00274 Mdot
.52062 .00874 Mdot
.56561 .02781 Mdot
.70625 .08692 Mdot
.07666 .22893 Mdot
.33647 .16057 Mdot
.39194 .03428 Mdot
.29748 .55965 Mdot
.97483 .41863 Mdot
.68978 .44186 Mdot
.4997 .61791 Mdot
.49903 .61762 Mdot
.49691 .61673 Mdot
.49017 .61387 Mdot
.46869 .60476 Mdot
.40054 .57592 Mdot
.19274 .4896 Mdot
.76148 .3515 Mdot
.56834 .49867 Mdot
.47459 .56009 Mdot
.34287 .53663 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.50931 .00395 Mdot
.52967 .01258 Mdot
.59426 .03992 Mdot
.79213 .12229 Mdot
.22041 .26469 Mdot
.41408 .11969 Mdot
.48503 .04385 Mdot
.53356 .02999 Mdot
.63206 .06087 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51188 .00504 Mdot
.53783 .01604 Mdot
.62 .05078 Mdot
.86559 .15178 Mdot
.28967 .2621 Mdot
.48239 .11911 Mdot
.64876 .10282 Mdot
.00718 .22151 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.50481 .00204 Mdot
.51532 .0065 Mdot
.54878 .02068 Mdot
.65425 .06519 Mdot
.95655 .18683 Mdot
.32322 .22661 Mdot
.47596 .0944 Mdot
.5928 .07221 Mdot
.84107 .15344 Mdot
.29005 .27748 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50657 .00279 Mdot
.52094 .00888 Mdot
.56663 .02824 Mdot
.70936 .08821 Mdot
.08308 .23097 Mdot
.33777 .1574 Mdot
.38911 .03173 Mdot
.28724 .55508 Mdot
.95315 .41155 Mdot
.68832 .45436 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.4778 .60862 Mdot
.42939 .58811 Mdot
.2785 .52478 Mdot
.89269 .37959 Mdot
.65593 .4717 Mdot
.61739 .59422 Mdot
.7394 .07541 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.486 .6121 Mdot
.45543 .59914 Mdot
.35887 .55836 Mdot
.07729 .44401 Mdot
.68428 .37514 Mdot
.50993 .51028 Mdot
.35047 .51948 Mdot
.99828 .40037 Mdot
.64867 .40197 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55363 .02273 Mdot
.66934 .07151 Mdot
.99378 .20052 Mdot
.32755 .20628 Mdot
.45036 .0759 Mdot
.49991 .03062 Mdot
.54931 .03054 Mdot
.67151 .07552 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47722 .60838 Mdot
.42754 .58733 Mdot
.2729 .52246 Mdot
.88199 .37644 Mdot
.65231 .47609 Mdot
.6178 .5967 Mdot
.74428 .07817 Mdot
.10935 .22562 Mdot
.32299 .13204 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.4933 .61519 Mdot
.47866 .60899 Mdot
.43212 .58927 Mdot
.28681 .52823 Mdot
.90913 .38461 Mdot
.66047 .46435 Mdot
.61375 .58916 Mdot
.72349 .06782 Mdot
.06865 .21332 Mdot
.49923 .61771 Mdot
.49756 .617 Mdot
.49222 .61474 Mdot
.47523 .60753 Mdot
.42122 .58466 Mdot
.2538 .51457 Mdot
.84772 .36706 Mdot
.63677 .48766 Mdot
.60664 .59941 Mdot
.72476 .073 Mdot
.07862 .2187 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50763 .00324 Mdot
.52431 .01031 Mdot
.57732 .03276 Mdot
.7418 .10165 Mdot
.14469 .249 Mdot
.35923 .13259 Mdot
.3891 .01846 Mdot
.26575 .5418 Mdot
.90483 .39498 Mdot
.67831 .47804 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50579 .00246 Mdot
.51846 .00783 Mdot
.55875 .0249 Mdot
.68517 .07813 Mdot
.03079 .21361 Mdot
.33051 .18524 Mdot
.4214 .05617 Mdot
.39913 .60427 Mdot
.23549 .5169 Mdot
.83411 .36997 Mdot
.49747 .61696 Mdot
.49195 .61462 Mdot
.47435 .60716 Mdot
.41844 .58348 Mdot
.24549 .51114 Mdot
.8339 .36366 Mdot
.62863 .49117 Mdot
.59598 .59785 Mdot
.69873 .0635 Mdot
.02792 .20345 Mdot
.31545 .1777 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47575 .60775 Mdot
.42289 .58536 Mdot
.25883 .51664 Mdot
.8564 .36932 Mdot
.64131 .4851 Mdot
.61143 .59956 Mdot
.73535 .07659 Mdot
.097 .22351 Mdot
.32199 .13905 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50552 .00234 Mdot
.51759 .00746 Mdot
.55598 .02373 Mdot
.67663 .07456 Mdot
.01108 .2067 Mdot
.32893 .19644 Mdot
.4368 .06667 Mdot
.45234 .00961 Mdot
.39747 .58412 Mdot
.19922 .49551 Mdot
.50015 6e-05 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51566 .00664 Mdot
.54985 .02113 Mdot
.65759 .06659 Mdot
.96494 .18995 Mdot
.32446 .22219 Mdot
.47089 .0905 Mdot
.57391 .06367 Mdot
.78385 .12975 Mdot
.49926 .61772 Mdot
.49763 .61703 Mdot
.49245 .61483 Mdot
.47594 .60783 Mdot
.42349 .58561 Mdot
.26063 .51738 Mdot
.85958 .37017 Mdot
.64287 .4841 Mdot
.61283 .59947 Mdot
.73821 .07749 Mdot
.10167 .22463 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.50931 .00395 Mdot
.52965 .01257 Mdot
.59422 .03991 Mdot
.79202 .12224 Mdot
.22027 .26468 Mdot
.41394 .1197 Mdot
.48473 .04375 Mdot
.53265 .02962 Mdot
.62921 .05968 Mdot
.49966 .61789 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48908 .6134 Mdot
.46521 .60329 Mdot
.38958 .57129 Mdot
.1613 .47695 Mdot
.73041 .35173 Mdot
.53645 .49816 Mdot
.39668 .53165 Mdot
.11258 .44245 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50693 .00294 Mdot
.52208 .00936 Mdot
.57024 .02977 Mdot
.72038 .09279 Mdot
.10512 .23779 Mdot
.3434 .14726 Mdot
.38289 .02441 Mdot
.26215 .54341 Mdot
.90337 .39629 Mdot
.68079 .48048 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49199 .61464 Mdot
.47447 .60721 Mdot
.41883 .58365 Mdot
.24665 .51162 Mdot
.83579 .36411 Mdot
.62981 .49073 Mdot
.59766 .59817 Mdot
.70299 .06509 Mdot
.0367 .20625 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52316 .00982 Mdot
.57368 .03122 Mdot
.7308 .09711 Mdot
.12492 .24358 Mdot
.35032 .1393 Mdot
.38285 .02011 Mdot
.25511 .53908 Mdot
.88876 .39162 Mdot
.67601 .48655 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52658 .01127 Mdot
.5845 .0358 Mdot
.76331 .11051 Mdot
.18002 .25754 Mdot
.3807 .12403 Mdot
.41873 .0235 Mdot
.34007 .56942 Mdot
.49985 .61797 Mdot
.49953 .61783 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48476 .61157 Mdot
.45149 .59747 Mdot
.34657 .55319 Mdot
.04552 .43198 Mdot
.67712 .39035 Mdot
.52286 .5227 Mdot
.40278 .54382 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50293 .00124 Mdot
.50934 .00396 Mdot
.52976 .01262 Mdot
.59455 .04004 Mdot
.79296 .12263 Mdot
.22146 .26483 Mdot
.41506 .11965 Mdot
.4872 .04459 Mdot
.54017 .03274 Mdot
.65275 .06958 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47696 .60827 Mdot
.42673 .58699 Mdot
.27042 .52143 Mdot
.87735 .3751 Mdot
.65057 .47788 Mdot
.61744 .59756 Mdot
.74492 .07879 Mdot
.11101 .22625 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50438 .00186 Mdot
.51397 .00592 Mdot
.54447 .01885 Mdot
.64082 .05955 Mdot
.92191 .17372 Mdot
.31549 .24324 Mdot
.49026 .10801 Mdot
.65042 .09899 Mdot
.00409 .21858 Mdot
.35163 .21479 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .00179 Mdot
.51346 .00571 Mdot
.54287 .01817 Mdot
.6358 .05744 Mdot
.90861 .1686 Mdot
.31109 .24875 Mdot
.49221 .11194 Mdot
.66165 .10472 Mdot
.03398 .23011 Mdot
.49851 .6174 Mdot
.49525 .61602 Mdot
.48486 .61161 Mdot
.4518 .5976 Mdot
.34753 .55359 Mdot
.04797 .4329 Mdot
.67754 .38909 Mdot
.52152 .52161 Mdot
.39769 .5415 Mdot
.13074 .45305 Mdot
.68901 .34503 Mdot
.49804 .6172 Mdot
.49375 .61539 Mdot
.4801 .6096 Mdot
.43667 .5912 Mdot
.30075 .53403 Mdot
.93812 .39392 Mdot
.66599 .44985 Mdot
.60011 .57731 Mdot
.67467 .04608 Mdot
.96173 .17741 Mdot
.30564 .21255 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.52378 .01009 Mdot
.57565 .03205 Mdot
.73675 .09957 Mdot
.13576 .2466 Mdot
.35494 .13546 Mdot
.38544 .01885 Mdot
.25855 .53961 Mdot
.89327 .39228 Mdot
.67635 .48397 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51092 .00463 Mdot
.53477 .01474 Mdot
.61037 .04672 Mdot
.83857 .14103 Mdot
.26948 .26632 Mdot
.46344 .11988 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51822 .00773 Mdot
.558 .02459 Mdot
.68288 .07718 Mdot
.02557 .21179 Mdot
.33007 .18819 Mdot
.42542 .05893 Mdot
.41295 .61033 Mdot
.27633 .53359 Mdot
.90422 .38806 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00194 Mdot
.51454 .00617 Mdot
.54631 .01963 Mdot
.64655 .06196 Mdot
.93685 .17941 Mdot
.31941 .23643 Mdot
.48558 .1027 Mdot
.63014 .08934 Mdot
.94887 .19699 Mdot
.34298 .24358 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.5082 .00348 Mdot
.52614 .01108 Mdot
.58309 .0352 Mdot
.7591 .10878 Mdot
.17346 .25608 Mdot
.37616 .12528 Mdot
.41129 .02171 Mdot
.32012 .56169 Mdot
.01303 .42824 Mdot
.68641 .41617 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50855 .00362 Mdot
.52723 .01154 Mdot
.58654 .03666 Mdot
.76937 .11299 Mdot
.18917 .25945 Mdot
.38746 .12255 Mdot
.43066 .0267 Mdot
.3731 .58246 Mdot
.14472 .47689 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51721 .0073 Mdot
.55478 .02322 Mdot
.67292 .07301 Mdot
.00233 .20359 Mdot
.32825 .20143 Mdot
.44371 .07136 Mdot
.47649 .02026 Mdot
.47413 .61657 Mdot
.43312 .59269 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.50381 .00161 Mdot
.51213 .00514 Mdot
.53862 .01637 Mdot
.62247 .05182 Mdot
.87242 .15448 Mdot
.29389 .26049 Mdot
.48566 .11852 Mdot
.65595 .10524 Mdot
.02448 .22777 Mdot
.35644 .20516 Mdot
.49822 .61728 Mdot
.49431 .61562 Mdot
.48188 .61035 Mdot
.44234 .59359 Mdot
.31819 .5413 Mdot
.97688 .40709 Mdot
.67013 .42845 Mdot
.57268 .55781 Mdot
.5805 .00483 Mdot
.70398 .07632 Mdot
.05628 .21773 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47697 .60827 Mdot
.42674 .58699 Mdot
.27045 .52144 Mdot
.87739 .37511 Mdot
.65059 .47786 Mdot
.61745 .59755 Mdot
.74492 .07878 Mdot
.111 .22625 Mdot
.32375 .13149 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49809 .61723 Mdot
.49393 .61546 Mdot
.48066 .60983 Mdot
.43844 .59194 Mdot
.30616 .53628 Mdot
.94987 .39783 Mdot
.66753 .44354 Mdot
.59259 .57172 Mdot
.64883 .03476 Mdot
.49765 .61704 Mdot
.49251 .61486 Mdot
.47615 .60792 Mdot
.42415 .5859 Mdot
.26263 .51821 Mdot
.86313 .37113 Mdot
.64455 .48294 Mdot
.61419 .59927 Mdot
.74078 .07824 Mdot
.10571 .22554 Mdot
.32348 .13459 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .00159 Mdot
.51198 .00508 Mdot
.53815 .01618 Mdot
.62101 .05121 Mdot
.86838 .15289 Mdot
.29144 .26146 Mdot
.48381 .11889 Mdot
.65193 .10391 Mdot
.01488 .22431 Mdot
.35554 .21054 Mdot
.49818 .61726 Mdot
.49421 .61558 Mdot
.48155 .61021 Mdot
.44128 .59315 Mdot
.31492 .53994 Mdot
.96942 .4045 Mdot
.66951 .43268 Mdot
.57843 .56175 Mdot
.6003 .01352 Mdot
.76287 .10047 Mdot
.16339 .24753 Mdot
.49797 .61718 Mdot
.49355 .6153 Mdot
.47944 .60932 Mdot
.43458 .59031 Mdot
.29434 .53136 Mdot
.92457 .3895 Mdot
.66376 .45684 Mdot
.60747 .58325 Mdot
.70043 .05745 Mdot
.02063 .1979 Mdot
.30997 .17882 Mdot
.498 .61718 Mdot
.49361 .61533 Mdot
.47965 .60941 Mdot
.43525 .59059 Mdot
.29639 .53221 Mdot
.92886 .39089 Mdot
.66452 .45466 Mdot
.60531 .58144 Mdot
.69278 .05406 Mdot
.00372 .19217 Mdot
.30908 .18872 Mdot
.49829 .61731 Mdot
.49457 .61573 Mdot
.48269 .6107 Mdot
.44491 .59468 Mdot
.32613 .54462 Mdot
.99542 .41364 Mdot
.67158 .41789 Mdot
.55807 .54788 Mdot
.52974 .60053 Mdot
.54575 .0099 Mdot
.62945 .05173 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53096 .01313 Mdot
.59835 .04165 Mdot
.80405 .12713 Mdot
.23485 .26625 Mdot
.42799 .11937 Mdot
.51678 .05487 Mdot
.63067 .07039 Mdot
.91929 .17838 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49677 .61666 Mdot
.4897 .61366 Mdot
.46718 .60412 Mdot
.39578 .57391 Mdot
.179 .48405 Mdot
.74684 .35095 Mdot
.55338 .49846 Mdot
.43848 .54702 Mdot
.23359 .4914 Mdot
.50042 .00018 Mdot
.50133 .00057 Mdot
.50425 .0018 Mdot
.51355 .00575 Mdot
.54315 .01829 Mdot
.63667 .0578 Mdot
.91092 .16949 Mdot
.31192 .24783 Mdot
.49203 .11131 Mdot
.66019 .10393 Mdot
.03008 .2286 Mdot
.35511 .20088 Mdot
.49955 .61784 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.48532 .61181 Mdot
.45327 .59822 Mdot
.35213 .55553 Mdot
.05975 .43733 Mdot
.67983 .38323 Mdot
.51582 .51667 Mdot
.37551 .53131 Mdot
.06692 .42732 Mdot
.49791 .61715 Mdot
.49335 .61522 Mdot
.47883 .60906 Mdot
.43264 .58949 Mdot
.2884 .52889 Mdot
.91233 .38561 Mdot
.66122 .46284 Mdot
.61265 .58802 Mdot
.71931 .06592 Mdot
.06027 .21073 Mdot
.31297 .15618 Mdot
.49855 .61742 Mdot
.49537 .61607 Mdot
.48524 .61177 Mdot
.453 .59811 Mdot
.35128 .55517 Mdot
.05755 .4365 Mdot
.67937 .38431 Mdot
.51679 .51756 Mdot
.37935 .53309 Mdot
.07778 .43165 Mdot
.66413 .36238 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50678 .00288 Mdot
.52161 .00916 Mdot
.56875 .02913 Mdot
.71583 .0909 Mdot
.09617 .23506 Mdot
.34087 .15123 Mdot
.38471 .02709 Mdot
.27034 .54735 Mdot
.91919 .40101 Mdot
.49983 .61796 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48249 .61061 Mdot
.44425 .5944 Mdot
.32409 .54377 Mdot
.99061 .41193 Mdot
.6712 .42063 Mdot
.56186 .55046 Mdot
.54299 .60637 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51643 .00697 Mdot
.5523 .02217 Mdot
.66523 .06979 Mdot
.98382 .1969 Mdot
.32664 .21187 Mdot
.45787 .08111 Mdot
.52664 .0425 Mdot
.6352 .06709 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47987 .6095 Mdot
.43594 .59088 Mdot
.29849 .53308 Mdot
.9333 .39233 Mdot
.66526 .45238 Mdot
.6029 .5795 Mdot
.68437 .05035 Mdot
.98456 .18553 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50593 .00252 Mdot
.51891 .00802 Mdot
.56017 .0255 Mdot
.68956 .07997 Mdot
.04067 .217 Mdot
.33144 .17971 Mdot
.41405 .05106 Mdot
.37392 .59323 Mdot
.16383 .48819 Mdot
.74915 .36175 Mdot
.49988 .61798 Mdot
.49962 .61787 Mdot
.4988 .61753 Mdot
.49619 .61642 Mdot
.48785 .61288 Mdot
.4613 .60163 Mdot
.37728 .56611 Mdot
.1269 .46329 Mdot
.7057 .35772 Mdot
.51405 .49959 Mdot
.34344 .51259 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52328 .00987 Mdot
.57403 .03137 Mdot
.73188 .09755 Mdot
.12691 .24414 Mdot
.35112 .13857 Mdot
.38318 .01981 Mdot
.25533 .53902 Mdot
.88888 .39155 Mdot
.67589 .4864 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50314 .00133 Mdot
.51 .00424 Mdot
.53185 .0135 Mdot
.60116 .04283 Mdot
.81218 .13042 Mdot
.24395 .26685 Mdot
.43716 .11941 Mdot
.53854 .06266 Mdot
.69717 .09804 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48012 .6096 Mdot
.43672 .59122 Mdot
.30089 .53409 Mdot
.93844 .39402 Mdot
.66604 .44968 Mdot
.59991 .57717 Mdot
.67401 .04579 Mdot
.96014 .17684 Mdot
.30544 .21341 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49025 .6139 Mdot
.46895 .60487 Mdot
.40136 .57626 Mdot
.19511 .49056 Mdot
.76418 .35171 Mdot
.57104 .49867 Mdot
.48096 .56236 Mdot
.36238 .54475 Mdot
.06215 .43248 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50617 .00261 Mdot
.51964 .00833 Mdot
.56251 .0265 Mdot
.69676 .08297 Mdot
.05652 .22234 Mdot
.33326 .17104 Mdot
.40321 .04323 Mdot
.33676 .57696 Mdot
.06618 .4508 Mdot
.69916 .39121 Mdot
.49787 .61713 Mdot
.49321 .61516 Mdot
.47838 .60887 Mdot
.43121 .58888 Mdot
.28404 .52708 Mdot
.90358 .38289 Mdot
.65906 .46692 Mdot
.61536 .59102 Mdot
.72993 .07081 Mdot
.08134 .21718 Mdot
.31598 .14502 Mdot
.49776 .61709 Mdot
.49287 .61501 Mdot
.4773 .60841 Mdot
.42779 .58744 Mdot
.27365 .52277 Mdot
.8834 .37685 Mdot
.65282 .47553 Mdot
.61784 .59641 Mdot
.74391 .07791 Mdot
.10853 .22535 Mdot
.32268 .13236 Mdot
.50015 6e-05 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51574 .00667 Mdot
.55011 .02124 Mdot
.6584 .06693 Mdot
.96697 .19071 Mdot
.32473 .22111 Mdot
.46959 .08953 Mdot
.56911 .06151 Mdot
.76907 .12358 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51143 .00485 Mdot
.53639 .01543 Mdot
.61548 .04888 Mdot
.85298 .14678 Mdot
.28096 .26451 Mdot
.4747 .11974 Mdot
.63067 .09639 Mdot
.96134 .20437 Mdot
.34944 .23985 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50804 .00341 Mdot
.5256 .01086 Mdot
.5814 .03449 Mdot
.75404 .1067 Mdot
.16534 .2542 Mdot
.37089 .12704 Mdot
.40334 .02005 Mdot
.29954 .55388 Mdot
.96848 .41343 Mdot
.68439 .44246 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50763 .00324 Mdot
.52431 .01031 Mdot
.57732 .03276 Mdot
.74179 .10165 Mdot
.14468 .249 Mdot
.35923 .1326 Mdot
.38909 .01846 Mdot
.26574 .5418 Mdot
.90482 .39497 Mdot
.67831 .47804 Mdot
.49956 .61785 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48591 .61206 Mdot
.45515 .59902 Mdot
.358 .55799 Mdot
.075 .44313 Mdot
.68362 .37615 Mdot
.51051 .51104 Mdot
.35314 .52077 Mdot
.00543 .40314 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47504 .60745 Mdot
.42064 .58441 Mdot
.25206 .51385 Mdot
.84478 .36632 Mdot
.63513 .48846 Mdot
.60469 .59922 Mdot
.72019 .07138 Mdot
.07025 .21635 Mdot
.31832 .15332 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50692 .00293 Mdot
.52203 .00934 Mdot
.57009 .0297 Mdot
.7199 .09259 Mdot
.1042 .23751 Mdot
.34312 .14766 Mdot
.38303 .02466 Mdot
.26286 .54376 Mdot
.49843 .61737 Mdot
.49501 .61592 Mdot
.4841 .61129 Mdot
.44937 .59657 Mdot
.33999 .55043 Mdot
.02902 .42585 Mdot
.67476 .39909 Mdot
.53306 .53046 Mdot
.44059 .56088 Mdot
.26106 .50708 Mdot
.84337 .35989 Mdot
.49739 .61693 Mdot
.49169 .61451 Mdot
.47352 .60681 Mdot
.41582 .58237 Mdot
.23766 .50792 Mdot
.82148 .36082 Mdot
.62036 .49373 Mdot
.58306 .59498 Mdot
.66476 .0505 Mdot
.95177 .17738 Mdot
.31002 .22141 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00305 Mdot
.52288 .0097 Mdot
.57278 .03084 Mdot
.72807 .09598 Mdot
.11983 .24212 Mdot
.34836 .14123 Mdot
.3823 .02098 Mdot
.25536 .53958 Mdot
.88981 .39212 Mdot
.67666 .4863 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49026 .61391 Mdot
.46899 .60489 Mdot
.40149 .57632 Mdot
.19549 .49072 Mdot
.76462 .35174 Mdot
.57148 .49866 Mdot
.48198 .56272 Mdot
.36551 .54605 Mdot
.07048 .43569 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51269 .00538 Mdot
.54041 .01713 Mdot
.62811 .0542 Mdot
.88788 .16055 Mdot
.30226 .2561 Mdot
.49066 .11644 Mdot
.66507 .10779 Mdot
.04502 .23482 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00822 Mdot
.56172 .02616 Mdot
.69434 .08196 Mdot
.05123 .22057 Mdot
.3326 .17389 Mdot
.40667 .04578 Mdot
.34862 .58216 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49106 .61424 Mdot
.47151 .60595 Mdot
.40946 .57968 Mdot
.2188 .5002 Mdot
.79398 .35548 Mdot
.59884 .49743 Mdot
.5426 .58328 Mdot
.54952 .00427 Mdot
.62951 .04944 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.5073 .00309 Mdot
.52325 .00986 Mdot
.57395 .03133 Mdot
.73162 .09745 Mdot
.12644 .24401 Mdot
.35093 .13874 Mdot
.3831 .01988 Mdot
.25526 .53903 Mdot
.88882 .39156 Mdot
.67591 .48645 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00156 Mdot
.51174 .00498 Mdot
.5374 .01586 Mdot
.61865 .05021 Mdot
.86183 .15029 Mdot
.2872 .26289 Mdot
.48032 .11936 Mdot
.64401 .10116 Mdot
.99541 .21718 Mdot
.3537 .22143 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47644 .60805 Mdot
.42507 .58629 Mdot
.26542 .51936 Mdot
.86815 .37251 Mdot
.6468 .48123 Mdot
.61572 .59883 Mdot
.74334 .07887 Mdot
.10948 .22629 Mdot
.32405 .13261 Mdot
.49945 .6178 Mdot
.49826 .61729 Mdot
.49445 .61568 Mdot
.4823 .61053 Mdot
.44368 .59416 Mdot
.32231 .54303 Mdot
.98644 .41045 Mdot
.67088 .42301 Mdot
.56516 .55269 Mdot
.55447 .61143 Mdot
.6239 .04291 Mdot
.49935 .61776 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47912 .60918 Mdot
.43356 .58988 Mdot
.2912 .53005 Mdot
.91807 .38742 Mdot
.66248 .46007 Mdot
.61042 .58586 Mdot
.71102 .06218 Mdot
.04323 .20532 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50496 .0021 Mdot
.51581 .0067 Mdot
.55033 .02133 Mdot
.65909 .06722 Mdot
.96868 .19134 Mdot
.32495 .22019 Mdot
.46847 .0887 Mdot
.56501 .05966 Mdot
.75638 .11827 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54094 .01736 Mdot
.62976 .05489 Mdot
.89237 .1623 Mdot
.30439 .25465 Mdot
.49149 .11563 Mdot
.66584 .10775 Mdot
.04632 .23515 Mdot
.35829 .19281 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50468 .00198 Mdot
.5149 .00632 Mdot
.54745 .02012 Mdot
.65013 .06346 Mdot
.94606 .1829 Mdot
.32136 .23195 Mdot
.48152 .09899 Mdot
.61404 .0819 Mdot
.49886 .61755 Mdot
.49636 .61649 Mdot
.4884 .61312 Mdot
.46306 .60237 Mdot
.3828 .56843 Mdot
.14222 .46934 Mdot
.71558 .35436 Mdot
.52212 .49847 Mdot
.36172 .5189 Mdot
.01904 .40624 Mdot
.64787 .38863 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50317 .00135 Mdot
.51011 .00429 Mdot
.5322 .01365 Mdot
.60227 .0433 Mdot
.8154 .13172 Mdot
.24739 .26698 Mdot
.44068 .11946 Mdot
.54704 .06573 Mdot
.49815 .61725 Mdot
.49411 .61554 Mdot
.48125 .61008 Mdot
.44032 .59274 Mdot
.31197 .5387 Mdot
.96274 .4022 Mdot
.6689 .43643 Mdot
.58345 .56523 Mdot
.61753 .02106 Mdot
.8123 .12038 Mdot
.22775 .25676 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50524 .00222 Mdot
.51671 .00709 Mdot
.55319 .02255 Mdot
.66798 .07094 Mdot
.99049 .19932 Mdot
.32726 .20814 Mdot
.45288 .07764 Mdot
.50884 .03459 Mdot
.57805 .04278 Mdot
.75971 .11227 Mdot
.49896 .61759 Mdot
.49669 .61663 Mdot
.48946 .61357 Mdot
.46644 .60381 Mdot
.39346 .57293 Mdot
.17235 .48138 Mdot
.74035 .35105 Mdot
.54666 .49832 Mdot
.42194 .54096 Mdot
.18478 .47146 Mdot
.72865 .33613 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51067 .00452 Mdot
.53398 .01441 Mdot
.60789 .04567 Mdot
.83151 .13821 Mdot
.26323 .26682 Mdot
.45705 .11979 Mdot
.58722 .08045 Mdot
.84178 .15733 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50387 .00164 Mdot
.51234 .00523 Mdot
.53929 .01666 Mdot
.62458 .05271 Mdot
.87823 .15677 Mdot
.29723 .25896 Mdot
.48793 .11786 Mdot
.66055 .10668 Mdot
.03518 .23153 Mdot
.35747 .19918 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.515 .00636 Mdot
.54776 .02025 Mdot
.6511 .06386 Mdot
.94853 .18383 Mdot
.32183 .23071 Mdot
.4803 .09794 Mdot
.6093 .07972 Mdot
.88965 .17327 Mdot
.32258 .26757 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50438 .00186 Mdot
.51396 .00592 Mdot
.54446 .01885 Mdot
.64078 .05953 Mdot
.9218 .17368 Mdot
.31545 .24329 Mdot
.49028 .10805 Mdot
.65054 .09905 Mdot
.00441 .21871 Mdot
.35167 .21461 Mdot
.49927 .61772 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47637 .60801 Mdot
.42485 .58619 Mdot
.26474 .51908 Mdot
.86691 .37217 Mdot
.64626 .48166 Mdot
.61538 .59895 Mdot
.74282 .07876 Mdot
.10875 .22616 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51215 .00515 Mdot
.5387 .01641 Mdot
.62273 .05193 Mdot
.87313 .15476 Mdot
.29432 .26031 Mdot
.48597 .11845 Mdot
.65659 .10545 Mdot
.026 .22831 Mdot
.35658 .20431 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.5059 .0025 Mdot
.51879 .00797 Mdot
.55979 .02534 Mdot
.68839 .07948 Mdot
.03806 .21611 Mdot
.33118 .18116 Mdot
.41596 .05239 Mdot
.38044 .59609 Mdot
.18199 .49538 Mdot
.76627 .36111 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49054 .61402 Mdot
.46986 .60525 Mdot
.40424 .57748 Mdot
.20348 .49396 Mdot
.77412 .35267 Mdot
.58075 .49853 Mdot
.50338 .57022 Mdot
.43108 .57335 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51527 .00647 Mdot
.54861 .02061 Mdot
.65374 .06497 Mdot
.95525 .18634 Mdot
.323 .22729 Mdot
.47671 .09499 Mdot
.5956 .07348 Mdot
.84941 .15687 Mdot
.29688 .27655 Mdot
.49838 .61735 Mdot
.49484 .61585 Mdot
.48357 .61107 Mdot
.44771 .59587 Mdot
.3348 .54826 Mdot
.01626 .42116 Mdot
.67337 .40612 Mdot
.54207 .53689 Mdot
.47315 .57544 Mdot
.36413 .55066 Mdot
.07517 .43945 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.5108 .00458 Mdot
.5344 .01459 Mdot
.6092 .04623 Mdot
.83525 .13971 Mdot
.2666 .26659 Mdot
.46051 .11984 Mdot
.59578 .08361 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51444 .00612 Mdot
.54598 .01949 Mdot
.64552 .06152 Mdot
.93418 .1784 Mdot
.31878 .23769 Mdot
.48659 .10371 Mdot
.49772 .61707 Mdot
.49274 .61495 Mdot
.47686 .60822 Mdot
.42639 .58684 Mdot
.26941 .52101 Mdot
.87547 .37456 Mdot
.64984 .47859 Mdot
.6172 .59786 Mdot
.74491 .07893 Mdot
.11123 .2264 Mdot
.32396 .13147 Mdot
.49808 .61722 Mdot
.49387 .61543 Mdot
.48047 .60975 Mdot
.43784 .59169 Mdot
.30432 .53551 Mdot
.94583 .39648 Mdot
.66704 .44573 Mdot
.59527 .57368 Mdot
.65803 .03879 Mdot
.92077 .16238 Mdot
.2975 .23283 Mdot
.49802 .6172 Mdot
.49371 .61537 Mdot
.47995 .60953 Mdot
.4362 .591 Mdot
.2993 .53342 Mdot
.93503 .3929 Mdot
.66553 .45148 Mdot
.60192 .57872 Mdot
.68096 .04885 Mdot
.97661 .18273 Mdot
.30722 .20433 Mdot
.49806 .61721 Mdot
.49383 .61542 Mdot
.48033 .6097 Mdot
.43742 .59151 Mdot
.30303 .53498 Mdot
.94304 .39555 Mdot
.66668 .44723 Mdot
.59707 .57502 Mdot
.66421 .04149 Mdot
.93623 .16812 Mdot
.30137 .22566 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49542 .61609 Mdot
.48541 .61185 Mdot
.45354 .59834 Mdot
.35298 .55588 Mdot
.06193 .43816 Mdot
.68031 .38218 Mdot
.51491 .51581 Mdot
.37185 .52962 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49428 .61561 Mdot
.48177 .6103 Mdot
.44197 .59344 Mdot
.31703 .54082 Mdot
.97422 .40617 Mdot
.66991 .42996 Mdot
.57474 .55921 Mdot
.58761 .00795 Mdot
.72534 .08513 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50515 .00218 Mdot
.51641 .00696 Mdot
.55223 .02214 Mdot
.66501 .0697 Mdot
.98328 .1967 Mdot
.32658 .21217 Mdot
.45827 .08138 Mdot
.52807 .04314 Mdot
.63975 .06902 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50584 .00248 Mdot
.5186 .00789 Mdot
.55919 .02509 Mdot
.68655 .07871 Mdot
.03391 .21468 Mdot
.33079 .18348 Mdot
.41904 .05454 Mdot
.39103 .60072 Mdot
.21204 .50741 Mdot
.80107 .36404 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50761 .00323 Mdot
.52423 .01027 Mdot
.57706 .03265 Mdot
.74103 .10133 Mdot
.14334 .24864 Mdot
.35856 .13301 Mdot
.38845 .01848 Mdot
.26439 .54136 Mdot
.90258 .39442 Mdot
.67794 .4792 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48636 .61225 Mdot
.45657 .59962 Mdot
.36243 .55986 Mdot
.0867 .44762 Mdot
.68725 .37116 Mdot
.50823 .50739 Mdot
.34153 .51501 Mdot
.97451 .3912 Mdot
.64556 .41473 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.51511 .00641 Mdot
.5481 .02039 Mdot
.65216 .06431 Mdot
.95125 .18484 Mdot
.32232 .22934 Mdot
.47889 .09677 Mdot
.6039 .07726 Mdot
.87392 .16688 Mdot
.31389 .27192 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52504 .01062 Mdot
.57962 .03373 Mdot
.74871 .1045 Mdot
.15652 .25204 Mdot
.36561 .12922 Mdot
.39623 .01892 Mdot
.28199 .54743 Mdot
.49943 .61779 Mdot
.49819 .61726 Mdot
.49422 .61558 Mdot
.48158 .61022 Mdot
.44137 .59318 Mdot
.31519 .54005 Mdot
.97002 .40471 Mdot
.66956 .43234 Mdot
.57797 .56143 Mdot
.59873 .01283 Mdot
.75826 .09859 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52237 .00948 Mdot
.57115 .03015 Mdot
.72315 .09394 Mdot
.11049 .23939 Mdot
.34509 .14499 Mdot
.38232 .02301 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47344 .60677 Mdot
.41558 .58227 Mdot
.23693 .50762 Mdot
.82035 .36058 Mdot
.61956 .49394 Mdot
.58171 .59464 Mdot
.66112 .04908 Mdot
.94299 .17421 Mdot
.30856 .22593 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51517 .00643 Mdot
.54831 .02048 Mdot
.65279 .06458 Mdot
.95284 .18544 Mdot
.3226 .22852 Mdot
.47804 .09606 Mdot
.60063 .07577 Mdot
.86432 .16297 Mdot
.30776 .27406 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47497 .60742 Mdot
.42041 .58431 Mdot
.25138 .51357 Mdot
.84362 .36603 Mdot
.63447 .48877 Mdot
.60387 .59912 Mdot
.71825 .07069 Mdot
.06662 .21531 Mdot
.31796 .15533 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02053 Mdot
.65314 .06472 Mdot
.95374 .18578 Mdot
.32275 .22806 Mdot
.47755 .09567 Mdot
.59877 .07492 Mdot
.85881 .16072 Mdot
.30393 .2751 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48132 .61011 Mdot
.44055 .59284 Mdot
.31266 .53899 Mdot
.9643 .40274 Mdot
.66904 .43556 Mdot
.5823 .56442 Mdot
.61356 .01932 Mdot
.80109 .1159 Mdot
.21515 .2559 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49147 .61442 Mdot
.47284 .60652 Mdot
.41367 .58146 Mdot
.23125 .50529 Mdot
.81175 .35877 Mdot
.61324 .49535 Mdot
.57063 .5917 Mdot
.63051 .03701 Mdot
.86494 .14489 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61225 Mdot
.45659 .59963 Mdot
.3625 .55988 Mdot
.08687 .44769 Mdot
.68731 .37109 Mdot
.50821 .50734 Mdot
.3414 .51494 Mdot
.97416 .39107 Mdot
.64551 .41491 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50497 .00211 Mdot
.51583 .00671 Mdot
.55038 .02136 Mdot
.65926 .06729 Mdot
.96911 .1915 Mdot
.325 .21996 Mdot
.46819 .08849 Mdot
.56398 .0592 Mdot
.75317 .11693 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50692 .00294 Mdot
.52206 .00935 Mdot
.57017 .02973 Mdot
.72015 .0927 Mdot
.10468 .23765 Mdot
.34327 .14745 Mdot
.38296 .02453 Mdot
.26248 .54358 Mdot
.90401 .39649 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50555 .00236 Mdot
.5177 .0075 Mdot
.55632 .02387 Mdot
.67769 .07501 Mdot
.01356 .20758 Mdot
.32912 .19503 Mdot
.43484 .06534 Mdot
.44553 .00661 Mdot
.37611 .57513 Mdot
.13905 .47153 Mdot
.49831 .61732 Mdot
.49461 .61575 Mdot
.48284 .61076 Mdot
.44539 .59488 Mdot
.32761 .54524 Mdot
.99892 .4149 Mdot
.67185 .41589 Mdot
.55531 .54601 Mdot
.52007 .59626 Mdot
.51487 .61482 Mdot
.53194 .01055 Mdot
.49979 .61794 Mdot
.49932 .61775 Mdot
.49783 .61712 Mdot
.4931 .61511 Mdot
.47801 .60871 Mdot
.43005 .58839 Mdot
.28052 .52562 Mdot
.89662 .38077 Mdot
.65712 .47001 Mdot
.61684 .59314 Mdot
.73648 .07395 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00131 Mdot
.50987 .00419 Mdot
.53145 .01333 Mdot
.59988 .0423 Mdot
.8085 .12893 Mdot
.2399 .26662 Mdot
.43305 .11937 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00142 Mdot
.51069 .00454 Mdot
.53406 .01444 Mdot
.60814 .04578 Mdot
.83222 .13849 Mdot
.26389 .26678 Mdot
.45772 .1198 Mdot
.58888 .08106 Mdot
.84655 .15925 Mdot
.30035 .28046 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50344 .00146 Mdot
.51095 .00464 Mdot
.53487 .01478 Mdot
.61068 .04685 Mdot
.83945 .14139 Mdot
.27022 .26624 Mdot
.4642 .11988 Mdot
.60491 .08697 Mdot
.89185 .17734 Mdot
.32881 .27006 Mdot
.49772 .61707 Mdot
.49275 .61496 Mdot
.47689 .60824 Mdot
.4265 .58689 Mdot
.26972 .52114 Mdot
.87605 .37473 Mdot
.65007 .47837 Mdot
.61728 .59777 Mdot
.74493 .07889 Mdot
.11119 .22636 Mdot
.3239 .13146 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .0029 Mdot
.52182 .00925 Mdot
.56942 .02942 Mdot
.71789 .09176 Mdot
.10024 .23631 Mdot
.34198 .1494 Mdot
.38376 .02582 Mdot
.26626 .54542 Mdot
.91128 .39864 Mdot
.68259 .4767 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51876 .00796 Mdot
.55971 .02531 Mdot
.68814 .07938 Mdot
.03751 .21592 Mdot
.33113 .18147 Mdot
.41637 .05268 Mdot
.38185 .5967 Mdot
.18594 .49696 Mdot
.77038 .3612 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.5042 .00178 Mdot
.51338 .00567 Mdot
.54261 .01806 Mdot
.635 .0571 Mdot
.90645 .16777 Mdot
.31029 .24958 Mdot
.49232 .1125 Mdot
.66283 .10538 Mdot
.03715 .23134 Mdot
.35625 .19722 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.5054 .00229 Mdot
.5172 .00729 Mdot
.55474 .0232 Mdot
.67278 .07295 Mdot
.00199 .20347 Mdot
.32822 .20162 Mdot
.44397 .07154 Mdot
.47741 .02067 Mdot
.47708 .61783 Mdot
.44249 .59665 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60957 Mdot
.43651 .59113 Mdot
.30024 .53381 Mdot
.93703 .39356 Mdot
.66583 .45042 Mdot
.60075 .57781 Mdot
.6769 .04706 Mdot
.96705 .17932 Mdot
.30627 .20965 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48963 .61364 Mdot
.46696 .60403 Mdot
.3951 .57362 Mdot
.17704 .48326 Mdot
.74489 .35095 Mdot
.55135 .49842 Mdot
.43352 .54521 Mdot
.21883 .48535 Mdot
.76998 .34063 Mdot
.49926 .61772 Mdot
.49764 .61704 Mdot
.49249 .61485 Mdot
.47609 .6079 Mdot
.42396 .58582 Mdot
.26207 .51798 Mdot
.86212 .37086 Mdot
.64408 .48328 Mdot
.61382 .59933 Mdot
.74012 .07805 Mdot
.10468 .22531 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48984 .61372 Mdot
.46763 .60431 Mdot
.39719 .5745 Mdot
.18305 .48569 Mdot
.75099 .351 Mdot
.55766 .49855 Mdot
.44893 .55084 Mdot
.26491 .5043 Mdot
.8432 .3574 Mdot
.49802 .6172 Mdot
.4937 .61536 Mdot
.47994 .60953 Mdot
.43617 .59098 Mdot
.29919 .53338 Mdot
.9348 .39283 Mdot
.66549 .45159 Mdot
.60205 .57882 Mdot
.6814 .04904 Mdot
.97766 .1831 Mdot
.30732 .20374 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53634 .01541 Mdot
.61529 .0488 Mdot
.85246 .14658 Mdot
.28057 .26459 Mdot
.47434 .11976 Mdot
.6298 .09607 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49086 .61416 Mdot
.47089 .60569 Mdot
.40748 .57885 Mdot
.21299 .49783 Mdot
.7862 .35426 Mdot
.59198 .498 Mdot
.52819 .57861 Mdot
.50646 .6046 Mdot
.49441 .61059 Mdot
.50004 2e-05 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54192 .01777 Mdot
.63282 .05618 Mdot
.90062 .16551 Mdot
.30799 .25177 Mdot
.4923 .11391 Mdot
.66506 .10677 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52528 .01072 Mdot
.5804 .03406 Mdot
.75105 .10547 Mdot
.16042 .25301 Mdot
.36789 .12822 Mdot
.39918 .01934 Mdot
.28915 .55003 Mdot
.94757 .40693 Mdot
.68322 .45466 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48298 .61082 Mdot
.44583 .59507 Mdot
.32898 .54582 Mdot
.00218 .41607 Mdot
.67212 .41404 Mdot
.55276 .54427 Mdot
.51111 .59229 Mdot
.48612 .60259 Mdot
.44032 .58973 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47783 .60863 Mdot
.42946 .58814 Mdot
.27872 .52487 Mdot
.89313 .37972 Mdot
.65606 .47152 Mdot
.61734 .5941 Mdot
.7391 .07526 Mdot
.09904 .22245 Mdot
.31982 .13645 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.52299 .00975 Mdot
.57314 .03099 Mdot
.72919 .09644 Mdot
.12193 .24273 Mdot
.34915 .14043 Mdot
.38248 .0206 Mdot
.25512 .53932 Mdot
.88915 .39185 Mdot
.67633 .48651 Mdot
.49918 .61769 Mdot
.49739 .61693 Mdot
.4917 .61451 Mdot
.47355 .60682 Mdot
.41591 .58241 Mdot
.23792 .50803 Mdot
.82189 .36091 Mdot
.62064 .49366 Mdot
.58353 .59509 Mdot
.66603 .05099 Mdot
.9548 .17847 Mdot
.49921 .6177 Mdot
.49747 .61696 Mdot
.49195 .61462 Mdot
.47437 .60717 Mdot
.4185 .58351 Mdot
.24566 .51121 Mdot
.83417 .36372 Mdot
.6288 .49111 Mdot
.59622 .5979 Mdot
.69935 .06373 Mdot
.02921 .20387 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.5068 .00288 Mdot
.52165 .00918 Mdot
.56887 .02919 Mdot
.71622 .09106 Mdot
.09693 .2353 Mdot
.34107 .15089 Mdot
.38451 .02685 Mdot
.26953 .54697 Mdot
.91761 .40054 Mdot
.68383 .47355 Mdot
.49985 .61797 Mdot
.49953 .61783 Mdot
.4985 .6174 Mdot
.49521 .616 Mdot
.48473 .61156 Mdot
.45138 .59742 Mdot
.34623 .55305 Mdot
.04466 .43166 Mdot
.67698 .39079 Mdot
.52334 .52308 Mdot
.4046 .54465 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .0024 Mdot
.51806 .00766 Mdot
.55748 .02436 Mdot
.68126 .0765 Mdot
.02184 .21049 Mdot
.32977 .19031 Mdot
.42832 .06091 Mdot
.42296 .61472 Mdot
.30648 .54605 Mdot
.96616 .4077 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50793 .00336 Mdot
.52525 .01071 Mdot
.5803 .03402 Mdot
.75075 .10535 Mdot
.15993 .25289 Mdot
.3676 .12834 Mdot
.39879 .01928 Mdot
.28821 .54969 Mdot
.94573 .40637 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48403 .61126 Mdot
.44917 .59649 Mdot
.33936 .55017 Mdot
.02746 .42527 Mdot
.67458 .39994 Mdot
.53411 .53122 Mdot
.44443 .5626 Mdot
.27306 .51213 Mdot
.86547 .36613 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .6112 Mdot
.44866 .59627 Mdot
.33778 .5495 Mdot
.02355 .42383 Mdot
.67413 .40208 Mdot
.53682 .53317 Mdot
.45426 .56701 Mdot
.30403 .52519 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50719 .00305 Mdot
.5229 .00971 Mdot
.57285 .03087 Mdot
.72829 .09607 Mdot
.12025 .24224 Mdot
.34851 .14107 Mdot
.38233 .0209 Mdot
.25529 .53952 Mdot
.88965 .39206 Mdot
.67659 .48635 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50497 .00211 Mdot
.51583 .00671 Mdot
.5504 .02137 Mdot
.65932 .06732 Mdot
.96926 .19155 Mdot
.32502 .21987 Mdot
.46809 .08842 Mdot
.5636 .05903 Mdot
.75199 .11643 Mdot
.1791 .26397 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49146 .61441 Mdot
.47281 .6065 Mdot
.41357 .58142 Mdot
.23096 .50518 Mdot
.81132 .35869 Mdot
.61292 .49541 Mdot
.57003 .59153 Mdot
.62883 .03634 Mdot
.50014 6e-05 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.50441 .00187 Mdot
.51405 .00596 Mdot
.54474 .01897 Mdot
.64167 .05991 Mdot
.92414 .17457 Mdot
.31614 .24227 Mdot
.48972 .10728 Mdot
.64788 .09775 Mdot
.9973 .21595 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50508 .00215 Mdot
.51619 .00686 Mdot
.55154 .02185 Mdot
.66285 .0688 Mdot
.978 .19477 Mdot
.32604 .2151 Mdot
.46208 .08408 Mdot
.54179 .04926 Mdot
.68347 .08756 Mdot
.04332 .2224 Mdot
.49995 .61801 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.485 .61167 Mdot
.45224 .59779 Mdot
.3489 .55417 Mdot
.05146 .4342 Mdot
.67817 .38733 Mdot
.5197 .5201 Mdot
.49785 .61712 Mdot
.49314 .61513 Mdot
.47816 .60877 Mdot
.43052 .58859 Mdot
.28193 .5262 Mdot
.8994 .38162 Mdot
.65792 .46879 Mdot
.61632 .59232 Mdot
.73407 .07278 Mdot
.08936 .21958 Mdot
.31754 .14102 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48791 .61291 Mdot
.46148 .6017 Mdot
.37785 .56634 Mdot
.12845 .4639 Mdot
.70662 .35733 Mdot
.51472 .49943 Mdot
.34486 .51306 Mdot
.97743 .39095 Mdot
.64374 .4118 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.50301 .00128 Mdot
.50958 .00406 Mdot
.53052 .01294 Mdot
.59697 .04107 Mdot
.80003 .1255 Mdot
.23013 .26581 Mdot
.42335 .11942 Mdot
.506 .05108 Mdot
.59765 .05664 Mdot
.82675 .14159 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50787 .00334 Mdot
.52508 .01063 Mdot
.57974 .03378 Mdot
.74907 .10465 Mdot
.15714 .2522 Mdot
.36596 .12906 Mdot
.39667 .01898 Mdot
.28306 .54782 Mdot
.93584 .40344 Mdot
.68228 .46132 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50438 .00186 Mdot
.51397 .00592 Mdot
.54447 .01885 Mdot
.64081 .05954 Mdot
.92187 .17371 Mdot
.31547 .24326 Mdot
.49026 .10803 Mdot
.65046 .09901 Mdot
.00419 .21862 Mdot
.35164 .21473 Mdot
.50041 .00017 Mdot
.50131 .00055 Mdot
.50417 .00177 Mdot
.51328 .00563 Mdot
.54228 .01792 Mdot
.63396 .05666 Mdot
.90368 .1667 Mdot
.30922 .25064 Mdot
.49237 .11319 Mdot
.66406 .10612 Mdot
.04053 .23267 Mdot
.35686 .1955 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50344 .00146 Mdot
.51096 .00465 Mdot
.53492 .0148 Mdot
.61082 .04691 Mdot
.83985 .14155 Mdot
.27057 .2662 Mdot
.46454 .11988 Mdot
.60578 .08729 Mdot
.89425 .17828 Mdot
.32993 .26927 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51543 .00654 Mdot
.54913 .02083 Mdot
.65535 .06565 Mdot
.95932 .18786 Mdot
.32365 .22517 Mdot
.47435 .09314 Mdot
.58674 .06946 Mdot
.82291 .14596 Mdot
.27319 .27829 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50947 .00402 Mdot
.53017 .01279 Mdot
.59586 .0406 Mdot
.7968 .12419 Mdot
.22623 .2654 Mdot
.41958 .1195 Mdot
.49737 .04808 Mdot
.57121 .04564 Mdot
.74834 .10947 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00226 Mdot
.51695 .00719 Mdot
.55395 .02287 Mdot
.67033 .07193 Mdot
.99615 .20137 Mdot
.32775 .20494 Mdot
.44853 .07465 Mdot
.49346 .02776 Mdot
.52857 .0217 Mdot
.6063 .04804 Mdot
.49927 .61772 Mdot
.49768 .61705 Mdot
.4926 .61489 Mdot
.47642 .60803 Mdot
.42499 .58625 Mdot
.26518 .51926 Mdot
.86772 .37239 Mdot
.64661 .48138 Mdot
.61561 .59887 Mdot
.74317 .07884 Mdot
.10924 .22624 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49681 .61668 Mdot
.48983 .61372 Mdot
.46761 .6043 Mdot
.39715 .57449 Mdot
.18293 .48564 Mdot
.75087 .351 Mdot
.55753 .49854 Mdot
.44862 .55072 Mdot
.26396 .50391 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50455 .00193 Mdot
.51449 .00614 Mdot
.54614 .01956 Mdot
.64602 .06173 Mdot
.93548 .17889 Mdot
.31909 .23708 Mdot
.48611 .10322 Mdot
.63232 .09036 Mdot
.95491 .19938 Mdot
.34424 .24062 Mdot
.49919 .61769 Mdot
.49742 .61694 Mdot
.49178 .61455 Mdot
.47383 .60694 Mdot
.41679 .58278 Mdot
.24054 .50911 Mdot
.82598 .36182 Mdot
.62346 .49287 Mdot
.58811 .59619 Mdot
.67828 .05573 Mdot
.98335 .18854 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51224 .00519 Mdot
.53899 .01653 Mdot
.62363 .05231 Mdot
.87564 .15575 Mdot
.29577 .25966 Mdot
.48698 .11817 Mdot
.65867 .10611 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51555 .00659 Mdot
.54951 .02099 Mdot
.65653 .06614 Mdot
.96228 .18896 Mdot
.32408 .22361 Mdot
.47256 .09176 Mdot
.58007 .06645 Mdot
.80269 .13758 Mdot
.25107 .27712 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50379 .00161 Mdot
.51207 .00512 Mdot
.53843 .01629 Mdot
.62188 .05158 Mdot
.87081 .15384 Mdot
.29293 .26089 Mdot
.48495 .11868 Mdot
.65443 .10474 Mdot
.02087 .22647 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52351 .00997 Mdot
.57478 .03169 Mdot
.73413 .09849 Mdot
.13103 .2453 Mdot
.35285 .13709 Mdot
.38407 .01929 Mdot
.25636 .53911 Mdot
.89011 .39168 Mdot
.67591 .48565 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50497 .00211 Mdot
.51583 .00671 Mdot
.55041 .02137 Mdot
.65934 .06732 Mdot
.96932 .19157 Mdot
.32503 .21984 Mdot
.46805 .08839 Mdot
.56347 .05897 Mdot
.75159 .11627 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52638 .01119 Mdot
.58387 .03553 Mdot
.76142 .10973 Mdot
.17709 .2569 Mdot
.37864 .12457 Mdot
.4153 .02265 Mdot
.3308 .56582 Mdot
.03769 .43688 Mdot
.68857 .40226 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.4798 .60947 Mdot
.43572 .59079 Mdot
.29783 .53281 Mdot
.93189 .39188 Mdot
.66503 .4531 Mdot
.60368 .58012 Mdot
.68709 .05155 Mdot
.99081 .18771 Mdot
.30831 .19623 Mdot
.49925 .61772 Mdot
.49763 .61703 Mdot
.49243 .61483 Mdot
.4759 .60781 Mdot
.42335 .58556 Mdot
.26022 .51722 Mdot
.85886 .36998 Mdot
.64252 .48433 Mdot
.61253 .5995 Mdot
.73761 .0773 Mdot
.1007 .2244 Mdot
.50048 .0002 Mdot
.50152 .00065 Mdot
.50485 .00206 Mdot
.51545 .00655 Mdot
.54918 .02085 Mdot
.65552 .06572 Mdot
.95975 .18802 Mdot
.32371 .22494 Mdot
.47409 .09294 Mdot
.58577 .06902 Mdot
.81998 .14475 Mdot
.27021 .27826 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00248 Mdot
.51867 .00792 Mdot
.55941 .02518 Mdot
.68722 .07899 Mdot
.03543 .2152 Mdot
.33093 .18263 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47498 .60742 Mdot
.42043 .58432 Mdot
.25143 .51359 Mdot
.84371 .36605 Mdot
.63452 .48875 Mdot
.60393 .59913 Mdot
.7184 .07074 Mdot
.06691 .21539 Mdot
.31798 .15517 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47786 .60865 Mdot
.42958 .58819 Mdot
.27907 .52502 Mdot
.8938 .37993 Mdot
.65627 .47123 Mdot
.61725 .59392 Mdot
.73864 .07502 Mdot
.09814 .22219 Mdot
.31959 .13686 Mdot
.49795 .61716 Mdot
.49347 .61527 Mdot
.4792 .60921 Mdot
.43382 .58999 Mdot
.29199 .53038 Mdot
.9197 .38794 Mdot
.66281 .45927 Mdot
.60972 .58522 Mdot
.70847 .06103 Mdot
.03788 .20359 Mdot
.311 .1688 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51796 .00761 Mdot
.55715 .02422 Mdot
.68024 .07607 Mdot
.0195 .20967 Mdot
.32958 .19164 Mdot
.43016 .06216 Mdot
.4293 .6175 Mdot
.49879 .61752 Mdot
.49613 .61639 Mdot
.48768 .61281 Mdot
.46075 .60139 Mdot
.37554 .56537 Mdot
.1221 .4614 Mdot
.70296 .35899 Mdot
.51219 .50013 Mdot
.33967 .51142 Mdot
.96534 .38668 Mdot
.64258 .41856 Mdot
.49914 .61767 Mdot
.49725 .61687 Mdot
.49125 .61432 Mdot
.47213 .60622 Mdot
.41143 .58052 Mdot
.22461 .50258 Mdot
.8021 .35691 Mdot
.60564 .49662 Mdot
.55625 .58751 Mdot
.58951 .02055 Mdot
.75006 .09922 Mdot
.4995 .61782 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48376 .61115 Mdot
.4483 .59612 Mdot
.33666 .54903 Mdot
.02081 .42283 Mdot
.67383 .40359 Mdot
.53877 .53456 Mdot
.46128 .57014 Mdot
.32628 .5346 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54142 .01756 Mdot
.63126 .05552 Mdot
.89641 .16387 Mdot
.30621 .25327 Mdot
.492 .11483 Mdot
.66581 .10742 Mdot
.04573 .2348 Mdot
.35799 .19299 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00207 Mdot
.51552 .00658 Mdot
.54941 .02095 Mdot
.65623 .06602 Mdot
.96153 .18869 Mdot
.32398 .224 Mdot
.47302 .09211 Mdot
.58178 .06722 Mdot
.80787 .13974 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00131 Mdot
.50987 .00419 Mdot
.53144 .01333 Mdot
.59986 .04229 Mdot
.80844 .12891 Mdot
.23983 .26662 Mdot
.43298 .11937 Mdot
.52855 .05906 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47564 .60771 Mdot
.42253 .58521 Mdot
.25776 .5162 Mdot
.85453 .36883 Mdot
.64037 .48568 Mdot
.61052 .59958 Mdot
.73343 .07596 Mdot
.09378 .22271 Mdot
.32146 .14072 Mdot
.49897 .6176 Mdot
.49671 .61664 Mdot
.48953 .61359 Mdot
.46665 .60389 Mdot
.39411 .5732 Mdot
.17419 .48212 Mdot
.74212 .351 Mdot
.54848 .49836 Mdot
.42645 .54261 Mdot
.19798 .47683 Mdot
.74342 .3371 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51705 .00723 Mdot
.55427 .023 Mdot
.67133 .07235 Mdot
.99854 .20223 Mdot
.32794 .20358 Mdot
.44667 .07338 Mdot
.4869 .02486 Mdot
.5075 .01273 Mdot
.53936 .01969 Mdot
.49828 .6173 Mdot
.49451 .61571 Mdot
.48252 .61062 Mdot
.44436 .59445 Mdot
.32444 .54392 Mdot
.99142 .41222 Mdot
.67127 .42017 Mdot
.56122 .55002 Mdot
.54077 .60539 Mdot
.5808 .02474 Mdot
.7369 .09647 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.5035 .00149 Mdot
.51116 .00473 Mdot
.53556 .01508 Mdot
.61284 .04776 Mdot
.84556 .14383 Mdot
.27525 .26557 Mdot
.46922 .11988 Mdot
.61729 .09152 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50658 .00279 Mdot
.52095 .00888 Mdot
.56665 .02824 Mdot
.70942 .08824 Mdot
.08322 .23102 Mdot
.33779 .15734 Mdot
.38905 .03168 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.48659 .61235 Mdot
.45731 .59994 Mdot
.36475 .56083 Mdot
.09288 .45001 Mdot
.68946 .36871 Mdot
.50771 .50571 Mdot
.33752 .51285 Mdot
.96378 .38705 Mdot
.64391 .42034 Mdot
.49859 .61744 Mdot
.4955 .61613 Mdot
.48568 .61196 Mdot
.45439 .5987 Mdot
.35562 .55699 Mdot
.06878 .44076 Mdot
.68195 .37896 Mdot
.51237 .51323 Mdot
.36133 .52469 Mdot
.02763 .41179 Mdot
.65269 .38631 Mdot
.5007 .0003 Mdot
.50225 .00095 Mdot
.50716 .00303 Mdot
.5228 .00967 Mdot
.57251 .03073 Mdot
.72727 .09565 Mdot
.11833 .24169 Mdot
.3478 .14182 Mdot
.38222 .02127 Mdot
.25564 .53981 Mdot
.89049 .39236 Mdot
.67694 .48606 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00126 Mdot
.50944 .00401 Mdot
.53008 .01276 Mdot
.59558 .04048 Mdot
.79598 .12386 Mdot
.22522 .26529 Mdot
.41862 .11952 Mdot
.49519 .04733 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48013 .60961 Mdot
.43677 .59123 Mdot
.30103 .53414 Mdot
.93872 .39412 Mdot
.66608 .44953 Mdot
.59975 .57704 Mdot
.67343 .04554 Mdot
.95874 .17633 Mdot
.30525 .21416 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50625 .00265 Mdot
.51991 .00844 Mdot
.56335 .02685 Mdot
.69932 .08404 Mdot
.06202 .22416 Mdot
.33403 .16811 Mdot
.39981 .04065 Mdot
.32503 .57182 Mdot
.03757 .44037 Mdot
.69427 .40586 Mdot
.4981 .61723 Mdot
.49394 .61546 Mdot
.48068 .60984 Mdot
.43852 .59198 Mdot
.30643 .53639 Mdot
.95045 .39803 Mdot
.6676 .44322 Mdot
.5922 .57143 Mdot
.64748 .03417 Mdot
.89366 .15215 Mdot
.28774 .24356 Mdot
.49745 .61695 Mdot
.49186 .61458 Mdot
.47409 .60705 Mdot
.41761 .58313 Mdot
.24298 .51011 Mdot
.82986 .36271 Mdot
.62604 .49207 Mdot
.59213 .59708 Mdot
.68882 .05976 Mdot
.00682 .19654 Mdot
.31459 .19022 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.47849 .60891 Mdot
.43156 .58903 Mdot
.28511 .52752 Mdot
.90571 .38355 Mdot
.65962 .46594 Mdot
.61478 .59032 Mdot
.72758 .06971 Mdot
.07674 .2158 Mdot
.3152 .14738 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50483 .00205 Mdot
.51538 .00652 Mdot
.54896 .02076 Mdot
.65484 .06544 Mdot
.95803 .18738 Mdot
.32345 .22584 Mdot
.47511 .09373 Mdot
.58958 .07075 Mdot
.83145 .14948 Mdot
.28146 .27812 Mdot
.49752 .61698 Mdot
.4921 .61468 Mdot
.47482 .60736 Mdot
.41993 .58411 Mdot
.24994 .51297 Mdot
.84122 .36543 Mdot
.63308 .4894 Mdot
.6021 .59889 Mdot
.71398 .06914 Mdot
.0585 .21293 Mdot
.31723 .15991 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49675 .61666 Mdot
.48965 .61364 Mdot
.46703 .60406 Mdot
.39531 .57371 Mdot
.17764 .48351 Mdot
.74549 .35095 Mdot
.55198 .49844 Mdot
.43505 .54577 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51748 .00741 Mdot
.55564 .02358 Mdot
.67556 .07412 Mdot
.00858 .20582 Mdot
.32873 .19787 Mdot
.43878 .06801 Mdot
.45924 .01265 Mdot
.41924 .59331 Mdot
.26323 .52161 Mdot
.49975 .61793 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.4919 .6146 Mdot
.47421 .6071 Mdot
.41801 .5833 Mdot
.24418 .5106 Mdot
.83178 .36316 Mdot
.62729 .49165 Mdot
.59401 .59747 Mdot
.69368 .0616 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50207 .00088 Mdot
.50658 .00279 Mdot
.52097 .00889 Mdot
.56671 .02827 Mdot
.7096 .08832 Mdot
.08359 .23113 Mdot
.33787 .15716 Mdot
.3889 .03154 Mdot
.28649 .55474 Mdot
.95159 .41105 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51264 .00536 Mdot
.54026 .01707 Mdot
.62763 .054 Mdot
.88657 .16003 Mdot
.30161 .25651 Mdot
.49037 .11666 Mdot
.66469 .10773 Mdot
.04425 .23459 Mdot
.35829 .19409 Mdot
.49861 .61745 Mdot
.49559 .61616 Mdot
.48594 .61207 Mdot
.45523 .59906 Mdot
.35825 .5581 Mdot
.07567 .44339 Mdot
.68381 .37585 Mdot
.51033 .51082 Mdot
.35234 .52039 Mdot
.00329 .40231 Mdot
.64931 .39926 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52315 .00982 Mdot
.57364 .0312 Mdot
.7307 .09707 Mdot
.12473 .24353 Mdot
.35024 .13937 Mdot
.38282 .02014 Mdot
.2551 .53909 Mdot
.88876 .39163 Mdot
.67603 .48656 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50428 .00181 Mdot
.51362 .00578 Mdot
.54337 .01839 Mdot
.63738 .0581 Mdot
.91281 .17022 Mdot
.31258 .24707 Mdot
.49183 .11079 Mdot
.65884 .10322 Mdot
.02648 .22721 Mdot
.49965 .61789 Mdot
.49888 .61756 Mdot
.49644 .61653 Mdot
.48867 .61323 Mdot
.46392 .60274 Mdot
.38553 .56958 Mdot
.14984 .47237 Mdot
.72116 .35309 Mdot
.5273 .49822 Mdot
.37419 .52341 Mdot
.05141 .41855 Mdot
.49956 .61785 Mdot
.49861 .61744 Mdot
.49556 .61615 Mdot
.48585 .61203 Mdot
.45495 .59894 Mdot
.35737 .55773 Mdot
.07336 .4425 Mdot
.68316 .37688 Mdot
.51096 .5116 Mdot
.35517 .52175 Mdot
.01091 .40527 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50438 .00186 Mdot
.51397 .00592 Mdot
.54447 .01885 Mdot
.64082 .05955 Mdot
.92191 .17372 Mdot
.31548 .24325 Mdot
.49026 .10801 Mdot
.65042 .09899 Mdot
.0041 .21858 Mdot
.35163 .21479 Mdot
.49769 .61705 Mdot
.49263 .61491 Mdot
.47651 .60807 Mdot
.42529 .58638 Mdot
.26607 .51963 Mdot
.86933 .37284 Mdot
.64731 .48082 Mdot
.61602 .5987 Mdot
.74376 .07895 Mdot
.11005 .22638 Mdot
.32411 .1323 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52246 .00952 Mdot
.57146 .03028 Mdot
.72407 .09432 Mdot
.11226 .23991 Mdot
.34568 .14426 Mdot
.38222 .02258 Mdot
.25777 .54112 Mdot
.89487 .39375 Mdot
.67845 .48428 Mdot
.49826 .61729 Mdot
.49444 .61568 Mdot
.4823 .61053 Mdot
.44366 .59415 Mdot
.32225 .543 Mdot
.98629 .4104 Mdot
.67087 .42309 Mdot
.56528 .55277 Mdot
.55488 .61161 Mdot
.62517 .04344 Mdot
.86446 .14789 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51648 .00699 Mdot
.55247 .02224 Mdot
.66575 .07001 Mdot
.98508 .19736 Mdot
.32676 .21117 Mdot
.45694 .08046 Mdot
.52332 .04103 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48038 .60971 Mdot
.43756 .59157 Mdot
.30346 .53516 Mdot
.94397 .39586 Mdot
.6668 .44673 Mdot
.59648 .57457 Mdot
.66216 .0406 Mdot
.93114 .16624 Mdot
.30021 .2281 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48365 .6111 Mdot
.44794 .59596 Mdot
.33552 .54856 Mdot
.01801 .4218 Mdot
.67354 .40514 Mdot
.54079 .53599 Mdot
.46856 .57339 Mdot
.34948 .54444 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.47551 .60765 Mdot
.4221 .58503 Mdot
.25647 .51567 Mdot
.8523 .36824 Mdot
.63922 .48634 Mdot
.60934 .59957 Mdot
.73087 .07511 Mdot
.08941 .22159 Mdot
.32078 .143 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50263 .00112 Mdot
.50838 .00356 Mdot
.52671 .01132 Mdot
.5849 .03597 Mdot
.76449 .11099 Mdot
.18182 .25793 Mdot
.38199 .12371 Mdot
.42094 .02407 Mdot
.3461 .57178 Mdot
.07474 .45033 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50827 .00351 Mdot
.52636 .01118 Mdot
.5838 .0355 Mdot
.76122 .10965 Mdot
.17677 .25683 Mdot
.37842 .12463 Mdot
.41493 .02256 Mdot
.32983 .56544 Mdot
.0354 .43607 Mdot
.68831 .40352 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48126 .61009 Mdot
.44035 .59275 Mdot
.31206 .53874 Mdot
.96296 .40228 Mdot
.66892 .43631 Mdot
.58329 .56511 Mdot
.61697 .02082 Mdot
.81074 .11975 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52368 .01004 Mdot
.57532 .03191 Mdot
.73576 .09916 Mdot
.13399 .24612 Mdot
.35414 .13606 Mdot
.38488 .019 Mdot
.2576 .53937 Mdot
.89186 .39199 Mdot
.67613 .48471 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50617 .00262 Mdot
.51967 .00834 Mdot
.5626 .02653 Mdot
.69702 .08308 Mdot
.05707 .22252 Mdot
.33334 .17074 Mdot
.40286 .04297 Mdot
.33554 .57643 Mdot
.06315 .44969 Mdot
.6985 .39267 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50781 .00331 Mdot
.52488 .01055 Mdot
.57911 .03352 Mdot
.74717 .10387 Mdot
.15392 .25139 Mdot
.36414 .12992 Mdot
.39443 .01872 Mdot
.27773 .54591 Mdot
.92592 .4006 Mdot
.68126 .46682 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50684 .0029 Mdot
.5218 .00925 Mdot
.56937 .02939 Mdot
.71771 .09168 Mdot
.0999 .2362 Mdot
.34188 .14956 Mdot
.38383 .02592 Mdot
.26658 .54557 Mdot
.9119 .39883 Mdot
.68272 .47639 Mdot
.49798 .61718 Mdot
.49358 .61531 Mdot
.47954 .60936 Mdot
.43489 .59044 Mdot
.29528 .53175 Mdot
.92653 .39014 Mdot
.66411 .45585 Mdot
.60651 .58243 Mdot
.697 .05593 Mdot
.0131 .19536 Mdot
.30958 .18323 Mdot
.49956 .61785 Mdot
.4986 .61744 Mdot
.49554 .61614 Mdot
.48581 .61201 Mdot
.4548 .59887 Mdot
.35691 .55753 Mdot
.07216 .44205 Mdot
.68284 .37742 Mdot
.5113 .51202 Mdot
.35671 .52249 Mdot
.01507 .40689 Mdot
.49918 .61768 Mdot
.49737 .61692 Mdot
.49163 .61448 Mdot
.47334 .60673 Mdot
.41524 .58213 Mdot
.23594 .50722 Mdot
.81884 .36025 Mdot
.61848 .49421 Mdot
.57988 .59418 Mdot
.65613 .04712 Mdot
.93077 .16974 Mdot
.49828 .6173 Mdot
.49451 .6157 Mdot
.4825 .61061 Mdot
.44428 .59442 Mdot
.32419 .54381 Mdot
.99084 .41201 Mdot
.67122 .4205 Mdot
.56168 .55034 Mdot
.54237 .6061 Mdot
.58588 .02689 Mdot
.75204 .10269 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50636 .0027 Mdot
.52026 .00859 Mdot
.56448 .02733 Mdot
.70278 .08548 Mdot
.06938 .22657 Mdot
.33518 .16427 Mdot
.39562 .03736 Mdot
.31049 .56542 Mdot
.00365 .4284 Mdot
.69134 .42501 Mdot
.49991 .61799 Mdot
.4997 .61791 Mdot
.49906 .61763 Mdot
.497 .61676 Mdot
.49044 .61398 Mdot
.46954 .60512 Mdot
.40322 .57705 Mdot
.20052 .49276 Mdot
.77054 .35229 Mdot
.57729 .4986 Mdot
.49549 .56748 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.5044 .00187 Mdot
.51402 .00595 Mdot
.54465 .01893 Mdot
.64139 .05979 Mdot
.9234 .17429 Mdot
.31592 .24259 Mdot
.4899 .10753 Mdot
.64874 .09817 Mdot
.99961 .21685 Mdot
.35106 .21721 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50399 .00169 Mdot
.51272 .00539 Mdot
.5405 .01717 Mdot
.62838 .05431 Mdot
.88863 .16084 Mdot
.30263 .25586 Mdot
.49082 .11631 Mdot
.66526 .10781 Mdot
.04538 .23493 Mdot
.35835 .19342 Mdot
.49981 .61795 Mdot
.49938 .61777 Mdot
.49804 .6172 Mdot
.49374 .61538 Mdot
.48007 .60958 Mdot
.43657 .59115 Mdot
.30043 .53389 Mdot
.93743 .39369 Mdot
.66589 .45021 Mdot
.60052 .57763 Mdot
.67609 .04671 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51176 .00499 Mdot
.53745 .01588 Mdot
.6188 .05028 Mdot
.86226 .15047 Mdot
.28749 .2628 Mdot
.48057 .11933 Mdot
.64459 .10137 Mdot
.99686 .21772 Mdot
.35384 .22063 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50341 .00144 Mdot
.51085 .0046 Mdot
.53455 .01465 Mdot
.60968 .04643 Mdot
.83661 .14025 Mdot
.26779 .26648 Mdot
.46173 .11986 Mdot
.5988 .08472 Mdot
.87474 .17054 Mdot
.31977 .27504 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50531 .00225 Mdot
.51692 .00717 Mdot
.55386 .02283 Mdot
.67006 .07182 Mdot
.99552 .20114 Mdot
.32769 .2053 Mdot
.44902 .07498 Mdot
.49518 .02853 Mdot
.53411 .02406 Mdot
.62381 .05544 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48907 .6134 Mdot
.46519 .60327 Mdot
.38951 .57126 Mdot
.16109 .47686 Mdot
.73023 .35175 Mdot
.53626 .49816 Mdot
.39621 .53148 Mdot
.11129 .44194 Mdot
.67271 .34697 Mdot
.49837 .61734 Mdot
.49481 .61583 Mdot
.48347 .61102 Mdot
.44737 .59573 Mdot
.33376 .54782 Mdot
.01373 .42024 Mdot
.67313 .40753 Mdot
.54395 .5382 Mdot
.47985 .57842 Mdot
.38561 .55979 Mdot
.13417 .46264 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.51212 .00514 Mdot
.53859 .01636 Mdot
.62239 .05179 Mdot
.87219 .15439 Mdot
.29376 .26054 Mdot
.48556 .11854 Mdot
.65574 .10518 Mdot
.024 .22759 Mdot
.49955 .61784 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.4853 .6118 Mdot
.45319 .59819 Mdot
.35188 .55542 Mdot
.05911 .43709 Mdot
.6797 .38354 Mdot
.5161 .51693 Mdot
.37661 .53182 Mdot
.07002 .42855 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.4869 .61248 Mdot
.45828 .60035 Mdot
.36781 .56212 Mdot
.10107 .45318 Mdot
.69271 .36566 Mdot
.50779 .50374 Mdot
.33455 .51096 Mdot
.95547 .38375 Mdot
.64232 .4245 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50558 .00237 Mdot
.51779 .00754 Mdot
.55661 .024 Mdot
.67857 .07538 Mdot
.01563 .20831 Mdot
.32928 .19385 Mdot
.4332 .06423 Mdot
.43985 .00411 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.50411 .00174 Mdot
.51309 .00555 Mdot
.54168 .01767 Mdot
.63207 .05586 Mdot
.89859 .16472 Mdot
.30714 .2525 Mdot
.49219 .11436 Mdot
.66552 .10712 Mdot
.04473 .23436 Mdot
.4975 .61697 Mdot
.49203 .61465 Mdot
.4746 .60727 Mdot
.41925 .58382 Mdot
.2479 .51213 Mdot
.83783 .3646 Mdot
.63106 .49024 Mdot
.5994 .59847 Mdot
.70734 .06671 Mdot
.04548 .20898 Mdot
.31633 .16739 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48988 .61374 Mdot
.46778 .60437 Mdot
.39767 .57471 Mdot
.18444 .48625 Mdot
.75244 .35104 Mdot
.55915 .49857 Mdot
.45254 .55215 Mdot
.27581 .50881 Mdot
.86347 .3632 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00116 Mdot
.50875 .00371 Mdot
.52787 .01182 Mdot
.58857 .03752 Mdot
.77538 .11545 Mdot
.19789 .26113 Mdot
.39435 .12142 Mdot
.44373 .03051 Mdot
.41043 .59746 Mdot
.24978 .51874 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.5059 .0025 Mdot
.51878 .00797 Mdot
.55978 .02534 Mdot
.68836 .07947 Mdot
.038 .21609 Mdot
.33117 .18119 Mdot
.416 .05243 Mdot
.3806 .59616 Mdot
.18244 .49556 Mdot
.49798 .61718 Mdot
.49355 .6153 Mdot
.47946 .60933 Mdot
.43466 .59034 Mdot
.29457 .53145 Mdot
.92504 .38965 Mdot
.66384 .45661 Mdot
.60724 .58305 Mdot
.69961 .05709 Mdot
.01885 .1973 Mdot
.30988 .17987 Mdot
.49839 .61735 Mdot
.49488 .61586 Mdot
.48368 .61111 Mdot
.44805 .59601 Mdot
.33586 .5487 Mdot
.01885 .42211 Mdot
.67363 .40468 Mdot
.54018 .53556 Mdot
.46636 .57241 Mdot
.34247 .54146 Mdot
.019 .41812 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48653 .61232 Mdot
.45712 .59986 Mdot
.36417 .56059 Mdot
.09132 .4494 Mdot
.68888 .36932 Mdot
.50779 .50611 Mdot
.33839 .51334 Mdot
.96613 .38797 Mdot
.64429 .41913 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.4876 .61277 Mdot
.4605 .60129 Mdot
.37476 .56504 Mdot
.11996 .46056 Mdot
.70178 .35958 Mdot
.51146 .50041 Mdot
.3383 .51102 Mdot
.96223 .38561 Mdot
.64228 .42029 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52363 .01002 Mdot
.57517 .03185 Mdot
.7353 .09897 Mdot
.13316 .24589 Mdot
.35377 .13635 Mdot
.38463 .01907 Mdot
.25721 .53928 Mdot
.8913 .39189 Mdot
.67605 .48501 Mdot
.49902 .61762 Mdot
.49689 .61671 Mdot
.49008 .61383 Mdot
.46842 .60464 Mdot
.39968 .57555 Mdot
.19024 .48859 Mdot
.7587 .35133 Mdot
.56553 .49865 Mdot
.46791 .5577 Mdot
.32249 .52816 Mdot
.96268 .39566 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51414 .006 Mdot
.54504 .01909 Mdot
.6426 .06029 Mdot
.92655 .1755 Mdot
.31681 .24119 Mdot
.48907 .10646 Mdot
.64494 .09633 Mdot
.98939 .21288 Mdot
.34974 .22271 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.5078 .00331 Mdot
.52485 .01054 Mdot
.57903 .03348 Mdot
.74694 .10378 Mdot
.15354 .25129 Mdot
.36393 .13003 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48425 .61136 Mdot
.44986 .59678 Mdot
.34149 .55106 Mdot
.03275 .42723 Mdot
.67524 .39708 Mdot
.53059 .52864 Mdot
.43155 .55682 Mdot
.23297 .4953 Mdot
.79702 .3486 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.51872 .00794 Mdot
.55956 .02525 Mdot
.68769 .07918 Mdot
.03648 .21556 Mdot
.33103 .18204 Mdot
.41713 .05321 Mdot
.38446 .59784 Mdot
.1933 .49989 Mdot
.7784 .36161 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47572 .60774 Mdot
.42279 .58532 Mdot
.25852 .51651 Mdot
.85586 .36918 Mdot
.64105 .48527 Mdot
.61117 .59957 Mdot
.73482 .07642 Mdot
.09612 .22329 Mdot
.32184 .13951 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51606 .00681 Mdot
.55113 .02167 Mdot
.66158 .06826 Mdot
.97486 .19362 Mdot
.32569 .21683 Mdot
.46429 .08566 Mdot
.54977 .05283 Mdot
.7087 .09822 Mdot
.09836 .24083 Mdot
.49941 .61778 Mdot
.49812 .61723 Mdot
.494 .61549 Mdot
.48087 .60992 Mdot
.43913 .59224 Mdot
.30829 .53717 Mdot
.95456 .39941 Mdot
.66806 .44097 Mdot
.58936 .56939 Mdot
.63776 .02991 Mdot
.86794 .14226 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50298 .00126 Mdot
.50949 .00402 Mdot
.53022 .01281 Mdot
.59601 .04066 Mdot
.79723 .12436 Mdot
.22675 .26546 Mdot
.42008 .11948 Mdot
.49851 .04847 Mdot
.57469 .04709 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50594 .00252 Mdot
.51892 .00802 Mdot
.56021 .02552 Mdot
.68966 .08001 Mdot
.0409 .21708 Mdot
.33146 .17958 Mdot
.41388 .05094 Mdot
.37334 .59298 Mdot
.16223 .48756 Mdot
.74778 .36189 Mdot
.49858 .61743 Mdot
.49548 .61612 Mdot
.48559 .61192 Mdot
.45412 .59858 Mdot
.35477 .55663 Mdot
.06656 .43992 Mdot
.6814 .37999 Mdot
.51314 .51404 Mdot
.36456 .52621 Mdot
.03647 .41526 Mdot
.65415 .38175 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50793 .00336 Mdot
.52527 .01072 Mdot
.58037 .03405 Mdot
.75096 .10543 Mdot
.16027 .25297 Mdot
.3678 .12826 Mdot
.39906 .01932 Mdot
.28886 .54993 Mdot
.94701 .40676 Mdot
.68318 .45498 Mdot
.49896 .61759 Mdot
.49668 .61662 Mdot
.48941 .61354 Mdot
.46627 .60373 Mdot
.39291 .57269 Mdot
.17075 .48074 Mdot
.73886 .35111 Mdot
.54511 .49829 Mdot
.41811 .53955 Mdot
.17364 .46694 Mdot
.71738 .33605 Mdot
.49906 .61764 Mdot
.49702 .61677 Mdot
.4905 .614 Mdot
.46973 .6052 Mdot
.40384 .57731 Mdot
.20233 .49349 Mdot
.77271 .35252 Mdot
.5794 .49856 Mdot
.50031 .56915 Mdot
.42169 .56944 Mdot
.23029 .49974 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50815 .00346 Mdot
.52596 .01101 Mdot
.58255 .03497 Mdot
.75747 .10811 Mdot
.17086 .25549 Mdot
.37443 .12581 Mdot
.40859 .02111 Mdot
.31306 .55899 Mdot
.99729 .42288 Mdot
.50074 .00031 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52401 .01018 Mdot
.57635 .03235 Mdot
.73889 .10045 Mdot
.13957 .24764 Mdot
.35672 .13421 Mdot
.38682 .01861 Mdot
.26111 .54034 Mdot
.89725 .39316 Mdot
.67703 .48193 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00349 Mdot
.52619 .0111 Mdot
.58326 .03527 Mdot
.75961 .10899 Mdot
.17425 .25626 Mdot
.3767 .12512 Mdot
.41214 .0219 Mdot
.32238 .56256 Mdot
.01815 .43001 Mdot
.68676 .41322 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.50842 .00357 Mdot
.52682 .01137 Mdot
.58525 .03611 Mdot
.76553 .11142 Mdot
.18341 .25826 Mdot
.38315 .12344 Mdot
.42294 .02459 Mdot
.3516 .57395 Mdot
.08855 .45546 Mdot
.49759 .61701 Mdot
.49234 .61478 Mdot
.47559 .60768 Mdot
.42237 .58514 Mdot
.25726 .51599 Mdot
.85368 .3686 Mdot
.63993 .48593 Mdot
.61008 .59958 Mdot
.73248 .07565 Mdot
.09217 .2223 Mdot
.3212 .14155 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51788 .00758 Mdot
.55691 .02412 Mdot
.67949 .07576 Mdot
.01776 .20906 Mdot
.32944 .19263 Mdot
.43153 .06309 Mdot
.43404 .00155 Mdot
.34042 .56017 Mdot
.04556 .4358 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50497 .00211 Mdot
.51584 .00672 Mdot
.55044 .02138 Mdot
.65945 .06737 Mdot
.96957 .19167 Mdot
.32506 .21971 Mdot
.46788 .08827 Mdot
.56286 .0587 Mdot
.74968 .11546 Mdot
.17524 .26301 Mdot
.49953 .61783 Mdot
.4985 .6174 Mdot
.49522 .616 Mdot
.48476 .61157 Mdot
.45147 .59746 Mdot
.3465 .55316 Mdot
.04534 .43191 Mdot
.67709 .39044 Mdot
.52296 .52278 Mdot
.40315 .54399 Mdot
.14687 .45964 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51466 .00622 Mdot
.54667 .01978 Mdot
.64768 .06243 Mdot
.93976 .18052 Mdot
.32006 .23504 Mdot
.48439 .10156 Mdot
.62533 .08711 Mdot
.93542 .19165 Mdot
.33975 .24989 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.52091 .00887 Mdot
.56653 .0282 Mdot
.70907 .08809 Mdot
.08249 .23079 Mdot
.33764 .15769 Mdot
.38935 .03196 Mdot
.28814 .55548 Mdot
.95501 .41215 Mdot
.68847 .4533 Mdot
.49991 .618 Mdot
.49972 .61791 Mdot
.49909 .61765 Mdot
.49711 .61681 Mdot
.49079 .61413 Mdot
.47065 .60559 Mdot
.40673 .57853 Mdot
.21079 .49693 Mdot
.78332 .35384 Mdot
.58937 .49817 Mdot
.52255 .57673 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50774 .00328 Mdot
.52465 .01045 Mdot
.5784 .03322 Mdot
.74504 .10299 Mdot
.1503 .25046 Mdot
.36215 .13094 Mdot
.39214 .01853 Mdot
.27245 .54406 Mdot
.9164 .39798 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48775 .61284 Mdot
.46098 .60149 Mdot
.37627 .56568 Mdot
.12409 .46218 Mdot
.70407 .35845 Mdot
.51292 .49989 Mdot
.34112 .51186 Mdot
.96866 .38784 Mdot
.64291 .41671 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50314 .00133 Mdot
.50999 .00424 Mdot
.53183 .0135 Mdot
.60111 .04281 Mdot
.81204 .13037 Mdot
.2438 .26684 Mdot
.43701 .11941 Mdot
.53817 .06252 Mdot
.69605 .09757 Mdot
.07907 .23672 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50704 .00299 Mdot
.52244 .00952 Mdot
.57139 .03025 Mdot
.72387 .09424 Mdot
.11186 .2398 Mdot
.34554 .14442 Mdot
.38223 .02268 Mdot
.25796 .54123 Mdot
.89525 .39387 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51705 .00723 Mdot
.55429 .02301 Mdot
.67138 .07237 Mdot
.99867 .20227 Mdot
.32795 .20351 Mdot
.44657 .07331 Mdot
.48655 .02471 Mdot
.50637 .01225 Mdot
.49984 .61797 Mdot
.49948 .61782 Mdot
.49835 .61734 Mdot
.49476 .61581 Mdot
.4833 .61095 Mdot
.44684 .5955 Mdot
.33212 .54713 Mdot
.00974 .41879 Mdot
.67276 .40977 Mdot
.54695 .54028 Mdot
.49054 .58317 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48933 .61351 Mdot
.46601 .60362 Mdot
.3921 .57236 Mdot
.16847 .47982 Mdot
.73675 .35121 Mdot
.54293 .49825 Mdot
.41272 .53756 Mdot
.15807 .46065 Mdot
.70341 .33704 Mdot
.49777 .61709 Mdot
.49291 .61503 Mdot
.4774 .60845 Mdot
.42811 .58757 Mdot
.27462 .52317 Mdot
.88524 .37739 Mdot
.65347 .47479 Mdot
.61785 .59602 Mdot
.74329 .07753 Mdot
.10725 .22494 Mdot
.32224 .13287 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50411 .00174 Mdot
.5131 .00556 Mdot
.54172 .01769 Mdot
.63222 .05593 Mdot
.899 .16488 Mdot
.30732 .25235 Mdot
.49221 .11427 Mdot
.66544 .10706 Mdot
.04449 .23426 Mdot
.35767 .19356 Mdot
.49863 .61745 Mdot
.49564 .61618 Mdot
.4861 .61214 Mdot
.45573 .59927 Mdot
.35982 .55875 Mdot
.07978 .44496 Mdot
.68502 .37406 Mdot
.50938 .50948 Mdot
.34779 .51817 Mdot
.99113 .39761 Mdot
.64777 .40583 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49072 .6141 Mdot
.47044 .6055 Mdot
.40606 .57825 Mdot
.20882 .49613 Mdot
.78079 .3535 Mdot
.58704 .49829 Mdot
.51745 .57502 Mdot
.47396 .59116 Mdot
.3916 .56713 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51466 .00622 Mdot
.54667 .01978 Mdot
.64768 .06243 Mdot
.93978 .18052 Mdot
.32006 .23503 Mdot
.48438 .10155 Mdot
.6253 .0871 Mdot
.93536 .19162 Mdot
.33973 .24992 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49594 .61631 Mdot
.48705 .61254 Mdot
.45877 .60055 Mdot
.36933 .56276 Mdot
.10518 .45478 Mdot
.6945 .36422 Mdot
.50817 .50288 Mdot
.33409 .51045 Mdot
.95384 .38302 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.50462 .00196 Mdot
.51471 .00624 Mdot
.54682 .01985 Mdot
.64817 .06264 Mdot
.94103 .181 Mdot
.32033 .23442 Mdot
.48384 .10105 Mdot
.62315 .0861 Mdot
.9293 .18921 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49338 .61523 Mdot
.4789 .60909 Mdot
.43286 .58958 Mdot
.28907 .52917 Mdot
.91371 .38605 Mdot
.66153 .46218 Mdot
.61215 .58751 Mdot
.71741 .06505 Mdot
.05642 .20952 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51513 .00642 Mdot
.54818 .02042 Mdot
.6524 .06441 Mdot
.95184 .18507 Mdot
.32243 .22904 Mdot
.47858 .09651 Mdot
.60269 .07671 Mdot
.87038 .16544 Mdot
.31171 .27275 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51419 .00602 Mdot
.54517 .01915 Mdot
.64301 .06047 Mdot
.92763 .17591 Mdot
.31711 .24071 Mdot
.48876 .10609 Mdot
.64357 .09568 Mdot
.98568 .21144 Mdot
.34925 .2247 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52397 .01017 Mdot
.57624 .03231 Mdot
.73856 .10032 Mdot
.13899 .24748 Mdot
.35644 .13439 Mdot
.38659 .01864 Mdot
.26067 .54021 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.5069 .00293 Mdot
.52197 .00932 Mdot
.56991 .02962 Mdot
.71936 .09237 Mdot
.10314 .23719 Mdot
.34281 .14813 Mdot
.38321 .02497 Mdot
.26372 .54419 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50815 .00345 Mdot
.52595 .011 Mdot
.58251 .03496 Mdot
.75737 .10807 Mdot
.1707 .25545 Mdot
.37433 .12585 Mdot
.40843 .02108 Mdot
.31263 .55883 Mdot
.99635 .42256 Mdot
.68554 .42595 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.4923 .61477 Mdot
.47548 .60764 Mdot
.42202 .58499 Mdot
.25621 .51556 Mdot
.85186 .36813 Mdot
.63899 .48647 Mdot
.6091 .59956 Mdot
.73033 .07493 Mdot
.08848 .22135 Mdot
.50044 .00019 Mdot
.50142 .0006 Mdot
.50451 .00191 Mdot
.51437 .00609 Mdot
.54576 .0194 Mdot
.64486 .06125 Mdot
.93247 .17775 Mdot
.31836 .23849 Mdot
.4872 .10435 Mdot
.63687 .0925 Mdot
.96747 .20432 Mdot
.34652 .23427 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50249 .00105 Mdot
.50792 .00336 Mdot
.52523 .0107 Mdot
.58024 .03399 Mdot
.75057 .10527 Mdot
.15962 .25281 Mdot
.36742 .12842 Mdot
.39855 .01924 Mdot
.28761 .54947 Mdot
.94457 .40602 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50632 .00268 Mdot
.52013 .00854 Mdot
.56405 .02715 Mdot
.70147 .08493 Mdot
.06662 .22567 Mdot
.33473 .1657 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50353 .0015 Mdot
.51123 .00476 Mdot
.53577 .01517 Mdot
.61353 .04805 Mdot
.84749 .1446 Mdot
.27678 .26532 Mdot
.47071 .11986 Mdot
.62096 .09286 Mdot
.93569 .19451 Mdot
.34428 .25252 Mdot
.5 .61803 Mdot
.49999 .61803 Mdot
.49996 .61802 Mdot
.49986 .61798 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48601 .6121 Mdot
.45547 .59915 Mdot
.35899 .55841 Mdot
.0776 .44413 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00327 Mdot
.52459 .01043 Mdot
.5782 .03313 Mdot
.74446 .10275 Mdot
.1493 .25021 Mdot
.36162 .13122 Mdot
.39156 .0185 Mdot
.27113 .5436 Mdot
.91407 .39736 Mdot
.67973 .47321 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50622 .00264 Mdot
.51982 .0084 Mdot
.56306 .02673 Mdot
.69845 .08367 Mdot
.06016 .22355 Mdot
.33376 .16909 Mdot
.40094 .04152 Mdot
.32892 .57353 Mdot
.04693 .44376 Mdot
.69556 .40087 Mdot
.49795 .61717 Mdot
.49348 .61527 Mdot
.47921 .60922 Mdot
.43386 .59 Mdot
.29213 .53044 Mdot
.91998 .38803 Mdot
.66287 .45913 Mdot
.6096 .58511 Mdot
.70803 .06084 Mdot
.03695 .20328 Mdot
.31094 .16933 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.42031 .58427 Mdot
.25107 .51344 Mdot
.8431 .3659 Mdot
.63417 .48891 Mdot
.6035 .59908 Mdot
.71735 .07037 Mdot
.06493 .21482 Mdot
.3178 .15628 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00114 Mdot
.5086 .00365 Mdot
.52739 .01161 Mdot
.58705 .03688 Mdot
.77089 .11362 Mdot
.1914 .25989 Mdot
.38918 .12224 Mdot
.43384 .0276 Mdot
.3821 .58606 Mdot
.16924 .48648 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .0021 Mdot
.51575 .00668 Mdot
.55015 .02126 Mdot
.65853 .06698 Mdot
.9673 .19083 Mdot
.32477 .22093 Mdot
.46938 .08937 Mdot
.56833 .06116 Mdot
.76666 .12257 Mdot
.20242 .26931 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.47699 .60828 Mdot
.42681 .58702 Mdot
.27066 .52153 Mdot
.87779 .37523 Mdot
.65074 .47771 Mdot
.61749 .59748 Mdot
.7449 .07874 Mdot
.11092 .22621 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00206 Mdot
.5155 .00657 Mdot
.54936 .02093 Mdot
.65608 .06596 Mdot
.96116 .18855 Mdot
.32392 .2242 Mdot
.47324 .09228 Mdot
.5826 .06759 Mdot
.81038 .14078 Mdot
.25992 .27783 Mdot
.49913 .61767 Mdot
.49724 .61686 Mdot
.49121 .61431 Mdot
.472 .60616 Mdot
.41101 .58034 Mdot
.22338 .50207 Mdot
.80035 .35659 Mdot
.6042 .49681 Mdot
.55343 .58666 Mdot
.5813 .01723 Mdot
.7259 .08937 Mdot
.49748 .61697 Mdot
.49197 .61463 Mdot
.47443 .60719 Mdot
.4187 .58359 Mdot
.24625 .51146 Mdot
.83514 .36395 Mdot
.62941 .49088 Mdot
.5971 .59806 Mdot
.70156 .06456 Mdot
.03378 .20532 Mdot
.31571 .17424 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52351 .00997 Mdot
.57476 .03168 Mdot
.73409 .09847 Mdot
.13095 .24527 Mdot
.35281 .13712 Mdot
.38405 .0193 Mdot
.25633 .5391 Mdot
.89008 .39168 Mdot
.67591 .48567 Mdot
.49845 .61737 Mdot
.49505 .61593 Mdot
.48422 .61134 Mdot
.44977 .59674 Mdot
.34121 .55094 Mdot
.03205 .42697 Mdot
.67514 .39745 Mdot
.53105 .52898 Mdot
.43323 .55758 Mdot
.23816 .49748 Mdot
.80503 .35034 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.5245 .01039 Mdot
.57791 .03301 Mdot
.74357 .10239 Mdot
.14777 .24981 Mdot
.36082 .13167 Mdot
.3907 .01847 Mdot
.26922 .54295 Mdot
.91075 .39648 Mdot
.67924 .47496 Mdot
.49862 .61745 Mdot
.49559 .61617 Mdot
.48596 .61208 Mdot
.4553 .59909 Mdot
.35848 .55819 Mdot
.07625 .44361 Mdot
.68398 .37559 Mdot
.51018 .51062 Mdot
.35166 .52006 Mdot
.00147 .4016 Mdot
.64908 .40024 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48265 .61068 Mdot
.44479 .59463 Mdot
.32576 .54447 Mdot
.99453 .41332 Mdot
.67151 .4184 Mdot
.55877 .54836 Mdot
.53219 .60161 Mdot
.55358 .01322 Mdot
.65384 .06196 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50853 .00362 Mdot
.52716 .01152 Mdot
.58635 .03658 Mdot
.7688 .11276 Mdot
.18831 .25928 Mdot
.38681 .12268 Mdot
.42946 .02636 Mdot
.36975 .58113 Mdot
.13575 .47341 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.4862 .61218 Mdot
.45606 .59941 Mdot
.36085 .55919 Mdot
.0825 .44601 Mdot
.68587 .3729 Mdot
.50885 .50863 Mdot
.34511 .51684 Mdot
.98401 .39486 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48667 .61238 Mdot
.45757 .60005 Mdot
.36557 .56117 Mdot
.09505 .45085 Mdot
.69028 .36788 Mdot
.50764 .50516 Mdot
.33646 .51224 Mdot
.96093 .38594 Mdot
.64341 .4218 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00227 Mdot
.51702 .00722 Mdot
.55418 .02296 Mdot
.67104 .07222 Mdot
.99784 .20198 Mdot
.32789 .20398 Mdot
.44722 .07375 Mdot
.48881 .02571 Mdot
.51364 .01534 Mdot
.55889 .02797 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50654 .00277 Mdot
.52082 .00883 Mdot
.56625 .02808 Mdot
.7082 .08773 Mdot
.0807 .23022 Mdot
.33727 .15857 Mdot
.39011 .03266 Mdot
.2909 .55672 Mdot
.96079 .41402 Mdot
.68891 .45 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.51442 .00611 Mdot
.5459 .01946 Mdot
.64529 .06143 Mdot
.93358 .17817 Mdot
.31863 .23798 Mdot
.48681 .10394 Mdot
.63522 .09173 Mdot
.96294 .20254 Mdot
.34574 .23659 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51315 .00558 Mdot
.54187 .01775 Mdot
.63267 .05612 Mdot
.90021 .16535 Mdot
.30782 .25192 Mdot
.49228 .114 Mdot
.66517 .10685 Mdot
.04367 .23393 Mdot
.35749 .19395 Mdot
.49794 .61716 Mdot
.49345 .61525 Mdot
.47912 .60918 Mdot
.43357 .58988 Mdot
.29123 .53007 Mdot
.91813 .38745 Mdot
.66249 .46004 Mdot
.61039 .58584 Mdot
.71092 .06213 Mdot
.04302 .20525 Mdot
.31137 .16585 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.4942 .61557 Mdot
.48151 .61019 Mdot
.44116 .59309 Mdot
.31453 .53978 Mdot
.96853 .40419 Mdot
.66943 .43318 Mdot
.57911 .56222 Mdot
.60264 .01454 Mdot
.76969 .10324 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50518 .00219 Mdot
.51649 .00699 Mdot
.55249 .02225 Mdot
.66581 .07004 Mdot
.98523 .19741 Mdot
.32677 .21108 Mdot
.45682 .08037 Mdot
.5229 .04084 Mdot
.62321 .06199 Mdot
.89041 .16514 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52 .00848 Mdot
.56363 .02697 Mdot
.70018 .08439 Mdot
.06386 .22477 Mdot
.3343 .16714 Mdot
.39872 .03981 Mdot
.32127 .57017 Mdot
.02863 .43717 Mdot
.69327 .41078 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52657 .01127 Mdot
.58447 .03578 Mdot
.76322 .11047 Mdot
.17987 .25751 Mdot
.3806 .12406 Mdot
.41855 .02346 Mdot
.33959 .56923 Mdot
.05873 .44446 Mdot
.69176 .39123 Mdot
.49927 .61772 Mdot
.49768 .61705 Mdot
.49259 .61489 Mdot
.47641 .60803 Mdot
.42496 .58624 Mdot
.26509 .51922 Mdot
.86755 .37234 Mdot
.64654 .48144 Mdot
.61556 .59889 Mdot
.7431 .07882 Mdot
.10914 .22623 Mdot
.49815 .61725 Mdot
.49411 .61553 Mdot
.48123 .61007 Mdot
.44025 .59271 Mdot
.31173 .53861 Mdot
.96221 .40202 Mdot
.66885 .43672 Mdot
.58384 .5655 Mdot
.61887 .02165 Mdot
.81608 .12188 Mdot
.23174 .25689 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47758 .60853 Mdot
.42867 .58781 Mdot
.27633 .52388 Mdot
.88851 .37835 Mdot
.65458 .47346 Mdot
.61775 .59527 Mdot
.74186 .07671 Mdot
.10439 .22406 Mdot
.32133 .13407 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50713 .00302 Mdot
.52272 .00963 Mdot
.57226 .03062 Mdot
.72651 .09533 Mdot
.1169 .24127 Mdot
.34729 .14238 Mdot
.38217 .02156 Mdot
.25601 .54006 Mdot
.89128 .39262 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .00159 Mdot
.51197 .00508 Mdot
.53813 .01617 Mdot
.62093 .05118 Mdot
.86818 .15281 Mdot
.29131 .26151 Mdot
.48371 .11891 Mdot
.65171 .10383 Mdot
.01435 .22412 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51668 .00707 Mdot
.5531 .02251 Mdot
.66771 .07083 Mdot
.98984 .19909 Mdot
.3272 .2085 Mdot
.45337 .07798 Mdot
.51059 .03536 Mdot
.58368 .04517 Mdot
.77659 .11922 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47648 .60806 Mdot
.4252 .58634 Mdot
.26581 .51953 Mdot
.86887 .37271 Mdot
.64711 .48098 Mdot
.61591 .59875 Mdot
.7436 .07892 Mdot
.10984 .22635 Mdot
.32409 .13241 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50323 .00137 Mdot
.51029 .00436 Mdot
.53278 .0139 Mdot
.60408 .04407 Mdot
.82061 .13382 Mdot
.25276 .26708 Mdot
.44621 .11956 Mdot
.56051 .07064 Mdot
.7634 .12539 Mdot
.20418 .27242 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49287 .61501 Mdot
.47728 .6084 Mdot
.42773 .58741 Mdot
.27346 .52269 Mdot
.88304 .37674 Mdot
.6527 .47567 Mdot
.61783 .59649 Mdot
.74401 .07798 Mdot
.10875 .22542 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51885 .00799 Mdot
.55998 .02542 Mdot
.68897 .07972 Mdot
.03936 .21655 Mdot
.33131 .18043 Mdot
.415 .05173 Mdot
.37717 .59465 Mdot
.17285 .49176 Mdot
.7573 .36121 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.50539 .00229 Mdot
.51719 .00729 Mdot
.55471 .02319 Mdot
.67268 .07291 Mdot
.00176 .20338 Mdot
.3282 .20175 Mdot
.44416 .07166 Mdot
.47805 .02095 Mdot
.47914 .00067 Mdot
.44901 .59942 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50308 .00131 Mdot
.50982 .00417 Mdot
.53129 .01327 Mdot
.5994 .04209 Mdot
.80709 .12836 Mdot
.23832 .26652 Mdot
.43146 .11937 Mdot
.52494 .05777 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50346 .00147 Mdot
.51101 .00467 Mdot
.53506 .01487 Mdot
.61129 .04711 Mdot
.84118 .14208 Mdot
.27168 .26607 Mdot
.46567 .11989 Mdot
.60855 .08831 Mdot
.90192 .18131 Mdot
.33327 .26659 Mdot
.49966 .61789 Mdot
.4989 .61757 Mdot
.49651 .61655 Mdot
.48888 .61332 Mdot
.46459 .60302 Mdot
.38762 .57046 Mdot
.15575 .47473 Mdot
.72579 .35231 Mdot
.53182 .49815 Mdot
.38525 .52745 Mdot
.08108 .43005 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51225 .00519 Mdot
.539 .01653 Mdot
.62366 .05232 Mdot
.8757 .15577 Mdot
.29581 .25964 Mdot
.487 .11816 Mdot
.65872 .10613 Mdot
.03098 .23007 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50333 .00141 Mdot
.51062 .0045 Mdot
.53381 .01434 Mdot
.60735 .04545 Mdot
.82998 .13759 Mdot
.26182 .2669 Mdot
.4556 .11976 Mdot
.58363 .07913 Mdot
.8314 .15313 Mdot
.28736 .2818 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00715 Mdot
.55365 .02274 Mdot
.66942 .07154 Mdot
.99396 .20058 Mdot
.32756 .20618 Mdot
.45022 .07581 Mdot
.49944 .03041 Mdot
.5478 .02989 Mdot
.6668 .07354 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00117 Mdot
.50876 .00372 Mdot
.52791 .01184 Mdot
.58872 .03758 Mdot
.77582 .11563 Mdot
.19851 .26124 Mdot
.39486 .12135 Mdot
.44472 .03082 Mdot
.41331 .59862 Mdot
.25821 .52218 Mdot
.50054 .00023 Mdot
.50171 .00073 Mdot
.50545 .00231 Mdot
.51736 .00736 Mdot
.55527 .02343 Mdot
.67442 .07364 Mdot
.00589 .20486 Mdot
.32853 .1994 Mdot
.4409 .06945 Mdot
.46666 .01592 Mdot
.44278 .60328 Mdot
.33492 .55137 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50483 .00205 Mdot
.51539 .00652 Mdot
.54898 .02077 Mdot
.6549 .06546 Mdot
.9582 .18744 Mdot
.32347 .22575 Mdot
.47501 .09366 Mdot
.58922 .07059 Mdot
.83036 .14903 Mdot
.4996 .61787 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48722 .61262 Mdot
.45931 .60078 Mdot
.37104 .56348 Mdot
.1098 .45658 Mdot
.69662 .36268 Mdot
.50887 .502 Mdot
.33442 .51022 Mdot
.95405 .38295 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50595 .00252 Mdot
.51894 .00803 Mdot
.56028 .02555 Mdot
.68989 .0801 Mdot
.0414 .21725 Mdot
.33151 .1793 Mdot
.41352 .05068 Mdot
.3721 .59243 Mdot
.15882 .48622 Mdot
.74493 .36223 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52403 .01019 Mdot
.57643 .03238 Mdot
.73912 .10055 Mdot
.13998 .24775 Mdot
.35692 .13407 Mdot
.38699 .01859 Mdot
.26143 .54044 Mdot
.89776 .39327 Mdot
.67712 .48167 Mdot
.50015 6e-05 Mdot
.50048 .00021 Mdot
.50154 .00066 Mdot
.50492 .00209 Mdot
.51568 .00665 Mdot
.54992 .02116 Mdot
.65782 .06668 Mdot
.96551 .19016 Mdot
.32453 .22189 Mdot
.47053 .09023 Mdot
.57257 .06307 Mdot
.77973 .12803 Mdot
.49771 .61706 Mdot
.4927 .61494 Mdot
.47673 .60817 Mdot
.42599 .58667 Mdot
.26818 .5205 Mdot
.87319 .37392 Mdot
.64892 .47943 Mdot
.61684 .5982 Mdot
.74469 .07902 Mdot
.11114 .22648 Mdot
.3241 .13162 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51105 .00469 Mdot
.53519 .01492 Mdot
.61169 .04728 Mdot
.84231 .14253 Mdot
.27262 .26595 Mdot
.4666 .11989 Mdot
.61086 .08916 Mdot
.90828 .18382 Mdot
.33579 .26421 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51979 .00839 Mdot
.56297 .02669 Mdot
.69818 .08356 Mdot
.05956 .22335 Mdot
.33368 .16941 Mdot
.4013 .04179 Mdot
.33018 .57408 Mdot
.05 .44487 Mdot
.69604 .39928 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00326 Mdot
.52446 .01037 Mdot
.57777 .03295 Mdot
.74316 .10222 Mdot
.14706 .24962 Mdot
.36045 .13188 Mdot
.39031 .01846 Mdot
.26837 .54267 Mdot
.90928 .39611 Mdot
.67902 .47572 Mdot
.49996 .61802 Mdot
.49989 .61799 Mdot
.49964 .61788 Mdot
.49885 .61754 Mdot
.49633 .61648 Mdot
.48829 .61307 Mdot
.46271 .60223 Mdot
.38172 .56797 Mdot
.13918 .46814 Mdot
.71348 .35494 Mdot
.52026 .49862 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.5066 .0028 Mdot
.52103 .00892 Mdot
.56692 .02836 Mdot
.71027 .08859 Mdot
.08494 .23156 Mdot
.33817 .1565 Mdot
.38837 .03102 Mdot
.28451 .55385 Mdot
.94751 .40976 Mdot
.68783 .45754 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50522 .00222 Mdot
.51664 .00706 Mdot
.55298 .02246 Mdot
.66731 .07066 Mdot
.98888 .19874 Mdot
.32711 .20904 Mdot
.45409 .07848 Mdot
.51316 .03651 Mdot
.59195 .04869 Mdot
.80111 .12927 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.4875 .61273 Mdot
.46019 .60116 Mdot
.3738 .56464 Mdot
.11733 .45953 Mdot
.70038 .36034 Mdot
.51065 .50078 Mdot
.33688 .51064 Mdot
.95908 .38454 Mdot
.64198 .42206 Mdot
.49804 .6172 Mdot
.49375 .61539 Mdot
.4801 .6096 Mdot
.43668 .5912 Mdot
.30077 .53404 Mdot
.93818 .39394 Mdot
.666 .44982 Mdot
.60007 .57729 Mdot
.67454 .04603 Mdot
.96142 .1773 Mdot
.3056 .21271 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47552 .60766 Mdot
.42216 .58505 Mdot
.25663 .51573 Mdot
.85258 .36832 Mdot
.63937 .48626 Mdot
.60949 .59957 Mdot
.7312 .07522 Mdot
.08999 .22174 Mdot
.32087 .14269 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52612 .01107 Mdot
.58304 .03518 Mdot
.75895 .10872 Mdot
.17322 .25603 Mdot
.376 .12533 Mdot
.41103 .02165 Mdot
.31945 .56143 Mdot
.0115 .42771 Mdot
.68632 .41706 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.5132 .0056 Mdot
.54204 .01782 Mdot
.6332 .05634 Mdot
.90164 .1659 Mdot
.30841 .2514 Mdot
.49234 .11367 Mdot
.66477 .10657 Mdot
.04253 .23346 Mdot
.35725 .19451 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49576 .61624 Mdot
.48649 .61231 Mdot
.45699 .5998 Mdot
.36374 .56041 Mdot
.09017 .44896 Mdot
.68847 .36977 Mdot
.50788 .50642 Mdot
.33909 .51372 Mdot
.96801 .38869 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.51809 .00767 Mdot
.55757 .0244 Mdot
.68153 .07661 Mdot
.02247 .21071 Mdot
.32982 .18995 Mdot
.42783 .06058 Mdot
.42126 .61398 Mdot
.30135 .54392 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48602 .61211 Mdot
.45548 .59916 Mdot
.35904 .55843 Mdot
.07774 .44418 Mdot
.68441 .37494 Mdot
.50982 .51013 Mdot
.34997 .51924 Mdot
.99694 .39985 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47592 .60782 Mdot
.42342 .58559 Mdot
.26042 .5173 Mdot
.8592 .37007 Mdot
.64269 .48422 Mdot
.61267 .59948 Mdot
.7379 .07739 Mdot
.10117 .22451 Mdot
.3227 .13691 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51776 .00753 Mdot
.55652 .02396 Mdot
.67829 .07526 Mdot
.01498 .20808 Mdot
.32923 .19422 Mdot
.43372 .06458 Mdot
.44165 .0049 Mdot
.36398 .57004 Mdot
.50073 .00031 Mdot
.50232 .00099 Mdot
.5074 .00314 Mdot
.52358 .01 Mdot
.575 .03178 Mdot
.73479 .09876 Mdot
.13223 .24563 Mdot
.35337 .13667 Mdot
.38438 .01917 Mdot
.25681 .53919 Mdot
.89074 .39179 Mdot
.67598 .48531 Mdot
.50015 6e-05 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50492 .00209 Mdot
.51567 .00664 Mdot
.54987 .02114 Mdot
.65767 .06662 Mdot
.96515 .19003 Mdot
.32448 .22208 Mdot
.47076 .0904 Mdot
.57342 .06345 Mdot
.78235 .12912 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47722 .60837 Mdot
.42754 .58733 Mdot
.27288 .52245 Mdot
.88195 .37643 Mdot
.6523 .4761 Mdot
.6178 .59671 Mdot
.74429 .07818 Mdot
.49832 .61732 Mdot
.49464 .61576 Mdot
.48292 .61079 Mdot
.44562 .59498 Mdot
.32832 .54554 Mdot
.00062 .41551 Mdot
.67199 .41493 Mdot
.55398 .5451 Mdot
.51539 .59419 Mdot
.49986 .60844 Mdot
.48413 .60831 Mdot
.49783 .61711 Mdot
.49309 .6151 Mdot
.47798 .60869 Mdot
.42993 .58834 Mdot
.28015 .52546 Mdot
.89591 .38056 Mdot
.65691 .47032 Mdot
.61695 .59334 Mdot
.73705 .07423 Mdot
.0951 .22128 Mdot
.31883 .13828 Mdot
.50023 .0001 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52405 .0102 Mdot
.57649 .03241 Mdot
.73931 .10063 Mdot
.14032 .24784 Mdot
.35708 .13396 Mdot
.38713 .01857 Mdot
.26171 .54052 Mdot
.8982 .39337 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50612 .0026 Mdot
.5195 .00827 Mdot
.56206 .0263 Mdot
.69537 .08239 Mdot
.05348 .22133 Mdot
.33287 .17268 Mdot
.40518 .04469 Mdot
.34351 .57992 Mdot
.08314 .45712 Mdot
.70366 .3835 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.47952 .60935 Mdot
.43484 .59042 Mdot
.29512 .53168 Mdot
.92619 .39003 Mdot
.66405 .45602 Mdot
.60667 .58257 Mdot
.69759 .05619 Mdot
.01442 .19581 Mdot
.30965 .18246 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47959 .60938 Mdot
.43504 .5905 Mdot
.29574 .53194 Mdot
.9275 .39045 Mdot
.66429 .45536 Mdot
.60601 .58202 Mdot
.69526 .05516 Mdot
.00925 .19406 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51443 .00612 Mdot
.54594 .01947 Mdot
.6454 .06147 Mdot
.93386 .17828 Mdot
.3187 .23784 Mdot
.48671 .10383 Mdot
.63479 .09152 Mdot
.96175 .20207 Mdot
.34553 .23719 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.52171 .00921 Mdot
.56907 .02927 Mdot
.71681 .09131 Mdot
.09811 .23566 Mdot
.34139 .15036 Mdot
.38423 .02648 Mdot
.26833 .5464 Mdot
.91527 .39983 Mdot
.68339 .47472 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50655 .00278 Mdot
.52087 .00885 Mdot
.56639 .02814 Mdot
.70864 .08792 Mdot
.08162 .23051 Mdot
.33746 .15812 Mdot
.38972 .0323 Mdot
.28947 .55608 Mdot
.9578 .41305 Mdot
.49992 .618 Mdot
.49976 .61793 Mdot
.49922 .61771 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.4203 .58427 Mdot
.25105 .51343 Mdot
.84307 .36589 Mdot
.63415 .48892 Mdot
.60347 .59907 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00325 Mdot
.52445 .01037 Mdot
.57776 .03294 Mdot
.74311 .1022 Mdot
.14698 .2496 Mdot
.3604 .1319 Mdot
.39027 .01846 Mdot
.26827 .54264 Mdot
.90911 .39606 Mdot
.679 .47581 Mdot
.50023 .0001 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52403 .01019 Mdot
.57643 .03238 Mdot
.7391 .10054 Mdot
.13996 .24774 Mdot
.3569 .13408 Mdot
.38698 .01859 Mdot
.26141 .54043 Mdot
.89773 .39327 Mdot
.49998 .61802 Mdot
.49993 .618 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47734 .60843 Mdot
.42792 .58749 Mdot
.27404 .52293 Mdot
.88415 .37707 Mdot
.65309 .47523 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49056 .61403 Mdot
.46993 .60529 Mdot
.40447 .57758 Mdot
.20417 .49424 Mdot
.77497 .35277 Mdot
.58156 .4985 Mdot
.50522 .57085 Mdot
.43671 .57569 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.52499 .0106 Mdot
.57948 .03367 Mdot
.74829 .10433 Mdot
.15582 .25187 Mdot
.36521 .12941 Mdot
.39574 .01886 Mdot
.28081 .54701 Mdot
.93161 .40222 Mdot
.68187 .46368 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50659 .0028 Mdot
.52101 .00891 Mdot
.56684 .02833 Mdot
.71002 .08849 Mdot
.08444 .2314 Mdot
.33806 .15674 Mdot
.38856 .03121 Mdot
.28523 .55417 Mdot
.94899 .41023 Mdot
.68796 .45671 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42796 .58751 Mdot
.27417 .52298 Mdot
.88439 .37714 Mdot
.65317 .47513 Mdot
.61785 .59621 Mdot
.74359 .07771 Mdot
.10787 .22514 Mdot
.32245 .13262 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51803 .00764 Mdot
.55738 .02432 Mdot
.68095 .07637 Mdot
.02114 .21025 Mdot
.32971 .19071 Mdot
.42887 .06128 Mdot
.42485 .61555 Mdot
.31226 .54845 Mdot
.97896 .41205 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50272 .00115 Mdot
.50866 .00367 Mdot
.52759 .0117 Mdot
.58768 .03714 Mdot
.77275 .11438 Mdot
.19412 .26042 Mdot
.39132 .12188 Mdot
.43787 .02877 Mdot
.39357 .59066 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50578 .00245 Mdot
.51842 .00781 Mdot
.55864 .02486 Mdot
.68484 .078 Mdot
.03005 .21335 Mdot
.33045 .18566 Mdot
.42197 .05657 Mdot
.40109 .60513 Mdot
.24121 .51922 Mdot
.84295 .3719 Mdot
.49985 .61797 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49505 .61593 Mdot
.48423 .61135 Mdot
.44979 .59675 Mdot
.34127 .55097 Mdot
.03222 .42703 Mdot
.67517 .39736 Mdot
.53094 .52889 Mdot
.43281 .55739 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50663 .00281 Mdot
.52111 .00895 Mdot
.56717 .02847 Mdot
.71103 .08891 Mdot
.0865 .23205 Mdot
.33851 .15575 Mdot
.38777 .03044 Mdot
.2823 .55285 Mdot
.943 .40833 Mdot
.68738 .46006 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00326 Mdot
.52447 .01037 Mdot
.57781 .03297 Mdot
.74326 .10226 Mdot
.14723 .24967 Mdot
.36054 .13183 Mdot
.39041 .01846 Mdot
.26857 .54274 Mdot
.90963 .3962 Mdot
.67908 .47554 Mdot
.49941 .61778 Mdot
.49812 .61724 Mdot
.494 .61549 Mdot
.48089 .60993 Mdot
.43918 .59226 Mdot
.30845 .53724 Mdot
.9549 .39953 Mdot
.6681 .44078 Mdot
.58911 .56922 Mdot
.63693 .02955 Mdot
.86571 .1414 Mdot
.4989 .61757 Mdot
.4965 .61655 Mdot
.48886 .61331 Mdot
.46453 .60299 Mdot
.38743 .57038 Mdot
.1552 .47451 Mdot
.72535 .35237 Mdot
.53138 .49815 Mdot
.38418 .52706 Mdot
.07817 .42891 Mdot
.65957 .35932 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51647 .00699 Mdot
.55244 .02223 Mdot
.66565 .06997 Mdot
.98484 .19727 Mdot
.32674 .2113 Mdot
.45712 .08058 Mdot
.52395 .0413 Mdot
.62656 .06342 Mdot
.89963 .16877 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49025 .6139 Mdot
.46895 .60487 Mdot
.40136 .57626 Mdot
.1951 .49056 Mdot
.76418 .35171 Mdot
.57104 .49867 Mdot
.48095 .56236 Mdot
.36235 .54473 Mdot
.06206 .43245 Mdot
.50004 2e-05 Mdot
.50011 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51185 .00502 Mdot
.53774 .016 Mdot
.6197 .05066 Mdot
.86477 .15146 Mdot
.28914 .26227 Mdot
.48196 .11917 Mdot
.64778 .10248 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48268 .61069 Mdot
.44485 .59466 Mdot
.32596 .54455 Mdot
.99501 .4135 Mdot
.67154 .41812 Mdot
.55838 .5481 Mdot
.53085 .60102 Mdot
.54929 .0114 Mdot
.64049 .05637 Mdot
.49963 .61788 Mdot
.49881 .61753 Mdot
.49621 .61643 Mdot
.48793 .61292 Mdot
.46157 .60174 Mdot
.37812 .56646 Mdot
.1292 .46419 Mdot
.70708 .35715 Mdot
.51505 .49936 Mdot
.34558 .51329 Mdot
.97915 .39157 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52529 .01073 Mdot
.58043 .03408 Mdot
.75115 .10551 Mdot
.16059 .25305 Mdot
.36799 .12818 Mdot
.39931 .01936 Mdot
.28947 .55015 Mdot
.50019 8e-05 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50612 .0026 Mdot
.51951 .00827 Mdot
.56209 .02631 Mdot
.69544 .08242 Mdot
.05365 .22138 Mdot
.33289 .17258 Mdot
.40506 .0446 Mdot
.34313 .57975 Mdot
.08217 .45676 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.5089 .00377 Mdot
.52835 .01202 Mdot
.59011 .03817 Mdot
.77994 .11732 Mdot
.20428 .26226 Mdot
.39968 .12076 Mdot
.45436 .03379 Mdot
.4415 .61009 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52365 .01003 Mdot
.57523 .03188 Mdot
.73549 .09905 Mdot
.1335 .24598 Mdot
.35393 .13623 Mdot
.38473 .01904 Mdot
.25737 .53932 Mdot
.89152 .39193 Mdot
.67609 .48489 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.515 .00636 Mdot
.54774 .02024 Mdot
.65104 .06384 Mdot
.94839 .18377 Mdot
.3218 .23078 Mdot
.48037 .098 Mdot
.60957 .07985 Mdot
.89045 .17359 Mdot
.50078 .00033 Mdot
.50249 .00105 Mdot
.50792 .00336 Mdot
.52524 .0107 Mdot
.58027 .03401 Mdot
.75067 .10531 Mdot
.1598 .25285 Mdot
.36752 .12838 Mdot
.39869 .01926 Mdot
.28794 .54959 Mdot
.94522 .40622 Mdot
.68305 .45601 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47635 .60801 Mdot
.42477 .58616 Mdot
.26452 .51899 Mdot
.86652 .37206 Mdot
.64608 .4818 Mdot
.61527 .59899 Mdot
.74264 .07872 Mdot
.10849 .22611 Mdot
.32392 .13314 Mdot
.5 .61803 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48366 .6111 Mdot
.44797 .59598 Mdot
.33562 .5486 Mdot
.01825 .42189 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .0027 Mdot
.52031 .00861 Mdot
.56464 .0274 Mdot
.70329 .08569 Mdot
.07046 .22692 Mdot
.33536 .16372 Mdot
.39505 .03689 Mdot
.30847 .56453 Mdot
.99909 .42683 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47757 .60852 Mdot
.42866 .5878 Mdot
.27627 .52385 Mdot
.8884 .37832 Mdot
.65454 .4735 Mdot
.61775 .5953 Mdot
.74191 .07674 Mdot
.1045 .22409 Mdot
.32136 .13403 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00342 Mdot
.52566 .01088 Mdot
.58158 .03456 Mdot
.75459 .10692 Mdot
.16623 .25441 Mdot
.37145 .12683 Mdot
.40414 .0202 Mdot
.30157 .55464 Mdot
.97269 .41478 Mdot
.68458 .43997 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00114 Mdot
.50859 .00364 Mdot
.52736 .0116 Mdot
.58698 .03684 Mdot
.77066 .11352 Mdot
.19107 .25983 Mdot
.38892 .12228 Mdot
.43336 .02746 Mdot
.38074 .58551 Mdot
.16549 .48501 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.47699 .60828 Mdot
.42682 .58702 Mdot
.2707 .52155 Mdot
.87786 .37525 Mdot
.65077 .47768 Mdot
.6175 .59747 Mdot
.7449 .07874 Mdot
.1109 .2262 Mdot
.32369 .13151 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48581 .61202 Mdot
.45483 .59888 Mdot
.35698 .55756 Mdot
.07235 .44212 Mdot
.68289 .37733 Mdot
.51125 .51196 Mdot
.35647 .52237 Mdot
.01441 .40663 Mdot
.65077 .39329 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50556 .00236 Mdot
.51771 .00751 Mdot
.55636 .02389 Mdot
.67781 .07506 Mdot
.01385 .20768 Mdot
.32914 .19486 Mdot
.43461 .06518 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51414 .006 Mdot
.54503 .01909 Mdot
.64258 .06029 Mdot
.92652 .17548 Mdot
.3168 .24121 Mdot
.48908 .10647 Mdot
.64499 .09636 Mdot
.98952 .21293 Mdot
.34976 .22264 Mdot
.49795 .61716 Mdot
.49347 .61526 Mdot
.47919 .60921 Mdot
.43379 .58997 Mdot
.29191 .53035 Mdot
.91953 .38789 Mdot
.66278 .45935 Mdot
.60979 .58529 Mdot
.70874 .06115 Mdot
.03844 .20377 Mdot
.31104 .16848 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51848 .00784 Mdot
.55881 .02493 Mdot
.68537 .07822 Mdot
.03124 .21376 Mdot
.33055 .18499 Mdot
.42106 .05594 Mdot
.39796 .60376 Mdot
.23208 .51551 Mdot
.82898 .3689 Mdot
.49852 .61741 Mdot
.4953 .61604 Mdot
.48502 .61168 Mdot
.45229 .59781 Mdot
.34908 .55424 Mdot
.05192 .43438 Mdot
.67825 .3871 Mdot
.51947 .5199 Mdot
.38982 .53791 Mdot
.10779 .44373 Mdot
.67615 .35127 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50764 .00324 Mdot
.52434 .01032 Mdot
.57739 .03279 Mdot
.74202 .10174 Mdot
.14507 .2491 Mdot
.35943 .13248 Mdot
.38929 .01845 Mdot
.26615 .54193 Mdot
.90551 .39515 Mdot
.67842 .47769 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.5049 .00208 Mdot
.51561 .00662 Mdot
.54968 .02106 Mdot
.65708 .06638 Mdot
.96368 .18948 Mdot
.32428 .22287 Mdot
.47169 .0911 Mdot
.57685 .06499 Mdot
.79285 .1335 Mdot
.23899 .27573 Mdot
.49908 .61764 Mdot
.49706 .61679 Mdot
.49064 .61407 Mdot
.4702 .6054 Mdot
.40531 .57793 Mdot
.20661 .49523 Mdot
.778 .35314 Mdot
.58443 .4984 Mdot
.51167 .57306 Mdot
.45638 .58386 Mdot
.33647 .54393 Mdot
.4976 .61702 Mdot
.49236 .6148 Mdot
.47568 .60772 Mdot
.42264 .58526 Mdot
.2581 .51634 Mdot
.85512 .36898 Mdot
.64067 .4855 Mdot
.61081 .59958 Mdot
.73406 .07617 Mdot
.09484 .22297 Mdot
.32163 .14017 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.5148 .00628 Mdot
.54712 .01998 Mdot
.6491 .06303 Mdot
.94343 .1819 Mdot
.32083 .23325 Mdot
.48277 .10008 Mdot
.6189 .08414 Mdot
.49866 .61747 Mdot
.49575 .61623 Mdot
.48645 .61229 Mdot
.45684 .59974 Mdot
.36328 .56021 Mdot
.08896 .44849 Mdot
.68804 .37025 Mdot
.50798 .50675 Mdot
.33989 .51415 Mdot
.97015 .38952 Mdot
.64492 .41703 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51119 .00474 Mdot
.53563 .01511 Mdot
.61309 .04787 Mdot
.84625 .1441 Mdot
.27581 .26548 Mdot
.46976 .11987 Mdot
.61862 .092 Mdot
.9294 .19207 Mdot
.34264 .25539 Mdot
.49996 .61802 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49541 .61609 Mdot
.48536 .61183 Mdot
.45339 .59828 Mdot
.3525 .55568 Mdot
.06071 .4377 Mdot
.68004 .38277 Mdot
.51541 .51629 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.5014 .0006 Mdot
.50447 .0019 Mdot
.51424 .00604 Mdot
.54535 .01923 Mdot
.64357 .0607 Mdot
.9291 .17647 Mdot
.3175 .24004 Mdot
.48831 .10557 Mdot
.64162 .09475 Mdot
.9804 .20938 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.50841 .00357 Mdot
.52678 .01136 Mdot
.58514 .03607 Mdot
.76521 .11129 Mdot
.18291 .25816 Mdot
.38279 .12353 Mdot
.42231 .02442 Mdot
.34986 .57326 Mdot
.08415 .45381 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51261 .00535 Mdot
.54015 .01702 Mdot
.62728 .05385 Mdot
.88563 .15967 Mdot
.30114 .2568 Mdot
.49014 .11681 Mdot
.66437 .10768 Mdot
.0436 .23438 Mdot
.35824 .19446 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49653 .61656 Mdot
.48896 .61335 Mdot
.46483 .60312 Mdot
.38836 .57078 Mdot
.15784 .47556 Mdot
.7275 .35207 Mdot
.53352 .49815 Mdot
.38944 .52899 Mdot
.09255 .43454 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47785 .60864 Mdot
.42955 .58818 Mdot
.27898 .52498 Mdot
.89363 .37987 Mdot
.65622 .4713 Mdot
.61728 .59397 Mdot
.73875 .07508 Mdot
.09837 .22225 Mdot
.31965 .13676 Mdot
.49757 .617 Mdot
.49227 .61475 Mdot
.47537 .60759 Mdot
.42166 .58484 Mdot
.25514 .51512 Mdot
.85001 .36765 Mdot
.63801 .48701 Mdot
.60804 .59951 Mdot
.72796 .07412 Mdot
.08433 .22025 Mdot
.32004 .14568 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50837 .00355 Mdot
.52666 .01131 Mdot
.58476 .03591 Mdot
.76407 .11082 Mdot
.18119 .25779 Mdot
.38154 .12382 Mdot
.42015 .02386 Mdot
.34395 .57094 Mdot
.06943 .44837 Mdot
.49976 .61793 Mdot
.49923 .61771 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60745 Mdot
.4206 .58439 Mdot
.25194 .5138 Mdot
.84458 .36627 Mdot
.63502 .48852 Mdot
.60454 .5992 Mdot
.71986 .07127 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48703 .61254 Mdot
.45871 .60053 Mdot
.36914 .56268 Mdot
.10466 .45458 Mdot
.69426 .36439 Mdot
.50811 .50298 Mdot
.33411 .5105 Mdot
.95395 .38308 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52504 .01062 Mdot
.57961 .03373 Mdot
.74869 .1045 Mdot
.1565 .25204 Mdot
.3656 .12923 Mdot
.39621 .01892 Mdot
.28195 .54742 Mdot
.93375 .40284 Mdot
.68208 .46249 Mdot
.49959 .61786 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.4869 .61248 Mdot
.45829 .60035 Mdot
.36782 .56212 Mdot
.1011 .45319 Mdot
.69272 .36565 Mdot
.50779 .50374 Mdot
.33454 .51096 Mdot
.95545 .38375 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52366 .01003 Mdot
.57524 .03188 Mdot
.73554 .09907 Mdot
.13358 .246 Mdot
.35396 .1362 Mdot
.38476 .01903 Mdot
.25741 .53933 Mdot
.89158 .39194 Mdot
.67609 .48486 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00113 Mdot
.50846 .00359 Mdot
.52693 .01142 Mdot
.58562 .03627 Mdot
.76663 .11187 Mdot
.18507 .25861 Mdot
.38437 .12317 Mdot
.42509 .02517 Mdot
.35755 .57629 Mdot
.10373 .46117 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51918 .00813 Mdot
.56105 .02587 Mdot
.69225 .08109 Mdot
.04664 .21903 Mdot
.33207 .1764 Mdot
.4098 .04804 Mdot
.35937 .58687 Mdot
.1244 .47281 Mdot
.72125 .36888 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51299 .00551 Mdot
.54137 .01754 Mdot
.63112 .05546 Mdot
.89603 .16373 Mdot
.30604 .2534 Mdot
.49197 .11491 Mdot
.66585 .10746 Mdot
.04586 .23486 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .00159 Mdot
.51198 .00508 Mdot
.53814 .01617 Mdot
.62097 .05119 Mdot
.86828 .15285 Mdot
.29138 .26149 Mdot
.48376 .1189 Mdot
.65182 .10387 Mdot
.01462 .22422 Mdot
.35552 .21069 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50338 .00144 Mdot
.51078 .00457 Mdot
.53435 .01456 Mdot
.60904 .04616 Mdot
.83478 .13952 Mdot
.26618 .26662 Mdot
.46008 .11984 Mdot
.59473 .08322 Mdot
.86322 .16594 Mdot
.31255 .2777 Mdot
.49773 .61707 Mdot
.49275 .61496 Mdot
.47691 .60824 Mdot
.42656 .58691 Mdot
.26991 .52122 Mdot
.8764 .37483 Mdot
.65021 .47824 Mdot
.61733 .59772 Mdot
.74494 .07886 Mdot
.11115 .22633 Mdot
.32387 .13146 Mdot
.4987 .61748 Mdot
.49585 .61627 Mdot
.48677 .61242 Mdot
.45786 .60017 Mdot
.36647 .56155 Mdot
.09747 .45178 Mdot
.69124 .36697 Mdot
.50764 .50457 Mdot
.33552 .51165 Mdot
.95829 .3849 Mdot
.64292 .42312 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50964 .00409 Mdot
.53069 .01301 Mdot
.5975 .04129 Mdot
.80157 .12612 Mdot
.23195 .26599 Mdot
.42513 .11939 Mdot
.51012 .05252 Mdot
.61026 .06189 Mdot
.86288 .15613 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48266 .61068 Mdot
.4448 .59464 Mdot
.32579 .54448 Mdot
.99462 .41336 Mdot
.67151 .41834 Mdot
.55869 .54831 Mdot
.53194 .6015 Mdot
.55276 .01287 Mdot
.65129 .06089 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51713 .00726 Mdot
.55453 .02311 Mdot
.67213 .07268 Mdot
.00046 .20292 Mdot
.3281 .20249 Mdot
.44517 .07236 Mdot
.48162 .02253 Mdot
.49055 .00552 Mdot
.48532 .6148 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50225 .00095 Mdot
.50715 .00303 Mdot
.52279 .00966 Mdot
.5725 .03072 Mdot
.72724 .09563 Mdot
.11828 .24167 Mdot
.34778 .14184 Mdot
.38221 .02128 Mdot
.25566 .53982 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48342 .611 Mdot
.44722 .59566 Mdot
.33329 .54762 Mdot
.01258 .41982 Mdot
.67302 .40818 Mdot
.54481 .53879 Mdot
.48292 .57979 Mdot
.39547 .56399 Mdot
.16227 .4739 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50152 .00065 Mdot
.50486 .00206 Mdot
.51547 .00656 Mdot
.54926 .02088 Mdot
.65576 .06582 Mdot
.96035 .18825 Mdot
.3238 .22462 Mdot
.47373 .09266 Mdot
.58443 .06842 Mdot
.81592 .14307 Mdot
.49823 .61728 Mdot
.49437 .61565 Mdot
.48206 .61043 Mdot
.44289 .59383 Mdot
.31987 .54201 Mdot
.98077 .40846 Mdot
.67044 .42624 Mdot
.56963 .55573 Mdot
.56997 .00021 Mdot
.67191 .063 Mdot
.98442 .19314 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50512 .00217 Mdot
.51631 .00691 Mdot
.55191 .022 Mdot
.664 .06928 Mdot
.98081 .1958 Mdot
.32634 .21355 Mdot
.46007 .08265 Mdot
.53453 .04602 Mdot
.6604 .07779 Mdot
.98814 .20256 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50425 .0018 Mdot
.51355 .00575 Mdot
.54316 .0183 Mdot
.63671 .05782 Mdot
.91103 .16954 Mdot
.31196 .24779 Mdot
.49202 .11128 Mdot
.66012 .10389 Mdot
.02987 .22852 Mdot
.35508 .20099 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50341 .00145 Mdot
.51087 .00461 Mdot
.53462 .01468 Mdot
.60989 .04652 Mdot
.83722 .1405 Mdot
.26832 .26643 Mdot
.46226 .11986 Mdot
.49803 .6172 Mdot
.49373 .61538 Mdot
.48003 .60956 Mdot
.43644 .5911 Mdot
.30003 .53373 Mdot
.93658 .39341 Mdot
.66576 .45066 Mdot
.60102 .57802 Mdot
.67783 .04747 Mdot
.96924 .1801 Mdot
.30651 .20844 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48127 .61009 Mdot
.44039 .59277 Mdot
.31216 .53878 Mdot
.96317 .40235 Mdot
.66894 .43619 Mdot
.58313 .565 Mdot
.61643 .02058 Mdot
.80922 .11915 Mdot
.2244 .2566 Mdot
.49895 .61759 Mdot
.49666 .61662 Mdot
.48935 .61352 Mdot
.46606 .60365 Mdot
.39227 .57242 Mdot
.16893 .48 Mdot
.73717 .35119 Mdot
.54336 .49826 Mdot
.4138 .53796 Mdot
.16117 .4619 Mdot
.70604 .33675 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47774 .6086 Mdot
.42919 .58803 Mdot
.27788 .52452 Mdot
.8915 .37924 Mdot
.65555 .47221 Mdot
.61752 .59453 Mdot
.74017 .0758 Mdot
.1011 .22307 Mdot
.32038 .13552 Mdot
.49819 .61727 Mdot
.49424 .61559 Mdot
.48165 .61025 Mdot
.44161 .59328 Mdot
.31592 .54036 Mdot
.97169 .40529 Mdot
.6697 .43139 Mdot
.5767 .56055 Mdot
.59433 .0109 Mdot
.74533 .09332 Mdot
.13496 .2408 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50378 .0016 Mdot
.51205 .00511 Mdot
.53837 .01627 Mdot
.62168 .05149 Mdot
.87025 .15362 Mdot
.29259 .26102 Mdot
.48469 .11873 Mdot
.65387 .10456 Mdot
.01955 .226 Mdot
.35598 .20792 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47564 .6077 Mdot
.42253 .58521 Mdot
.25774 .51619 Mdot
.85451 .36882 Mdot
.64036 .48568 Mdot
.6105 .59958 Mdot
.7334 .07595 Mdot
.09373 .2227 Mdot
.4996 .61786 Mdot
.49873 .6175 Mdot
.49595 .61632 Mdot
.4871 .61256 Mdot
.45892 .60062 Mdot
.36979 .56295 Mdot
.10641 .45526 Mdot
.69505 .3638 Mdot
.50833 .50263 Mdot
.33409 .51035 Mdot
.95368 .38293 Mdot
.49893 .61758 Mdot
.49659 .61659 Mdot
.48914 .61343 Mdot
.4654 .60337 Mdot
.39018 .57154 Mdot
.16299 .47762 Mdot
.73186 .35158 Mdot
.53792 .49817 Mdot
.40033 .533 Mdot
.12281 .44652 Mdot
.67882 .34363 Mdot
.49816 .61725 Mdot
.49413 .61555 Mdot
.4813 .61011 Mdot
.44049 .59281 Mdot
.31249 .53892 Mdot
.96391 .4026 Mdot
.66901 .43577 Mdot
.58259 .56462 Mdot
.61456 .01976 Mdot
.8039 .11702 Mdot
.21842 .25619 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52244 .00952 Mdot
.5714 .03026 Mdot
.7239 .09425 Mdot
.11192 .23981 Mdot
.34556 .1444 Mdot
.38223 .02266 Mdot
.25793 .54121 Mdot
.89519 .39385 Mdot
.50037 .00016 Mdot
.50117 .00049 Mdot
.50371 .00158 Mdot
.51183 .00502 Mdot
.53769 .01598 Mdot
.61956 .0506 Mdot
.86436 .1513 Mdot
.28887 .26236 Mdot
.48174 .1192 Mdot
.64727 .1023 Mdot
.0035 .22016 Mdot
.35448 .21692 Mdot
.49858 .61743 Mdot
.49547 .61611 Mdot
.48556 .61191 Mdot
.45402 .59854 Mdot
.35448 .55651 Mdot
.06582 .43963 Mdot
.68122 .38034 Mdot
.51341 .51432 Mdot
.36568 .52673 Mdot
.03956 .41648 Mdot
.65471 .38018 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00282 Mdot
.5212 .00899 Mdot
.56746 .02859 Mdot
.7119 .08927 Mdot
.08826 .2326 Mdot
.33891 .15491 Mdot
.38714 .0298 Mdot
.2799 .55176 Mdot
.93812 .40681 Mdot
.68685 .46274 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50756 .0032 Mdot
.52408 .01021 Mdot
.57657 .03244 Mdot
.73953 .10072 Mdot
.14072 .24794 Mdot
.35727 .13384 Mdot
.38729 .01855 Mdot
.26203 .54062 Mdot
.89872 .3935 Mdot
.67728 .48118 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52546 .01079 Mdot
.58095 .03429 Mdot
.75269 .10614 Mdot
.16312 .25366 Mdot
.36952 .12756 Mdot
.4014 .0197 Mdot
.29466 .55207 Mdot
.49952 .61783 Mdot
.49846 .61738 Mdot
.4951 .61595 Mdot
.48438 .61141 Mdot
.45027 .59695 Mdot
.34278 .5516 Mdot
.03598 .42842 Mdot
.67567 .39535 Mdot
.52853 .52709 Mdot
.42394 .5534 Mdot
.20956 .48554 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61476 Mdot
.47544 .60762 Mdot
.42189 .58494 Mdot
.25583 .5154 Mdot
.8512 .36796 Mdot
.63864 .48667 Mdot
.60873 .59955 Mdot
.72951 .07465 Mdot
.08705 .22097 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51399 .00593 Mdot
.54455 .01889 Mdot
.64106 .05965 Mdot
.92254 .17396 Mdot
.31567 .24297 Mdot
.49011 .10781 Mdot
.64972 .09865 Mdot
.00222 .21786 Mdot
.35139 .2158 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50763 .00324 Mdot
.52432 .01031 Mdot
.57733 .03277 Mdot
.74184 .10167 Mdot
.14476 .24902 Mdot
.35927 .13257 Mdot
.38913 .01846 Mdot
.26582 .54182 Mdot
.90496 .39501 Mdot
.67833 .47797 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61226 Mdot
.45661 .59964 Mdot
.36257 .55991 Mdot
.08705 .44776 Mdot
.68737 .37102 Mdot
.50818 .50729 Mdot
.34127 .51487 Mdot
.9738 .39093 Mdot
.64546 .41511 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00112 Mdot
.50845 .00358 Mdot
.52692 .01142 Mdot
.58559 .03626 Mdot
.76653 .11183 Mdot
.18493 .25858 Mdot
.38426 .1232 Mdot
.4249 .02511 Mdot
.35702 .57608 Mdot
.49742 .61694 Mdot
.49177 .61454 Mdot
.47377 .60691 Mdot
.41662 .58271 Mdot
.24004 .5089 Mdot
.82519 .36164 Mdot
.62292 .49303 Mdot
.58725 .59599 Mdot
.67601 .05485 Mdot
.97815 .18674 Mdot
.31297 .20693 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49145 .61441 Mdot
.47276 .60648 Mdot
.4134 .58135 Mdot
.23047 .50497 Mdot
.8106 .35854 Mdot
.61236 .49552 Mdot
.56902 .59124 Mdot
.62598 .03521 Mdot
.498 .61719 Mdot
.49362 .61533 Mdot
.47968 .60942 Mdot
.43535 .59063 Mdot
.29669 .53233 Mdot
.92949 .39109 Mdot
.66463 .45434 Mdot
.60498 .58117 Mdot
.69163 .05355 Mdot
.00113 .19128 Mdot
.30894 .19023 Mdot
.49948 .61781 Mdot
.49834 .61733 Mdot
.49472 .61579 Mdot
.48317 .6109 Mdot
.44642 .59532 Mdot
.3308 .54658 Mdot
.00656 .41764 Mdot
.67248 .41157 Mdot
.54938 .54195 Mdot
.49917 .587 Mdot
.44772 .58623 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00148 Mdot
.51109 .0047 Mdot
.53533 .01498 Mdot
.61212 .04746 Mdot
.84352 .14301 Mdot
.27361 .26581 Mdot
.46759 .11989 Mdot
.61329 .09005 Mdot
.91494 .18643 Mdot
.33819 .26158 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.49291 .61503 Mdot
.47741 .60846 Mdot
.42815 .58759 Mdot
.27474 .52322 Mdot
.88547 .37745 Mdot
.65355 .4747 Mdot
.61785 .59597 Mdot
.7432 .07747 Mdot
.10707 .22488 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50775 .00329 Mdot
.52469 .01047 Mdot
.57853 .03327 Mdot
.74543 .10315 Mdot
.15096 .25063 Mdot
.36251 .13075 Mdot
.39254 .01856 Mdot
.27336 .54437 Mdot
.91801 .39842 Mdot
.68028 .47111 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50293 .00124 Mdot
.50934 .00396 Mdot
.52974 .01261 Mdot
.59451 .04003 Mdot
.79284 .12258 Mdot
.22131 .26481 Mdot
.41492 .11966 Mdot
.4869 .04448 Mdot
.53924 .03235 Mdot
.64985 .06836 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47474 .60732 Mdot
.41968 .584 Mdot
.24918 .51266 Mdot
.83995 .36512 Mdot
.63233 .48972 Mdot
.60111 .59874 Mdot
.71157 .06826 Mdot
.05383 .21153 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00314 Mdot
.52362 .01002 Mdot
.57514 .03184 Mdot
.73522 .09894 Mdot
.13301 .24585 Mdot
.35371 .1364 Mdot
.38459 .01909 Mdot
.25714 .53927 Mdot
.8912 .39187 Mdot
.67604 .48506 Mdot
.50027 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.50889 .00377 Mdot
.52832 .01201 Mdot
.59001 .03813 Mdot
.77964 .1172 Mdot
.20387 .26219 Mdot
.39933 .1208 Mdot
.45364 .03357 Mdot
.4394 .60923 Mdot
.33645 .5544 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51389 .00589 Mdot
.54422 .01875 Mdot
.64004 .05922 Mdot
.91984 .17292 Mdot
.31486 .24414 Mdot
.4907 .10868 Mdot
.65261 .10006 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00156 Mdot
.51169 .00496 Mdot
.53724 .01579 Mdot
.61814 .05 Mdot
.86042 .14974 Mdot
.28625 .26317 Mdot
.4795 .11944 Mdot
.64209 .10049 Mdot
.99061 .2154 Mdot
.35321 .2241 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48513 .61173 Mdot
.45264 .59796 Mdot
.35016 .5547 Mdot
.05467 .43541 Mdot
.67878 .38572 Mdot
.51812 .51874 Mdot
.38459 .5355 Mdot
.09271 .43764 Mdot
.6695 .35648 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49666 .61662 Mdot
.48937 .61352 Mdot
.46613 .60367 Mdot
.39247 .57251 Mdot
.16952 .48024 Mdot
.73771 .35116 Mdot
.54392 .49827 Mdot
.41518 .53847 Mdot
.16516 .46351 Mdot
.50021 9e-05 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52177 .00923 Mdot
.56925 .02935 Mdot
.71736 .09154 Mdot
.0992 .23599 Mdot
.34169 .14987 Mdot
.38398 .02614 Mdot
.26725 .54589 Mdot
.91318 .39921 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51428 .00606 Mdot
.54548 .01928 Mdot
.64397 .06087 Mdot
.93013 .17686 Mdot
.31777 .23957 Mdot
.48799 .1052 Mdot
.6402 .09407 Mdot
.97655 .20788 Mdot
.34795 .22954 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00124 Mdot
.50929 .00394 Mdot
.52958 .01254 Mdot
.59398 .0398 Mdot
.79129 .12195 Mdot
.21935 .26455 Mdot
.41309 .11974 Mdot
.48284 .04311 Mdot
.52691 .02723 Mdot
.61114 .05206 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.4749 .60739 Mdot
.42019 .58422 Mdot
.25071 .51329 Mdot
.8425 .36575 Mdot
.63383 .48907 Mdot
.60306 .59902 Mdot
.7163 .06999 Mdot
.06295 .21424 Mdot
.31761 .15739 Mdot
.49881 .61753 Mdot
.49619 .61642 Mdot
.48787 .61289 Mdot
.46138 .60166 Mdot
.37753 .56621 Mdot
.12758 .46355 Mdot
.7061 .35755 Mdot
.51434 .49952 Mdot
.34405 .51279 Mdot
.97551 .39026 Mdot
.64356 .41288 Mdot
.4974 .61693 Mdot
.49172 .61452 Mdot
.47363 .60685 Mdot
.41616 .58252 Mdot
.23866 .50834 Mdot
.82304 .36117 Mdot
.62145 .49344 Mdot
.58486 .59542 Mdot
.66961 .05238 Mdot
.96328 .1815 Mdot
.31154 .21524 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50365 .00155 Mdot
.51163 .00493 Mdot
.53705 .01571 Mdot
.61754 .04974 Mdot
.85874 .14907 Mdot
.28509 .2635 Mdot
.47848 .11952 Mdot
.63969 .09963 Mdot
.98455 .21313 Mdot
.35255 .22744 Mdot
.50047 .0002 Mdot
.5015 .00063 Mdot
.50477 .00202 Mdot
.51519 .00644 Mdot
.54837 .0205 Mdot
.65298 .06465 Mdot
.95331 .18562 Mdot
.32268 .22828 Mdot
.47778 .09586 Mdot
.59966 .07532 Mdot
.86144 .16179 Mdot
.30579 .27462 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51189 .00504 Mdot
.53787 .01605 Mdot
.62011 .05083 Mdot
.86588 .1519 Mdot
.28986 .26203 Mdot
.48255 .11909 Mdot
.64911 .10294 Mdot
.00803 .22183 Mdot
.35491 .21438 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50832 .00353 Mdot
.52652 .01124 Mdot
.5843 .03571 Mdot
.76272 .11026 Mdot
.1791 .25734 Mdot
.38005 .12419 Mdot
.41763 .02323 Mdot
.3371 .56826 Mdot
.05269 .44226 Mdot
.69069 .3943 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48765 .6128 Mdot
.46067 .60136 Mdot
.37528 .56526 Mdot
.12138 .46112 Mdot
.70256 .35918 Mdot
.51193 .50022 Mdot
.33919 .51127 Mdot
.96424 .3863 Mdot
.64248 .41917 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50278 .00118 Mdot
.50884 .00375 Mdot
.52817 .01194 Mdot
.58952 .03792 Mdot
.77818 .1166 Mdot
.20184 .26184 Mdot
.39761 .121 Mdot
.45019 .03249 Mdot
.42925 .60509 Mdot
.30565 .54164 Mdot
.49906 .61764 Mdot
.49702 .61677 Mdot
.4905 .61401 Mdot
.46975 .60521 Mdot
.40391 .57734 Mdot
.20252 .49357 Mdot
.77295 .35254 Mdot
.57963 .49856 Mdot
.50084 .56934 Mdot
.4233 .57011 Mdot
.23511 .50173 Mdot
.49889 .61756 Mdot
.49647 .61654 Mdot
.48876 .61327 Mdot
.46421 .60286 Mdot
.38642 .56996 Mdot
.15237 .47338 Mdot
.72311 .35274 Mdot
.52918 .49818 Mdot
.37879 .52508 Mdot
.06364 .42326 Mdot
.65556 .36583 Mdot
.50066 .00028 Mdot
.50211 .00089 Mdot
.50672 .00285 Mdot
.5214 .00908 Mdot
.5681 .02886 Mdot
.71386 .09008 Mdot
.09222 .23384 Mdot
.33986 .15305 Mdot
.38583 .02841 Mdot
.27485 .54944 Mdot
.92804 .40369 Mdot
.68553 .46816 Mdot
.50033 .00014 Mdot
.50107 .00045 Mdot
.50339 .00144 Mdot
.51081 .00459 Mdot
.53444 .0146 Mdot
.60933 .04628 Mdot
.83561 .13985 Mdot
.26691 .26656 Mdot
.46083 .11985 Mdot
.59658 .0839 Mdot
.86846 .16803 Mdot
.31595 .27656 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00332 Mdot
.52496 .01058 Mdot
.57937 .03363 Mdot
.74797 .1042 Mdot
.15528 .25173 Mdot
.3649 .12955 Mdot
.39536 .01882 Mdot
.27991 .54668 Mdot
.92994 .40174 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .0099 Mdot
.57429 .03148 Mdot
.73267 .09788 Mdot
.12836 .24455 Mdot
.35172 .13804 Mdot
.38346 .01962 Mdot
.2556 .53901 Mdot
.88916 .39156 Mdot
.67586 .48621 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52444 .01036 Mdot
.57774 .03294 Mdot
.74305 .10217 Mdot
.14687 .24957 Mdot
.36035 .13194 Mdot
.39021 .01846 Mdot
.26815 .54259 Mdot
.90891 .39601 Mdot
.67896 .47592 Mdot
.49756 .617 Mdot
.49223 .61474 Mdot
.47526 .60754 Mdot
.42132 .5847 Mdot
.25411 .51469 Mdot
.84824 .3672 Mdot
.63705 .48751 Mdot
.60696 .59944 Mdot
.72551 .07327 Mdot
.07997 .21907 Mdot
.31946 .14801 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.4798 .60947 Mdot
.43572 .59079 Mdot
.29783 .53281 Mdot
.93191 .39188 Mdot
.66504 .4531 Mdot
.60367 .58011 Mdot
.68705 .05153 Mdot
.99074 .18769 Mdot
.30831 .19627 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.485 .61167 Mdot
.45224 .59779 Mdot
.34891 .55417 Mdot
.05148 .43421 Mdot
.67817 .38731 Mdot
.51969 .52009 Mdot
.39067 .53829 Mdot
.11025 .44473 Mdot
.67737 .3505 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51265 .00537 Mdot
.5403 .01709 Mdot
.62775 .05405 Mdot
.88689 .16016 Mdot
.30177 .25641 Mdot
.49044 .1166 Mdot
.66479 .10775 Mdot
.04446 .23465 Mdot
.35831 .19397 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50526 .00223 Mdot
.51676 .00711 Mdot
.55335 .02261 Mdot
.66846 .07115 Mdot
.99166 .19975 Mdot
.32736 .20748 Mdot
.45199 .07702 Mdot
.50568 .03318 Mdot
.56788 .03844 Mdot
.49996 .61802 Mdot
.49989 .61799 Mdot
.49963 .61788 Mdot
.49884 .61754 Mdot
.49629 .61646 Mdot
.48819 .61303 Mdot
.46239 .60209 Mdot
.38069 .56754 Mdot
.13632 .46701 Mdot
.71157 .35553 Mdot
.51863 .49879 Mdot
.49974 .61792 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49167 .6145 Mdot
.47345 .60678 Mdot
.4156 .58228 Mdot
.237 .50765 Mdot
.82047 .3606 Mdot
.61965 .49392 Mdot
.58186 .59468 Mdot
.66151 .04923 Mdot
.4977 .61706 Mdot
.49269 .61493 Mdot
.4767 .60816 Mdot
.4259 .58664 Mdot
.26792 .5204 Mdot
.87273 .37379 Mdot
.64873 .4796 Mdot
.61675 .59827 Mdot
.74461 .07902 Mdot
.11107 .22648 Mdot
.32412 .13167 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.5037 .00157 Mdot
.51177 .00499 Mdot
.53749 .0159 Mdot
.61893 .05033 Mdot
.86262 .15061 Mdot
.28773 .26273 Mdot
.48078 .11931 Mdot
.64506 .10153 Mdot
.99804 .21815 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.48509 .61171 Mdot
.45254 .59791 Mdot
.34984 .55456 Mdot
.05385 .43511 Mdot
.67862 .38613 Mdot
.51852 .51908 Mdot
.38612 .53621 Mdot
.09712 .43942 Mdot
.67131 .35487 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49074 .61411 Mdot
.47049 .60552 Mdot
.40624 .57832 Mdot
.20933 .49634 Mdot
.78145 .35359 Mdot
.58765 .49826 Mdot
.51878 .57547 Mdot
.47802 .59284 Mdot
.49919 .61769 Mdot
.49741 .61693 Mdot
.49174 .61453 Mdot
.47368 .60687 Mdot
.41631 .58258 Mdot
.23911 .50852 Mdot
.82374 .36132 Mdot
.62193 .49331 Mdot
.58565 .59561 Mdot
.67173 .0532 Mdot
.96824 .18326 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51517 .00643 Mdot
.5483 .02048 Mdot
.65279 .06457 Mdot
.95283 .18544 Mdot
.3226 .22853 Mdot
.47804 .09607 Mdot
.60066 .07578 Mdot
.86439 .163 Mdot
.3078 .27404 Mdot
.49999 .61803 Mdot
.49996 .61802 Mdot
.49987 .61798 Mdot
.49959 .61786 Mdot
.49869 .61748 Mdot
.49584 .61627 Mdot
.48673 .61241 Mdot
.45775 .60012 Mdot
.36612 .56141 Mdot
.09653 .45142 Mdot
.69086 .36732 Mdot
.49973 .61792 Mdot
.49913 .61767 Mdot
.49724 .61686 Mdot
.4912 .6143 Mdot
.47197 .60615 Mdot
.4109 .58029 Mdot
.22306 .50194 Mdot
.7999 .35651 Mdot
.60383 .49686 Mdot
.55269 .58643 Mdot
.57916 .01636 Mdot
.49778 .61709 Mdot
.49291 .61503 Mdot
.47742 .60846 Mdot
.42818 .5876 Mdot
.27482 .52325 Mdot
.88563 .3775 Mdot
.6536 .47464 Mdot
.61785 .59593 Mdot
.74314 .07744 Mdot
.10695 .22485 Mdot
.32214 .13299 Mdot
.498 .61718 Mdot
.49362 .61533 Mdot
.47966 .60941 Mdot
.43529 .59061 Mdot
.2965 .53226 Mdot
.92909 .39097 Mdot
.66456 .45455 Mdot
.60519 .58134 Mdot
.69235 .05387 Mdot
.00276 .19184 Mdot
.30903 .18928 Mdot
.4983 .61731 Mdot
.49457 .61573 Mdot
.4827 .6107 Mdot
.44493 .59469 Mdot
.32619 .54465 Mdot
.99555 .41369 Mdot
.67159 .41781 Mdot
.55796 .54781 Mdot
.52936 .60036 Mdot
.54456 .00939 Mdot
.62574 .05017 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.4421 .59349 Mdot
.31744 .54099 Mdot
.97515 .40649 Mdot
.66999 .42943 Mdot
.57402 .55872 Mdot
.58513 .00686 Mdot
.71792 .08207 Mdot
.0846 .22663 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48268 .61069 Mdot
.44487 .59467 Mdot
.32602 .54458 Mdot
.99514 .41354 Mdot
.67155 .41805 Mdot
.55828 .54803 Mdot
.53049 .60086 Mdot
.54816 .01092 Mdot
.63698 .05489 Mdot
.49956 .61785 Mdot
.49859 .61744 Mdot
.49552 .61613 Mdot
.48572 .61198 Mdot
.45452 .59875 Mdot
.35602 .55716 Mdot
.06982 .44116 Mdot
.68222 .37848 Mdot
.51203 .51285 Mdot
.35986 .52399 Mdot
.02362 .41022 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51554 .00659 Mdot
.54949 .02098 Mdot
.65647 .06612 Mdot
.96213 .18891 Mdot
.32406 .22369 Mdot
.47265 .09183 Mdot
.5804 .0666 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48511 .61172 Mdot
.45261 .59794 Mdot
.35005 .55465 Mdot
.05441 .43532 Mdot
.67873 .38585 Mdot
.51825 .51885 Mdot
.38508 .53573 Mdot
.09413 .43822 Mdot
.67007 .35595 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.4849 .61163 Mdot
.45193 .59766 Mdot
.34794 .55377 Mdot
.04902 .43329 Mdot
.67772 .38856 Mdot
.52097 .52115 Mdot
.39556 .54053 Mdot
.12451 .45052 Mdot
.68517 .3465 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47959 .60938 Mdot
.43506 .59051 Mdot
.29581 .53197 Mdot
.92765 .3905 Mdot
.66431 .45528 Mdot
.60594 .58196 Mdot
.695 .05504 Mdot
.00867 .19386 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48427 .61137 Mdot
.44993 .59681 Mdot
.34172 .55116 Mdot
.03333 .42744 Mdot
.67531 .39676 Mdot
.53021 .52836 Mdot
.43017 .5562 Mdot
.2287 .49352 Mdot
.49738 .61692 Mdot
.49167 .6145 Mdot
.47345 .60678 Mdot
.4156 .58228 Mdot
.237 .50765 Mdot
.82046 .3606 Mdot
.61964 .49392 Mdot
.58185 .59468 Mdot
.66149 .04922 Mdot
.9439 .17453 Mdot
.30872 .22548 Mdot
.49989 .61799 Mdot
.49966 .61789 Mdot
.49892 .61757 Mdot
.49654 .61657 Mdot
.48899 .61336 Mdot
.46493 .60317 Mdot
.3887 .57092 Mdot
.15879 .47594 Mdot
.72829 .35197 Mdot
.53431 .49815 Mdot
.39138 .5297 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.515 .00636 Mdot
.54777 .02025 Mdot
.65111 .06387 Mdot
.94857 .18384 Mdot
.32184 .23069 Mdot
.48028 .09793 Mdot
.60923 .07969 Mdot
.88946 .17319 Mdot
.32249 .26763 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50694 .00294 Mdot
.52209 .00937 Mdot
.57029 .02979 Mdot
.72053 .09285 Mdot
.10541 .23787 Mdot
.34349 .14714 Mdot
.38285 .02433 Mdot
.26193 .5433 Mdot
.90295 .39617 Mdot
.68069 .48067 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.5087 .00369 Mdot
.52772 .01175 Mdot
.5881 .03732 Mdot
.77399 .11488 Mdot
.1959 .26076 Mdot
.39274 .12165 Mdot
.4406 .02958 Mdot
.4014 .59381 Mdot
.49956 .61785 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48581 .61202 Mdot
.45481 .59888 Mdot
.35695 .55755 Mdot
.07225 .44208 Mdot
.68286 .37738 Mdot
.51128 .51199 Mdot
.3566 .52244 Mdot
.01476 .40677 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48464 .61152 Mdot
.4511 .5973 Mdot
.34535 .55268 Mdot
.04245 .43083 Mdot
.67663 .39194 Mdot
.52461 .52408 Mdot
.40937 .54681 Mdot
.16541 .46726 Mdot
.71565 .34007 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50324 .00138 Mdot
.51034 .00438 Mdot
.53292 .01396 Mdot
.60454 .04426 Mdot
.82194 .13436 Mdot
.25409 .26709 Mdot
.4476 .11959 Mdot
.5639 .07188 Mdot
.77351 .12954 Mdot
.21924 .27548 Mdot
.49793 .61716 Mdot
.4934 .61523 Mdot
.47897 .60912 Mdot
.4331 .58968 Mdot
.28979 .52947 Mdot
.91518 .38651 Mdot
.66186 .46148 Mdot
.61159 .58697 Mdot
.71533 .06411 Mdot
.05215 .20817 Mdot
.31214 .16068 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47714 .60834 Mdot
.4273 .58723 Mdot
.27215 .52215 Mdot
.88057 .37603 Mdot
.6518 .47664 Mdot
.61773 .59698 Mdot
.74458 .0784 Mdot
.11002 .22586 Mdot
.32327 .13179 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48769 .61281 Mdot
.46079 .60141 Mdot
.37568 .56543 Mdot
.12249 .46155 Mdot
.70317 .35888 Mdot
.51232 .50008 Mdot
.33994 .5115 Mdot
.96595 .38689 Mdot
.4984 .61736 Mdot
.49491 .61588 Mdot
.4838 .61116 Mdot
.44842 .59617 Mdot
.33702 .54918 Mdot
.02168 .42315 Mdot
.67393 .40311 Mdot
.53814 .53412 Mdot
.45903 .56914 Mdot
.31915 .53158 Mdot
.96271 .39774 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58507 .03604 Mdot
.765 .1112 Mdot
.1826 .25809 Mdot
.38256 .12358 Mdot
.42191 .02432 Mdot
.34878 .57283 Mdot
.08143 .4528 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52639 .01119 Mdot
.58388 .03554 Mdot
.76147 .10975 Mdot
.17716 .25691 Mdot
.37869 .12455 Mdot
.41537 .02267 Mdot
.33101 .5659 Mdot
.03819 .43706 Mdot
.68863 .402 Mdot
.499 .61761 Mdot
.4968 .61668 Mdot
.48981 .61371 Mdot
.46753 .60427 Mdot
.39689 .57437 Mdot
.18217 .48533 Mdot
.75008 .35099 Mdot
.55672 .49853 Mdot
.44665 .55 Mdot
.25803 .50146 Mdot
.83099 .35411 Mdot
.49748 .61697 Mdot
.49197 .61463 Mdot
.47443 .60719 Mdot
.41871 .5836 Mdot
.24629 .51147 Mdot
.8352 .36397 Mdot
.62944 .49087 Mdot
.59714 .59807 Mdot
.70168 .06461 Mdot
.03403 .2054 Mdot
.31572 .1741 Mdot
.49999 .61803 Mdot
.49998 .61802 Mdot
.49993 .618 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47554 .60766 Mdot
.42221 .58508 Mdot
.25679 .5158 Mdot
.85286 .36839 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51704 .00723 Mdot
.55424 .02299 Mdot
.67125 .07231 Mdot
.99835 .20216 Mdot
.32793 .20369 Mdot
.44682 .07348 Mdot
.48742 .02509 Mdot
.50917 .01344 Mdot
.54467 .02194 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50658 .00279 Mdot
.52096 .00889 Mdot
.56668 .02826 Mdot
.70951 .08828 Mdot
.0834 .23107 Mdot
.33783 .15725 Mdot
.38898 .03161 Mdot
.28677 .55487 Mdot
.95217 .41124 Mdot
.68824 .45492 Mdot
.49996 .61802 Mdot
.49986 .61798 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48601 .6121 Mdot
.45546 .59915 Mdot
.35896 .5584 Mdot
.07753 .4441 Mdot
.68435 .37503 Mdot
.50987 .5102 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60202 Mdot
.38022 .56734 Mdot
.13502 .46649 Mdot
.71072 .35581 Mdot
.51793 .49888 Mdot
.35196 .51546 Mdot
.9946 .39717 Mdot
.64534 .40218 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50547 .00232 Mdot
.51743 .00739 Mdot
.55549 .02352 Mdot
.6751 .07393 Mdot
.0075 .20543 Mdot
.32865 .19848 Mdot
.43963 .06859 Mdot
.46222 .01396 Mdot
.42868 .5973 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .00029 Mdot
.50221 .00094 Mdot
.50706 .00299 Mdot
.52248 .00953 Mdot
.57151 .0303 Mdot
.72423 .09439 Mdot
.11256 .24 Mdot
.34578 .14414 Mdot
.3822 .02251 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47784 .60864 Mdot
.4295 .58816 Mdot
.27882 .52491 Mdot
.89333 .37978 Mdot
.65612 .47144 Mdot
.61731 .59405 Mdot
.73897 .07519 Mdot
.09879 .22238 Mdot
.31975 .13657 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48803 .61296 Mdot
.46187 .60187 Mdot
.37907 .56686 Mdot
.13182 .46523 Mdot
.70869 .35652 Mdot
.51629 .49913 Mdot
.34828 .5142 Mdot
.98564 .39391 Mdot
.64451 .4072 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47989 .60951 Mdot
.43601 .59091 Mdot
.2987 .53317 Mdot
.93374 .39248 Mdot
.66533 .45214 Mdot
.60265 .5793 Mdot
.6835 .04996 Mdot
.98253 .18481 Mdot
.30772 .20098 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00165 Mdot
.51236 .00524 Mdot
.53936 .01669 Mdot
.62481 .05281 Mdot
.87887 .15702 Mdot
.29758 .25878 Mdot
.48815 .11778 Mdot
.66097 .10681 Mdot
.03614 .23186 Mdot
.35756 .19865 Mdot
.49827 .6173 Mdot
.49448 .61569 Mdot
.48241 .61057 Mdot
.444 .5943 Mdot
.32332 .54345 Mdot
.98879 .41128 Mdot
.67106 .42167 Mdot
.5633 .55143 Mdot
.54801 .60858 Mdot
.60364 .03438 Mdot
.80398 .12382 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50376 .00159 Mdot
.51196 .00507 Mdot
.5381 .01616 Mdot
.62086 .05114 Mdot
.86797 .15272 Mdot
.29118 .26156 Mdot
.48361 .11893 Mdot
.65148 .10375 Mdot
.0138 .22392 Mdot
.35544 .21115 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50346 .00147 Mdot
.51101 .00467 Mdot
.53507 .01487 Mdot
.6113 .04711 Mdot
.8412 .14209 Mdot
.2717 .26606 Mdot
.46569 .11989 Mdot
.6086 .08832 Mdot
.90205 .18137 Mdot
.33333 .26654 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51068 .00453 Mdot
.53402 .01443 Mdot
.60802 .04573 Mdot
.83188 .13835 Mdot
.26357 .2668 Mdot
.4574 .11979 Mdot
.58808 .08077 Mdot
.49988 .61798 Mdot
.4996 .61787 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.48719 .6126 Mdot
.4592 .60074 Mdot
.3707 .56333 Mdot
.10887 .45622 Mdot
.69618 .36298 Mdot
.50871 .50217 Mdot
.33429 .51024 Mdot
.5002 8e-05 Mdot
.50062 .00026 Mdot
.50199 .00084 Mdot
.50633 .00268 Mdot
.52015 .00855 Mdot
.56413 .02718 Mdot
.70173 .08504 Mdot
.06717 .22585 Mdot
.33482 .16541 Mdot
.39683 .03833 Mdot
.31472 .56728 Mdot
.01333 .43177 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.5072 .00305 Mdot
.52294 .00973 Mdot
.57297 .03092 Mdot
.72865 .09622 Mdot
.12093 .24244 Mdot
.34877 .14081 Mdot
.38239 .02078 Mdot
.25521 .53943 Mdot
.88942 .39197 Mdot
.49786 .61713 Mdot
.49317 .61514 Mdot
.47825 .60881 Mdot
.4308 .58871 Mdot
.2828 .52657 Mdot
.90113 .38214 Mdot
.6584 .46802 Mdot
.61595 .5918 Mdot
.73244 .07199 Mdot
.0862 .21864 Mdot
.3169 .14258 Mdot
.49884 .61754 Mdot
.49632 .61647 Mdot
.48827 .61306 Mdot
.46265 .6022 Mdot
.38152 .56789 Mdot
.13863 .46792 Mdot
.71311 .35505 Mdot
.51994 .49865 Mdot
.35661 .51709 Mdot
.00614 .40143 Mdot
.64646 .39574 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00327 Mdot
.52459 .01043 Mdot
.5782 .03313 Mdot
.74445 .10275 Mdot
.14928 .2502 Mdot
.36161 .13123 Mdot
.39155 .0185 Mdot
.27111 .5436 Mdot
.91403 .39735 Mdot
.67973 .47323 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52382 .0101 Mdot
.57577 .03211 Mdot
.73714 .09973 Mdot
.13646 .24679 Mdot
.35526 .13523 Mdot
.38567 .01879 Mdot
.25896 .53972 Mdot
.8939 .39241 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.51511 .00641 Mdot
.54811 .02039 Mdot
.65217 .06432 Mdot
.95127 .18485 Mdot
.32233 .22932 Mdot
.47888 .09675 Mdot
.60385 .07723 Mdot
.87376 .16682 Mdot
.31379 .27196 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .6126 Mdot
.45916 .60072 Mdot
.37054 .56327 Mdot
.10846 .45606 Mdot
.69599 .36311 Mdot
.50864 .50224 Mdot
.33424 .51025 Mdot
.95377 .38289 Mdot
.64168 .42515 Mdot
.4998 .61795 Mdot
.49937 .61777 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.4797 .60943 Mdot
.43541 .59066 Mdot
.29686 .53241 Mdot
.92986 .39121 Mdot
.66469 .45415 Mdot
.60478 .58101 Mdot
.69093 .05324 Mdot
.50053 .00022 Mdot
.50169 .00071 Mdot
.50537 .00228 Mdot
.5171 .00725 Mdot
.55445 .02308 Mdot
.67188 .07258 Mdot
.99986 .2027 Mdot
.32805 .20283 Mdot
.44564 .07267 Mdot
.48326 .02325 Mdot
.49583 .00777 Mdot
.50215 .0039 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50654 .00277 Mdot
.52082 .00883 Mdot
.56624 .02807 Mdot
.70818 .08772 Mdot
.08066 .23021 Mdot
.33726 .15859 Mdot
.39012 .03267 Mdot
.29095 .55674 Mdot
.96091 .41406 Mdot
.68891 .44993 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51427 .00605 Mdot
.54545 .01927 Mdot
.64389 .06083 Mdot
.92992 .17678 Mdot
.31771 .23967 Mdot
.48805 .10528 Mdot
.64049 .09421 Mdot
.97734 .20818 Mdot
.34807 .22912 Mdot
.49834 .61733 Mdot
.49472 .6158 Mdot
.48319 .61091 Mdot
.44649 .59535 Mdot
.33102 .54667 Mdot
.00709 .41784 Mdot
.67253 .41126 Mdot
.54897 .54167 Mdot
.49771 .58635 Mdot
.44302 .58423 Mdot
.30466 .53253 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48497 .61166 Mdot
.45213 .59774 Mdot
.34858 .55403 Mdot
.05064 .4339 Mdot
.67802 .38774 Mdot
.52012 .52045 Mdot
.39232 .53905 Mdot
.11504 .44667 Mdot
.67984 .34906 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47916 .6092 Mdot
.43368 .58993 Mdot
.29157 .53021 Mdot
.91883 .38767 Mdot
.66263 .4597 Mdot
.6101 .58556 Mdot
.70984 .06165 Mdot
.04076 .20452 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.53112 .0132 Mdot
.59887 .04187 Mdot
.80555 .12774 Mdot
.23657 .26639 Mdot
.42971 .11937 Mdot
.52082 .0563 Mdot
.64306 .07555 Mdot
.95213 .19102 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .00291 Mdot
.52183 .00926 Mdot
.56944 .02943 Mdot
.71795 .09178 Mdot
.10036 .23634 Mdot
.34201 .14935 Mdot
.38373 .02578 Mdot
.26615 .54536 Mdot
.91106 .39858 Mdot
.68255 .4768 Mdot
.49787 .61713 Mdot
.49322 .61516 Mdot
.47841 .60888 Mdot
.43132 .58893 Mdot
.28437 .52721 Mdot
.90423 .3831 Mdot
.65923 .46662 Mdot
.61519 .59081 Mdot
.72923 .07048 Mdot
.07997 .21677 Mdot
.31574 .14572 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50244 .00103 Mdot
.50777 .00329 Mdot
.52474 .01049 Mdot
.57866 .03333 Mdot
.74584 .10332 Mdot
.15167 .25082 Mdot
.3629 .13055 Mdot
.39298 .01859 Mdot
.27437 .54473 Mdot
.91981 .39891 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50707 .003 Mdot
.52253 .00955 Mdot
.57168 .03037 Mdot
.72474 .0946 Mdot
.11354 .24029 Mdot
.34611 .14374 Mdot
.38217 .02229 Mdot
.49834 .61733 Mdot
.49473 .6158 Mdot
.4832 .61091 Mdot
.44651 .59536 Mdot
.3311 .5467 Mdot
.00728 .4179 Mdot
.67255 .41116 Mdot
.54883 .54157 Mdot
.49721 .58613 Mdot
.44142 .58355 Mdot
.29972 .53046 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49407 .61552 Mdot
.4811 .61002 Mdot
.43985 .59254 Mdot
.31051 .5381 Mdot
.95949 .40109 Mdot
.66858 .43824 Mdot
.58584 .5669 Mdot
.6257 .02464 Mdot
.83512 .12943 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60957 Mdot
.4365 .59112 Mdot
.30022 .53381 Mdot
.93699 .39355 Mdot
.66583 .45044 Mdot
.60077 .57783 Mdot
.67698 .0471 Mdot
.96724 .17939 Mdot
.30629 .20955 Mdot
.49757 .617 Mdot
.49224 .61475 Mdot
.47529 .60756 Mdot
.42143 .58475 Mdot
.25445 .51483 Mdot
.84883 .36735 Mdot
.63737 .48735 Mdot
.60733 .59946 Mdot
.72635 .07356 Mdot
.08147 .21948 Mdot
.31965 .14721 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51128 .00478 Mdot
.53591 .01523 Mdot
.61396 .04823 Mdot
.8487 .14508 Mdot
.27772 .26515 Mdot
.47162 .11984 Mdot
.62319 .09367 Mdot
.94162 .1968 Mdot
.50042 .00018 Mdot
.50133 .00057 Mdot
.50425 .0018 Mdot
.51354 .00574 Mdot
.5431 .01827 Mdot
.63653 .05774 Mdot
.91055 .16935 Mdot
.31179 .24798 Mdot
.49206 .11142 Mdot
.66044 .10406 Mdot
.03074 .22886 Mdot
.35522 .20054 Mdot
.49755 .61699 Mdot
.49219 .61472 Mdot
.47513 .60749 Mdot
.42092 .58453 Mdot
.25291 .5142 Mdot
.84621 .36668 Mdot
.63593 .48808 Mdot
.60565 .59932 Mdot
.72247 .0722 Mdot
.07446 .21754 Mdot
.31879 .151 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.51369 .0058 Mdot
.54358 .01848 Mdot
.63803 .05837 Mdot
.91452 .17088 Mdot
.31316 .24637 Mdot
.49161 .11029 Mdot
.65749 .10252 Mdot
.0229 .22584 Mdot
.35408 .20468 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51788 .00758 Mdot
.55692 .02413 Mdot
.67953 .07578 Mdot
.01786 .2091 Mdot
.32945 .19258 Mdot
.43145 .06304 Mdot
.43377 .00143 Mdot
.33958 .55982 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.47939 .60929 Mdot
.43442 .59024 Mdot
.29385 .53115 Mdot
.92354 .38917 Mdot
.66356 .45736 Mdot
.60797 .58367 Mdot
.70218 .05823 Mdot
.02443 .19916 Mdot
.31018 .1766 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48669 .61239 Mdot
.4576 .60006 Mdot
.36568 .56122 Mdot
.09536 .45096 Mdot
.6904 .36776 Mdot
.50764 .50508 Mdot
.33633 .51216 Mdot
.96056 .38579 Mdot
.64334 .42198 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .61119 Mdot
.44864 .59626 Mdot
.3377 .54947 Mdot
.02335 .42376 Mdot
.67411 .40219 Mdot
.49812 .61724 Mdot
.49402 .6155 Mdot
.48095 .60995 Mdot
.43936 .59233 Mdot
.309 .53747 Mdot
.95612 .39994 Mdot
.66823 .44011 Mdot
.58825 .56861 Mdot
.63398 .02826 Mdot
.85775 .1383 Mdot
.26761 .2533 Mdot
.49891 .61757 Mdot
.49653 .61656 Mdot
.48895 .61335 Mdot
.46481 .60311 Mdot
.38831 .57076 Mdot
.1577 .47551 Mdot
.72739 .35209 Mdot
.5334 .49815 Mdot
.38916 .52889 Mdot
.09177 .43424 Mdot
.66423 .3538 Mdot
.49926 .61772 Mdot
.49766 .61704 Mdot
.49253 .61487 Mdot
.47622 .60795 Mdot
.42435 .58598 Mdot
.26325 .51847 Mdot
.86424 .37143 Mdot
.64506 .48257 Mdot
.61456 .59919 Mdot
.74145 .07842 Mdot
.10673 .22575 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51224 .00519 Mdot
.53897 .01652 Mdot
.62358 .05229 Mdot
.87548 .15568 Mdot
.29568 .2597 Mdot
.48691 .11819 Mdot
.65855 .10607 Mdot
.03057 .22992 Mdot
.35702 .20176 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52442 .01035 Mdot
.57766 .0329 Mdot
.74283 .10208 Mdot
.14648 .24947 Mdot
.36015 .13205 Mdot
.39001 .01845 Mdot
.2677 .54244 Mdot
.90813 .39581 Mdot
.67884 .47632 Mdot
.49777 .61709 Mdot
.49288 .61501 Mdot
.47732 .60842 Mdot
.42785 .58746 Mdot
.27384 .52285 Mdot
.88376 .37695 Mdot
.65295 .47539 Mdot
.61785 .59634 Mdot
.7438 .07784 Mdot
.1083 .22527 Mdot
.3226 .13245 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50808 .00343 Mdot
.52574 .01091 Mdot
.58184 .03467 Mdot
.75537 .10725 Mdot
.1675 .25471 Mdot
.37226 .12655 Mdot
.40532 .02043 Mdot
.30458 .55578 Mdot
.97902 .41682 Mdot
.68484 .43622 Mdot
.49762 .61702 Mdot
.4924 .61481 Mdot
.4758 .60777 Mdot
.42304 .58543 Mdot
.25928 .51683 Mdot
.8572 .36953 Mdot
.64171 .48486 Mdot
.6118 .59955 Mdot
.73612 .07684 Mdot
.09827 .22382 Mdot
.3222 .1384 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47593 .60783 Mdot
.42345 .5856 Mdot
.26051 .51733 Mdot
.85935 .37011 Mdot
.64277 .48417 Mdot
.61274 .59948 Mdot
.73803 .07743 Mdot
.10137 .22456 Mdot
.32273 .13681 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .0034 Mdot
.52557 .01084 Mdot
.58131 .03445 Mdot
.75377 .10659 Mdot
.1649 .25409 Mdot
.37062 .12714 Mdot
.40294 .01998 Mdot
.29853 .55351 Mdot
.9664 .41277 Mdot
.6843 .44368 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.49131 .61435 Mdot
.47232 .6063 Mdot
.41203 .58077 Mdot
.2264 .50331 Mdot
.80466 .35738 Mdot
.60771 .49631 Mdot
.56026 .58871 Mdot
.60107 .02522 Mdot
.7835 .11275 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51796 .00761 Mdot
.55715 .02422 Mdot
.68024 .07607 Mdot
.01949 .20967 Mdot
.32958 .19165 Mdot
.43016 .06216 Mdot
.42933 .61752 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00822 Mdot
.56172 .02616 Mdot
.69434 .08196 Mdot
.05123 .22057 Mdot
.3326 .1739 Mdot
.40667 .04578 Mdot
.34863 .58216 Mdot
.09626 .46206 Mdot
.70814 .37816 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51542 .00654 Mdot
.54909 .02081 Mdot
.65524 .0656 Mdot
.95903 .18776 Mdot
.3236 .22532 Mdot
.47452 .09327 Mdot
.58738 .06975 Mdot
.82483 .14675 Mdot
.49848 .61739 Mdot
.49517 .61598 Mdot
.4846 .6115 Mdot
.45097 .59725 Mdot
.34495 .55251 Mdot
.04143 .43045 Mdot
.67647 .39248 Mdot
.52521 .52455 Mdot
.41161 .54782 Mdot
.17213 .47003 Mdot
.72193 .33979 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48044 .60974 Mdot
.43774 .59165 Mdot
.30401 .53539 Mdot
.94517 .39626 Mdot
.66696 .44609 Mdot
.49894 .61758 Mdot
.49661 .6166 Mdot
.48919 .61345 Mdot
.46557 .60344 Mdot
.39071 .57177 Mdot
.16448 .47822 Mdot
.73317 .35147 Mdot
.53926 .49819 Mdot
.40363 .53421 Mdot
.13213 .45024 Mdot
.68443 .34134 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51797 .00762 Mdot
.5572 .02425 Mdot
.6804 .07614 Mdot
.01986 .2098 Mdot
.32961 .19144 Mdot
.42987 .06197 Mdot
.42832 .61707 Mdot
.32285 .55285 Mdot
.00322 .42049 Mdot
.49831 .61732 Mdot
.4946 .61574 Mdot
.4828 .61074 Mdot
.44526 .59483 Mdot
.32721 .54508 Mdot
.99798 .41456 Mdot
.67178 .41643 Mdot
.55605 .54651 Mdot
.52266 .5974 Mdot
.52316 .0003 Mdot
.55826 .0217 Mdot
.5004 .00017 Mdot
.50126 .00053 Mdot
.50402 .0017 Mdot
.51279 .00542 Mdot
.54074 .01727 Mdot
.62913 .05463 Mdot
.89064 .16163 Mdot
.30359 .25522 Mdot
.49121 .11596 Mdot
.66565 .10781 Mdot
.04606 .23511 Mdot
.35835 .193 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00136 Mdot
.51025 .00434 Mdot
.53263 .01384 Mdot
.60363 .04388 Mdot
.8193 .1333 Mdot
.25144 .26707 Mdot
.44485 .11953 Mdot
.55717 .06942 Mdot
.75343 .12129 Mdot
.18836 .2688 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50374 .00159 Mdot
.51192 .00505 Mdot
.53795 .01609 Mdot
.62036 .05094 Mdot
.8666 .15218 Mdot
.29032 .26187 Mdot
.48292 .11903 Mdot
.64995 .10323 Mdot
.01006 .22257 Mdot
.3551 .21324 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50715 .00303 Mdot
.52278 .00966 Mdot
.57247 .03071 Mdot
.72714 .09559 Mdot
.11808 .24162 Mdot
.34771 .14192 Mdot
.3822 .02132 Mdot
.2557 .53985 Mdot
.89062 .3924 Mdot
.67699 .48601 Mdot
.49865 .61746 Mdot
.49569 .61621 Mdot
.48628 .61222 Mdot
.45631 .59951 Mdot
.36164 .55952 Mdot
.0846 .44681 Mdot
.68655 .37203 Mdot
.50851 .508 Mdot
.34324 .51589 Mdot
.97904 .39295 Mdot
.64619 .41232 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50263 .00112 Mdot
.50839 .00356 Mdot
.52672 .01133 Mdot
.58493 .03598 Mdot
.76458 .11103 Mdot
.18196 .25795 Mdot
.38209 .12369 Mdot
.4211 .02411 Mdot
.34656 .57196 Mdot
.49964 .61788 Mdot
.49884 .61754 Mdot
.4963 .61646 Mdot
.4882 .61303 Mdot
.46241 .6021 Mdot
.38077 .56758 Mdot
.13655 .4671 Mdot
.71173 .35548 Mdot
.51876 .49878 Mdot
.35387 .51613 Mdot
.99932 .39891 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53635 .01541 Mdot
.61533 .04881 Mdot
.85255 .14661 Mdot
.28064 .26457 Mdot
.47441 .11975 Mdot
.62995 .09613 Mdot
.95947 .20366 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52304 .00977 Mdot
.57327 .03105 Mdot
.72958 .0966 Mdot
.12266 .24294 Mdot
.34943 .14015 Mdot
.38256 .02047 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51554 .00659 Mdot
.54947 .02097 Mdot
.65641 .06609 Mdot
.96198 .18885 Mdot
.32404 .22377 Mdot
.47274 .0919 Mdot
.58075 .06675 Mdot
.80475 .13844 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.4755 .60765 Mdot
.4221 .58503 Mdot
.25645 .51566 Mdot
.85226 .36823 Mdot
.6392 .48635 Mdot
.60932 .59957 Mdot
.73083 .07509 Mdot
.08934 .22157 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50451 .00191 Mdot
.51435 .00609 Mdot
.5457 .01937 Mdot
.64466 .06116 Mdot
.93195 .17755 Mdot
.31823 .23873 Mdot
.48738 .10454 Mdot
.63762 .09285 Mdot
.96952 .20512 Mdot
.49983 .61796 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49441 .61567 Mdot
.4822 .61049 Mdot
.44335 .59402 Mdot
.32131 .54261 Mdot
.98411 .40963 Mdot
.6707 .42434 Mdot
.567 .55394 Mdot
.56086 .61424 Mdot
.50007 3e-05 Mdot
.50022 .0001 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52317 .00983 Mdot
.5737 .03123 Mdot
.73088 .09714 Mdot
.12507 .24362 Mdot
.35038 .13925 Mdot
.38288 .02009 Mdot
.25512 .53908 Mdot
.49935 .61776 Mdot
.49793 .61716 Mdot
.4934 .61524 Mdot
.47898 .60912 Mdot
.43313 .5897 Mdot
.2899 .52951 Mdot
.9154 .38658 Mdot
.66191 .46137 Mdot
.6115 .58688 Mdot
.715 .06397 Mdot
.05149 .20796 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48652 .61232 Mdot
.45709 .59984 Mdot
.36407 .56054 Mdot
.09105 .4493 Mdot
.68879 .36942 Mdot
.50781 .50618 Mdot
.33855 .51342 Mdot
.96655 .38813 Mdot
.64436 .41891 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52314 .00981 Mdot
.57361 .03119 Mdot
.73061 .09703 Mdot
.12457 .24348 Mdot
.35018 .13943 Mdot
.3828 .02016 Mdot
.25509 .5391 Mdot
.88877 .39163 Mdot
.67604 .48656 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.503 .00127 Mdot
.50955 .00405 Mdot
.53043 .0129 Mdot
.59668 .04094 Mdot
.7992 .12516 Mdot
.22914 .26571 Mdot
.42239 .11943 Mdot
.50377 .0503 Mdot
.59082 .0538 Mdot
.80682 .1335 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50478 .00203 Mdot
.51523 .00646 Mdot
.54849 .02056 Mdot
.65338 .06482 Mdot
.95434 .186 Mdot
.32285 .22775 Mdot
.47722 .0954 Mdot
.59752 .07435 Mdot
.85511 .1592 Mdot
.30124 .27572 Mdot
.49756 .617 Mdot
.49223 .61474 Mdot
.47526 .60754 Mdot
.42133 .5847 Mdot
.25414 .51471 Mdot
.8483 .36721 Mdot
.63708 .4875 Mdot
.607 .59944 Mdot
.72559 .07329 Mdot
.08012 .21911 Mdot
.31948 .14793 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48938 .61353 Mdot
.46618 .6037 Mdot
.39264 .57258 Mdot
.17001 .48044 Mdot
.73816 .35114 Mdot
.54439 .49828 Mdot
.41634 .5389 Mdot
.16851 .46487 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.4937 .61536 Mdot
.47992 .60952 Mdot
.43609 .59095 Mdot
.29896 .53328 Mdot
.9343 .39266 Mdot
.66542 .45186 Mdot
.60234 .57905 Mdot
.68241 .04949 Mdot
.98001 .18392 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50751 .00318 Mdot
.52392 .01014 Mdot
.57609 .03224 Mdot
.73809 .10012 Mdot
.13816 .24726 Mdot
.35605 .13466 Mdot
.38628 .01868 Mdot
.26008 .54004 Mdot
.89562 .39279 Mdot
.67675 .48276 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00255 Mdot
.51912 .00811 Mdot
.56086 .02579 Mdot
.69167 .08085 Mdot
.04535 .21859 Mdot
.33193 .17711 Mdot
.41071 .04869 Mdot
.36246 .58822 Mdot
.13265 .476 Mdot
.72611 .36678 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50331 .0014 Mdot
.51054 .00447 Mdot
.53358 .01424 Mdot
.60662 .04514 Mdot
.82789 .13675 Mdot
.25987 .26698 Mdot
.45358 .11972 Mdot
.57864 .07729 Mdot
.81691 .14726 Mdot
.27313 .28196 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53223 .01367 Mdot
.60236 .04334 Mdot
.81566 .13183 Mdot
.24767 .26699 Mdot
.44096 .11946 Mdot
.54772 .06598 Mdot
.72499 .10956 Mdot
.13806 .25529 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48534 .61182 Mdot
.45334 .59825 Mdot
.35233 .55561 Mdot
.06027 .43753 Mdot
.67995 .38298 Mdot
.5156 .51646 Mdot
.37462 .5309 Mdot
.06442 .42632 Mdot
.66021 .36822 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.523 .00975 Mdot
.57317 .03101 Mdot
.72928 .09648 Mdot
.1221 .24277 Mdot
.34921 .14036 Mdot
.3825 .02057 Mdot
.25511 .5393 Mdot
.88911 .39183 Mdot
.67631 .48652 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49234 .61478 Mdot
.47558 .60768 Mdot
.42235 .58513 Mdot
.25721 .51597 Mdot
.85358 .36858 Mdot
.63988 .48596 Mdot
.61002 .59958 Mdot
.73236 .07561 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48082 .6099 Mdot
.43896 .59216 Mdot
.30777 .53695 Mdot
.9534 .39902 Mdot
.66794 .44161 Mdot
.59017 .56997 Mdot
.64053 .03113 Mdot
.87534 .14512 Mdot
.2786 .24923 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50493 .00209 Mdot
.51572 .00666 Mdot
.55004 .02121 Mdot
.65818 .06684 Mdot
.96641 .1905 Mdot
.32465 .22141 Mdot
.46995 .0898 Mdot
.57044 .06211 Mdot
.77317 .12529 Mdot
.21211 .27128 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49276 .61496 Mdot
.47693 .60825 Mdot
.42661 .58694 Mdot
.27006 .52128 Mdot
.87668 .37491 Mdot
.65031 .47813 Mdot
.61736 .59767 Mdot
.74494 .07884 Mdot
.11112 .22631 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52355 .00998 Mdot
.57489 .03173 Mdot
.73448 .09863 Mdot
.13167 .24548 Mdot
.35312 .13686 Mdot
.38423 .01922 Mdot
.25659 .53915 Mdot
.89043 .39173 Mdot
.67594 .48547 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50832 .00353 Mdot
.52649 .01123 Mdot
.58423 .03568 Mdot
.76249 .11017 Mdot
.17875 .25726 Mdot
.3798 .12426 Mdot
.41721 .02312 Mdot
.33597 .56782 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48961 .61363 Mdot
.4669 .604 Mdot
.39489 .57353 Mdot
.17642 .48302 Mdot
.74429 .35096 Mdot
.55073 .49841 Mdot
.43198 .54464 Mdot
.21428 .48349 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50468 .00199 Mdot
.51492 .00633 Mdot
.54751 .02014 Mdot
.6503 .06353 Mdot
.94649 .18306 Mdot
.32144 .23174 Mdot
.48132 .09881 Mdot
.61324 .08153 Mdot
.90104 .17787 Mdot
.3279 .26382 Mdot
.49987 .61798 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49565 .61619 Mdot
.48615 .61216 Mdot
.45589 .59933 Mdot
.3603 .55896 Mdot
.08106 .44545 Mdot
.68542 .37351 Mdot
.50912 .50907 Mdot
.34649 .51752 Mdot
.49741 .61693 Mdot
.49173 .61453 Mdot
.47366 .60687 Mdot
.41627 .58256 Mdot
.239 .50847 Mdot
.82357 .36128 Mdot
.62181 .49334 Mdot
.58545 .59556 Mdot
.6712 .05299 Mdot
.96701 .18282 Mdot
.31195 .21319 Mdot
.4977 .61706 Mdot
.49268 .61493 Mdot
.47667 .60814 Mdot
.42579 .58659 Mdot
.26759 .52026 Mdot
.87212 .37362 Mdot
.64848 .47982 Mdot
.61664 .59835 Mdot
.7445 .07902 Mdot
.11095 .22648 Mdot
.32413 .13175 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.5055 .00233 Mdot
.51754 .00744 Mdot
.55582 .02366 Mdot
.67614 .07436 Mdot
.00993 .2063 Mdot
.32884 .19709 Mdot
.43771 .06728 Mdot
.45551 .011 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00091 Mdot
.50687 .00291 Mdot
.5219 .00929 Mdot
.56967 .02952 Mdot
.71863 .09206 Mdot
.10169 .23675 Mdot
.34239 .14876 Mdot
.38347 .02538 Mdot
.26494 .54478 Mdot
.49909 .61765 Mdot
.4971 .61681 Mdot
.49077 .61412 Mdot
.47061 .60557 Mdot
.40661 .57848 Mdot
.21043 .49679 Mdot
.78286 .35378 Mdot
.58895 .49819 Mdot
.52162 .57642 Mdot
.48661 .5964 Mdot
.43156 .58401 Mdot
.49883 .61754 Mdot
.49627 .61645 Mdot
.4881 .61299 Mdot
.46211 .60197 Mdot
.37982 .56718 Mdot
.13391 .46605 Mdot
.71001 .35605 Mdot
.51734 .49896 Mdot
.35064 .51501 Mdot
.99137 .39599 Mdot
.64504 .40399 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47958 .60937 Mdot
.43502 .59049 Mdot
.29568 .53191 Mdot
.92736 .3904 Mdot
.66426 .45543 Mdot
.49791 .61715 Mdot
.49335 .61522 Mdot
.47882 .60905 Mdot
.43262 .58948 Mdot
.28835 .52887 Mdot
.91224 .38558 Mdot
.6612 .46288 Mdot
.61269 .58805 Mdot
.71944 .06598 Mdot
.06054 .21081 Mdot
.313 .15603 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52374 .01007 Mdot
.57551 .032 Mdot
.73635 .0994 Mdot
.13505 .24641 Mdot
.35462 .1357 Mdot
.38521 .0189 Mdot
.25815 .53951 Mdot
.89267 .39216 Mdot
.67626 .48429 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49084 .61415 Mdot
.47083 .60567 Mdot
.40731 .57878 Mdot
.21249 .49763 Mdot
.78554 .35416 Mdot
.59139 .49804 Mdot
.52692 .57819 Mdot
.50262 .60302 Mdot
.48226 .60545 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.50231 .00098 Mdot
.50735 .00312 Mdot
.5234 .00992 Mdot
.57444 .03154 Mdot
.73312 .09807 Mdot
.12918 .24478 Mdot
.35206 .13775 Mdot
.38363 .01951 Mdot
.2558 .53903 Mdot
.88939 .39158 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49495 .61589 Mdot
.4839 .61121 Mdot
.44874 .5963 Mdot
.33801 .5496 Mdot
.02412 .42404 Mdot
.67419 .40177 Mdot
.53643 .53289 Mdot
.45282 .56636 Mdot
.29948 .52326 Mdot
.49872 .61749 Mdot
.49591 .6163 Mdot
.48696 .6125 Mdot
.45847 .60043 Mdot
.36839 .56236 Mdot
.10263 .45379 Mdot
.69338 .3651 Mdot
.50791 .50341 Mdot
.33429 .51073 Mdot
.95465 .3834 Mdot
.64212 .42488 Mdot
.49791 .61715 Mdot
.49336 .61522 Mdot
.47883 .60906 Mdot
.43265 .58949 Mdot
.28844 .52891 Mdot
.91242 .38564 Mdot
.66124 .4628 Mdot
.61262 .58799 Mdot
.71919 .06586 Mdot
.06003 .21065 Mdot
.31294 .15631 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00147 Mdot
.51101 .00467 Mdot
.53506 .01486 Mdot
.61127 .0471 Mdot
.84113 .14206 Mdot
.27164 .26607 Mdot
.46562 .11989 Mdot
.60844 .08827 Mdot
.90162 .18119 Mdot
.33315 .2667 Mdot
.50074 .00031 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52402 .01018 Mdot
.57638 .03236 Mdot
.73897 .10049 Mdot
.13972 .24768 Mdot
.35679 .13416 Mdot
.38688 .0186 Mdot
.26123 .54038 Mdot
.89744 .3932 Mdot
.67706 .48183 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47947 .60933 Mdot
.43468 .59035 Mdot
.29465 .53149 Mdot
.92521 .38971 Mdot
.66387 .45652 Mdot
.60716 .58298 Mdot
.69931 .05695 Mdot
.01819 .19708 Mdot
.30984 .18025 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48978 .6137 Mdot
.46745 .60423 Mdot
.39665 .57427 Mdot
.18148 .48506 Mdot
.74937 .35097 Mdot
.55599 .49852 Mdot
.44486 .54935 Mdot
.25267 .49925 Mdot
.82178 .35173 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47318 .60666 Mdot
.41475 .58192 Mdot
.23447 .50662 Mdot
.8166 .35977 Mdot
.61686 .49459 Mdot
.57707 .59344 Mdot
.64842 .0441 Mdot
.91151 .1626 Mdot
.49742 .61694 Mdot
.49178 .61455 Mdot
.47381 .60693 Mdot
.41672 .58275 Mdot
.24034 .50902 Mdot
.82566 .36175 Mdot
.62325 .49293 Mdot
.58777 .59611 Mdot
.67738 .05538 Mdot
.9813 .18783 Mdot
.3132 .20513 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50353 .0015 Mdot
.51124 .00477 Mdot
.53581 .01518 Mdot
.61365 .0481 Mdot
.84783 .14473 Mdot
.27704 .26527 Mdot
.47097 .11985 Mdot
.62158 .09309 Mdot
.93735 .19515 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50619 .00262 Mdot
.51971 .00836 Mdot
.56273 .02658 Mdot
.69741 .08324 Mdot
.05792 .2228 Mdot
.33345 .17029 Mdot
.40232 .04257 Mdot
.33371 .57563 Mdot
.05863 .44803 Mdot
.69758 .39489 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50333 .00141 Mdot
.51061 .0045 Mdot
.53379 .01432 Mdot
.60726 .04541 Mdot
.82973 .13749 Mdot
.26159 .26691 Mdot
.45536 .11975 Mdot
.58303 .07891 Mdot
.82968 .15244 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50584 .00248 Mdot
.51862 .00789 Mdot
.55926 .02512 Mdot
.68674 .07879 Mdot
.03434 .21483 Mdot
.33083 .18324 Mdot
.41872 .05432 Mdot
.38993 .60024 Mdot
.5001 4e-05 Mdot
.50032 .00013 Mdot
.501 .00043 Mdot
.5032 .00136 Mdot
.5102 .00433 Mdot
.53249 .01378 Mdot
.60318 .04369 Mdot
.81803 .13278 Mdot
.25013 .26705 Mdot
.4435 .11951 Mdot
.55388 .06822 Mdot
.74356 .11723 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50514 .00218 Mdot
.51638 .00694 Mdot
.55214 .0221 Mdot
.66471 .06957 Mdot
.98254 .19643 Mdot
.32651 .21258 Mdot
.45881 .08176 Mdot
.53 .044 Mdot
.64591 .07164 Mdot
.9513 .18874 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.4203 .58427 Mdot
.25106 .51343 Mdot
.84309 .36589 Mdot
.63416 .48891 Mdot
.60349 .59907 Mdot
.71733 .07036 Mdot
.06489 .21481 Mdot
.31779 .1563 Mdot
.50081 .00035 Mdot
.5026 .0011 Mdot
.50827 .00351 Mdot
.52634 .01117 Mdot
.58374 .03548 Mdot
.76104 .10958 Mdot
.1765 .25677 Mdot
.37823 .12468 Mdot
.41462 .02249 Mdot
.32899 .56511 Mdot
.03343 .43537 Mdot
.68809 .4046 Mdot
.4986 .61744 Mdot
.49553 .61614 Mdot
.48576 .612 Mdot
.45466 .59881 Mdot
.35646 .55735 Mdot
.07098 .4416 Mdot
.68252 .37795 Mdot
.51166 .51244 Mdot
.35828 .52324 Mdot
.01931 .40854 Mdot
.65145 .39069 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50512 .00217 Mdot
.51631 .00692 Mdot
.55192 .02201 Mdot
.66402 .06929 Mdot
.98087 .19582 Mdot
.32634 .21351 Mdot
.46002 .08262 Mdot
.53437 .04595 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50573 .00243 Mdot
.51827 .00775 Mdot
.55815 .02465 Mdot
.68332 .07736 Mdot
.02659 .21215 Mdot
.33015 .18762 Mdot
.42463 .05839 Mdot
.41024 .60914 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50655 .00278 Mdot
.52085 .00884 Mdot
.56635 .02812 Mdot
.70852 .08787 Mdot
.08136 .23043 Mdot
.33741 .15824 Mdot
.38982 .0324 Mdot
.28986 .55626 Mdot
.95862 .41331 Mdot
.68875 .45124 Mdot
.49889 .61756 Mdot
.49645 .61653 Mdot
.48868 .61323 Mdot
.46396 .60275 Mdot
.38562 .56962 Mdot
.15012 .47248 Mdot
.72137 .35305 Mdot
.5275 .49822 Mdot
.37468 .52358 Mdot
.0527 .41904 Mdot
.65311 .37107 Mdot
.49843 .61737 Mdot
.49501 .61592 Mdot
.4841 .61129 Mdot
.44937 .59657 Mdot
.33996 .55042 Mdot
.02895 .42582 Mdot
.67476 .39913 Mdot
.5331 .53049 Mdot
.44075 .56096 Mdot
.26157 .50729 Mdot
.84428 .36014 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50663 .00281 Mdot
.52112 .00896 Mdot
.5672 .02848 Mdot
.7111 .08894 Mdot
.08663 .23209 Mdot
.33854 .15569 Mdot
.38772 .03039 Mdot
.28211 .55276 Mdot
.9426 .40821 Mdot
.68734 .46027 Mdot
.49993 .618 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.4923 .61477 Mdot
.47546 .60763 Mdot
.42198 .58498 Mdot
.25608 .51551 Mdot
.85163 .36807 Mdot
.63887 .48654 Mdot
.60897 .59955 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47506 .60746 Mdot
.42069 .58443 Mdot
.25223 .51392 Mdot
.84505 .36639 Mdot
.63528 .48839 Mdot
.60487 .59924 Mdot
.72063 .07154 Mdot
.07107 .21658 Mdot
.31841 .15286 Mdot
.49789 .61714 Mdot
.49328 .61519 Mdot
.4786 .60896 Mdot
.43191 .58918 Mdot
.28617 .52796 Mdot
.90783 .38421 Mdot
.66015 .46496 Mdot
.61416 .58961 Mdot
.72509 .06856 Mdot
.07183 .2143 Mdot
.31445 .14995 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48345 .61101 Mdot
.4473 .5957 Mdot
.33355 .54773 Mdot
.01321 .42005 Mdot
.67308 .40782 Mdot
.54433 .53847 Mdot
.48124 .57904 Mdot
.39006 .56168 Mdot
.14677 .46767 Mdot
.50006 2e-05 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51918 .00813 Mdot
.56105 .02587 Mdot
.69226 .08109 Mdot
.04666 .21903 Mdot
.33207 .17639 Mdot
.40979 .04803 Mdot
.35933 .58685 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50698 .00296 Mdot
.52225 .00944 Mdot
.57078 .03 Mdot
.72203 .09347 Mdot
.10833 .23875 Mdot
.3444 .1459 Mdot
.3825 .02355 Mdot
.25994 .54228 Mdot
.8991 .39503 Mdot
.67968 .48242 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.51548 .00656 Mdot
.54929 .02089 Mdot
.65586 .06586 Mdot
.96059 .18834 Mdot
.32384 .2245 Mdot
.47359 .09255 Mdot
.58389 .06817 Mdot
.8143 .1424 Mdot
.26421 .27806 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51853 .00786 Mdot
.55898 .025 Mdot
.68588 .07843 Mdot
.03241 .21417 Mdot
.33066 .18433 Mdot
.42017 .05533 Mdot
.39491 .60242 Mdot
.22322 .51193 Mdot
.81618 .36646 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51442 .00611 Mdot
.54591 .01946 Mdot
.64531 .06143 Mdot
.93363 .17819 Mdot
.31865 .23795 Mdot
.48679 .10392 Mdot
.63515 .09169 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49206 .61467 Mdot
.47469 .6073 Mdot
.41953 .58394 Mdot
.24874 .51248 Mdot
.83923 .36494 Mdot
.6319 .4899 Mdot
.60054 .59865 Mdot
.71016 .06775 Mdot
.05107 .2107 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50704 .00299 Mdot
.52244 .00951 Mdot
.57137 .03024 Mdot
.7238 .09421 Mdot
.11175 .23976 Mdot
.34551 .14447 Mdot
.38224 .0227 Mdot
.25802 .54126 Mdot
.89536 .3939 Mdot
.6786 .48407 Mdot
.49887 .61756 Mdot
.4964 .61651 Mdot
.48853 .61317 Mdot
.46348 .60255 Mdot
.38414 .569 Mdot
.14595 .47083 Mdot
.71826 .3537 Mdot
.52456 .49832 Mdot
.36756 .521 Mdot
.03406 .41192 Mdot
.64985 .38058 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50824 .00349 Mdot
.52625 .01113 Mdot
.58346 .03536 Mdot
.76019 .10923 Mdot
.17516 .25647 Mdot
.37731 .12494 Mdot
.41313 .02213 Mdot
.32501 .56357 Mdot
.02419 .43211 Mdot
.68722 .40978 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00207 Mdot
.51552 .00658 Mdot
.54942 .02095 Mdot
.65626 .06603 Mdot
.9616 .18871 Mdot
.32399 .22397 Mdot
.47297 .09208 Mdot
.58161 .06714 Mdot
.80737 .13953 Mdot
.25652 .27759 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.47939 .6093 Mdot
.43443 .59025 Mdot
.29388 .53117 Mdot
.92361 .38919 Mdot
.66358 .45733 Mdot
.60794 .58365 Mdot
.70207 .05818 Mdot
.0242 .19908 Mdot
.31017 .17674 Mdot
.49871 .61749 Mdot
.4959 .61629 Mdot
.48693 .61249 Mdot
.45839 .60039 Mdot
.36814 .56226 Mdot
.10195 .45352 Mdot
.69309 .36534 Mdot
.50785 .50355 Mdot
.33439 .51083 Mdot
.95498 .38354 Mdot
.6422 .42473 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52657 .01127 Mdot
.58448 .03579 Mdot
.76323 .11048 Mdot
.1799 .25751 Mdot
.38061 .12405 Mdot
.41858 .02346 Mdot
.33967 .56927 Mdot
.05894 .44453 Mdot
.6918 .39113 Mdot
.5001 4e-05 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50309 .00131 Mdot
.50986 .00418 Mdot
.5314 .01331 Mdot
.59975 .04224 Mdot
.8081 .12877 Mdot
.23946 .26659 Mdot
.43261 .11937 Mdot
.52766 .05875 Mdot
.66399 .08426 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51419 .00602 Mdot
.54518 .01915 Mdot
.64304 .06048 Mdot
.92771 .17594 Mdot
.31713 .24067 Mdot
.48873 .10606 Mdot
.64346 .09562 Mdot
.98539 .21133 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.5037 .00157 Mdot
.5118 .005 Mdot
.53759 .01594 Mdot
.61922 .05046 Mdot
.86343 .15093 Mdot
.28827 .26256 Mdot
.48123 .11926 Mdot
.64611 .1019 Mdot
.00064 .21911 Mdot
.35421 .21852 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47906 .60915 Mdot
.43336 .58979 Mdot
.2906 .5298 Mdot
.91683 .38703 Mdot
.66222 .46067 Mdot
.61093 .58634 Mdot
.71289 .06301 Mdot
.04712 .20656 Mdot
.3117 .16352 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48774 .61284 Mdot
.46097 .60149 Mdot
.37622 .56566 Mdot
.12398 .46214 Mdot
.70401 .35848 Mdot
.51287 .49991 Mdot
.34103 .51183 Mdot
.96845 .38777 Mdot
.64289 .41682 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.4799 .60951 Mdot
.43603 .59092 Mdot
.29878 .53321 Mdot
.93392 .39254 Mdot
.66536 .45205 Mdot
.60255 .57922 Mdot
.68315 .04981 Mdot
.98172 .18453 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50545 .00231 Mdot
.51735 .00736 Mdot
.55522 .02341 Mdot
.67427 .07358 Mdot
.00553 .20473 Mdot
.3285 .1996 Mdot
.44119 .06964 Mdot
.46765 .01635 Mdot
.44591 .6046 Mdot
.34459 .55542 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50648 .00275 Mdot
.52065 .00875 Mdot
.5657 .02784 Mdot
.70651 .08703 Mdot
.07721 .2291 Mdot
.33658 .1603 Mdot
.39168 .03405 Mdot
.29655 .55924 Mdot
.97284 .41797 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48602 .61211 Mdot
.45548 .59916 Mdot
.35903 .55843 Mdot
.07772 .44417 Mdot
.6844 .37495 Mdot
.50983 .51014 Mdot
.34999 .51925 Mdot
.99701 .39988 Mdot
.64851 .40265 Mdot
.49886 .61755 Mdot
.49637 .61649 Mdot
.48843 .61313 Mdot
.46314 .60241 Mdot
.38305 .56854 Mdot
.14291 .46962 Mdot
.71607 .35423 Mdot
.52256 .49844 Mdot
.36277 .51928 Mdot
.02171 .40725 Mdot
.64819 .38719 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52305 .00977 Mdot
.57331 .03106 Mdot
.72969 .09665 Mdot
.12285 .24299 Mdot
.3495 .14008 Mdot
.38258 .02044 Mdot
.25507 .53923 Mdot
.88895 .39176 Mdot
.49783 .61711 Mdot
.49307 .6151 Mdot
.47793 .60867 Mdot
.42977 .58827 Mdot
.27967 .52526 Mdot
.89496 .38027 Mdot
.65662 .47073 Mdot
.61709 .5936 Mdot
.73778 .07459 Mdot
.0965 .2217 Mdot
.31918 .13762 Mdot
.49906 .61763 Mdot
.497 .61676 Mdot
.49043 .61398 Mdot
.46953 .60511 Mdot
.40319 .57704 Mdot
.20044 .49272 Mdot
.77043 .35228 Mdot
.5772 .49861 Mdot
.49526 .5674 Mdot
.40623 .56301 Mdot
.18454 .48102 Mdot
.49996 .61802 Mdot
.49988 .61798 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48746 .61272 Mdot
.46007 .6011 Mdot
.3734 .56447 Mdot
.11622 .45909 Mdot
.6998 .36067 Mdot
.51034 .50094 Mdot
.50048 .0002 Mdot
.50151 .00064 Mdot
.50482 .00205 Mdot
.51537 .00652 Mdot
.54894 .02074 Mdot
.65475 .0654 Mdot
.95781 .1873 Mdot
.32341 .22596 Mdot
.47524 .09383 Mdot
.59007 .07097 Mdot
.8329 .15008 Mdot
.2828 .27806 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53218 .01364 Mdot
.60219 .04327 Mdot
.81517 .13163 Mdot
.24715 .26698 Mdot
.44043 .11946 Mdot
.54644 .06551 Mdot
.72111 .10795 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52504 .01062 Mdot
.57963 .03374 Mdot
.74874 .10452 Mdot
.15658 .25206 Mdot
.36565 .12921 Mdot
.39627 .01893 Mdot
.2821 .54747 Mdot
.93403 .40291 Mdot
.68211 .46234 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51224 .00519 Mdot
.53899 .01653 Mdot
.62365 .05232 Mdot
.87567 .15576 Mdot
.29579 .25965 Mdot
.48699 .11817 Mdot
.6587 .10612 Mdot
.03091 .23004 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51728 .00733 Mdot
.55499 .02331 Mdot
.67357 .07328 Mdot
.00387 .20414 Mdot
.32837 .20055 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50358 .00152 Mdot
.51142 .00484 Mdot
.53637 .01542 Mdot
.61541 .04885 Mdot
.85279 .14671 Mdot
.28082 .26453 Mdot
.47458 .11975 Mdot
.63036 .09628 Mdot
.96054 .20406 Mdot
.49831 .61732 Mdot
.49462 .61575 Mdot
.48286 .61076 Mdot
.44543 .5949 Mdot
.32773 .54529 Mdot
.99921 .415 Mdot
.67188 .41573 Mdot
.55508 .54585 Mdot
.51928 .5959 Mdot
.51231 .61373 Mdot
.5238 .0071 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49294 .61504 Mdot
.47749 .60849 Mdot
.42841 .5877 Mdot
.27552 .52354 Mdot
.88696 .37789 Mdot
.65406 .47409 Mdot
.61782 .59563 Mdot
.74259 .07711 Mdot
.49868 .61747 Mdot
.49578 .61625 Mdot
.48657 .61234 Mdot
.45722 .5999 Mdot
.36448 .56072 Mdot
.09216 .44973 Mdot
.68919 .36899 Mdot
.50774 .50589 Mdot
.33791 .51307 Mdot
.96484 .38746 Mdot
.64408 .4198 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50368 .00156 Mdot
.51171 .00497 Mdot
.53729 .01581 Mdot
.6183 .05007 Mdot
.86087 .14992 Mdot
.28655 .26308 Mdot
.47977 .11941 Mdot
.64271 .10071 Mdot
.99217 .21598 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.52048 .00868 Mdot
.56517 .02762 Mdot
.70491 .08636 Mdot
.07387 .22803 Mdot
.33596 .16198 Mdot
.39329 .03544 Mdot
.3023 .56179 Mdot
.98534 .42214 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52 .00848 Mdot
.56363 .02697 Mdot
.70019 .0844 Mdot
.06388 .22477 Mdot
.3343 .16713 Mdot
.39871 .03981 Mdot
.32124 .57015 Mdot
.02855 .43714 Mdot
.69327 .41082 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50457 .00194 Mdot
.51455 .00617 Mdot
.54633 .01964 Mdot
.64661 .06198 Mdot
.93701 .17947 Mdot
.31944 .23636 Mdot
.48551 .10264 Mdot
.62988 .08923 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49795 .61717 Mdot
.49348 .61527 Mdot
.47922 .60922 Mdot
.43389 .59002 Mdot
.29221 .53047 Mdot
.92015 .38809 Mdot
.6629 .45904 Mdot
.60952 .58504 Mdot
.70775 .06071 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41914 .58378 Mdot
.24758 .512 Mdot
.83731 .36447 Mdot
.63074 .49037 Mdot
.59896 .59839 Mdot
.70625 .0663 Mdot
.0433 .20831 Mdot
.49996 .61802 Mdot
.49989 .61799 Mdot
.49964 .61788 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48832 .61308 Mdot
.46281 .60227 Mdot
.38203 .56811 Mdot
.14005 .46848 Mdot
.71408 .35477 Mdot
.52078 .49857 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50338 .00143 Mdot
.51075 .00456 Mdot
.53425 .01452 Mdot
.60872 .04603 Mdot
.83389 .13916 Mdot
.26539 .26668 Mdot
.45927 .11982 Mdot
.59271 .08247 Mdot
.8575 .16364 Mdot
.3086 .2788 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51814 .00769 Mdot
.55774 .02447 Mdot
.68205 .07683 Mdot
.02366 .21113 Mdot
.32991 .18927 Mdot
.4269 .05994 Mdot
.41805 .61256 Mdot
.29164 .53991 Mdot
.93461 .39738 Mdot
.49796 .61717 Mdot
.49351 .61528 Mdot
.47933 .60927 Mdot
.43424 .59016 Mdot
.29328 .53092 Mdot
.92237 .3888 Mdot
.66334 .45794 Mdot
.60852 .58415 Mdot
.70415 .0591 Mdot
.02867 .20057 Mdot
.31042 .17413 Mdot
.49848 .61739 Mdot
.49515 .61598 Mdot
.48455 .61148 Mdot
.4508 .59718 Mdot
.34441 .55228 Mdot
.04007 .42994 Mdot
.67626 .39319 Mdot
.52601 .52518 Mdot
.41461 .54919 Mdot
.18119 .47377 Mdot
.731 .3398 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47685 .60822 Mdot
.42638 .58684 Mdot
.26936 .52099 Mdot
.87537 .37454 Mdot
.6498 .47862 Mdot
.61719 .59788 Mdot
.74491 .07893 Mdot
.11123 .2264 Mdot
.32397 .13148 Mdot
.50042 .00018 Mdot
.50133 .00057 Mdot
.50425 .0018 Mdot
.51355 .00575 Mdot
.54315 .01829 Mdot
.63667 .0578 Mdot
.91092 .16949 Mdot
.31192 .24783 Mdot
.49203 .11131 Mdot
.66019 .10393 Mdot
.03008 .2286 Mdot
.35511 .20088 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50489 .00207 Mdot
.51556 .0066 Mdot
.54955 .02101 Mdot
.65668 .06621 Mdot
.96266 .18911 Mdot
.32414 .22341 Mdot
.47232 .09158 Mdot
.5792 .06605 Mdot
.80003 .13648 Mdot
.2479 .2768 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50364 .00154 Mdot
.5116 .00492 Mdot
.53695 .01566 Mdot
.61721 .04961 Mdot
.85784 .14871 Mdot
.28446 .26367 Mdot
.47792 .11957 Mdot
.63836 .09916 Mdot
.98116 .21187 Mdot
.35216 .22929 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48815 .61301 Mdot
.46226 .60203 Mdot
.38027 .56737 Mdot
.13517 .46655 Mdot
.71082 .35577 Mdot
.51801 .49887 Mdot
.35215 .51553 Mdot
.99506 .39734 Mdot
.64538 .40192 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48371 .61113 Mdot
.44814 .59605 Mdot
.33616 .54883 Mdot
.01959 .42238 Mdot
.67371 .40427 Mdot
.53965 .53518 Mdot
.46444 .57155 Mdot
.33634 .53886 Mdot
.00378 .4125 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.50539 .00229 Mdot
.51719 .00729 Mdot
.55471 .02319 Mdot
.67269 .07291 Mdot
.00178 .20339 Mdot
.3282 .20174 Mdot
.44414 .07165 Mdot
.47798 .02092 Mdot
.47892 .00058 Mdot
.44831 .59912 Mdot
.49814 .61724 Mdot
.49406 .61552 Mdot
.48109 .61002 Mdot
.43982 .59253 Mdot
.31041 .53806 Mdot
.95927 .40102 Mdot
.66856 .43836 Mdot
.58599 .56701 Mdot
.62623 .02487 Mdot
.83658 .13 Mdot
.2512 .25625 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51465 .00621 Mdot
.54664 .01977 Mdot
.6476 .0624 Mdot
.93956 .18044 Mdot
.32002 .23514 Mdot
.48447 .10164 Mdot
.62567 .08727 Mdot
.9364 .19204 Mdot
.34001 .24944 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52165 .00918 Mdot
.56886 .02918 Mdot
.71619 .09105 Mdot
.09687 .23528 Mdot
.34106 .15091 Mdot
.38453 .02687 Mdot
.26959 .547 Mdot
.91773 .40057 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50766 .00325 Mdot
.52442 .01035 Mdot
.57765 .0329 Mdot
.74279 .10206 Mdot
.14641 .24945 Mdot
.36011 .13207 Mdot
.38997 .01845 Mdot
.26762 .54242 Mdot
.908 .39578 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50998 .00423 Mdot
.53177 .01347 Mdot
.60091 .04273 Mdot
.81148 .13014 Mdot
.24319 .26681 Mdot
.43639 .1194 Mdot
.53668 .06199 Mdot
.69152 .09569 Mdot
.06914 .23339 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50451 .00191 Mdot
.51436 .00609 Mdot
.54571 .01938 Mdot
.6447 .06118 Mdot
.93204 .17759 Mdot
.31825 .23869 Mdot
.48735 .10451 Mdot
.63749 .09279 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47645 .60805 Mdot
.42511 .5863 Mdot
.26553 .51941 Mdot
.86835 .37256 Mdot
.64689 .48116 Mdot
.61578 .59881 Mdot
.74341 .07888 Mdot
.10958 .2263 Mdot
.32406 .13255 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41914 .58378 Mdot
.24758 .512 Mdot
.83732 .36448 Mdot
.63075 .49037 Mdot
.59897 .5984 Mdot
.70627 .06631 Mdot
.04334 .20832 Mdot
.3162 .16864 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50522 .00222 Mdot
.51665 .00706 Mdot
.55299 .02246 Mdot
.66735 .07068 Mdot
.98898 .19877 Mdot
.32712 .20899 Mdot
.45402 .07843 Mdot
.51291 .0364 Mdot
.59115 .04835 Mdot
.79875 .12831 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50836 .00355 Mdot
.52664 .0113 Mdot
.5847 .03588 Mdot
.76391 .11075 Mdot
.18093 .25774 Mdot
.38135 .12387 Mdot
.41984 .02378 Mdot
.3431 .57061 Mdot
.06731 .44759 Mdot
.69354 .38703 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51646 .00698 Mdot
.5524 .02221 Mdot
.66552 .06991 Mdot
.98453 .19716 Mdot
.32671 .21148 Mdot
.45735 .08074 Mdot
.52477 .04167 Mdot
.6292 .06454 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50289 .00123 Mdot
.50922 .00391 Mdot
.52936 .01245 Mdot
.5933 .03952 Mdot
.78931 .12114 Mdot
.21681 .26421 Mdot
.41075 .11986 Mdot
.47772 .04139 Mdot
.51137 .0208 Mdot
.56205 .03132 Mdot
.49905 .61763 Mdot
.49697 .61675 Mdot
.49034 .61394 Mdot
.46923 .60499 Mdot
.40224 .57663 Mdot
.19765 .49159 Mdot
.76714 .35196 Mdot
.57397 .49865 Mdot
.4878 .56478 Mdot
.38334 .55347 Mdot
.11914 .45475 Mdot
.49894 .61758 Mdot
.49662 .6166 Mdot
.48923 .61347 Mdot
.46569 .60349 Mdot
.39109 .57193 Mdot
.16557 .47865 Mdot
.73413 .35139 Mdot
.54024 .4982 Mdot
.40606 .53511 Mdot
.13901 .45299 Mdot
.68896 .33989 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.51369 .00581 Mdot
.5436 .01849 Mdot
.63811 .05841 Mdot
.91474 .17097 Mdot
.31323 .24628 Mdot
.49158 .11023 Mdot
.65732 .10243 Mdot
.02244 .22566 Mdot
.35401 .20492 Mdot
.5001 4e-05 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00137 Mdot
.51026 .00435 Mdot
.53267 .01385 Mdot
.60374 .04393 Mdot
.81964 .13343 Mdot
.25178 .26708 Mdot
.44521 .11954 Mdot
.55805 .06974 Mdot
.75605 .12237 Mdot
.49794 .61716 Mdot
.49345 .61526 Mdot
.47913 .60918 Mdot
.43359 .58989 Mdot
.29129 .53009 Mdot
.91826 .38749 Mdot
.66252 .45998 Mdot
.61034 .58579 Mdot
.71072 .06204 Mdot
.0426 .20511 Mdot
.31134 .16609 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48571 .61197 Mdot
.4545 .59874 Mdot
.35595 .55713 Mdot
.06966 .44109 Mdot
.68218 .37856 Mdot
.51208 .51291 Mdot
.36009 .5241 Mdot
.02424 .41047 Mdot
.65217 .38808 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47348 .60679 Mdot
.41569 .58232 Mdot
.23727 .50777 Mdot
.82089 .36069 Mdot
.61994 .49384 Mdot
.58235 .5948 Mdot
.66285 .04975 Mdot
.94719 .17573 Mdot
.30929 .22379 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51432 .00607 Mdot
.5456 .01933 Mdot
.64436 .06103 Mdot
.93115 .17725 Mdot
.31803 .2391 Mdot
.48765 .10483 Mdot
.63877 .0934 Mdot
.97265 .20635 Mdot
.34735 .23158 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.49419 .61557 Mdot
.4815 .61019 Mdot
.44112 .59308 Mdot
.31441 .53973 Mdot
.96827 .4041 Mdot
.6694 .43333 Mdot
.57931 .56235 Mdot
.60332 .01484 Mdot
.77167 .10404 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.5076 .00322 Mdot
.52423 .01027 Mdot
.57704 .03264 Mdot
.74097 .10131 Mdot
.14324 .24862 Mdot
.35851 .13304 Mdot
.38841 .01848 Mdot
.26429 .54133 Mdot
.90241 .39438 Mdot
.67791 .47928 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51643 .00697 Mdot
.55231 .02218 Mdot
.66526 .06981 Mdot
.9839 .19693 Mdot
.32664 .21183 Mdot
.45781 .08107 Mdot
.52644 .04241 Mdot
.63455 .06681 Mdot
.92129 .17721 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.5238 .01009 Mdot
.5757 .03207 Mdot
.7369 .09963 Mdot
.13603 .24668 Mdot
.35507 .13537 Mdot
.38553 .01883 Mdot
.25871 .53965 Mdot
.89351 .39233 Mdot
.67639 .48385 Mdot
.49866 .61747 Mdot
.49574 .61623 Mdot
.48644 .61228 Mdot
.45681 .59972 Mdot
.36318 .56017 Mdot
.08868 .44838 Mdot
.68794 .37036 Mdot
.50801 .50683 Mdot
.34008 .51425 Mdot
.97066 .38972 Mdot
.645 .41676 Mdot
.49832 .61732 Mdot
.49464 .61576 Mdot
.48291 .61079 Mdot
.44561 .59498 Mdot
.32829 .54553 Mdot
.00054 .41548 Mdot
.67198 .41497 Mdot
.55404 .54514 Mdot
.51561 .59428 Mdot
.50057 .60874 Mdot
.48638 .60927 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48297 .61081 Mdot
.4458 .59506 Mdot
.32887 .54577 Mdot
.00194 .41598 Mdot
.6721 .41418 Mdot
.55295 .5444 Mdot
.51178 .59259 Mdot
.48825 .60349 Mdot
.4471 .5926 Mdot
.49896 .61759 Mdot
.4967 .61663 Mdot
.48947 .61357 Mdot
.46646 .60381 Mdot
.39352 .57295 Mdot
.17251 .48144 Mdot
.74051 .35104 Mdot
.54682 .49833 Mdot
.42234 .5411 Mdot
.18594 .47193 Mdot
.72989 .33618 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50997 .00423 Mdot
.53175 .01346 Mdot
.60084 .0427 Mdot
.81128 .13006 Mdot
.24297 .2668 Mdot
.43616 .1194 Mdot
.53613 .06179 Mdot
.68985 .095 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50817 .00346 Mdot
.52601 .01103 Mdot
.5827 .03504 Mdot
.75795 .1083 Mdot
.17162 .25567 Mdot
.37493 .12565 Mdot
.40937 .02128 Mdot
.31508 .55976 Mdot
.00174 .42438 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47985 .60949 Mdot
.43589 .59086 Mdot
.29835 .53303 Mdot
.933 .39224 Mdot
.66521 .45253 Mdot
.60307 .57963 Mdot
.68494 .0506 Mdot
.98588 .18599 Mdot
.30797 .19906 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48824 .61305 Mdot
.46253 .60215 Mdot
.38114 .56773 Mdot
.13759 .46751 Mdot
.71241 .35526 Mdot
.51934 .49871 Mdot
.35521 .5166 Mdot
.00264 .40013 Mdot
.64611 .39768 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51315 .00558 Mdot
.54188 .01775 Mdot
.6327 .05613 Mdot
.9003 .16539 Mdot
.30786 .25188 Mdot
.49229 .11398 Mdot
.66515 .10683 Mdot
.04361 .2339 Mdot
.35747 .19398 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.52607 .01106 Mdot
.5829 .03512 Mdot
.75852 .10854 Mdot
.17253 .25587 Mdot
.37554 .12547 Mdot
.41031 .02149 Mdot
.31754 .5607 Mdot
.00723 .42625 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51375 .00583 Mdot
.54377 .01856 Mdot
.63863 .05863 Mdot
.91611 .1715 Mdot
.31368 .24571 Mdot
.49138 .10982 Mdot
.65614 .10183 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50569 .00241 Mdot
.51811 .00768 Mdot
.55765 .02444 Mdot
.6818 .07673 Mdot
.02309 .21093 Mdot
.32987 .1896 Mdot
.42735 .06025 Mdot
.41959 .61324 Mdot
.29629 .54183 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48772 .61282 Mdot
.46088 .60145 Mdot
.37595 .56554 Mdot
.12321 .46183 Mdot
.70357 .35869 Mdot
.51259 .5 Mdot
.34046 .51165 Mdot
.96713 .3873 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61476 Mdot
.47543 .60762 Mdot
.42188 .58493 Mdot
.25579 .51538 Mdot
.85112 .36794 Mdot
.6386 .48669 Mdot
.60868 .59954 Mdot
.72941 .07461 Mdot
.08687 .22093 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51433 .00608 Mdot
.54562 .01934 Mdot
.64442 .06106 Mdot
.93131 .17731 Mdot
.31807 .23903 Mdot
.4876 .10477 Mdot
.63854 .09329 Mdot
.97204 .20611 Mdot
.34726 .2319 Mdot
.49762 .61702 Mdot
.4924 .61481 Mdot
.4758 .60777 Mdot
.42304 .58543 Mdot
.25929 .51683 Mdot
.85721 .36954 Mdot
.64172 .48485 Mdot
.6118 .59955 Mdot
.73614 .07684 Mdot
.0983 .22383 Mdot
.32221 .13839 Mdot
.49905 .61763 Mdot
.49697 .61675 Mdot
.49035 .61394 Mdot
.46926 .605 Mdot
.40236 .57668 Mdot
.19801 .49174 Mdot
.76755 .352 Mdot
.57438 .49865 Mdot
.48875 .56511 Mdot
.38625 .55469 Mdot
.12729 .45799 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47991 .60952 Mdot
.43608 .59094 Mdot
.29893 .53327 Mdot
.93423 .39264 Mdot
.66541 .45189 Mdot
.60238 .57908 Mdot
.68254 .04954 Mdot
.9803 .18403 Mdot
.30754 .20225 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51418 .00601 Mdot
.54516 .01915 Mdot
.64298 .06046 Mdot
.92757 .17588 Mdot
.31709 .24074 Mdot
.48878 .10611 Mdot
.64364 .09571 Mdot
.98589 .21152 Mdot
.34927 .22459 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60203 Mdot
.38023 .56735 Mdot
.13505 .4665 Mdot
.71074 .3558 Mdot
.51794 .49888 Mdot
.352 .51548 Mdot
.9947 .39721 Mdot
.64535 .40212 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50716 .00304 Mdot
.52282 .00968 Mdot
.5726 .03076 Mdot
.72754 .09576 Mdot
.11883 .24183 Mdot
.34799 .14163 Mdot
.38224 .02117 Mdot
.25554 .53973 Mdot
.89025 .39227 Mdot
.67684 .48614 Mdot
.49826 .6173 Mdot
.49446 .61568 Mdot
.48235 .61055 Mdot
.44382 .59422 Mdot
.32277 .54322 Mdot
.98751 .41083 Mdot
.67096 .4224 Mdot
.56431 .55212 Mdot
.55152 .61013 Mdot
.61467 .03903 Mdot
.83534 .13638 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50766 .00325 Mdot
.52442 .01035 Mdot
.57764 .0329 Mdot
.74278 .10206 Mdot
.14639 .24945 Mdot
.3601 .13208 Mdot
.38996 .01845 Mdot
.2676 .54241 Mdot
.90797 .39577 Mdot
.67882 .47641 Mdot
.49911 .61766 Mdot
.49718 .61684 Mdot
.49101 .61422 Mdot
.47136 .60589 Mdot
.40898 .57948 Mdot
.2174 .49963 Mdot
.79208 .35517 Mdot
.59719 .49759 Mdot
.5392 .58219 Mdot
.53942 .00013 Mdot
.59816 .03631 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53097 .01313 Mdot
.59837 .04166 Mdot
.80412 .12716 Mdot
.23493 .26625 Mdot
.42807 .11937 Mdot
.51697 .05494 Mdot
.63126 .07064 Mdot
.92087 .17899 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.5261 .01107 Mdot
.58299 .03516 Mdot
.7588 .10865 Mdot
.17297 .25597 Mdot
.37583 .12538 Mdot
.41077 .02159 Mdot
.31877 .56117 Mdot
.00997 .42719 Mdot
.68623 .41795 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50464 .00197 Mdot
.51478 .00627 Mdot
.54706 .01995 Mdot
.64889 .06294 Mdot
.94288 .1817 Mdot
.32072 .23352 Mdot
.48302 .1003 Mdot
.61988 .08459 Mdot
.92004 .18551 Mdot
.33516 .25656 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47487 .60738 Mdot
.4201 .58418 Mdot
.25046 .51319 Mdot
.84208 .36564 Mdot
.63358 .48917 Mdot
.60275 .59898 Mdot
.71556 .06972 Mdot
.06152 .21382 Mdot
.31749 .15819 Mdot
.49802 .6172 Mdot
.4937 .61536 Mdot
.47993 .60952 Mdot
.43613 .59096 Mdot
.29906 .53332 Mdot
.93452 .39274 Mdot
.66545 .45174 Mdot
.60221 .57895 Mdot
.68196 .04929 Mdot
.97896 .18356 Mdot
.30743 .203 Mdot
.49914 .61767 Mdot
.49726 .61687 Mdot
.49127 .61433 Mdot
.4722 .60625 Mdot
.41164 .58061 Mdot
.22525 .50284 Mdot
.80301 .35707 Mdot
.60638 .49651 Mdot
.5577 .58795 Mdot
.59369 .02224 Mdot
.76223 .10417 Mdot
.50026 .00011 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52631 .01116 Mdot
.58364 .03543 Mdot
.76075 .10946 Mdot
.17604 .25666 Mdot
.37791 .12477 Mdot
.4141 .02236 Mdot
.32761 .56458 Mdot
.0302 .43423 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50418 .00177 Mdot
.5133 .00564 Mdot
.54236 .01796 Mdot
.63422 .05677 Mdot
.90437 .16696 Mdot
.30949 .25038 Mdot
.49236 .11302 Mdot
.66378 .10594 Mdot
.03976 .23236 Mdot
.35671 .19589 Mdot
.49935 .61776 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47911 .60918 Mdot
.43353 .58986 Mdot
.29112 .53002 Mdot
.9179 .38737 Mdot
.66244 .46015 Mdot
.61049 .58593 Mdot
.71128 .06229 Mdot
.04377 .20549 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50306 .0013 Mdot
.50976 .00414 Mdot
.53108 .01318 Mdot
.59872 .04181 Mdot
.80513 .12757 Mdot
.23609 .26635 Mdot
.42923 .11937 Mdot
.51968 .0559 Mdot
.63958 .0741 Mdot
.94302 .18754 Mdot
.49805 .61721 Mdot
.4938 .6154 Mdot
.48024 .60965 Mdot
.43711 .59138 Mdot
.30209 .53459 Mdot
.94101 .39487 Mdot
.6664 .44832 Mdot
.59834 .57597 Mdot
.66859 .04342 Mdot
.94702 .17208 Mdot
.30346 .22029 Mdot
.49812 .61724 Mdot
.49402 .6155 Mdot
.48095 .60996 Mdot
.43938 .59234 Mdot
.30905 .53749 Mdot
.95623 .39998 Mdot
.66824 .44005 Mdot
.58818 .56855 Mdot
.63372 .02814 Mdot
.85706 .13803 Mdot
.26712 .25344 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50752 .00319 Mdot
.52396 .01016 Mdot
.57621 .03229 Mdot
.73846 .10028 Mdot
.13882 .24743 Mdot
.35636 .13445 Mdot
.38653 .01864 Mdot
.26055 .54017 Mdot
.89636 .39295 Mdot
.67687 .48238 Mdot
.49909 .61765 Mdot
.49711 .61681 Mdot
.4908 .61413 Mdot
.47069 .60561 Mdot
.40688 .57859 Mdot
.21121 .49711 Mdot
.78387 .35392 Mdot
.58987 .49814 Mdot
.52364 .5771 Mdot
.49272 .59893 Mdot
.45089 .59218 Mdot
.49927 .61772 Mdot
.49767 .61705 Mdot
.49258 .61489 Mdot
.47635 .60801 Mdot
.42478 .58616 Mdot
.26453 .519 Mdot
.86655 .37207 Mdot
.64609 .48179 Mdot
.61528 .59899 Mdot
.74266 .07872 Mdot
.10851 .22611 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.47849 .60891 Mdot
.43155 .58903 Mdot
.28508 .52751 Mdot
.90565 .38353 Mdot
.6596 .46597 Mdot
.6148 .59035 Mdot
.72765 .06975 Mdot
.07689 .21584 Mdot
.31523 .1473 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50695 .00295 Mdot
.52213 .00939 Mdot
.57041 .02984 Mdot
.7209 .09301 Mdot
.10614 .23809 Mdot
.34371 .14683 Mdot
.38275 .02413 Mdot
.2614 .54304 Mdot
.90193 .39587 Mdot
.49845 .61737 Mdot
.49505 .61593 Mdot
.48422 .61134 Mdot
.44976 .59674 Mdot
.3412 .55094 Mdot
.03203 .42696 Mdot
.67514 .39746 Mdot
.53106 .52899 Mdot
.43327 .5576 Mdot
.2383 .49754 Mdot
.80525 .35039 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50506 .00215 Mdot
.51612 .00684 Mdot
.55133 .02176 Mdot
.6622 .06852 Mdot
.97638 .19417 Mdot
.32586 .21599 Mdot
.46323 .0849 Mdot
.54593 .05111 Mdot
.69656 .0931 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00226 Mdot
.51701 .00721 Mdot
.55414 .02295 Mdot
.67092 .07217 Mdot
.99755 .20187 Mdot
.32786 .20414 Mdot
.44744 .0739 Mdot
.4896 .02606 Mdot
.51619 .01643 Mdot
.56701 .03141 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.51079 .00458 Mdot
.53437 .01457 Mdot
.6091 .04618 Mdot
.83495 .13959 Mdot
.26633 .26661 Mdot
.46023 .11984 Mdot
.5951 .08335 Mdot
.86428 .16636 Mdot
.31325 .27748 Mdot
.49756 .617 Mdot
.49222 .61473 Mdot
.4752 .60752 Mdot
.42115 .58463 Mdot
.2536 .51448 Mdot
.84739 .36698 Mdot
.63658 .48775 Mdot
.60642 .59939 Mdot
.72426 .07283 Mdot
.07771 .21845 Mdot
.31918 .14923 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52329 .00987 Mdot
.57407 .03139 Mdot
.732 .0976 Mdot
.12713 .24421 Mdot
.35121 .13849 Mdot
.38322 .01978 Mdot
.25536 .53901 Mdot
.88891 .39155 Mdot
.49993 .61801 Mdot
.49979 .61794 Mdot
.49933 .61775 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47833 .60885 Mdot
.43106 .58882 Mdot
.2836 .52689 Mdot
.90269 .38262 Mdot
.65883 .46732 Mdot
.61558 .59131 Mdot
.49748 .61696 Mdot
.49196 .61463 Mdot
.4744 .60718 Mdot
.41861 .58355 Mdot
.246 .51135 Mdot
.83473 .36385 Mdot
.62915 .49098 Mdot
.59672 .59799 Mdot
.70062 .06421 Mdot
.03184 .20471 Mdot
.31562 .17539 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47577 .60776 Mdot
.42293 .58538 Mdot
.25895 .51669 Mdot
.85661 .36938 Mdot
.64142 .48504 Mdot
.61153 .59956 Mdot
.73556 .07666 Mdot
.09735 .2236 Mdot
.32205 .13887 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50603 .00256 Mdot
.5192 .00814 Mdot
.5611 .02589 Mdot
.69241 .08115 Mdot
.04699 .21914 Mdot
.33211 .17621 Mdot
.40956 .04787 Mdot
.35855 .5865 Mdot
.12221 .47197 Mdot
.72004 .36948 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47758 .60853 Mdot
.42869 .58781 Mdot
.27636 .52389 Mdot
.88857 .37837 Mdot
.6546 .47343 Mdot
.61774 .59525 Mdot
.74182 .07669 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50664 .00281 Mdot
.52114 .00896 Mdot
.56726 .02851 Mdot
.7113 .08902 Mdot
.08705 .23223 Mdot
.33864 .15549 Mdot
.38757 .03024 Mdot
.28153 .5525 Mdot
.94143 .40784 Mdot
.68721 .46092 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00149 Mdot
.51116 .00473 Mdot
.53553 .01507 Mdot
.61277 .04774 Mdot
.84537 .14375 Mdot
.2751 .26559 Mdot
.46907 .11988 Mdot
.61693 .09138 Mdot
.92482 .19029 Mdot
.34133 .25742 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48427 .61136 Mdot
.44993 .59681 Mdot
.34171 .55115 Mdot
.03331 .42743 Mdot
.67531 .39678 Mdot
.53023 .52837 Mdot
.43021 .55622 Mdot
.22884 .49358 Mdot
.79084 .34734 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00148 Mdot
.51116 .00473 Mdot
.53553 .01507 Mdot
.61277 .04773 Mdot
.84534 .14374 Mdot
.27508 .26559 Mdot
.46905 .11988 Mdot
.61688 .09137 Mdot
.9247 .19024 Mdot
.3413 .25747 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .00139 Mdot
.51047 .00444 Mdot
.53336 .01415 Mdot
.60593 .04485 Mdot
.82591 .13596 Mdot
.25798 .26703 Mdot
.45162 .11968 Mdot
.57381 .07551 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47474 .60732 Mdot
.41967 .584 Mdot
.24915 .51265 Mdot
.8399 .36511 Mdot
.6323 .48973 Mdot
.60108 .59874 Mdot
.71148 .06823 Mdot
.05365 .21147 Mdot
.31686 .16268 Mdot
.49777 .61709 Mdot
.4929 .61502 Mdot
.47737 .60844 Mdot
.42801 .58753 Mdot
.27432 .52305 Mdot
.88468 .37722 Mdot
.65327 .47502 Mdot
.61785 .59614 Mdot
.74349 .07765 Mdot
.10767 .22507 Mdot
.32238 .1327 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51127 .00478 Mdot
.53591 .01522 Mdot
.61395 .04823 Mdot
.84868 .14507 Mdot
.2777 .26515 Mdot
.47161 .11984 Mdot
.62314 .09366 Mdot
.94151 .19676 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.5119 .00504 Mdot
.53788 .01606 Mdot
.62017 .05085 Mdot
.86605 .15197 Mdot
.28997 .26199 Mdot
.48264 .11908 Mdot
.64931 .10301 Mdot
.00852 .222 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50333 .00141 Mdot
.5106 .0045 Mdot
.53376 .01432 Mdot
.60719 .04538 Mdot
.82953 .13741 Mdot
.2614 .26692 Mdot
.45516 .11975 Mdot
.58255 .07873 Mdot
.82829 .15187 Mdot
.28445 .28193 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.5036 .00153 Mdot
.51146 .00486 Mdot
.5365 .01547 Mdot
.6158 .04901 Mdot
.85388 .14714 Mdot
.28162 .26436 Mdot
.47532 .11972 Mdot
.63216 .09693 Mdot
.96523 .20585 Mdot
.35004 .23782 Mdot
.49984 .61797 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49486 .61585 Mdot
.48363 .61109 Mdot
.44788 .59594 Mdot
.33534 .54848 Mdot
.01757 .42164 Mdot
.6735 .40539 Mdot
.54111 .53621 Mdot
.4697 .5739 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50736 .00312 Mdot
.52345 .00994 Mdot
.57459 .03161 Mdot
.73356 .09825 Mdot
.13 .24501 Mdot
.3524 .13746 Mdot
.38382 .01941 Mdot
.25603 .53906 Mdot
.88968 .39162 Mdot
.67587 .4859 Mdot
.49997 .61802 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49708 .61679 Mdot
.49068 .61408 Mdot
.47033 .60545 Mdot
.40572 .57811 Mdot
.20783 .49573 Mdot
.77953 .35333 Mdot
.58587 .49834 Mdot
.498 .61719 Mdot
.49364 .61534 Mdot
.47973 .60944 Mdot
.43551 .5907 Mdot
.29717 .53254 Mdot
.93051 .39143 Mdot
.6648 .45382 Mdot
.60444 .58072 Mdot
.68972 .05271 Mdot
.99681 .18979 Mdot
.30869 .19275 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00341 Mdot
.52564 .01087 Mdot
.58152 .03454 Mdot
.7544 .10685 Mdot
.16592 .25433 Mdot
.37125 .1269 Mdot
.40386 .02015 Mdot
.30085 .55438 Mdot
.9712 .4143 Mdot
.49862 .61745 Mdot
.4956 .61617 Mdot
.486 .6121 Mdot
.45541 .59913 Mdot
.3588 .55833 Mdot
.07711 .44394 Mdot
.68423 .37522 Mdot
.50997 .51034 Mdot
.35067 .51958 Mdot
.99882 .40058 Mdot
.64874 .40167 Mdot
.49979 .61794 Mdot
.49932 .61775 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.4781 .60875 Mdot
.43033 .58851 Mdot
.28136 .52597 Mdot
.89829 .38128 Mdot
.6576 .46928 Mdot
.61654 .59265 Mdot
.73507 .07326 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49075 .61411 Mdot
.47054 .60554 Mdot
.40639 .57839 Mdot
.20979 .49653 Mdot
.78203 .35367 Mdot
.58819 .49823 Mdot
.51997 .57587 Mdot
.49823 .61728 Mdot
.49437 .61564 Mdot
.48205 .61042 Mdot
.44287 .59382 Mdot
.31982 .54198 Mdot
.98064 .40841 Mdot
.67043 .42631 Mdot
.56973 .5558 Mdot
.57033 .00037 Mdot
.67301 .06346 Mdot
.98703 .19407 Mdot
.49852 .6174 Mdot
.49527 .61603 Mdot
.48493 .61164 Mdot
.45201 .59769 Mdot
.3482 .55387 Mdot
.04968 .43354 Mdot
.67784 .38823 Mdot
.52062 .52087 Mdot
.39424 .53993 Mdot
.12065 .44894 Mdot
.68292 .34751 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49541 .61609 Mdot
.48538 .61184 Mdot
.45346 .5983 Mdot
.35271 .55577 Mdot
.06124 .4379 Mdot
.68016 .38251 Mdot
.51519 .51608 Mdot
.37298 .53014 Mdot
.05983 .4245 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.52089 .00886 Mdot
.56648 .02817 Mdot
.7089 .08802 Mdot
.08214 .23068 Mdot
.33757 .15786 Mdot
.38949 .03209 Mdot
.28866 .55572 Mdot
.95611 .4125 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51093 .00463 Mdot
.5348 .01476 Mdot
.61046 .04676 Mdot
.83883 .14114 Mdot
.2697 .26629 Mdot
.46367 .11988 Mdot
.60361 .08649 Mdot
.88821 .17589 Mdot
.32705 .27122 Mdot
.49906 .61764 Mdot
.497 .61676 Mdot
.49045 .61399 Mdot
.46959 .60514 Mdot
.40339 .57712 Mdot
.20101 .49296 Mdot
.77112 .35235 Mdot
.57786 .49859 Mdot
.4968 .56793 Mdot
.41094 .56497 Mdot
.19834 .48664 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51092 .00463 Mdot
.53479 .01475 Mdot
.61043 .04675 Mdot
.83874 .1411 Mdot
.26962 .2663 Mdot
.46359 .11988 Mdot
.6034 .08641 Mdot
.88764 .17567 Mdot
.32676 .27139 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49562 .61618 Mdot
.48604 .61211 Mdot
.45554 .59919 Mdot
.35921 .5585 Mdot
.07819 .44435 Mdot
.68454 .37475 Mdot
.50972 .50999 Mdot
.34947 .51899 Mdot
.99562 .39934 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.5083 .00352 Mdot
.52643 .01121 Mdot
.58404 .0356 Mdot
.76192 .10994 Mdot
.17787 .25707 Mdot
.37918 .12442 Mdot
.41619 .02287 Mdot
.3332 .56675 Mdot
.04337 .43891 Mdot
.68928 .3992 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50505 .00214 Mdot
.51609 .00682 Mdot
.55122 .02171 Mdot
.66186 .06838 Mdot
.97556 .19387 Mdot
.32577 .21644 Mdot
.4638 .08531 Mdot
.548 .05204 Mdot
.7031 .09586 Mdot
.08665 .23704 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50299 .00127 Mdot
.50952 .00404 Mdot
.53033 .01286 Mdot
.59637 .04081 Mdot
.79828 .12479 Mdot
.22803 .2656 Mdot
.42131 .11946 Mdot
.50132 .04945 Mdot
.58331 .05067 Mdot
.78463 .12442 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47318 .60666 Mdot
.41475 .58192 Mdot
.23447 .50662 Mdot
.8166 .35977 Mdot
.61686 .49459 Mdot
.57707 .59345 Mdot
.64843 .0441 Mdot
.91153 .16261 Mdot
.49963 .61788 Mdot
.49882 .61753 Mdot
.49623 .61644 Mdot
.48799 .61294 Mdot
.46176 .60182 Mdot
.37873 .56671 Mdot
.13088 .46486 Mdot
.7081 .35674 Mdot
.51584 .49921 Mdot
.34728 .51386 Mdot
.98322 .39303 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48569 .61197 Mdot
.45443 .59871 Mdot
.35574 .55704 Mdot
.06911 .44088 Mdot
.68204 .37881 Mdot
.51226 .51311 Mdot
.36086 .52446 Mdot
.02633 .41129 Mdot
.65249 .38698 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .00341 Mdot
.52559 .01085 Mdot
.58136 .03447 Mdot
.75391 .10665 Mdot
.16513 .25415 Mdot
.37076 .12709 Mdot
.40315 .02002 Mdot
.29905 .5537 Mdot
.96747 .41311 Mdot
.68435 .44305 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52163 .00917 Mdot
.56883 .02917 Mdot
.71607 .091 Mdot
.09665 .23521 Mdot
.341 .15102 Mdot
.38459 .02694 Mdot
.26983 .54711 Mdot
.91819 .40071 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52451 .01039 Mdot
.57794 .03302 Mdot
.74367 .10243 Mdot
.14795 .24986 Mdot
.36091 .13162 Mdot
.3908 .01847 Mdot
.26943 .54303 Mdot
.91111 .39658 Mdot
.6793 .47477 Mdot
.49891 .61757 Mdot
.49652 .61656 Mdot
.4889 .61333 Mdot
.46465 .60305 Mdot
.38782 .57055 Mdot
.1563 .47495 Mdot
.72625 .35224 Mdot
.53227 .49815 Mdot
.38635 .52785 Mdot
.08409 .43123 Mdot
.66148 .35685 Mdot
.49992 .618 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47446 .60721 Mdot
.41881 .58364 Mdot
.24657 .51159 Mdot
.83566 .36408 Mdot
.62973 .49076 Mdot
.59755 .59815 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51267 .00537 Mdot
.54033 .0171 Mdot
.62786 .05409 Mdot
.88719 .16028 Mdot
.30192 .25632 Mdot
.49051 .11656 Mdot
.49899 .61761 Mdot
.4968 .61668 Mdot
.4898 .61371 Mdot
.4675 .60425 Mdot
.39679 .57433 Mdot
.1819 .48522 Mdot
.74979 .35098 Mdot
.55642 .49852 Mdot
.44593 .54974 Mdot
.25587 .50057 Mdot
.82725 .35313 Mdot
.49766 .61704 Mdot
.49254 .61487 Mdot
.47624 .60796 Mdot
.42443 .58602 Mdot
.26349 .51857 Mdot
.86467 .37155 Mdot
.64525 .48243 Mdot
.6147 .59915 Mdot
.7417 .07849 Mdot
.1071 .22583 Mdot
.32371 .13387 Mdot
.49751 .61698 Mdot
.49206 .61467 Mdot
.4747 .60731 Mdot
.41956 .58396 Mdot
.24884 .51252 Mdot
.83939 .36498 Mdot
.632 .48986 Mdot
.60067 .59867 Mdot
.71048 .06787 Mdot
.0517 .21088 Mdot
.31673 .1638 Mdot
.4975 .61697 Mdot
.49204 .61466 Mdot
.47464 .60728 Mdot
.41936 .58387 Mdot
.24822 .51227 Mdot
.83837 .36473 Mdot
.63138 .49011 Mdot
.59984 .59854 Mdot
.70844 .06711 Mdot
.04767 .20966 Mdot
.31646 .16613 Mdot
.49814 .61724 Mdot
.49406 .61552 Mdot
.48108 .61001 Mdot
.43978 .59251 Mdot
.31031 .53801 Mdot
.95903 .40093 Mdot
.66853 .4385 Mdot
.58617 .56713 Mdot
.62683 .02513 Mdot
.83823 .13065 Mdot
.25261 .2561 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51798 .00762 Mdot
.55722 .02425 Mdot
.68046 .07617 Mdot
.02001 .20985 Mdot
.32962 .19135 Mdot
.42976 .06189 Mdot
.42792 .6169 Mdot
.32163 .55234 Mdot
.00037 .41949 Mdot
.50018 8e-05 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50596 .00253 Mdot
.51897 .00805 Mdot
.56039 .02559 Mdot
.69022 .08024 Mdot
.04215 .2175 Mdot
.33159 .17888 Mdot
.41298 .0503 Mdot
.37025 .59163 Mdot
.15376 .48423 Mdot
.49948 .61781 Mdot
.49835 .61733 Mdot
.49474 .61581 Mdot
.48326 .61093 Mdot
.4467 .59544 Mdot
.33168 .54695 Mdot
.00867 .41841 Mdot
.67267 .41037 Mdot
.54776 .54084 Mdot
.49343 .58445 Mdot
.42923 .57836 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48987 .61374 Mdot
.46773 .60435 Mdot
.39752 .57464 Mdot
.18399 .48607 Mdot
.75197 .35103 Mdot
.55866 .49856 Mdot
.45138 .55173 Mdot
.27228 .50735 Mdot
.50003 1e-05 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.5087 .00369 Mdot
.52772 .01175 Mdot
.58812 .03733 Mdot
.77404 .11491 Mdot
.19597 .26077 Mdot
.3928 .12165 Mdot
.44071 .02961 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.5217 .0092 Mdot
.56903 .02925 Mdot
.7167 .09126 Mdot
.09789 .23559 Mdot
.34133 .15045 Mdot
.38428 .02654 Mdot
.26854 .5465 Mdot
.91569 .39996 Mdot
.68347 .47451 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00343 Mdot
.52579 .01094 Mdot
.582 .03474 Mdot
.75585 .10744 Mdot
.16827 .25489 Mdot
.37275 .12638 Mdot
.40604 .02058 Mdot
.30645 .55648 Mdot
.98297 .41812 Mdot
.68499 .43387 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49705 .61678 Mdot
.4906 .61405 Mdot
.47006 .60534 Mdot
.40488 .57775 Mdot
.20535 .49472 Mdot
.77643 .35294 Mdot
.58295 .49846 Mdot
.50835 .57193 Mdot
.44627 .57967 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51144 .00485 Mdot
.53642 .01544 Mdot
.61557 .04891 Mdot
.85322 .14688 Mdot
.28114 .26447 Mdot
.47487 .11974 Mdot
.63107 .09654 Mdot
.9624 .20477 Mdot
.3496 .23931 Mdot
.49857 .61743 Mdot
.49545 .61611 Mdot
.48551 .61189 Mdot
.45386 .59847 Mdot
.35397 .5563 Mdot
.06451 .43914 Mdot
.68091 .38095 Mdot
.5139 .51481 Mdot
.3677 .52768 Mdot
.04513 .41868 Mdot
.65577 .37739 Mdot
.50023 .0001 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52404 .01019 Mdot
.57645 .03239 Mdot
.73917 .10057 Mdot
.14007 .24777 Mdot
.35696 .13405 Mdot
.38702 .01858 Mdot
.2615 .54046 Mdot
.89787 .3933 Mdot
.49745 .61695 Mdot
.49189 .61459 Mdot
.47415 .60708 Mdot
.41782 .58322 Mdot
.24364 .51038 Mdot
.83091 .36295 Mdot
.62672 .49184 Mdot
.59316 .59729 Mdot
.69149 .06077 Mdot
.01261 .19846 Mdot
.31483 .18678 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49066 .61407 Mdot
.47025 .60542 Mdot
.40547 .578 Mdot
.20707 .49542 Mdot
.77858 .35321 Mdot
.58498 .49838 Mdot
.51288 .57347 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.48659 .61235 Mdot
.45729 .59993 Mdot
.36469 .56081 Mdot
.09271 .44994 Mdot
.6894 .36877 Mdot
.50772 .50575 Mdot
.3376 .5129 Mdot
.96402 .38715 Mdot
.64395 .42022 Mdot
.49745 .61695 Mdot
.49187 .61458 Mdot
.47409 .60705 Mdot
.41762 .58313 Mdot
.24303 .51013 Mdot
.82994 .36273 Mdot
.62609 .49205 Mdot
.59221 .59709 Mdot
.68903 .05984 Mdot
.00728 .19669 Mdot
.31461 .18994 Mdot
.49767 .61704 Mdot
.49256 .61488 Mdot
.47631 .60799 Mdot
.42465 .58611 Mdot
.26414 .51883 Mdot
.86584 .37187 Mdot
.64578 .48203 Mdot
.61507 .59905 Mdot
.74231 .07864 Mdot
.10801 .22601 Mdot
.32385 .13339 Mdot
.49838 .61735 Mdot
.49482 .61584 Mdot
.48351 .61104 Mdot
.44751 .59578 Mdot
.33418 .548 Mdot
.01475 .42061 Mdot
.67322 .40696 Mdot
.54319 .53767 Mdot
.47715 .57722 Mdot
.37696 .55611 Mdot
.11004 .45307 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.50441 .00187 Mdot
.51404 .00596 Mdot
.54472 .01896 Mdot
.6416 .05988 Mdot
.92395 .1745 Mdot
.31608 .24235 Mdot
.48976 .10734 Mdot
.64811 .09786 Mdot
.9979 .21619 Mdot
.35084 .21813 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00156 Mdot
.51174 .00498 Mdot
.53739 .01585 Mdot
.61862 .0502 Mdot
.86174 .15026 Mdot
.28714 .26291 Mdot
.48027 .11936 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00175 Mdot
.51318 .00559 Mdot
.54196 .01779 Mdot
.63296 .05624 Mdot
.90101 .16566 Mdot
.30815 .25163 Mdot
.49232 .11382 Mdot
.66496 .1067 Mdot
.04306 .23368 Mdot
.35736 .19424 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.4806 .60981 Mdot
.43828 .59187 Mdot
.30567 .53608 Mdot
.94878 .39747 Mdot
.6674 .44413 Mdot
.59333 .57225 Mdot
.65135 .03586 Mdot
.9037 .15596 Mdot
.29184 .23989 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51268 .00538 Mdot
.54037 .01712 Mdot
.62798 .05414 Mdot
.88752 .1604 Mdot
.30208 .25622 Mdot
.49058 .1165 Mdot
.66497 .10778 Mdot
.04483 .23476 Mdot
.35833 .19375 Mdot
.49991 .61799 Mdot
.49971 .61791 Mdot
.49906 .61764 Mdot
.49701 .61676 Mdot
.49046 .61399 Mdot
.46962 .60515 Mdot
.40347 .57716 Mdot
.20126 .49306 Mdot
.77142 .35238 Mdot
.57815 .49859 Mdot
.49745 .56816 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50543 .0023 Mdot
.5173 .00734 Mdot
.55507 .02334 Mdot
.67382 .07339 Mdot
.00447 .20435 Mdot
.32841 .20021 Mdot
.44203 .07022 Mdot
.47059 .01765 Mdot
.45528 .60857 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.48929 .61349 Mdot
.4659 .60357 Mdot
.39174 .5722 Mdot
.16742 .4794 Mdot
.7358 .35127 Mdot
.54195 .49823 Mdot
.4103 .53667 Mdot
.15112 .45785 Mdot
.69781 .33788 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60958 Mdot
.43653 .59113 Mdot
.30031 .53384 Mdot
.93718 .39361 Mdot
.66585 .45035 Mdot
.60067 .57775 Mdot
.67661 .04693 Mdot
.96634 .17907 Mdot
.30619 .21004 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47765 .60856 Mdot
.4289 .58791 Mdot
.27702 .52416 Mdot
.88983 .37874 Mdot
.65501 .47291 Mdot
.61766 .59495 Mdot
.74116 .07632 Mdot
.10302 .22364 Mdot
.32092 .13467 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48194 .61038 Mdot
.44253 .59367 Mdot
.31876 .54154 Mdot
.9782 .40756 Mdot
.67024 .4277 Mdot
.57165 .5571 Mdot
.57693 .00327 Mdot
.69318 .07184 Mdot
.0331 .21008 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.5151 .0064 Mdot
.54809 .02039 Mdot
.65211 .06429 Mdot
.95112 .1848 Mdot
.3223 .2294 Mdot
.47896 .09682 Mdot
.60416 .07738 Mdot
.87469 .16719 Mdot
.31435 .27173 Mdot
.49852 .61741 Mdot
.4953 .61604 Mdot
.48502 .61168 Mdot
.45231 .59782 Mdot
.34912 .55426 Mdot
.05203 .43442 Mdot
.67828 .38704 Mdot
.51941 .51985 Mdot
.3896 .5378 Mdot
.10715 .44347 Mdot
.67585 .35147 Mdot
.49788 .61714 Mdot
.49326 .61518 Mdot
.47852 .60893 Mdot
.43167 .58908 Mdot
.28544 .52766 Mdot
.90637 .38376 Mdot
.65978 .46564 Mdot
.61459 .59011 Mdot
.72682 .06936 Mdot
.07526 .21534 Mdot
.31497 .14815 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51156 .0049 Mdot
.53682 .01561 Mdot
.61681 .04944 Mdot
.8567 .14826 Mdot
.28366 .26387 Mdot
.4772 .11961 Mdot
.63664 .09854 Mdot
.97679 .21022 Mdot
.35163 .23166 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.477 .60828 Mdot
.42685 .58704 Mdot
.27079 .52158 Mdot
.87803 .3753 Mdot
.65084 .47762 Mdot
.61752 .59744 Mdot
.74489 .07872 Mdot
.11086 .22619 Mdot
.32367 .13152 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00348 Mdot
.52617 .0111 Mdot
.58322 .03525 Mdot
.75948 .10893 Mdot
.17405 .25622 Mdot
.37656 .12516 Mdot
.41192 .02185 Mdot
.32179 .56233 Mdot
.01682 .42955 Mdot
.68666 .41399 Mdot
.49977 .61794 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49249 .61485 Mdot
.47608 .60789 Mdot
.42393 .5858 Mdot
.26196 .51793 Mdot
.86193 .3708 Mdot
.64399 .48334 Mdot
.61375 .59935 Mdot
.73998 .07802 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51074 .00456 Mdot
.53421 .01451 Mdot
.60861 .04598 Mdot
.83357 .13903 Mdot
.2651 .2667 Mdot
.45897 .11982 Mdot
.59197 .0822 Mdot
.85539 .1628 Mdot
.30708 .27916 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54654 .01973 Mdot
.64729 .06227 Mdot
.93877 .18014 Mdot
.31984 .23552 Mdot
.4848 .10195 Mdot
.627 .08788 Mdot
.94011 .19352 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50406 .00172 Mdot
.51292 .00548 Mdot
.54116 .01745 Mdot
.63044 .05518 Mdot
.89419 .16301 Mdot
.30522 .25403 Mdot
.49175 .11528 Mdot
.66591 .10764 Mdot
.04626 .23507 Mdot
.35819 .19278 Mdot
.49969 .6179 Mdot
.49902 .61762 Mdot
.49689 .61671 Mdot
.49009 .61383 Mdot
.46843 .60465 Mdot
.39972 .57557 Mdot
.19034 .48863 Mdot
.7588 .35133 Mdot
.56564 .49865 Mdot
.46816 .55779 Mdot
.32325 .52847 Mdot
.50024 .0001 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50777 .00329 Mdot
.52475 .01049 Mdot
.57869 .03334 Mdot
.74593 .10336 Mdot
.15182 .25085 Mdot
.36298 .1305 Mdot
.39307 .0186 Mdot
.27458 .5448 Mdot
.92019 .39901 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.48219 .61048 Mdot
.44331 .59401 Mdot
.32119 .54256 Mdot
.98383 .40953 Mdot
.67068 .4245 Mdot
.56723 .5541 Mdot
.56164 .61458 Mdot
.64621 .05227 Mdot
.50079 .00033 Mdot
.50252 .00107 Mdot
.50802 .0034 Mdot
.52554 .01083 Mdot
.58122 .03441 Mdot
.7535 .10648 Mdot
.16445 .25398 Mdot
.37034 .12725 Mdot
.40255 .01991 Mdot
.29755 .55314 Mdot
.96439 .41213 Mdot
.6842 .44487 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52319 .00983 Mdot
.57377 .03126 Mdot
.73107 .09722 Mdot
.12542 .24372 Mdot
.35052 .13912 Mdot
.38293 .02003 Mdot
.25515 .53906 Mdot
.88876 .39159 Mdot
.67597 .48653 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52126 .00901 Mdot
.56763 .02866 Mdot
.71243 .08949 Mdot
.08933 .23294 Mdot
.33917 .1544 Mdot
.38676 .02942 Mdot
.27847 .55111 Mdot
.93526 .40592 Mdot
.6865 .46429 Mdot
.49873 .6175 Mdot
.49596 .61632 Mdot
.48714 .61258 Mdot
.45904 .60067 Mdot
.37019 .56312 Mdot
.10749 .45568 Mdot
.69554 .36343 Mdot
.50848 .50243 Mdot
.33415 .51029 Mdot
.95367 .38289 Mdot
.64171 .42523 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.4862 .61218 Mdot
.45606 .59941 Mdot
.36085 .55919 Mdot
.08251 .44601 Mdot
.68587 .3729 Mdot
.50885 .50863 Mdot
.3451 .51683 Mdot
.98399 .39485 Mdot
.64685 .40967 Mdot
.49975 .61793 Mdot
.4992 .6177 Mdot
.49747 .61696 Mdot
.49192 .61461 Mdot
.47428 .60713 Mdot
.41821 .58338 Mdot
.24478 .51085 Mdot
.83275 .36338 Mdot
.6279 .49143 Mdot
.59492 .59765 Mdot
.69601 .06248 Mdot
.49893 .61758 Mdot
.4966 .61659 Mdot
.48916 .61344 Mdot
.46547 .6034 Mdot
.39041 .57164 Mdot
.16363 .47788 Mdot
.73242 .35153 Mdot
.53849 .49818 Mdot
.40174 .53352 Mdot
.1268 .44811 Mdot
.68114 .34261 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52451 .01039 Mdot
.57795 .03303 Mdot
.74368 .10243 Mdot
.14796 .24986 Mdot
.36092 .13161 Mdot
.39081 .01847 Mdot
.26945 .54303 Mdot
.91115 .39659 Mdot
.6793 .47475 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47948 .60933 Mdot
.43471 .59036 Mdot
.29473 .53152 Mdot
.92539 .38977 Mdot
.66391 .45643 Mdot
.60707 .58291 Mdot
.699 .05682 Mdot
.01752 .19685 Mdot
.30981 .18065 Mdot
.49933 .61775 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47818 .60878 Mdot
.43057 .58861 Mdot
.28209 .52627 Mdot
.89972 .38171 Mdot
.65801 .46865 Mdot
.61625 .59223 Mdot
.73378 .07263 Mdot
.0888 .21941 Mdot
.49808 .61722 Mdot
.4939 .61545 Mdot
.48055 .60979 Mdot
.43811 .5918 Mdot
.30514 .53586 Mdot
.94764 .39708 Mdot
.66726 .44476 Mdot
.59409 .57281 Mdot
.65397 .03701 Mdot
.91042 .1585 Mdot
.29426 .23723 Mdot
.4983 .61731 Mdot
.49458 .61574 Mdot
.48274 .61072 Mdot
.44507 .59475 Mdot
.32662 .54483 Mdot
.99656 .41405 Mdot
.67167 .41724 Mdot
.55716 .54727 Mdot
.52658 .59913 Mdot
.53567 .00562 Mdot
.59781 .03841 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50663 .00281 Mdot
.52113 .00896 Mdot
.56721 .02848 Mdot
.71115 .08896 Mdot
.08675 .23213 Mdot
.33857 .15563 Mdot
.38768 .03035 Mdot
.28195 .55269 Mdot
.94227 .4081 Mdot
.68731 .46046 Mdot
.49881 .61753 Mdot
.49622 .61643 Mdot
.48796 .61293 Mdot
.46166 .60178 Mdot
.3784 .56658 Mdot
.12998 .4645 Mdot
.70755 .35696 Mdot
.51541 .49929 Mdot
.34636 .51355 Mdot
.981 .39223 Mdot
.64408 .4098 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48617 .61217 Mdot
.45595 .59936 Mdot
.36049 .55904 Mdot
.08155 .44564 Mdot
.68557 .3733 Mdot
.50903 .50892 Mdot
.34601 .51729 Mdot
.98641 .39578 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47908 .60916 Mdot
.43342 .58982 Mdot
.29079 .52988 Mdot
.91723 .38716 Mdot
.6623 .46048 Mdot
.61077 .58618 Mdot
.71229 .06275 Mdot
.04588 .20617 Mdot
.3116 .16422 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50678 .00288 Mdot
.52161 .00916 Mdot
.56876 .02914 Mdot
.71588 .09092 Mdot
.09627 .23509 Mdot
.3409 .15119 Mdot
.38468 .02706 Mdot
.27023 .5473 Mdot
.91898 .40095 Mdot
.68407 .47285 Mdot
.50053 .00022 Mdot
.50167 .00071 Mdot
.50533 .00226 Mdot
.51699 .0072 Mdot
.55407 .02292 Mdot
.6707 .07208 Mdot
.99705 .20169 Mdot
.32782 .20443 Mdot
.44783 .07417 Mdot
.491 .02667 Mdot
.52066 .01833 Mdot
.58122 .03743 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50364 .00154 Mdot
.51158 .00491 Mdot
.53689 .01564 Mdot
.61705 .04954 Mdot
.85738 .14853 Mdot
.28413 .26375 Mdot
.47762 .11959 Mdot
.63767 .09891 Mdot
.9794 .2112 Mdot
.35195 .23025 Mdot
.50004 2e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50368 .00156 Mdot
.51171 .00497 Mdot
.53731 .01582 Mdot
.61835 .05009 Mdot
.86101 .14997 Mdot
.28664 .26306 Mdot
.47985 .11941 Mdot
.6429 .10077 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48202 .61041 Mdot
.44279 .59378 Mdot
.31957 .54188 Mdot
.98005 .40821 Mdot
.67038 .42665 Mdot
.57019 .55611 Mdot
.57191 .00106 Mdot
.67786 .06548 Mdot
.99845 .19813 Mdot
.49935 .61776 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47906 .60916 Mdot
.43339 .5898 Mdot
.29069 .52984 Mdot
.91702 .38709 Mdot
.66226 .46058 Mdot
.61085 .58627 Mdot
.71261 .06289 Mdot
.04655 .20638 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47715 .60835 Mdot
.42732 .58724 Mdot
.27221 .52217 Mdot
.88069 .37606 Mdot
.65184 .47659 Mdot
.61773 .59695 Mdot
.74455 .07838 Mdot
.10997 .22584 Mdot
.32325 .13181 Mdot
.49804 .6172 Mdot
.49375 .61538 Mdot
.48008 .60959 Mdot
.4366 .59116 Mdot
.30052 .53393 Mdot
.93764 .39376 Mdot
.66592 .4501 Mdot
.60039 .57753 Mdot
.67565 .04652 Mdot
.96407 .17825 Mdot
.30593 .21128 Mdot
.49834 .61733 Mdot
.49471 .61579 Mdot
.48315 .61089 Mdot
.44635 .59529 Mdot
.33059 .54649 Mdot
.00605 .41746 Mdot
.67244 .41185 Mdot
.54977 .54222 Mdot
.50055 .58761 Mdot
.45214 .58812 Mdot
.33302 .54441 Mdot
.49969 .6179 Mdot
.49903 .61762 Mdot
.4969 .61672 Mdot
.49013 .61385 Mdot
.46857 .60471 Mdot
.40016 .57576 Mdot
.19163 .48915 Mdot
.76024 .35142 Mdot
.56709 .49866 Mdot
.47163 .55903 Mdot
.33383 .53287 Mdot
.49828 .61731 Mdot
.49453 .61571 Mdot
.48256 .61064 Mdot
.44448 .5945 Mdot
.3248 .54407 Mdot
.99228 .41252 Mdot
.67133 .41968 Mdot
.56054 .54956 Mdot
.53839 .60434 Mdot
.57327 .02155 Mdot
.7142 .0871 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.5196 .00831 Mdot
.56239 .02644 Mdot
.69637 .08281 Mdot
.05566 .22205 Mdot
.33315 .1715 Mdot
.40376 .04364 Mdot
.33865 .57779 Mdot
.07088 .45255 Mdot
.70028 .38899 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50741 .00314 Mdot
.52361 .01001 Mdot
.57509 .03182 Mdot
.73507 .09888 Mdot
.13274 .24577 Mdot
.35359 .13649 Mdot
.38452 .01911 Mdot
.25703 .53924 Mdot
.89103 .39184 Mdot
.67602 .48515 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50819 .00347 Mdot
.5261 .01107 Mdot
.58298 .03516 Mdot
.75878 .10865 Mdot
.17295 .25597 Mdot
.37582 .12538 Mdot
.41074 .02159 Mdot
.3187 .56115 Mdot
.00981 .42713 Mdot
.68622 .41804 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.5063 .00267 Mdot
.52006 .00851 Mdot
.56385 .02706 Mdot
.70085 .08467 Mdot
.06529 .22524 Mdot
.33452 .16639 Mdot
.3979 .03917 Mdot
.31841 .56891 Mdot
.0219 .43478 Mdot
.69265 .41455 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52176 .00923 Mdot
.56922 .02933 Mdot
.71727 .0915 Mdot
.09902 .23594 Mdot
.34164 .14995 Mdot
.38402 .02619 Mdot
.26742 .54597 Mdot
.91351 .39931 Mdot
.68305 .4756 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50548 .00232 Mdot
.51746 .0074 Mdot
.55559 .02356 Mdot
.6754 .07405 Mdot
.00821 .20568 Mdot
.32871 .19808 Mdot
.43907 .06821 Mdot
.46026 .01309 Mdot
.42245 .59467 Mdot
.27287 .52559 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50629 .00267 Mdot
.52003 .00849 Mdot
.56374 .02702 Mdot
.70053 .08454 Mdot
.06462 .22502 Mdot
.33442 .16674 Mdot
.39828 .03947 Mdot
.31975 .5695 Mdot
.02505 .4359 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50403 .00171 Mdot
.51285 .00545 Mdot
.54091 .01735 Mdot
.62968 .05486 Mdot
.89213 .16221 Mdot
.30428 .25472 Mdot
.49146 .11568 Mdot
.66582 .10776 Mdot
.0463 .23515 Mdot
.3583 .19283 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00164 Mdot
.51235 .00524 Mdot
.53933 .01667 Mdot
.62471 .05277 Mdot
.87858 .1569 Mdot
.29743 .25886 Mdot
.48806 .11782 Mdot
.66079 .10675 Mdot
.03572 .23172 Mdot
.35752 .19889 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.523 .00975 Mdot
.57317 .031 Mdot
.72925 .09647 Mdot
.12205 .24276 Mdot
.34919 .14038 Mdot
.38249 .02058 Mdot
.25511 .53931 Mdot
.88912 .39184 Mdot
.67632 .48652 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47343 .60677 Mdot
.41552 .58225 Mdot
.23676 .50756 Mdot
.8201 .36052 Mdot
.61938 .49398 Mdot
.58142 .59457 Mdot
.66031 .04876 Mdot
.94103 .17349 Mdot
.49907 .61764 Mdot
.49702 .61677 Mdot
.49052 .61401 Mdot
.46981 .60523 Mdot
.40408 .57741 Mdot
.20302 .49377 Mdot
.77356 .35261 Mdot
.58021 .49854 Mdot
.50216 .56979 Mdot
.42734 .5718 Mdot
.24729 .50676 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50661 .0028 Mdot
.52105 .00893 Mdot
.56698 .02839 Mdot
.71045 .08867 Mdot
.08531 .23168 Mdot
.33825 .15633 Mdot
.38822 .03089 Mdot
.28398 .55361 Mdot
.94642 .40941 Mdot
.49751 .61698 Mdot
.49207 .61467 Mdot
.47472 .60732 Mdot
.41963 .58398 Mdot
.24904 .5126 Mdot
.83971 .36506 Mdot
.63219 .48978 Mdot
.60093 .59871 Mdot
.71111 .0681 Mdot
.05294 .21126 Mdot
.31681 .16308 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50427 .00181 Mdot
.51361 .00577 Mdot
.54334 .01837 Mdot
.63727 .05805 Mdot
.91251 .17011 Mdot
.31248 .24719 Mdot
.49187 .11087 Mdot
.65906 .10333 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51786 .00757 Mdot
.55685 .0241 Mdot
.6793 .07568 Mdot
.01732 .20891 Mdot
.32941 .19288 Mdot
.43187 .06333 Mdot
.43523 .00208 Mdot
.34411 .56172 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.47879 .60904 Mdot
.43251 .58943 Mdot
.288 .52872 Mdot
.91154 .38537 Mdot
.66104 .46322 Mdot
.61294 .5883 Mdot
.72037 .0664 Mdot
.06242 .2114 Mdot
.31322 .155 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50608 .00258 Mdot
.51936 .00821 Mdot
.56162 .02612 Mdot
.69402 .08183 Mdot
.05053 .22034 Mdot
.33251 .17427 Mdot
.40714 .04612 Mdot
.35023 .58286 Mdot
.10039 .46362 Mdot
.70975 .37661 Mdot
.49815 .61725 Mdot
.49411 .61554 Mdot
.48124 .61008 Mdot
.44031 .59273 Mdot
.31192 .53869 Mdot
.96264 .40217 Mdot
.66889 .43648 Mdot
.58352 .56528 Mdot
.61778 .02117 Mdot
.813 .12066 Mdot
.2285 .25679 Mdot
.50006 2e-05 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.5057 .00242 Mdot
.51816 .0077 Mdot
.55781 .02451 Mdot
.68229 .07693 Mdot
.02422 .21132 Mdot
.32996 .18896 Mdot
.42646 .05964 Mdot
.41654 .6119 Mdot
.50078 .00033 Mdot
.5025 .00106 Mdot
.50797 .00338 Mdot
.52537 .01076 Mdot
.58068 .03418 Mdot
.7519 .10582 Mdot
.16183 .25335 Mdot
.36874 .12787 Mdot
.40032 .01952 Mdot
.29197 .55107 Mdot
.95315 .40863 Mdot
.68359 .45144 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.503 .00127 Mdot
.50955 .00405 Mdot
.53042 .0129 Mdot
.59665 .04093 Mdot
.79911 .12513 Mdot
.22903 .2657 Mdot
.42228 .11944 Mdot
.50354 .05022 Mdot
.59009 .05349 Mdot
.80468 .13262 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50346 .00147 Mdot
.51101 .00467 Mdot
.53506 .01487 Mdot
.61129 .04711 Mdot
.84117 .14208 Mdot
.27168 .26607 Mdot
.46566 .11989 Mdot
.60853 .0883 Mdot
.90187 .1813 Mdot
.33326 .26661 Mdot
.49927 .61772 Mdot
.49767 .61704 Mdot
.49256 .61488 Mdot
.47631 .60799 Mdot
.42465 .58611 Mdot
.26415 .51884 Mdot
.86586 .37188 Mdot
.64579 .48202 Mdot
.61508 .59905 Mdot
.74233 .07864 Mdot
.10803 .22602 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.47911 .60917 Mdot
.43352 .58986 Mdot
.29109 .53001 Mdot
.91785 .38735 Mdot
.66243 .46018 Mdot
.61051 .58595 Mdot
.71135 .06232 Mdot
.04393 .20554 Mdot
.31144 .16533 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51261 .00535 Mdot
.54015 .01702 Mdot
.62728 .05385 Mdot
.88562 .15966 Mdot
.30114 .25681 Mdot
.49014 .11681 Mdot
.66436 .10768 Mdot
.04359 .23437 Mdot
.35824 .19447 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51157 .00491 Mdot
.53685 .01563 Mdot
.61692 .04949 Mdot
.85703 .14839 Mdot
.28389 .26381 Mdot
.4774 .1196 Mdot
.63714 .09872 Mdot
.97805 .2107 Mdot
.35178 .23098 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49917 .61768 Mdot
.49734 .61691 Mdot
.49154 .61445 Mdot
.47304 .6066 Mdot
.41431 .58173 Mdot
.23315 .50607 Mdot
.8146 .35935 Mdot
.61538 .49491 Mdot
.57447 .59275 Mdot
.49843 .61737 Mdot
.49498 .61591 Mdot
.48401 .61126 Mdot
.44911 .59646 Mdot
.33915 .55008 Mdot
.02695 .42508 Mdot
.67452 .40022 Mdot
.53447 .53148 Mdot
.44571 .56318 Mdot
.27709 .51382 Mdot
.87319 .36841 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .0029 Mdot
.52181 .00925 Mdot
.56939 .0294 Mdot
.71777 .09171 Mdot
.10002 .23624 Mdot
.34192 .1495 Mdot
.3838 .02589 Mdot
.26647 .54552 Mdot
.91168 .39876 Mdot
.68268 .4765 Mdot
.49789 .61714 Mdot
.49329 .61519 Mdot
.47862 .60897 Mdot
.43197 .5892 Mdot
.28636 .52804 Mdot
.90822 .38433 Mdot
.66025 .46478 Mdot
.61404 .58948 Mdot
.72462 .06834 Mdot
.0709 .21401 Mdot
.31432 .15044 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51299 .00551 Mdot
.54136 .01753 Mdot
.63107 .05544 Mdot
.89589 .16367 Mdot
.30598 .25345 Mdot
.49195 .11494 Mdot
.66586 .10748 Mdot
.0459 .23488 Mdot
.35804 .19292 Mdot
.49984 .61796 Mdot
.49948 .61781 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48306 .61085 Mdot
.44608 .59518 Mdot
.32975 .54614 Mdot
.00405 .41674 Mdot
.67227 .41298 Mdot
.55132 .54328 Mdot
.50601 .59003 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.508 .00339 Mdot
.52547 .0108 Mdot
.58099 .03431 Mdot
.75282 .1062 Mdot
.16335 .25372 Mdot
.36966 .12751 Mdot
.40159 .01974 Mdot
.29514 .55224 Mdot
.95949 .41059 Mdot
.68395 .44775 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50428 .00181 Mdot
.51363 .00578 Mdot
.54339 .01839 Mdot
.63743 .05812 Mdot
.91294 .17027 Mdot
.31262 .24702 Mdot
.49182 .11075 Mdot
.65874 .10317 Mdot
.02622 .22711 Mdot
.35454 .20292 Mdot
.49959 .61786 Mdot
.49868 .61747 Mdot
.4958 .61625 Mdot
.48661 .61236 Mdot
.45736 .59996 Mdot
.36491 .5609 Mdot
.09329 .45017 Mdot
.68961 .36855 Mdot
.50769 .5056 Mdot
.3373 .51273 Mdot
.9632 .38683 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50577 .00245 Mdot
.51839 .0078 Mdot
.55853 .02481 Mdot
.68451 .07786 Mdot
.02929 .21309 Mdot
.33038 .18609 Mdot
.42255 .05696 Mdot
.40308 .606 Mdot
.24706 .52161 Mdot
.85235 .37409 Mdot
.50074 .00032 Mdot
.50237 .00101 Mdot
.50756 .00321 Mdot
.52408 .01021 Mdot
.57659 .03245 Mdot
.73961 .10075 Mdot
.14086 .24798 Mdot
.35734 .13379 Mdot
.38735 .01855 Mdot
.26215 .54066 Mdot
.89891 .39354 Mdot
.67731 .48108 Mdot
.49858 .61743 Mdot
.49549 .61612 Mdot
.48562 .61193 Mdot
.4542 .59862 Mdot
.35504 .55675 Mdot
.06728 .44019 Mdot
.68158 .37966 Mdot
.51289 .51378 Mdot
.3635 .52571 Mdot
.03356 .41412 Mdot
.65365 .38324 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51686 .00715 Mdot
.55367 .02275 Mdot
.66946 .07156 Mdot
.99407 .20062 Mdot
.32757 .20612 Mdot
.45014 .07575 Mdot
.49914 .03028 Mdot
.54685 .02949 Mdot
.66382 .07229 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50406 .00172 Mdot
.51294 .00549 Mdot
.5412 .01747 Mdot
.63057 .05524 Mdot
.89456 .16315 Mdot
.30539 .25391 Mdot
.4918 .11521 Mdot
.66591 .10761 Mdot
.04621 .23503 Mdot
.35816 .1928 Mdot
.49784 .61712 Mdot
.49311 .61511 Mdot
.47806 .60873 Mdot
.43019 .58845 Mdot
.28094 .52579 Mdot
.89744 .38102 Mdot
.65736 .46965 Mdot
.61669 .5929 Mdot
.7358 .07361 Mdot
.09269 .22057 Mdot
.31827 .13942 Mdot
.4978 .6171 Mdot
.493 .61507 Mdot
.47771 .60858 Mdot
.42908 .58798 Mdot
.27757 .52439 Mdot
.8909 .37906 Mdot
.65536 .47246 Mdot
.61757 .59468 Mdot
.74054 .076 Mdot
.10182 .22328 Mdot
.32057 .1352 Mdot
.49886 .61755 Mdot
.49636 .61649 Mdot
.4884 .61312 Mdot
.46306 .60237 Mdot
.38281 .56844 Mdot
.14224 .46935 Mdot
.7156 .35435 Mdot
.52213 .49847 Mdot
.36176 .51892 Mdot
.01912 .40628 Mdot
.64787 .38859 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50447 .00189 Mdot
.51423 .00603 Mdot
.5453 .0192 Mdot
.64341 .06064 Mdot
.92869 .17631 Mdot
.31739 .24023 Mdot
.48844 .10572 Mdot
.64217 .09501 Mdot
.98189 .20996 Mdot
.34872 .22671 Mdot
.49952 .61783 Mdot
.49848 .61739 Mdot
.49517 .61599 Mdot
.48462 .61151 Mdot
.45102 .59727 Mdot
.34511 .55258 Mdot
.04183 .4306 Mdot
.67653 .39226 Mdot
.52497 .52436 Mdot
.41071 .54742 Mdot
.16944 .46892 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49336 .61522 Mdot
.47886 .60907 Mdot
.43274 .58953 Mdot
.2887 .52901 Mdot
.91295 .38581 Mdot
.66136 .46254 Mdot
.61243 .58779 Mdot
.71847 .06553 Mdot
.05857 .21019 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50706 .003 Mdot
.5225 .00954 Mdot
.57159 .03034 Mdot
.72447 .09448 Mdot
.11301 .24013 Mdot
.34593 .14395 Mdot
.38219 .02241 Mdot
.25742 .54093 Mdot
.89419 .39354 Mdot
.67823 .48457 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00113 Mdot
.50845 .00359 Mdot
.52693 .01142 Mdot
.58561 .03627 Mdot
.76661 .11186 Mdot
.18504 .2586 Mdot
.38435 .12318 Mdot
.42504 .02515 Mdot
.35742 .57624 Mdot
.1034 .46104 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50923 .00392 Mdot
.52941 .01247 Mdot
.59345 .03958 Mdot
.78973 .12131 Mdot
.21735 .26428 Mdot
.41125 .11983 Mdot
.4788 .04175 Mdot
.51466 .02216 Mdot
.57247 .03573 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50266 .00113 Mdot
.50846 .00359 Mdot
.52695 .01143 Mdot
.58568 .03629 Mdot
.7668 .11194 Mdot
.18533 .25866 Mdot
.38457 .12313 Mdot
.42543 .02526 Mdot
.3585 .57667 Mdot
.10619 .4621 Mdot
.49967 .61789 Mdot
.49896 .61759 Mdot
.49667 .61662 Mdot
.4894 .61354 Mdot
.46623 .60371 Mdot
.39277 .57264 Mdot
.17038 .48058 Mdot
.7385 .35112 Mdot
.54474 .49828 Mdot
.41721 .53922 Mdot
.17103 .46588 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.4929 .61502 Mdot
.47739 .60845 Mdot
.42809 .58756 Mdot
.27455 .52314 Mdot
.88511 .37735 Mdot
.65342 .47484 Mdot
.61785 .59605 Mdot
.74334 .07756 Mdot
.50044 .00018 Mdot
.50139 .00059 Mdot
.50442 .00188 Mdot
.51409 .00597 Mdot
.54486 .01902 Mdot
.64203 .06006 Mdot
.92508 .17493 Mdot
.3164 .24185 Mdot
.48947 .10696 Mdot
.64676 .09721 Mdot
.99429 .21479 Mdot
.35038 .22008 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53224 .01367 Mdot
.60238 .04335 Mdot
.81573 .13185 Mdot
.24773 .26699 Mdot
.44103 .11946 Mdot
.54788 .06604 Mdot
.72548 .10976 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50325 .00138 Mdot
.51035 .00439 Mdot
.53298 .01398 Mdot
.60471 .04433 Mdot
.82242 .13455 Mdot
.25457 .26708 Mdot
.44809 .1196 Mdot
.56511 .07232 Mdot
.7771 .13102 Mdot
.22437 .27643 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52611 .01107 Mdot
.583 .03516 Mdot
.75882 .10866 Mdot
.17301 .25598 Mdot
.37586 .12537 Mdot
.41081 .0216 Mdot
.31887 .56121 Mdot
.0102 .42727 Mdot
.68624 .41782 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.5048 .00203 Mdot
.51528 .00648 Mdot
.54865 .02062 Mdot
.65387 .06503 Mdot
.95558 .18647 Mdot
.32306 .22712 Mdot
.47652 .09485 Mdot
.59489 .07316 Mdot
.84732 .15601 Mdot
.29522 .27682 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.50509 .00216 Mdot
.51622 .00688 Mdot
.55163 .02189 Mdot
.66314 .06892 Mdot
.97871 .19503 Mdot
.32612 .21471 Mdot
.46158 .08372 Mdot
.53996 .04845 Mdot
.67767 .08511 Mdot
.02988 .21768 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48789 .6129 Mdot
.46143 .60168 Mdot
.37767 .56627 Mdot
.12795 .4637 Mdot
.70633 .35745 Mdot
.5145 .49948 Mdot
.34439 .5129 Mdot
.97633 .39056 Mdot
.64364 .41242 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48105 .61 Mdot
.43969 .59247 Mdot
.31003 .5379 Mdot
.95841 .40072 Mdot
.66847 .43884 Mdot
.58662 .56745 Mdot
.62837 .0258 Mdot
.84246 .13232 Mdot
.25612 .25566 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51786 .00757 Mdot
.55685 .0241 Mdot
.67932 .07569 Mdot
.01736 .20892 Mdot
.32941 .19286 Mdot
.43184 .0633 Mdot
.43511 .00202 Mdot
.34373 .56155 Mdot
.05382 .43886 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51253 .00532 Mdot
.53992 .01692 Mdot
.62654 .05354 Mdot
.88361 .15888 Mdot
.30011 .25741 Mdot
.48962 .11712 Mdot
.66356 .1075 Mdot
.04187 .23381 Mdot
.49977 .61794 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47662 .60812 Mdot
.42562 .58652 Mdot
.26709 .52005 Mdot
.87119 .37336 Mdot
.64809 .48015 Mdot
.61645 .59847 Mdot
.74429 .07901 Mdot
.49949 .61782 Mdot
.49836 .61734 Mdot
.49478 .61582 Mdot
.48337 .61098 Mdot
.44706 .5956 Mdot
.33281 .54742 Mdot
.01142 .4194 Mdot
.67291 .40883 Mdot
.54568 .5394 Mdot
.48603 .58117 Mdot
.40544 .56823 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50412 .00175 Mdot
.51314 .00557 Mdot
.54184 .01774 Mdot
.63259 .05609 Mdot
.9 .16527 Mdot
.30774 .25199 Mdot
.49227 .11405 Mdot
.66522 .10689 Mdot
.04382 .23399 Mdot
.35752 .19387 Mdot
.49996 .61802 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.4986 .61744 Mdot
.49554 .61614 Mdot
.48579 .61201 Mdot
.45475 .59885 Mdot
.35674 .55746 Mdot
.07172 .44188 Mdot
.68272 .37762 Mdot
.51144 .51218 Mdot
.49829 .61731 Mdot
.49455 .61572 Mdot
.48263 .61067 Mdot
.4447 .59459 Mdot
.32548 .54435 Mdot
.99387 .41309 Mdot
.67146 .41877 Mdot
.55929 .54871 Mdot
.534 .60241 Mdot
.55933 .01566 Mdot
.67162 .0694 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.52301 .00976 Mdot
.57318 .03101 Mdot
.7293 .09649 Mdot
.12214 .24279 Mdot
.34923 .14035 Mdot
.3825 .02056 Mdot
.2551 .5393 Mdot
.8891 .39183 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.4913 .61434 Mdot
.47229 .60628 Mdot
.41192 .58072 Mdot
.22606 .50317 Mdot
.80417 .35729 Mdot
.60731 .49637 Mdot
.55951 .58849 Mdot
.5989 .02435 Mdot
.77728 .11024 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.47953 .60935 Mdot
.43486 .59043 Mdot
.2952 .53172 Mdot
.92637 .39008 Mdot
.66409 .45593 Mdot
.60659 .5825 Mdot
.69728 .05605 Mdot
.01373 .19558 Mdot
.30961 .18286 Mdot
.4987 .61748 Mdot
.49585 .61628 Mdot
.48679 .61243 Mdot
.45793 .6002 Mdot
.36669 .56165 Mdot
.09806 .45201 Mdot
.69147 .36675 Mdot
.50766 .50443 Mdot
.33532 .51152 Mdot
.95774 .38468 Mdot
.64281 .42339 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50798 .00339 Mdot
.52543 .01078 Mdot
.58087 .03426 Mdot
.75244 .10604 Mdot
.16273 .25357 Mdot
.36928 .12766 Mdot
.40107 .01965 Mdot
.29383 .55176 Mdot
.95685 .40977 Mdot
.68381 .44928 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50274 .00116 Mdot
.50874 .0037 Mdot
.52783 .0118 Mdot
.58846 .03747 Mdot
.77504 .11531 Mdot
.1974 .26104 Mdot
.39396 .12148 Mdot
.44295 .03028 Mdot
.4082 .59656 Mdot
.24326 .51609 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49774 .61707 Mdot
.49279 .61497 Mdot
.47702 .60829 Mdot
.42689 .58705 Mdot
.27092 .52164 Mdot
.87827 .37536 Mdot
.65093 .47753 Mdot
.61754 .5974 Mdot
.74487 .07869 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50527 .00223 Mdot
.51678 .00712 Mdot
.55343 .02265 Mdot
.66872 .07125 Mdot
.99227 .19997 Mdot
.32742 .20713 Mdot
.45152 .0767 Mdot
.50401 .03244 Mdot
.56252 .03616 Mdot
.71243 .09265 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53216 .01364 Mdot
.60215 .04325 Mdot
.81506 .13158 Mdot
.24703 .26697 Mdot
.44031 .11945 Mdot
.54613 .0654 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50669 .00284 Mdot
.52131 .00904 Mdot
.56781 .02874 Mdot
.71298 .08972 Mdot
.09046 .23329 Mdot
.33943 .15388 Mdot
.38639 .02902 Mdot
.27703 .55045 Mdot
.93238 .40503 Mdot
.68613 .46584 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00283 Mdot
.52123 .009 Mdot
.56753 .02862 Mdot
.71212 .08936 Mdot
.08872 .23275 Mdot
.33902 .1547 Mdot
.38697 .02964 Mdot
.27929 .55148 Mdot
.9369 .40643 Mdot
.6867 .4634 Mdot
.49801 .61719 Mdot
.49365 .61534 Mdot
.47976 .60945 Mdot
.43561 .59074 Mdot
.29748 .53267 Mdot
.93117 .39164 Mdot
.66491 .45348 Mdot
.60408 .58044 Mdot
.68848 .05216 Mdot
.99399 .18882 Mdot
.30852 .19439 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50495 .0021 Mdot
.51577 .00669 Mdot
.5502 .02128 Mdot
.65868 .06705 Mdot
.96767 .19096 Mdot
.32482 .22073 Mdot
.46914 .08919 Mdot
.56745 .06076 Mdot
.49797 .61717 Mdot
.49352 .61529 Mdot
.47937 .60929 Mdot
.43435 .59021 Mdot
.29363 .53107 Mdot
.9231 .38903 Mdot
.66348 .45758 Mdot
.60818 .58385 Mdot
.70293 .05856 Mdot
.02604 .1997 Mdot
.31027 .17566 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47834 .60885 Mdot
.4311 .58883 Mdot
.28369 .52693 Mdot
.90289 .38268 Mdot
.65888 .46723 Mdot
.61553 .59124 Mdot
.73066 .07115 Mdot
.08276 .21761 Mdot
.31624 .1443 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51854 .00786 Mdot
.55901 .02501 Mdot
.68599 .07848 Mdot
.03266 .21425 Mdot
.33068 .18419 Mdot
.41999 .0552 Mdot
.39427 .60214 Mdot
.22136 .51117 Mdot
.81358 .36601 Mdot
.49939 .61778 Mdot
.49806 .61721 Mdot
.49383 .61542 Mdot
.48036 .60971 Mdot
.4375 .59154 Mdot
.30327 .53508 Mdot
.94356 .39572 Mdot
.66675 .44696 Mdot
.59674 .57477 Mdot
.66308 .041 Mdot
.93343 .16708 Mdot
.49883 .61754 Mdot
.49629 .61646 Mdot
.48817 .61302 Mdot
.46233 .60206 Mdot
.38052 .56747 Mdot
.13584 .46682 Mdot
.71126 .35563 Mdot
.51837 .49882 Mdot
.35298 .51581 Mdot
.9971 .39809 Mdot
.64557 .40078 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.51091 .00462 Mdot
.53473 .01473 Mdot
.61025 .04667 Mdot
.83822 .1409 Mdot
.26918 .26635 Mdot
.46314 .11987 Mdot
.60231 .08601 Mdot
.49943 .61779 Mdot
.49817 .61726 Mdot
.49418 .61557 Mdot
.48145 .61017 Mdot
.44097 .59302 Mdot
.31397 .53954 Mdot
.96726 .40375 Mdot
.66931 .4339 Mdot
.58008 .56288 Mdot
.60595 .01599 Mdot
.77927 .10712 Mdot
.5008 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.52572 .0109 Mdot
.58177 .03464 Mdot
.75516 .10716 Mdot
.16715 .25463 Mdot
.37203 .12662 Mdot
.40499 .02037 Mdot
.30375 .55546 Mdot
.97726 .41625 Mdot
.68476 .43726 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51726 .00732 Mdot
.55495 .02329 Mdot
.67345 .07323 Mdot
.00359 .20404 Mdot
.32835 .20071 Mdot
.44272 .07069 Mdot
.47301 .01872 Mdot
.49752 .61698 Mdot
.4921 .61469 Mdot
.47485 .60737 Mdot
.42002 .58415 Mdot
.25022 .51309 Mdot
.84169 .36555 Mdot
.63335 .48928 Mdot
.60245 .59894 Mdot
.71484 .06946 Mdot
.06015 .21342 Mdot
.31737 .15897 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.48488 .61162 Mdot
.45188 .59763 Mdot
.34777 .5537 Mdot
.04859 .43313 Mdot
.67765 .38878 Mdot
.52119 .52134 Mdot
.39643 .54093 Mdot
.12704 .45154 Mdot
.6867 .34588 Mdot
.4992 .61769 Mdot
.49744 .61695 Mdot
.49183 .61457 Mdot
.47398 .607 Mdot
.41728 .58299 Mdot
.242 .50971 Mdot
.82829 .36235 Mdot
.62501 .4924 Mdot
.59054 .59673 Mdot
.68468 .05818 Mdot
.99773 .19347 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48373 .61114 Mdot
.44821 .59608 Mdot
.33638 .54891 Mdot
.02011 .42257 Mdot
.67376 .40398 Mdot
.53927 .53492 Mdot
.46309 .57095 Mdot
.33205 .53704 Mdot
.99329 .40867 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52198 .00932 Mdot
.56994 .02964 Mdot
.71945 .0924 Mdot
.10331 .23724 Mdot
.34286 .14805 Mdot
.38318 .02492 Mdot
.26357 .54412 Mdot
.90611 .39711 Mdot
.68145 .47919 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50777 .0033 Mdot
.52476 .0105 Mdot
.57874 .03336 Mdot
.74608 .10342 Mdot
.15207 .25092 Mdot
.36312 .13043 Mdot
.39323 .01861 Mdot
.27494 .54492 Mdot
.92084 .39919 Mdot
.68064 .46959 Mdot
.49932 .61774 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47791 .60867 Mdot
.42971 .58825 Mdot
.27948 .52519 Mdot
.8946 .38017 Mdot
.65651 .47089 Mdot
.61715 .5937 Mdot
.73806 .07473 Mdot
.09702 .22186 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.51689 .00716 Mdot
.55377 .02279 Mdot
.66977 .07169 Mdot
.9948 .20088 Mdot
.32763 .2057 Mdot
.44957 .07536 Mdot
.49713 .02939 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49229 .61477 Mdot
.47545 .60763 Mdot
.42194 .58496 Mdot
.25597 .51546 Mdot
.85144 .36802 Mdot
.63877 .4866 Mdot
.60886 .59955 Mdot
.72981 .07475 Mdot
.49816 .61725 Mdot
.49413 .61555 Mdot
.48131 .61011 Mdot
.44053 .59283 Mdot
.3126 .53897 Mdot
.96416 .40269 Mdot
.66903 .43563 Mdot
.5824 .56449 Mdot
.61392 .01948 Mdot
.80209 .1163 Mdot
.21632 .25601 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50588 .00249 Mdot
.51874 .00795 Mdot
.55963 .02528 Mdot
.6879 .07927 Mdot
.03696 .21573 Mdot
.33108 .18177 Mdot
.41677 .05296 Mdot
.38323 .5973 Mdot
.18983 .49851 Mdot
.77456 .36138 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50702 .00298 Mdot
.52235 .00948 Mdot
.5711 .03013 Mdot
.723 .09388 Mdot
.11019 .2393 Mdot
.34499 .14511 Mdot
.38234 .02308 Mdot
.25883 .5417 Mdot
.89696 .39439 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50963 .00408 Mdot
.53068 .01301 Mdot
.59745 .04127 Mdot
.80144 .12607 Mdot
.2318 .26598 Mdot
.42499 .1194 Mdot
.50978 .0524 Mdot
.60923 .06146 Mdot
.49753 .61698 Mdot
.49212 .61469 Mdot
.47489 .60738 Mdot
.42014 .5842 Mdot
.25057 .51323 Mdot
.84226 .36569 Mdot
.63369 .48913 Mdot
.60288 .599 Mdot
.71588 .06983 Mdot
.06214 .214 Mdot
.31754 .15785 Mdot
.49907 .61764 Mdot
.49702 .61677 Mdot
.49052 .61401 Mdot
.46979 .60523 Mdot
.40403 .57739 Mdot
.20288 .49372 Mdot
.77338 .35259 Mdot
.58005 .49855 Mdot
.50178 .56966 Mdot
.42619 .57132 Mdot
.24382 .50532 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50996 .00422 Mdot
.53172 .01345 Mdot
.60075 .04266 Mdot
.811 .12994 Mdot
.24266 .26678 Mdot
.43585 .1194 Mdot
.5354 .06152 Mdot
.4998 .61795 Mdot
.49938 .61777 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47985 .60949 Mdot
.43587 .59085 Mdot
.29828 .533 Mdot
.93285 .39219 Mdot
.66519 .45261 Mdot
.60315 .5797 Mdot
.68524 .05073 Mdot
.49833 .61732 Mdot
.49467 .61577 Mdot
.48301 .61083 Mdot
.44591 .59511 Mdot
.32922 .54592 Mdot
.00278 .41628 Mdot
.67217 .41371 Mdot
.5523 .54395 Mdot
.50949 .59157 Mdot
.48091 .60037 Mdot
.42375 .58271 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52335 .0099 Mdot
.57426 .03147 Mdot
.73257 .09784 Mdot
.12817 .2445 Mdot
.35164 .13811 Mdot
.38342 .01964 Mdot
.25556 .53901 Mdot
.88911 .39156 Mdot
.67586 .48624 Mdot
.49863 .61745 Mdot
.49565 .61619 Mdot
.48614 .61216 Mdot
.45587 .59932 Mdot
.36024 .55893 Mdot
.0809 .44539 Mdot
.68537 .37358 Mdot
.50915 .50913 Mdot
.34665 .5176 Mdot
.9881 .39644 Mdot
.64738 .40746 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50741 .00314 Mdot
.52361 .01001 Mdot
.57508 .03181 Mdot
.73504 .09886 Mdot
.13268 .24576 Mdot
.35357 .13651 Mdot
.3845 .01912 Mdot
.257 .53923 Mdot
.891 .39183 Mdot
.67601 .48517 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.5155 .00657 Mdot
.54933 .02091 Mdot
.656 .06592 Mdot
.96094 .18847 Mdot
.32389 .22431 Mdot
.47337 .09239 Mdot
.58311 .06782 Mdot
.81191 .14141 Mdot
.26161 .27793 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50763 .00323 Mdot
.52429 .0103 Mdot
.57726 .03273 Mdot
.74161 .10157 Mdot
.14436 .24891 Mdot
.35907 .1327 Mdot
.38894 .01846 Mdot
.2654 .54169 Mdot
.90426 .39483 Mdot
.67822 .47833 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50349 .00148 Mdot
.51111 .00471 Mdot
.53538 .015 Mdot
.61228 .04753 Mdot
.84397 .14319 Mdot
.27398 .26576 Mdot
.46796 .11989 Mdot
.61419 .09038 Mdot
.9174 .18739 Mdot
.33902 .26057 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50693 .00294 Mdot
.52209 .00937 Mdot
.57028 .02978 Mdot
.7205 .09284 Mdot
.10537 .23786 Mdot
.34348 .14716 Mdot
.38286 .02434 Mdot
.26197 .54332 Mdot
.90302 .39619 Mdot
.68071 .48064 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51256 .00533 Mdot
.54001 .01696 Mdot
.62684 .05366 Mdot
.88442 .15919 Mdot
.30053 .25717 Mdot
.48984 .117 Mdot
.6639 .10758 Mdot
.04262 .23406 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51846 .00783 Mdot
.55876 .02491 Mdot
.68522 .07815 Mdot
.03091 .21365 Mdot
.33052 .18517 Mdot
.42132 .05611 Mdot
.39883 .60414 Mdot
.23461 .51654 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00305 Mdot
.52288 .0097 Mdot
.57278 .03084 Mdot
.72808 .09598 Mdot
.11986 .24213 Mdot
.34836 .14123 Mdot
.3823 .02098 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47345 .60677 Mdot
.41558 .58227 Mdot
.23694 .50763 Mdot
.82038 .36058 Mdot
.61958 .49393 Mdot
.58175 .59465 Mdot
.66121 .04911 Mdot
.94322 .17429 Mdot
.3086 .22582 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50585 .00248 Mdot
.51863 .0079 Mdot
.55928 .02513 Mdot
.68682 .07882 Mdot
.03452 .21489 Mdot
.33085 .18314 Mdot
.41859 .05423 Mdot
.38946 .60003 Mdot
.20755 .5056 Mdot
.49863 .61745 Mdot
.49563 .61618 Mdot
.48606 .61212 Mdot
.45562 .59922 Mdot
.35947 .55861 Mdot
.07885 .44461 Mdot
.68474 .37446 Mdot
.50957 .50977 Mdot
.34876 .51864 Mdot
.99371 .3986 Mdot
.6481 .40443 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.52571 .0109 Mdot
.58174 .03463 Mdot
.75506 .10712 Mdot
.16699 .25459 Mdot
.37193 .12666 Mdot
.40484 .02034 Mdot
.30336 .55532 Mdot
.97645 .41599 Mdot
.68473 .43774 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00342 Mdot
.52566 .01088 Mdot
.58158 .03456 Mdot
.75457 .10692 Mdot
.1662 .2544 Mdot
.37143 .12684 Mdot
.40412 .0202 Mdot
.30151 .55462 Mdot
.49979 .61794 Mdot
.49933 .61775 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47833 .60885 Mdot
.43107 .58882 Mdot
.28361 .5269 Mdot
.90272 .38263 Mdot
.65883 .4673 Mdot
.61557 .5913 Mdot
.73083 .07123 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49399 .61549 Mdot
.48086 .60992 Mdot
.43909 .59222 Mdot
.30815 .53711 Mdot
.95425 .39931 Mdot
.66803 .44114 Mdot
.58957 .56955 Mdot
.6385 .03024 Mdot
.86993 .14303 Mdot
.49921 .6177 Mdot
.4975 .61697 Mdot
.49203 .61465 Mdot
.4746 .60727 Mdot
.41925 .58382 Mdot
.24789 .51213 Mdot
.83782 .3646 Mdot
.63105 .49025 Mdot
.59939 .59847 Mdot
.70731 .0667 Mdot
.04542 .20896 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00348 Mdot
.52617 .0111 Mdot
.5832 .03525 Mdot
.75942 .10891 Mdot
.17396 .2562 Mdot
.3765 .12518 Mdot
.41182 .02183 Mdot
.32154 .56224 Mdot
.01623 .42935 Mdot
.68662 .41432 Mdot
.49964 .61788 Mdot
.49884 .61754 Mdot
.49632 .61647 Mdot
.48826 .61306 Mdot
.46261 .60218 Mdot
.3814 .56784 Mdot
.1383 .46779 Mdot
.71289 .35512 Mdot
.51975 .49867 Mdot
.35616 .51693 Mdot
.005 .40101 Mdot
.49772 .61707 Mdot
.49272 .61495 Mdot
.47681 .6082 Mdot
.42624 .58678 Mdot
.26894 .52082 Mdot
.8746 .37432 Mdot
.64949 .47891 Mdot
.61707 .598 Mdot
.74485 .07897 Mdot
.11124 .22644 Mdot
.32402 .13151 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50556 .00236 Mdot
.51771 .00751 Mdot
.55638 .0239 Mdot
.67787 .07508 Mdot
.01399 .20773 Mdot
.32915 .19478 Mdot
.4345 .06511 Mdot
.44434 .00608 Mdot
.37237 .57356 Mdot
.12884 .46752 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51513 .00642 Mdot
.54818 .02042 Mdot
.65238 .0644 Mdot
.95181 .18506 Mdot
.32242 .22905 Mdot
.47859 .09652 Mdot
.60275 .07673 Mdot
.49868 .61748 Mdot
.49581 .61626 Mdot
.48664 .61237 Mdot
.45746 .6 Mdot
.36522 .56103 Mdot
.09413 .45049 Mdot
.68993 .36822 Mdot
.50766 .50538 Mdot
.33688 .51249 Mdot
.96207 .38639 Mdot
.64361 .42122 Mdot
.49804 .6172 Mdot
.49376 .61539 Mdot
.48013 .60961 Mdot
.43676 .59123 Mdot
.30101 .53413 Mdot
.93868 .3941 Mdot
.66607 .44955 Mdot
.59977 .57706 Mdot
.67351 .04557 Mdot
.95893 .1764 Mdot
.30528 .21405 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51563 .00663 Mdot
.54977 .0211 Mdot
.65735 .06649 Mdot
.96433 .18973 Mdot
.32437 .22252 Mdot
.47128 .09079 Mdot
.57533 .06431 Mdot
.7882 .13156 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50455 .00193 Mdot
.5145 .00615 Mdot
.54616 .01957 Mdot
.6461 .06177 Mdot
.93568 .17897 Mdot
.31914 .23699 Mdot
.48603 .10315 Mdot
.632 .09021 Mdot
.95403 .19903 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.4778 .60862 Mdot
.42938 .58811 Mdot
.27846 .52476 Mdot
.89262 .37957 Mdot
.6559 .47174 Mdot
.6174 .59424 Mdot
.73945 .07543 Mdot
.49828 .6173 Mdot
.49451 .6157 Mdot
.4825 .61061 Mdot
.44429 .59442 Mdot
.32422 .54382 Mdot
.9909 .41203 Mdot
.67123 .42047 Mdot
.56164 .5503 Mdot
.5422 .60602 Mdot
.58534 .02666 Mdot
.75043 .10203 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50642 .00272 Mdot
.52047 .00868 Mdot
.56512 .0276 Mdot
.70475 .0863 Mdot
.07353 .22792 Mdot
.3359 .16215 Mdot
.39346 .03558 Mdot
.3029 .56206 Mdot
.98666 .42259 Mdot
.69041 .43494 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.50912 .00387 Mdot
.52906 .01232 Mdot
.59235 .03912 Mdot
.78653 .12001 Mdot
.21318 .26368 Mdot
.40745 .12007 Mdot
.4706 .03903 Mdot
.4899 .01193 Mdot
.49406 .00257 Mdot
.50064 .00027 Mdot
.50202 .00086 Mdot
.50645 .00273 Mdot
.52054 .00871 Mdot
.56534 .02769 Mdot
.70544 .08658 Mdot
.07497 .22838 Mdot
.33616 .16142 Mdot
.39275 .03497 Mdot
.30037 .56094 Mdot
.98111 .42072 Mdot
.69012 .43819 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51074 .00455 Mdot
.53421 .0145 Mdot
.60859 .04597 Mdot
.8335 .139 Mdot
.26504 .2667 Mdot
.45891 .11982 Mdot
.59182 .08214 Mdot
.85495 .16262 Mdot
.49932 .61775 Mdot
.49783 .61711 Mdot
.49309 .6151 Mdot
.47799 .6087 Mdot
.42998 .58836 Mdot
.28029 .52552 Mdot
.89618 .38064 Mdot
.65699 .4702 Mdot
.61691 .59326 Mdot
.73684 .07412 Mdot
.09468 .22116 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50283 .0012 Mdot
.50901 .00382 Mdot
.52871 .01218 Mdot
.59125 .03865 Mdot
.78329 .11869 Mdot
.20886 .26302 Mdot
.40363 .12037 Mdot
.46251 .03639 Mdot
.46566 .00195 Mdot
.41771 .5884 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48802 .61296 Mdot
.46186 .60186 Mdot
.37902 .56684 Mdot
.1317 .46518 Mdot
.70861 .35655 Mdot
.51623 .49914 Mdot
.34816 .51416 Mdot
.98533 .3938 Mdot
.64448 .40737 Mdot
.49908 .61764 Mdot
.49706 .61679 Mdot
.49064 .61406 Mdot
.47019 .60539 Mdot
.40527 .57791 Mdot
.20651 .49519 Mdot
.77787 .35312 Mdot
.58431 .49841 Mdot
.51139 .57297 Mdot
.45555 .58352 Mdot
.33388 .54284 Mdot
.49941 .61779 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48104 .60999 Mdot
.43965 .59245 Mdot
.30988 .53783 Mdot
.95808 .40061 Mdot
.66844 .43903 Mdot
.58685 .56761 Mdot
.62919 .02616 Mdot
.84471 .1332 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47982 .60948 Mdot
.43579 .59082 Mdot
.29802 .53289 Mdot
.93231 .39201 Mdot
.6651 .45289 Mdot
.60345 .57994 Mdot
.68629 .0512 Mdot
.98899 .18708 Mdot
.30819 .19728 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50528 .00224 Mdot
.51683 .00713 Mdot
.55356 .0227 Mdot
.66913 .07143 Mdot
.99327 .20033 Mdot
.3275 .20657 Mdot
.45075 .07617 Mdot
.50131 .03125 Mdot
.55383 .03246 Mdot
.68556 .08141 Mdot
.50072 .00031 Mdot
.5023 .00097 Mdot
.50732 .0031 Mdot
.52331 .00989 Mdot
.57415 .03142 Mdot
.73224 .0977 Mdot
.12758 .24433 Mdot
.35139 .13832 Mdot
.38331 .01972 Mdot
.25544 .53901 Mdot
.88899 .39155 Mdot
.67587 .48632 Mdot
.49757 .617 Mdot
.49226 .61475 Mdot
.47536 .60758 Mdot
.42163 .58483 Mdot
.25504 .51507 Mdot
.84983 .3676 Mdot
.63791 .48706 Mdot
.60793 .5995 Mdot
.72772 .07403 Mdot
.0839 .22013 Mdot
.31998 .1459 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48031 .60969 Mdot
.43736 .59148 Mdot
.30284 .5349 Mdot
.94262 .39541 Mdot
.66662 .44746 Mdot
.59734 .57521 Mdot
.66512 .04189 Mdot
.93848 .16895 Mdot
.30184 .22457 Mdot
.49939 .61778 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48038 .60972 Mdot
.43757 .59157 Mdot
.30349 .53517 Mdot
.94405 .39588 Mdot
.66681 .44669 Mdot
.59643 .57454 Mdot
.662 .04053 Mdot
.93074 .16609 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50623 .00264 Mdot
.51984 .00841 Mdot
.56313 .02676 Mdot
.69866 .08376 Mdot
.06062 .2237 Mdot
.33383 .16885 Mdot
.40066 .0413 Mdot
.32796 .57311 Mdot
.04462 .44291 Mdot
.69522 .40209 Mdot
.49845 .61738 Mdot
.49507 .61594 Mdot
.48431 .61138 Mdot
.45003 .59685 Mdot
.34204 .55129 Mdot
.03412 .42773 Mdot
.67542 .39634 Mdot
.52971 .52798 Mdot
.42829 .55536 Mdot
.22293 .49111 Mdot
.78227 .34569 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51749 .00742 Mdot
.55568 .0236 Mdot
.67571 .07418 Mdot
.00892 .20594 Mdot
.32876 .19767 Mdot
.43851 .06783 Mdot
.45829 .01223 Mdot
.41623 .59204 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48053 .60978 Mdot
.43805 .59178 Mdot
.30498 .53579 Mdot
.94729 .39696 Mdot
.66722 .44494 Mdot
.59432 .57298 Mdot
.65476 .03735 Mdot
.91245 .15926 Mdot
.29494 .23639 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.5041 .00174 Mdot
.51305 .00553 Mdot
.54155 .01761 Mdot
.63167 .0557 Mdot
.89752 .16431 Mdot
.30669 .25288 Mdot
.49211 .11459 Mdot
.66569 .10728 Mdot
.04528 .2346 Mdot
.35786 .19319 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50607 .00257 Mdot
.51933 .0082 Mdot
.56151 .02607 Mdot
.69368 .08168 Mdot
.04979 .22009 Mdot
.33243 .17468 Mdot
.40764 .04649 Mdot
.35196 .58362 Mdot
.10489 .46534 Mdot
.49747 .61696 Mdot
.49192 .61461 Mdot
.47428 .60713 Mdot
.41821 .58338 Mdot
.24479 .51085 Mdot
.83277 .36339 Mdot
.62791 .49143 Mdot
.59493 .59765 Mdot
.69606 .0625 Mdot
.02234 .20165 Mdot
.31522 .18101 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50295 .00125 Mdot
.50939 .00398 Mdot
.52991 .01268 Mdot
.59502 .04024 Mdot
.79434 .12319 Mdot
.22319 .26504 Mdot
.41669 .11959 Mdot
.49085 .04583 Mdot
.5513 .03736 Mdot
.68737 .0841 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00165 Mdot
.51237 .00524 Mdot
.53939 .0167 Mdot
.62488 .05284 Mdot
.87906 .15709 Mdot
.29769 .25872 Mdot
.48822 .11775 Mdot
.6611 .10684 Mdot
.03642 .23196 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51227 .0052 Mdot
.53907 .01656 Mdot
.62389 .05242 Mdot
.87634 .15602 Mdot
.29617 .25947 Mdot
.48724 .11809 Mdot
.65921 .10628 Mdot
.0321 .23046 Mdot
.35717 .20091 Mdot
.49919 .61769 Mdot
.49743 .61694 Mdot
.49182 .61456 Mdot
.47393 .60698 Mdot
.41712 .58292 Mdot
.24153 .50951 Mdot
.82755 .36218 Mdot
.62452 .49255 Mdot
.58978 .59656 Mdot
.68267 .05741 Mdot
.99325 .19195 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00207 Mdot
.51552 .00658 Mdot
.54941 .02094 Mdot
.65622 .06602 Mdot
.96151 .18868 Mdot
.32397 .22401 Mdot
.47303 .09212 Mdot
.58181 .06723 Mdot
.80798 .13978 Mdot
.25722 .27764 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47385 .60694 Mdot
.41685 .58281 Mdot
.24073 .50919 Mdot
.82628 .36189 Mdot
.62367 .49281 Mdot
.58844 .59626 Mdot
.67914 .05606 Mdot
.98531 .18922 Mdot
.31348 .20282 Mdot
.49926 .61772 Mdot
.49765 .61704 Mdot
.49251 .61486 Mdot
.47613 .60791 Mdot
.4241 .58587 Mdot
.26247 .51815 Mdot
.86285 .37105 Mdot
.64442 .48304 Mdot
.61409 .59929 Mdot
.7406 .07819 Mdot
.10544 .22548 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50947 .00402 Mdot
.53017 .01279 Mdot
.59585 .04059 Mdot
.79676 .12417 Mdot
.22618 .26539 Mdot
.41953 .1195 Mdot
.49726 .04804 Mdot
.57087 .0455 Mdot
.74731 .10905 Mdot
.50003 1e-05 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58507 .03604 Mdot
.765 .1112 Mdot
.1826 .25809 Mdot
.38255 .12358 Mdot
.4219 .02432 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00131 Mdot
.50987 .00419 Mdot
.53144 .01333 Mdot
.59987 .04229 Mdot
.80845 .12891 Mdot
.23985 .26662 Mdot
.433 .11937 Mdot
.52859 .05908 Mdot
.66684 .08544 Mdot
.01196 .2133 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50789 .00334 Mdot
.52513 .01065 Mdot
.5799 .03385 Mdot
.74954 .10484 Mdot
.15791 .25239 Mdot
.36641 .12886 Mdot
.39725 .01906 Mdot
.28444 .54831 Mdot
.93846 .40421 Mdot
.68251 .45985 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00127 Mdot
.50951 .00403 Mdot
.53029 .01284 Mdot
.59623 .04075 Mdot
.79787 .12462 Mdot
.22753 .26554 Mdot
.42083 .11947 Mdot
.50022 .04906 Mdot
.57993 .04927 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51067 .00452 Mdot
.53398 .01441 Mdot
.60789 .04567 Mdot
.83151 .13821 Mdot
.26323 .26682 Mdot
.45705 .11979 Mdot
.58722 .08045 Mdot
.84177 .15732 Mdot
.29645 .28101 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50415 .00176 Mdot
.51322 .00561 Mdot
.54211 .01785 Mdot
.63341 .05643 Mdot
.90222 .16613 Mdot
.30864 .25118 Mdot
.49235 .11354 Mdot
.66459 .10645 Mdot
.042 .23325 Mdot
.35714 .19477 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50725 .00308 Mdot
.52311 .0098 Mdot
.5735 .03114 Mdot
.73026 .09688 Mdot
.12392 .2433 Mdot
.34992 .13968 Mdot
.38271 .02027 Mdot
.25507 .53915 Mdot
.88881 .39168 Mdot
.6761 .48657 Mdot
.49961 .61787 Mdot
.49875 .6175 Mdot
.496 .61634 Mdot
.48727 .61263 Mdot
.45945 .60084 Mdot
.37145 .56365 Mdot
.11092 .45702 Mdot
.69716 .36231 Mdot
.50909 .5018 Mdot
.33464 .51022 Mdot
.95443 .38305 Mdot
.49903 .61762 Mdot
.49691 .61672 Mdot
.49016 .61386 Mdot
.46865 .60474 Mdot
.40044 .57587 Mdot
.19242 .48947 Mdot
.76113 .35148 Mdot
.56798 .49866 Mdot
.47374 .55979 Mdot
.34029 .53556 Mdot
.00551 .41113 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50629 .00267 Mdot
.52005 .0085 Mdot
.5638 .02704 Mdot
.7007 .08461 Mdot
.06496 .22513 Mdot
.33447 .16656 Mdot
.39808 .03932 Mdot
.31906 .56919 Mdot
.02343 .43532 Mdot
.69278 .41368 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00162 Mdot
.51214 .00515 Mdot
.53865 .01639 Mdot
.62257 .05187 Mdot
.87271 .15459 Mdot
.29407 .26041 Mdot
.48579 .11849 Mdot
.65621 .10533 Mdot
.0251 .22799 Mdot
.3565 .20481 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.50539 .00229 Mdot
.51718 .00728 Mdot
.55469 .02318 Mdot
.67262 .07289 Mdot
.00162 .20333 Mdot
.32819 .20183 Mdot
.44427 .07174 Mdot
.47844 .02112 Mdot
.48038 .0012 Mdot
.45296 .60109 Mdot
.49832 .61732 Mdot
.49465 .61577 Mdot
.48296 .61081 Mdot
.44575 .59504 Mdot
.32874 .54572 Mdot
.00162 .41586 Mdot
.67207 .41436 Mdot
.5532 .54457 Mdot
.51265 .59298 Mdot
.49107 .60469 Mdot
.4561 .59642 Mdot
.49806 .61721 Mdot
.49383 .61542 Mdot
.48034 .6097 Mdot
.43742 .59151 Mdot
.30304 .53498 Mdot
.94306 .39555 Mdot
.66668 .44722 Mdot
.59706 .575 Mdot
.66416 .04147 Mdot
.93611 .16807 Mdot
.30134 .22572 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.4794 .6093 Mdot
.43446 .59026 Mdot
.29397 .5312 Mdot
.9238 .38925 Mdot
.66361 .45723 Mdot
.60785 .58357 Mdot
.70175 .05804 Mdot
.0235 .19885 Mdot
.31013 .17715 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51624 .00689 Mdot
.5517 .02191 Mdot
.66335 .069 Mdot
.97921 .19521 Mdot
.32617 .21443 Mdot
.46122 .08346 Mdot
.53867 .04787 Mdot
.67354 .08336 Mdot
.02013 .2142 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52444 .01036 Mdot
.57771 .03293 Mdot
.74297 .10214 Mdot
.14673 .24954 Mdot
.36028 .13198 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50994 .00422 Mdot
.53167 .01343 Mdot
.60059 .04259 Mdot
.81054 .12976 Mdot
.24216 .26676 Mdot
.43534 .11939 Mdot
.53417 .06108 Mdot
.68387 .09252 Mdot
.49939 .61778 Mdot
.49805 .61721 Mdot
.4938 .61541 Mdot
.48025 .60966 Mdot
.43716 .5914 Mdot
.30222 .53464 Mdot
.9413 .39497 Mdot
.66644 .44816 Mdot
.59816 .57584 Mdot
.66797 .04314 Mdot
.9455 .17152 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.4275 .58731 Mdot
.27278 .52241 Mdot
.88176 .37637 Mdot
.65223 .47618 Mdot
.61779 .59675 Mdot
.74434 .07821 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50357 .00152 Mdot
.51139 .00483 Mdot
.53626 .01538 Mdot
.61507 .0487 Mdot
.85183 .14633 Mdot
.2801 .26469 Mdot
.4739 .11977 Mdot
.62872 .09569 Mdot
.95625 .20243 Mdot
.34858 .24247 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50831 .00353 Mdot
.52649 .01123 Mdot
.5842 .03567 Mdot
.76242 .11014 Mdot
.17864 .25724 Mdot
.37972 .12428 Mdot
.41708 .02309 Mdot
.33562 .56769 Mdot
.4975 .61697 Mdot
.49204 .61466 Mdot
.47463 .60728 Mdot
.41933 .58385 Mdot
.24813 .51223 Mdot
.83821 .36469 Mdot
.63129 .49015 Mdot
.59972 .59852 Mdot
.70812 .067 Mdot
.04704 .20946 Mdot
.31642 .16649 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51495 .00634 Mdot
.54761 .02018 Mdot
.65061 .06366 Mdot
.94728 .18335 Mdot
.32159 .23134 Mdot
.48093 .09847 Mdot
.61172 .08084 Mdot
.89668 .17611 Mdot
.32596 .26531 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48389 .6112 Mdot
.44872 .59629 Mdot
.33794 .54957 Mdot
.02396 .42398 Mdot
.67417 .40186 Mdot
.53654 .53297 Mdot
.45322 .56654 Mdot
.30075 .5238 Mdot
.92158 .38369 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.51941 .00823 Mdot
.56176 .02617 Mdot
.69444 .082 Mdot
.05144 .22064 Mdot
.33262 .17378 Mdot
.40652 .04567 Mdot
.34814 .58195 Mdot
.09498 .46157 Mdot
.70766 .37866 Mdot
.49765 .61704 Mdot
.49252 .61486 Mdot
.47617 .60793 Mdot
.4242 .58592 Mdot
.26278 .51827 Mdot
.86339 .3712 Mdot
.64467 .48286 Mdot
.61428 .59925 Mdot
.74095 .07829 Mdot
.10596 .22559 Mdot
.32352 .13446 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.4853 .6118 Mdot
.45319 .59819 Mdot
.35189 .55542 Mdot
.05912 .43709 Mdot
.6797 .38354 Mdot
.51609 .51692 Mdot
.37659 .53182 Mdot
.06997 .42853 Mdot
.66174 .36574 Mdot
.49999 .61803 Mdot
.49997 .61802 Mdot
.49989 .61799 Mdot
.49965 .61788 Mdot
.49887 .61756 Mdot
.49642 .61651 Mdot
.48858 .61319 Mdot
.46362 .60261 Mdot
.38458 .56918 Mdot
.14718 .47132 Mdot
.71916 .3535 Mdot
.49798 .61718 Mdot
.49357 .61531 Mdot
.47952 .60935 Mdot
.43483 .59041 Mdot
.29509 .53167 Mdot
.92613 .39001 Mdot
.66404 .45606 Mdot
.60671 .5826 Mdot
.69771 .05624 Mdot
.01468 .1959 Mdot
.30966 .18231 Mdot
.498 .61719 Mdot
.49364 .61533 Mdot
.47972 .60944 Mdot
.43548 .59069 Mdot
.29709 .5325 Mdot
.93033 .39137 Mdot
.66477 .45391 Mdot
.60453 .5808 Mdot
.69005 .05286 Mdot
.99758 .19006 Mdot
.30873 .19231 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00212 Mdot
.51596 .00677 Mdot
.55082 .02154 Mdot
.66063 .06786 Mdot
.97251 .19275 Mdot
.32542 .21811 Mdot
.46591 .08683 Mdot
.55564 .05546 Mdot
.72716 .106 Mdot
.13495 .25203 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48306 .61085 Mdot
.44608 .59518 Mdot
.32977 .54615 Mdot
.00408 .41675 Mdot
.67227 .41297 Mdot
.55129 .54326 Mdot
.50593 .59 Mdot
.46946 .59549 Mdot
.38746 .56735 Mdot
.49863 .61745 Mdot
.49565 .61619 Mdot
.48613 .61215 Mdot
.45585 .59932 Mdot
.36019 .55891 Mdot
.08076 .44534 Mdot
.68532 .37364 Mdot
.50918 .50917 Mdot
.34679 .51768 Mdot
.98849 .39659 Mdot
.64743 .40725 Mdot
.49943 .61779 Mdot
.4982 .61727 Mdot
.49425 .6156 Mdot
.48169 .61027 Mdot
.44173 .59334 Mdot
.31632 .54052 Mdot
.97259 .4056 Mdot
.66978 .43088 Mdot
.576 .56008 Mdot
.59195 .00986 Mdot
.73828 .09044 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52545 .01079 Mdot
.58092 .03428 Mdot
.7526 .10611 Mdot
.16299 .25363 Mdot
.36944 .12759 Mdot
.40128 .01968 Mdot
.29437 .55196 Mdot
.95795 .41011 Mdot
.68387 .44865 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47344 .60677 Mdot
.41557 .58226 Mdot
.23689 .50761 Mdot
.8203 .36056 Mdot
.61953 .49395 Mdot
.58166 .59463 Mdot
.66097 .04902 Mdot
.94262 .17407 Mdot
.30849 .22612 Mdot
.49794 .61716 Mdot
.49345 .61526 Mdot
.47913 .60919 Mdot
.43361 .5899 Mdot
.29136 .53012 Mdot
.9184 .38753 Mdot
.66254 .45991 Mdot
.61028 .58573 Mdot
.71051 .06194 Mdot
.04215 .20497 Mdot
.31131 .16635 Mdot
.49884 .61754 Mdot
.49629 .61646 Mdot
.48818 .61302 Mdot
.46237 .60208 Mdot
.38064 .56752 Mdot
.13618 .46695 Mdot
.71148 .35556 Mdot
.51855 .4988 Mdot
.3534 .51596 Mdot
.99814 .39847 Mdot
.64567 .4002 Mdot
.49828 .6173 Mdot
.49452 .61571 Mdot
.48255 .61063 Mdot
.44444 .59448 Mdot
.32467 .54402 Mdot
.99198 .41242 Mdot
.67131 .41985 Mdot
.56078 .54972 Mdot
.53923 .60471 Mdot
.57592 .02268 Mdot
.72221 .09042 Mdot
.49999 .61803 Mdot
.49996 .61802 Mdot
.49987 .61798 Mdot
.49958 .61785 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.48629 .61222 Mdot
.45636 .59953 Mdot
.36177 .55958 Mdot
.08495 .44695 Mdot
.68667 .37188 Mdot
.50008 4e-05 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50854 .00362 Mdot
.5272 .01153 Mdot
.58647 .03663 Mdot
.76916 .11291 Mdot
.18885 .25938 Mdot
.38721 .1226 Mdot
.4302 .02657 Mdot
.37183 .58196 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50661 .0028 Mdot
.52105 .00893 Mdot
.56697 .02838 Mdot
.71042 .08865 Mdot
.08525 .23166 Mdot
.33824 .15635 Mdot
.38824 .03091 Mdot
.28406 .55364 Mdot
.94658 .40946 Mdot
.68774 .45806 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.5036 .00153 Mdot
.51146 .00486 Mdot
.53649 .01547 Mdot
.61579 .04901 Mdot
.85384 .14712 Mdot
.28159 .26436 Mdot
.47529 .11972 Mdot
.63209 .0969 Mdot
.96504 .20578 Mdot
.35001 .23792 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00202 Mdot
.51515 .00642 Mdot
.54823 .02045 Mdot
.65256 .06448 Mdot
.95225 .18522 Mdot
.3225 .22883 Mdot
.47836 .09633 Mdot
.60185 .07632 Mdot
.86791 .16443 Mdot
.31013 .2733 Mdot
.49738 .61692 Mdot
.49165 .61449 Mdot
.47341 .60676 Mdot
.41546 .58222 Mdot
.23658 .50748 Mdot
.81981 .36046 Mdot
.61918 .49404 Mdot
.58107 .59448 Mdot
.65938 .0484 Mdot
.93875 .17266 Mdot
.30775 .22805 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.5062 .00263 Mdot
.51976 .00838 Mdot
.56287 .02665 Mdot
.69786 .08343 Mdot
.05889 .22313 Mdot
.33358 .16977 Mdot
.40172 .04211 Mdot
.33162 .57471 Mdot
.0535 .44615 Mdot
.69663 .39748 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52317 .00983 Mdot
.5737 .03123 Mdot
.73088 .09714 Mdot
.12507 .24362 Mdot
.35037 .13925 Mdot
.38287 .02009 Mdot
.25512 .53908 Mdot
.88876 .39161 Mdot
.676 .48654 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54656 .01974 Mdot
.64736 .06229 Mdot
.93893 .1802 Mdot
.31988 .23544 Mdot
.48473 .10189 Mdot
.62673 .08776 Mdot
.93936 .19322 Mdot
.4981 .61723 Mdot
.49393 .61546 Mdot
.48066 .60984 Mdot
.43847 .59195 Mdot
.30625 .53632 Mdot
.95006 .3979 Mdot
.66756 .44343 Mdot
.59246 .57162 Mdot
.64838 .03456 Mdot
.896 .15304 Mdot
.28875 .24273 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50531 .00225 Mdot
.51693 .00718 Mdot
.55388 .02284 Mdot
.67013 .07184 Mdot
.99566 .20119 Mdot
.3277 .20521 Mdot
.44891 .07491 Mdot
.49478 .02835 Mdot
.53283 .02351 Mdot
.61976 .05373 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.53569 .01513 Mdot
.61327 .04794 Mdot
.84676 .14431 Mdot
.27621 .26541 Mdot
.47015 .11986 Mdot
.61959 .09236 Mdot
.932 .19308 Mdot
.34334 .25422 Mdot
.49784 .61712 Mdot
.49311 .61511 Mdot
.47803 .60872 Mdot
.43012 .58842 Mdot
.28073 .5257 Mdot
.89703 .3809 Mdot
.65724 .46983 Mdot
.61677 .59302 Mdot
.73614 .07378 Mdot
.09335 .22077 Mdot
.31842 .1391 Mdot
.49749 .61697 Mdot
.49199 .61464 Mdot
.47448 .60721 Mdot
.41887 .58366 Mdot
.24675 .51166 Mdot
.83595 .36415 Mdot
.62991 .49069 Mdot
.5978 .59819 Mdot
.70334 .06523 Mdot
.03742 .20647 Mdot
.31589 .1721 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50331 .0014 Mdot
.51054 .00447 Mdot
.53356 .01423 Mdot
.60655 .04511 Mdot
.8277 .13668 Mdot
.25969 .26698 Mdot
.45339 .11971 Mdot
.57818 .07712 Mdot
.81558 .14672 Mdot
.27173 .28192 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50688 .00292 Mdot
.52191 .00929 Mdot
.5697 .02954 Mdot
.71872 .0921 Mdot
.10188 .23681 Mdot
.34245 .14868 Mdot
.38343 .02533 Mdot
.26478 .5447 Mdot
.90843 .3978 Mdot
.68198 .47808 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52164 .00917 Mdot
.56884 .02917 Mdot
.7161 .09102 Mdot
.09671 .23523 Mdot
.34101 .15099 Mdot
.38457 .02692 Mdot
.26977 .54708 Mdot
.91807 .40067 Mdot
.68391 .47332 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51501 .00637 Mdot
.5478 .02026 Mdot
.65121 .06391 Mdot
.94881 .18393 Mdot
.32188 .23057 Mdot
.48016 .09782 Mdot
.60875 .07947 Mdot
.88807 .17263 Mdot
.32178 .26805 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48961 .61363 Mdot
.46692 .60401 Mdot
.39497 .57356 Mdot
.17665 .48311 Mdot
.74451 .35096 Mdot
.55096 .49841 Mdot
.43255 .54485 Mdot
.21597 .48418 Mdot
.7661 .34 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52312 .0098 Mdot
.57355 .03117 Mdot
.73042 .09695 Mdot
.12421 .24338 Mdot
.35004 .13957 Mdot
.38275 .02022 Mdot
.25508 .53913 Mdot
.88879 .39166 Mdot
.67607 .48657 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50676 .00287 Mdot
.52153 .00913 Mdot
.56851 .02903 Mdot
.7151 .0906 Mdot
.0947 .23461 Mdot
.34049 .1519 Mdot
.3851 .02757 Mdot
.27195 .5481 Mdot
.92234 .40196 Mdot
.68465 .47113 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50289 .00123 Mdot
.50921 .00391 Mdot
.52934 .01244 Mdot
.59324 .03949 Mdot
.78913 .12107 Mdot
.21658 .26418 Mdot
.41054 .11987 Mdot
.47726 .04123 Mdot
.50997 .02022 Mdot
.55764 .02946 Mdot
.49751 .61698 Mdot
.49208 .61467 Mdot
.47477 .60733 Mdot
.41976 .58404 Mdot
.24943 .51276 Mdot
.84037 .36522 Mdot
.63258 .48961 Mdot
.60144 .59879 Mdot
.71238 .06856 Mdot
.0554 .212 Mdot
.31699 .16167 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50437 .00185 Mdot
.51391 .0059 Mdot
.5443 .01878 Mdot
.64029 .05932 Mdot
.9205 .17318 Mdot
.31506 .24385 Mdot
.49056 .10847 Mdot
.65192 .09972 Mdot
.00809 .22013 Mdot
.35213 .21263 Mdot
.49951 .61783 Mdot
.49843 .61737 Mdot
.495 .61591 Mdot
.48407 .61128 Mdot
.44928 .59653 Mdot
.3397 .55031 Mdot
.0283 .42558 Mdot
.67468 .39948 Mdot
.53355 .53081 Mdot
.44236 .56168 Mdot
.26659 .5094 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47987 .6095 Mdot
.43593 .59088 Mdot
.29846 .53307 Mdot
.93324 .39232 Mdot
.66525 .45241 Mdot
.60294 .57952 Mdot
.68448 .0504 Mdot
.98482 .18562 Mdot
.30789 .19967 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48038 .60971 Mdot
.43756 .59157 Mdot
.30348 .53516 Mdot
.94401 .39587 Mdot
.6668 .44671 Mdot
.59646 .57456 Mdot
.6621 .04057 Mdot
.93097 .16617 Mdot
.30017 .22818 Mdot
.49761 .61702 Mdot
.4924 .61481 Mdot
.47579 .60777 Mdot
.42301 .58541 Mdot
.25919 .51679 Mdot
.85703 .36949 Mdot
.64163 .48491 Mdot
.61172 .59955 Mdot
.73596 .07679 Mdot
.09801 .22376 Mdot
.32216 .13853 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50652 .00276 Mdot
.52077 .00881 Mdot
.56608 .02801 Mdot
.7077 .08752 Mdot
.07966 .22989 Mdot
.33706 .15908 Mdot
.39056 .03307 Mdot
.29254 .55745 Mdot
.96426 .41515 Mdot
.49801 .61719 Mdot
.49366 .61534 Mdot
.47979 .60947 Mdot
.4357 .59078 Mdot
.29777 .53279 Mdot
.93178 .39184 Mdot
.66501 .45316 Mdot
.60374 .58017 Mdot
.6873 .05164 Mdot
.99129 .18788 Mdot
.30834 .19595 Mdot
.49875 .6175 Mdot
.49601 .61634 Mdot
.48729 .61264 Mdot
.45952 .60087 Mdot
.37168 .56375 Mdot
.11155 .45726 Mdot
.69746 .36211 Mdot
.50921 .50169 Mdot
.33478 .51023 Mdot
.9547 .38313 Mdot
.64165 .42456 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47928 .60925 Mdot
.43408 .5901 Mdot
.29281 .53072 Mdot
.92138 .38848 Mdot
.66315 .45844 Mdot
.60897 .58455 Mdot
.70577 .05983 Mdot
.03215 .20171 Mdot
.31063 .17211 Mdot
.49756 .617 Mdot
.49224 .61474 Mdot
.47526 .60755 Mdot
.42134 .58471 Mdot
.25417 .51472 Mdot
.84835 .36722 Mdot
.63711 .48748 Mdot
.60703 .59944 Mdot
.72567 .07332 Mdot
.08025 .21914 Mdot
.31949 .14786 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00343 Mdot
.52579 .01094 Mdot
.58201 .03474 Mdot
.75587 .10745 Mdot
.1683 .2549 Mdot
.37277 .12637 Mdot
.40607 .02058 Mdot
.30653 .55651 Mdot
.98316 .41818 Mdot
.685 .43376 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46985 .60525 Mdot
.40421 .57746 Mdot
.20339 .49393 Mdot
.77401 .35266 Mdot
.58065 .49853 Mdot
.50316 .57014 Mdot
.43039 .57306 Mdot
.49948 .61781 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44668 .59543 Mdot
.33163 .54693 Mdot
.00856 .41837 Mdot
.67266 .41043 Mdot
.54784 .5409 Mdot
.49372 .58459 Mdot
.43019 .57877 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.5075 .00318 Mdot
.52389 .01013 Mdot
.57599 .0322 Mdot
.73779 .1 Mdot
.13763 .24711 Mdot
.3558 .13484 Mdot
.38608 .01871 Mdot
.25971 .53993 Mdot
.89505 .39266 Mdot
.67665 .48305 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50774 .00328 Mdot
.52465 .01045 Mdot
.57838 .03321 Mdot
.74498 .10297 Mdot
.1502 .25044 Mdot
.3621 .13096 Mdot
.39209 .01853 Mdot
.27232 .54402 Mdot
.91617 .39792 Mdot
.68003 .47209 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54191 .01777 Mdot
.63279 .05617 Mdot
.90055 .16548 Mdot
.30796 .25179 Mdot
.4923 .11393 Mdot
.66508 .10679 Mdot
.04342 .23382 Mdot
.35743 .19407 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .61119 Mdot
.44865 .59627 Mdot
.33774 .54949 Mdot
.02347 .4238 Mdot
.67412 .40212 Mdot
.53688 .53321 Mdot
.4976 .61701 Mdot
.49234 .61478 Mdot
.47559 .60768 Mdot
.42238 .58515 Mdot
.2573 .51601 Mdot
.85373 .36862 Mdot
.63996 .48592 Mdot
.6101 .59958 Mdot
.73254 .07567 Mdot
.09228 .22233 Mdot
.32122 .1415 Mdot
.49832 .61732 Mdot
.49465 .61577 Mdot
.48297 .61081 Mdot
.44579 .59506 Mdot
.32886 .54577 Mdot
.0019 .41596 Mdot
.67209 .4142 Mdot
.55298 .54442 Mdot
.51188 .59263 Mdot
.4886 .60364 Mdot
.44822 .59308 Mdot
.49969 .6179 Mdot
.49902 .61762 Mdot
.49688 .61671 Mdot
.49005 .61382 Mdot
.46831 .6046 Mdot
.39935 .57541 Mdot
.18928 .48821 Mdot
.75765 .35127 Mdot
.56447 .49864 Mdot
.46536 .55678 Mdot
.31471 .52492 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50304 .00129 Mdot
.5097 .00411 Mdot
.53089 .0131 Mdot
.59812 .04155 Mdot
.8034 .12687 Mdot
.23409 .26618 Mdot
.42725 .11938 Mdot
.51503 .05425 Mdot
.62532 .06816 Mdot
.4981 .61723 Mdot
.49395 .61547 Mdot
.48072 .60986 Mdot
.43865 .59203 Mdot
.30683 .53656 Mdot
.95133 .39832 Mdot
.6677 .44274 Mdot
.5916 .571 Mdot
.64543 .03327 Mdot
.8883 .1501 Mdot
.28529 .24536 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50432 .00183 Mdot
.51378 .00584 Mdot
.54387 .0186 Mdot
.63892 .05875 Mdot
.9169 .1718 Mdot
.31394 .24538 Mdot
.49125 .10959 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49545 .6161 Mdot
.4855 .61188 Mdot
.45382 .59846 Mdot
.35383 .55624 Mdot
.06413 .43899 Mdot
.68082 .38113 Mdot
.51404 .51496 Mdot
.36829 .52796 Mdot
.04678 .41933 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50496 .0021 Mdot
.5158 .0067 Mdot
.5503 .02132 Mdot
.65899 .06718 Mdot
.96843 .19125 Mdot
.32492 .22032 Mdot
.46864 .08882 Mdot
.56562 .05994 Mdot
.75825 .11906 Mdot
.1893 .2664 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51239 .00525 Mdot
.53946 .01673 Mdot
.62512 .05294 Mdot
.87971 .15734 Mdot
.29804 .25854 Mdot
.48843 .11767 Mdot
.6615 .10696 Mdot
.03732 .23227 Mdot
.35768 .19799 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48055 .60979 Mdot
.43809 .5918 Mdot
.30511 .53584 Mdot
.94756 .39706 Mdot
.66726 .4448 Mdot
.59414 .57285 Mdot
.65414 .03708 Mdot
.91087 .15867 Mdot
.49886 .61755 Mdot
.49636 .61649 Mdot
.4884 .61312 Mdot
.46306 .60237 Mdot
.3828 .56843 Mdot
.1422 .46934 Mdot
.71557 .35436 Mdot
.52211 .49847 Mdot
.36169 .51889 Mdot
.01897 .40622 Mdot
.64786 .38868 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50419 .00178 Mdot
.51334 .00566 Mdot
.54249 .01801 Mdot
.63461 .05694 Mdot
.90543 .16737 Mdot
.3099 .24998 Mdot
.49235 .11276 Mdot
.66332 .10567 Mdot
.03848 .23186 Mdot
.35648 .19654 Mdot
.49795 .61717 Mdot
.49347 .61527 Mdot
.47921 .60922 Mdot
.43384 .58999 Mdot
.29205 .53041 Mdot
.91982 .38798 Mdot
.66284 .45921 Mdot
.60966 .58517 Mdot
.70828 .06095 Mdot
.03747 .20345 Mdot
.31097 .16903 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48743 .6127 Mdot
.45998 .60107 Mdot
.37313 .56436 Mdot
.11549 .45881 Mdot
.69943 .36089 Mdot
.51014 .50105 Mdot
.33606 .51045 Mdot
.95731 .38395 Mdot
.64183 .42306 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47445 .6072 Mdot
.41876 .58361 Mdot
.24642 .51152 Mdot
.83541 .36402 Mdot
.62957 .49082 Mdot
.59733 .59811 Mdot
.70215 .06478 Mdot
.035 .20571 Mdot
.31577 .17353 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00314 Mdot
.52355 .00999 Mdot
.57491 .03174 Mdot
.73454 .09866 Mdot
.13178 .24551 Mdot
.35317 .13683 Mdot
.38426 .01921 Mdot
.25663 .53916 Mdot
.89049 .39174 Mdot
.49776 .61708 Mdot
.49287 .61501 Mdot
.47728 .6084 Mdot
.42772 .58741 Mdot
.27343 .52268 Mdot
.88299 .37673 Mdot
.65267 .47569 Mdot
.61783 .5965 Mdot
.74403 .07799 Mdot
.10878 .22543 Mdot
.32278 .13226 Mdot
.49885 .61755 Mdot
.49633 .61648 Mdot
.4883 .61307 Mdot
.46275 .60224 Mdot
.38183 .56802 Mdot
.1395 .46826 Mdot
.7137 .35488 Mdot
.52045 .4986 Mdot
.3578 .51751 Mdot
.00911 .40253 Mdot
.64676 .39409 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54143 .01756 Mdot
.63129 .05554 Mdot
.89651 .16391 Mdot
.30625 .25323 Mdot
.49201 .11481 Mdot
.66581 .10741 Mdot
.04569 .23478 Mdot
.49862 .61745 Mdot
.4956 .61617 Mdot
.48598 .61209 Mdot
.45536 .59911 Mdot
.35867 .55827 Mdot
.07676 .4438 Mdot
.68412 .37537 Mdot
.51006 .51046 Mdot
.35108 .51978 Mdot
.99991 .401 Mdot
.64888 .40109 Mdot
.49803 .6172 Mdot
.49374 .61538 Mdot
.48005 .60957 Mdot
.43651 .59113 Mdot
.30024 .53381 Mdot
.93703 .39356 Mdot
.66583 .45042 Mdot
.60075 .57781 Mdot
.6769 .04706 Mdot
.96705 .17932 Mdot
.30627 .20965 Mdot
.49905 .61763 Mdot
.49696 .61675 Mdot
.49032 .61393 Mdot
.46917 .60496 Mdot
.40207 .57656 Mdot
.19716 .4914 Mdot
.76656 .35191 Mdot
.5734 .49865 Mdot
.48648 .56431 Mdot
.37929 .55179 Mdot
.10791 .45031 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50552 .00234 Mdot
.51759 .00746 Mdot
.55599 .02373 Mdot
.67666 .07458 Mdot
.01115 .20673 Mdot
.32893 .1964 Mdot
.43675 .06663 Mdot
.45215 .00952 Mdot
.39687 .58387 Mdot
.1975 .49481 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51315 .00558 Mdot
.54187 .01775 Mdot
.63268 .05612 Mdot
.90024 .16536 Mdot
.30783 .25191 Mdot
.49228 .114 Mdot
.66516 .10684 Mdot
.04365 .23392 Mdot
.35748 .19396 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47779 .60862 Mdot
.42935 .5881 Mdot
.27838 .52473 Mdot
.89246 .37952 Mdot
.65585 .4718 Mdot
.61742 .59428 Mdot
.73956 .07549 Mdot
.09991 .22271 Mdot
.32005 .13605 Mdot
.4981 .61723 Mdot
.49394 .61546 Mdot
.48069 .60984 Mdot
.43853 .59198 Mdot
.30645 .5364 Mdot
.9505 .39804 Mdot
.66761 .4432 Mdot
.59216 .57141 Mdot
.64736 .03412 Mdot
.89335 .15203 Mdot
.28761 .24366 Mdot
.49941 .61779 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48103 .60999 Mdot
.43962 .59244 Mdot
.30981 .5378 Mdot
.95792 .40056 Mdot
.66842 .43911 Mdot
.58697 .56769 Mdot
.62957 .02633 Mdot
.84575 .13361 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48344 .61101 Mdot
.44728 .59568 Mdot
.33346 .54769 Mdot
.013 .41998 Mdot
.67306 .40794 Mdot
.54449 .53857 Mdot
.48179 .57928 Mdot
.39183 .56244 Mdot
.15184 .46971 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52373 .01006 Mdot
.57548 .03198 Mdot
.73625 .09936 Mdot
.13486 .24636 Mdot
.35454 .13577 Mdot
.38515 .01892 Mdot
.25805 .53948 Mdot
.89252 .39213 Mdot
.67624 .48436 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50693 .00294 Mdot
.52207 .00936 Mdot
.5702 .02975 Mdot
.72024 .09273 Mdot
.10486 .23771 Mdot
.34332 .14738 Mdot
.38293 .02448 Mdot
.26235 .54351 Mdot
.90375 .39641 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50793 .00336 Mdot
.52526 .01071 Mdot
.58033 .03403 Mdot
.75084 .10538 Mdot
.16007 .25292 Mdot
.36768 .12831 Mdot
.3989 .0193 Mdot
.28847 .54978 Mdot
.94625 .40653 Mdot
.68313 .45542 Mdot
.49944 .6178 Mdot
.49821 .61728 Mdot
.49431 .61562 Mdot
.48186 .61034 Mdot
.44227 .59356 Mdot
.31796 .54121 Mdot
.97636 .40691 Mdot
.67009 .42875 Mdot
.57308 .55808 Mdot
.58189 .00545 Mdot
.7082 .07806 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48468 .61154 Mdot
.45121 .59735 Mdot
.3457 .55283 Mdot
.04334 .43116 Mdot
.67677 .39148 Mdot
.5241 .52368 Mdot
.40743 .54593 Mdot
.1596 .46487 Mdot
.71053 .34049 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48636 .61225 Mdot
.45658 .59963 Mdot
.36247 .55987 Mdot
.08679 .44765 Mdot
.68728 .37113 Mdot
.50822 .50736 Mdot
.34147 .51498 Mdot
.97434 .39114 Mdot
.64554 .41482 Mdot
.50032 .00013 Mdot
.501 .00043 Mdot
.5032 .00136 Mdot
.5102 .00432 Mdot
.53248 .01377 Mdot
.60315 .04367 Mdot
.81793 .13274 Mdot
.25002 .26705 Mdot
.44339 .11951 Mdot
.55361 .06812 Mdot
.74275 .11689 Mdot
.17037 .26428 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50763 .00324 Mdot
.52431 .01031 Mdot
.57732 .03276 Mdot
.7418 .10165 Mdot
.1447 .249 Mdot
.35924 .13259 Mdot
.3891 .01846 Mdot
.26576 .5418 Mdot
.90485 .39498 Mdot
.49791 .61715 Mdot
.49335 .61521 Mdot
.47881 .60905 Mdot
.43257 .58946 Mdot
.28818 .5288 Mdot
.91189 .38548 Mdot
.66112 .46305 Mdot
.61281 .58818 Mdot
.7199 .06619 Mdot
.06147 .2111 Mdot
.31311 .15552 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .00341 Mdot
.52559 .01085 Mdot
.58138 .03448 Mdot
.75399 .10668 Mdot
.16525 .25418 Mdot
.37084 .12706 Mdot
.40326 .02004 Mdot
.29934 .55381 Mdot
.96807 .4133 Mdot
.68437 .4427 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50285 .00121 Mdot
.50909 .00385 Mdot
.52894 .01227 Mdot
.59196 .03895 Mdot
.78538 .11954 Mdot
.21166 .26345 Mdot
.4061 .12017 Mdot
.46771 .03808 Mdot
.48123 .00835 Mdot
.46665 .60902 Mdot
.4974 .61693 Mdot
.4917 .61452 Mdot
.47358 .60683 Mdot
.41599 .58244 Mdot
.23816 .50813 Mdot
.82226 .36099 Mdot
.6209 .49359 Mdot
.58396 .5952 Mdot
.6672 .05144 Mdot
.95758 .17946 Mdot
.31084 .21833 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47486 .60738 Mdot
.42007 .58417 Mdot
.25037 .51315 Mdot
.84193 .36561 Mdot
.6335 .48921 Mdot
.60264 .59896 Mdot
.71528 .06962 Mdot
.06101 .21367 Mdot
.31744 .15849 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50334 .00141 Mdot
.51063 .00451 Mdot
.53385 .01435 Mdot
.60746 .04549 Mdot
.83028 .13771 Mdot
.26211 .26688 Mdot
.45589 .11976 Mdot
.58434 .07939 Mdot
.83348 .15397 Mdot
.28925 .28168 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47834 .60885 Mdot
.43108 .58883 Mdot
.28363 .52691 Mdot
.90276 .38264 Mdot
.65884 .46729 Mdot
.61556 .59128 Mdot
.73079 .07121 Mdot
.08301 .21768 Mdot
.31629 .14417 Mdot
.50044 .00019 Mdot
.5014 .0006 Mdot
.50447 .0019 Mdot
.51426 .00605 Mdot
.54539 .01924 Mdot
.6437 .06076 Mdot
.92945 .1766 Mdot
.31759 .23988 Mdot
.4882 .10545 Mdot
.64114 .09452 Mdot
.97911 .20888 Mdot
.34832 .22819 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52148 .00911 Mdot
.56834 .02896 Mdot
.71459 .09039 Mdot
.09369 .2343 Mdot
.34023 .15237 Mdot
.38539 .02791 Mdot
.27311 .54864 Mdot
.9246 .40265 Mdot
.68501 .46996 Mdot
.49937 .61777 Mdot
.498 .61719 Mdot
.49364 .61534 Mdot
.47973 .60944 Mdot
.43549 .5907 Mdot
.29713 .53252 Mdot
.93042 .3914 Mdot
.66479 .45386 Mdot
.60448 .58076 Mdot
.68989 .05278 Mdot
.99719 .18993 Mdot
.49876 .61751 Mdot
.49605 .61636 Mdot
.48741 .6127 Mdot
.45991 .60104 Mdot
.3729 .56426 Mdot
.11487 .45856 Mdot
.69911 .36108 Mdot
.50998 .50115 Mdot
.33582 .51039 Mdot
.95679 .38378 Mdot
.64179 .42335 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47444 .6072 Mdot
.41874 .58361 Mdot
.24637 .51151 Mdot
.83534 .364 Mdot
.62953 .49084 Mdot
.59727 .59809 Mdot
.70199 .06472 Mdot
.03466 .2056 Mdot
.31575 .17373 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00227 Mdot
.51702 .00722 Mdot
.55419 .02297 Mdot
.67109 .07225 Mdot
.99798 .20203 Mdot
.3279 .2039 Mdot
.44711 .07368 Mdot
.48844 .02554 Mdot
.51244 .01484 Mdot
.5551 .02636 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.48628 .61222 Mdot
.45633 .59952 Mdot
.36168 .55954 Mdot
.0847 .44685 Mdot
.68658 .37198 Mdot
.5085 .50797 Mdot
.34315 .51584 Mdot
.97881 .39286 Mdot
.64616 .41245 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50629 .00267 Mdot
.52003 .00849 Mdot
.56374 .02702 Mdot
.70054 .08454 Mdot
.06462 .22502 Mdot
.33442 .16674 Mdot
.39828 .03947 Mdot
.31974 .56949 Mdot
.02503 .43589 Mdot
.69293 .41279 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50555 .00235 Mdot
.51767 .00749 Mdot
.55624 .02384 Mdot
.67744 .0749 Mdot
.01298 .20738 Mdot
.32907 .19536 Mdot
.4353 .06565 Mdot
.44713 .00731 Mdot
.3811 .57723 Mdot
.15286 .47697 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51996 .00846 Mdot
.56351 .02692 Mdot
.69981 .08424 Mdot
.06308 .22451 Mdot
.33418 .16755 Mdot
.39918 .04017 Mdot
.32287 .57087 Mdot
.03242 .43853 Mdot
.69367 .40868 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50603 .00256 Mdot
.5192 .00814 Mdot
.56111 .0259 Mdot
.69244 .08117 Mdot
.04705 .21917 Mdot
.33211 .17618 Mdot
.40952 .04784 Mdot
.35839 .58644 Mdot
.12179 .47181 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52143 .00909 Mdot
.56819 .0289 Mdot
.71414 .0902 Mdot
.09278 .23401 Mdot
.34 .15279 Mdot
.38566 .02822 Mdot
.27418 .54914 Mdot
.92672 .40329 Mdot
.68534 .46885 Mdot
.49967 .6179 Mdot
.49896 .61759 Mdot
.4967 .61663 Mdot
.48947 .61357 Mdot
.46647 .60382 Mdot
.39353 .57296 Mdot
.17255 .48146 Mdot
.74054 .35104 Mdot
.54685 .49833 Mdot
.42243 .54114 Mdot
.18621 .47204 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00115 Mdot
.50862 .00365 Mdot
.52744 .01164 Mdot
.58723 .03695 Mdot
.77142 .11383 Mdot
.19217 .26004 Mdot
.38978 .12213 Mdot
.43497 .02793 Mdot
.38531 .58734 Mdot
.17811 .48998 Mdot
.49931 .61774 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47768 .60857 Mdot
.42901 .58795 Mdot
.27733 .5243 Mdot
.89044 .37892 Mdot
.65521 .47265 Mdot
.61761 .5948 Mdot
.74081 .07614 Mdot
.10234 .22344 Mdot
.49848 .61739 Mdot
.49516 .61598 Mdot
.48457 .61149 Mdot
.45088 .59721 Mdot
.34466 .55239 Mdot
.0407 .43018 Mdot
.67636 .39286 Mdot
.52564 .52489 Mdot
.41321 .54855 Mdot
.17697 .47202 Mdot
.72668 .33974 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51573 .00667 Mdot
.55008 .02123 Mdot
.65833 .0669 Mdot
.96679 .19064 Mdot
.3247 .2212 Mdot
.46971 .08962 Mdot
.56954 .0617 Mdot
.77041 .12414 Mdot
.20804 .27047 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50314 .00133 Mdot
.51001 .00425 Mdot
.5319 .01352 Mdot
.60131 .0429 Mdot
.81262 .1306 Mdot
.24442 .26687 Mdot
.43764 .11942 Mdot
.5397 .06307 Mdot
.70069 .0995 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49406 .61552 Mdot
.48109 .61001 Mdot
.43981 .59252 Mdot
.3104 .53805 Mdot
.95923 .401 Mdot
.66855 .43839 Mdot
.58602 .56703 Mdot
.62634 .02492 Mdot
.83687 .13012 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50686 .00291 Mdot
.52186 .00927 Mdot
.56953 .02947 Mdot
.71823 .0919 Mdot
.10091 .23651 Mdot
.34217 .14911 Mdot
.38362 .02562 Mdot
.26564 .54512 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.51549 .00657 Mdot
.54933 .02091 Mdot
.65597 .06591 Mdot
.96088 .18844 Mdot
.32388 .22435 Mdot
.47341 .09242 Mdot
.58325 .06788 Mdot
.81234 .14159 Mdot
.26209 .27796 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50514 .00218 Mdot
.51638 .00695 Mdot
.55216 .02211 Mdot
.66477 .0696 Mdot
.98269 .19649 Mdot
.32653 .2125 Mdot
.4587 .08169 Mdot
.52961 .04383 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50317 .00135 Mdot
.51011 .00429 Mdot
.53219 .01365 Mdot
.60222 .04328 Mdot
.81527 .13167 Mdot
.24725 .26698 Mdot
.44054 .11946 Mdot
.54669 .0656 Mdot
.72187 .10827 Mdot
.13206 .25351 Mdot
.49972 .61791 Mdot
.49911 .61765 Mdot
.49715 .61683 Mdot
.49092 .61419 Mdot
.47109 .60578 Mdot
.40814 .57912 Mdot
.21491 .49861 Mdot
.78872 .35464 Mdot
.59424 .49784 Mdot
.53301 .58019 Mdot
.52094 .61057 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41915 .58378 Mdot
.2476 .51201 Mdot
.83734 .36448 Mdot
.63076 .49036 Mdot
.59899 .5984 Mdot
.70632 .06633 Mdot
.04345 .20836 Mdot
.31621 .16858 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50213 .00091 Mdot
.5068 .00288 Mdot
.52166 .00919 Mdot
.56892 .0292 Mdot
.71635 .09112 Mdot
.09719 .23537 Mdot
.34114 .15077 Mdot
.38445 .02677 Mdot
.26926 .54685 Mdot
.91709 .40038 Mdot
.499 .61761 Mdot
.4968 .61668 Mdot
.4898 .61371 Mdot
.46751 .60426 Mdot
.39683 .57435 Mdot
.18201 .48527 Mdot
.74991 .35098 Mdot
.55654 .49853 Mdot
.44621 .54985 Mdot
.25673 .50093 Mdot
.82873 .35351 Mdot
.49833 .61733 Mdot
.49469 .61578 Mdot
.48307 .61086 Mdot
.44612 .59519 Mdot
.32988 .54619 Mdot
.00434 .41684 Mdot
.6723 .41282 Mdot
.55109 .54312 Mdot
.50521 .58968 Mdot
.46713 .5945 Mdot
.38009 .56424 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47347 .60678 Mdot
.41564 .5823 Mdot
.23713 .50771 Mdot
.82067 .36064 Mdot
.61979 .49388 Mdot
.58209 .59474 Mdot
.66215 .04948 Mdot
.94549 .17511 Mdot
.309 .22466 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51644 .00697 Mdot
.55234 .02219 Mdot
.66535 .06984 Mdot
.9841 .197 Mdot
.32666 .21172 Mdot
.45766 .08096 Mdot
.5259 .04218 Mdot
.63283 .06608 Mdot
.91666 .17542 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47685 .60822 Mdot
.42636 .58683 Mdot
.26933 .52098 Mdot
.87531 .37452 Mdot
.64978 .47865 Mdot
.61718 .59789 Mdot
.7449 .07894 Mdot
.11124 .22641 Mdot
.32397 .13148 Mdot
.49899 .6176 Mdot
.49677 .61666 Mdot
.48971 .61367 Mdot
.46722 .60413 Mdot
.3959 .57396 Mdot
.17934 .48419 Mdot
.74719 .35095 Mdot
.55373 .49847 Mdot
.43934 .54734 Mdot
.23616 .49246 Mdot
.79515 .34547 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48246 .6106 Mdot
.44417 .59437 Mdot
.32383 .54366 Mdot
.99 .41171 Mdot
.67116 .42098 Mdot
.56235 .55079 Mdot
.54468 .60712 Mdot
.59316 .02996 Mdot
.77352 .11147 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52315 .00982 Mdot
.57363 .0312 Mdot
.73066 .09705 Mdot
.12467 .24351 Mdot
.35022 .1394 Mdot
.38282 .02015 Mdot
.2551 .5391 Mdot
.88877 .39163 Mdot
.67603 .48656 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47451 .60723 Mdot
.41895 .5837 Mdot
.24701 .51177 Mdot
.83638 .36425 Mdot
.63017 .49059 Mdot
.59817 .59826 Mdot
.70427 .06557 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48388 .6112 Mdot
.44868 .59628 Mdot
.33784 .54953 Mdot
.0237 .42389 Mdot
.67415 .402 Mdot
.53672 .5331 Mdot
.45388 .56684 Mdot
.30281 .52467 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.5039 .00165 Mdot
.51243 .00527 Mdot
.53959 .01678 Mdot
.62552 .05311 Mdot
.88081 .15778 Mdot
.29864 .25823 Mdot
.48879 .11752 Mdot
.66214 .10714 Mdot
.03877 .23277 Mdot
.35781 .19718 Mdot
.4988 .61753 Mdot
.49619 .61642 Mdot
.48787 .61289 Mdot
.46136 .60165 Mdot
.37747 .56619 Mdot
.12742 .46349 Mdot
.70601 .35759 Mdot
.51427 .49953 Mdot
.34391 .51274 Mdot
.97517 .39014 Mdot
.64353 .41307 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47783 .60863 Mdot
.42947 .58814 Mdot
.27873 .52487 Mdot
.89314 .37973 Mdot
.65607 .47151 Mdot
.61734 .5941 Mdot
.7391 .07525 Mdot
.09903 .22245 Mdot
.31982 .13646 Mdot
.49839 .61735 Mdot
.49488 .61586 Mdot
.4837 .61112 Mdot
.44812 .59604 Mdot
.33608 .54879 Mdot
.01939 .42231 Mdot
.67368 .40438 Mdot
.53979 .53528 Mdot
.46495 .57178 Mdot
.33797 .53955 Mdot
.0078 .41398 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .00991 Mdot
.57432 .03149 Mdot
.73273 .09791 Mdot
.12848 .24459 Mdot
.35177 .138 Mdot
.38349 .0196 Mdot
.25563 .53901 Mdot
.88919 .39156 Mdot
.67586 .48619 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51139 .00483 Mdot
.53629 .01539 Mdot
.61514 .04873 Mdot
.85203 .14641 Mdot
.28025 .26466 Mdot
.47404 .11977 Mdot
.62907 .09581 Mdot
.95717 .20277 Mdot
.34874 .24201 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50327 .00139 Mdot
.51043 .00442 Mdot
.53322 .01408 Mdot
.60548 .04466 Mdot
.82462 .13544 Mdot
.25674 .26706 Mdot
.45033 .11965 Mdot
.57063 .07435 Mdot
.79343 .1377 Mdot
.24612 .27978 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00348 Mdot
.52618 .0111 Mdot
.58323 .03526 Mdot
.7595 .10894 Mdot
.17408 .25623 Mdot
.37658 .12515 Mdot
.41196 .02186 Mdot
.3219 .56237 Mdot
.01705 .42963 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61007 Mdot
.44019 .59268 Mdot
.31155 .53853 Mdot
.96181 .40188 Mdot
.66881 .43695 Mdot
.58414 .5657 Mdot
.61987 .02209 Mdot
.81889 .123 Mdot
.23462 .25694 Mdot
.49834 .61733 Mdot
.4947 .61579 Mdot
.48311 .61087 Mdot
.44624 .59525 Mdot
.33026 .54635 Mdot
.00525 .41717 Mdot
.67237 .4123 Mdot
.55039 .54264 Mdot
.50272 .58858 Mdot
.45914 .5911 Mdot
.35495 .55364 Mdot
.4974 .61693 Mdot
.49173 .61453 Mdot
.47366 .60687 Mdot
.41626 .58256 Mdot
.23897 .50846 Mdot
.82352 .36127 Mdot
.62178 .49335 Mdot
.5854 .59555 Mdot
.67105 .05294 Mdot
.96666 .1827 Mdot
.31192 .21338 Mdot
.49846 .61738 Mdot
.4951 .61596 Mdot
.4844 .61142 Mdot
.45033 .59698 Mdot
.34295 .55167 Mdot
.03641 .42858 Mdot
.67573 .39512 Mdot
.52826 .52689 Mdot
.42294 .55295 Mdot
.2065 .48427 Mdot
.76019 .3422 Mdot
.49803 .6172 Mdot
.49371 .61537 Mdot
.47997 .60954 Mdot
.43626 .59102 Mdot
.29949 .5335 Mdot
.93542 .39303 Mdot
.66559 .45127 Mdot
.60169 .57854 Mdot
.68016 .0485 Mdot
.97475 .18207 Mdot
.30705 .20537 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50298 .00126 Mdot
.5095 .00403 Mdot
.53025 .01282 Mdot
.59609 .0407 Mdot
.79748 .12446 Mdot
.22705 .26549 Mdot
.42037 .11948 Mdot
.49917 .0487 Mdot
.57673 .04793 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.5033 .0014 Mdot
.51052 .00446 Mdot
.53352 .01421 Mdot
.60642 .04506 Mdot
.82733 .13653 Mdot
.25934 .267 Mdot
.45302 .11971 Mdot
.57727 .07679 Mdot
.81291 .14564 Mdot
.26888 .2818 Mdot
.4975 .61698 Mdot
.49205 .61466 Mdot
.47466 .60729 Mdot
.41943 .5839 Mdot
.24843 .51235 Mdot
.83871 .36481 Mdot
.63159 .49003 Mdot
.60012 .59859 Mdot
.70913 .06737 Mdot
.04904 .21008 Mdot
.31655 .16533 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47984 .60949 Mdot
.43585 .59085 Mdot
.29823 .53298 Mdot
.93275 .39215 Mdot
.66517 .45266 Mdot
.60321 .57974 Mdot
.68544 .05082 Mdot
.98703 .18639 Mdot
.30805 .1984 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50415 .00176 Mdot
.51321 .0056 Mdot
.54205 .01783 Mdot
.63325 .05636 Mdot
.90178 .16596 Mdot
.30846 .25134 Mdot
.49234 .11364 Mdot
.66473 .10654 Mdot
.0424 .23341 Mdot
.35722 .19457 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50701 .00297 Mdot
.52233 .00947 Mdot
.57103 .0301 Mdot
.72276 .09378 Mdot
.10974 .23917 Mdot
.34485 .1453 Mdot
.38237 .02319 Mdot
.25909 .54184 Mdot
.89746 .39453 Mdot
.50036 .00015 Mdot
.50114 .00049 Mdot
.50365 .00155 Mdot
.51162 .00493 Mdot
.537 .01569 Mdot
.61737 .04968 Mdot
.85828 .14889 Mdot
.28477 .26358 Mdot
.4782 .11954 Mdot
.63902 .09939 Mdot
.98285 .2125 Mdot
.35236 .22837 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52405 .0102 Mdot
.57647 .0324 Mdot
.73925 .1006 Mdot
.14022 .24781 Mdot
.35703 .134 Mdot
.38708 .01858 Mdot
.26162 .54049 Mdot
.89807 .39334 Mdot
.67717 .48151 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50525 .00223 Mdot
.51672 .00709 Mdot
.55323 .02256 Mdot
.66811 .071 Mdot
.99081 .19944 Mdot
.32729 .20795 Mdot
.45263 .07747 Mdot
.50796 .0342 Mdot
.57522 .04157 Mdot
.75116 .10874 Mdot
.49831 .61732 Mdot
.49462 .61575 Mdot
.48285 .61076 Mdot
.44541 .5949 Mdot
.32769 .54528 Mdot
.99913 .41497 Mdot
.67187 .41578 Mdot
.55515 .5459 Mdot
.51951 .59601 Mdot
.51306 .61405 Mdot
.52619 .00811 Mdot
.49902 .61762 Mdot
.49686 .6167 Mdot
.49001 .6138 Mdot
.46817 .60454 Mdot
.39891 .57523 Mdot
.18802 .48769 Mdot
.75627 .3512 Mdot
.56306 .49863 Mdot
.46199 .55557 Mdot
.30445 .52067 Mdot
.92202 .38168 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48495 .61165 Mdot
.45208 .59772 Mdot
.34842 .55397 Mdot
.05023 .43374 Mdot
.67794 .38795 Mdot
.52033 .52063 Mdot
.39314 .53942 Mdot
.11743 .44764 Mdot
.68113 .34838 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50697 .00295 Mdot
.52219 .00941 Mdot
.57059 .02991 Mdot
.72145 .09323 Mdot
.1072 .23841 Mdot
.34404 .14637 Mdot
.38262 .02384 Mdot
.26067 .54266 Mdot
.49787 .61713 Mdot
.49321 .61515 Mdot
.47836 .60886 Mdot
.43115 .58886 Mdot
.28386 .527 Mdot
.90322 .38279 Mdot
.65897 .46708 Mdot
.61545 .59114 Mdot
.7303 .07099 Mdot
.08207 .2174 Mdot
.31611 .14465 Mdot
.49799 .61718 Mdot
.49361 .61532 Mdot
.47964 .6094 Mdot
.43521 .59058 Mdot
.29626 .53216 Mdot
.92859 .3908 Mdot
.66448 .4548 Mdot
.60545 .58155 Mdot
.69328 .05428 Mdot
.00484 .19255 Mdot
.30914 .18807 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48825 .61305 Mdot
.46258 .60217 Mdot
.38129 .5678 Mdot
.138 .46767 Mdot
.71269 .35518 Mdot
.51958 .49869 Mdot
.35576 .51679 Mdot
.00401 .40064 Mdot
.64624 .39692 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50548 .00232 Mdot
.51746 .0074 Mdot
.55558 .02356 Mdot
.67538 .07404 Mdot
.00814 .20566 Mdot
.3287 .19812 Mdot
.43912 .06825 Mdot
.46045 .01318 Mdot
.42304 .59492 Mdot
.27466 .52633 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.4946 .61574 Mdot
.48278 .61073 Mdot
.44519 .5948 Mdot
.32701 .54499 Mdot
.99751 .41439 Mdot
.67174 .4167 Mdot
.55642 .54676 Mdot
.52397 .59798 Mdot
.52734 .00208 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.48059 .6098 Mdot
.43823 .59186 Mdot
.30554 .53602 Mdot
.94849 .39737 Mdot
.66737 .44429 Mdot
.59352 .57239 Mdot
.65201 .03615 Mdot
.49807 .61721 Mdot
.49384 .61542 Mdot
.48038 .60971 Mdot
.43756 .59157 Mdot
.30345 .53515 Mdot
.94395 .39585 Mdot
.6668 .44674 Mdot
.59649 .57458 Mdot
.66222 .04062 Mdot
.93128 .16629 Mdot
.30025 .22803 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00326 Mdot
.52447 .01038 Mdot
.57782 .03297 Mdot
.7433 .10227 Mdot
.1473 .24969 Mdot
.36057 .13181 Mdot
.39044 .01846 Mdot
.26865 .54276 Mdot
.90976 .39623 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49427 .6156 Mdot
.48175 .6103 Mdot
.44191 .59341 Mdot
.31687 .54075 Mdot
.97386 .40604 Mdot
.66988 .43016 Mdot
.57502 .55941 Mdot
.58857 .00837 Mdot
.72822 .08631 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48702 .61253 Mdot
.45867 .60051 Mdot
.36903 .56263 Mdot
.10436 .45446 Mdot
.69413 .3645 Mdot
.50807 .50305 Mdot
.33413 .51053 Mdot
.95403 .38312 Mdot
.64193 .42515 Mdot
.49741 .61694 Mdot
.49176 .61454 Mdot
.47374 .6069 Mdot
.41652 .58267 Mdot
.23975 .50878 Mdot
.82474 .36154 Mdot
.62262 .49312 Mdot
.58676 .59587 Mdot
.6747 .05435 Mdot
.97514 .18568 Mdot
.31272 .20864 Mdot
.49784 .61712 Mdot
.49311 .61511 Mdot
.47804 .60872 Mdot
.43012 .58842 Mdot
.28073 .5257 Mdot
.89704 .3809 Mdot
.65724 .46983 Mdot
.61676 .59302 Mdot
.73614 .07378 Mdot
.09335 .22076 Mdot
.31842 .1391 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50327 .00139 Mdot
.51042 .00442 Mdot
.53318 .01407 Mdot
.60534 .0446 Mdot
.82424 .13528 Mdot
.25636 .26707 Mdot
.44994 .11964 Mdot
.56967 .074 Mdot
.7906 .13654 Mdot
.24254 .27931 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.4857 .61197 Mdot
.45446 .59873 Mdot
.35584 .55708 Mdot
.06937 .44098 Mdot
.6821 .37869 Mdot
.51218 .51301 Mdot
.3605 .52429 Mdot
.02535 .4109 Mdot
.65234 .3875 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52057 .00872 Mdot
.56544 .02773 Mdot
.70573 .0867 Mdot
.07557 .22858 Mdot
.33627 .16112 Mdot
.39246 .03473 Mdot
.29933 .56048 Mdot
.97885 .41996 Mdot
.69 .43952 Mdot
.49916 .61768 Mdot
.49733 .6169 Mdot
.49149 .61443 Mdot
.47291 .60655 Mdot
.41387 .58155 Mdot
.23186 .50555 Mdot
.81267 .35896 Mdot
.61394 .49521 Mdot
.57189 .59204 Mdot
.63403 .03841 Mdot
.8743 .14849 Mdot
.49771 .61706 Mdot
.4927 .61494 Mdot
.47674 .60817 Mdot
.42602 .58669 Mdot
.26829 .52055 Mdot
.87341 .37398 Mdot
.64901 .47935 Mdot
.61688 .59817 Mdot
.74472 .07901 Mdot
.11116 .22647 Mdot
.32409 .1316 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50761 .00323 Mdot
.52423 .01027 Mdot
.57706 .03265 Mdot
.74102 .10133 Mdot
.14333 .24864 Mdot
.35855 .13301 Mdot
.38845 .01848 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57374 .03125 Mdot
.731 .09719 Mdot
.12529 .24369 Mdot
.35046 .13916 Mdot
.38291 .02005 Mdot
.25514 .53907 Mdot
.88876 .3916 Mdot
.67598 .48653 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51462 .0062 Mdot
.54655 .01973 Mdot
.64731 .06227 Mdot
.9388 .18015 Mdot
.31985 .2355 Mdot
.48479 .10194 Mdot
.62694 .08786 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50645 .00274 Mdot
.52055 .00872 Mdot
.5654 .02772 Mdot
.70562 .08666 Mdot
.07535 .22851 Mdot
.33623 .16123 Mdot
.39256 .03482 Mdot
.29971 .56065 Mdot
.97967 .42024 Mdot
.69004 .43903 Mdot
.49843 .61737 Mdot
.495 .61591 Mdot
.48407 .61128 Mdot
.4493 .59654 Mdot
.33974 .55033 Mdot
.02842 .42562 Mdot
.67469 .39942 Mdot
.53346 .53075 Mdot
.44207 .56155 Mdot
.26567 .50902 Mdot
.8517 .36219 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51157 .00491 Mdot
.53685 .01562 Mdot
.6169 .04947 Mdot
.85695 .14836 Mdot
.28383 .26383 Mdot
.47735 .1196 Mdot
.63702 .09868 Mdot
.97775 .21058 Mdot
.35175 .23114 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50814 .00345 Mdot
.52592 .01099 Mdot
.5824 .03491 Mdot
.75705 .10794 Mdot
.17019 .25534 Mdot
.37399 .12596 Mdot
.40792 .02097 Mdot
.3113 .55832 Mdot
.99345 .42159 Mdot
.68542 .42766 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50487 .00207 Mdot
.51553 .00659 Mdot
.54945 .02096 Mdot
.65634 .06607 Mdot
.96181 .18879 Mdot
.32402 .22386 Mdot
.47284 .09198 Mdot
.58114 .06693 Mdot
.80593 .13893 Mdot
.25486 .27746 Mdot
.49781 .61711 Mdot
.49302 .61507 Mdot
.47777 .60861 Mdot
.42928 .58807 Mdot
.27817 .52464 Mdot
.89206 .37941 Mdot
.65573 .47197 Mdot
.61746 .59438 Mdot
.73981 .07562 Mdot
.10041 .22286 Mdot
.32019 .13583 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48933 .61351 Mdot
.46601 .60362 Mdot
.39209 .57235 Mdot
.16844 .47981 Mdot
.73672 .35122 Mdot
.5429 .49825 Mdot
.41265 .53754 Mdot
.15785 .46056 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48179 .61031 Mdot
.44205 .59347 Mdot
.3173 .54093 Mdot
.97485 .40638 Mdot
.66996 .42961 Mdot
.57426 .55889 Mdot
.58595 .00722 Mdot
.72038 .08309 Mdot
.08943 .22808 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49427 .6156 Mdot
.48173 .61029 Mdot
.44186 .59339 Mdot
.31671 .54069 Mdot
.9735 .40591 Mdot
.66985 .43037 Mdot
.57531 .5596 Mdot
.58955 .0088 Mdot
.73114 .08751 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50199 .00084 Mdot
.50635 .00269 Mdot
.52022 .00858 Mdot
.56436 .02727 Mdot
.70241 .08532 Mdot
.0686 .22632 Mdot
.33505 .16467 Mdot
.39605 .0377 Mdot
.31196 .56607 Mdot
.00702 .42957 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48961 .61363 Mdot
.46689 .604 Mdot
.39488 .57353 Mdot
.17641 .48301 Mdot
.74428 .35096 Mdot
.55072 .49841 Mdot
.43195 .54463 Mdot
.2142 .48346 Mdot
.76373 .33963 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50249 .00105 Mdot
.50792 .00336 Mdot
.52523 .0107 Mdot
.58024 .03399 Mdot
.75056 .10526 Mdot
.15961 .25281 Mdot
.36741 .12843 Mdot
.39854 .01924 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50837 .00355 Mdot
.52666 .0113 Mdot
.58475 .0359 Mdot
.76404 .11081 Mdot
.18113 .25778 Mdot
.3815 .12383 Mdot
.42008 .02385 Mdot
.34376 .57087 Mdot
.06896 .44819 Mdot
.69392 .38625 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47661 .60812 Mdot
.4256 .58651 Mdot
.26702 .52002 Mdot
.87106 .37332 Mdot
.64804 .4802 Mdot
.61642 .59849 Mdot
.74426 .07901 Mdot
.11068 .22646 Mdot
.49894 .61758 Mdot
.49661 .6166 Mdot
.4892 .61345 Mdot
.4656 .60345 Mdot
.3908 .5718 Mdot
.16475 .47833 Mdot
.73341 .35145 Mdot
.5395 .49819 Mdot
.40423 .53443 Mdot
.13381 .45091 Mdot
.68551 .34096 Mdot
.49961 .61787 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.48751 .61274 Mdot
.46022 .60117 Mdot
.37388 .56467 Mdot
.11754 .45961 Mdot
.70049 .36028 Mdot
.51071 .50074 Mdot
.33698 .51067 Mdot
.9593 .38461 Mdot
.49897 .6176 Mdot
.49673 .61665 Mdot
.48958 .61361 Mdot
.46681 .60396 Mdot
.3946 .57341 Mdot
.17561 .48269 Mdot
.74349 .35097 Mdot
.54991 .49839 Mdot
.42996 .5439 Mdot
.20831 .48105 Mdot
.75607 .33854 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48029 .60968 Mdot
.43729 .59146 Mdot
.30263 .53481 Mdot
.94217 .39526 Mdot
.66656 .4477 Mdot
.59762 .57543 Mdot
.6661 .04232 Mdot
.94089 .16983 Mdot
.30233 .22338 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.4953 .61604 Mdot
.48503 .61168 Mdot
.45232 .59782 Mdot
.34917 .55428 Mdot
.05214 .43446 Mdot
.6783 .38698 Mdot
.51936 .51981 Mdot
.38939 .53771 Mdot
.10655 .44323 Mdot
.49782 .61711 Mdot
.49307 .61509 Mdot
.47792 .60867 Mdot
.42975 .58827 Mdot
.27961 .52524 Mdot
.89484 .38024 Mdot
.65659 .47078 Mdot
.61711 .59364 Mdot
.73787 .07464 Mdot
.09668 .22175 Mdot
.31922 .13754 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48617 .61217 Mdot
.45596 .59937 Mdot
.36054 .55906 Mdot
.0817 .4457 Mdot
.68562 .37324 Mdot
.509 .50888 Mdot
.34587 .51722 Mdot
.98604 .39564 Mdot
.64712 .40857 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51979 .00839 Mdot
.56297 .02669 Mdot
.69815 .08355 Mdot
.05951 .22333 Mdot
.33367 .16944 Mdot
.40134 .04182 Mdot
.33031 .57413 Mdot
.05029 .44498 Mdot
.49988 .61798 Mdot
.49962 .61787 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48763 .61279 Mdot
.46061 .60133 Mdot
.3751 .56519 Mdot
.12089 .46092 Mdot
.70228 .35932 Mdot
.51176 .50029 Mdot
.33887 .51118 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50314 .00133 Mdot
.51002 .00425 Mdot
.53191 .01353 Mdot
.60135 .04292 Mdot
.81276 .13065 Mdot
.24457 .26688 Mdot
.43779 .11942 Mdot
.54006 .0632 Mdot
.70178 .09995 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49228 .61476 Mdot
.47541 .60761 Mdot
.42181 .58491 Mdot
.25559 .5153 Mdot
.85078 .36785 Mdot
.63842 .48679 Mdot
.60849 .59953 Mdot
.72897 .07446 Mdot
.0861 .22072 Mdot
.49955 .61784 Mdot
.49858 .61743 Mdot
.49547 .61611 Mdot
.48556 .61191 Mdot
.45404 .59855 Mdot
.35452 .55653 Mdot
.06592 .43967 Mdot
.68125 .38029 Mdot
.51337 .51428 Mdot
.36553 .52666 Mdot
.03913 .41631 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51388 .00589 Mdot
.5442 .01874 Mdot
.63997 .05919 Mdot
.91965 .17285 Mdot
.3148 .24422 Mdot
.49074 .10874 Mdot
.6528 .10016 Mdot
.01043 .22103 Mdot
.35243 .21137 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.5124 .00526 Mdot
.53948 .01674 Mdot
.62517 .05296 Mdot
.87984 .1574 Mdot
.29811 .25851 Mdot
.48848 .11765 Mdot
.66158 .10698 Mdot
.0375 .23233 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.51089 .00462 Mdot
.5347 .01471 Mdot
.61014 .04663 Mdot
.83792 .14077 Mdot
.26892 .26637 Mdot
.46287 .11987 Mdot
.60164 .08576 Mdot
.88272 .17372 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49103 .61423 Mdot
.47144 .60592 Mdot
.40923 .57959 Mdot
.21812 .49992 Mdot
.79305 .35533 Mdot
.59803 .49751 Mdot
.54094 .58275 Mdot
.5446 .00226 Mdot
.61428 .04306 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49056 .61403 Mdot
.46994 .60529 Mdot
.40448 .57758 Mdot
.2042 .49425 Mdot
.77501 .35278 Mdot
.5816 .4985 Mdot
.50531 .57088 Mdot
.43697 .5758 Mdot
.27655 .51889 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49543 .6161 Mdot
.48544 .61186 Mdot
.45363 .59838 Mdot
.35325 .556 Mdot
.06264 .43842 Mdot
.68047 .38185 Mdot
.51463 .51553 Mdot
.37069 .52908 Mdot
.05344 .42196 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48249 .61061 Mdot
.44425 .5944 Mdot
.32409 .54377 Mdot
.99059 .41192 Mdot
.6712 .42064 Mdot
.56188 .55047 Mdot
.54305 .6064 Mdot
.58801 .02779 Mdot
.75837 .10528 Mdot
.50035 .00015 Mdot
.50112 .00047 Mdot
.50356 .00151 Mdot
.51135 .00481 Mdot
.53616 .01533 Mdot
.61474 .04856 Mdot
.8509 .14596 Mdot
.2794 .26483 Mdot
.47324 .1198 Mdot
.62711 .0951 Mdot
.95203 .20081 Mdot
.34782 .24461 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.47429 .60713 Mdot
.41826 .5834 Mdot
.24493 .51091 Mdot
.833 .36344 Mdot
.62806 .49138 Mdot
.59515 .59769 Mdot
.69661 .06271 Mdot
.02349 .20203 Mdot
.31527 .18033 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50669 .00284 Mdot
.52132 .00904 Mdot
.56782 .02874 Mdot
.71299 .08972 Mdot
.09047 .2333 Mdot
.33944 .15387 Mdot
.38638 .02901 Mdot
.27701 .55044 Mdot
.93233 .40501 Mdot
.68613 .46587 Mdot
.49827 .6173 Mdot
.4945 .6157 Mdot
.48249 .61061 Mdot
.44427 .59441 Mdot
.32414 .54379 Mdot
.99071 .41197 Mdot
.67121 .42057 Mdot
.56178 .5504 Mdot
.54272 .60625 Mdot
.58698 .02735 Mdot
.7553 .10403 Mdot
.49921 .6177 Mdot
.4975 .61697 Mdot
.49203 .61465 Mdot
.4746 .60726 Mdot
.41924 .58382 Mdot
.24788 .51213 Mdot
.8378 .36459 Mdot
.63104 .49025 Mdot
.59938 .59846 Mdot
.70728 .06669 Mdot
.04537 .20895 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00156 Mdot
.51176 .00499 Mdot
.53744 .01587 Mdot
.61877 .05027 Mdot
.86218 .15043 Mdot
.28743 .26282 Mdot
.48052 .11934 Mdot
.64448 .10133 Mdot
.99658 .21761 Mdot
.35381 .22078 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49544 .6161 Mdot
.48548 .61188 Mdot
.45376 .59843 Mdot
.35367 .55617 Mdot
.06372 .43883 Mdot
.68072 .38133 Mdot
.5142 .51512 Mdot
.36895 .52827 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.51958 .0083 Mdot
.5623 .02641 Mdot
.69611 .0827 Mdot
.0551 .22187 Mdot
.33308 .1718 Mdot
.40412 .0439 Mdot
.33987 .57833 Mdot
.07396 .45369 Mdot
.70106 .38757 Mdot
.49853 .61741 Mdot
.49531 .61605 Mdot
.48507 .6117 Mdot
.45246 .59788 Mdot
.34959 .55446 Mdot
.05322 .43487 Mdot
.6785 .38645 Mdot
.51883 .51935 Mdot
.38733 .53676 Mdot
.10059 .44082 Mdot
.67281 .35365 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48979 .6137 Mdot
.46747 .60424 Mdot
.39671 .5743 Mdot
.18165 .48512 Mdot
.74954 .35098 Mdot
.55617 .49852 Mdot
.4453 .54951 Mdot
.25398 .4998 Mdot
.82401 .3523 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48084 .60991 Mdot
.43901 .59219 Mdot
.30793 .53702 Mdot
.95375 .39914 Mdot
.66798 .44141 Mdot
.58992 .56979 Mdot
.63969 .03076 Mdot
.87311 .14426 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52147 .00911 Mdot
.56832 .02895 Mdot
.71453 .09036 Mdot
.09356 .23426 Mdot
.3402 .15243 Mdot
.38543 .02795 Mdot
.27326 .54871 Mdot
.9249 .40274 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00074 Mdot
.50553 .00234 Mdot
.5176 .00746 Mdot
.55603 .02375 Mdot
.67678 .07463 Mdot
.01144 .20683 Mdot
.32895 .19624 Mdot
.43652 .06648 Mdot
.45137 .00918 Mdot
.3944 .58283 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50555 .00235 Mdot
.51767 .00749 Mdot
.55626 .02385 Mdot
.67748 .07492 Mdot
.01307 .20741 Mdot
.32908 .1953 Mdot
.43522 .0656 Mdot
.44686 .00719 Mdot
.38026 .57687 Mdot
.15053 .47605 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.5055 .00233 Mdot
.51751 .00742 Mdot
.55573 .02362 Mdot
.67585 .07424 Mdot
.00925 .20605 Mdot
.32879 .19749 Mdot
.43825 .06765 Mdot
.4574 .01183 Mdot
.4134 .59084 Mdot
.24581 .51446 Mdot
.4988 .61752 Mdot
.49617 .61641 Mdot
.48779 .61286 Mdot
.46112 .60155 Mdot
.37669 .56586 Mdot
.12527 .46264 Mdot
.70475 .35814 Mdot
.51338 .49976 Mdot
.34205 .51215 Mdot
.97082 .3886 Mdot
.64311 .4155 Mdot
.49836 .61734 Mdot
.49479 .61582 Mdot
.48339 .61099 Mdot
.44712 .59562 Mdot
.33298 .54749 Mdot
.01182 .41955 Mdot
.67295 .4086 Mdot
.54538 .53919 Mdot
.48496 .58069 Mdot
.402 .56677 Mdot
.18117 .48155 Mdot
.49775 .61708 Mdot
.49282 .61499 Mdot
.47713 .60834 Mdot
.42725 .58721 Mdot
.272 .52208 Mdot
.88029 .37595 Mdot
.65169 .47675 Mdot
.61771 .59703 Mdot
.74462 .07844 Mdot
.11014 .2259 Mdot
.32332 .13175 Mdot
.49871 .61749 Mdot
.4959 .6163 Mdot
.48695 .6125 Mdot
.45844 .60042 Mdot
.3683 .56233 Mdot
.10241 .4537 Mdot
.69328 .36518 Mdot
.50789 .50345 Mdot
.33432 .51076 Mdot
.95475 .38345 Mdot
.64214 .42483 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50346 .00147 Mdot
.51104 .00468 Mdot
.53516 .01491 Mdot
.61159 .04724 Mdot
.84203 .14242 Mdot
.27238 .26598 Mdot
.46637 .11989 Mdot
.61028 .08894 Mdot
.90669 .18319 Mdot
.33518 .26482 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50597 .00253 Mdot
.51902 .00807 Mdot
.56054 .02566 Mdot
.69068 .08043 Mdot
.04317 .21785 Mdot
.33169 .17832 Mdot
.41225 .04979 Mdot
.36776 .59053 Mdot
.14695 .48157 Mdot
.73573 .36388 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50415 .00176 Mdot
.51323 .00561 Mdot
.54214 .01786 Mdot
.63351 .05647 Mdot
.90247 .16623 Mdot
.30874 .25109 Mdot
.49235 .11348 Mdot
.66451 .10639 Mdot
.04176 .23316 Mdot
.35709 .19488 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51819 .00771 Mdot
.55789 .02454 Mdot
.68252 .07703 Mdot
.02475 .21151 Mdot
.33 .18866 Mdot
.42605 .05936 Mdot
.41513 .61128 Mdot
.28284 .53628 Mdot
.91689 .39186 Mdot
.50006 2e-05 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50601 .00255 Mdot
.51915 .00812 Mdot
.56094 .02583 Mdot
.69193 .08096 Mdot
.04594 .21879 Mdot
.33199 .17679 Mdot
.41029 .04839 Mdot
.36105 .5876 Mdot
.49813 .61724 Mdot
.49404 .61551 Mdot
.481 .60998 Mdot
.43954 .59241 Mdot
.30955 .5377 Mdot
.95734 .40036 Mdot
.66836 .43943 Mdot
.58738 .56799 Mdot
.63099 .02695 Mdot
.84964 .13513 Mdot
.26174 .2547 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51228 .00521 Mdot
.5391 .01658 Mdot
.62397 .05246 Mdot
.87657 .15611 Mdot
.2963 .25941 Mdot
.48733 .11806 Mdot
.65938 .10633 Mdot
.03249 .2306 Mdot
.35721 .20068 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52354 .00998 Mdot
.57486 .03172 Mdot
.73439 .09859 Mdot
.13149 .24543 Mdot
.35305 .13693 Mdot
.38418 .01924 Mdot
.25653 .53914 Mdot
.89034 .39172 Mdot
.67593 .48552 Mdot
.49928 .61773 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47684 .60821 Mdot
.42632 .58681 Mdot
.26919 .52092 Mdot
.87505 .37445 Mdot
.64967 .47874 Mdot
.61714 .59793 Mdot
.74489 .07895 Mdot
.11124 .22642 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51564 .00663 Mdot
.5498 .02111 Mdot
.65744 .06653 Mdot
.96456 .18981 Mdot
.3244 .2224 Mdot
.47113 .09068 Mdot
.5748 .06407 Mdot
.78657 .13088 Mdot
.2308 .27455 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47386 .60695 Mdot
.41688 .58282 Mdot
.24082 .50922 Mdot
.82642 .36192 Mdot
.62376 .49278 Mdot
.58858 .59629 Mdot
.67953 .05621 Mdot
.98619 .18952 Mdot
.31354 .20231 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48277 .61073 Mdot
.44514 .59478 Mdot
.32685 .54493 Mdot
.99712 .41425 Mdot
.67171 .41692 Mdot
.55672 .54697 Mdot
.52503 .59845 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.49411 .61553 Mdot
.48122 .61007 Mdot
.44023 .5927 Mdot
.31168 .53859 Mdot
.9621 .40198 Mdot
.66884 .43679 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51245 .00528 Mdot
.53963 .0168 Mdot
.62566 .05317 Mdot
.88119 .15793 Mdot
.29884 .25812 Mdot
.48891 .11747 Mdot
.66236 .1072 Mdot
.03924 .23293 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51073 .00455 Mdot
.53418 .01449 Mdot
.60851 .04594 Mdot
.83329 .13892 Mdot
.26485 .26672 Mdot
.45871 .11981 Mdot
.59134 .08197 Mdot
.85356 .16207 Mdot
.30574 .27946 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47765 .60856 Mdot
.42891 .58791 Mdot
.27703 .52417 Mdot
.88986 .37875 Mdot
.65502 .4729 Mdot
.61766 .59494 Mdot
.74114 .07632 Mdot
.10298 .22363 Mdot
.32091 .13469 Mdot
.50061 .00026 Mdot
.50195 .00082 Mdot
.5062 .00263 Mdot
.51974 .00837 Mdot
.56283 .02663 Mdot
.69773 .08338 Mdot
.05861 .22304 Mdot
.33355 .16992 Mdot
.40189 .04224 Mdot
.33222 .57497 Mdot
.05496 .44668 Mdot
.69689 .39674 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52505 .01062 Mdot
.57964 .03374 Mdot
.74878 .10453 Mdot
.15664 .25207 Mdot
.36568 .12919 Mdot
.39631 .01893 Mdot
.28219 .5475 Mdot
.93421 .40297 Mdot
.68212 .46224 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50619 .00263 Mdot
.51972 .00836 Mdot
.56277 .0266 Mdot
.69754 .08329 Mdot
.05819 .22289 Mdot
.33349 .17014 Mdot
.40215 .04244 Mdot
.33313 .57537 Mdot
.05719 .4475 Mdot
.6973 .39561 Mdot
.4987 .61748 Mdot
.49586 .61628 Mdot
.48681 .61244 Mdot
.45799 .60023 Mdot
.3669 .56173 Mdot
.09862 .45223 Mdot
.6917 .36654 Mdot
.50767 .5043 Mdot
.33515 .51141 Mdot
.95725 .38448 Mdot
.64271 .42364 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51684 .00714 Mdot
.55362 .02273 Mdot
.66932 .07151 Mdot
.99373 .2005 Mdot
.32754 .20631 Mdot
.4504 .07593 Mdot
.50005 .03069 Mdot
.54979 .03074 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51499 .00636 Mdot
.54774 .02024 Mdot
.65102 .06383 Mdot
.94833 .18375 Mdot
.32179 .23081 Mdot
.4804 .09803 Mdot
.60969 .07991 Mdot
.89081 .17374 Mdot
.32316 .26721 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.505 .00212 Mdot
.51593 .00676 Mdot
.55072 .0215 Mdot
.6603 .06773 Mdot
.97169 .19245 Mdot
.32532 .21856 Mdot
.46646 .08723 Mdot
.55766 .05636 Mdot
.73347 .10866 Mdot
.14672 .2554 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50833 .00353 Mdot
.52652 .01125 Mdot
.58432 .03572 Mdot
.76276 .11028 Mdot
.17916 .25735 Mdot
.38009 .12418 Mdot
.4177 .02324 Mdot
.3373 .56834 Mdot
.05318 .44244 Mdot
.69077 .39405 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50657 .00278 Mdot
.52091 .00887 Mdot
.56655 .0282 Mdot
.70911 .08811 Mdot
.08257 .23081 Mdot
.33766 .15765 Mdot
.38931 .03193 Mdot
.28801 .55542 Mdot
.95474 .41207 Mdot
.68845 .45346 Mdot
.5007 .0003 Mdot
.50223 .00095 Mdot
.50711 .00301 Mdot
.52264 .0096 Mdot
.57201 .03051 Mdot
.72574 .09501 Mdot
.11544 .24085 Mdot
.34677 .14297 Mdot
.38215 .02186 Mdot
.25646 .54036 Mdot
.89225 .39293 Mdot
.67759 .48537 Mdot
.49764 .61703 Mdot
.49248 .61484 Mdot
.47603 .60787 Mdot
.42378 .58574 Mdot
.26151 .51775 Mdot
.86114 .37059 Mdot
.64362 .4836 Mdot
.61345 .59939 Mdot
.73942 .07785 Mdot
.10359 .22507 Mdot
.32312 .13567 Mdot
.49819 .61727 Mdot
.49425 .61559 Mdot
.48167 .61026 Mdot
.44166 .59331 Mdot
.31609 .54043 Mdot
.97208 .40542 Mdot
.66973 .43117 Mdot
.57639 .56035 Mdot
.59329 .01044 Mdot
.74226 .09206 Mdot
.12967 .23943 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49236 .61479 Mdot
.47567 .60772 Mdot
.42261 .58525 Mdot
.258 .5163 Mdot
.85496 .36894 Mdot
.64059 .48555 Mdot
.61073 .59958 Mdot
.73388 .07611 Mdot
.09454 .2229 Mdot
.50046 .0002 Mdot
.50147 .00063 Mdot
.5047 .00199 Mdot
.51497 .00635 Mdot
.54766 .0202 Mdot
.65078 .06373 Mdot
.94773 .18352 Mdot
.32168 .23111 Mdot
.4807 .09828 Mdot
.61085 .08044 Mdot
.89416 .17509 Mdot
.32478 .26614 Mdot
.49906 .61763 Mdot
.49699 .61676 Mdot
.49042 .61397 Mdot
.46949 .6051 Mdot
.40308 .57699 Mdot
.20012 .4926 Mdot
.77005 .35224 Mdot
.57683 .49861 Mdot
.49442 .5671 Mdot
.40363 .56192 Mdot
.17696 .47794 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.4848 .61159 Mdot
.4516 .59752 Mdot
.34692 .55334 Mdot
.04641 .43231 Mdot
.67727 .38989 Mdot
.52237 .5223 Mdot
.40091 .54297 Mdot
.14022 .45692 Mdot
.69538 .34311 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.5263 .01115 Mdot
.5836 .03542 Mdot
.76063 .10941 Mdot
.17585 .25662 Mdot
.37779 .1248 Mdot
.41389 .02232 Mdot
.32705 .56436 Mdot
.0289 .43377 Mdot
.68764 .40712 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52599 .01102 Mdot
.58264 .03501 Mdot
.75775 .10822 Mdot
.17131 .25559 Mdot
.37473 .12572 Mdot
.40905 .02121 Mdot
.31424 .55944 Mdot
.99989 .42375 Mdot
.6857 .42386 Mdot
.49901 .61761 Mdot
.49683 .61669 Mdot
.4899 .61375 Mdot
.46784 .6044 Mdot
.39786 .57478 Mdot
.18497 .48646 Mdot
.753 .35106 Mdot
.55972 .49858 Mdot
.45393 .55265 Mdot
.28001 .51054 Mdot
.87158 .36561 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54192 .01777 Mdot
.63283 .05619 Mdot
.90065 .16552 Mdot
.308 .25176 Mdot
.4923 .1139 Mdot
.66506 .10677 Mdot
.04334 .23379 Mdot
.35742 .19411 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49941 .61778 Mdot
.49812 .61724 Mdot
.49402 .6155 Mdot
.48095 .60995 Mdot
.43936 .59233 Mdot
.309 .53747 Mdot
.95613 .39995 Mdot
.66823 .4401 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49542 .61609 Mdot
.48541 .61185 Mdot
.45356 .59835 Mdot
.35302 .5559 Mdot
.06205 .4382 Mdot
.68034 .38212 Mdot
.51486 .51576 Mdot
.37164 .52952 Mdot
.05608 .42301 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50584 .00248 Mdot
.5186 .00789 Mdot
.55921 .02509 Mdot
.68658 .07872 Mdot
.03399 .21471 Mdot
.3308 .18344 Mdot
.41899 .0545 Mdot
.39083 .60063 Mdot
.21147 .50718 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50278 .00118 Mdot
.50885 .00375 Mdot
.52818 .01195 Mdot
.58957 .03794 Mdot
.77832 .11666 Mdot
.20203 .26187 Mdot
.39778 .12098 Mdot
.45052 .03259 Mdot
.43022 .60549 Mdot
.30856 .54285 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50674 .00286 Mdot
.52147 .0091 Mdot
.56829 .02894 Mdot
.71445 .09033 Mdot
.0934 .23421 Mdot
.34016 .1525 Mdot
.38547 .02801 Mdot
.27345 .5488 Mdot
.92527 .40285 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49057 .61404 Mdot
.46997 .6053 Mdot
.40459 .57763 Mdot
.20451 .49438 Mdot
.77538 .35282 Mdot
.58196 .49849 Mdot
.5061 .57116 Mdot
.43941 .57681 Mdot
.5004 .00017 Mdot
.50126 .00053 Mdot
.50401 .0017 Mdot
.51278 .00542 Mdot
.5407 .01726 Mdot
.62902 .05458 Mdot
.89035 .16151 Mdot
.30345 .25531 Mdot
.49116 .11601 Mdot
.6656 .10781 Mdot
.04599 .23509 Mdot
.35835 .19305 Mdot
.49954 .61784 Mdot
.49855 .61742 Mdot
.49537 .61607 Mdot
.48525 .61178 Mdot
.45303 .59812 Mdot
.35137 .55521 Mdot
.05779 .43659 Mdot
.67942 .38419 Mdot
.51668 .51746 Mdot
.37892 .53289 Mdot
.07657 .43117 Mdot
.49752 .61698 Mdot
.49208 .61468 Mdot
.47479 .60734 Mdot
.41983 .58407 Mdot
.24963 .51284 Mdot
.84069 .3653 Mdot
.63277 .48953 Mdot
.60169 .59883 Mdot
.71299 .06878 Mdot
.05659 .21236 Mdot
.31708 .16099 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50274 .00116 Mdot
.50872 .0037 Mdot
.52776 .01177 Mdot
.58825 .03738 Mdot
.77442 .11506 Mdot
.19652 .26087 Mdot
.39324 .12158 Mdot
.44156 .02987 Mdot
.40419 .59493 Mdot
.23162 .51138 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52352 .00997 Mdot
.57479 .03169 Mdot
.73418 .09851 Mdot
.13112 .24532 Mdot
.35289 .13706 Mdot
.38409 .01928 Mdot
.25639 .53911 Mdot
.89016 .39169 Mdot
.67591 .48562 Mdot
.49956 .61785 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.4857 .61197 Mdot
.45446 .59873 Mdot
.35583 .55708 Mdot
.06934 .44097 Mdot
.6821 .3787 Mdot
.51218 .51302 Mdot
.36053 .52431 Mdot
.02544 .41093 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48054 .60978 Mdot
.43806 .59178 Mdot
.30499 .5358 Mdot
.94731 .39697 Mdot
.66722 .44493 Mdot
.59431 .57297 Mdot
.65471 .03733 Mdot
.91232 .15921 Mdot
.2949 .23644 Mdot
.50039 .00017 Mdot
.50126 .00053 Mdot
.504 .0017 Mdot
.51274 .0054 Mdot
.54059 .01721 Mdot
.62865 .05443 Mdot
.88935 .16112 Mdot
.30297 .25563 Mdot
.49097 .11619 Mdot
.66542 .10782 Mdot
.04567 .23501 Mdot
.35836 .19325 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.52082 .00883 Mdot
.56624 .02807 Mdot
.70817 .08772 Mdot
.08064 .2302 Mdot
.33726 .1586 Mdot
.39014 .03268 Mdot
.291 .55676 Mdot
.961 .41408 Mdot
.68892 .44988 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .61259 Mdot
.45915 .60072 Mdot
.37053 .56326 Mdot
.10842 .45604 Mdot
.69597 .36313 Mdot
.50863 .50225 Mdot
.33423 .51025 Mdot
.95376 .38289 Mdot
.64168 .42516 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51484 .00629 Mdot
.54725 .02003 Mdot
.64951 .0632 Mdot
.94446 .18229 Mdot
.32104 .23274 Mdot
.48229 .09965 Mdot
.61702 .08327 Mdot
.91188 .18224 Mdot
.33227 .25982 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52444 .01036 Mdot
.57772 .03293 Mdot
.74301 .10215 Mdot
.1468 .24956 Mdot
.36031 .13196 Mdot
.39018 .01846 Mdot
.26807 .54257 Mdot
.90876 .39597 Mdot
.67894 .476 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51188 .00504 Mdot
.53783 .01604 Mdot
.62 .05078 Mdot
.86558 .15178 Mdot
.28967 .2621 Mdot
.48239 .11911 Mdot
.64876 .10282 Mdot
.00717 .22151 Mdot
.49761 .61702 Mdot
.49237 .6148 Mdot
.47571 .60773 Mdot
.42275 .5853 Mdot
.25841 .51647 Mdot
.85568 .36913 Mdot
.64095 .48533 Mdot
.61108 .59957 Mdot
.73463 .07636 Mdot
.0958 .22322 Mdot
.32179 .13967 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02053 Mdot
.65314 .06472 Mdot
.95374 .18578 Mdot
.32275 .22806 Mdot
.47754 .09567 Mdot
.59876 .07492 Mdot
.8588 .16071 Mdot
.30393 .2751 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50788 .00334 Mdot
.52511 .01065 Mdot
.57985 .03383 Mdot
.7494 .10479 Mdot
.15768 .25233 Mdot
.36628 .12892 Mdot
.39708 .01903 Mdot
.28403 .54817 Mdot
.93768 .40398 Mdot
.68244 .46029 Mdot
.49873 .6175 Mdot
.49597 .61632 Mdot
.48716 .61259 Mdot
.4591 .6007 Mdot
.37038 .5632 Mdot
.108 .45588 Mdot
.69578 .36326 Mdot
.50856 .50233 Mdot
.33419 .51026 Mdot
.95371 .38289 Mdot
.64169 .4252 Mdot
.49894 .61758 Mdot
.49661 .6166 Mdot
.48921 .61346 Mdot
.46563 .60346 Mdot
.39091 .57185 Mdot
.16507 .47846 Mdot
.73369 .35143 Mdot
.53979 .4982 Mdot
.40494 .5347 Mdot
.13585 .45172 Mdot
.68683 .34053 Mdot
.49889 .61756 Mdot
.49646 .61653 Mdot
.48872 .61325 Mdot
.46409 .60281 Mdot
.38604 .5698 Mdot
.1513 .47296 Mdot
.72228 .35288 Mdot
.52838 .4982 Mdot
.37682 .52436 Mdot
.05838 .42123 Mdot
.65433 .36831 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50964 .00409 Mdot
.5307 .01302 Mdot
.59752 .0413 Mdot
.80163 .12615 Mdot
.23203 .266 Mdot
.42521 .11939 Mdot
.51029 .05258 Mdot
.6108 .06212 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52544 .01079 Mdot
.5809 .03427 Mdot
.75255 .10609 Mdot
.1629 .25361 Mdot
.36939 .12761 Mdot
.40121 .01967 Mdot
.2942 .55189 Mdot
.95759 .41 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50703 .00298 Mdot
.5224 .0095 Mdot
.57127 .0302 Mdot
.72349 .09408 Mdot
.11114 .23958 Mdot
.34531 .14472 Mdot
.38227 .02285 Mdot
.25832 .54143 Mdot
.89596 .39408 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50272 .00115 Mdot
.50866 .00367 Mdot
.52757 .01169 Mdot
.58764 .03712 Mdot
.77262 .11432 Mdot
.19392 .26038 Mdot
.39116 .1219 Mdot
.43758 .02869 Mdot
.39274 .59032 Mdot
.19891 .49824 Mdot
.49796 .61717 Mdot
.49351 .61528 Mdot
.47932 .60926 Mdot
.43419 .59014 Mdot
.29314 .53086 Mdot
.92207 .3887 Mdot
.66328 .4581 Mdot
.60866 .58427 Mdot
.70465 .05933 Mdot
.02974 .20092 Mdot
.31048 .17351 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50687 .00291 Mdot
.52187 .00927 Mdot
.56958 .02949 Mdot
.71837 .09195 Mdot
.10119 .23659 Mdot
.34225 .14898 Mdot
.38356 .02554 Mdot
.2654 .545 Mdot
.90961 .39815 Mdot
.68224 .47751 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48499 .61167 Mdot
.45222 .59778 Mdot
.34886 .55415 Mdot
.05136 .43417 Mdot
.67815 .38738 Mdot
.51976 .52014 Mdot
.39092 .53841 Mdot
.11097 .44502 Mdot
.67773 .35028 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.5072 .00306 Mdot
.52295 .00973 Mdot
.57301 .03094 Mdot
.72878 .09627 Mdot
.12116 .2425 Mdot
.34885 .14072 Mdot
.38241 .02074 Mdot
.25518 .53941 Mdot
.88935 .39194 Mdot
.49973 .61792 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.4913 .61434 Mdot
.47227 .60628 Mdot
.41187 .5807 Mdot
.22591 .50311 Mdot
.80396 .35725 Mdot
.60714 .4964 Mdot
.55918 .58839 Mdot
.59796 .02397 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50785 .00333 Mdot
.52502 .01061 Mdot
.57956 .03371 Mdot
.74853 .10443 Mdot
.15622 .25197 Mdot
.36544 .1293 Mdot
.39601 .0189 Mdot
.28148 .54725 Mdot
.93286 .40258 Mdot
.68199 .46299 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50507 .00215 Mdot
.51615 .00685 Mdot
.55142 .0218 Mdot
.66248 .06864 Mdot
.97707 .19443 Mdot
.32594 .21562 Mdot
.46274 .08455 Mdot
.54417 .05032 Mdot
.69101 .09075 Mdot
.06036 .22827 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50668 .00283 Mdot
.52127 .00902 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51119 .00475 Mdot
.53564 .01511 Mdot
.61312 .04788 Mdot
.84634 .14414 Mdot
.27587 .26547 Mdot
.46983 .11987 Mdot
.61879 .09206 Mdot
.92984 .19224 Mdot
.34276 .2552 Mdot
.49779 .6171 Mdot
.49295 .61504 Mdot
.47754 .60851 Mdot
.42855 .58776 Mdot
.27594 .52372 Mdot
.88776 .37813 Mdot
.65433 .47377 Mdot
.61778 .59545 Mdot
.74222 .07691 Mdot
.10511 .22428 Mdot
.32155 .13376 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50736 .00312 Mdot
.52345 .00994 Mdot
.5746 .03161 Mdot
.73358 .09826 Mdot
.13003 .24502 Mdot
.35242 .13744 Mdot
.38383 .01941 Mdot
.25604 .53906 Mdot
.50037 .00016 Mdot
.50117 .00049 Mdot
.50371 .00157 Mdot
.51183 .00502 Mdot
.53767 .01597 Mdot
.6195 .05057 Mdot
.86421 .15124 Mdot
.28877 .2624 Mdot
.48166 .11921 Mdot
.64708 .10224 Mdot
.00304 .22 Mdot
.35444 .21718 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00179 Mdot
.51342 .00569 Mdot
.54272 .01811 Mdot
.63535 .05724 Mdot
.90739 .16813 Mdot
.31064 .24922 Mdot
.49228 .11226 Mdot
.66234 .1051 Mdot
.03583 .23083 Mdot
.35603 .19789 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50483 .00205 Mdot
.51538 .00652 Mdot
.54897 .02076 Mdot
.65485 .06544 Mdot
.95806 .18739 Mdot
.32345 .22582 Mdot
.47509 .09372 Mdot
.49999 .61803 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49935 .61776 Mdot
.49793 .61716 Mdot
.49341 .61524 Mdot
.47901 .60913 Mdot
.43321 .58973 Mdot
.29013 .52961 Mdot
.91587 .38673 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52329 .00987 Mdot
.57407 .03138 Mdot
.73198 .0976 Mdot
.1271 .2442 Mdot
.3512 .1385 Mdot
.38322 .01979 Mdot
.25536 .53901 Mdot
.88891 .39155 Mdot
.67589 .48638 Mdot
.50046 .0002 Mdot
.50147 .00063 Mdot
.5047 .00199 Mdot
.51497 .00635 Mdot
.54766 .0202 Mdot
.65078 .06373 Mdot
.94773 .18352 Mdot
.32168 .23111 Mdot
.4807 .09828 Mdot
.61086 .08044 Mdot
.89417 .1751 Mdot
.32479 .26613 Mdot
.49868 .61748 Mdot
.49581 .61626 Mdot
.48665 .61237 Mdot
.45749 .60001 Mdot
.36532 .56107 Mdot
.09438 .45059 Mdot
.69003 .36813 Mdot
.50766 .50532 Mdot
.33677 .51242 Mdot
.96176 .38626 Mdot
.64356 .42138 Mdot
.49843 .61737 Mdot
.495 .61591 Mdot
.48406 .61127 Mdot
.44925 .59652 Mdot
.33959 .55026 Mdot
.02803 .42548 Mdot
.67464 .39963 Mdot
.53373 .53094 Mdot
.44302 .56198 Mdot
.26867 .51028 Mdot
.85723 .36375 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52515 .01067 Mdot
.57999 .03389 Mdot
.74981 .10496 Mdot
.15837 .2525 Mdot
.36668 .12874 Mdot
.39759 .0191 Mdot
.28527 .54861 Mdot
.94005 .40468 Mdot
.49855 .61742 Mdot
.49538 .61607 Mdot
.48528 .61179 Mdot
.45312 .59816 Mdot
.35166 .55533 Mdot
.05854 .43688 Mdot
.67958 .38382 Mdot
.51635 .51715 Mdot
.37759 .53228 Mdot
.0728 .42966 Mdot
.66258 .3645 Mdot
.50016 7e-05 Mdot
.50053 .00022 Mdot
.50167 .00071 Mdot
.50533 .00226 Mdot
.51699 .0072 Mdot
.55407 .02292 Mdot
.67071 .07209 Mdot
.99706 .2017 Mdot
.32782 .20442 Mdot
.44783 .07417 Mdot
.49097 .02666 Mdot
.52057 .01829 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51177 .00499 Mdot
.53748 .01589 Mdot
.61889 .05032 Mdot
.86251 .15056 Mdot
.28765 .26275 Mdot
.48071 .11932 Mdot
.64491 .10148 Mdot
.99767 .21802 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.5259 .01098 Mdot
.58236 .03489 Mdot
.75692 .10788 Mdot
.16999 .25529 Mdot
.37386 .126 Mdot
.40772 .02093 Mdot
.31079 .55813 Mdot
.99234 .42122 Mdot
.68537 .42832 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47929 .60925 Mdot
.43412 .59011 Mdot
.29292 .53077 Mdot
.92162 .38856 Mdot
.66319 .45832 Mdot
.60886 .58446 Mdot
.70539 .05965 Mdot
.03132 .20144 Mdot
.31058 .17259 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51013 .00429 Mdot
.53225 .01368 Mdot
.60243 .04337 Mdot
.81587 .13191 Mdot
.24788 .267 Mdot
.44118 .11947 Mdot
.54825 .06617 Mdot
.7266 .11022 Mdot
.1411 .25618 Mdot
.49921 .6177 Mdot
.4975 .61697 Mdot
.49203 .61465 Mdot
.47461 .60727 Mdot
.41928 .58384 Mdot
.24799 .51217 Mdot
.83799 .36464 Mdot
.63116 .4902 Mdot
.59954 .59849 Mdot
.70767 .06683 Mdot
.04615 .20919 Mdot
.49922 .6177 Mdot
.4975 .61697 Mdot
.49204 .61466 Mdot
.47463 .60728 Mdot
.41933 .58386 Mdot
.24814 .51223 Mdot
.83824 .3647 Mdot
.63131 .49014 Mdot
.59974 .59852 Mdot
.70818 .06702 Mdot
.04715 .2095 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.50869 .00369 Mdot
.52769 .01174 Mdot
.58802 .03729 Mdot
.77375 .11479 Mdot
.19556 .26069 Mdot
.39247 .12169 Mdot
.44008 .02942 Mdot
.39991 .59321 Mdot
.21931 .50642 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50369 .00157 Mdot
.51177 .00499 Mdot
.53749 .01589 Mdot
.61892 .05033 Mdot
.8626 .1506 Mdot
.28771 .26273 Mdot
.48076 .11931 Mdot
.64503 .10152 Mdot
.99795 .21812 Mdot
.35395 .22002 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50812 .00344 Mdot
.52586 .01097 Mdot
.58223 .03484 Mdot
.75652 .10772 Mdot
.16934 .25514 Mdot
.37344 .12614 Mdot
.40708 .02079 Mdot
.30913 .5575 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.5187 .00793 Mdot
.55952 .02523 Mdot
.68755 .07913 Mdot
.03617 .21546 Mdot
.331 .18221 Mdot
.41735 .05337 Mdot
.38523 .59818 Mdot
.1955 .50077 Mdot
.78089 .36179 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50759 .00322 Mdot
.52417 .01025 Mdot
.57686 .03257 Mdot
.74041 .10108 Mdot
.14226 .24836 Mdot
.35802 .13335 Mdot
.38796 .0185 Mdot
.26337 .54104 Mdot
.9009 .39401 Mdot
.67765 .48006 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50757 .00321 Mdot
.52411 .01022 Mdot
.57667 .03249 Mdot
.73985 .10085 Mdot
.14127 .24809 Mdot
.35754 .13366 Mdot
.38752 .01853 Mdot
.2625 .54076 Mdot
.89947 .39367 Mdot
.4974 .61693 Mdot
.4917 .61452 Mdot
.47357 .60683 Mdot
.41599 .58244 Mdot
.23815 .50813 Mdot
.82224 .36099 Mdot
.62089 .49359 Mdot
.58394 .5952 Mdot
.66715 .05142 Mdot
.95746 .17942 Mdot
.31083 .21839 Mdot
.49805 .61721 Mdot
.49379 .6154 Mdot
.48021 .60964 Mdot
.43701 .59134 Mdot
.30178 .53446 Mdot
.94035 .39465 Mdot
.66631 .44867 Mdot
.59875 .57628 Mdot
.67 .04403 Mdot
.95045 .17333 Mdot
.30403 .21853 Mdot
.49843 .61737 Mdot
.495 .61592 Mdot
.48409 .61129 Mdot
.44934 .59656 Mdot
.33986 .55038 Mdot
.02872 .42573 Mdot
.67473 .39926 Mdot
.53326 .5306 Mdot
.44133 .56122 Mdot
.26338 .50805 Mdot
.84753 .36103 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48043 .60973 Mdot
.43771 .59163 Mdot
.30392 .53535 Mdot
.94496 .39619 Mdot
.66693 .4462 Mdot
.59584 .5741 Mdot
.65999 .03964 Mdot
.92569 .16421 Mdot
.29885 .23063 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50306 .0013 Mdot
.50975 .00413 Mdot
.53105 .01316 Mdot
.59862 .04176 Mdot
.80483 .12745 Mdot
.23575 .26632 Mdot
.42889 .11937 Mdot
.49838 .61735 Mdot
.49485 .61585 Mdot
.48358 .61107 Mdot
.44774 .59588 Mdot
.33491 .5483 Mdot
.01653 .42126 Mdot
.6734 .40596 Mdot
.54187 .53675 Mdot
.47243 .57512 Mdot
.36184 .54968 Mdot
.06907 .43709 Mdot
.49958 .61786 Mdot
.49868 .61747 Mdot
.49578 .61625 Mdot
.48657 .61234 Mdot
.45722 .5999 Mdot
.36449 .56072 Mdot
.09216 .44973 Mdot
.68919 .36899 Mdot
.50774 .50589 Mdot
.33791 .51307 Mdot
.96483 .38746 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50642 .00272 Mdot
.52044 .00867 Mdot
.56504 .02756 Mdot
.70451 .0862 Mdot
.07303 .22776 Mdot
.33581 .16241 Mdot
.39372 .03579 Mdot
.30379 .56246 Mdot
.98865 .42326 Mdot
.69051 .43378 Mdot
.49897 .6176 Mdot
.49673 .61665 Mdot
.48958 .61361 Mdot
.4668 .60396 Mdot
.39458 .5734 Mdot
.17553 .48266 Mdot
.74341 .35097 Mdot
.54983 .49839 Mdot
.42976 .54383 Mdot
.20772 .48081 Mdot
.75532 .33844 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50751 .00318 Mdot
.52391 .01014 Mdot
.57606 .03223 Mdot
.738 .10009 Mdot
.138 .24721 Mdot
.35598 .13472 Mdot
.38622 .01869 Mdot
.25996 .54 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48384 .61118 Mdot
.44855 .59622 Mdot
.33743 .54936 Mdot
.02269 .42352 Mdot
.67403 .40255 Mdot
.53743 .53361 Mdot
.45644 .56798 Mdot
.31093 .5281 Mdot
.94396 .39124 Mdot
.49886 .61755 Mdot
.49637 .6165 Mdot
.48844 .61313 Mdot
.46319 .60243 Mdot
.38322 .56861 Mdot
.14337 .4698 Mdot
.7164 .35415 Mdot
.52285 .49842 Mdot
.36348 .51953 Mdot
.02352 .40793 Mdot
.64841 .38621 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51255 .00532 Mdot
.53997 .01694 Mdot
.62671 .05361 Mdot
.88406 .15905 Mdot
.30034 .25728 Mdot
.48974 .11705 Mdot
.66375 .10755 Mdot
.04229 .23395 Mdot
.35814 .1952 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50312 .00132 Mdot
.50993 .00421 Mdot
.53162 .01341 Mdot
.60042 .04252 Mdot
.81005 .12956 Mdot
.24162 .26673 Mdot
.43479 .11939 Mdot
.53287 .06061 Mdot
.67989 .09086 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.47788 .60865 Mdot
.42963 .58821 Mdot
.27923 .52508 Mdot
.89411 .38002 Mdot
.65637 .4711 Mdot
.61721 .59384 Mdot
.73841 .07491 Mdot
.09772 .22206 Mdot
.31948 .13706 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50156 .00066 Mdot
.50498 .00211 Mdot
.51588 .00673 Mdot
.55056 .02143 Mdot
.65981 .06752 Mdot
.97048 .192 Mdot
.32517 .21922 Mdot
.46728 .08783 Mdot
.56065 .0577 Mdot
.7428 .11258 Mdot
.49939 .61778 Mdot
.49807 .61722 Mdot
.49385 .61543 Mdot
.48041 .60973 Mdot
.43766 .59161 Mdot
.30376 .53528 Mdot
.94463 .39608 Mdot
.66689 .44638 Mdot
.59605 .57426 Mdot
.66071 .03996 Mdot
.92751 .16489 Mdot
.49846 .61738 Mdot
.49511 .61596 Mdot
.48441 .61142 Mdot
.45037 .597 Mdot
.34308 .55173 Mdot
.03674 .42871 Mdot
.67578 .39494 Mdot
.52805 .52673 Mdot
.42218 .5526 Mdot
.20417 .4833 Mdot
.75726 .34183 Mdot
.49959 .61786 Mdot
.4987 .61748 Mdot
.49585 .61627 Mdot
.48678 .61243 Mdot
.45792 .60019 Mdot
.36666 .56163 Mdot
.09797 .45198 Mdot
.69144 .36678 Mdot
.50765 .50445 Mdot
.33535 .51154 Mdot
.95782 .38471 Mdot
.50061 .00026 Mdot
.50196 .00083 Mdot
.50624 .00265 Mdot
.51988 .00843 Mdot
.56326 .02681 Mdot
.69906 .08393 Mdot
.06146 .22398 Mdot
.33395 .1684 Mdot
.40015 .04091 Mdot
.3262 .57233 Mdot
.04035 .44137 Mdot
.69463 .40436 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51797 .00762 Mdot
.5572 .02424 Mdot
.68039 .07614 Mdot
.01984 .20979 Mdot
.32961 .19145 Mdot
.42989 .06198 Mdot
.42839 .6171 Mdot
.32305 .55293 Mdot
.00368 .42065 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47571 .60774 Mdot
.42276 .58531 Mdot
.25846 .51649 Mdot
.85575 .36915 Mdot
.64099 .4853 Mdot
.61112 .59957 Mdot
.73471 .07638 Mdot
.09593 .22325 Mdot
.49984 .61797 Mdot
.49948 .61781 Mdot
.49835 .61733 Mdot
.49474 .6158 Mdot
.48325 .61093 Mdot
.44669 .59544 Mdot
.33164 .54693 Mdot
.00859 .41838 Mdot
.67266 .41042 Mdot
.54782 .54088 Mdot
.49365 .58455 Mdot
.49859 .61743 Mdot
.49549 .61612 Mdot
.48565 .61195 Mdot
.4543 .59866 Mdot
.35533 .55687 Mdot
.06802 .44047 Mdot
.68176 .37931 Mdot
.51263 .5135 Mdot
.36241 .5252 Mdot
.03058 .41295 Mdot
.65316 .38477 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51773 .00752 Mdot
.55644 .02392 Mdot
.67806 .07516 Mdot
.01443 .20789 Mdot
.32919 .19453 Mdot
.43416 .06488 Mdot
.44315 .00556 Mdot
.36868 .57201 Mdot
.11883 .46362 Mdot
.49857 .61743 Mdot
.49545 .6161 Mdot
.4855 .61189 Mdot
.45384 .59847 Mdot
.35391 .55627 Mdot
.06435 .43907 Mdot
.68087 .38103 Mdot
.51396 .51488 Mdot
.36795 .5278 Mdot
.04584 .41895 Mdot
.65591 .37705 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.4876 .61277 Mdot
.4605 .60129 Mdot
.37476 .56504 Mdot
.11995 .46056 Mdot
.70178 .35959 Mdot
.51145 .50041 Mdot
.3383 .51102 Mdot
.96222 .3856 Mdot
.64228 .4203 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47856 .60894 Mdot
.43177 .58912 Mdot
.28576 .52779 Mdot
.90701 .38396 Mdot
.65995 .46534 Mdot
.6144 .58989 Mdot
.72607 .06901 Mdot
.07377 .21489 Mdot
.31474 .14893 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49076 .61412 Mdot
.47058 .60556 Mdot
.40652 .57844 Mdot
.21016 .49668 Mdot
.78251 .35373 Mdot
.58863 .49821 Mdot
.52092 .57619 Mdot
.48451 .59553 Mdot
.42489 .58119 Mdot
.49756 .617 Mdot
.49223 .61474 Mdot
.47525 .60754 Mdot
.42131 .58469 Mdot
.25408 .51468 Mdot
.84819 .36718 Mdot
.63703 .48753 Mdot
.60693 .59944 Mdot
.72544 .07324 Mdot
.07985 .21903 Mdot
.31944 .14808 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.5058 .00246 Mdot
.51848 .00784 Mdot
.55882 .02493 Mdot
.68538 .07822 Mdot
.03128 .21377 Mdot
.33056 .18496 Mdot
.42103 .05592 Mdot
.39786 .60371 Mdot
.23178 .51539 Mdot
.82853 .36881 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48478 .61158 Mdot
.45154 .59749 Mdot
.34674 .55326 Mdot
.04596 .43214 Mdot
.6772 .39013 Mdot
.52262 .5225 Mdot
.40186 .5434 Mdot
.14305 .45808 Mdot
.69741 .34261 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47452 .60723 Mdot
.419 .58372 Mdot
.24714 .51182 Mdot
.83659 .3643 Mdot
.6303 .49054 Mdot
.59835 .59829 Mdot
.70472 .06574 Mdot
.04023 .20735 Mdot
.31603 .17046 Mdot
.49996 .61802 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.49861 .61744 Mdot
.49557 .61615 Mdot
.48587 .61204 Mdot
.45502 .59896 Mdot
.35758 .55781 Mdot
.0739 .44271 Mdot
.68331 .37664 Mdot
.5108 .51142 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50797 .00338 Mdot
.5254 .01077 Mdot
.58077 .03422 Mdot
.75217 .10593 Mdot
.16228 .25346 Mdot
.369 .12777 Mdot
.40069 .01958 Mdot
.29288 .55141 Mdot
.95496 .40919 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.523 .00975 Mdot
.57317 .031 Mdot
.72926 .09647 Mdot
.12207 .24277 Mdot
.3492 .14038 Mdot
.38249 .02058 Mdot
.25511 .53931 Mdot
.88911 .39184 Mdot
.67632 .48652 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48864 .61322 Mdot
.46381 .60269 Mdot
.38517 .56943 Mdot
.14886 .47198 Mdot
.72041 .35324 Mdot
.52659 .49824 Mdot
.37246 .52278 Mdot
.04685 .4168 Mdot
.65198 .37399 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52311 .0098 Mdot
.57352 .03115 Mdot
.73032 .09691 Mdot
.12404 .24333 Mdot
.34997 .13963 Mdot
.38273 .02025 Mdot
.25507 .53914 Mdot
.8888 .39167 Mdot
.67609 .48657 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51092 .00463 Mdot
.53479 .01475 Mdot
.61044 .04675 Mdot
.83876 .14111 Mdot
.26964 .2663 Mdot
.46361 .11988 Mdot
.60346 .08643 Mdot
.88779 .17573 Mdot
.49915 .61767 Mdot
.49729 .61688 Mdot
.49135 .61437 Mdot
.47245 .60635 Mdot
.41244 .58094 Mdot
.22762 .50381 Mdot
.80642 .35772 Mdot
.60911 .49609 Mdot
.56294 .5895 Mdot
.60875 .02831 Mdot
.80529 .12147 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00286 Mdot
.52145 .0091 Mdot
.56825 .02892 Mdot
.71433 .09028 Mdot
.09316 .23413 Mdot
.3401 .15261 Mdot
.38554 .02809 Mdot
.27373 .54893 Mdot
.92582 .40302 Mdot
.6852 .46932 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50378 .0016 Mdot
.51204 .0051 Mdot
.53833 .01625 Mdot
.62158 .05145 Mdot
.86997 .15351 Mdot
.29242 .26109 Mdot
.48456 .11875 Mdot
.65359 .10446 Mdot
.01888 .22576 Mdot
.35591 .2083 Mdot
.49812 .61724 Mdot
.49401 .61549 Mdot
.48091 .60994 Mdot
.43924 .59228 Mdot
.30864 .53732 Mdot
.95533 .39968 Mdot
.66815 .44054 Mdot
.58881 .569 Mdot
.63589 .02909 Mdot
.86292 .14031 Mdot
.27107 .25225 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49407 .61552 Mdot
.48111 .61003 Mdot
.43989 .59256 Mdot
.31063 .53815 Mdot
.95976 .40118 Mdot
.66861 .43809 Mdot
.58564 .56676 Mdot
.62501 .02434 Mdot
.49772 .61707 Mdot
.49272 .61495 Mdot
.47682 .6082 Mdot
.42627 .58679 Mdot
.26902 .52085 Mdot
.87475 .37436 Mdot
.64955 .47885 Mdot
.6171 .59798 Mdot
.74487 .07897 Mdot
.11124 .22643 Mdot
.32401 .1315 Mdot
.49931 .61774 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47767 .60857 Mdot
.42898 .58794 Mdot
.27726 .52426 Mdot
.89029 .37888 Mdot
.65516 .47272 Mdot
.61762 .59483 Mdot
.74089 .07618 Mdot
.10251 .22349 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50923 .00391 Mdot
.52939 .01246 Mdot
.59339 .03955 Mdot
.78956 .12124 Mdot
.21713 .26425 Mdot
.41104 .11984 Mdot
.47835 .0416 Mdot
.51329 .02159 Mdot
.56814 .0339 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48583 .61202 Mdot
.45487 .5989 Mdot
.35711 .55762 Mdot
.07268 .44224 Mdot
.68298 .37719 Mdot
.51115 .51184 Mdot
.35604 .52217 Mdot
.01326 .40618 Mdot
.65061 .39391 Mdot
.4986 .61744 Mdot
.49553 .61614 Mdot
.48575 .61199 Mdot
.45463 .5988 Mdot
.35637 .5573 Mdot
.07073 .4415 Mdot
.68246 .37807 Mdot
.51174 .51253 Mdot
.35862 .5234 Mdot
.02023 .4089 Mdot
.65158 .39019 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48082 .6099 Mdot
.43897 .59217 Mdot
.30779 .53696 Mdot
.95344 .39904 Mdot
.66794 .44158 Mdot
.59014 .56995 Mdot
.64043 .03108 Mdot
.87508 .14502 Mdot
.27845 .2493 Mdot
.4995 .61782 Mdot
.49842 .61736 Mdot
.49496 .6159 Mdot
.48395 .61123 Mdot
.44889 .59637 Mdot
.33849 .5498 Mdot
.02532 .42448 Mdot
.67433 .40111 Mdot
.53559 .53229 Mdot
.44979 .56501 Mdot
.28993 .51923 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.4806 .60981 Mdot
.43828 .59187 Mdot
.30567 .53608 Mdot
.94878 .39747 Mdot
.6674 .44413 Mdot
.59333 .57225 Mdot
.65135 .03586 Mdot
.90371 .15596 Mdot
.29185 .23988 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.5068 .00288 Mdot
.52165 .00918 Mdot
.56889 .02919 Mdot
.71625 .09108 Mdot
.097 .23532 Mdot
.34109 .15086 Mdot
.3845 .02682 Mdot
.26946 .54694 Mdot
.91747 .40049 Mdot
.6838 .47362 Mdot
.49792 .61715 Mdot
.49338 .61523 Mdot
.4789 .60909 Mdot
.43288 .58959 Mdot
.28912 .52919 Mdot
.91381 .38608 Mdot
.66156 .46213 Mdot
.61211 .58747 Mdot
.71727 .06499 Mdot
.05612 .20942 Mdot
.31253 .15847 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50315 .00134 Mdot
.51003 .00425 Mdot
.53195 .01355 Mdot
.60148 .04297 Mdot
.81313 .13081 Mdot
.24497 .26689 Mdot
.43821 .11942 Mdot
.54105 .06356 Mdot
.7048 .1012 Mdot
.5007 .00029 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.52249 .00954 Mdot
.57154 .03032 Mdot
.72432 .09443 Mdot
.11274 .24005 Mdot
.34584 .14406 Mdot
.3822 .02247 Mdot
.25754 .541 Mdot
.89443 .39362 Mdot
.67831 .48447 Mdot
.50063 .00027 Mdot
.50202 .00085 Mdot
.50642 .00272 Mdot
.52046 .00868 Mdot
.56512 .0276 Mdot
.70474 .08629 Mdot
.07351 .22791 Mdot
.33589 .16216 Mdot
.39347 .03559 Mdot
.30293 .56208 Mdot
.98674 .42262 Mdot
.69041 .4349 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50601 .00255 Mdot
.51914 .00811 Mdot
.5609 .02581 Mdot
.6918 .0809 Mdot
.04565 .21869 Mdot
.33196 .17695 Mdot
.4105 .04854 Mdot
.36174 .5879 Mdot
.13072 .47525 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50686 .00291 Mdot
.52184 .00926 Mdot
.56948 .02944 Mdot
.71807 .09183 Mdot
.1006 .23642 Mdot
.34208 .14924 Mdot
.38368 .02571 Mdot
.26593 .54526 Mdot
.91063 .39845 Mdot
.68246 .47701 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50821 .00348 Mdot
.52615 .01109 Mdot
.58314 .03522 Mdot
.75924 .10884 Mdot
.17367 .25613 Mdot
.3763 .12523 Mdot
.41152 .02176 Mdot
.32073 .56193 Mdot
.01441 .42872 Mdot
.6865 .41538 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51644 .00697 Mdot
.55233 .02218 Mdot
.66532 .06983 Mdot
.98403 .19698 Mdot
.32666 .21175 Mdot
.45771 .081 Mdot
.52608 .04225 Mdot
.6334 .06633 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.503 .00127 Mdot
.50956 .00405 Mdot
.53045 .01291 Mdot
.59673 .04096 Mdot
.79933 .12522 Mdot
.22929 .26573 Mdot
.42253 .11943 Mdot
.50411 .05042 Mdot
.59186 .05423 Mdot
.80988 .13474 Mdot
.49919 .61769 Mdot
.49741 .61694 Mdot
.49175 .61453 Mdot
.47371 .60688 Mdot
.4164 .58262 Mdot
.23939 .50864 Mdot
.82418 .36142 Mdot
.62224 .49322 Mdot
.58614 .59573 Mdot
.67304 .05371 Mdot
.97131 .18434 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.52591 .01099 Mdot
.58238 .0349 Mdot
.75697 .1079 Mdot
.17007 .25531 Mdot
.37391 .12598 Mdot
.4078 .02094 Mdot
.31099 .5582 Mdot
.99276 .42136 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.51037 .0044 Mdot
.53304 .01401 Mdot
.60491 .04442 Mdot
.82298 .13478 Mdot
.25513 .26708 Mdot
.44866 .11961 Mdot
.56653 .07284 Mdot
.7813 .13274 Mdot
.2302 .27744 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50759 .00322 Mdot
.52419 .01026 Mdot
.57692 .03259 Mdot
.74059 .10116 Mdot
.14258 .24844 Mdot
.35818 .13325 Mdot
.3881 .01849 Mdot
.26367 .54113 Mdot
.90139 .39413 Mdot
.67774 .47981 Mdot
.49844 .61737 Mdot
.49503 .61593 Mdot
.48417 .61132 Mdot
.4496 .59667 Mdot
.34069 .55073 Mdot
.03078 .4265 Mdot
.67498 .39814 Mdot
.53188 .52959 Mdot
.4363 .55896 Mdot
.24768 .50146 Mdot
.82036 .35393 Mdot
.49836 .61734 Mdot
.49477 .61581 Mdot
.48333 .61096 Mdot
.44692 .59553 Mdot
.33237 .54724 Mdot
.01034 .41901 Mdot
.67282 .40943 Mdot
.54649 .53996 Mdot
.48892 .58245 Mdot
.41475 .57219 Mdot
.21872 .49688 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52195 .00931 Mdot
.56982 .02959 Mdot
.71908 .09225 Mdot
.10259 .23702 Mdot
.34265 .14836 Mdot
.3833 .02512 Mdot
.26417 .54441 Mdot
.90725 .39745 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50453 .00192 Mdot
.51443 .00612 Mdot
.54595 .01948 Mdot
.64543 .06148 Mdot
.93394 .17831 Mdot
.31872 .23781 Mdot
.48668 .1038 Mdot
.63468 .09147 Mdot
.96144 .20195 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50513 .00218 Mdot
.51636 .00694 Mdot
.55207 .02207 Mdot
.66451 .06949 Mdot
.98205 .19625 Mdot
.32646 .21286 Mdot
.45917 .08202 Mdot
.53129 .04457 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50759 .00322 Mdot
.52417 .01025 Mdot
.57685 .03256 Mdot
.74039 .10107 Mdot
.14223 .24835 Mdot
.35801 .13336 Mdot
.38795 .0185 Mdot
.26335 .54103 Mdot
.90086 .394 Mdot
.67765 .48008 Mdot
.49946 .6178 Mdot
.49826 .6173 Mdot
.49447 .61569 Mdot
.48238 .61056 Mdot
.44392 .59426 Mdot
.32306 .54334 Mdot
.98819 .41107 Mdot
.67102 .42201 Mdot
.56377 .55175 Mdot
.54966 .60931 Mdot
.60882 .03656 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49057 .61403 Mdot
.46996 .6053 Mdot
.40456 .57761 Mdot
.20443 .49434 Mdot
.77528 .35281 Mdot
.58186 .49849 Mdot
.50589 .57108 Mdot
.43876 .57655 Mdot
.49803 .6172 Mdot
.49372 .61537 Mdot
.47998 .60955 Mdot
.4363 .59104 Mdot
.29961 .53355 Mdot
.93569 .39312 Mdot
.66563 .45113 Mdot
.60154 .57842 Mdot
.67963 .04826 Mdot
.9735 .18162 Mdot
.30694 .20607 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.5169 .00716 Mdot
.55379 .0228 Mdot
.66983 .07172 Mdot
.99495 .20094 Mdot
.32764 .20562 Mdot
.44946 .07529 Mdot
.49673 .02922 Mdot
.5391 .02618 Mdot
.63953 .06207 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.49948 .61782 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.4833 .61095 Mdot
.44685 .5955 Mdot
.33214 .54714 Mdot
.00979 .41881 Mdot
.67277 .40974 Mdot
.54691 .54025 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49147 .61442 Mdot
.47283 .60651 Mdot
.41363 .58145 Mdot
.23114 .50525 Mdot
.81159 .35874 Mdot
.61312 .49537 Mdot
.57041 .59163 Mdot
.62989 .03676 Mdot
.86328 .14424 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00148 Mdot
.51116 .00473 Mdot
.53553 .01506 Mdot
.61276 .04773 Mdot
.84533 .14374 Mdot
.27507 .2656 Mdot
.46904 .11988 Mdot
.61685 .09135 Mdot
.92461 .19021 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50661 .0028 Mdot
.52107 .00894 Mdot
.56704 .02841 Mdot
.71063 .08874 Mdot
.08569 .2318 Mdot
.33833 .15614 Mdot
.38808 .03074 Mdot
.28343 .55336 Mdot
.9453 .40906 Mdot
.68761 .45877 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50569 .00241 Mdot
.51812 .00768 Mdot
.55766 .02444 Mdot
.68181 .07673 Mdot
.02312 .21094 Mdot
.32987 .18958 Mdot
.42732 .06023 Mdot
.4195 .6132 Mdot
.29601 .54171 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50381 .00161 Mdot
.51213 .00514 Mdot
.53864 .01638 Mdot
.62253 .05185 Mdot
.8726 .15455 Mdot
.294 .26044 Mdot
.48574 .1185 Mdot
.65611 .1053 Mdot
.02487 .22791 Mdot
.35647 .20494 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50833 .00353 Mdot
.52653 .01125 Mdot
.58433 .03572 Mdot
.76279 .1103 Mdot
.17921 .25736 Mdot
.38013 .12417 Mdot
.41777 .02326 Mdot
.33747 .56841 Mdot
.05359 .44259 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50678 .00287 Mdot
.52159 .00915 Mdot
.56867 .0291 Mdot
.71561 .09081 Mdot
.09572 .23492 Mdot
.34075 .15144 Mdot
.38483 .02724 Mdot
.27083 .54758 Mdot
.92014 .4013 Mdot
.68428 .47226 Mdot
.49742 .61694 Mdot
.49179 .61455 Mdot
.47386 .60695 Mdot
.4169 .58283 Mdot
.24088 .50925 Mdot
.82651 .36194 Mdot
.62382 .49276 Mdot
.58868 .59632 Mdot
.67979 .05631 Mdot
.98678 .18973 Mdot
.31357 .20197 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47591 .60782 Mdot
.42338 .58557 Mdot
.26032 .51725 Mdot
.85902 .37002 Mdot
.6426 .48428 Mdot
.6126 .59949 Mdot
.73775 .07735 Mdot
.10092 .22445 Mdot
.32266 .13704 Mdot
.49901 .61761 Mdot
.49683 .61669 Mdot
.48991 .61376 Mdot
.46787 .60441 Mdot
.39796 .57483 Mdot
.18526 .48658 Mdot
.75331 .35107 Mdot
.56004 .49859 Mdot
.45472 .55294 Mdot
.28237 .51152 Mdot
.87622 .36702 Mdot
.4987 .61748 Mdot
.49585 .61628 Mdot
.48679 .61243 Mdot
.45792 .60019 Mdot
.36667 .56164 Mdot
.09801 .45199 Mdot
.69145 .36677 Mdot
.50766 .50444 Mdot
.33534 .51153 Mdot
.95779 .3847 Mdot
.64282 .42337 Mdot
.49903 .61762 Mdot
.49691 .61672 Mdot
.49015 .61386 Mdot
.46864 .60474 Mdot
.40038 .57585 Mdot
.19226 .48941 Mdot
.76095 .35147 Mdot
.56781 .49866 Mdot
.47332 .55964 Mdot
.33901 .53502 Mdot
.00233 .40996 Mdot
.49787 .61713 Mdot
.49322 .61516 Mdot
.47839 .60887 Mdot
.43124 .58889 Mdot
.28412 .52711 Mdot
.90374 .38294 Mdot
.6591 .46684 Mdot
.61532 .59097 Mdot
.72976 .07073 Mdot
.081 .21708 Mdot
.31592 .14519 Mdot
.49794 .61716 Mdot
.49343 .61525 Mdot
.47908 .60916 Mdot
.43343 .58982 Mdot
.29081 .52989 Mdot
.91726 .38717 Mdot
.66231 .46046 Mdot
.61075 .58617 Mdot
.71225 .06272 Mdot
.04578 .20614 Mdot
.31159 .16428 Mdot
.49771 .61706 Mdot
.49272 .61495 Mdot
.47679 .60819 Mdot
.42619 .58676 Mdot
.26879 .52076 Mdot
.87433 .37424 Mdot
.64938 .47901 Mdot
.61703 .59804 Mdot
.74483 .07898 Mdot
.11123 .22645 Mdot
.32404 .13152 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50312 .00132 Mdot
.50993 .00421 Mdot
.53164 .01342 Mdot
.6005 .04256 Mdot
.81028 .12965 Mdot
.24187 .26674 Mdot
.43505 .11939 Mdot
.53347 .06083 Mdot
.68174 .09164 Mdot
.04713 .22582 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50531 .00225 Mdot
.51693 .00718 Mdot
.55389 .02284 Mdot
.67016 .07186 Mdot
.99574 .20122 Mdot
.32771 .20517 Mdot
.44885 .07487 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51317 .00558 Mdot
.54193 .01777 Mdot
.63285 .05619 Mdot
.9007 .16554 Mdot
.30802 .25174 Mdot
.4923 .11389 Mdot
.66504 .10676 Mdot
.04331 .23378 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47929 .60925 Mdot
.43411 .59011 Mdot
.29291 .53076 Mdot
.92159 .38855 Mdot
.66319 .45833 Mdot
.60888 .58447 Mdot
.70544 .05968 Mdot
.03143 .20148 Mdot
.31059 .17253 Mdot
.4989 .61757 Mdot
.49648 .61654 Mdot
.4888 .61328 Mdot
.46431 .6029 Mdot
.38675 .5701 Mdot
.15329 .47375 Mdot
.72383 .35261 Mdot
.52989 .49817 Mdot
.38051 .52571 Mdot
.06827 .42506 Mdot
.65674 .36369 Mdot
.49772 .61707 Mdot
.49272 .61495 Mdot
.47682 .6082 Mdot
.42626 .58679 Mdot
.26902 .52085 Mdot
.87474 .37436 Mdot
.64955 .47886 Mdot
.6171 .59798 Mdot
.74487 .07897 Mdot
.11124 .22643 Mdot
.32401 .1315 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47445 .6072 Mdot
.41875 .58361 Mdot
.2464 .51152 Mdot
.83537 .36401 Mdot
.62955 .49083 Mdot
.5973 .5981 Mdot
.70207 .06475 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48906 .6134 Mdot
.46516 .60326 Mdot
.38943 .57123 Mdot
.16087 .47677 Mdot
.73004 .35177 Mdot
.53607 .49815 Mdot
.39575 .53131 Mdot
.10999 .44143 Mdot
.67207 .34739 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50502 .00213 Mdot
.51598 .00678 Mdot
.55087 .02156 Mdot
.66078 .06793 Mdot
.97288 .19289 Mdot
.32546 .21791 Mdot
.46565 .08664 Mdot
.55471 .05504 Mdot
.72424 .10477 Mdot
.12938 .25039 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50377 .0016 Mdot
.51201 .00509 Mdot
.53826 .01622 Mdot
.62134 .05135 Mdot
.8693 .15325 Mdot
.29201 .26125 Mdot
.48425 .11881 Mdot
.6529 .10423 Mdot
.01722 .22516 Mdot
.35576 .20923 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50648 .00275 Mdot
.52065 .00876 Mdot
.5657 .02784 Mdot
.70652 .08703 Mdot
.07722 .22911 Mdot
.33658 .16029 Mdot
.39167 .03405 Mdot
.29653 .55923 Mdot
.97279 .41795 Mdot
.68966 .44305 Mdot
.49947 .61781 Mdot
.49832 .61732 Mdot
.49466 .61577 Mdot
.48298 .61082 Mdot
.44582 .59507 Mdot
.32894 .5458 Mdot
.0021 .41603 Mdot
.67211 .41409 Mdot
.55283 .54432 Mdot
.51135 .5924 Mdot
.48688 .60291 Mdot
.49839 .61735 Mdot
.49486 .61585 Mdot
.48363 .61109 Mdot
.44787 .59594 Mdot
.33532 .54847 Mdot
.01754 .42163 Mdot
.6735 .40541 Mdot
.54114 .53623 Mdot
.4698 .57394 Mdot
.35342 .54611 Mdot
.04697 .42864 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50833 .00353 Mdot
.52654 .01126 Mdot
.58439 .03575 Mdot
.76296 .11036 Mdot
.17947 .25742 Mdot
.38031 .12413 Mdot
.41808 .02334 Mdot
.33831 .56873 Mdot
.05562 .44332 Mdot
.69119 .39281 Mdot
.49859 .61743 Mdot
.4955 .61612 Mdot
.48565 .61195 Mdot
.45432 .59867 Mdot
.35541 .5569 Mdot
.06824 .44055 Mdot
.68182 .37921 Mdot
.51255 .51342 Mdot
.3621 .52505 Mdot
.02973 .41262 Mdot
.65302 .38521 Mdot
.49997 .61802 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49917 .61768 Mdot
.49734 .61691 Mdot
.49153 .61444 Mdot
.47302 .60659 Mdot
.41423 .5817 Mdot
.23293 .50598 Mdot
.81427 .35929 Mdot
.61514 .49496 Mdot
.49834 .61733 Mdot
.4947 .61578 Mdot
.4831 .61087 Mdot
.4462 .59523 Mdot
.33013 .5463 Mdot
.00496 .41707 Mdot
.67235 .41247 Mdot
.55061 .5428 Mdot
.50351 .58893 Mdot
.46168 .59218 Mdot
.36293 .557 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52397 .01016 Mdot
.57624 .0323 Mdot
.73854 .10031 Mdot
.13896 .24747 Mdot
.35643 .1344 Mdot
.38658 .01864 Mdot
.26065 .5402 Mdot
.89652 .39299 Mdot
.6769 .4823 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50703 .00298 Mdot
.52241 .0095 Mdot
.57128 .0302 Mdot
.72353 .0941 Mdot
.11122 .23961 Mdot
.34533 .14469 Mdot
.38227 .02283 Mdot
.25828 .5414 Mdot
.89588 .39406 Mdot
.67876 .48384 Mdot
.49865 .61746 Mdot
.49569 .61621 Mdot
.48628 .61222 Mdot
.45632 .59952 Mdot
.36167 .55954 Mdot
.08468 .44684 Mdot
.68658 .37199 Mdot
.5085 .50798 Mdot
.34317 .51585 Mdot
.97886 .39288 Mdot
.64617 .41242 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51961 .00832 Mdot
.56241 .02645 Mdot
.69645 .08284 Mdot
.05583 .22211 Mdot
.33317 .17141 Mdot
.40365 .04356 Mdot
.33826 .57762 Mdot
.06992 .45219 Mdot
.70004 .38943 Mdot
.50059 .00025 Mdot
.50186 .00079 Mdot
.50594 .00252 Mdot
.51892 .00802 Mdot
.56022 .02552 Mdot
.6897 .08003 Mdot
.04099 .21711 Mdot
.33147 .17953 Mdot
.41382 .0509 Mdot
.37313 .59288 Mdot
.16165 .48734 Mdot
.74729 .36194 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50523 .00222 Mdot
.51667 .00707 Mdot
.55305 .02249 Mdot
.66755 .07076 Mdot
.98946 .19895 Mdot
.32717 .20872 Mdot
.45366 .07818 Mdot
.51162 .03582 Mdot
.58699 .04658 Mdot
.78644 .12327 Mdot
.49831 .61732 Mdot
.49461 .61575 Mdot
.48282 .61075 Mdot
.44533 .59486 Mdot
.32742 .54517 Mdot
.99848 .41474 Mdot
.67182 .41614 Mdot
.55566 .54624 Mdot
.52129 .59679 Mdot
.51875 .61647 Mdot
.54428 .01578 Mdot
.49833 .61732 Mdot
.49467 .61577 Mdot
.48301 .61083 Mdot
.44592 .59511 Mdot
.32927 .54594 Mdot
.0029 .41632 Mdot
.67218 .41364 Mdot
.55221 .54389 Mdot
.50915 .59142 Mdot
.47981 .5999 Mdot
.42028 .58124 Mdot
.49919 .61769 Mdot
.4974 .61693 Mdot
.49173 .61453 Mdot
.47366 .60686 Mdot
.41625 .58255 Mdot
.23894 .50845 Mdot
.82346 .36126 Mdot
.62174 .49336 Mdot
.58534 .59554 Mdot
.67089 .05288 Mdot
.9663 .18257 Mdot
.49861 .61744 Mdot
.49556 .61615 Mdot
.48587 .61204 Mdot
.45499 .59895 Mdot
.35751 .55778 Mdot
.07372 .44264 Mdot
.68326 .37672 Mdot
.51086 .51148 Mdot
.35472 .52154 Mdot
.00969 .40479 Mdot
.65013 .39582 Mdot
.49772 .61707 Mdot
.49274 .61495 Mdot
.47687 .60822 Mdot
.42642 .58685 Mdot
.26949 .52104 Mdot
.87561 .3746 Mdot
.64989 .47853 Mdot
.61722 .59784 Mdot
.74492 .07892 Mdot
.11122 .22639 Mdot
.32394 .13147 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.52088 .00885 Mdot
.56644 .02816 Mdot
.7088 .08798 Mdot
.08194 .23061 Mdot
.33753 .15796 Mdot
.38958 .03217 Mdot
.28897 .55585 Mdot
.95674 .41271 Mdot
.68861 .45232 Mdot
.49884 .61754 Mdot
.49631 .61647 Mdot
.48825 .61305 Mdot
.46257 .60216 Mdot
.38126 .56778 Mdot
.13792 .46764 Mdot
.71263 .35519 Mdot
.51953 .49869 Mdot
.35566 .51675 Mdot
.00375 .40054 Mdot
.64622 .39707 Mdot
.50047 .0002 Mdot
.50148 .00063 Mdot
.50472 .002 Mdot
.51505 .00638 Mdot
.54792 .02031 Mdot
.65159 .06407 Mdot
.94979 .1843 Mdot
.32206 .23008 Mdot
.47966 .0974 Mdot
.60682 .07859 Mdot
.88245 .17035 Mdot
.31881 .26968 Mdot
.50045 .00019 Mdot
.50143 .0006 Mdot
.50454 .00193 Mdot
.51447 .00614 Mdot
.54607 .01953 Mdot
.64582 .06165 Mdot
.93495 .17869 Mdot
.31896 .23733 Mdot
.48631 .10342 Mdot
.63314 .09075 Mdot
.95718 .20027 Mdot
.34468 .23949 Mdot
.49786 .61712 Mdot
.49317 .61514 Mdot
.47824 .60881 Mdot
.43077 .5887 Mdot
.28269 .52652 Mdot
.90091 .38208 Mdot
.65834 .46812 Mdot
.616 .59186 Mdot
.73265 .07209 Mdot
.08662 .21876 Mdot
.31698 .14237 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50925 .00392 Mdot
.52946 .01249 Mdot
.59361 .03965 Mdot
.79021 .12151 Mdot
.21797 .26437 Mdot
.41181 .1198 Mdot
.48004 .04217 Mdot
.51842 .02372 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50661 .0028 Mdot
.52107 .00893 Mdot
.56703 .02841 Mdot
.7106 .08873 Mdot
.08563 .23178 Mdot
.33832 .15617 Mdot
.3881 .03077 Mdot
.28352 .5534 Mdot
.94549 .40912 Mdot
.68763 .45867 Mdot
.49932 .61775 Mdot
.49785 .61712 Mdot
.49314 .61513 Mdot
.47816 .60877 Mdot
.43051 .58859 Mdot
.28191 .52619 Mdot
.89936 .3816 Mdot
.65791 .46881 Mdot
.61633 .59234 Mdot
.73411 .0728 Mdot
.08945 .21961 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50668 .00283 Mdot
.52128 .00902 Mdot
.5677 .02869 Mdot
.71262 .08957 Mdot
.08973 .23307 Mdot
.33926 .15422 Mdot
.38663 .02927 Mdot
.27796 .55087 Mdot
.93423 .4056 Mdot
.68637 .46485 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50963 .00408 Mdot
.53067 .01301 Mdot
.59744 .04126 Mdot
.80141 .12606 Mdot
.23176 .26597 Mdot
.42495 .1194 Mdot
.50968 .05237 Mdot
.60894 .06134 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00116 Mdot
.50875 .00371 Mdot
.52787 .01182 Mdot
.58857 .03752 Mdot
.77538 .11545 Mdot
.19789 .26113 Mdot
.39435 .12142 Mdot
.44373 .03052 Mdot
.41045 .59747 Mdot
.24983 .51876 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.5063 .00267 Mdot
.52007 .00851 Mdot
.56387 .02707 Mdot
.70093 .08471 Mdot
.06546 .22529 Mdot
.33455 .1663 Mdot
.3978 .03909 Mdot
.31807 .56876 Mdot
.02111 .4345 Mdot
.69258 .41499 Mdot
.50036 .00015 Mdot
.50113 .00048 Mdot
.50361 .00153 Mdot
.51151 .00488 Mdot
.53666 .01554 Mdot
.61632 .04923 Mdot
.85535 .14772 Mdot
.28269 .26411 Mdot
.47631 .11967 Mdot
.63453 .09778 Mdot
.97135 .20817 Mdot
.35092 .23459 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50572 .00242 Mdot
.51821 .00772 Mdot
.55796 .02457 Mdot
.68274 .07712 Mdot
.02525 .21168 Mdot
.33004 .18837 Mdot
.42566 .0591 Mdot
.41379 .6107 Mdot
.27883 .53463 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54142 .01756 Mdot
.63126 .05553 Mdot
.89643 .16388 Mdot
.30621 .25326 Mdot
.49201 .11483 Mdot
.66581 .10742 Mdot
.04573 .2348 Mdot
.35799 .19299 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50712 .00302 Mdot
.52269 .00962 Mdot
.57217 .03058 Mdot
.72624 .09522 Mdot
.11638 .24112 Mdot
.3471 .14259 Mdot
.38216 .02167 Mdot
.25616 .54016 Mdot
.89161 .39273 Mdot
.50057 .00024 Mdot
.50183 .00078 Mdot
.50583 .00247 Mdot
.51857 .00787 Mdot
.55909 .02504 Mdot
.68622 .07857 Mdot
.03317 .21443 Mdot
.33072 .1839 Mdot
.4196 .05493 Mdot
.39295 .60156 Mdot
.21756 .50964 Mdot
.80837 .36515 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50423 .00179 Mdot
.51346 .00571 Mdot
.54287 .01817 Mdot
.6358 .05743 Mdot
.90859 .1686 Mdot
.31108 .24875 Mdot
.49221 .11194 Mdot
.66166 .10473 Mdot
.03401 .23012 Mdot
.35573 .19883 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.52301 .00976 Mdot
.57318 .03101 Mdot
.7293 .09649 Mdot
.12213 .24278 Mdot
.34922 .14035 Mdot
.3825 .02057 Mdot
.2551 .5393 Mdot
.8891 .39183 Mdot
.67631 .48652 Mdot
.49977 .61793 Mdot
.49926 .61772 Mdot
.49763 .61703 Mdot
.49245 .61483 Mdot
.47594 .60783 Mdot
.42348 .58561 Mdot
.26061 .51738 Mdot
.85954 .37016 Mdot
.64286 .48411 Mdot
.61282 .59947 Mdot
.73818 .07748 Mdot
.50027 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.50889 .00377 Mdot
.52831 .012 Mdot
.58996 .03811 Mdot
.77949 .11714 Mdot
.20367 .26215 Mdot
.39915 .12082 Mdot
.45329 .03346 Mdot
.43837 .60881 Mdot
.3333 .5531 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48427 .61136 Mdot
.44992 .59681 Mdot
.34169 .55114 Mdot
.03326 .42741 Mdot
.6753 .39681 Mdot
.53026 .5284 Mdot
.43035 .55628 Mdot
.22925 .49375 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .00139 Mdot
.51048 .00444 Mdot
.53337 .01415 Mdot
.60594 .04485 Mdot
.82594 .13597 Mdot
.25801 .26703 Mdot
.45165 .11968 Mdot
.57388 .07554 Mdot
.803 .1416 Mdot
.25774 .28104 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48119 .61006 Mdot
.44015 .59267 Mdot
.31143 .53848 Mdot
.96154 .40179 Mdot
.66878 .4371 Mdot
.58434 .56584 Mdot
.62056 .02239 Mdot
.82082 .12377 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.5046 .00195 Mdot
.51467 .00622 Mdot
.54671 .0198 Mdot
.64781 .06248 Mdot
.94009 .18064 Mdot
.32013 .23488 Mdot
.48425 .10143 Mdot
.62477 .08685 Mdot
.93385 .19102 Mdot
.33933 .2506 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48015 .60962 Mdot
.43683 .59126 Mdot
.30122 .53422 Mdot
.93914 .39426 Mdot
.66614 .44931 Mdot
.59949 .57684 Mdot
.67254 .04515 Mdot
.9566 .17556 Mdot
.30496 .2153 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50693 .00294 Mdot
.52209 .00937 Mdot
.57027 .02978 Mdot
.72048 .09283 Mdot
.10532 .23785 Mdot
.34346 .14718 Mdot
.38286 .02435 Mdot
.262 .54334 Mdot
.90308 .39621 Mdot
.68072 .48061 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.5063 .00267 Mdot
.52006 .00851 Mdot
.56383 .02705 Mdot
.7008 .08465 Mdot
.06519 .2252 Mdot
.3345 .16645 Mdot
.39796 .03922 Mdot
.31862 .569 Mdot
.02239 .43496 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.5311 .01319 Mdot
.5988 .04184 Mdot
.80537 .12766 Mdot
.23636 .26637 Mdot
.4295 .11937 Mdot
.52032 .05613 Mdot
.64155 .07492 Mdot
.94819 .18951 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51247 .00529 Mdot
.5397 .01683 Mdot
.62588 .05326 Mdot
.8818 .15816 Mdot
.29916 .25795 Mdot
.48909 .11738 Mdot
.66268 .10728 Mdot
.03996 .23317 Mdot
.49747 .61696 Mdot
.49195 .61462 Mdot
.47436 .60716 Mdot
.41847 .58349 Mdot
.24556 .51117 Mdot
.83402 .36369 Mdot
.62871 .49114 Mdot
.59609 .59787 Mdot
.699 .0636 Mdot
.02849 .20364 Mdot
.31547 .17736 Mdot
.49867 .61747 Mdot
.49576 .61624 Mdot
.48648 .6123 Mdot
.45696 .59979 Mdot
.36366 .56037 Mdot
.08997 .44888 Mdot
.6884 .36985 Mdot
.50789 .50648 Mdot
.33922 .51379 Mdot
.96835 .38882 Mdot
.64464 .41797 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51515 .00643 Mdot
.54825 .02045 Mdot
.65261 .0645 Mdot
.95238 .18527 Mdot
.32252 .22876 Mdot
.47829 .09627 Mdot
.60159 .0762 Mdot
.86712 .16411 Mdot
.30961 .27348 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47423 .60711 Mdot
.41805 .58332 Mdot
.24432 .51066 Mdot
.83201 .36321 Mdot
.62743 .4916 Mdot
.59422 .59751 Mdot
.69422 .0618 Mdot
.01844 .20038 Mdot
.31506 .18332 Mdot
.49924 .61771 Mdot
.49758 .61701 Mdot
.49227 .61476 Mdot
.47539 .6076 Mdot
.42173 .58487 Mdot
.25535 .5152 Mdot
.85037 .36774 Mdot
.6382 .48691 Mdot
.60825 .59952 Mdot
.72843 .07428 Mdot
.08516 .22047 Mdot
.49932 .61774 Mdot
.49783 .61711 Mdot
.49308 .6151 Mdot
.47795 .60868 Mdot
.42985 .58831 Mdot
.2799 .52536 Mdot
.89543 .38041 Mdot
.65676 .47053 Mdot
.61703 .59347 Mdot
.73743 .07441 Mdot
.09583 .2215 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47698 .60827 Mdot
.42677 .587 Mdot
.27054 .52148 Mdot
.87757 .37516 Mdot
.65066 .4778 Mdot
.61747 .59752 Mdot
.74491 .07876 Mdot
.11097 .22623 Mdot
.32373 .1315 Mdot
.49952 .61783 Mdot
.49849 .61739 Mdot
.49517 .61599 Mdot
.48463 .61152 Mdot
.45106 .59729 Mdot
.34522 .55262 Mdot
.04212 .43071 Mdot
.67657 .39211 Mdot
.5248 .52423 Mdot
.41009 .54713 Mdot
.16756 .46814 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50594 .00252 Mdot
.51891 .00802 Mdot
.56018 .02551 Mdot
.6896 .07998 Mdot
.04076 .21703 Mdot
.33145 .17966 Mdot
.41399 .05101 Mdot
.3737 .59314 Mdot
.16323 .48796 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51263 .00535 Mdot
.54021 .01705 Mdot
.62746 .05392 Mdot
.8861 .15985 Mdot
.30138 .25666 Mdot
.49026 .11673 Mdot
.66453 .10771 Mdot
.04394 .23449 Mdot
.35827 .19427 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.48508 .61171 Mdot
.45248 .59789 Mdot
.34967 .55449 Mdot
.05343 .43495 Mdot
.67854 .38634 Mdot
.51872 .51926 Mdot
.38692 .53658 Mdot
.09941 .44034 Mdot
.67229 .35406 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50263 .00112 Mdot
.50838 .00355 Mdot
.5267 .01132 Mdot
.58488 .03596 Mdot
.76443 .11097 Mdot
.18173 .25791 Mdot
.38193 .12373 Mdot
.42082 .02404 Mdot
.34577 .57166 Mdot
.07394 .45003 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50301 .00128 Mdot
.50959 .00407 Mdot
.53056 .01296 Mdot
.59709 .04112 Mdot
.80039 .12565 Mdot
.23055 .26586 Mdot
.42377 .11941 Mdot
.50695 .05141 Mdot
.60057 .05786 Mdot
.83519 .14501 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48833 .61308 Mdot
.46282 .60227 Mdot
.38206 .56812 Mdot
.14015 .46852 Mdot
.71415 .35475 Mdot
.52084 .49857 Mdot
.35872 .51783 Mdot
.01143 .4034 Mdot
.64701 .39281 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.50911 .00386 Mdot
.52901 .0123 Mdot
.59218 .03904 Mdot
.78601 .1198 Mdot
.21249 .26358 Mdot
.40684 .12011 Mdot
.46929 .0386 Mdot
.48598 .01031 Mdot
.49868 .61748 Mdot
.49581 .61626 Mdot
.48665 .61237 Mdot
.45749 .60001 Mdot
.36532 .56107 Mdot
.09439 .45059 Mdot
.69003 .36813 Mdot
.50766 .50532 Mdot
.33676 .51242 Mdot
.96174 .38626 Mdot
.64356 .42138 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50809 .00343 Mdot
.52578 .01093 Mdot
.58198 .03473 Mdot
.75577 .10741 Mdot
.16814 .25486 Mdot
.37267 .1264 Mdot
.40593 .02055 Mdot
.30615 .55637 Mdot
.98234 .41791 Mdot
.68497 .43425 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.5209 .00886 Mdot
.56649 .02818 Mdot
.70894 .08804 Mdot
.08221 .2307 Mdot
.33758 .15783 Mdot
.38946 .03206 Mdot
.28855 .55567 Mdot
.95588 .41243 Mdot
.68854 .45281 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51486 .0063 Mdot
.5473 .02005 Mdot
.64966 .06326 Mdot
.94485 .18244 Mdot
.32112 .23255 Mdot
.4821 .09949 Mdot
.61629 .08293 Mdot
.90981 .1814 Mdot
.33148 .26061 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47984 .60948 Mdot
.43584 .59084 Mdot
.29818 .53296 Mdot
.93264 .39212 Mdot
.66515 .45272 Mdot
.60327 .57979 Mdot
.68564 .05091 Mdot
.9875 .18656 Mdot
.30809 .19813 Mdot
.49774 .61707 Mdot
.49279 .61498 Mdot
.47703 .60829 Mdot
.42693 .58707 Mdot
.27105 .52169 Mdot
.87851 .37543 Mdot
.65102 .47744 Mdot
.61756 .59736 Mdot
.74485 .07867 Mdot
.11074 .22613 Mdot
.3236 .13156 Mdot
.49881 .61753 Mdot
.49621 .61643 Mdot
.48793 .61292 Mdot
.46157 .60174 Mdot
.37813 .56646 Mdot
.12923 .4642 Mdot
.70709 .35714 Mdot
.51507 .49936 Mdot
.34561 .5133 Mdot
.97921 .39159 Mdot
.64391 .41081 Mdot
.49787 .61713 Mdot
.49323 .61516 Mdot
.47843 .60889 Mdot
.43136 .58895 Mdot
.2845 .52727 Mdot
.90449 .38318 Mdot
.6593 .4665 Mdot
.61512 .59073 Mdot
.72894 .07035 Mdot
.07941 .2166 Mdot
.31565 .146 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50825 .0035 Mdot
.52629 .01115 Mdot
.58357 .0354 Mdot
.76052 .10936 Mdot
.17569 .25659 Mdot
.37767 .12483 Mdot
.41371 .02227 Mdot
.32656 .56417 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47601 .60786 Mdot
.42369 .5857 Mdot
.26126 .51764 Mdot
.86069 .37047 Mdot
.6434 .48374 Mdot
.61328 .59942 Mdot
.73908 .07775 Mdot
.10306 .22495 Mdot
.32303 .13595 Mdot
.49752 .61698 Mdot
.49208 .61468 Mdot
.47479 .60734 Mdot
.41982 .58406 Mdot
.24962 .51284 Mdot
.84068 .3653 Mdot
.63276 .48953 Mdot
.60168 .59883 Mdot
.71296 .06877 Mdot
.05653 .21234 Mdot
.31708 .16103 Mdot
.49901 .61761 Mdot
.49684 .61669 Mdot
.48994 .61377 Mdot
.46795 .60444 Mdot
.39821 .57493 Mdot
.18598 .48687 Mdot
.75407 .3511 Mdot
.56082 .4986 Mdot
.45659 .55362 Mdot
.28806 .51388 Mdot
.88759 .37053 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50541 .0023 Mdot
.51725 .00731 Mdot
.5549 .02327 Mdot
.67328 .07316 Mdot
.00319 .2039 Mdot
.32831 .20094 Mdot
.44303 .0709 Mdot
.47409 .0192 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.5104 .00441 Mdot
.53312 .01404 Mdot
.60517 .04453 Mdot
.82373 .13508 Mdot
.25586 .26707 Mdot
.44943 .11963 Mdot
.5684 .07353 Mdot
.78684 .135 Mdot
.23765 .27861 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50263 .00111 Mdot
.50837 .00355 Mdot
.52667 .01131 Mdot
.58477 .03591 Mdot
.76412 .11084 Mdot
.18125 .2578 Mdot
.38158 .12381 Mdot
.42023 .02388 Mdot
.34416 .57102 Mdot
.06994 .44856 Mdot
.49865 .61746 Mdot
.4957 .61621 Mdot
.4863 .61222 Mdot
.45636 .59953 Mdot
.36178 .55958 Mdot
.08498 .44696 Mdot
.68668 .37187 Mdot
.50846 .50789 Mdot
.34292 .51573 Mdot
.9782 .39262 Mdot
.64608 .41277 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47986 .60949 Mdot
.4359 .59087 Mdot
.29839 .53304 Mdot
.93308 .39226 Mdot
.66522 .45249 Mdot
.60302 .57959 Mdot
.68479 .05053 Mdot
.98553 .18587 Mdot
.30794 .19927 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.4778 .60862 Mdot
.42937 .5881 Mdot
.27843 .52475 Mdot
.89257 .37955 Mdot
.65589 .47176 Mdot
.6174 .59425 Mdot
.73949 .07545 Mdot
.09978 .22267 Mdot
.32002 .13612 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50704 .00298 Mdot
.52241 .0095 Mdot
.57129 .03021 Mdot
.72358 .09412 Mdot
.11131 .23963 Mdot
.34536 .14465 Mdot
.38226 .02281 Mdot
.25823 .54138 Mdot
.89579 .39403 Mdot
.67873 .48388 Mdot
.49749 .61697 Mdot
.49201 .61465 Mdot
.47456 .60724 Mdot
.41909 .58376 Mdot
.24743 .51194 Mdot
.83707 .36441 Mdot
.63059 .49043 Mdot
.59876 .59836 Mdot
.70574 .06612 Mdot
.04228 .20799 Mdot
.31614 .16926 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48115 .61004 Mdot
.44 .5926 Mdot
.31096 .53828 Mdot
.96049 .40143 Mdot
.66868 .43769 Mdot
.58511 .56639 Mdot
.62321 .02355 Mdot
.49949 .61782 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48365 .6111 Mdot
.44795 .59597 Mdot
.33556 .54857 Mdot
.01812 .42184 Mdot
.67355 .40508 Mdot
.54071 .53593 Mdot
.46828 .57327 Mdot
.34858 .54405 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52363 .01002 Mdot
.57517 .03185 Mdot
.73531 .09897 Mdot
.13317 .24589 Mdot
.35378 .13635 Mdot
.38464 .01907 Mdot
.25721 .53928 Mdot
.8913 .39189 Mdot
.49984 .61797 Mdot
.49949 .61782 Mdot
.49836 .61734 Mdot
.49478 .61582 Mdot
.48336 .61098 Mdot
.44704 .59558 Mdot
.33273 .54739 Mdot
.01123 .41933 Mdot
.6729 .40893 Mdot
.54582 .5395 Mdot
.48654 .5814 Mdot
.4985 .6174 Mdot
.49524 .61601 Mdot
.48482 .6116 Mdot
.45168 .59755 Mdot
.34718 .55344 Mdot
.04707 .43256 Mdot
.67738 .38956 Mdot
.52201 .52201 Mdot
.39954 .54235 Mdot
.1362 .45528 Mdot
.6926 .34387 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48646 .61229 Mdot
.45687 .59975 Mdot
.36339 .56026 Mdot
.08923 .4486 Mdot
.68813 .37014 Mdot
.50796 .50668 Mdot
.33971 .51405 Mdot
.96965 .38933 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.51319 .00559 Mdot
.542 .01781 Mdot
.63307 .05629 Mdot
.9013 .16578 Mdot
.30827 .25152 Mdot
.49233 .11375 Mdot
.66487 .10664 Mdot
.04281 .23358 Mdot
.3573 .19437 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50319 .00135 Mdot
.51017 .00431 Mdot
.5324 .01374 Mdot
.6029 .04357 Mdot
.81722 .13245 Mdot
.24929 .26704 Mdot
.44263 .11949 Mdot
.55177 .06745 Mdot
.73721 .11461 Mdot
.16062 .26168 Mdot
.49786 .61713 Mdot
.4932 .61515 Mdot
.47832 .60884 Mdot
.43104 .58881 Mdot
.28351 .52686 Mdot
.90253 .38257 Mdot
.65878 .46739 Mdot
.61562 .59136 Mdot
.73102 .07133 Mdot
.08347 .21782 Mdot
.31637 .14394 Mdot
.49922 .6177 Mdot
.49751 .61698 Mdot
.49205 .61466 Mdot
.47469 .6073 Mdot
.41951 .58393 Mdot
.24869 .51246 Mdot
.83914 .36492 Mdot
.63185 .48992 Mdot
.60047 .59864 Mdot
.70999 .06769 Mdot
.05073 .21059 Mdot
.49986 .61797 Mdot
.49956 .61785 Mdot
.49859 .61743 Mdot
.4955 .61612 Mdot
.48565 .61195 Mdot
.45431 .59867 Mdot
.35538 .55689 Mdot
.06816 .44052 Mdot
.6818 .37925 Mdot
.51258 .51345 Mdot
.36222 .52511 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50508 .00215 Mdot
.51619 .00686 Mdot
.55154 .02185 Mdot
.66285 .0688 Mdot
.97799 .19477 Mdot
.32604 .2151 Mdot
.46209 .08408 Mdot
.5418 .04927 Mdot
.68349 .08757 Mdot
.50007 3e-05 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50765 .00324 Mdot
.52436 .01033 Mdot
.57747 .03282 Mdot
.74224 .10184 Mdot
.14546 .2492 Mdot
.35962 .13236 Mdot
.38948 .01845 Mdot
.26657 .54207 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48938 .61353 Mdot
.46618 .60369 Mdot
.39263 .57258 Mdot
.16996 .48042 Mdot
.73812 .35114 Mdot
.54434 .49827 Mdot
.41623 .53885 Mdot
.16817 .46473 Mdot
.71225 .33626 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49088 .61417 Mdot
.47094 .60571 Mdot
.40766 .57892 Mdot
.21351 .49804 Mdot
.78688 .35436 Mdot
.59259 .49796 Mdot
.5295 .57904 Mdot
.51041 .60623 Mdot
.49886 .61755 Mdot
.49638 .6165 Mdot
.48848 .61315 Mdot
.4633 .60247 Mdot
.38355 .56875 Mdot
.1443 .47017 Mdot
.71706 .35399 Mdot
.52346 .49838 Mdot
.36491 .52005 Mdot
.0272 .40932 Mdot
.64889 .38422 Mdot
.49744 .61695 Mdot
.49185 .61458 Mdot
.47404 .60703 Mdot
.41745 .58306 Mdot
.24252 .50992 Mdot
.82913 .36254 Mdot
.62556 .49222 Mdot
.5914 .59692 Mdot
.68691 .05903 Mdot
.00265 .19514 Mdot
.31441 .19268 Mdot
.50017 7e-05 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50565 .0024 Mdot
.518 .00763 Mdot
.55731 .02429 Mdot
.68072 .07628 Mdot
.02061 .21006 Mdot
.32967 .19101 Mdot
.42928 .06156 Mdot
.42627 .61617 Mdot
.31658 .55024 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51543 .00654 Mdot
.54914 .02083 Mdot
.65538 .06566 Mdot
.9594 .18789 Mdot
.32366 .22513 Mdot
.4743 .0931 Mdot
.58656 .06938 Mdot
.82237 .14573 Mdot
.27264 .27829 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.47552 .60765 Mdot
.42214 .58504 Mdot
.25656 .5157 Mdot
.85246 .36829 Mdot
.6393 .4863 Mdot
.60943 .59957 Mdot
.73106 .07517 Mdot
.08974 .22168 Mdot
.32083 .14282 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50654 .00277 Mdot
.52084 .00884 Mdot
.56632 .02811 Mdot
.70842 .08782 Mdot
.08115 .23036 Mdot
.33736 .15835 Mdot
.38991 .03248 Mdot
.29019 .5564 Mdot
.95931 .41354 Mdot
.6888 .45085 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50379 .00161 Mdot
.51206 .00512 Mdot
.53842 .01629 Mdot
.62184 .05156 Mdot
.87068 .15379 Mdot
.29285 .26092 Mdot
.48489 .11869 Mdot
.6543 .1047 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50618 .00262 Mdot
.51969 .00835 Mdot
.56265 .02655 Mdot
.69718 .08314 Mdot
.05741 .22263 Mdot
.33338 .17056 Mdot
.40265 .04281 Mdot
.33482 .57611 Mdot
.06137 .44903 Mdot
.69813 .39354 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.4743 .60714 Mdot
.41828 .58341 Mdot
.24499 .51094 Mdot
.83308 .36346 Mdot
.62812 .49136 Mdot
.59523 .59771 Mdot
.69681 .06278 Mdot
.02392 .20216 Mdot
.31528 .18007 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49603 .61635 Mdot
.48736 .61268 Mdot
.45976 .60097 Mdot
.37244 .56407 Mdot
.11361 .45807 Mdot
.69847 .36147 Mdot
.50967 .50135 Mdot
.33537 .51031 Mdot
.95586 .38348 Mdot
.498 .61718 Mdot
.49361 .61533 Mdot
.47965 .60941 Mdot
.43526 .5906 Mdot
.2964 .53222 Mdot
.92889 .3909 Mdot
.66453 .45465 Mdot
.6053 .58143 Mdot
.69273 .05404 Mdot
.00361 .19213 Mdot
.30907 .18879 Mdot
.49858 .61743 Mdot
.49548 .61612 Mdot
.4856 .61193 Mdot
.45415 .5986 Mdot
.35489 .55668 Mdot
.06688 .44003 Mdot
.68148 .37984 Mdot
.51303 .51392 Mdot
.36409 .52599 Mdot
.03519 .41476 Mdot
.65393 .3824 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52639 .01119 Mdot
.5839 .03554 Mdot
.76151 .10977 Mdot
.17723 .25693 Mdot
.37874 .12454 Mdot
.41545 .02269 Mdot
.33122 .56598 Mdot
.49848 .61739 Mdot
.49515 .61598 Mdot
.48454 .61148 Mdot
.45079 .59717 Mdot
.34438 .55227 Mdot
.04 .42992 Mdot
.67625 .39323 Mdot
.52606 .52521 Mdot
.41478 .54926 Mdot
.18171 .47398 Mdot
.73154 .33982 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50332 .00141 Mdot
.51057 .00448 Mdot
.53367 .01428 Mdot
.60689 .04526 Mdot
.82868 .13707 Mdot
.26061 .26695 Mdot
.45434 .11973 Mdot
.58052 .07798 Mdot
.8224 .14949 Mdot
.27873 .28203 Mdot
.49991 .618 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49067 .61408 Mdot
.47029 .60544 Mdot
.40559 .57805 Mdot
.20745 .49557 Mdot
.77905 .35327 Mdot
.58542 .49836 Mdot
.51386 .57381 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50599 .00254 Mdot
.51909 .0081 Mdot
.56077 .02576 Mdot
.69139 .08073 Mdot
.04475 .21839 Mdot
.33186 .17745 Mdot
.41113 .04899 Mdot
.36392 .58885 Mdot
.13656 .47752 Mdot
.72858 .36589 Mdot
.49799 .61718 Mdot
.49358 .61531 Mdot
.47955 .60936 Mdot
.43494 .59046 Mdot
.29543 .53181 Mdot
.92685 .39024 Mdot
.66417 .45569 Mdot
.60634 .58229 Mdot
.69642 .05567 Mdot
.01183 .19493 Mdot
.30951 .18398 Mdot
.4992 .61769 Mdot
.49744 .61695 Mdot
.49185 .61458 Mdot
.47403 .60702 Mdot
.41744 .58306 Mdot
.24248 .5099 Mdot
.82905 .36252 Mdot
.62551 .49224 Mdot
.59132 .5969 Mdot
.68672 .05896 Mdot
.00222 .19499 Mdot
.49742 .61694 Mdot
.49178 .61455 Mdot
.47383 .60694 Mdot
.4168 .58279 Mdot
.24058 .50912 Mdot
.82604 .36184 Mdot
.6235 .49286 Mdot
.58818 .5962 Mdot
.67845 .05579 Mdot
.98374 .18868 Mdot
.31338 .20372 Mdot
.49875 .61751 Mdot
.49603 .61635 Mdot
.48735 .61267 Mdot
.4597 .60095 Mdot
.37226 .56399 Mdot
.11312 .45788 Mdot
.69823 .36162 Mdot
.50956 .50143 Mdot
.33521 .51028 Mdot
.95554 .38339 Mdot
.6417 .42406 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51217 .00516 Mdot
.53876 .01644 Mdot
.62293 .05202 Mdot
.8737 .15498 Mdot
.29465 .26016 Mdot
.4862 .11839 Mdot
.65708 .10561 Mdot
.02716 .22872 Mdot
.49762 .61702 Mdot
.4924 .61481 Mdot
.4758 .60777 Mdot
.42304 .58543 Mdot
.25929 .51683 Mdot
.85722 .36954 Mdot
.64172 .48485 Mdot
.61181 .59955 Mdot
.73614 .07684 Mdot
.09831 .22383 Mdot
.32221 .13838 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00142 Mdot
.5107 .00454 Mdot
.53407 .01445 Mdot
.60817 .0458 Mdot
.83232 .13853 Mdot
.26398 .26678 Mdot
.45781 .1198 Mdot
.58911 .08115 Mdot
.84721 .15951 Mdot
.50079 .00033 Mdot
.50252 .00107 Mdot
.50802 .0034 Mdot
.52553 .01083 Mdot
.58119 .0344 Mdot
.75342 .10644 Mdot
.16433 .25395 Mdot
.37026 .12728 Mdot
.40244 .01989 Mdot
.29726 .55303 Mdot
.96381 .41195 Mdot
.68417 .44521 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50994 .00421 Mdot
.53166 .01342 Mdot
.60056 .04258 Mdot
.81045 .12972 Mdot
.24206 .26675 Mdot
.43524 .11939 Mdot
.53393 .06099 Mdot
.68313 .09221 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49682 .61668 Mdot
.48985 .61373 Mdot
.46768 .60433 Mdot
.39737 .57458 Mdot
.18356 .48589 Mdot
.75152 .35102 Mdot
.5582 .49856 Mdot
.45025 .55132 Mdot
.26887 .50594 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50458 .00194 Mdot
.51459 .00619 Mdot
.54646 .0197 Mdot
.64703 .06216 Mdot
.9381 .17989 Mdot
.31969 .23584 Mdot
.48508 .10221 Mdot
.62811 .0884 Mdot
.94323 .19475 Mdot
.34171 .24627 Mdot
.50072 .00031 Mdot
.5023 .00098 Mdot
.50733 .00311 Mdot
.52336 .0099 Mdot
.57429 .03148 Mdot
.73265 .09787 Mdot
.12832 .24454 Mdot
.3517 .13806 Mdot
.38345 .01962 Mdot
.25559 .53901 Mdot
.88915 .39156 Mdot
.67586 .48621 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50894 .00379 Mdot
.52849 .01208 Mdot
.59053 .03835 Mdot
.78117 .11782 Mdot
.20598 .26255 Mdot
.40113 .12061 Mdot
.45733 .03473 Mdot
.45029 .61368 Mdot
.36989 .56834 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.507 .00297 Mdot
.52229 .00945 Mdot
.57092 .03005 Mdot
.72244 .09364 Mdot
.10912 .23898 Mdot
.34465 .14557 Mdot
.38243 .02335 Mdot
.25945 .54203 Mdot
.89817 .39475 Mdot
.67942 .48284 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50677 .00287 Mdot
.52157 .00915 Mdot
.56862 .02908 Mdot
.71546 .09075 Mdot
.09542 .23483 Mdot
.34067 .15158 Mdot
.38491 .02734 Mdot
.27116 .54773 Mdot
.92078 .40149 Mdot
.68439 .47193 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50703 .00298 Mdot
.52239 .0095 Mdot
.57124 .03019 Mdot
.72341 .09405 Mdot
.111 .23954 Mdot
.34526 .14478 Mdot
.38228 .02288 Mdot
.2584 .54147 Mdot
.89611 .39413 Mdot
.67883 .48374 Mdot
.49864 .61746 Mdot
.49568 .6162 Mdot
.48624 .6122 Mdot
.45619 .59946 Mdot
.36124 .55935 Mdot
.08354 .4464 Mdot
.6862 .37247 Mdot
.50868 .50832 Mdot
.34417 .51636 Mdot
.9815 .39389 Mdot
.64652 .41101 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00213 Mdot
.51598 .00677 Mdot
.55086 .02156 Mdot
.66074 .06791 Mdot
.97278 .19285 Mdot
.32545 .21797 Mdot
.46572 .08669 Mdot
.55498 .05516 Mdot
.72507 .10512 Mdot
.13097 .25086 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.5093 .00394 Mdot
.52963 .01256 Mdot
.59415 .03987 Mdot
.7918 .12215 Mdot
.22 .26464 Mdot
.41369 .11971 Mdot
.48417 .04356 Mdot
.53094 .02891 Mdot
.62385 .05742 Mdot
.49932 .61775 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47811 .60875 Mdot
.43036 .58852 Mdot
.28145 .526 Mdot
.89845 .38133 Mdot
.65765 .46921 Mdot
.61651 .59261 Mdot
.73493 .07319 Mdot
.09101 .22007 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60745 Mdot
.42061 .5844 Mdot
.25198 .51382 Mdot
.84464 .36628 Mdot
.63505 .4885 Mdot
.60459 .59921 Mdot
.71996 .0713 Mdot
.06982 .21623 Mdot
.31828 .15355 Mdot
.49791 .61715 Mdot
.49333 .6152 Mdot
.47874 .60902 Mdot
.43235 .58937 Mdot
.28753 .52853 Mdot
.91057 .38506 Mdot
.66081 .46367 Mdot
.61327 .58865 Mdot
.72165 .06698 Mdot
.06498 .21219 Mdot
.31353 .15361 Mdot
.49838 .61735 Mdot
.49484 .61584 Mdot
.48355 .61106 Mdot
.44764 .59584 Mdot
.33461 .54817 Mdot
.01578 .42099 Mdot
.67332 .40638 Mdot
.54242 .53713 Mdot
.47441 .576 Mdot
.36816 .55237 Mdot
.08601 .44366 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50712 .00302 Mdot
.52269 .00962 Mdot
.57217 .03058 Mdot
.72624 .09522 Mdot
.11638 .24112 Mdot
.3471 .14259 Mdot
.38216 .02167 Mdot
.50068 .00029 Mdot
.50218 .00093 Mdot
.50695 .00295 Mdot
.52214 .00939 Mdot
.57045 .02985 Mdot
.721 .09305 Mdot
.10634 .23815 Mdot
.34377 .14674 Mdot
.38273 .02407 Mdot
.26126 .54296 Mdot
.90166 .39579 Mdot
.68036 .48126 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .0018 Mdot
.51356 .00575 Mdot
.54317 .0183 Mdot
.63674 .05783 Mdot
.9111 .16957 Mdot
.31198 .24776 Mdot
.49201 .11126 Mdot
.66007 .10386 Mdot
.02974 .22847 Mdot
.35506 .20106 Mdot
.49833 .61733 Mdot
.49468 .61578 Mdot
.48306 .61085 Mdot
.44607 .59517 Mdot
.32973 .54613 Mdot
.00399 .41672 Mdot
.67227 .41301 Mdot
.55136 .54331 Mdot
.50616 .5901 Mdot
.47019 .5958 Mdot
.38976 .56833 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48669 .61239 Mdot
.45761 .60006 Mdot
.36569 .56122 Mdot
.09538 .45097 Mdot
.69041 .36775 Mdot
.50764 .50507 Mdot
.33632 .51215 Mdot
.96053 .38578 Mdot
.64334 .422 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47343 .60677 Mdot
.41552 .58225 Mdot
.23676 .50756 Mdot
.8201 .36052 Mdot
.61938 .49398 Mdot
.58142 .59457 Mdot
.66031 .04876 Mdot
.94103 .17349 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00148 Mdot
.51109 .0047 Mdot
.53532 .01498 Mdot
.6121 .04745 Mdot
.84346 .14299 Mdot
.27356 .26582 Mdot
.46754 .11989 Mdot
.61317 .09 Mdot
.91461 .1863 Mdot
.33808 .26172 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52029 .0086 Mdot
.56456 .02736 Mdot
.70305 .08559 Mdot
.06995 .22676 Mdot
.33527 .16398 Mdot
.39532 .03711 Mdot
.30942 .56494 Mdot
.00122 .42756 Mdot
.4988 .61753 Mdot
.49618 .61641 Mdot
.48782 .61287 Mdot
.4612 .60158 Mdot
.37696 .56597 Mdot
.126 .46293 Mdot
.70517 .35795 Mdot
.51367 .49968 Mdot
.34266 .51234 Mdot
.97224 .3891 Mdot
.64325 .41471 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02052 Mdot
.65313 .06472 Mdot
.95371 .18577 Mdot
.32275 .22808 Mdot
.47756 .09568 Mdot
.59883 .07495 Mdot
.859 .16079 Mdot
.30407 .27507 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.48761 .61278 Mdot
.46053 .6013 Mdot
.37485 .56508 Mdot
.12021 .46065 Mdot
.70191 .35951 Mdot
.51154 .50038 Mdot
.33845 .51106 Mdot
.96256 .38572 Mdot
.64231 .42011 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50579 .00246 Mdot
.51844 .00782 Mdot
.5587 .02488 Mdot
.68503 .07808 Mdot
.03048 .2135 Mdot
.33049 .18541 Mdot
.42164 .05634 Mdot
.39995 .60463 Mdot
.23788 .51787 Mdot
.83777 .37075 Mdot
.49913 .61766 Mdot
.49721 .61685 Mdot
.49113 .61427 Mdot
.47173 .60605 Mdot
.41017 .57998 Mdot
.22089 .50106 Mdot
.79687 .35597 Mdot
.6013 .49717 Mdot
.54762 .58486 Mdot
.56431 .01032 Mdot
.67487 .06833 Mdot
.49799 .61718 Mdot
.4936 .61532 Mdot
.4796 .60938 Mdot
.43508 .59052 Mdot
.29586 .53199 Mdot
.92775 .39053 Mdot
.66433 .45523 Mdot
.60589 .58191 Mdot
.69481 .05496 Mdot
.00827 .19372 Mdot
.30932 .18606 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47445 .6072 Mdot
.41875 .58361 Mdot
.2464 .51152 Mdot
.83538 .36401 Mdot
.62956 .49083 Mdot
.59731 .5981 Mdot
.70209 .06476 Mdot
.03487 .20567 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52354 .00998 Mdot
.57487 .03172 Mdot
.7344 .0986 Mdot
.13152 .24543 Mdot
.35306 .13692 Mdot
.38419 .01924 Mdot
.25654 .53914 Mdot
.89035 .39172 Mdot
.67593 .48552 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48534 .61182 Mdot
.45331 .59824 Mdot
.35226 .55558 Mdot
.06008 .43746 Mdot
.6799 .38307 Mdot
.51568 .51654 Mdot
.37495 .53105 Mdot
.06534 .42669 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00267 Mdot
.52002 .00849 Mdot
.56371 .027 Mdot
.70044 .0845 Mdot
.06442 .22495 Mdot
.33439 .16685 Mdot
.3984 .03956 Mdot
.32015 .56967 Mdot
.02599 .43623 Mdot
.69302 .41224 Mdot
.50008 4e-05 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50267 .00113 Mdot
.50851 .00361 Mdot
.52711 .0115 Mdot
.58618 .03651 Mdot
.7683 .11255 Mdot
.18757 .25913 Mdot
.38624 .12279 Mdot
.42845 .02608 Mdot
.36689 .57999 Mdot
.49878 .61751 Mdot
.4961 .61638 Mdot
.48757 .61276 Mdot
.46042 .60125 Mdot
.3745 .56494 Mdot
.11925 .46028 Mdot
.7014 .35979 Mdot
.51123 .5005 Mdot
.33789 .51091 Mdot
.96131 .38529 Mdot
.64219 .42081 Mdot
.4976 .61701 Mdot
.49234 .61479 Mdot
.4756 .60769 Mdot
.42242 .58516 Mdot
.25741 .51605 Mdot
.85393 .36867 Mdot
.64006 .48586 Mdot
.6102 .59958 Mdot
.73276 .07574 Mdot
.09264 .22242 Mdot
.32128 .1413 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50575 .00244 Mdot
.51832 .00777 Mdot
.55832 .02472 Mdot
.68385 .07758 Mdot
.02779 .21257 Mdot
.33026 .18693 Mdot
.4237 .05775 Mdot
.40703 .60773 Mdot
.2587 .52636 Mdot
.872 .37904 Mdot
.49973 .61792 Mdot
.49914 .61767 Mdot
.49727 .61687 Mdot
.49129 .61434 Mdot
.47226 .60627 Mdot
.41182 .58068 Mdot
.22576 .50305 Mdot
.80374 .35721 Mdot
.60697 .49642 Mdot
.55885 .58829 Mdot
.597 .02358 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42796 .58751 Mdot
.27415 .52298 Mdot
.88436 .37713 Mdot
.65316 .47515 Mdot
.61785 .59621 Mdot
.7436 .07772 Mdot
.1079 .22514 Mdot
.32246 .13261 Mdot
.50005 2e-05 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50157 .00066 Mdot
.50499 .00212 Mdot
.51591 .00675 Mdot
.55066 .02147 Mdot
.66011 .06765 Mdot
.97122 .19228 Mdot
.32527 .21881 Mdot
.46678 .08746 Mdot
.55882 .05688 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50717 .00304 Mdot
.52284 .00969 Mdot
.57266 .03079 Mdot
.72773 .09584 Mdot
.1192 .24194 Mdot
.34812 .14148 Mdot
.38226 .0211 Mdot
.25547 .53967 Mdot
.89008 .39221 Mdot
.67678 .4862 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.51038 .0044 Mdot
.53306 .01402 Mdot
.60496 .04444 Mdot
.82314 .13484 Mdot
.25529 .26708 Mdot
.44883 .11962 Mdot
.56693 .07299 Mdot
.78251 .13323 Mdot
.23185 .27771 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50658 .00279 Mdot
.52096 .00889 Mdot
.56668 .02826 Mdot
.70953 .08829 Mdot
.08344 .23109 Mdot
.33784 .15723 Mdot
.38896 .03159 Mdot
.28671 .55484 Mdot
.95205 .4112 Mdot
.68823 .45499 Mdot
.49884 .61754 Mdot
.4963 .61646 Mdot
.48821 .61304 Mdot
.46246 .60212 Mdot
.38091 .56763 Mdot
.13694 .46725 Mdot
.71198 .3554 Mdot
.51898 .49875 Mdot
.35437 .5163 Mdot
.00054 .39936 Mdot
.6459 .39885 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.5144 .00611 Mdot
.54585 .01944 Mdot
.64512 .06136 Mdot
.93315 .17801 Mdot
.31853 .23818 Mdot
.48696 .1041 Mdot
.63587 .09203 Mdot
.96471 .20323 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50815 .00345 Mdot
.52595 .011 Mdot
.58251 .03496 Mdot
.75738 .10807 Mdot
.17071 .25546 Mdot
.37434 .12584 Mdot
.40844 .02108 Mdot
.31267 .55884 Mdot
.99643 .42259 Mdot
.68555 .4259 Mdot
.49881 .61753 Mdot
.49621 .61643 Mdot
.48792 .61291 Mdot
.46154 .60173 Mdot
.37802 .56642 Mdot
.12892 .46408 Mdot
.70691 .35721 Mdot
.51493 .49938 Mdot
.34531 .5132 Mdot
.97851 .39134 Mdot
.64384 .4112 Mdot
.49741 .61694 Mdot
.49175 .61454 Mdot
.47373 .6069 Mdot
.41649 .58265 Mdot
.23964 .50874 Mdot
.82456 .3615 Mdot
.6225 .49315 Mdot
.58657 .59583 Mdot
.67418 .05415 Mdot
.97393 .18526 Mdot
.31262 .20932 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50502 .00213 Mdot
.51598 .00678 Mdot
.55087 .02157 Mdot
.66079 .06793 Mdot
.9729 .1929 Mdot
.32547 .2179 Mdot
.46564 .08663 Mdot
.55466 .05502 Mdot
.72408 .10471 Mdot
.12907 .2503 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00155 Mdot
.51168 .00495 Mdot
.53721 .01578 Mdot
.61804 .04996 Mdot
.86013 .14962 Mdot
.28605 .26323 Mdot
.47933 .11945 Mdot
.64168 .10034 Mdot
.98958 .21501 Mdot
.3531 .22467 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49615 .6164 Mdot
.48772 .61283 Mdot
.46089 .60145 Mdot
.376 .56556 Mdot
.12335 .46189 Mdot
.70365 .35865 Mdot
.51264 .49998 Mdot
.34056 .51168 Mdot
.96736 .38739 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00123 Mdot
.50927 .00393 Mdot
.52952 .01252 Mdot
.59381 .03973 Mdot
.7908 .12175 Mdot
.21872 .26447 Mdot
.41251 .11977 Mdot
.48157 .04268 Mdot
.52304 .02563 Mdot
.59896 .04692 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53095 .01312 Mdot
.59832 .04164 Mdot
.80396 .12709 Mdot
.23474 .26624 Mdot
.42789 .11937 Mdot
.51654 .05479 Mdot
.62994 .07009 Mdot
.91731 .1776 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49304 .61508 Mdot
.47781 .60863 Mdot
.42942 .58813 Mdot
.2786 .52482 Mdot
.89289 .37965 Mdot
.65599 .47162 Mdot
.61737 .59417 Mdot
.73927 .07534 Mdot
.09936 .22255 Mdot
.49993 .618 Mdot
.49977 .61794 Mdot
.49927 .61773 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47648 .60806 Mdot
.4252 .58634 Mdot
.2658 .51952 Mdot
.86884 .3727 Mdot
.6471 .48099 Mdot
.6159 .59875 Mdot
.49874 .6175 Mdot
.49598 .61633 Mdot
.4872 .61261 Mdot
.45925 .60076 Mdot
.37082 .56339 Mdot
.10922 .45635 Mdot
.69635 .36286 Mdot
.50877 .5021 Mdot
.33433 .51023 Mdot
.9539 .38292 Mdot
.64166 .42505 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50514 .00218 Mdot
.51636 .00694 Mdot
.55208 .02208 Mdot
.66455 .06951 Mdot
.98215 .19629 Mdot
.32647 .2128 Mdot
.45909 .08196 Mdot
.53102 .04446 Mdot
.6492 .07304 Mdot
.9598 .19196 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50535 .00227 Mdot
.51703 .00722 Mdot
.55422 .02298 Mdot
.67117 .07228 Mdot
.99816 .20209 Mdot
.32791 .2038 Mdot
.44697 .07358 Mdot
.48794 .02532 Mdot
.51085 .01416 Mdot
.55002 .02421 Mdot
.49853 .61741 Mdot
.4953 .61604 Mdot
.48503 .61169 Mdot
.45235 .59783 Mdot
.34925 .55432 Mdot
.05236 .43454 Mdot
.67834 .38688 Mdot
.51925 .51971 Mdot
.38897 .53752 Mdot
.10534 .44274 Mdot
.67498 .35206 Mdot
.49852 .6174 Mdot
.49527 .61603 Mdot
.48493 .61165 Mdot
.45203 .5977 Mdot
.34826 .5539 Mdot
.04982 .43359 Mdot
.67787 .38815 Mdot
.52054 .5208 Mdot
.39395 .5398 Mdot
.11981 .4486 Mdot
.68245 .34773 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50775 .00329 Mdot
.5247 .01047 Mdot
.57855 .03328 Mdot
.7455 .10318 Mdot
.15109 .25067 Mdot
.36259 .13071 Mdot
.39263 .01857 Mdot
.27355 .54444 Mdot
.91835 .39851 Mdot
.68032 .47093 Mdot
.49932 .61775 Mdot
.49783 .61712 Mdot
.4931 .61511 Mdot
.47801 .60871 Mdot
.43005 .58839 Mdot
.28052 .52562 Mdot
.89662 .38077 Mdot
.65712 .47001 Mdot
.61684 .59314 Mdot
.73648 .07395 Mdot
.094 .22096 Mdot
.49813 .61724 Mdot
.49404 .61551 Mdot
.48102 .60998 Mdot
.43959 .59243 Mdot
.30969 .53776 Mdot
.95766 .40047 Mdot
.66839 .43926 Mdot
.58715 .56783 Mdot
.63021 .02661 Mdot
.84751 .1343 Mdot
.26012 .25501 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50315 .00134 Mdot
.51003 .00426 Mdot
.53196 .01355 Mdot
.60151 .04298 Mdot
.8132 .13083 Mdot
.24505 .2669 Mdot
.43828 .11942 Mdot
.54123 .06363 Mdot
.70533 .10142 Mdot
.09883 .2432 Mdot
.49756 .617 Mdot
.49221 .61473 Mdot
.47519 .60752 Mdot
.42112 .58461 Mdot
.25351 .51444 Mdot
.84722 .36693 Mdot
.63649 .4878 Mdot
.60631 .59938 Mdot
.72401 .07274 Mdot
.07726 .21832 Mdot
.31912 .14948 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50295 .00125 Mdot
.50939 .00398 Mdot
.52991 .01268 Mdot
.59502 .04024 Mdot
.79434 .12319 Mdot
.22319 .26504 Mdot
.41668 .11959 Mdot
.49083 .04583 Mdot
.55125 .03734 Mdot
.6872 .08403 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48672 .6124 Mdot
.45772 .60011 Mdot
.36605 .56138 Mdot
.09636 .45135 Mdot
.69079 .36738 Mdot
.50763 .50483 Mdot
.33592 .51191 Mdot
.95943 .38535 Mdot
.64314 .42255 Mdot
.49952 .61783 Mdot
.49848 .61739 Mdot
.49515 .61598 Mdot
.48456 .61149 Mdot
.45084 .5972 Mdot
.34456 .55235 Mdot
.04045 .43008 Mdot
.67632 .39299 Mdot
.52579 .525 Mdot
.41378 .54881 Mdot
.17868 .47273 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49734 .61691 Mdot
.49152 .61444 Mdot
.473 .60659 Mdot
.41417 .58167 Mdot
.23273 .5059 Mdot
.81397 .35923 Mdot
.61492 .49501 Mdot
.57364 .59253 Mdot
.63894 .04035 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.5101 .00428 Mdot
.53217 .01364 Mdot
.60217 .04326 Mdot
.8151 .1316 Mdot
.24708 .26697 Mdot
.44036 .11945 Mdot
.54625 .06545 Mdot
.72056 .10773 Mdot
.12952 .25275 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52547 .0108 Mdot
.58097 .0343 Mdot
.75276 .10617 Mdot
.16325 .2537 Mdot
.3696 .12753 Mdot
.40151 .01972 Mdot
.29494 .55217 Mdot
.95909 .41047 Mdot
.68393 .44798 Mdot
.49948 .61782 Mdot
.49835 .61734 Mdot
.49476 .61581 Mdot
.4833 .61095 Mdot
.44684 .5955 Mdot
.33212 .54713 Mdot
.00975 .4188 Mdot
.67276 .40976 Mdot
.54694 .54027 Mdot
.49052 .58316 Mdot
.41989 .57438 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .0034 Mdot
.52557 .01084 Mdot
.58131 .03445 Mdot
.75377 .10659 Mdot
.1649 .25409 Mdot
.37062 .12714 Mdot
.40294 .01998 Mdot
.29853 .55351 Mdot
.9664 .41277 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50787 .00334 Mdot
.52508 .01064 Mdot
.57976 .03379 Mdot
.74912 .10467 Mdot
.15721 .25221 Mdot
.36601 .12904 Mdot
.39673 .01899 Mdot
.28319 .54786 Mdot
.93609 .40351 Mdot
.6823 .46118 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50266 .00113 Mdot
.50846 .00359 Mdot
.52695 .01143 Mdot
.58567 .03629 Mdot
.76679 .11194 Mdot
.18531 .25866 Mdot
.38455 .12314 Mdot
.42541 .02525 Mdot
.35844 .57664 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51216 .00516 Mdot
.53872 .01642 Mdot
.6228 .05196 Mdot
.87332 .15484 Mdot
.29443 .26026 Mdot
.48605 .11843 Mdot
.65676 .10551 Mdot
.02639 .22845 Mdot
.35662 .20409 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00332 Mdot
.52497 .01059 Mdot
.57942 .03365 Mdot
.74811 .10426 Mdot
.15551 .25179 Mdot
.36503 .12949 Mdot
.39552 .01884 Mdot
.28029 .54682 Mdot
.93064 .40194 Mdot
.68177 .46422 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51714 .00727 Mdot
.55457 .02313 Mdot
.67226 .07274 Mdot
.00077 .20303 Mdot
.32812 .20231 Mdot
.44493 .07219 Mdot
.48076 .02215 Mdot
.4878 .00435 Mdot
.49771 .61706 Mdot
.49269 .61493 Mdot
.47672 .60816 Mdot
.42594 .58665 Mdot
.26805 .52045 Mdot
.87296 .37385 Mdot
.64883 .47951 Mdot
.6168 .59824 Mdot
.74465 .07902 Mdot
.1111 .22648 Mdot
.32411 .13165 Mdot
.49983 .61796 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49455 .61572 Mdot
.48262 .61067 Mdot
.44469 .59459 Mdot
.32544 .54433 Mdot
.99378 .41306 Mdot
.67145 .41882 Mdot
.55936 .54876 Mdot
.53426 .60252 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48195 .61038 Mdot
.44255 .59368 Mdot
.31883 .54157 Mdot
.97836 .40761 Mdot
.67025 .42761 Mdot
.57152 .55702 Mdot
.57651 .00308 Mdot
.69188 .0713 Mdot
.03024 .20912 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51502 .00637 Mdot
.54781 .02027 Mdot
.65124 .06392 Mdot
.9489 .18396 Mdot
.3219 .23053 Mdot
.48011 .09778 Mdot
.60858 .0794 Mdot
.88757 .17243 Mdot
.32152 .2682 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50576 .00244 Mdot
.51835 .00778 Mdot
.5584 .02475 Mdot
.68409 .07768 Mdot
.02834 .21276 Mdot
.3303 .18662 Mdot
.42328 .05747 Mdot
.40559 .6071 Mdot
.25445 .52462 Mdot
.86467 .37714 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48669 .61239 Mdot
.45761 .60006 Mdot
.36568 .56122 Mdot
.09536 .45097 Mdot
.6904 .36776 Mdot
.50764 .50508 Mdot
.33633 .51216 Mdot
.96056 .38579 Mdot
.64334 .42199 Mdot
.49842 .61736 Mdot
.49495 .61589 Mdot
.48391 .61121 Mdot
.44879 .59632 Mdot
.33815 .54966 Mdot
.02448 .42418 Mdot
.67423 .40157 Mdot
.53617 .53271 Mdot
.45189 .56595 Mdot
.29654 .52202 Mdot
.9126 .38074 Mdot
.49953 .61784 Mdot
.49851 .6174 Mdot
.49525 .61602 Mdot
.48486 .61162 Mdot
.45181 .59761 Mdot
.34757 .55361 Mdot
.04807 .43293 Mdot
.67756 .38905 Mdot
.52147 .52157 Mdot
.3975 .54141 Mdot
.13017 .45282 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51067 .00452 Mdot
.53397 .0144 Mdot
.60784 .04565 Mdot
.83137 .13815 Mdot
.26311 .26683 Mdot
.45692 .11978 Mdot
.58691 .08034 Mdot
.84088 .15696 Mdot
.2957 .2811 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50332 .00141 Mdot
.51058 .00449 Mdot
.5337 .01429 Mdot
.60699 .0453 Mdot
.82895 .13718 Mdot
.26087 .26694 Mdot
.45461 .11974 Mdot
.58118 .07823 Mdot
.82431 .15026 Mdot
.49823 .61728 Mdot
.49437 .61565 Mdot
.48205 .61042 Mdot
.44288 .59382 Mdot
.31985 .542 Mdot
.98072 .40844 Mdot
.67044 .42627 Mdot
.56967 .55576 Mdot
.57012 .00027 Mdot
.67236 .06319 Mdot
.9855 .19353 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51253 .00531 Mdot
.5399 .01692 Mdot
.6265 .05352 Mdot
.88348 .15883 Mdot
.30004 .25745 Mdot
.48958 .11714 Mdot
.6635 .10749 Mdot
.04175 .23377 Mdot
.35809 .19551 Mdot
.49973 .61792 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.49131 .61435 Mdot
.47232 .6063 Mdot
.41202 .58077 Mdot
.22636 .50329 Mdot
.8046 .35737 Mdot
.60766 .49632 Mdot
.56018 .58869 Mdot
.60082 .02512 Mdot
.49818 .61726 Mdot
.49419 .61557 Mdot
.4815 .61019 Mdot
.44112 .59308 Mdot
.31442 .53973 Mdot
.96827 .4041 Mdot
.6694 .43332 Mdot
.57931 .56235 Mdot
.60331 .01484 Mdot
.77164 .10403 Mdot
.17649 .25021 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50357 .00151 Mdot
.51138 .00483 Mdot
.53625 .01537 Mdot
.61502 .04868 Mdot
.8517 .14627 Mdot
.28 .26471 Mdot
.47381 .11978 Mdot
.6285 .0956 Mdot
.95566 .2022 Mdot
.34848 .24277 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47576 .60776 Mdot
.42292 .58538 Mdot
.25894 .51668 Mdot
.85659 .36937 Mdot
.64141 .48504 Mdot
.61152 .59956 Mdot
.73554 .07665 Mdot
.09732 .22359 Mdot
.32204 .13889 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49847 .61739 Mdot
.49513 .61597 Mdot
.48448 .61145 Mdot
.4506 .59709 Mdot
.34379 .55202 Mdot
.03852 .42937 Mdot
.67603 .394 Mdot
.52695 .5259 Mdot
.41811 .55076 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00178 Mdot
.51341 .00569 Mdot
.5427 .0181 Mdot
.63526 .05721 Mdot
.90716 .16804 Mdot
.31056 .24931 Mdot
.49229 .11232 Mdot
.66246 .10517 Mdot
.03616 .23096 Mdot
.35608 .19772 Mdot
.4977 .61706 Mdot
.49268 .61493 Mdot
.47669 .60815 Mdot
.42585 .58662 Mdot
.26778 .52034 Mdot
.87247 .37371 Mdot
.64863 .47969 Mdot
.6167 .59831 Mdot
.74457 .07902 Mdot
.11102 .22648 Mdot
.32413 .13171 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42794 .5875 Mdot
.2741 .52295 Mdot
.88425 .3771 Mdot
.65312 .47519 Mdot
.61785 .59623 Mdot
.74364 .07774 Mdot
.10797 .22517 Mdot
.32248 .13258 Mdot
.5007 .00029 Mdot
.50221 .00094 Mdot
.50706 .00299 Mdot
.52248 .00953 Mdot
.57152 .03031 Mdot
.72425 .0944 Mdot
.1126 .24001 Mdot
.34579 .14412 Mdot
.3822 .0225 Mdot
.25761 .54103 Mdot
.89455 .39365 Mdot
.67835 .48441 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47459 .60726 Mdot
.41919 .5838 Mdot
.24772 .51206 Mdot
.83754 .36453 Mdot
.63088 .49031 Mdot
.59916 .59843 Mdot
.70673 .06648 Mdot
.04426 .20861 Mdot
.31626 .1681 Mdot
.49787 .61713 Mdot
.49321 .61516 Mdot
.47838 .60887 Mdot
.43121 .58888 Mdot
.28404 .52708 Mdot
.90358 .38289 Mdot
.65906 .46692 Mdot
.61536 .59102 Mdot
.72993 .07081 Mdot
.08134 .21718 Mdot
.31598 .14502 Mdot
.49987 .61798 Mdot
.49957 .61785 Mdot
.49863 .61745 Mdot
.49564 .61618 Mdot
.48611 .61214 Mdot
.45576 .59928 Mdot
.3599 .55879 Mdot
.08 .44505 Mdot
.68509 .37397 Mdot
.50933 .50941 Mdot
.34756 .51805 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00254 Mdot
.5191 .0081 Mdot
.56079 .02576 Mdot
.69145 .08076 Mdot
.04488 .21843 Mdot
.33188 .17737 Mdot
.41104 .04892 Mdot
.36359 .58871 Mdot
.13569 .47718 Mdot
.72802 .36609 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00126 Mdot
.50944 .004 Mdot
.53005 .01274 Mdot
.59548 .04044 Mdot
.7957 .12374 Mdot
.22488 .26525 Mdot
.41829 .11953 Mdot
.49445 .04707 Mdot
.56229 .04193 Mdot
.50071 .0003 Mdot
.50228 .00096 Mdot
.50725 .00307 Mdot
.52309 .00979 Mdot
.57345 .03112 Mdot
.73012 .09683 Mdot
.12366 .24322 Mdot
.34982 .13977 Mdot
.38268 .02031 Mdot
.25506 .53916 Mdot
.88884 .39169 Mdot
.67613 .48657 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50323 .00137 Mdot
.51028 .00436 Mdot
.53275 .01389 Mdot
.60401 .04404 Mdot
.82041 .13374 Mdot
.25256 .26708 Mdot
.44601 .11956 Mdot
.56002 .07046 Mdot
.76193 .12479 Mdot
.20191 .27192 Mdot
.49745 .61695 Mdot
.49187 .61458 Mdot
.47409 .60705 Mdot
.41762 .58313 Mdot
.24302 .51012 Mdot
.82991 .36272 Mdot
.62607 .49206 Mdot
.59218 .59709 Mdot
.68896 .05981 Mdot
.00712 .19664 Mdot
.31461 .19004 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48961 .61363 Mdot
.4669 .604 Mdot
.39488 .57353 Mdot
.17641 .48301 Mdot
.74428 .35096 Mdot
.55072 .49841 Mdot
.43196 .54464 Mdot
.21422 .48346 Mdot
.76375 .33963 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51251 .00531 Mdot
.53985 .0169 Mdot
.62635 .05346 Mdot
.88308 .15867 Mdot
.29984 .25757 Mdot
.48947 .1172 Mdot
.66332 .10744 Mdot
.04135 .23364 Mdot
.35806 .19573 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48837 .6131 Mdot
.46295 .60232 Mdot
.38245 .56828 Mdot
.14123 .46895 Mdot
.71489 .35454 Mdot
.5215 .49851 Mdot
.36027 .51838 Mdot
.01534 .40486 Mdot
.64744 .39066 Mdot
.49902 .61762 Mdot
.49689 .61671 Mdot
.49009 .61383 Mdot
.46843 .60465 Mdot
.39972 .57557 Mdot
.19034 .48863 Mdot
.75881 .35133 Mdot
.56564 .49865 Mdot
.46818 .5578 Mdot
.32329 .52849 Mdot
.96454 .39632 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50407 .00172 Mdot
.51295 .00549 Mdot
.54125 .01749 Mdot
.63074 .0553 Mdot
.895 .16332 Mdot
.30559 .25376 Mdot
.49185 .11512 Mdot
.6659 .10757 Mdot
.04612 .23499 Mdot
.35812 .19283 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50379 .00161 Mdot
.51209 .00512 Mdot
.53849 .01632 Mdot
.62207 .05165 Mdot
.87131 .15404 Mdot
.29323 .26076 Mdot
.48517 .11863 Mdot
.65491 .1049 Mdot
.02203 .22689 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50798 .00338 Mdot
.52543 .01078 Mdot
.58085 .03425 Mdot
.75238 .10602 Mdot
.16263 .25355 Mdot
.36922 .12768 Mdot
.40098 .01963 Mdot
.29362 .55168 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50612 .00259 Mdot
.51948 .00826 Mdot
.562 .02628 Mdot
.69518 .08231 Mdot
.05307 .22119 Mdot
.33282 .1729 Mdot
.40545 .04488 Mdot
.34444 .58033 Mdot
.08551 .45801 Mdot
.7044 .38249 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51525 .00647 Mdot
.54856 .02059 Mdot
.65358 .06491 Mdot
.95485 .18619 Mdot
.32294 .22749 Mdot
.47693 .09517 Mdot
.59644 .07386 Mdot
.85192 .1579 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50599 .00254 Mdot
.51908 .00809 Mdot
.56072 .02573 Mdot
.69124 .08067 Mdot
.04441 .21827 Mdot
.33182 .17763 Mdot
.41137 .04916 Mdot
.36474 .58922 Mdot
.13878 .47838 Mdot
.73005 .36542 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.5078 .00331 Mdot
.52485 .01054 Mdot
.57903 .03348 Mdot
.74693 .10377 Mdot
.15352 .25129 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49434 .61564 Mdot
.48198 .61039 Mdot
.44264 .59372 Mdot
.31911 .54169 Mdot
.97901 .40784 Mdot
.6703 .42724 Mdot
.57101 .55667 Mdot
.57474 .0023 Mdot
.6865 .06907 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51805 .00765 Mdot
.55744 .02435 Mdot
.68113 .07645 Mdot
.02156 .21039 Mdot
.32974 .19047 Mdot
.42854 .06106 Mdot
.42372 .61505 Mdot
.30881 .54702 Mdot
.97129 .40943 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51572 .00667 Mdot
.55006 .02122 Mdot
.65826 .06687 Mdot
.96662 .19058 Mdot
.32468 .22129 Mdot
.46982 .0897 Mdot
.56994 .06188 Mdot
.77164 .12465 Mdot
.20986 .27084 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48746 .61272 Mdot
.46006 .6011 Mdot
.37337 .56446 Mdot
.11615 .45907 Mdot
.69977 .36069 Mdot
.51032 .50095 Mdot
.33634 .51051 Mdot
.95791 .38415 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49853 .61741 Mdot
.49531 .61604 Mdot
.48505 .6117 Mdot
.45241 .59786 Mdot
.34944 .5544 Mdot
.05284 .43473 Mdot
.67843 .38663 Mdot
.51901 .51951 Mdot
.38805 .53709 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50527 .00224 Mdot
.5168 .00712 Mdot
.55347 .02267 Mdot
.66885 .07131 Mdot
.9926 .20009 Mdot
.32744 .20695 Mdot
.45127 .07653 Mdot
.50313 .03205 Mdot
.55968 .03495 Mdot
.70367 .08899 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51068 .00453 Mdot
.53402 .01442 Mdot
.608 .04572 Mdot
.83183 .13834 Mdot
.26353 .2668 Mdot
.45736 .11979 Mdot
.58798 .08073 Mdot
.84395 .1582 Mdot
.29826 .28077 Mdot
.50075 .00032 Mdot
.50237 .00101 Mdot
.50756 .00321 Mdot
.5241 .01022 Mdot
.57664 .03247 Mdot
.73974 .1008 Mdot
.14108 .24804 Mdot
.35745 .13372 Mdot
.38745 .01854 Mdot
.26234 .54071 Mdot
.89922 .39361 Mdot
.67737 .48092 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.51942 .00823 Mdot
.56179 .02619 Mdot
.69453 .08204 Mdot
.05165 .22071 Mdot
.33265 .17367 Mdot
.40639 .04557 Mdot
.34767 .58174 Mdot
.09377 .46112 Mdot
.49874 .6175 Mdot
.49597 .61633 Mdot
.48717 .61259 Mdot
.45914 .60071 Mdot
.37048 .56324 Mdot
.1083 .456 Mdot
.69592 .36317 Mdot
.50861 .50227 Mdot
.33422 .51025 Mdot
.95374 .38289 Mdot
.64168 .42517 Mdot
.50044 .00019 Mdot
.5014 .0006 Mdot
.50447 .0019 Mdot
.51425 .00604 Mdot
.54539 .01924 Mdot
.64368 .06075 Mdot
.92939 .17658 Mdot
.31757 .23991 Mdot
.48822 .10547 Mdot
.64122 .09456 Mdot
.97932 .20896 Mdot
.34835 .22808 Mdot
.49873 .6175 Mdot
.49597 .61632 Mdot
.48715 .61258 Mdot
.45907 .60068 Mdot
.37029 .56316 Mdot
.10777 .45579 Mdot
.69567 .36334 Mdot
.50853 .50237 Mdot
.33417 .51027 Mdot
.95369 .38289 Mdot
.6417 .42521 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00227 Mdot
.51702 .00722 Mdot
.55417 .02296 Mdot
.67102 .07222 Mdot
.99781 .20197 Mdot
.32788 .204 Mdot
.44724 .07377 Mdot
.4889 .02575 Mdot
.51393 .01547 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50761 .00323 Mdot
.52423 .01027 Mdot
.57705 .03265 Mdot
.74098 .10132 Mdot
.14326 .24862 Mdot
.35852 .13303 Mdot
.38842 .01848 Mdot
.26432 .54134 Mdot
.90245 .39439 Mdot
.67792 .47927 Mdot
.49754 .61699 Mdot
.49218 .61472 Mdot
.47508 .60747 Mdot
.42074 .58445 Mdot
.25237 .51398 Mdot
.84529 .36645 Mdot
.63542 .48832 Mdot
.60504 .59926 Mdot
.72103 .07168 Mdot
.0718 .21679 Mdot
.31849 .15246 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52545 .01079 Mdot
.58091 .03428 Mdot
.75259 .1061 Mdot
.16296 .25363 Mdot
.36942 .1276 Mdot
.40127 .01968 Mdot
.29432 .55194 Mdot
.95785 .41008 Mdot
.68386 .4487 Mdot
.49888 .61756 Mdot
.49642 .61651 Mdot
.48859 .61319 Mdot
.46365 .60262 Mdot
.38465 .56921 Mdot
.14738 .47139 Mdot
.71931 .35347 Mdot
.52554 .49828 Mdot
.36993 .52186 Mdot
.04022 .41426 Mdot
.65082 .37737 Mdot
.49848 .61739 Mdot
.49517 .61599 Mdot
.48461 .61151 Mdot
.451 .59726 Mdot
.34504 .55255 Mdot
.04165 .43053 Mdot
.6765 .39236 Mdot
.52508 .52445 Mdot
.41111 .5476 Mdot
.17063 .46941 Mdot
.7205 .33983 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47916 .6092 Mdot
.43368 .58993 Mdot
.29158 .53021 Mdot
.91884 .38767 Mdot
.66264 .45969 Mdot
.61009 .58556 Mdot
.70982 .06164 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .613 Mdot
.46223 .60202 Mdot
.38019 .56733 Mdot
.13494 .46646 Mdot
.71067 .35582 Mdot
.51789 .49888 Mdot
.35187 .51543 Mdot
.99439 .3971 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48652 .61232 Mdot
.45709 .59984 Mdot
.36406 .56054 Mdot
.09103 .44929 Mdot
.68878 .36943 Mdot
.50781 .50619 Mdot
.33856 .51343 Mdot
.9666 .38815 Mdot
.5002 9e-05 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.50649 .00275 Mdot
.52067 .00877 Mdot
.56578 .02788 Mdot
.70678 .08714 Mdot
.07775 .22928 Mdot
.33668 .16003 Mdot
.39143 .03383 Mdot
.29565 .55884 Mdot
.97089 .41732 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50554 .00235 Mdot
.51763 .00748 Mdot
.55613 .02379 Mdot
.67709 .07476 Mdot
.01217 .20709 Mdot
.32901 .19582 Mdot
.43594 .06608 Mdot
.44934 .00828 Mdot
.38804 .58014 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00304 Mdot
.52287 .0097 Mdot
.57274 .03082 Mdot
.72796 .09593 Mdot
.11963 .24207 Mdot
.34828 .14131 Mdot
.38229 .02102 Mdot
.25539 .53961 Mdot
.88989 .39215 Mdot
.6767 .48627 Mdot
.49751 .61698 Mdot
.49208 .61467 Mdot
.47476 .60733 Mdot
.41975 .58403 Mdot
.2494 .51275 Mdot
.84032 .36521 Mdot
.63255 .48963 Mdot
.6014 .59878 Mdot
.71228 .06852 Mdot
.05521 .21194 Mdot
.31698 .16178 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.51511 .00641 Mdot
.54811 .02039 Mdot
.65217 .06432 Mdot
.95128 .18486 Mdot
.32233 .22932 Mdot
.47888 .09675 Mdot
.60384 .07723 Mdot
.87373 .1668 Mdot
.31378 .27196 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51648 .00699 Mdot
.55246 .02224 Mdot
.6657 .06999 Mdot
.98496 .19732 Mdot
.32675 .21124 Mdot
.45703 .08052 Mdot
.52362 .04116 Mdot
.62552 .06298 Mdot
.89678 .16765 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51428 .00606 Mdot
.54547 .01928 Mdot
.64394 .06086 Mdot
.93008 .17684 Mdot
.31775 .2396 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50924 .00392 Mdot
.52942 .01248 Mdot
.5935 .0396 Mdot
.78988 .12137 Mdot
.21755 .26431 Mdot
.41142 .11982 Mdot
.47919 .04188 Mdot
.51582 .02264 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00332 Mdot
.52498 .01059 Mdot
.57942 .03365 Mdot
.74813 .10426 Mdot
.15554 .2518 Mdot
.36505 .12948 Mdot
.39554 .01884 Mdot
.28034 .54684 Mdot
.93073 .40197 Mdot
.68178 .46417 Mdot
.49794 .61716 Mdot
.49345 .61526 Mdot
.47913 .60918 Mdot
.4336 .58989 Mdot
.29133 .53011 Mdot
.91833 .38751 Mdot
.66253 .45994 Mdot
.61031 .58576 Mdot
.71062 .062 Mdot
.04239 .20505 Mdot
.31133 .16621 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50271 .00115 Mdot
.50862 .00366 Mdot
.52747 .01165 Mdot
.58731 .03699 Mdot
.77166 .11393 Mdot
.19253 .26011 Mdot
.39006 .12208 Mdot
.4355 .02808 Mdot
.38681 .58794 Mdot
.50073 .00031 Mdot
.50231 .00098 Mdot
.50737 .00312 Mdot
.52347 .00995 Mdot
.57465 .03163 Mdot
.73375 .09833 Mdot
.13033 .2451 Mdot
.35255 .13734 Mdot
.3839 .01937 Mdot
.25613 .53907 Mdot
.88981 .39163 Mdot
.67588 .48582 Mdot
.50034 .00015 Mdot
.5011 .00047 Mdot
.5035 .00148 Mdot
.51114 .00473 Mdot
.53549 .01505 Mdot
.61264 .04768 Mdot
.845 .1436 Mdot
.27481 .26564 Mdot
.46878 .11988 Mdot
.61621 .09112 Mdot
.92287 .18953 Mdot
.34075 .25826 Mdot
.49917 .61768 Mdot
.49735 .61691 Mdot
.49154 .61445 Mdot
.47306 .60661 Mdot
.41436 .58175 Mdot
.2333 .50614 Mdot
.81483 .3594 Mdot
.61555 .49488 Mdot
.57477 .59283 Mdot
.64208 .04159 Mdot
.89529 .1565 Mdot
.49891 .61757 Mdot
.49651 .61656 Mdot
.48889 .61332 Mdot
.46461 .60303 Mdot
.3877 .5705 Mdot
.15596 .47481 Mdot
.72596 .35228 Mdot
.53198 .49815 Mdot
.38566 .5276 Mdot
.08221 .43049 Mdot
.66085 .35762 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49146 .61441 Mdot
.47281 .6065 Mdot
.41356 .58142 Mdot
.23094 .50517 Mdot
.81129 .35868 Mdot
.61289 .49542 Mdot
.56999 .59152 Mdot
.62871 .03629 Mdot
.86013 .14302 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .00181 Mdot
.51358 .00576 Mdot
.54325 .01834 Mdot
.637 .05794 Mdot
.91178 .16983 Mdot
.31222 .24749 Mdot
.49195 .11107 Mdot
.65959 .10361 Mdot
.02848 .22798 Mdot
.35487 .20172 Mdot
.499 .61761 Mdot
.4968 .61668 Mdot
.4898 .61371 Mdot
.46752 .60426 Mdot
.39686 .57436 Mdot
.18208 .4853 Mdot
.74999 .35098 Mdot
.55662 .49853 Mdot
.44641 .54992 Mdot
.25732 .50117 Mdot
.82975 .35378 Mdot
.49903 .61762 Mdot
.49689 .61672 Mdot
.49011 .61384 Mdot
.46849 .60467 Mdot
.39991 .57565 Mdot
.1909 .48886 Mdot
.75943 .35137 Mdot
.56627 .49866 Mdot
.46967 .55833 Mdot
.32785 .53039 Mdot
.9753 .40014 Mdot
.49766 .61704 Mdot
.49253 .61487 Mdot
.47621 .60795 Mdot
.42435 .58598 Mdot
.26322 .51846 Mdot
.86419 .37142 Mdot
.64504 .48259 Mdot
.61455 .59919 Mdot
.74143 .07842 Mdot
.10669 .22575 Mdot
.32364 .13408 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50072 .00031 Mdot
.50231 .00098 Mdot
.50735 .00312 Mdot
.5234 .00992 Mdot
.57444 .03154 Mdot
.73312 .09807 Mdot
.12918 .24478 Mdot
.35206 .13775 Mdot
.38363 .01951 Mdot
.2558 .53903 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00247 Mdot
.51852 .00785 Mdot
.55896 .02499 Mdot
.68581 .0784 Mdot
.03225 .21411 Mdot
.33064 .18442 Mdot
.4203 .05541 Mdot
.39534 .60261 Mdot
.22447 .51243 Mdot
.81794 .36678 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.5205 .00869 Mdot
.56522 .02764 Mdot
.70505 .08642 Mdot
.07415 .22812 Mdot
.33601 .16184 Mdot
.39315 .03532 Mdot
.3018 .56157 Mdot
.98424 .42177 Mdot
.69028 .43636 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50223 .00095 Mdot
.50711 .00301 Mdot
.52264 .0096 Mdot
.57203 .03052 Mdot
.72582 .09504 Mdot
.11559 .24089 Mdot
.34682 .14291 Mdot
.38215 .02183 Mdot
.25641 .54033 Mdot
.89214 .3929 Mdot
.5007 .00029 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.52248 .00953 Mdot
.57152 .03031 Mdot
.72426 .0944 Mdot
.11261 .24002 Mdot
.3458 .14411 Mdot
.3822 .0225 Mdot
.2576 .54103 Mdot
.89454 .39365 Mdot
.67835 .48442 Mdot
.49865 .61746 Mdot
.49571 .61621 Mdot
.48632 .61223 Mdot
.45644 .59957 Mdot
.36204 .55969 Mdot
.08567 .44722 Mdot
.6869 .37159 Mdot
.50836 .50769 Mdot
.34235 .51544 Mdot
.97669 .39204 Mdot
.64587 .41357 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50763 .00323 Mdot
.52429 .0103 Mdot
.57726 .03273 Mdot
.7416 .10157 Mdot
.14435 .24891 Mdot
.35906 .1327 Mdot
.38893 .01846 Mdot
.2654 .54169 Mdot
.90425 .39483 Mdot
.67822 .47834 Mdot
.50018 7e-05 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.5181 .00768 Mdot
.55761 .02442 Mdot
.68166 .07667 Mdot
.02278 .21082 Mdot
.32984 .18978 Mdot
.42759 .06041 Mdot
.42044 .61361 Mdot
.29884 .54289 Mdot
.4981 .61723 Mdot
.49394 .61547 Mdot
.48071 .60985 Mdot
.4386 .59201 Mdot
.30667 .5365 Mdot
.95098 .39821 Mdot
.66766 .44293 Mdot
.59183 .57117 Mdot
.64624 .03363 Mdot
.89042 .15091 Mdot
.28629 .24466 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49651 .61655 Mdot
.48888 .61332 Mdot
.4646 .60302 Mdot
.38765 .57048 Mdot
.15582 .47476 Mdot
.72585 .3523 Mdot
.53188 .49815 Mdot
.38539 .5275 Mdot
.08148 .4302 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47451 .60723 Mdot
.41895 .5837 Mdot
.24701 .51177 Mdot
.83637 .36425 Mdot
.63017 .49059 Mdot
.59817 .59826 Mdot
.70426 .06557 Mdot
.49765 .61704 Mdot
.4925 .61485 Mdot
.47612 .60791 Mdot
.42404 .58585 Mdot
.2623 .51807 Mdot
.86255 .37097 Mdot
.64428 .48314 Mdot
.61398 .59931 Mdot
.7404 .07813 Mdot
.10513 .22541 Mdot
.32338 .13489 Mdot
.49827 .6173 Mdot
.49447 .61569 Mdot
.48239 .61057 Mdot
.44396 .59428 Mdot
.3232 .5434 Mdot
.98851 .41118 Mdot
.67104 .42183 Mdot
.56353 .55159 Mdot
.5488 .60893 Mdot
.60611 .03542 Mdot
.81107 .12667 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49071 .6141 Mdot
.47042 .60549 Mdot
.40602 .57823 Mdot
.20869 .49608 Mdot
.78063 .35348 Mdot
.58689 .4983 Mdot
.51711 .57491 Mdot
.47294 .59073 Mdot
.38836 .56577 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00286 Mdot
.52145 .00909 Mdot
.56824 .02892 Mdot
.71428 .09026 Mdot
.09307 .2341 Mdot
.34007 .15266 Mdot
.38557 .02812 Mdot
.27384 .54898 Mdot
.92604 .40309 Mdot
.68523 .46921 Mdot
.49796 .61717 Mdot
.49351 .61528 Mdot
.47931 .60926 Mdot
.43417 .59013 Mdot
.29307 .53083 Mdot
.92193 .38866 Mdot
.66325 .45816 Mdot
.60872 .58433 Mdot
.70487 .05943 Mdot
.03022 .20108 Mdot
.31051 .17323 Mdot
.49979 .61795 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47887 .60907 Mdot
.43276 .58954 Mdot
.28877 .52904 Mdot
.9131 .38586 Mdot
.6614 .46247 Mdot
.61238 .58774 Mdot
.71826 .06544 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50811 .00344 Mdot
.52584 .01095 Mdot
.58214 .0348 Mdot
.75627 .10762 Mdot
.16894 .25505 Mdot
.37318 .12623 Mdot
.40669 .02071 Mdot
.30813 .55712 Mdot
.98658 .4193 Mdot
.68514 .43173 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51877 .00796 Mdot
.55975 .02532 Mdot
.68826 .07942 Mdot
.03776 .216 Mdot
.33115 .18133 Mdot
.41618 .05255 Mdot
.38122 .59642 Mdot
.18416 .49625 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51451 .00615 Mdot
.54621 .01959 Mdot
.64625 .06183 Mdot
.93608 .17912 Mdot
.31923 .2368 Mdot
.48588 .103 Mdot
.63137 .08992 Mdot
.9523 .19835 Mdot
.34371 .2419 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00467 Mdot
.53505 .01486 Mdot
.61124 .04709 Mdot
.84104 .14202 Mdot
.27156 .26608 Mdot
.46554 .11989 Mdot
.60825 .08819 Mdot
.90109 .18098 Mdot
.33293 .26689 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50937 .00397 Mdot
.52984 .01265 Mdot
.59482 .04016 Mdot
.79376 .12295 Mdot
.22246 .26495 Mdot
.416 .11961 Mdot
.4893 .0453 Mdot
.54657 .03539 Mdot
.67269 .07795 Mdot
.49893 .61758 Mdot
.49658 .61659 Mdot
.48912 .61342 Mdot
.46534 .60334 Mdot
.38998 .57146 Mdot
.16242 .47739 Mdot
.73137 .35163 Mdot
.53742 .49817 Mdot
.39908 .53254 Mdot
.11932 .44513 Mdot
.67687 .34459 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50365 .00155 Mdot
.51164 .00493 Mdot
.53706 .01571 Mdot
.61756 .04975 Mdot
.85879 .14909 Mdot
.28512 .26349 Mdot
.47851 .11952 Mdot
.63977 .09966 Mdot
.98474 .21321 Mdot
.35257 .22733 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48203 .61041 Mdot
.44281 .59379 Mdot
.31963 .5419 Mdot
.98019 .40825 Mdot
.6704 .42657 Mdot
.57008 .55604 Mdot
.57153 .0009 Mdot
.67671 .065 Mdot
.99575 .19718 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.5055 .00233 Mdot
.51751 .00743 Mdot
.55574 .02363 Mdot
.67588 .07425 Mdot
.00933 .20608 Mdot
.32879 .19744 Mdot
.43818 .06761 Mdot
.45716 .01173 Mdot
.41266 .59053 Mdot
.24363 .51357 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48499 .61167 Mdot
.4522 .59777 Mdot
.34879 .55412 Mdot
.05119 .4341 Mdot
.67812 .38747 Mdot
.51984 .52021 Mdot
.39125 .53856 Mdot
.11195 .44541 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47786 .60865 Mdot
.42957 .58819 Mdot
.27905 .52501 Mdot
.89376 .37991 Mdot
.65626 .47125 Mdot
.61726 .59393 Mdot
.73866 .07503 Mdot
.0982 .2222 Mdot
.3196 .13684 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.48621 .61219 Mdot
.4561 .59942 Mdot
.36097 .55924 Mdot
.08283 .44613 Mdot
.68597 .37277 Mdot
.5088 .50853 Mdot
.34481 .51668 Mdot
.98321 .39455 Mdot
.64675 .41009 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.51441 .00611 Mdot
.54588 .01945 Mdot
.64523 .0614 Mdot
.93342 .17811 Mdot
.31859 .23805 Mdot
.48687 .104 Mdot
.63546 .09184 Mdot
.96359 .20279 Mdot
.49977 .61794 Mdot
.49927 .61772 Mdot
.49766 .61704 Mdot
.49255 .61487 Mdot
.47626 .60797 Mdot
.42449 .58604 Mdot
.26365 .51863 Mdot
.86495 .37163 Mdot
.64538 .48233 Mdot
.61479 .59913 Mdot
.74185 .07853 Mdot
.49989 .61799 Mdot
.49964 .61788 Mdot
.49885 .61754 Mdot
.49632 .61647 Mdot
.48828 .61306 Mdot
.46268 .60221 Mdot
.38161 .56793 Mdot
.13888 .46802 Mdot
.71328 .355 Mdot
.52009 .49863 Mdot
.35695 .51721 Mdot
.49792 .61715 Mdot
.49336 .61522 Mdot
.47884 .60906 Mdot
.43268 .5895 Mdot
.28852 .52894 Mdot
.91258 .38569 Mdot
.66128 .46272 Mdot
.61256 .58793 Mdot
.71897 .06576 Mdot
.05958 .21051 Mdot
.31289 .15656 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48134 .61012 Mdot
.44062 .59287 Mdot
.31289 .53909 Mdot
.96483 .40292 Mdot
.66909 .43526 Mdot
.5819 .56415 Mdot
.6122 .01873 Mdot
.79721 .11434 Mdot
.21053 .25544 Mdot
.49739 .61693 Mdot
.49168 .61451 Mdot
.47351 .6068 Mdot
.41578 .58236 Mdot
.23754 .50787 Mdot
.82129 .36078 Mdot
.62023 .49377 Mdot
.58283 .59492 Mdot
.66415 .05026 Mdot
.9503 .17685 Mdot
.3098 .22218 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49606 .61636 Mdot
.48746 .61272 Mdot
.46006 .6011 Mdot
.37338 .56446 Mdot
.11617 .45907 Mdot
.69978 .36069 Mdot
.51032 .50095 Mdot
.33635 .51051 Mdot
.95792 .38415 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50725 .00308 Mdot
.52311 .0098 Mdot
.57351 .03115 Mdot
.7303 .0969 Mdot
.12399 .24331 Mdot
.34995 .13965 Mdot
.38272 .02026 Mdot
.25507 .53914 Mdot
.88881 .39167 Mdot
.67609 .48657 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50543 .0023 Mdot
.5173 .00733 Mdot
.55506 .02334 Mdot
.67376 .07337 Mdot
.00434 .20431 Mdot
.3284 .20028 Mdot
.44213 .07028 Mdot
.47094 .01781 Mdot
.4564 .60905 Mdot
.37729 .56914 Mdot
.4979 .61715 Mdot
.49332 .6152 Mdot
.47872 .60901 Mdot
.43231 .58935 Mdot
.28738 .52847 Mdot
.91029 .38497 Mdot
.66074 .46381 Mdot
.61337 .58875 Mdot
.72202 .06715 Mdot
.06572 .21242 Mdot
.31362 .15321 Mdot
.49902 .61762 Mdot
.49689 .61671 Mdot
.49009 .61383 Mdot
.46842 .60465 Mdot
.39971 .57556 Mdot
.19031 .48862 Mdot
.75878 .35133 Mdot
.56561 .49865 Mdot
.4681 .55777 Mdot
.32304 .52839 Mdot
.96397 .39611 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49853 .61741 Mdot
.49531 .61604 Mdot
.48505 .61169 Mdot
.45239 .59785 Mdot
.34938 .55437 Mdot
.0527 .43467 Mdot
.6784 .38671 Mdot
.51908 .51957 Mdot
.38832 .53722 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51812 .00769 Mdot
.55769 .02445 Mdot
.6819 .07677 Mdot
.02332 .21101 Mdot
.32989 .18947 Mdot
.42717 .06012 Mdot
.41897 .61297 Mdot
.2944 .54105 Mdot
.94034 .39921 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.4984 .61735 Mdot
.4949 .61587 Mdot
.48375 .61114 Mdot
.44826 .5961 Mdot
.33651 .54897 Mdot
.02045 .42269 Mdot
.67379 .40379 Mdot
.53903 .53474 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50714 .00303 Mdot
.52275 .00965 Mdot
.57238 .03067 Mdot
.72687 .09548 Mdot
.11758 .24147 Mdot
.34753 .14212 Mdot
.38219 .02142 Mdot
.25582 .53994 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51419 .00602 Mdot
.54519 .01916 Mdot
.64305 .06048 Mdot
.92775 .17595 Mdot
.31714 .24066 Mdot
.48872 .10604 Mdot
.6434 .0956 Mdot
.98525 .21127 Mdot
.34919 .22493 Mdot
.49824 .61729 Mdot
.49438 .61565 Mdot
.48209 .61044 Mdot
.44299 .59387 Mdot
.3202 .54214 Mdot
.98152 .40872 Mdot
.6705 .42581 Mdot
.56904 .55533 Mdot
.56793 .61735 Mdot
.66566 .0604 Mdot
.96937 .18771 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48371 .61113 Mdot
.44815 .59605 Mdot
.33618 .54883 Mdot
.01962 .42239 Mdot
.67371 .40425 Mdot
.53962 .53516 Mdot
.46436 .57152 Mdot
.33609 .53876 Mdot
.00316 .41227 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51727 .00733 Mdot
.55499 .02331 Mdot
.67355 .07328 Mdot
.00383 .20412 Mdot
.32836 .20058 Mdot
.44253 .07056 Mdot
.47235 .01843 Mdot
.4609 .61096 Mdot
.39138 .57507 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.5175 .00742 Mdot
.5557 .02361 Mdot
.67577 .0742 Mdot
.00906 .20599 Mdot
.32877 .19759 Mdot
.4384 .06775 Mdot
.45791 .01206 Mdot
.41501 .59152 Mdot
.49914 .61767 Mdot
.49725 .61687 Mdot
.49124 .61432 Mdot
.47211 .60621 Mdot
.41135 .58048 Mdot
.22439 .50249 Mdot
.80178 .35685 Mdot
.60538 .49665 Mdot
.55575 .58736 Mdot
.58805 .01996 Mdot
.7458 .09749 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50474 .00201 Mdot
.51509 .0064 Mdot
.54805 .02037 Mdot
.65199 .06424 Mdot
.95082 .18468 Mdot
.32225 .22956 Mdot
.47912 .09695 Mdot
.60477 .07765 Mdot
.87646 .16791 Mdot
.3154 .27128 Mdot
.50039 .00017 Mdot
.50126 .00053 Mdot
.504 .0017 Mdot
.51275 .00541 Mdot
.5406 .01721 Mdot
.62868 .05444 Mdot
.88944 .16116 Mdot
.30302 .2556 Mdot
.49098 .11617 Mdot
.66544 .10782 Mdot
.04571 .23502 Mdot
.35836 .19323 Mdot
.49927 .61773 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47646 .60805 Mdot
.42513 .58631 Mdot
.26559 .51943 Mdot
.86846 .3726 Mdot
.64693 .48112 Mdot
.61581 .5988 Mdot
.74346 .07889 Mdot
.10964 .22631 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.5042 .00178 Mdot
.51339 .00568 Mdot
.54264 .01808 Mdot
.63508 .05713 Mdot
.90668 .16786 Mdot
.31037 .2495 Mdot
.49231 .11244 Mdot
.66271 .10532 Mdot
.03684 .23122 Mdot
.3562 .19738 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49076 .61412 Mdot
.47058 .60556 Mdot
.40651 .57844 Mdot
.21012 .49666 Mdot
.78246 .35372 Mdot
.58858 .49821 Mdot
.52082 .57616 Mdot
.4842 .5954 Mdot
.42391 .58078 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48723 .61262 Mdot
.45935 .6008 Mdot
.37114 .56352 Mdot
.11009 .45669 Mdot
.69676 .36258 Mdot
.50892 .50195 Mdot
.33447 .51022 Mdot
.95413 .38297 Mdot
.64165 .42491 Mdot
.49873 .6175 Mdot
.49595 .61632 Mdot
.4871 .61257 Mdot
.45893 .60062 Mdot
.36984 .56297 Mdot
.10655 .45531 Mdot
.69511 .36375 Mdot
.50835 .50261 Mdot
.3341 .51034 Mdot
.95368 .38292 Mdot
.64176 .42526 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51714 .00727 Mdot
.55455 .02312 Mdot
.67219 .07271 Mdot
.00059 .20297 Mdot
.32811 .20242 Mdot
.44507 .07229 Mdot
.48126 .02237 Mdot
.4894 .00503 Mdot
.49907 .61764 Mdot
.49705 .61678 Mdot
.49059 .61404 Mdot
.47003 .60533 Mdot
.40477 .5777 Mdot
.20505 .4946 Mdot
.77605 .3529 Mdot
.58259 .49847 Mdot
.50754 .57165 Mdot
.4438 .57864 Mdot
.2975 .52761 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.5056 .00237 Mdot
.51784 .00756 Mdot
.55678 .02407 Mdot
.67909 .07559 Mdot
.01683 .20873 Mdot
.32937 .19316 Mdot
.43226 .06359 Mdot
.43658 .00267 Mdot
.34826 .56345 Mdot
.06527 .44314 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49066 .61407 Mdot
.47024 .60542 Mdot
.40546 .57799 Mdot
.20705 .49541 Mdot
.77855 .35321 Mdot
.58495 .49838 Mdot
.51282 .57345 Mdot
.45988 .58532 Mdot
.34741 .54852 Mdot
.50046 .00019 Mdot
.50145 .00062 Mdot
.50463 .00196 Mdot
.51475 .00625 Mdot
.54696 .01991 Mdot
.6486 .06282 Mdot
.94213 .18141 Mdot
.32057 .23388 Mdot
.48335 .10061 Mdot
.62121 .0852 Mdot
.92382 .18702 Mdot
.33638 .25498 Mdot
.49854 .61742 Mdot
.49535 .61606 Mdot
.4852 .61176 Mdot
.45288 .59806 Mdot
.35091 .55501 Mdot
.0566 .43614 Mdot
.67917 .38477 Mdot
.51722 .51794 Mdot
.38105 .53388 Mdot
.0826 .43358 Mdot
.66574 .3604 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00467 Mdot
.53505 .01486 Mdot
.61124 .04709 Mdot
.84104 .14202 Mdot
.27156 .26608 Mdot
.46555 .11989 Mdot
.60825 .0882 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.5059 .0025 Mdot
.5188 .00797 Mdot
.55983 .02536 Mdot
.6885 .07953 Mdot
.03831 .21619 Mdot
.3312 .18102 Mdot
.41577 .05227 Mdot
.37981 .59581 Mdot
.18022 .49468 Mdot
.76448 .36109 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52329 .00988 Mdot
.57408 .03139 Mdot
.73202 .09761 Mdot
.12716 .24421 Mdot
.35122 .13848 Mdot
.38323 .01978 Mdot
.25537 .53901 Mdot
.88891 .39155 Mdot
.67588 .48637 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50388 .00165 Mdot
.51237 .00525 Mdot
.5394 .0167 Mdot
.62492 .05286 Mdot
.87917 .15713 Mdot
.29775 .2587 Mdot
.48826 .11774 Mdot
.66116 .10686 Mdot
.03657 .23201 Mdot
.3576 .19841 Mdot
.50079 .00033 Mdot
.50251 .00107 Mdot
.50801 .0034 Mdot
.52551 .01082 Mdot
.5811 .03436 Mdot
.75315 .10633 Mdot
.16389 .25385 Mdot
.36999 .12738 Mdot
.40206 .01982 Mdot
.29631 .55268 Mdot
.96186 .41133 Mdot
.68408 .44635 Mdot
.49783 .61711 Mdot
.49308 .6151 Mdot
.47794 .60868 Mdot
.42983 .5883 Mdot
.27984 .52533 Mdot
.8953 .38038 Mdot
.65673 .47059 Mdot
.61705 .59351 Mdot
.73753 .07446 Mdot
.09601 .22156 Mdot
.31906 .13785 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51454 .00616 Mdot
.54628 .01962 Mdot
.64648 .06192 Mdot
.93666 .17934 Mdot
.31936 .23652 Mdot
.48565 .10277 Mdot
.63044 .08949 Mdot
.94972 .19732 Mdot
.34317 .24316 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50199 .00084 Mdot
.50634 .00269 Mdot
.52021 .00857 Mdot
.56432 .02726 Mdot
.7023 .08528 Mdot
.06837 .22625 Mdot
.33501 .16479 Mdot
.39617 .0378 Mdot
.3124 .56626 Mdot
.49818 .61726 Mdot
.49421 .61558 Mdot
.48157 .61022 Mdot
.44134 .59317 Mdot
.31509 .54001 Mdot
.96979 .40463 Mdot
.66954 .43247 Mdot
.57815 .56155 Mdot
.59933 .01309 Mdot
.76002 .09931 Mdot
.15897 .24656 Mdot
.49991 .618 Mdot
.49972 .61792 Mdot
.49912 .61766 Mdot
.49718 .61684 Mdot
.49103 .61423 Mdot
.47142 .60591 Mdot
.40916 .57956 Mdot
.21793 .49984 Mdot
.79279 .35529 Mdot
.59781 .49753 Mdot
.54048 .5826 Mdot
.49967 .61789 Mdot
.49894 .61758 Mdot
.49662 .6166 Mdot
.48924 .61347 Mdot
.46573 .60351 Mdot
.39122 .57198 Mdot
.16596 .47881 Mdot
.73448 .35136 Mdot
.54059 .49821 Mdot
.40694 .53543 Mdot
.14152 .454 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .00181 Mdot
.51357 .00575 Mdot
.5432 .01832 Mdot
.63685 .05788 Mdot
.9114 .16968 Mdot
.31209 .24764 Mdot
.49198 .11118 Mdot
.65986 .10375 Mdot
.0292 .22826 Mdot
.35498 .20134 Mdot
.49956 .61785 Mdot
.49858 .61743 Mdot
.49549 .61612 Mdot
.48562 .61194 Mdot
.45422 .59863 Mdot
.35509 .55677 Mdot
.0674 .44023 Mdot
.68161 .3796 Mdot
.51284 .51373 Mdot
.36332 .52562 Mdot
.03306 .41392 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47984 .60948 Mdot
.43584 .59084 Mdot
.2982 .53297 Mdot
.93269 .39214 Mdot
.66516 .45269 Mdot
.60324 .57977 Mdot
.68555 .05087 Mdot
.98728 .18648 Mdot
.30807 .19826 Mdot
.50031 .00013 Mdot
.50098 .00041 Mdot
.50311 .00132 Mdot
.5099 .0042 Mdot
.53154 .01337 Mdot
.60018 .04242 Mdot
.80935 .12928 Mdot
.24085 .26668 Mdot
.43401 .11938 Mdot
.531 .05994 Mdot
.6742 .0885 Mdot
.02957 .21963 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48769 .61281 Mdot
.4608 .60141 Mdot
.3757 .56544 Mdot
.12252 .46156 Mdot
.70319 .35887 Mdot
.51233 .50008 Mdot
.33996 .5115 Mdot
.966 .38691 Mdot
.49819 .61726 Mdot
.49422 .61558 Mdot
.48159 .61023 Mdot
.44139 .59319 Mdot
.31526 .54008 Mdot
.97018 .40477 Mdot
.66957 .43225 Mdot
.57785 .56135 Mdot
.59831 .01264 Mdot
.75702 .09809 Mdot
.15424 .24549 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00823 Mdot
.56174 .02617 Mdot
.69438 .08198 Mdot
.05132 .2206 Mdot
.33261 .17384 Mdot
.40661 .04573 Mdot
.34842 .58207 Mdot
.0957 .46185 Mdot
.70793 .37838 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47786 .60864 Mdot
.42956 .58818 Mdot
.27901 .52499 Mdot
.89369 .37989 Mdot
.65624 .47128 Mdot
.61727 .59395 Mdot
.73871 .07506 Mdot
.09829 .22223 Mdot
.31963 .13679 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47888 .60908 Mdot
.4328 .58956 Mdot
.28889 .52909 Mdot
.91334 .38593 Mdot
.66145 .46236 Mdot
.61229 .58765 Mdot
.71792 .06529 Mdot
.05745 .20984 Mdot
.31267 .15773 Mdot
.49906 .61763 Mdot
.49699 .61676 Mdot
.49041 .61397 Mdot
.46947 .60509 Mdot
.403 .57695 Mdot
.19987 .49249 Mdot
.76975 .35221 Mdot
.57653 .49862 Mdot
.49373 .56686 Mdot
.40153 .56105 Mdot
.17086 .47547 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50661 .0028 Mdot
.52106 .00893 Mdot
.567 .02839 Mdot
.71049 .08868 Mdot
.0854 .23171 Mdot
.33827 .15628 Mdot
.38819 .03085 Mdot
.28384 .55355 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48977 .6137 Mdot
.46743 .60422 Mdot
.39656 .57424 Mdot
.18123 .48495 Mdot
.74911 .35097 Mdot
.55572 .49851 Mdot
.4442 .54911 Mdot
.25069 .49844 Mdot
.81845 .35089 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50639 .00271 Mdot
.52034 .00863 Mdot
.56473 .02743 Mdot
.70357 .0858 Mdot
.07105 .22711 Mdot
.33546 .16342 Mdot
.39474 .03664 Mdot
.30738 .56405 Mdot
.99665 .42599 Mdot
.69094 .4291 Mdot
.50049 .00021 Mdot
.50158 .00067 Mdot
.50502 .00213 Mdot
.516 .00678 Mdot
.55093 .02159 Mdot
.66096 .068 Mdot
.97333 .19305 Mdot
.32552 .21766 Mdot
.46534 .08642 Mdot
.5536 .05454 Mdot
.72073 .10329 Mdot
.12257 .24835 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50312 .00132 Mdot
.50994 .00422 Mdot
.53167 .01343 Mdot
.60059 .04259 Mdot
.81055 .12976 Mdot
.24217 .26676 Mdot
.43535 .11939 Mdot
.53419 .06109 Mdot
.68394 .09255 Mdot
.05214 .22756 Mdot
.49933 .61775 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47817 .60878 Mdot
.43056 .58861 Mdot
.28207 .52626 Mdot
.89967 .3817 Mdot
.658 .46867 Mdot
.61626 .59224 Mdot
.73382 .07266 Mdot
.08888 .21944 Mdot
.49816 .61725 Mdot
.49413 .61555 Mdot
.48131 .61011 Mdot
.44051 .59282 Mdot
.31253 .53894 Mdot
.964 .40263 Mdot
.66902 .43572 Mdot
.58252 .56457 Mdot
.61432 .01966 Mdot
.80323 .11676 Mdot
.21765 .25612 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51716 .00727 Mdot
.55461 .02315 Mdot
.67238 .07279 Mdot
.00104 .20313 Mdot
.32814 .20216 Mdot
.44472 .07204 Mdot
.48002 .02182 Mdot
.48542 .00334 Mdot
.46899 .60788 Mdot
.50016 7e-05 Mdot
.50053 .00022 Mdot
.50167 .00071 Mdot
.50533 .00226 Mdot
.51699 .00721 Mdot
.5541 .02293 Mdot
.67079 .07212 Mdot
.99726 .20177 Mdot
.32784 .20431 Mdot
.44767 .07406 Mdot
.49041 .02641 Mdot
.51877 .01753 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50528 .00224 Mdot
.51683 .00714 Mdot
.55356 .0227 Mdot
.66914 .07143 Mdot
.99329 .20034 Mdot
.3275 .20656 Mdot
.45074 .07616 Mdot
.50126 .03122 Mdot
.55366 .03239 Mdot
.50018 8e-05 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50598 .00254 Mdot
.51906 .00808 Mdot
.56066 .02571 Mdot
.69106 .08059 Mdot
.044 .21813 Mdot
.33178 .17786 Mdot
.41166 .04937 Mdot
.36573 .58965 Mdot
.14146 .47942 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.5028 .00119 Mdot
.50892 .00378 Mdot
.52842 .01205 Mdot
.59031 .03825 Mdot
.78051 .11755 Mdot
.20507 .26239 Mdot
.40035 .12069 Mdot
.45573 .03423 Mdot
.44556 .61175 Mdot
.35531 .56226 Mdot
.49799 .61718 Mdot
.49358 .61531 Mdot
.47955 .60936 Mdot
.43493 .59046 Mdot
.29541 .5318 Mdot
.92681 .39022 Mdot
.66416 .45571 Mdot
.60637 .58231 Mdot
.6965 .05571 Mdot
.01201 .19499 Mdot
.30952 .18387 Mdot
.49823 .61728 Mdot
.49435 .61564 Mdot
.48199 .6104 Mdot
.44268 .59374 Mdot
.31923 .54174 Mdot
.97928 .40793 Mdot
.67032 .42709 Mdot
.5708 .55653 Mdot
.57402 .00199 Mdot
.6843 .06816 Mdot
.01326 .20331 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50599 .00254 Mdot
.51908 .00809 Mdot
.56073 .02574 Mdot
.69127 .08068 Mdot
.04448 .21829 Mdot
.33183 .17759 Mdot
.41132 .04913 Mdot
.36457 .58914 Mdot
.13831 .4782 Mdot
.72973 .36552 Mdot
.4987 .61748 Mdot
.49585 .61627 Mdot
.48677 .61242 Mdot
.45785 .60017 Mdot
.36646 .56155 Mdot
.09745 .45178 Mdot
.69123 .36697 Mdot
.50764 .50457 Mdot
.33552 .51166 Mdot
.95831 .3849 Mdot
.64292 .42311 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52638 .01118 Mdot
.58386 .03552 Mdot
.76138 .10972 Mdot
.17703 .25688 Mdot
.3786 .12458 Mdot
.41522 .02263 Mdot
.3306 .56574 Mdot
.03722 .43671 Mdot
.68851 .40252 Mdot
.49988 .61798 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49604 .61635 Mdot
.48737 .61268 Mdot
.45979 .60099 Mdot
.37253 .56411 Mdot
.11388 .45817 Mdot
.69861 .36138 Mdot
.50974 .5013 Mdot
.33546 .51032 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60202 Mdot
.38021 .56734 Mdot
.135 .46649 Mdot
.71071 .35581 Mdot
.51792 .49888 Mdot
.35195 .51546 Mdot
.99457 .39716 Mdot
.49788 .61714 Mdot
.49326 .61517 Mdot
.47851 .60892 Mdot
.43164 .58907 Mdot
.28536 .52762 Mdot
.90621 .38371 Mdot
.65974 .46571 Mdot
.61464 .59016 Mdot
.72701 .06945 Mdot
.07563 .21546 Mdot
.31502 .14795 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48031 .60969 Mdot
.43735 .59148 Mdot
.30282 .53489 Mdot
.94259 .3954 Mdot
.66662 .44747 Mdot
.59736 .57523 Mdot
.6652 .04193 Mdot
.93867 .16902 Mdot
.30188 .22448 Mdot
.49943 .61779 Mdot
.49819 .61727 Mdot
.49423 .61559 Mdot
.48163 .61024 Mdot
.44152 .59325 Mdot
.31566 .54025 Mdot
.9711 .40508 Mdot
.66965 .43173 Mdot
.57715 .56087 Mdot
.59591 .01159 Mdot
.74997 .09521 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49073 .6141 Mdot
.47048 .60552 Mdot
.4062 .57831 Mdot
.20923 .4963 Mdot
.78131 .35357 Mdot
.58752 .49827 Mdot
.5185 .57538 Mdot
.47717 .59249 Mdot
.40172 .5714 Mdot
.50046 .00019 Mdot
.50145 .00062 Mdot
.50463 .00197 Mdot
.51477 .00626 Mdot
.54701 .01993 Mdot
.64876 .06288 Mdot
.94256 .18157 Mdot
.32066 .23368 Mdot
.48316 .10044 Mdot
.62047 .08486 Mdot
.9217 .18617 Mdot
.3357 .25587 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51563 .00663 Mdot
.54976 .02109 Mdot
.65731 .06647 Mdot
.96424 .18969 Mdot
.32436 .22257 Mdot
.47134 .09084 Mdot
.57555 .06441 Mdot
.78887 .13184 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47779 .60862 Mdot
.42936 .5881 Mdot
.2784 .52474 Mdot
.8925 .37954 Mdot
.65587 .47178 Mdot
.61741 .59427 Mdot
.73953 .07547 Mdot
.09986 .2227 Mdot
.32004 .13608 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49706 .61679 Mdot
.49062 .61406 Mdot
.47012 .60536 Mdot
.40506 .57782 Mdot
.20587 .49493 Mdot
.77708 .35302 Mdot
.58357 .49844 Mdot
.50972 .5724 Mdot
.45046 .58141 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50798 .00339 Mdot
.52543 .01078 Mdot
.58087 .03426 Mdot
.75245 .10604 Mdot
.16273 .25357 Mdot
.36928 .12765 Mdot
.40107 .01965 Mdot
.29384 .55176 Mdot
.95688 .40978 Mdot
.68381 .44927 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50679 .00288 Mdot
.52163 .00917 Mdot
.56881 .02916 Mdot
.71602 .09098 Mdot
.09655 .23518 Mdot
.34097 .15106 Mdot
.38461 .02697 Mdot
.26994 .54716 Mdot
.9184 .40077 Mdot
.68397 .47315 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50355 .00151 Mdot
.51131 .0048 Mdot
.53602 .01527 Mdot
.61431 .04838 Mdot
.8497 .14548 Mdot
.27849 .26501 Mdot
.47236 .11982 Mdot
.62499 .09433 Mdot
.94642 .19865 Mdot
.34671 .24739 Mdot
.49892 .61758 Mdot
.49657 .61658 Mdot
.48908 .6134 Mdot
.46523 .60329 Mdot
.38962 .57131 Mdot
.16141 .47699 Mdot
.7305 .35172 Mdot
.53654 .49816 Mdot
.3969 .53173 Mdot
.11321 .4427 Mdot
.67367 .34638 Mdot
.49819 .61727 Mdot
.49423 .61559 Mdot
.48161 .61024 Mdot
.44148 .59323 Mdot
.31553 .54019 Mdot
.97079 .40498 Mdot
.66962 .4319 Mdot
.57739 .56103 Mdot
.59671 .01194 Mdot
.75233 .09618 Mdot
.14665 .24371 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.48963 .61364 Mdot
.46696 .60403 Mdot
.3951 .57362 Mdot
.17705 .48327 Mdot
.7449 .35095 Mdot
.55136 .49842 Mdot
.43354 .54522 Mdot
.21891 .48538 Mdot
.77009 .34065 Mdot
.49797 .61717 Mdot
.49352 .61529 Mdot
.47936 .60928 Mdot
.43433 .59021 Mdot
.29358 .53104 Mdot
.92299 .38899 Mdot
.66346 .45764 Mdot
.60823 .5839 Mdot
.70312 .05864 Mdot
.02645 .19983 Mdot
.31029 .17542 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.53111 .01319 Mdot
.59883 .04185 Mdot
.80545 .1277 Mdot
.23645 .26638 Mdot
.42959 .11937 Mdot
.52053 .0562 Mdot
.64218 .07518 Mdot
.94985 .19015 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47929 .60925 Mdot
.43411 .59011 Mdot
.2929 .53076 Mdot
.92158 .38854 Mdot
.66319 .45834 Mdot
.60888 .58447 Mdot
.49837 .61734 Mdot
.49479 .61583 Mdot
.48341 .611 Mdot
.44719 .59565 Mdot
.3332 .54759 Mdot
.01237 .41975 Mdot
.673 .40829 Mdot
.54497 .53891 Mdot
.48349 .58004 Mdot
.39729 .56476 Mdot
.16751 .47602 Mdot
.50074 .00032 Mdot
.50237 .001 Mdot
.50755 .0032 Mdot
.52404 .01019 Mdot
.57644 .03239 Mdot
.73916 .10056 Mdot
.14006 .24777 Mdot
.35695 .13405 Mdot
.38702 .01858 Mdot
.2615 .54046 Mdot
.89786 .3933 Mdot
.67713 .48162 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50545 .00231 Mdot
.51735 .00736 Mdot
.55523 .02341 Mdot
.67431 .0736 Mdot
.00564 .20477 Mdot
.32851 .19954 Mdot
.4411 .06959 Mdot
.46736 .01623 Mdot
.44499 .60421 Mdot
.34175 .55423 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48593 .61207 Mdot
.45519 .59904 Mdot
.35812 .55804 Mdot
.07531 .44325 Mdot
.68371 .37601 Mdot
.51043 .51094 Mdot
.35277 .5206 Mdot
.00445 .40276 Mdot
.64945 .39864 Mdot
.49839 .61735 Mdot
.49488 .61586 Mdot
.4837 .61112 Mdot
.4481 .59604 Mdot
.33603 .54877 Mdot
.01927 .42226 Mdot
.67367 .40444 Mdot
.53987 .53534 Mdot
.46526 .57192 Mdot
.33894 .53997 Mdot
.01022 .41487 Mdot
.49986 .61798 Mdot
.49957 .61785 Mdot
.49862 .61745 Mdot
.49559 .61616 Mdot
.48594 .61207 Mdot
.45524 .59906 Mdot
.35827 .55811 Mdot
.07571 .4434 Mdot
.68382 .37583 Mdot
.51032 .5108 Mdot
.35229 .52036 Mdot
.49945 .6178 Mdot
.49824 .61729 Mdot
.49441 .61566 Mdot
.48218 .61048 Mdot
.44327 .59399 Mdot
.32107 .54251 Mdot
.98354 .40943 Mdot
.67066 .42466 Mdot
.56745 .55425 Mdot
.56242 .61492 Mdot
.64862 .05328 Mdot
.4981 .61723 Mdot
.49396 .61547 Mdot
.48075 .60987 Mdot
.43873 .59207 Mdot
.30706 .53666 Mdot
.95184 .39849 Mdot
.66776 .44246 Mdot
.59125 .57075 Mdot
.64423 .03275 Mdot
.88514 .14889 Mdot
.28377 .24636 Mdot
.49771 .61706 Mdot
.49269 .61494 Mdot
.47672 .60816 Mdot
.42595 .58666 Mdot
.26808 .52046 Mdot
.87302 .37387 Mdot
.64885 .47949 Mdot
.61681 .59823 Mdot
.74466 .07902 Mdot
.11111 .22648 Mdot
.32411 .13164 Mdot
.4978 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42911 .58799 Mdot
.27765 .52443 Mdot
.89106 .37911 Mdot
.65541 .47239 Mdot
.61756 .59464 Mdot
.74044 .07595 Mdot
.10162 .22322 Mdot
.32052 .13529 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.47701 .60828 Mdot
.42687 .58704 Mdot
.27084 .52161 Mdot
.87813 .37532 Mdot
.65088 .47758 Mdot
.61753 .59742 Mdot
.74488 .07871 Mdot
.11084 .22618 Mdot
.32366 .13153 Mdot
.49928 .61773 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47658 .6081 Mdot
.42551 .58647 Mdot
.26673 .5199 Mdot
.87053 .37317 Mdot
.64782 .48039 Mdot
.6163 .59856 Mdot
.74412 .079 Mdot
.11051 .22644 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49848 .61739 Mdot
.49516 .61598 Mdot
.48458 .61149 Mdot
.4509 .59722 Mdot
.34474 .55242 Mdot
.04091 .43026 Mdot
.67639 .39275 Mdot
.52551 .52479 Mdot
.41275 .54834 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.52659 .01127 Mdot
.58452 .0358 Mdot
.76336 .11053 Mdot
.18009 .25755 Mdot
.38075 .12402 Mdot
.41881 .02352 Mdot
.3403 .56951 Mdot
.06045 .44508 Mdot
.6921 .39038 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50662 .00281 Mdot
.52108 .00894 Mdot
.56708 .02843 Mdot
.71075 .08879 Mdot
.08593 .23187 Mdot
.33839 .15602 Mdot
.38798 .03065 Mdot
.28309 .5532 Mdot
.9446 .40884 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.4805 .60977 Mdot
.43795 .59174 Mdot
.30467 .53566 Mdot
.9466 .39674 Mdot
.66714 .44531 Mdot
.59477 .57331 Mdot
.6563 .03803 Mdot
.91638 .16074 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.5357 .01514 Mdot
.6133 .04796 Mdot
.84687 .14435 Mdot
.27629 .2654 Mdot
.47023 .11986 Mdot
.61979 .09243 Mdot
.93254 .19329 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48861 .6132 Mdot
.46373 .60266 Mdot
.38491 .56932 Mdot
.14812 .47169 Mdot
.71986 .35335 Mdot
.52607 .49826 Mdot
.37119 .52232 Mdot
.04353 .41552 Mdot
.65138 .37567 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49087 .61416 Mdot
.47091 .6057 Mdot
.40756 .57888 Mdot
.21322 .49793 Mdot
.7865 .3543 Mdot
.59225 .49798 Mdot
.52877 .5788 Mdot
.5082 .60532 Mdot
.49992 .61292 Mdot
.49858 .61743 Mdot
.49548 .61612 Mdot
.4856 .61193 Mdot
.45415 .5986 Mdot
.35487 .55668 Mdot
.06684 .44002 Mdot
.68147 .37986 Mdot
.51304 .51394 Mdot
.36415 .52602 Mdot
.03535 .41482 Mdot
.65396 .38232 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48722 .61262 Mdot
.45931 .60078 Mdot
.37102 .56347 Mdot
.10975 .45656 Mdot
.6966 .36269 Mdot
.50886 .50201 Mdot
.33441 .51022 Mdot
.95404 .38295 Mdot
.64165 .42497 Mdot
.49828 .61731 Mdot
.49453 .61572 Mdot
.48258 .61065 Mdot
.44456 .59453 Mdot
.32505 .54417 Mdot
.99286 .41273 Mdot
.67138 .41934 Mdot
.56008 .54925 Mdot
.53678 .60363 Mdot
.56817 .0194 Mdot
.69871 .08068 Mdot
.50024 .0001 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50777 .00329 Mdot
.52475 .01049 Mdot
.5787 .03334 Mdot
.74595 .10337 Mdot
.15185 .25086 Mdot
.363 .1305 Mdot
.39309 .0186 Mdot
.27462 .54481 Mdot
.92027 .39903 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50405 .00172 Mdot
.51291 .00547 Mdot
.54111 .01743 Mdot
.63028 .05511 Mdot
.89377 .16285 Mdot
.30504 .25417 Mdot
.4917 .11536 Mdot
.66591 .10767 Mdot
.0463 .23509 Mdot
.35822 .19277 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47715 .60834 Mdot
.4273 .58723 Mdot
.27217 .52215 Mdot
.88061 .37604 Mdot
.65181 .47663 Mdot
.61773 .59697 Mdot
.74457 .07839 Mdot
.11001 .22585 Mdot
.32326 .1318 Mdot
.49854 .61742 Mdot
.49536 .61607 Mdot
.48521 .61176 Mdot
.45291 .59807 Mdot
.35101 .55506 Mdot
.05687 .43624 Mdot
.67923 .38464 Mdot
.5171 .51783 Mdot
.38057 .53365 Mdot
.08123 .43303 Mdot
.66527 .36096 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50536 .00227 Mdot
.51708 .00724 Mdot
.55438 .02305 Mdot
.67167 .07249 Mdot
.99936 .20252 Mdot
.32801 .20312 Mdot
.44604 .07295 Mdot
.48466 .02387 Mdot
.50031 .00967 Mdot
.51643 .00996 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51015 .0043 Mdot
.53232 .0137 Mdot
.60263 .04346 Mdot
.81644 .13214 Mdot
.24848 .26702 Mdot
.4418 .11948 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.52011 .00853 Mdot
.564 .02712 Mdot
.70132 .08487 Mdot
.06629 .22556 Mdot
.33468 .16587 Mdot
.39733 .03872 Mdot
.31644 .56804 Mdot
.01731 .43316 Mdot
.69227 .41715 Mdot
.50041 .00017 Mdot
.50131 .00055 Mdot
.50416 .00177 Mdot
.51326 .00562 Mdot
.54224 .01791 Mdot
.63383 .05661 Mdot
.90333 .16656 Mdot
.30908 .25077 Mdot
.49236 .11327 Mdot
.6642 .1062 Mdot
.0409 .23282 Mdot
.35693 .19531 Mdot
.49961 .61787 Mdot
.49875 .6175 Mdot
.49601 .61634 Mdot
.48729 .61264 Mdot
.45951 .60087 Mdot
.37166 .56374 Mdot
.11149 .45724 Mdot
.69743 .36213 Mdot
.5092 .5017 Mdot
.33477 .51023 Mdot
.95467 .38312 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.4929 .61502 Mdot
.47738 .60844 Mdot
.42804 .58754 Mdot
.2744 .52308 Mdot
.88484 .37727 Mdot
.65333 .47495 Mdot
.61785 .59611 Mdot
.74344 .07762 Mdot
.10755 .22504 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50525 .00223 Mdot
.51673 .00709 Mdot
.55325 .02257 Mdot
.66816 .07102 Mdot
.99093 .19948 Mdot
.3273 .20789 Mdot
.45254 .0774 Mdot
.50764 .03406 Mdot
.57421 .04114 Mdot
.7481 .10747 Mdot
.50027 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.50888 .00377 Mdot
.52829 .012 Mdot
.58992 .03809 Mdot
.77937 .11709 Mdot
.2035 .26212 Mdot
.39901 .12083 Mdot
.453 .03337 Mdot
.43751 .60846 Mdot
.33067 .55201 Mdot
.49924 .61771 Mdot
.49759 .61701 Mdot
.49234 .61478 Mdot
.47558 .60768 Mdot
.42235 .58514 Mdot
.25722 .51598 Mdot
.8536 .36858 Mdot
.6399 .48596 Mdot
.61004 .59958 Mdot
.7324 .07562 Mdot
.09203 .22226 Mdot
.4974 .61693 Mdot
.49171 .61452 Mdot
.47359 .60683 Mdot
.41603 .58246 Mdot
.23828 .50818 Mdot
.82244 .36103 Mdot
.62103 .49356 Mdot
.58417 .59525 Mdot
.66777 .05167 Mdot
.95894 .17995 Mdot
.31102 .2176 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47317 .60666 Mdot
.41472 .58191 Mdot
.23438 .50658 Mdot
.81645 .35974 Mdot
.61675 .49461 Mdot
.57688 .5934 Mdot
.64791 .0439 Mdot
.91021 .16211 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50896 .0038 Mdot
.52854 .0121 Mdot
.5907 .03842 Mdot
.78167 .11802 Mdot
.20666 .26266 Mdot
.40171 .12055 Mdot
.45853 .03512 Mdot
.45385 .61514 Mdot
.3809 .57295 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51239 .00525 Mdot
.53945 .01672 Mdot
.62507 .05292 Mdot
.87957 .15729 Mdot
.29797 .25858 Mdot
.48839 .11769 Mdot
.66142 .10694 Mdot
.03714 .23221 Mdot
.35766 .19809 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.5203 .00861 Mdot
.56459 .02737 Mdot
.70312 .08562 Mdot
.0701 .22681 Mdot
.3353 .1639 Mdot
.39524 .03705 Mdot
.30914 .56482 Mdot
.00061 .42735 Mdot
.50046 .00019 Mdot
.50145 .00062 Mdot
.50462 .00196 Mdot
.51473 .00625 Mdot
.54689 .01988 Mdot
.64839 .06273 Mdot
.94159 .18121 Mdot
.32045 .23415 Mdot
.4836 .10083 Mdot
.62217 .08565 Mdot
.92654 .18811 Mdot
.33722 .25382 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47986 .6095 Mdot
.43592 .59088 Mdot
.29844 .53307 Mdot
.9332 .3923 Mdot
.66524 .45243 Mdot
.60296 .57954 Mdot
.68455 .05043 Mdot
.98498 .18568 Mdot
.49949 .61782 Mdot
.49838 .61735 Mdot
.49485 .61585 Mdot
.48359 .61108 Mdot
.44777 .59589 Mdot
.33499 .54833 Mdot
.01671 .42133 Mdot
.67341 .40586 Mdot
.54174 .53665 Mdot
.47196 .57491 Mdot
.36033 .54904 Mdot
.49942 .61779 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61007 Mdot
.4402 .59269 Mdot
.3116 .53855 Mdot
.96192 .40192 Mdot
.66882 .43689 Mdot
.58406 .56565 Mdot
.6196 .02197 Mdot
.81812 .12269 Mdot
.50003 1e-05 Mdot
.50008 4e-05 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50267 .00113 Mdot
.50851 .00361 Mdot
.52711 .0115 Mdot
.58618 .03651 Mdot
.7683 .11255 Mdot
.18757 .25913 Mdot
.38624 .12279 Mdot
.42844 .02608 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48443 .61143 Mdot
.45043 .59702 Mdot
.34326 .5518 Mdot
.03719 .42887 Mdot
.67584 .39471 Mdot
.52777 .52652 Mdot
.42116 .55214 Mdot
.20106 .48201 Mdot
.75343 .34138 Mdot
.50043 .00018 Mdot
.50135 .00057 Mdot
.50432 .00183 Mdot
.51375 .00583 Mdot
.54378 .01856 Mdot
.63866 .05864 Mdot
.91621 .17153 Mdot
.31371 .24567 Mdot
.49136 .10979 Mdot
.65606 .10179 Mdot
.0191 .22437 Mdot
.35356 .20671 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50247 .00105 Mdot
.50786 .00333 Mdot
.52505 .01062 Mdot
.57965 .03375 Mdot
.7488 .10454 Mdot
.15667 .25208 Mdot
.3657 .12918 Mdot
.39634 .01894 Mdot
.28226 .54753 Mdot
.93433 .403 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46983 .60524 Mdot
.40414 .57744 Mdot
.2032 .49384 Mdot
.77377 .35263 Mdot
.58042 .49854 Mdot
.50262 .56996 Mdot
.42877 .57239 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50812 .00345 Mdot
.52588 .01097 Mdot
.58229 .03486 Mdot
.7567 .10779 Mdot
.16964 .25521 Mdot
.37363 .12608 Mdot
.40737 .02085 Mdot
.30989 .55778 Mdot
.99037 .42056 Mdot
.68529 .42949 Mdot
.50072 .00031 Mdot
.5023 .00097 Mdot
.50732 .00311 Mdot
.52333 .00989 Mdot
.57421 .03144 Mdot
.73241 .09777 Mdot
.12789 .24442 Mdot
.35152 .13821 Mdot
.38337 .01968 Mdot
.2555 .53901 Mdot
.88905 .39155 Mdot
.67587 .48628 Mdot
.49812 .61724 Mdot
.494 .61549 Mdot
.48088 .60993 Mdot
.43916 .59225 Mdot
.30837 .53721 Mdot
.95474 .39947 Mdot
.66808 .44087 Mdot
.58923 .5693 Mdot
.63732 .02972 Mdot
.86677 .14181 Mdot
.27353 .25139 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53634 .01541 Mdot
.61532 .04881 Mdot
.85252 .1466 Mdot
.28062 .26458 Mdot
.47439 .11976 Mdot
.6299 .09611 Mdot
.95933 .2036 Mdot
.49862 .61745 Mdot
.49559 .61616 Mdot
.48595 .61208 Mdot
.45527 .59907 Mdot
.35838 .55815 Mdot
.07601 .44352 Mdot
.68391 .3757 Mdot
.51025 .51071 Mdot
.35194 .5202 Mdot
.00223 .4019 Mdot
.64917 .39983 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00282 Mdot
.52122 .009 Mdot
.56752 .02861 Mdot
.71208 .08935 Mdot
.08864 .23272 Mdot
.339 .15473 Mdot
.387 .02967 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51465 .00621 Mdot
.54664 .01977 Mdot
.64761 .0624 Mdot
.93958 .18045 Mdot
.32002 .23513 Mdot
.48446 .10163 Mdot
.62564 .08725 Mdot
.9363 .192 Mdot
.33998 .24949 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51352 .00573 Mdot
.54306 .01825 Mdot
.6364 .05769 Mdot
.91019 .16921 Mdot
.31166 .24812 Mdot
.4921 .11151 Mdot
.66068 .10419 Mdot
.03137 .2291 Mdot
.35531 .20021 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50374 .00159 Mdot
.51191 .00505 Mdot
.53794 .01609 Mdot
.62035 .05093 Mdot
.86657 .15217 Mdot
.2903 .26188 Mdot
.4829 .11904 Mdot
.64992 .10322 Mdot
.00999 .22254 Mdot
.49819 .61727 Mdot
.49424 .61559 Mdot
.48165 .61025 Mdot
.44161 .59328 Mdot
.31592 .54035 Mdot
.97168 .40529 Mdot
.6697 .4314 Mdot
.5767 .56056 Mdot
.59436 .01091 Mdot
.7454 .09335 Mdot
.13507 .24083 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.5144 .00611 Mdot
.54585 .01944 Mdot
.64511 .06135 Mdot
.93312 .178 Mdot
.31852 .23819 Mdot
.48697 .10411 Mdot
.63591 .09205 Mdot
.96481 .20327 Mdot
.34607 .23563 Mdot
.49953 .61784 Mdot
.49852 .61741 Mdot
.49527 .61603 Mdot
.48495 .61165 Mdot
.45207 .59772 Mdot
.34838 .55395 Mdot
.05014 .43371 Mdot
.67793 .38799 Mdot
.52038 .52067 Mdot
.39332 .53951 Mdot
.11795 .44785 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52145 .00909 Mdot
.56823 .02892 Mdot
.71426 .09025 Mdot
.09302 .23409 Mdot
.34006 .15268 Mdot
.38558 .02813 Mdot
.27389 .549 Mdot
.92615 .40312 Mdot
.68525 .46915 Mdot
.4996 .61786 Mdot
.49872 .61749 Mdot
.49593 .61631 Mdot
.48705 .61254 Mdot
.45875 .60054 Mdot
.36926 .56273 Mdot
.10497 .4547 Mdot
.6944 .36429 Mdot
.50814 .50292 Mdot
.3341 .51047 Mdot
.95388 .38305 Mdot
.49816 .61726 Mdot
.49415 .61555 Mdot
.48136 .61013 Mdot
.44068 .59289 Mdot
.31305 .53916 Mdot
.96519 .40304 Mdot
.66913 .43506 Mdot
.58163 .56396 Mdot
.61128 .01833 Mdot
.79459 .11329 Mdot
.20732 .25508 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50722 .00306 Mdot
.52299 .00975 Mdot
.57311 .03098 Mdot
.72909 .0964 Mdot
.12175 .24267 Mdot
.34908 .1405 Mdot
.38246 .02063 Mdot
.25513 .53934 Mdot
.88919 .39187 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51117 .00474 Mdot
.53558 .01509 Mdot
.61292 .0478 Mdot
.84578 .14392 Mdot
.27543 .26554 Mdot
.46939 .11987 Mdot
.61773 .09167 Mdot
.49748 .61697 Mdot
.49197 .61463 Mdot
.47442 .60719 Mdot
.41867 .58358 Mdot
.24615 .51141 Mdot
.83497 .36391 Mdot
.6293 .49092 Mdot
.59694 .59803 Mdot
.70117 .06442 Mdot
.03298 .20507 Mdot
.31567 .17471 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50437 .00185 Mdot
.51392 .0059 Mdot
.54434 .0188 Mdot
.6404 .05937 Mdot
.9208 .1733 Mdot
.31515 .24372 Mdot
.4905 .10837 Mdot
.65161 .09957 Mdot
.00726 .2198 Mdot
.35203 .21308 Mdot
.498 .61719 Mdot
.49363 .61533 Mdot
.47971 .60943 Mdot
.43544 .59067 Mdot
.29695 .53245 Mdot
.93005 .39128 Mdot
.66473 .45406 Mdot
.60468 .58092 Mdot
.69058 .05309 Mdot
.99877 .19047 Mdot
.3088 .19161 Mdot
.49902 .61762 Mdot
.49686 .6167 Mdot
.49 .61379 Mdot
.46816 .60453 Mdot
.39887 .57521 Mdot
.1879 .48764 Mdot
.75614 .35119 Mdot
.56293 .49863 Mdot
.46167 .55545 Mdot
.30348 .52026 Mdot
.9199 .38097 Mdot
.49875 .6175 Mdot
.49602 .61635 Mdot
.48733 .61266 Mdot
.45967 .60093 Mdot
.37214 .56394 Mdot
.1128 .45775 Mdot
.69807 .36172 Mdot
.50949 .50148 Mdot
.33512 .51027 Mdot
.95535 .38333 Mdot
.64168 .42418 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.4794 .6093 Mdot
.43444 .59025 Mdot
.2939 .53117 Mdot
.92365 .38921 Mdot
.66358 .45731 Mdot
.60792 .58363 Mdot
.702 .05815 Mdot
.02405 .19903 Mdot
.31016 .17683 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50293 .00124 Mdot
.50935 .00396 Mdot
.52978 .01263 Mdot
.59463 .04008 Mdot
.79319 .12272 Mdot
.22176 .26487 Mdot
.41534 .11964 Mdot
.48782 .0448 Mdot
.54206 .03352 Mdot
.65866 .07206 Mdot
.49909 .61765 Mdot
.49711 .61681 Mdot
.49079 .61413 Mdot
.47065 .60559 Mdot
.40674 .57853 Mdot
.21081 .49694 Mdot
.78335 .35385 Mdot
.58939 .49817 Mdot
.5226 .57675 Mdot
.48958 .59763 Mdot
.44093 .58797 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49067 .61408 Mdot
.47028 .60543 Mdot
.40556 .57803 Mdot
.20734 .49553 Mdot
.77891 .35325 Mdot
.58529 .49837 Mdot
.51357 .57371 Mdot
.46219 .58628 Mdot
.35463 .55156 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52518 .01068 Mdot
.58006 .03392 Mdot
.75003 .10505 Mdot
.15873 .25259 Mdot
.36689 .12865 Mdot
.39787 .01914 Mdot
.28594 .54886 Mdot
.94134 .40506 Mdot
.68275 .45822 Mdot
.49794 .61716 Mdot
.49344 .61525 Mdot
.4791 .60917 Mdot
.43351 .58985 Mdot
.29105 .52999 Mdot
.91775 .38732 Mdot
.66241 .46022 Mdot
.61055 .58598 Mdot
.7115 .06239 Mdot
.04424 .20564 Mdot
.31147 .16516 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47817 .60878 Mdot
.43054 .5886 Mdot
.282 .52623 Mdot
.89954 .38166 Mdot
.65796 .46873 Mdot
.61629 .59228 Mdot
.73395 .07272 Mdot
.08912 .21951 Mdot
.31749 .14114 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51668 .00707 Mdot
.5531 .02251 Mdot
.6677 .07082 Mdot
.98981 .19908 Mdot
.3272 .20852 Mdot
.45339 .07799 Mdot
.51068 .0354 Mdot
.58396 .04529 Mdot
.77742 .11956 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48386 .61119 Mdot
.44863 .59626 Mdot
.33767 .54946 Mdot
.0233 .42374 Mdot
.6741 .40222 Mdot
.537 .5333 Mdot
.45491 .5673 Mdot
.30608 .52605 Mdot
.93319 .38757 Mdot
.49924 .61771 Mdot
.49757 .617 Mdot
.49225 .61475 Mdot
.4753 .60756 Mdot
.42145 .58475 Mdot
.2545 .51485 Mdot
.84891 .36737 Mdot
.63742 .48732 Mdot
.60738 .59947 Mdot
.72646 .0736 Mdot
.08167 .21953 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00148 Mdot
.5111 .00471 Mdot
.53535 .01499 Mdot
.6122 .0475 Mdot
.84376 .14311 Mdot
.2738 .26578 Mdot
.46778 .11989 Mdot
.61377 .09022 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50836 .00355 Mdot
.52663 .01129 Mdot
.58467 .03587 Mdot
.76379 .11071 Mdot
.18076 .2577 Mdot
.38123 .1239 Mdot
.41962 .02373 Mdot
.34252 .57038 Mdot
.06589 .44707 Mdot
.49962 .61787 Mdot
.49879 .61752 Mdot
.49613 .61639 Mdot
.48768 .61281 Mdot
.46076 .6014 Mdot
.37559 .56539 Mdot
.12222 .46145 Mdot
.70302 .35895 Mdot
.51223 .50012 Mdot
.33975 .51144 Mdot
.96552 .38674 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57518 .03185 Mdot
.73534 .09898 Mdot
.13321 .2459 Mdot
.3538 .13633 Mdot
.38465 .01907 Mdot
.25723 .53929 Mdot
.89133 .39189 Mdot
.67606 .48499 Mdot
.5002 8e-05 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50631 .00268 Mdot
.52011 .00853 Mdot
.56401 .02713 Mdot
.70134 .08488 Mdot
.06633 .22558 Mdot
.33468 .16585 Mdot
.39731 .0387 Mdot
.31635 .568 Mdot
.01712 .4331 Mdot
.4986 .61744 Mdot
.49553 .61614 Mdot
.48576 .61199 Mdot
.45465 .59881 Mdot
.35644 .55734 Mdot
.07093 .44158 Mdot
.68251 .37798 Mdot
.51168 .51245 Mdot
.35835 .52327 Mdot
.01949 .40861 Mdot
.65147 .39059 Mdot
.49883 .61754 Mdot
.49627 .61645 Mdot
.48811 .61299 Mdot
.46212 .60197 Mdot
.37984 .56719 Mdot
.13398 .46608 Mdot
.71005 .35603 Mdot
.51738 .49896 Mdot
.35072 .51503 Mdot
.99157 .39606 Mdot
.64505 .40388 Mdot
.49899 .61761 Mdot
.49678 .61667 Mdot
.48976 .61369 Mdot
.46737 .6042 Mdot
.39639 .57416 Mdot
.18073 .48475 Mdot
.7486 .35096 Mdot
.55519 .4985 Mdot
.44291 .54864 Mdot
.24683 .49685 Mdot
.81206 .34933 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47855 .60894 Mdot
.43175 .58911 Mdot
.28567 .52776 Mdot
.90684 .3839 Mdot
.6599 .46542 Mdot
.61446 .58995 Mdot
.72627 .06911 Mdot
.07417 .21501 Mdot
.3148 .14871 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48467 .61154 Mdot
.45121 .59735 Mdot
.34569 .55282 Mdot
.0433 .43115 Mdot
.67676 .3915 Mdot
.52412 .52369 Mdot
.40751 .54597 Mdot
.15984 .46497 Mdot
.71073 .34047 Mdot
.50003 1e-05 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00115 Mdot
.50862 .00365 Mdot
.52745 .01164 Mdot
.58726 .03696 Mdot
.7715 .11386 Mdot
.19229 .26007 Mdot
.38988 .12211 Mdot
.43514 .02798 Mdot
.49836 .61734 Mdot
.49478 .61582 Mdot
.48338 .61099 Mdot
.44709 .59561 Mdot
.3329 .54746 Mdot
.01163 .41948 Mdot
.67293 .40871 Mdot
.54552 .53929 Mdot
.48547 .58092 Mdot
.40366 .56747 Mdot
.186 .48351 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50477 .00202 Mdot
.51521 .00645 Mdot
.54842 .02053 Mdot
.65316 .06473 Mdot
.95377 .18579 Mdot
.32276 .22805 Mdot
.47753 .09565 Mdot
.5987 .07489 Mdot
.85862 .16064 Mdot
.3038 .27513 Mdot
.50074 .00031 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.524 .01018 Mdot
.57634 .03235 Mdot
.73886 .10044 Mdot
.13953 .24762 Mdot
.3567 .13422 Mdot
.38681 .01861 Mdot
.26108 .54033 Mdot
.8972 .39314 Mdot
.67702 .48196 Mdot
.49949 .61782 Mdot
.49836 .61734 Mdot
.49479 .61582 Mdot
.48339 .61099 Mdot
.44713 .59562 Mdot
.333 .5475 Mdot
.01188 .41957 Mdot
.67296 .40857 Mdot
.54533 .53916 Mdot
.48479 .58062 Mdot
.40147 .56654 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50709 .00301 Mdot
.52258 .00957 Mdot
.57182 .03043 Mdot
.72518 .09478 Mdot
.11437 .24053 Mdot
.3464 .1434 Mdot
.38215 .0221 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.42751 .58732 Mdot
.2728 .52242 Mdot
.8818 .37638 Mdot
.65225 .47616 Mdot
.61779 .59674 Mdot
.74433 .0782 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52125 .00901 Mdot
.56762 .02866 Mdot
.7124 .08948 Mdot
.08928 .23292 Mdot
.33915 .15443 Mdot
.38678 .02944 Mdot
.27854 .55114 Mdot
.93541 .40596 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49627 .61645 Mdot
.48813 .613 Mdot
.46219 .602 Mdot
.38007 .56728 Mdot
.13459 .46632 Mdot
.71045 .3559 Mdot
.5177 .49891 Mdot
.35145 .51529 Mdot
.99336 .39672 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48385 .61118 Mdot
.44858 .59624 Mdot
.3375 .54939 Mdot
.02288 .42359 Mdot
.67405 .40245 Mdot
.5373 .53351 Mdot
.45597 .56777 Mdot
.30945 .52748 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49292 .61503 Mdot
.47745 .60847 Mdot
.42827 .58764 Mdot
.2751 .52337 Mdot
.88616 .37766 Mdot
.65379 .47442 Mdot
.61784 .59582 Mdot
.74293 .07731 Mdot
.10652 .22471 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50523 .00222 Mdot
.51666 .00706 Mdot
.55303 .02248 Mdot
.66748 .07074 Mdot
.9893 .19889 Mdot
.32715 .20881 Mdot
.45378 .07826 Mdot
.51205 .03601 Mdot
.58839 .04718 Mdot
.79059 .12497 Mdot
.4986 .61744 Mdot
.49552 .61614 Mdot
.48574 .61199 Mdot
.4546 .59879 Mdot
.35628 .55727 Mdot
.07052 .44142 Mdot
.6824 .37817 Mdot
.51181 .5126 Mdot
.35891 .52354 Mdot
.02102 .40921 Mdot
.65169 .38978 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47602 .60787 Mdot
.42373 .58572 Mdot
.26137 .51769 Mdot
.86088 .37052 Mdot
.64349 .48368 Mdot
.61335 .59941 Mdot
.73923 .07779 Mdot
.10328 .225 Mdot
.32306 .13583 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50581 .00246 Mdot
.5185 .00784 Mdot
.55887 .02495 Mdot
.68554 .07829 Mdot
.03163 .2139 Mdot
.33059 .18477 Mdot
.42077 .05573 Mdot
.39695 .60331 Mdot
.22913 .51432 Mdot
.82463 .36804 Mdot
.49819 .61727 Mdot
.49423 .61559 Mdot
.48163 .61025 Mdot
.44154 .59325 Mdot
.31571 .54027 Mdot
.9712 .40512 Mdot
.66966 .43167 Mdot
.57707 .56081 Mdot
.59562 .01146 Mdot
.74913 .09487 Mdot
.14136 .24241 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.50511 .00217 Mdot
.51628 .0069 Mdot
.55182 .02197 Mdot
.66372 .06916 Mdot
.98012 .19555 Mdot
.32626 .21393 Mdot
.46056 .083 Mdot
.53632 .04682 Mdot
.66607 .08019 Mdot
.00213 .20769 Mdot
.49794 .61716 Mdot
.49342 .61524 Mdot
.47905 .60915 Mdot
.43333 .58978 Mdot
.29051 .52977 Mdot
.91665 .38697 Mdot
.66218 .46076 Mdot
.611 .58641 Mdot
.71316 .06314 Mdot
.04769 .20675 Mdot
.31175 .1632 Mdot
.49857 .61743 Mdot
.49545 .61611 Mdot
.48552 .61189 Mdot
.45388 .59848 Mdot
.35403 .55632 Mdot
.06465 .43919 Mdot
.68094 .38089 Mdot
.51384 .51476 Mdot
.36748 .52758 Mdot
.04453 .41844 Mdot
.65565 .37769 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50707 .003 Mdot
.52254 .00956 Mdot
.5717 .03038 Mdot
.7248 .09462 Mdot
.11364 .24032 Mdot
.34614 .1437 Mdot
.38217 .02226 Mdot
.25715 .54077 Mdot
.89364 .39337 Mdot
.67806 .4848 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51526 .00647 Mdot
.5486 .0206 Mdot
.6537 .06496 Mdot
.95516 .18631 Mdot
.32299 .22733 Mdot
.47676 .09503 Mdot
.59578 .07356 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00212 Mdot
.51596 .00677 Mdot
.5508 .02153 Mdot
.66055 .06783 Mdot
.97231 .19268 Mdot
.3254 .21822 Mdot
.46604 .08692 Mdot
.55613 .05568 Mdot
.72867 .10664 Mdot
.1378 .25286 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43732 .59147 Mdot
.30273 .53485 Mdot
.94239 .39533 Mdot
.66659 .44758 Mdot
.59748 .57532 Mdot
.66563 .04212 Mdot
.93974 .16941 Mdot
.3021 .22395 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.5112 .00475 Mdot
.53567 .01512 Mdot
.61319 .04791 Mdot
.84653 .14421 Mdot
.27603 .26544 Mdot
.46997 .11987 Mdot
.61915 .0922 Mdot
.93083 .19262 Mdot
.34302 .25475 Mdot
.49744 .61695 Mdot
.49184 .61457 Mdot
.47399 .60701 Mdot
.41731 .583 Mdot
.24209 .50974 Mdot
.82843 .36238 Mdot
.6251 .49237 Mdot
.59069 .59677 Mdot
.68507 .05833 Mdot
.99859 .19377 Mdot
.31422 .19507 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.50591 .00251 Mdot
.51883 .00798 Mdot
.55991 .02539 Mdot
.68877 .07964 Mdot
.0389 .21639 Mdot
.33126 .18069 Mdot
.41534 .05196 Mdot
.37834 .59516 Mdot
.1761 .49304 Mdot
.49919 .61769 Mdot
.49741 .61694 Mdot
.49176 .61454 Mdot
.47375 .60691 Mdot
.41656 .58268 Mdot
.23985 .50882 Mdot
.82489 .36158 Mdot
.62272 .49309 Mdot
.58693 .59591 Mdot
.67514 .05452 Mdot
.97615 .18604 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50435 .00184 Mdot
.51386 .00588 Mdot
.54413 .01871 Mdot
.63974 .05909 Mdot
.91906 .17263 Mdot
.31462 .24447 Mdot
.49086 .10892 Mdot
.65339 .10045 Mdot
.01199 .22163 Mdot
.35263 .21052 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50184 .00078 Mdot
.50587 .00249 Mdot
.51869 .00793 Mdot
.5595 .02522 Mdot
.68749 .0791 Mdot
.03603 .21541 Mdot
.33099 .18229 Mdot
.41746 .05344 Mdot
.38559 .59834 Mdot
.19651 .50117 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47854 .60894 Mdot
.43174 .58911 Mdot
.28565 .52775 Mdot
.9068 .38389 Mdot
.65989 .46544 Mdot
.61447 .58996 Mdot
.72632 .06913 Mdot
.07427 .21505 Mdot
.31481 .14866 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.50649 .00275 Mdot
.52067 .00877 Mdot
.56578 .02788 Mdot
.70676 .08713 Mdot
.07772 .22927 Mdot
.33668 .16004 Mdot
.39144 .03384 Mdot
.2957 .55886 Mdot
.971 .41736 Mdot
.68956 .4441 Mdot
.49808 .61722 Mdot
.49389 .61544 Mdot
.48052 .60977 Mdot
.43801 .59176 Mdot
.30484 .53573 Mdot
.94698 .39686 Mdot
.66718 .44511 Mdot
.59453 .57313 Mdot
.65546 .03766 Mdot
.91425 .15994 Mdot
.29552 .23564 Mdot
.49832 .61732 Mdot
.49464 .61576 Mdot
.48293 .61079 Mdot
.44565 .595 Mdot
.32843 .54559 Mdot
.00088 .4156 Mdot
.67201 .41478 Mdot
.55378 .54496 Mdot
.5147 .59388 Mdot
.49763 .60748 Mdot
.477 .60528 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50323 .00137 Mdot
.51028 .00436 Mdot
.53275 .01388 Mdot
.60398 .04403 Mdot
.82034 .13371 Mdot
.25248 .26708 Mdot
.44593 .11956 Mdot
.55982 .07039 Mdot
.76134 .12455 Mdot
.20099 .27172 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00467 Mdot
.53504 .01486 Mdot
.61123 .04708 Mdot
.841 .14201 Mdot
.27153 .26608 Mdot
.46552 .11989 Mdot
.60818 .08817 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46983 .60524 Mdot
.40414 .57744 Mdot
.2032 .49385 Mdot
.77378 .35264 Mdot
.58043 .49854 Mdot
.50265 .56996 Mdot
.42885 .57242 Mdot
.25183 .50863 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50749 .00317 Mdot
.52385 .01011 Mdot
.57585 .03214 Mdot
.73737 .09982 Mdot
.13687 .2469 Mdot
.35545 .13509 Mdot
.38581 .01876 Mdot
.25922 .53979 Mdot
.89429 .3925 Mdot
.67652 .48345 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.5076 .00322 Mdot
.5242 .01026 Mdot
.57697 .03261 Mdot
.74074 .10122 Mdot
.14284 .24851 Mdot
.35831 .13317 Mdot
.38822 .01849 Mdot
.26392 .54121 Mdot
.90179 .39423 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.50291 .00123 Mdot
.50926 .00392 Mdot
.52948 .0125 Mdot
.59368 .03968 Mdot
.79042 .12159 Mdot
.21823 .2644 Mdot
.41205 .11979 Mdot
.48057 .04234 Mdot
.52001 .02437 Mdot
.58938 .04287 Mdot
.49825 .61729 Mdot
.49442 .61567 Mdot
.48223 .6105 Mdot
.44344 .59406 Mdot
.32158 .54272 Mdot
.98473 .40985 Mdot
.67075 .42399 Mdot
.56651 .55361 Mdot
.55917 .6135 Mdot
.63856 .04906 Mdot
.9005 .16189 Mdot
.49812 .61724 Mdot
.49401 .61549 Mdot
.48091 .60994 Mdot
.43924 .59228 Mdot
.30863 .53731 Mdot
.95529 .39966 Mdot
.66814 .44057 Mdot
.58884 .56902 Mdot
.63598 .02913 Mdot
.86317 .14041 Mdot
.27124 .2522 Mdot
.50006 2e-05 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00255 Mdot
.51913 .00811 Mdot
.56087 .0258 Mdot
.69171 .08086 Mdot
.04546 .21862 Mdot
.33194 .17706 Mdot
.41063 .04864 Mdot
.36221 .58811 Mdot
.49971 .61791 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49067 .61408 Mdot
.47028 .60543 Mdot
.40558 .57805 Mdot
.20741 .49556 Mdot
.77901 .35327 Mdot
.58538 .49837 Mdot
.51377 .57378 Mdot
.4628 .58653 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48636 .61225 Mdot
.45656 .59962 Mdot
.3624 .55984 Mdot
.0866 .44758 Mdot
.68722 .3712 Mdot
.50824 .50742 Mdot
.34161 .51505 Mdot
.97472 .39128 Mdot
.64559 .41462 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50607 .00257 Mdot
.51934 .0082 Mdot
.56155 .02609 Mdot
.69381 .08174 Mdot
.05008 .22018 Mdot
.33246 .17452 Mdot
.40745 .04634 Mdot
.35129 .58333 Mdot
.10314 .46467 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50395 .00168 Mdot
.5126 .00534 Mdot
.54011 .01701 Mdot
.62716 .0538 Mdot
.8853 .15954 Mdot
.30098 .2569 Mdot
.49006 .11686 Mdot
.66425 .10765 Mdot
.04334 .23429 Mdot
.35823 .19461 Mdot
.49902 .61762 Mdot
.49689 .61672 Mdot
.4901 .61384 Mdot
.46847 .60467 Mdot
.39986 .57563 Mdot
.19075 .4888 Mdot
.75926 .35136 Mdot
.5661 .49865 Mdot
.46927 .55819 Mdot
.32663 .52988 Mdot
.97239 .3991 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50183 .00077 Mdot
.50582 .00247 Mdot
.51854 .00786 Mdot
.55902 .02501 Mdot
.686 .07848 Mdot
.03267 .21425 Mdot
.33068 .18418 Mdot
.41998 .05519 Mdot
.39425 .60213 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51726 .00732 Mdot
.55493 .02328 Mdot
.67337 .0732 Mdot
.0034 .20397 Mdot
.32833 .20082 Mdot
.44286 .07078 Mdot
.47352 .01895 Mdot
.46464 .61254 Mdot
.49803 .6172 Mdot
.49373 .61537 Mdot
.48002 .60956 Mdot
.43642 .59109 Mdot
.29997 .5337 Mdot
.93646 .39337 Mdot
.66575 .45073 Mdot
.60109 .57807 Mdot
.67808 .04758 Mdot
.96983 .18031 Mdot
.30657 .20811 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.52501 .0106 Mdot
.57951 .03369 Mdot
.7484 .10437 Mdot
.156 .25191 Mdot
.36531 .12936 Mdot
.39586 .01888 Mdot
.2811 .54711 Mdot
.93216 .40237 Mdot
.68192 .46338 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.50459 .00195 Mdot
.51464 .00621 Mdot
.5466 .01976 Mdot
.64748 .06234 Mdot
.93924 .18032 Mdot
.31995 .23529 Mdot
.48461 .10177 Mdot
.62621 .08752 Mdot
.9379 .19264 Mdot
.3404 .24876 Mdot
.50081 .00034 Mdot
.50258 .0011 Mdot
.50823 .00349 Mdot
.52621 .01111 Mdot
.58334 .0353 Mdot
.75983 .10908 Mdot
.1746 .25634 Mdot
.37693 .12505 Mdot
.41251 .02199 Mdot
.32338 .56294 Mdot
.02043 .4308 Mdot
.68692 .41192 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.47481 .60735 Mdot
.41991 .5841 Mdot
.24987 .51294 Mdot
.8411 .3654 Mdot
.63301 .48943 Mdot
.602 .59887 Mdot
.71374 .06906 Mdot
.05805 .21279 Mdot
.3172 .16016 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47767 .60857 Mdot
.42896 .58793 Mdot
.2772 .52424 Mdot
.89019 .37885 Mdot
.65513 .47276 Mdot
.61763 .59486 Mdot
.74095 .07622 Mdot
.10262 .22352 Mdot
.3208 .13484 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52373 .01006 Mdot
.57548 .03198 Mdot
.73625 .09936 Mdot
.13487 .24636 Mdot
.35454 .13576 Mdot
.38515 .01892 Mdot
.25805 .53948 Mdot
.89252 .39213 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50522 .00221 Mdot
.51662 .00705 Mdot
.55291 .02243 Mdot
.66712 .07058 Mdot
.98842 .19857 Mdot
.32707 .2093 Mdot
.45444 .07872 Mdot
.51441 .03706 Mdot
.59597 .0504 Mdot
.8129 .13408 Mdot
.49913 .61767 Mdot
.49724 .61686 Mdot
.4912 .6143 Mdot
.47195 .60614 Mdot
.41086 .58028 Mdot
.22293 .50189 Mdot
.79972 .35647 Mdot
.60368 .49688 Mdot
.5524 .58634 Mdot
.57831 .01601 Mdot
.71699 .08571 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50325 .00138 Mdot
.51036 .00439 Mdot
.53299 .01399 Mdot
.60476 .04436 Mdot
.82258 .13462 Mdot
.25473 .26708 Mdot
.44825 .1196 Mdot
.56551 .07247 Mdot
.77827 .13149 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49025 .6139 Mdot
.46895 .60487 Mdot
.40138 .57627 Mdot
.19517 .49059 Mdot
.76425 .35171 Mdot
.57111 .49867 Mdot
.48112 .56242 Mdot
.36286 .54495 Mdot
.06344 .43298 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.5061 .00259 Mdot
.51944 .00824 Mdot
.56186 .02622 Mdot
.69474 .08213 Mdot
.05211 .22087 Mdot
.3327 .17341 Mdot
.40608 .04535 Mdot
.3466 .58128 Mdot
.09104 .46009 Mdot
.70624 .38022 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00137 Mdot
.51027 .00435 Mdot
.5327 .01386 Mdot
.60384 .04397 Mdot
.81992 .13355 Mdot
.25207 .26708 Mdot
.4455 .11955 Mdot
.55877 .07 Mdot
.75819 .12325 Mdot
.19604 .2706 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.50649 .00275 Mdot
.52066 .00876 Mdot
.56574 .02786 Mdot
.70666 .08709 Mdot
.07752 .2292 Mdot
.33664 .16014 Mdot
.39153 .03393 Mdot
.29604 .55901 Mdot
.97172 .4176 Mdot
.6896 .44367 Mdot
.49816 .61726 Mdot
.49415 .61555 Mdot
.48136 .61013 Mdot
.44067 .59289 Mdot
.31302 .53914 Mdot
.96511 .40302 Mdot
.66912 .4351 Mdot
.58169 .564 Mdot
.61147 .01841 Mdot
.79513 .11351 Mdot
.20799 .25516 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50372 .00158 Mdot
.51186 .00503 Mdot
.53778 .01602 Mdot
.61985 .05072 Mdot
.86517 .15162 Mdot
.2894 .26219 Mdot
.48217 .11914 Mdot
.64826 .10265 Mdot
.00594 .22106 Mdot
.35471 .21555 Mdot
.4982 .61727 Mdot
.49426 .6156 Mdot
.48172 .61028 Mdot
.4418 .59337 Mdot
.31653 .54061 Mdot
.97307 .40577 Mdot
.66982 .43061 Mdot
.57563 .55983 Mdot
.59068 .0093 Mdot
.7345 .08889 Mdot
.11592 .23573 Mdot
.4997 .61791 Mdot
.49903 .61762 Mdot
.49692 .61673 Mdot
.4902 .61388 Mdot
.46878 .6048 Mdot
.40083 .57604 Mdot
.19357 .48994 Mdot
.76243 .35157 Mdot
.56929 .49867 Mdot
.47684 .56089 Mdot
.34976 .5395 Mdot
.50067 .00028 Mdot
.50213 .00091 Mdot
.5068 .00288 Mdot
.52167 .00919 Mdot
.56893 .02921 Mdot
.71638 .09113 Mdot
.09726 .23539 Mdot
.34116 .15074 Mdot
.38443 .02674 Mdot
.2692 .54681 Mdot
.91696 .40034 Mdot
.68371 .47388 Mdot
.49794 .61716 Mdot
.49345 .61526 Mdot
.47913 .60918 Mdot
.43358 .58989 Mdot
.29129 .53009 Mdot
.91824 .38748 Mdot
.66251 .45998 Mdot
.61034 .58579 Mdot
.71075 .06205 Mdot
.04266 .20513 Mdot
.31135 .16605 Mdot
.49958 .61786 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.48657 .61234 Mdot
.45725 .59991 Mdot
.36457 .56075 Mdot
.09238 .44981 Mdot
.68928 .3689 Mdot
.50773 .50583 Mdot
.33778 .513 Mdot
.9645 .38733 Mdot
.49804 .6172 Mdot
.49377 .61539 Mdot
.48016 .60962 Mdot
.43685 .59127 Mdot
.30129 .53425 Mdot
.93928 .3943 Mdot
.66616 .44924 Mdot
.59941 .57678 Mdot
.67226 .04503 Mdot
.95593 .17532 Mdot
.30486 .21565 Mdot
.49933 .61775 Mdot
.49786 .61713 Mdot
.49317 .61514 Mdot
.47825 .60881 Mdot
.4308 .58871 Mdot
.28279 .52656 Mdot
.9011 .38214 Mdot
.65839 .46803 Mdot
.61595 .5918 Mdot
.73246 .072 Mdot
.08624 .21865 Mdot
.50001 0 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51218 .00516 Mdot
.53879 .01644 Mdot
.623 .05205 Mdot
.8739 .15506 Mdot
.29477 .26011 Mdot
.48628 .11836 Mdot
.49893 .61758 Mdot
.49658 .61658 Mdot
.4891 .61341 Mdot
.46528 .60331 Mdot
.3898 .57138 Mdot
.16191 .47719 Mdot
.73093 .35168 Mdot
.53697 .49816 Mdot
.39798 .53213 Mdot
.11623 .4439 Mdot
.67522 .34548 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.44212 .5935 Mdot
.31749 .54101 Mdot
.97529 .40654 Mdot
.67 .42936 Mdot
.57392 .55865 Mdot
.58476 .0067 Mdot
.71683 .08162 Mdot
.08246 .22597 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.5052 .00221 Mdot
.51658 .00703 Mdot
.55278 .02237 Mdot
.66672 .07042 Mdot
.98744 .19822 Mdot
.32698 .20985 Mdot
.45518 .07923 Mdot
.51702 .03822 Mdot
.60434 .05397 Mdot
.50003 1e-05 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.50841 .00357 Mdot
.52678 .01136 Mdot
.58515 .03607 Mdot
.76523 .1113 Mdot
.18295 .25817 Mdot
.38281 .12352 Mdot
.42235 .02444 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48762 .61279 Mdot
.46058 .60132 Mdot
.37503 .56516 Mdot
.12069 .46084 Mdot
.70217 .35938 Mdot
.5117 .50031 Mdot
.33875 .51114 Mdot
.96322 .38595 Mdot
.64238 .41974 Mdot
.49778 .61709 Mdot
.49293 .61504 Mdot
.47748 .60849 Mdot
.42836 .58768 Mdot
.27538 .52349 Mdot
.8867 .37781 Mdot
.65397 .4742 Mdot
.61782 .59569 Mdot
.7427 .07718 Mdot
.10607 .22457 Mdot
.32185 .13336 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52442 .01035 Mdot
.57766 .0329 Mdot
.74282 .10207 Mdot
.14647 .24947 Mdot
.36014 .13206 Mdot
.39 .01845 Mdot
.26769 .54244 Mdot
.90811 .3958 Mdot
.67884 .47634 Mdot
.50034 .00014 Mdot
.50107 .00045 Mdot
.50341 .00145 Mdot
.51087 .00461 Mdot
.53463 .01468 Mdot
.60994 .04654 Mdot
.83734 .14054 Mdot
.26842 .26642 Mdot
.46237 .11987 Mdot
.60039 .0853 Mdot
.87922 .17232 Mdot
.32232 .27385 Mdot
.50071 .0003 Mdot
.50228 .00096 Mdot
.50725 .00307 Mdot
.52309 .00979 Mdot
.57346 .03113 Mdot
.73013 .09683 Mdot
.12368 .24323 Mdot
.34983 .13976 Mdot
.38268 .0203 Mdot
.25506 .53916 Mdot
.88884 .39169 Mdot
.67612 .48657 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50285 .00121 Mdot
.50909 .00385 Mdot
.52894 .01227 Mdot
.59197 .03895 Mdot
.7854 .11955 Mdot
.21169 .26346 Mdot
.40612 .12017 Mdot
.46776 .0381 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.5075 .00318 Mdot
.5239 .01013 Mdot
.576 .0322 Mdot
.73783 .10002 Mdot
.1377 .24713 Mdot
.35584 .13482 Mdot
.38611 .01871 Mdot
.25976 .53995 Mdot
.89513 .39268 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.5181 .00768 Mdot
.55762 .02442 Mdot
.68169 .07668 Mdot
.02284 .21084 Mdot
.32985 .18974 Mdot
.42754 .06038 Mdot
.42027 .61354 Mdot
.29834 .54268 Mdot
.9486 .40188 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48616 .61217 Mdot
.45594 .59935 Mdot
.36045 .55902 Mdot
.08146 .44561 Mdot
.68554 .37334 Mdot
.50904 .50895 Mdot
.3461 .51733 Mdot
.98665 .39588 Mdot
.6472 .40824 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52198 .00932 Mdot
.56992 .02963 Mdot
.71941 .09239 Mdot
.10324 .23722 Mdot
.34284 .14808 Mdot
.38319 .02494 Mdot
.26363 .54414 Mdot
.90622 .39714 Mdot
.49995 .61801 Mdot
.49984 .61796 Mdot
.49948 .61781 Mdot
.49833 .61733 Mdot
.49469 .61578 Mdot
.48309 .61086 Mdot
.44617 .59522 Mdot
.33003 .54626 Mdot
.00472 .41698 Mdot
.67233 .4126 Mdot
.5508 .54292 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47957 .60937 Mdot
.435 .59049 Mdot
.29563 .53189 Mdot
.92726 .39037 Mdot
.66424 .45548 Mdot
.60614 .58212 Mdot
.69569 .05535 Mdot
.01022 .19439 Mdot
.30943 .18492 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47778 .60861 Mdot
.42932 .58808 Mdot
.27828 .52469 Mdot
.89228 .37947 Mdot
.6558 .47188 Mdot
.61744 .59433 Mdot
.73968 .07555 Mdot
.10014 .22278 Mdot
.32012 .13595 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.48331 .61096 Mdot
.44686 .59551 Mdot
.33218 .54716 Mdot
.0099 .41885 Mdot
.67278 .40968 Mdot
.54683 .54019 Mdot
.49011 .58298 Mdot
.41858 .57382 Mdot
.23018 .5016 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51427 .00605 Mdot
.54543 .01926 Mdot
.64381 .0608 Mdot
.92973 .17671 Mdot
.31766 .23976 Mdot
.48812 .10535 Mdot
.64076 .09434 Mdot
.97808 .20847 Mdot
.49742 .61694 Mdot
.49177 .61454 Mdot
.47378 .60692 Mdot
.41665 .58272 Mdot
.24013 .50894 Mdot
.82534 .36168 Mdot
.62303 .493 Mdot
.58742 .59603 Mdot
.67644 .05502 Mdot
.97914 .18708 Mdot
.31304 .20637 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50272 .00115 Mdot
.50866 .00367 Mdot
.52759 .0117 Mdot
.5877 .03715 Mdot
.77279 .11439 Mdot
.19417 .26043 Mdot
.39136 .12187 Mdot
.43795 .02879 Mdot
.39381 .59075 Mdot
.20194 .49945 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47649 .60806 Mdot
.42522 .58635 Mdot
.26586 .51954 Mdot
.86894 .37273 Mdot
.64714 .48095 Mdot
.61593 .59874 Mdot
.74363 .07892 Mdot
.10987 .22635 Mdot
.32409 .13239 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48464 .61152 Mdot
.45109 .5973 Mdot
.34532 .55267 Mdot
.04238 .4308 Mdot
.67661 .39198 Mdot
.52465 .52412 Mdot
.40952 .54688 Mdot
.16586 .46745 Mdot
.71606 .34004 Mdot
.5 0 Mdot
.50001 0 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.50729 .00309 Mdot
.52323 .00985 Mdot
.57389 .03131 Mdot
.73146 .09738 Mdot
.12614 .24392 Mdot
.4993 .61774 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47736 .60843 Mdot
.42798 .58752 Mdot
.27422 .52301 Mdot
.88449 .37717 Mdot
.65321 .47509 Mdot
.61785 .59618 Mdot
.74356 .07769 Mdot
.1078 .22511 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.5067 .00284 Mdot
.52134 .00905 Mdot
.56789 .02877 Mdot
.71322 .08982 Mdot
.09093 .23344 Mdot
.33955 .15365 Mdot
.38623 .02885 Mdot
.27644 .55017 Mdot
.93119 .40466 Mdot
.68597 .46648 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.5061 .00259 Mdot
.51944 .00824 Mdot
.56186 .02622 Mdot
.69474 .08213 Mdot
.05212 .22087 Mdot
.33271 .17341 Mdot
.40607 .04534 Mdot
.34659 .58127 Mdot
.09101 .46008 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.52591 .01098 Mdot
.58237 .0349 Mdot
.75694 .10789 Mdot
.17002 .2553 Mdot
.37388 .12599 Mdot
.40775 .02093 Mdot
.31086 .55815 Mdot
.99247 .42126 Mdot
.68538 .42824 Mdot
.49789 .61714 Mdot
.49328 .61519 Mdot
.4786 .60896 Mdot
.43193 .58919 Mdot
.28622 .52798 Mdot
.90794 .38424 Mdot
.66018 .46491 Mdot
.61412 .58957 Mdot
.72495 .0685 Mdot
.07156 .21422 Mdot
.31441 .15009 Mdot
.50053 .00023 Mdot
.50169 .00072 Mdot
.5054 .00229 Mdot
.51719 .00729 Mdot
.55473 .0232 Mdot
.67276 .07294 Mdot
.00194 .20345 Mdot
.32822 .20165 Mdot
.44401 .07156 Mdot
.47754 .02072 Mdot
.47749 .618 Mdot
.4438 .59721 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.52659 .01127 Mdot
.58452 .03581 Mdot
.76337 .11053 Mdot
.18011 .25756 Mdot
.38077 .12401 Mdot
.41884 .02353 Mdot
.34037 .56954 Mdot
.06064 .44515 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48837 .6131 Mdot
.46295 .60233 Mdot
.38247 .56829 Mdot
.1413 .46898 Mdot
.71494 .35453 Mdot
.52154 .49851 Mdot
.36036 .51842 Mdot
.01558 .40495 Mdot
.64747 .39052 Mdot
.49824 .61729 Mdot
.4944 .61566 Mdot
.48217 .61048 Mdot
.44326 .59398 Mdot
.32103 .54249 Mdot
.98346 .4094 Mdot
.67065 .42471 Mdot
.56751 .55429 Mdot
.56264 .61502 Mdot
.64931 .05356 Mdot
.9285 .17255 Mdot
.49898 .6176 Mdot
.49675 .61665 Mdot
.48963 .61364 Mdot
.46697 .60403 Mdot
.39513 .57363 Mdot
.17713 .4833 Mdot
.74498 .35095 Mdot
.55145 .49842 Mdot
.43375 .54529 Mdot
.21951 .48563 Mdot
.77091 .34078 Mdot
.49746 .61696 Mdot
.49189 .6146 Mdot
.47418 .60709 Mdot
.41791 .58326 Mdot
.24389 .51048 Mdot
.83131 .36305 Mdot
.62698 .49175 Mdot
.59355 .59737 Mdot
.6925 .06115 Mdot
.01477 .19917 Mdot
.31492 .1855 Mdot
.4997 .61791 Mdot
.49904 .61763 Mdot
.49693 .61673 Mdot
.49023 .61389 Mdot
.46887 .60483 Mdot
.40112 .57616 Mdot
.19439 .49027 Mdot
.76336 .35164 Mdot
.57023 .49867 Mdot
.47904 .56168 Mdot
.3565 .5423 Mdot
.5007 .0003 Mdot
.50223 .00095 Mdot
.50712 .00302 Mdot
.52268 .00962 Mdot
.57214 .03057 Mdot
.72614 .09518 Mdot
.1162 .24107 Mdot
.34703 .14267 Mdot
.38215 .0217 Mdot
.25622 .5402 Mdot
.89173 .39277 Mdot
.67741 .48558 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50295 .00125 Mdot
.5094 .00399 Mdot
.52994 .0127 Mdot
.59514 .04029 Mdot
.79468 .12333 Mdot
.22362 .2651 Mdot
.41709 .11957 Mdot
.49175 .04614 Mdot
.55404 .0385 Mdot
.69583 .08763 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51388 .00589 Mdot
.54421 .01874 Mdot
.64 .0592 Mdot
.91975 .17289 Mdot
.31483 .24418 Mdot
.49072 .1087 Mdot
.6527 .10011 Mdot
.49908 .61765 Mdot
.49708 .6168 Mdot
.49069 .61409 Mdot
.47035 .60546 Mdot
.4058 .57814 Mdot
.20805 .49582 Mdot
.77981 .35337 Mdot
.58613 .49833 Mdot
.51543 .57434 Mdot
.46783 .58862 Mdot
.3723 .55899 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51823 .00773 Mdot
.55803 .0246 Mdot
.68296 .07721 Mdot
.02574 .21185 Mdot
.33008 .18809 Mdot
.42528 .05884 Mdot
.41248 .61012 Mdot
.27492 .53302 Mdot
.90154 .38728 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49817 .61726 Mdot
.49416 .61556 Mdot
.4814 .61015 Mdot
.44079 .59294 Mdot
.31342 .53931 Mdot
.96601 .40333 Mdot
.6692 .43459 Mdot
.58101 .56353 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00314 Mdot
.52355 .00999 Mdot
.57492 .03174 Mdot
.73456 .09866 Mdot
.13181 .24551 Mdot
.35318 .13682 Mdot
.38427 .01921 Mdot
.25665 .53916 Mdot
.8905 .39174 Mdot
.67595 .48543 Mdot
.49904 .61763 Mdot
.49694 .61674 Mdot
.49024 .6139 Mdot
.46893 .60486 Mdot
.4013 .57624 Mdot
.19493 .49049 Mdot
.76398 .35169 Mdot
.57083 .49867 Mdot
.48047 .56219 Mdot
.36089 .54413 Mdot
.05822 .43097 Mdot
.49832 .61732 Mdot
.49463 .61576 Mdot
.4829 .61078 Mdot
.44558 .59497 Mdot
.32821 .54549 Mdot
.00036 .41541 Mdot
.67197 .41508 Mdot
.55419 .54524 Mdot
.51613 .59451 Mdot
.50223 .60944 Mdot
.49166 .6115 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49627 .61645 Mdot
.48812 .613 Mdot
.46217 .60199 Mdot
.37999 .56725 Mdot
.13439 .46624 Mdot
.71032 .35594 Mdot
.5176 .49892 Mdot
.35121 .5152 Mdot
.99276 .3965 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51225 .0052 Mdot
.53902 .01654 Mdot
.62374 .05236 Mdot
.87591 .15585 Mdot
.29593 .25958 Mdot
.48708 .11814 Mdot
.65889 .10618 Mdot
.03136 .2302 Mdot
.3571 .20132 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51684 .00714 Mdot
.55361 .02273 Mdot
.66929 .07149 Mdot
.99366 .20047 Mdot
.32754 .20635 Mdot
.45045 .07597 Mdot
.50024 .03077 Mdot
.55039 .03099 Mdot
.67485 .07693 Mdot
.50052 .00022 Mdot
.50164 .0007 Mdot
.50524 .00222 Mdot
.51668 .00707 Mdot
.55309 .02251 Mdot
.66768 .07082 Mdot
.98976 .19906 Mdot
.32719 .20854 Mdot
.45343 .07802 Mdot
.5108 .03546 Mdot
.58435 .04546 Mdot
.77857 .12004 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.5051 .00216 Mdot
.51623 .00688 Mdot
.55168 .02191 Mdot
.66329 .06898 Mdot
.97907 .19516 Mdot
.32615 .21451 Mdot
.46132 .08354 Mdot
.53903 .04803 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47949 .60934 Mdot
.43472 .59037 Mdot
.29477 .53154 Mdot
.92546 .38979 Mdot
.66392 .45639 Mdot
.60704 .58288 Mdot
.69888 .05676 Mdot
.01724 .19676 Mdot
.30979 .18081 Mdot
.50054 .00023 Mdot
.50173 .00074 Mdot
.50552 .00234 Mdot
.5176 .00746 Mdot
.55602 .02375 Mdot
.67675 .07461 Mdot
.01136 .2068 Mdot
.32895 .19628 Mdot
.43658 .06652 Mdot
.45158 .00927 Mdot
.39507 .58311 Mdot
.19232 .49273 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.51141 .00484 Mdot
.53634 .01541 Mdot
.61529 .0488 Mdot
.85246 .14657 Mdot
.28057 .26459 Mdot
.47434 .11976 Mdot
.62979 .09607 Mdot
.95905 .20349 Mdot
.34906 .24104 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00147 Mdot
.51107 .0047 Mdot
.53527 .01495 Mdot
.61193 .04738 Mdot
.84299 .1428 Mdot
.27318 .26587 Mdot
.46716 .11989 Mdot
.61223 .08966 Mdot
.91203 .18529 Mdot
.33717 .26275 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42914 .58801 Mdot
.27773 .52446 Mdot
.89121 .37915 Mdot
.65546 .47233 Mdot
.61754 .5946 Mdot
.74035 .0759 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50817 .00346 Mdot
.52602 .01103 Mdot
.58273 .03505 Mdot
.75802 .10833 Mdot
.17173 .25569 Mdot
.37501 .12563 Mdot
.40948 .02131 Mdot
.31538 .55988 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52605 .01105 Mdot
.58283 .03509 Mdot
.75831 .10846 Mdot
.17221 .2558 Mdot
.37532 .12553 Mdot
.40997 .02141 Mdot
.31666 .56037 Mdot
.49949 .61782 Mdot
.49836 .61734 Mdot
.49477 .61582 Mdot
.48335 .61097 Mdot
.44699 .59556 Mdot
.33259 .54733 Mdot
.01087 .4192 Mdot
.67286 .40913 Mdot
.54609 .53968 Mdot
.4875 .58182 Mdot
.41016 .57024 Mdot
.4997 .61791 Mdot
.49905 .61763 Mdot
.49696 .61675 Mdot
.49032 .61393 Mdot
.46915 .60496 Mdot
.40201 .57654 Mdot
.197 .49133 Mdot
.76637 .35189 Mdot
.57321 .49866 Mdot
.48603 .56415 Mdot
.37792 .55122 Mdot
.49793 .61716 Mdot
.4934 .61523 Mdot
.47896 .60911 Mdot
.43307 .58967 Mdot
.28972 .52944 Mdot
.91503 .38646 Mdot
.66183 .46155 Mdot
.61165 .58702 Mdot
.71554 .06421 Mdot
.05259 .20831 Mdot
.31218 .16044 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50655 .00278 Mdot
.52088 .00885 Mdot
.56644 .02816 Mdot
.70879 .08798 Mdot
.08192 .23061 Mdot
.33752 .15797 Mdot
.38959 .03218 Mdot
.289 .55587 Mdot
.95682 .41273 Mdot
.50037 .00016 Mdot
.50119 .0005 Mdot
.50378 .0016 Mdot
.51204 .00511 Mdot
.53835 .01626 Mdot
.62163 .05147 Mdot
.87009 .15356 Mdot
.29249 .26106 Mdot
.48462 .11874 Mdot
.65372 .10451 Mdot
.01918 .22587 Mdot
.35594 .20813 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52226 .00944 Mdot
.57081 .03001 Mdot
.7221 .09351 Mdot
.10847 .23879 Mdot
.34444 .14584 Mdot
.38249 .02351 Mdot
.25985 .54224 Mdot
.89893 .39498 Mdot
.67963 .4825 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51494 .00633 Mdot
.54756 .02016 Mdot
.65047 .0636 Mdot
.94694 .18322 Mdot
.32153 .23151 Mdot
.4811 .09862 Mdot
.61238 .08114 Mdot
.89857 .17688 Mdot
.32681 .26467 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.5047 .002 Mdot
.51499 .00636 Mdot
.54772 .02023 Mdot
.65098 .06381 Mdot
.94823 .18371 Mdot
.32177 .23086 Mdot
.48045 .09807 Mdot
.60988 .07999 Mdot
.89135 .17396 Mdot
.32342 .26704 Mdot
.49862 .61745 Mdot
.49559 .61616 Mdot
.48595 .61208 Mdot
.45526 .59907 Mdot
.35834 .55813 Mdot
.07588 .44347 Mdot
.68387 .37576 Mdot
.51028 .51075 Mdot
.35209 .52027 Mdot
.00262 .40205 Mdot
.64922 .39962 Mdot
.50078 .00033 Mdot
.5025 .00106 Mdot
.50796 .00338 Mdot
.52537 .01076 Mdot
.58066 .03417 Mdot
.75183 .10579 Mdot
.16172 .25332 Mdot
.36867 .1279 Mdot
.40023 .0195 Mdot
.29174 .55099 Mdot
.95269 .40849 Mdot
.68356 .4517 Mdot
.49981 .61795 Mdot
.49938 .61777 Mdot
.49802 .6172 Mdot
.49371 .61537 Mdot
.47995 .60953 Mdot
.43621 .591 Mdot
.29932 .53343 Mdot
.93507 .39291 Mdot
.66554 .45145 Mdot
.6019 .5787 Mdot
.68087 .04881 Mdot
.50017 7e-05 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50542 .0023 Mdot
.51726 .00732 Mdot
.55494 .02329 Mdot
.67342 .07322 Mdot
.00351 .20401 Mdot
.32834 .20075 Mdot
.44278 .07073 Mdot
.47321 .01881 Mdot
.46366 .61213 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50513 .00218 Mdot
.51634 .00693 Mdot
.55203 .02206 Mdot
.66439 .06944 Mdot
.98176 .19615 Mdot
.32643 .21302 Mdot
.45938 .08216 Mdot
.53204 .04491 Mdot
.65244 .07441 Mdot
.9681 .19509 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48645 .61229 Mdot
.45685 .59974 Mdot
.36333 .56023 Mdot
.08907 .44854 Mdot
.68808 .3702 Mdot
.50797 .50672 Mdot
.33981 .51411 Mdot
.96993 .38944 Mdot
.64489 .41714 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50785 .00333 Mdot
.52501 .0106 Mdot
.57953 .03369 Mdot
.74844 .10439 Mdot
.15606 .25193 Mdot
.36535 .12934 Mdot
.39591 .01888 Mdot
.28122 .54715 Mdot
.93237 .40244 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51541 .00653 Mdot
.54905 .02079 Mdot
.65512 .06555 Mdot
.95873 .18764 Mdot
.32356 .22548 Mdot
.4747 .09341 Mdot
.58805 .07005 Mdot
.82683 .14758 Mdot
.27706 .27826 Mdot
.49883 .61754 Mdot
.49626 .61645 Mdot
.48808 .61298 Mdot
.46203 .60194 Mdot
.37957 .56707 Mdot
.13321 .46578 Mdot
.70957 .3562 Mdot
.51699 .49901 Mdot
.34984 .51473 Mdot
.98941 .39528 Mdot
.64486 .40508 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43731 .59146 Mdot
.30269 .53484 Mdot
.94231 .39531 Mdot
.66658 .44762 Mdot
.59753 .57536 Mdot
.66579 .04219 Mdot
.94013 .16955 Mdot
.30217 .22376 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50531 .00225 Mdot
.51692 .00717 Mdot
.55386 .02283 Mdot
.67004 .07181 Mdot
.99546 .20112 Mdot
.32769 .20533 Mdot
.44906 .07501 Mdot
.49533 .02859 Mdot
.53459 .02426 Mdot
.62532 .05607 Mdot
.49777 .61709 Mdot
.49288 .61502 Mdot
.47733 .60842 Mdot
.4279 .58748 Mdot
.27396 .5229 Mdot
.884 .37702 Mdot
.65304 .47529 Mdot
.61785 .59629 Mdot
.74372 .07779 Mdot
.10814 .22522 Mdot
.32254 .13251 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00156 Mdot
.5117 .00496 Mdot
.53727 .0158 Mdot
.61824 .05004 Mdot
.8607 .14985 Mdot
.28643 .26312 Mdot
.47966 .11942 Mdot
.64247 .10062 Mdot
.99157 .21575 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50288 .00122 Mdot
.50916 .00388 Mdot
.52918 .01237 Mdot
.59273 .03928 Mdot
.78764 .12046 Mdot
.21464 .2639 Mdot
.40877 .11998 Mdot
.47343 .03996 Mdot
.49842 .01545 Mdot
.52105 .01398 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48769 .61281 Mdot
.46079 .60141 Mdot
.37566 .56542 Mdot
.12243 .46153 Mdot
.70314 .3589 Mdot
.5123 .50009 Mdot
.3399 .51148 Mdot
.96585 .38686 Mdot
.64263 .41828 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50045 .00019 Mdot
.50143 .00061 Mdot
.50456 .00193 Mdot
.51454 .00616 Mdot
.54628 .01962 Mdot
.64647 .06192 Mdot
.93665 .17934 Mdot
.31936 .23653 Mdot
.48566 .10278 Mdot
.63046 .0895 Mdot
.49825 .61729 Mdot
.49442 .61567 Mdot
.48223 .6105 Mdot
.44345 .59406 Mdot
.3216 .54273 Mdot
.98478 .40987 Mdot
.67075 .42396 Mdot
.56648 .55359 Mdot
.55904 .61344 Mdot
.63814 .04889 Mdot
.89938 .16146 Mdot
.49857 .61743 Mdot
.49546 .61611 Mdot
.48553 .6119 Mdot
.45394 .59851 Mdot
.3542 .5564 Mdot
.0651 .43936 Mdot
.68105 .38068 Mdot
.51367 .51459 Mdot
.36679 .52725 Mdot
.04261 .41768 Mdot
.65528 .37865 Mdot
.49823 .61728 Mdot
.49437 .61565 Mdot
.48206 .61043 Mdot
.44289 .59383 Mdot
.31988 .54201 Mdot
.98078 .40846 Mdot
.67044 .42623 Mdot
.56962 .55573 Mdot
.56995 .0002 Mdot
.67184 .06297 Mdot
.98426 .19308 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50676 .00287 Mdot
.52154 .00914 Mdot
.56854 .02905 Mdot
.7152 .09064 Mdot
.09491 .23467 Mdot
.34054 .15181 Mdot
.38505 .0275 Mdot
.27172 .548 Mdot
.92189 .40182 Mdot
.68457 .47137 Mdot
.49969 .6179 Mdot
.49901 .61762 Mdot
.49686 .6167 Mdot
.48999 .61379 Mdot
.46811 .60451 Mdot
.39873 .57515 Mdot
.18747 .48747 Mdot
.75567 .35117 Mdot
.56246 .49862 Mdot
.46054 .55505 Mdot
.30004 .51884 Mdot
.49901 .61761 Mdot
.49684 .61669 Mdot
.48994 .61377 Mdot
.46796 .60445 Mdot
.39823 .57494 Mdot
.18604 .48689 Mdot
.75414 .3511 Mdot
.56089 .4986 Mdot
.45676 .55368 Mdot
.28856 .51408 Mdot
.88861 .37085 Mdot
.49939 .61777 Mdot
.49805 .61721 Mdot
.49379 .6154 Mdot
.4802 .60964 Mdot
.437 .59133 Mdot
.30174 .53444 Mdot
.94025 .39462 Mdot
.6663 .44872 Mdot
.59882 .57633 Mdot
.67022 .04413 Mdot
.95098 .17352 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47989 .60951 Mdot
.43601 .59091 Mdot
.2987 .53317 Mdot
.93374 .39248 Mdot
.66533 .45215 Mdot
.60265 .5793 Mdot
.6835 .04997 Mdot
.98255 .18482 Mdot
.30772 .20096 Mdot
.49845 .61738 Mdot
.49505 .61594 Mdot
.48424 .61135 Mdot
.44983 .59677 Mdot
.34141 .55102 Mdot
.03255 .42715 Mdot
.67521 .39719 Mdot
.53072 .52874 Mdot
.43204 .55704 Mdot
.23447 .49593 Mdot
.79932 .34909 Mdot
.49914 .61767 Mdot
.49725 .61687 Mdot
.49124 .61432 Mdot
.47208 .6062 Mdot
.41127 .58045 Mdot
.22416 .50239 Mdot
.80146 .35679 Mdot
.60511 .49669 Mdot
.55523 .5872 Mdot
.58653 .01935 Mdot
.74134 .09567 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50704 .00299 Mdot
.52243 .00951 Mdot
.57134 .03023 Mdot
.72372 .09417 Mdot
.11158 .23971 Mdot
.34545 .14454 Mdot
.38225 .02274 Mdot
.2581 .5413 Mdot
.89552 .39395 Mdot
.67865 .484 Mdot
.50004 1e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50363 .00154 Mdot
.51155 .0049 Mdot
.5368 .0156 Mdot
.61675 .04941 Mdot
.85653 .1482 Mdot
.28354 .2639 Mdot
.47709 .11962 Mdot
.63638 .09845 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48268 .61069 Mdot
.44487 .59467 Mdot
.32601 .54458 Mdot
.99514 .41354 Mdot
.67155 .41805 Mdot
.55829 .54803 Mdot
.53051 .60087 Mdot
.54823 .01095 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47812 .60876 Mdot
.43039 .58854 Mdot
.28155 .52605 Mdot
.89865 .38139 Mdot
.65771 .46912 Mdot
.61647 .59255 Mdot
.73475 .0731 Mdot
.09066 .21997 Mdot
.31782 .14039 Mdot
.49881 .61753 Mdot
.49621 .61642 Mdot
.48791 .61291 Mdot
.4615 .60171 Mdot
.37789 .56636 Mdot
.12856 .46394 Mdot
.70669 .3573 Mdot
.51477 .49942 Mdot
.34497 .51309 Mdot
.97769 .39104 Mdot
.64377 .41166 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.5124 .00526 Mdot
.53949 .01674 Mdot
.6252 .05297 Mdot
.87993 .15743 Mdot
.29816 .25848 Mdot
.48851 .11764 Mdot
.66163 .107 Mdot
.03762 .23238 Mdot
.3577 .19782 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47982 .60948 Mdot
.43578 .59082 Mdot
.29802 .53289 Mdot
.9323 .39201 Mdot
.6651 .45289 Mdot
.60346 .57994 Mdot
.68631 .0512 Mdot
.98902 .18709 Mdot
.30819 .19726 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50769 .00326 Mdot
.52448 .01038 Mdot
.57786 .03299 Mdot
.74344 .10233 Mdot
.14754 .24975 Mdot
.3607 .13174 Mdot
.39057 .01846 Mdot
.26894 .54286 Mdot
.91026 .39636 Mdot
.67917 .47522 Mdot
.49977 .61794 Mdot
.49927 .61772 Mdot
.49766 .61704 Mdot
.49254 .61487 Mdot
.47624 .60796 Mdot
.42444 .58602 Mdot
.26349 .51857 Mdot
.86468 .37155 Mdot
.64526 .48242 Mdot
.61471 .59915 Mdot
.7417 .07849 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58507 .03604 Mdot
.765 .1112 Mdot
.1826 .25809 Mdot
.38256 .12358 Mdot
.42191 .02432 Mdot
.34877 .57283 Mdot
.08141 .4528 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50896 .0038 Mdot
.52855 .01211 Mdot
.59073 .03843 Mdot
.78176 .11806 Mdot
.20678 .26268 Mdot
.40182 .12054 Mdot
.45875 .03519 Mdot
.4545 .61541 Mdot
.49888 .61756 Mdot
.49644 .61652 Mdot
.48866 .61322 Mdot
.46388 .60272 Mdot
.38538 .56952 Mdot
.14943 .47221 Mdot
.72085 .35315 Mdot
.527 .49823 Mdot
.37346 .52314 Mdot
.04949 .41781 Mdot
.65247 .37267 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.4833 .61095 Mdot
.44685 .59551 Mdot
.33215 .54715 Mdot
.00983 .41883 Mdot
.67277 .40972 Mdot
.54688 .54023 Mdot
.49031 .58307 Mdot
.4192 .57409 Mdot
.23204 .50236 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43732 .59147 Mdot
.30271 .53485 Mdot
.94235 .39532 Mdot
.66659 .4476 Mdot
.5975 .57534 Mdot
.6657 .04215 Mdot
.93992 .16947 Mdot
.30213 .22386 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.48061 .60981 Mdot
.43829 .59188 Mdot
.30571 .53609 Mdot
.94886 .39749 Mdot
.66741 .44409 Mdot
.59327 .57221 Mdot
.65116 .03578 Mdot
.90319 .15577 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47646 .60805 Mdot
.42513 .58631 Mdot
.26559 .51943 Mdot
.86847 .3726 Mdot
.64694 .48112 Mdot
.61581 .59879 Mdot
.74346 .07889 Mdot
.10964 .22631 Mdot
.32407 .13252 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47458 .60726 Mdot
.41919 .5838 Mdot
.24771 .51205 Mdot
.83752 .36452 Mdot
.63087 .49032 Mdot
.59914 .59842 Mdot
.70669 .06647 Mdot
.04419 .20858 Mdot
.31625 .16815 Mdot
.49856 .61743 Mdot
.49542 .61609 Mdot
.48542 .61185 Mdot
.45359 .59836 Mdot
.35312 .55594 Mdot
.06229 .43829 Mdot
.6804 .38201 Mdot
.51477 .51567 Mdot
.37126 .52934 Mdot
.05502 .42259 Mdot
.65788 .37259 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52372 .01006 Mdot
.57544 .03197 Mdot
.73614 .09932 Mdot
.13467 .2463 Mdot
.35445 .13583 Mdot
.38509 .01894 Mdot
.25795 .53946 Mdot
.89237 .3921 Mdot
.67621 .48444 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.51319 .00559 Mdot
.54199 .0178 Mdot
.63305 .05628 Mdot
.90124 .16575 Mdot
.30824 .25154 Mdot
.49232 .11377 Mdot
.66489 .10665 Mdot
.04287 .2336 Mdot
.35732 .19434 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50746 .00316 Mdot
.52377 .01008 Mdot
.57561 .03204 Mdot
.73665 .09953 Mdot
.13559 .24655 Mdot
.35486 .13552 Mdot
.38538 .01886 Mdot
.25845 .53959 Mdot
.89312 .39225 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47887 .60907 Mdot
.43277 .58954 Mdot
.28879 .52905 Mdot
.91314 .38587 Mdot
.66141 .46245 Mdot
.61236 .58772 Mdot
.7182 .06541 Mdot
.05803 .21002 Mdot
.31273 .15741 Mdot
.5004 .00017 Mdot
.50126 .00054 Mdot
.50402 .00171 Mdot
.51281 .00543 Mdot
.54081 .0173 Mdot
.62934 .05472 Mdot
.89123 .16186 Mdot
.30387 .25502 Mdot
.49131 .11585 Mdot
.66573 .1078 Mdot
.04618 .23514 Mdot
.35833 .19292 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49528 .61603 Mdot
.48497 .61166 Mdot
.45213 .59774 Mdot
.34858 .55403 Mdot
.05063 .4339 Mdot
.67802 .38774 Mdot
.52012 .52045 Mdot
.39234 .53906 Mdot
.1151 .44669 Mdot
.50036 .00015 Mdot
.50115 .00049 Mdot
.50367 .00156 Mdot
.5117 .00496 Mdot
.53727 .0158 Mdot
.61823 .05004 Mdot
.86067 .14984 Mdot
.28641 .26312 Mdot
.47965 .11942 Mdot
.64243 .10061 Mdot
.99147 .21572 Mdot
.3533 .22362 Mdot
.50014 6e-05 Mdot
.50043 .00018 Mdot
.50138 .00059 Mdot
.5044 .00186 Mdot
.51401 .00594 Mdot
.54461 .01891 Mdot
.64126 .05973 Mdot
.92304 .17415 Mdot
.31582 .24275 Mdot
.48999 .10764 Mdot
.64916 .09837 Mdot
.00071 .21727 Mdot
.49917 .61768 Mdot
.49736 .61691 Mdot
.49158 .61446 Mdot
.47318 .60666 Mdot
.41475 .58192 Mdot
.23448 .50662 Mdot
.8166 .35977 Mdot
.61686 .49459 Mdot
.57708 .59345 Mdot
.64846 .04411 Mdot
.9116 .16263 Mdot
.49906 .61764 Mdot
.49702 .61677 Mdot
.49049 .614 Mdot
.46972 .6052 Mdot
.40381 .5773 Mdot
.20223 .49345 Mdot
.7726 .3525 Mdot
.57929 .49856 Mdot
.50007 .56907 Mdot
.42094 .56913 Mdot
.22803 .49881 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49084 .61415 Mdot
.47081 .60566 Mdot
.40725 .57875 Mdot
.21231 .49755 Mdot
.7853 .35413 Mdot
.59117 .49806 Mdot
.52644 .57803 Mdot
.50119 .60243 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00248 Mdot
.51867 .00791 Mdot
.55941 .02518 Mdot
.6872 .07898 Mdot
.03538 .21519 Mdot
.33093 .18266 Mdot
.41795 .05378 Mdot
.38726 .59907 Mdot
.20126 .50308 Mdot
.78764 .3624 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.4851 .61171 Mdot
.45255 .59792 Mdot
.34987 .55458 Mdot
.05394 .43514 Mdot
.67864 .38609 Mdot
.51848 .51905 Mdot
.38597 .53614 Mdot
.09667 .43924 Mdot
.67112 .35503 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49267 .61493 Mdot
.47667 .60814 Mdot
.42578 .58658 Mdot
.26755 .52024 Mdot
.87204 .3736 Mdot
.64845 .47985 Mdot
.61662 .59836 Mdot
.74448 .07902 Mdot
.11094 .22648 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52613 .01108 Mdot
.58307 .03519 Mdot
.75904 .10875 Mdot
.17336 .25606 Mdot
.37609 .1253 Mdot
.41118 .02168 Mdot
.31984 .56158 Mdot
.01239 .42802 Mdot
.68637 .41655 Mdot
.49838 .61735 Mdot
.49485 .61585 Mdot
.4836 .61108 Mdot
.44779 .5959 Mdot
.33505 .54836 Mdot
.01686 .42138 Mdot
.67343 .40578 Mdot
.54163 .53658 Mdot
.47157 .57473 Mdot
.35909 .54852 Mdot
.06179 .43429 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50895 .0038 Mdot
.52851 .01209 Mdot
.59062 .03838 Mdot
.78142 .11792 Mdot
.20632 .2626 Mdot
.40142 .12058 Mdot
.45792 .03492 Mdot
.45204 .6144 Mdot
.37531 .57061 Mdot
.49777 .61709 Mdot
.49289 .61502 Mdot
.47735 .60843 Mdot
.42795 .5875 Mdot
.27414 .52297 Mdot
.88433 .37712 Mdot
.65315 .47516 Mdot
.61785 .59622 Mdot
.74361 .07772 Mdot
.10791 .22515 Mdot
.32246 .1326 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50507 .00215 Mdot
.51616 .00685 Mdot
.55145 .02181 Mdot
.66257 .06868 Mdot
.97729 .19451 Mdot
.32596 .21549 Mdot
.46259 .08444 Mdot
.5436 .05007 Mdot
.68921 .08999 Mdot
.05634 .2269 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47663 .60813 Mdot
.42567 .58654 Mdot
.26723 .52011 Mdot
.87146 .37343 Mdot
.64821 .48006 Mdot
.6165 .59844 Mdot
.74436 .07902 Mdot
.11079 .22647 Mdot
.32414 .13186 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48837 .6131 Mdot
.46296 .60233 Mdot
.38249 .5683 Mdot
.14133 .46899 Mdot
.71496 .35452 Mdot
.52156 .49851 Mdot
.36041 .51844 Mdot
.0157 .40499 Mdot
.64748 .39046 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47423 .60711 Mdot
.41805 .58332 Mdot
.24432 .51066 Mdot
.83201 .36321 Mdot
.62743 .4916 Mdot
.59422 .59751 Mdot
.69423 .06181 Mdot
.01847 .20039 Mdot
.31506 .18331 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50468 .00198 Mdot
.51491 .00632 Mdot
.54748 .02013 Mdot
.65021 .06349 Mdot
.94627 .18297 Mdot
.3214 .23184 Mdot
.48142 .0989 Mdot
.61364 .08172 Mdot
.9022 .17834 Mdot
.3284 .26341 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50561 .00238 Mdot
.51787 .00758 Mdot
.55689 .02411 Mdot
.67943 .07574 Mdot
.01763 .20902 Mdot
.32943 .19271 Mdot
.43163 .06316 Mdot
.43439 .00171 Mdot
.3415 .56062 Mdot
.04825 .4368 Mdot
.49914 .61767 Mdot
.49727 .61688 Mdot
.49131 .61435 Mdot
.47233 .6063 Mdot
.41205 .58078 Mdot
.22646 .50333 Mdot
.80475 .3574 Mdot
.60778 .4963 Mdot
.5604 .58875 Mdot
.60148 .02538 Mdot
.78466 .11321 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.4877 .61282 Mdot
.46084 .60143 Mdot
.37584 .5655 Mdot
.12292 .46172 Mdot
.70341 .35876 Mdot
.51248 .50003 Mdot
.34025 .51159 Mdot
.96665 .38714 Mdot
.64271 .41783 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.48078 .60989 Mdot
.43884 .59211 Mdot
.3074 .5368 Mdot
.9526 .39875 Mdot
.66785 .44205 Mdot
.59073 .57037 Mdot
.64244 .03196 Mdot
.88041 .14707 Mdot
.28136 .2478 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50387 .00164 Mdot
.51234 .00523 Mdot
.53929 .01666 Mdot
.62459 .05272 Mdot
.87827 .15678 Mdot
.29725 .25894 Mdot
.48795 .11786 Mdot
.66058 .10669 Mdot
.03525 .23156 Mdot
.35747 .19915 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50517 .00219 Mdot
.51646 .00698 Mdot
.55241 .02222 Mdot
.66557 .06994 Mdot
.98466 .1972 Mdot
.32672 .21141 Mdot
.45725 .08067 Mdot
.52443 .04152 Mdot
.62811 .06408 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50599 .00254 Mdot
.51909 .0081 Mdot
.56076 .02575 Mdot
.69136 .08072 Mdot
.04467 .21836 Mdot
.33185 .17749 Mdot
.41119 .04903 Mdot
.36411 .58894 Mdot
.13707 .47772 Mdot
.72892 .36578 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48645 .61229 Mdot
.45686 .59974 Mdot
.36333 .56023 Mdot
.0891 .44854 Mdot
.68808 .3702 Mdot
.50797 .50672 Mdot
.3398 .5141 Mdot
.9699 .38942 Mdot
.49816 .61725 Mdot
.49412 .61554 Mdot
.48127 .61009 Mdot
.4404 .59277 Mdot
.31221 .53881 Mdot
.96329 .40239 Mdot
.66895 .43612 Mdot
.58304 .56494 Mdot
.61613 .02045 Mdot
.80837 .11881 Mdot
.22346 .25654 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.48692 .61249 Mdot
.45834 .60037 Mdot
.36798 .56219 Mdot
.10154 .45336 Mdot
.69291 .36549 Mdot
.50782 .50364 Mdot
.33446 .51089 Mdot
.9552 .38364 Mdot
.64226 .42463 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.51958 .0083 Mdot
.5623 .02641 Mdot
.69612 .0827 Mdot
.05512 .22187 Mdot
.33308 .17179 Mdot
.40411 .0439 Mdot
.33985 .57832 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52529 .01072 Mdot
.58041 .03407 Mdot
.75108 .10548 Mdot
.16047 .25302 Mdot
.36792 .12821 Mdot
.39922 .01934 Mdot
.28925 .55007 Mdot
.94777 .40699 Mdot
.68324 .45454 Mdot
.49894 .61759 Mdot
.49663 .61661 Mdot
.48927 .61349 Mdot
.46584 .60355 Mdot
.39156 .57213 Mdot
.16691 .4792 Mdot
.73533 .3513 Mdot
.54148 .49822 Mdot
.40913 .53624 Mdot
.14776 .4565 Mdot
.69525 .33837 Mdot
.49755 .617 Mdot
.4922 .61473 Mdot
.47516 .6075 Mdot
.421 .58456 Mdot
.25315 .5143 Mdot
.84661 .36678 Mdot
.63616 .48797 Mdot
.60592 .59935 Mdot
.7231 .07242 Mdot
.0756 .21786 Mdot
.31892 .15038 Mdot
.49828 .61731 Mdot
.49453 .61572 Mdot
.48259 .61065 Mdot
.44457 .59454 Mdot
.32508 .54418 Mdot
.99293 .41275 Mdot
.67138 .41931 Mdot
.56003 .54922 Mdot
.53661 .60356 Mdot
.56761 .01916 Mdot
.69701 .07997 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50811 .00344 Mdot
.52582 .01095 Mdot
.5821 .03478 Mdot
.75615 .10757 Mdot
.16875 .255 Mdot
.37305 .12627 Mdot
.4065 .02067 Mdot
.30763 .55693 Mdot
.98552 .41895 Mdot
.68509 .43236 Mdot
.49793 .61716 Mdot
.49341 .61524 Mdot
.47901 .60913 Mdot
.43322 .58973 Mdot
.29017 .52962 Mdot
.91595 .38675 Mdot
.66203 .4611 Mdot
.61129 .58667 Mdot
.7142 .0636 Mdot
.04983 .20743 Mdot
.31193 .16199 Mdot
.4993 .61774 Mdot
.49776 .61709 Mdot
.49287 .61501 Mdot
.47729 .6084 Mdot
.42775 .58742 Mdot
.27353 .52272 Mdot
.88317 .37678 Mdot
.65274 .47562 Mdot
.61784 .59646 Mdot
.74397 .07796 Mdot
.10867 .2254 Mdot
.49789 .61714 Mdot
.49327 .61518 Mdot
.47857 .60895 Mdot
.43182 .58914 Mdot
.2859 .52785 Mdot
.9073 .38404 Mdot
.66002 .46521 Mdot
.61432 .58979 Mdot
.72573 .06886 Mdot
.0731 .21469 Mdot
.31464 .14928 Mdot
.49833 .61732 Mdot
.49466 .61577 Mdot
.483 .61082 Mdot
.44588 .59509 Mdot
.32914 .54588 Mdot
.00257 .41621 Mdot
.67215 .41382 Mdot
.55246 .54406 Mdot
.51005 .59182 Mdot
.48269 .60113 Mdot
.42943 .58511 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47572 .60774 Mdot
.42277 .58531 Mdot
.25847 .51649 Mdot
.85577 .36915 Mdot
.641 .4853 Mdot
.61113 .59957 Mdot
.73473 .07639 Mdot
.09596 .22326 Mdot
.32182 .13959 Mdot
.49782 .61711 Mdot
.49304 .61508 Mdot
.47784 .60864 Mdot
.42949 .58815 Mdot
.2788 .5249 Mdot
.89328 .37977 Mdot
.65611 .47145 Mdot
.61732 .59406 Mdot
.739 .0752 Mdot
.09884 .2224 Mdot
.31977 .13654 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47768 .60857 Mdot
.429 .58795 Mdot
.2773 .52428 Mdot
.89038 .3789 Mdot
.65519 .47268 Mdot
.61762 .59481 Mdot
.74084 .07616 Mdot
.1024 .22346 Mdot
.32074 .13494 Mdot
.49948 .61781 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48329 .61095 Mdot
.44679 .59548 Mdot
.33197 .54707 Mdot
.00938 .41866 Mdot
.67273 .40998 Mdot
.54723 .54047 Mdot
.49153 .58361 Mdot
.42314 .57576 Mdot
.49847 .61739 Mdot
.49514 .61597 Mdot
.48451 .61146 Mdot
.45067 .59712 Mdot
.34403 .55212 Mdot
.03911 .42959 Mdot
.67612 .39369 Mdot
.52659 .52562 Mdot
.41677 .55016 Mdot
.18771 .47647 Mdot
.73797 .34008 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50414 .00176 Mdot
.51319 .00559 Mdot
.54199 .0178 Mdot
.63306 .05628 Mdot
.90127 .16576 Mdot
.30826 .25153 Mdot
.49232 .11376 Mdot
.66488 .10665 Mdot
.04284 .23359 Mdot
.35731 .19435 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50522 .00221 Mdot
.51664 .00706 Mdot
.55297 .02245 Mdot
.6673 .07066 Mdot
.98886 .19873 Mdot
.32711 .20905 Mdot
.45411 .07849 Mdot
.51323 .03654 Mdot
.59218 .04879 Mdot
.80178 .12954 Mdot
.49875 .6175 Mdot
.49602 .61634 Mdot
.4873 .61265 Mdot
.45957 .60089 Mdot
.37184 .56381 Mdot
.11198 .45743 Mdot
.69767 .36198 Mdot
.50931 .50162 Mdot
.33489 .51024 Mdot
.95491 .38319 Mdot
.64166 .42444 Mdot
.49989 .61799 Mdot
.49963 .61788 Mdot
.49884 .61754 Mdot
.49629 .61646 Mdot
.48818 .61302 Mdot
.46236 .60208 Mdot
.3806 .56751 Mdot
.13609 .46691 Mdot
.71142 .35558 Mdot
.51851 .49881 Mdot
.35329 .51592 Mdot
.49816 .61725 Mdot
.49415 .61555 Mdot
.48135 .61013 Mdot
.44065 .59288 Mdot
.31297 .53913 Mdot
.96501 .40298 Mdot
.66911 .43516 Mdot
.58177 .56405 Mdot
.61174 .01853 Mdot
.79591 .11382 Mdot
.20894 .25527 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.5076 .00322 Mdot
.52421 .01027 Mdot
.57701 .03263 Mdot
.74086 .10126 Mdot
.14304 .24857 Mdot
.35841 .1331 Mdot
.38831 .01848 Mdot
.26411 .54127 Mdot
.9021 .3943 Mdot
.67786 .47944 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51822 .00773 Mdot
.558 .02459 Mdot
.68288 .07718 Mdot
.02556 .21179 Mdot
.33007 .1882 Mdot
.42543 .05893 Mdot
.41297 .61033 Mdot
.27637 .53361 Mdot
.90431 .38809 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49089 .61417 Mdot
.47099 .60574 Mdot
.40783 .57899 Mdot
.214 .49824 Mdot
.78753 .35446 Mdot
.59318 .49792 Mdot
.53074 .57945 Mdot
.51414 .60777 Mdot
.51872 .00283 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50662 .00281 Mdot
.5211 .00895 Mdot
.56713 .02845 Mdot
.71091 .08886 Mdot
.08625 .23197 Mdot
.33846 .15587 Mdot
.38786 .03054 Mdot
.28264 .553 Mdot
.9437 .40855 Mdot
.68745 .45967 Mdot
.49957 .61785 Mdot
.49863 .61745 Mdot
.49562 .61618 Mdot
.48605 .61212 Mdot
.45556 .5992 Mdot
.35929 .55854 Mdot
.07841 .44443 Mdot
.68461 .37465 Mdot
.50967 .50992 Mdot
.34924 .51888 Mdot
.995 .3991 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.5196 .00831 Mdot
.56237 .02644 Mdot
.69633 .08279 Mdot
.05557 .22203 Mdot
.33314 .17154 Mdot
.40381 .04368 Mdot
.33883 .57787 Mdot
.07134 .45272 Mdot
.70039 .38877 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47495 .60741 Mdot
.42036 .58429 Mdot
.25123 .5135 Mdot
.84337 .36596 Mdot
.63433 .48884 Mdot
.60369 .5991 Mdot
.71782 .07053 Mdot
.06581 .21507 Mdot
.31788 .15579 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50605 .00257 Mdot
.51928 .00817 Mdot
.56135 .026 Mdot
.6932 .08148 Mdot
.04873 .21973 Mdot
.3323 .17526 Mdot
.40836 .04701 Mdot
.35444 .58471 Mdot
.11136 .46781 Mdot
.71454 .37279 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61225 Mdot
.45659 .59963 Mdot
.36249 .55988 Mdot
.08686 .44768 Mdot
.68731 .3711 Mdot
.50821 .50734 Mdot
.34141 .51495 Mdot
.97419 .39108 Mdot
.64551 .4149 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50642 .00272 Mdot
.52044 .00867 Mdot
.56504 .02757 Mdot
.70452 .0862 Mdot
.07304 .22776 Mdot
.33581 .1624 Mdot
.39371 .03579 Mdot
.30377 .56245 Mdot
.98859 .42324 Mdot
.69051 .43381 Mdot
.5007 .0003 Mdot
.50223 .00094 Mdot
.5071 .00301 Mdot
.52261 .00959 Mdot
.57192 .03047 Mdot
.72546 .0949 Mdot
.11491 .24069 Mdot
.34658 .14318 Mdot
.38215 .02198 Mdot
.25665 .54047 Mdot
.89263 .39306 Mdot
.67772 .48521 Mdot
.49997 .61802 Mdot
.49992 .618 Mdot
.49974 .61792 Mdot
.49918 .61768 Mdot
.49737 .61692 Mdot
.49163 .61449 Mdot
.47334 .60673 Mdot
.41525 .58213 Mdot
.23597 .50723 Mdot
.81887 .36026 Mdot
.61851 .4942 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48113 .61003 Mdot
.43995 .59258 Mdot
.31081 .53822 Mdot
.96015 .40132 Mdot
.66864 .43787 Mdot
.58535 .56656 Mdot
.62404 .02391 Mdot
.83052 .12761 Mdot
.24582 .25667 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50338 .00143 Mdot
.51078 .00457 Mdot
.53432 .01455 Mdot
.60896 .04613 Mdot
.83456 .13943 Mdot
.26598 .26663 Mdot
.45988 .11983 Mdot
.59423 .08303 Mdot
.8618 .16537 Mdot
.31159 .27798 Mdot
.50063 .00027 Mdot
.50199 .00085 Mdot
.50635 .00269 Mdot
.52023 .00858 Mdot
.56437 .02728 Mdot
.70245 .08534 Mdot
.06868 .22635 Mdot
.33506 .16463 Mdot
.396 .03766 Mdot
.31181 .566 Mdot
.00667 .42945 Mdot
.69153 .42326 Mdot
.49953 .61784 Mdot
.49851 .6174 Mdot
.49524 .61602 Mdot
.48483 .6116 Mdot
.45172 .59757 Mdot
.34727 .55349 Mdot
.04732 .43265 Mdot
.67743 .38943 Mdot
.52187 .5219 Mdot
.39903 .54211 Mdot
.13468 .45466 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47679 .60819 Mdot
.42617 .58675 Mdot
.26872 .52073 Mdot
.87419 .3742 Mdot
.64933 .47906 Mdot
.61701 .59806 Mdot
.74482 .07899 Mdot
.11123 .22645 Mdot
.32405 .13153 Mdot
.49895 .61759 Mdot
.49666 .61662 Mdot
.48935 .61352 Mdot
.46609 .60366 Mdot
.39236 .57246 Mdot
.16918 .48011 Mdot
.7374 .35118 Mdot
.54361 .49826 Mdot
.4144 .53818 Mdot
.1629 .4626 Mdot
.70753 .3366 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .00121 Mdot
.50906 .00384 Mdot
.52885 .01223 Mdot
.59167 .03883 Mdot
.78451 .11918 Mdot
.21049 .26327 Mdot
.40506 .12025 Mdot
.46552 .03737 Mdot
.47468 .00566 Mdot
.44601 .60031 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50274 .00116 Mdot
.50872 .0037 Mdot
.52778 .01178 Mdot
.5883 .0374 Mdot
.77458 .11513 Mdot
.19675 .26091 Mdot
.39342 .12155 Mdot
.44192 .02997 Mdot
.4052 .59534 Mdot
.23456 .51257 Mdot
.4987 .61748 Mdot
.49586 .61628 Mdot
.48681 .61244 Mdot
.458 .60023 Mdot
.36693 .56175 Mdot
.0987 .45226 Mdot
.69173 .36651 Mdot
.50767 .50428 Mdot
.33512 .51139 Mdot
.95718 .38445 Mdot
.64269 .42367 Mdot
.49757 .61701 Mdot
.49227 .61476 Mdot
.47539 .6076 Mdot
.42172 .58487 Mdot
.25532 .51519 Mdot
.85033 .36773 Mdot
.63818 .48692 Mdot
.60822 .59952 Mdot
.72838 .07426 Mdot
.08507 .22045 Mdot
.32014 .14528 Mdot
.49838 .61735 Mdot
.49484 .61584 Mdot
.48355 .61106 Mdot
.44764 .59584 Mdot
.33459 .54817 Mdot
.01575 .42098 Mdot
.67332 .4064 Mdot
.54245 .53715 Mdot
.4745 .57604 Mdot
.36847 .5525 Mdot
.08686 .44399 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50712 .00302 Mdot
.52269 .00962 Mdot
.57217 .03058 Mdot
.72623 .09522 Mdot
.11637 .24112 Mdot
.3471 .14259 Mdot
.38216 .02167 Mdot
.49894 .61759 Mdot
.49663 .6166 Mdot
.48926 .61348 Mdot
.4658 .60353 Mdot
.39144 .57207 Mdot
.16657 .47906 Mdot
.73502 .35133 Mdot
.54116 .49822 Mdot
.40834 .53595 Mdot
.14549 .45559 Mdot
.69356 .33873 Mdot
.49841 .61736 Mdot
.49492 .61588 Mdot
.48383 .61118 Mdot
.44851 .59621 Mdot
.3373 .5493 Mdot
.02237 .4234 Mdot
.674 .40273 Mdot
.53765 .53377 Mdot
.45727 .56835 Mdot
.31354 .52921 Mdot
.94987 .39327 Mdot
.5006 .00025 Mdot
.5019 .00081 Mdot
.50607 .00257 Mdot
.51932 .00819 Mdot
.5615 .02606 Mdot
.69364 .08167 Mdot
.04969 .22006 Mdot
.33242 .17473 Mdot
.4077 .04653 Mdot
.35218 .58372 Mdot
.10546 .46555 Mdot
.71187 .37478 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51997 .00847 Mdot
.56354 .02693 Mdot
.69992 .08429 Mdot
.06332 .22459 Mdot
.33422 .16743 Mdot
.39904 .04006 Mdot
.32239 .57066 Mdot
.03126 .43811 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .0027 Mdot
.52031 .00861 Mdot
.56463 .02739 Mdot
.70324 .08567 Mdot
.07035 .22689 Mdot
.33534 .16377 Mdot
.39511 .03694 Mdot
.30868 .56462 Mdot
.99955 .42699 Mdot
.6911 .4274 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49089 .61417 Mdot
.47099 .60573 Mdot
.40781 .57899 Mdot
.21394 .49822 Mdot
.78744 .35444 Mdot
.5931 .49792 Mdot
.53058 .57939 Mdot
.51364 .60757 Mdot
.51714 .00216 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50556 .00236 Mdot
.51771 .00751 Mdot
.55636 .02389 Mdot
.67778 .07505 Mdot
.01379 .20766 Mdot
.32914 .1949 Mdot
.43466 .06522 Mdot
.4449 .00633 Mdot
.37415 .5743 Mdot
.13367 .46941 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50429 .00182 Mdot
.51366 .00579 Mdot
.54348 .01843 Mdot
.63773 .05825 Mdot
.91373 .17058 Mdot
.31289 .24669 Mdot
.49172 .11052 Mdot
.65813 .10285 Mdot
.02458 .22648 Mdot
.35431 .20378 Mdot
.50022 .0001 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50728 .00309 Mdot
.52318 .00983 Mdot
.57373 .03124 Mdot
.73097 .09718 Mdot
.12523 .24367 Mdot
.35044 .13919 Mdot
.3829 .02006 Mdot
.25513 .53907 Mdot
.88876 .3916 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49082 .61414 Mdot
.47075 .60563 Mdot
.40704 .57866 Mdot
.21169 .4973 Mdot
.78449 .35401 Mdot
.59044 .4981 Mdot
.52486 .5775 Mdot
.49641 .60045 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52176 .00923 Mdot
.56923 .02934 Mdot
.71731 .09152 Mdot
.0991 .23596 Mdot
.34166 .14991 Mdot
.384 .02617 Mdot
.26734 .54593 Mdot
.91336 .39926 Mdot
.68302 .47567 Mdot
.49874 .6175 Mdot
.496 .61634 Mdot
.48725 .61263 Mdot
.45939 .60082 Mdot
.37126 .56357 Mdot
.11042 .45682 Mdot
.69691 .36248 Mdot
.50899 .50189 Mdot
.33454 .51022 Mdot
.95424 .383 Mdot
.64164 .42484 Mdot
.49995 .61801 Mdot
.49984 .61796 Mdot
.49948 .61781 Mdot
.49834 .61733 Mdot
.4947 .61579 Mdot
.48312 .61088 Mdot
.44627 .59526 Mdot
.33035 .54639 Mdot
.00549 .41726 Mdot
.67239 .41217 Mdot
.55021 .54252 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51301 .00552 Mdot
.54143 .01756 Mdot
.63129 .05554 Mdot
.89649 .1639 Mdot
.30624 .25324 Mdot
.49201 .11481 Mdot
.66581 .10741 Mdot
.0457 .23479 Mdot
.35798 .193 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47487 .60738 Mdot
.42009 .58418 Mdot
.25042 .51317 Mdot
.84202 .36563 Mdot
.63354 .48919 Mdot
.6027 .59897 Mdot
.71543 .06967 Mdot
.06129 .21375 Mdot
.31747 .15833 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00249 Mdot
.51867 .00792 Mdot
.55943 .02519 Mdot
.68728 .07901 Mdot
.03556 .21525 Mdot
.33094 .18256 Mdot
.41781 .05369 Mdot
.38679 .59887 Mdot
.19993 .50255 Mdot
.78605 .36224 Mdot
.49961 .61787 Mdot
.49875 .6175 Mdot
.49603 .61635 Mdot
.48734 .61266 Mdot
.45967 .60094 Mdot
.37217 .56395 Mdot
.11288 .45778 Mdot
.69811 .3617 Mdot
.5095 .50147 Mdot
.33514 .51027 Mdot
.9554 .38334 Mdot
.4997 .61791 Mdot
.49905 .61763 Mdot
.49699 .61676 Mdot
.4904 .61396 Mdot
.46942 .60507 Mdot
.40284 .57689 Mdot
.1994 .4923 Mdot
.7692 .35215 Mdot
.57599 .49863 Mdot
.49249 .56643 Mdot
.39772 .55947 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49248 .61484 Mdot
.47604 .60787 Mdot
.4238 .58575 Mdot
.26157 .51777 Mdot
.86124 .37062 Mdot
.64366 .48357 Mdot
.61349 .59939 Mdot
.73949 .07787 Mdot
.1037 .2251 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48329 .61095 Mdot
.44679 .59548 Mdot
.33197 .54707 Mdot
.00938 .41866 Mdot
.67273 .40997 Mdot
.54722 .54047 Mdot
.49151 .5836 Mdot
.42307 .57574 Mdot
.24369 .50717 Mdot
.49828 .6173 Mdot
.49452 .61571 Mdot
.48255 .61063 Mdot
.44444 .59448 Mdot
.32469 .54402 Mdot
.99201 .41243 Mdot
.67131 .41983 Mdot
.56076 .54971 Mdot
.53915 .60468 Mdot
.57566 .02257 Mdot
.72144 .0901 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .61119 Mdot
.44864 .59626 Mdot
.33769 .54947 Mdot
.02335 .42376 Mdot
.67411 .40219 Mdot
.53696 .53327 Mdot
.45477 .56723 Mdot
.30563 .52586 Mdot
.49825 .61729 Mdot
.49443 .61567 Mdot
.48226 .61051 Mdot
.44353 .5941 Mdot
.32187 .54284 Mdot
.98542 .41009 Mdot
.6708 .42359 Mdot
.56597 .55324 Mdot
.55728 .61266 Mdot
.63267 .04659 Mdot
.8848 .15583 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50925 .00392 Mdot
.52947 .0125 Mdot
.59365 .03966 Mdot
.79032 .12155 Mdot
.21811 .26439 Mdot
.41194 .11979 Mdot
.48033 .04226 Mdot
.51928 .02407 Mdot
.58707 .0419 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51995 .00846 Mdot
.56348 .0269 Mdot
.69973 .08421 Mdot
.06291 .22446 Mdot
.33416 .16764 Mdot
.39928 .04025 Mdot
.32321 .57102 Mdot
.03323 .43881 Mdot
.69376 .40823 Mdot
.49847 .61738 Mdot
.49512 .61596 Mdot
.48444 .61144 Mdot
.45047 .59704 Mdot
.3434 .55186 Mdot
.03753 .429 Mdot
.67589 .39453 Mdot
.52756 .52636 Mdot
.42037 .55179 Mdot
.19866 .48101 Mdot
.75053 .34107 Mdot
.49898 .6176 Mdot
.49674 .61665 Mdot
.4896 .61362 Mdot
.46688 .60399 Mdot
.39484 .57351 Mdot
.1763 .48297 Mdot
.74416 .35096 Mdot
.5506 .49841 Mdot
.43167 .54453 Mdot
.21335 .48311 Mdot
.76261 .33946 Mdot
.49767 .61704 Mdot
.49257 .61488 Mdot
.47632 .60799 Mdot
.42468 .58612 Mdot
.26424 .51887 Mdot
.86601 .37192 Mdot
.64586 .48197 Mdot
.61512 .59904 Mdot
.7424 .07866 Mdot
.10814 .22604 Mdot
.32387 .13333 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.5263 .01115 Mdot
.58363 .03543 Mdot
.76069 .10943 Mdot
.17595 .25665 Mdot
.37786 .12478 Mdot
.41401 .02234 Mdot
.32735 .56448 Mdot
.02962 .43402 Mdot
.68771 .40672 Mdot
.50063 .00027 Mdot
.50199 .00084 Mdot
.50635 .00269 Mdot
.52022 .00857 Mdot
.56433 .02726 Mdot
.70234 .08529 Mdot
.06845 .22627 Mdot
.33502 .16475 Mdot
.39613 .03776 Mdot
.31225 .5662 Mdot
.00768 .4298 Mdot
.69159 .42268 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49856 .61743 Mdot
.49543 .61609 Mdot
.48543 .61186 Mdot
.45361 .59837 Mdot
.35318 .55597 Mdot
.06245 .43835 Mdot
.68043 .38193 Mdot
.5147 .51561 Mdot
.37099 .52922 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48933 .61351 Mdot
.46601 .60362 Mdot
.39209 .57235 Mdot
.16843 .47981 Mdot
.73671 .35122 Mdot
.5429 .49825 Mdot
.41264 .53753 Mdot
.15784 .46056 Mdot
.70322 .33706 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49236 .6148 Mdot
.47567 .60772 Mdot
.42263 .58525 Mdot
.25806 .51632 Mdot
.85506 .36897 Mdot
.64064 .48552 Mdot
.61078 .59958 Mdot
.73399 .07615 Mdot
.09473 .22295 Mdot
.49965 .61788 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48863 .61321 Mdot
.4638 .60269 Mdot
.38514 .56942 Mdot
.14876 .47194 Mdot
.72034 .35326 Mdot
.52652 .49825 Mdot
.37229 .52272 Mdot
.0464 .41662 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51105 .00469 Mdot
.5352 .01492 Mdot
.61172 .04729 Mdot
.8424 .14257 Mdot
.27269 .26594 Mdot
.46668 .11989 Mdot
.61104 .08922 Mdot
.90878 .18401 Mdot
.49758 .61701 Mdot
.49228 .61476 Mdot
.47542 .60761 Mdot
.42182 .58491 Mdot
.25562 .51532 Mdot
.85084 .36786 Mdot
.63845 .48677 Mdot
.60852 .59954 Mdot
.72905 .07449 Mdot
.08625 .22076 Mdot
.32031 .14466 Mdot
.5006 .00026 Mdot
.50193 .00082 Mdot
.50614 .0026 Mdot
.51955 .00829 Mdot
.56222 .02637 Mdot
.69586 .0826 Mdot
.05456 .22169 Mdot
.33301 .17209 Mdot
.40447 .04416 Mdot
.34108 .57886 Mdot
.077 .45482 Mdot
.70187 .38619 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.51009 .00428 Mdot
.53214 .01363 Mdot
.60209 .04323 Mdot
.81487 .13151 Mdot
.24683 .26697 Mdot
.44011 .11945 Mdot
.54565 .06523 Mdot
.71874 .10697 Mdot
.12596 .25168 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51964 .00833 Mdot
.56249 .02649 Mdot
.6967 .08294 Mdot
.05637 .22229 Mdot
.33324 .17112 Mdot
.4033 .0433 Mdot
.33708 .57711 Mdot
.49837 .61734 Mdot
.49479 .61583 Mdot
.48341 .611 Mdot
.44718 .59564 Mdot
.33317 .54757 Mdot
.01229 .41972 Mdot
.67299 .40834 Mdot
.54503 .53895 Mdot
.4837 .58013 Mdot
.39797 .56505 Mdot
.16947 .47681 Mdot
.49969 .6179 Mdot
.49901 .61762 Mdot
.49686 .6167 Mdot
.48999 .61379 Mdot
.46813 .60452 Mdot
.39878 .57517 Mdot
.18764 .48754 Mdot
.75586 .35118 Mdot
.56264 .49862 Mdot
.46099 .55521 Mdot
.30139 .5194 Mdot
.49866 .61747 Mdot
.49574 .61623 Mdot
.48644 .61228 Mdot
.45681 .59972 Mdot
.3632 .56018 Mdot
.08873 .4484 Mdot
.68796 .37034 Mdot
.508 .50682 Mdot
.34005 .51423 Mdot
.97056 .38968 Mdot
.64498 .41681 Mdot
.4983 .61731 Mdot
.4946 .61574 Mdot
.48279 .61074 Mdot
.44521 .59481 Mdot
.32707 .54502 Mdot
.99763 .41443 Mdot
.67175 .41663 Mdot
.55632 .5467 Mdot
.52363 .59783 Mdot
.52625 .00162 Mdot
.56805 .02584 Mdot
.49738 .61692 Mdot
.49167 .6145 Mdot
.47346 .60678 Mdot
.41562 .58229 Mdot
.23706 .50768 Mdot
.82056 .36062 Mdot
.61971 .4939 Mdot
.58196 .59471 Mdot
.66179 .04934 Mdot
.94462 .1748 Mdot
.30885 .22511 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48765 .6128 Mdot
.46066 .60135 Mdot
.37525 .56525 Mdot
.12131 .46109 Mdot
.70251 .35921 Mdot
.51191 .50023 Mdot
.33914 .51126 Mdot
.96412 .38626 Mdot
.64246 .41924 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.5057 .00242 Mdot
.51817 .0077 Mdot
.55783 .02451 Mdot
.68233 .07695 Mdot
.02431 .21136 Mdot
.32997 .1889 Mdot
.42639 .05959 Mdot
.4163 .6118 Mdot
.28637 .53773 Mdot
.92392 .39402 Mdot
.49742 .61694 Mdot
.4918 .61455 Mdot
.47386 .60695 Mdot
.41691 .58283 Mdot
.24089 .50925 Mdot
.82654 .36195 Mdot
.62384 .49276 Mdot
.58871 .59632 Mdot
.67986 .05634 Mdot
.98694 .18978 Mdot
.31359 .20188 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49087 .61416 Mdot
.47092 .6057 Mdot
.40758 .57889 Mdot
.21327 .49794 Mdot
.78656 .35431 Mdot
.59231 .49798 Mdot
.52889 .57884 Mdot
.50857 .60547 Mdot
.50109 .61341 Mdot
.49944 .6178 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48204 .61042 Mdot
.44284 .59381 Mdot
.31973 .54195 Mdot
.98043 .40834 Mdot
.67041 .42643 Mdot
.5699 .55591 Mdot
.57089 .00061 Mdot
.67474 .06418 Mdot
.50022 9e-05 Mdot
.5007 .00029 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.52249 .00954 Mdot
.57154 .03031 Mdot
.72431 .09442 Mdot
.11271 .24005 Mdot
.34583 .14407 Mdot
.3822 .02248 Mdot
.25756 .541 Mdot
.89445 .39362 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51093 .00463 Mdot
.5348 .01475 Mdot
.61045 .04676 Mdot
.83881 .14113 Mdot
.26968 .2663 Mdot
.46365 .11988 Mdot
.60356 .08647 Mdot
.88808 .17584 Mdot
.32698 .27126 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.48789 .6129 Mdot
.46142 .60168 Mdot
.37764 .56626 Mdot
.12789 .46368 Mdot
.70629 .35747 Mdot
.51447 .49949 Mdot
.34433 .51288 Mdot
.97618 .3905 Mdot
.64363 .4125 Mdot
.49948 .61781 Mdot
.49834 .61733 Mdot
.49472 .6158 Mdot
.48319 .61091 Mdot
.44648 .59535 Mdot
.33101 .54667 Mdot
.00707 .41783 Mdot
.67253 .41128 Mdot
.54899 .54168 Mdot
.49778 .58638 Mdot
.44324 .58432 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51351 .00573 Mdot
.54301 .01824 Mdot
.63626 .05763 Mdot
.90983 .16907 Mdot
.31153 .24827 Mdot
.49212 .11161 Mdot
.66091 .10431 Mdot
.03199 .22934 Mdot
.35541 .19988 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48569 .61197 Mdot
.45445 .59872 Mdot
.35579 .55706 Mdot
.06924 .44093 Mdot
.68207 .37875 Mdot
.51222 .51306 Mdot
.36068 .52438 Mdot
.02584 .41109 Mdot
.65241 .38725 Mdot
.50078 .00033 Mdot
.50249 .00105 Mdot
.50792 .00336 Mdot
.52522 .01069 Mdot
.5802 .03398 Mdot
.75045 .10522 Mdot
.15943 .25276 Mdot
.3673 .12847 Mdot
.3984 .01922 Mdot
.28724 .54933 Mdot
.94385 .40581 Mdot
.68295 .45679 Mdot
.49761 .61702 Mdot
.49237 .6148 Mdot
.4757 .60773 Mdot
.4227 .58528 Mdot
.25827 .51641 Mdot
.85543 .36907 Mdot
.64083 .4854 Mdot
.61096 .59958 Mdot
.73438 .07628 Mdot
.09538 .22311 Mdot
.32172 .13989 Mdot
.49905 .61763 Mdot
.49699 .61676 Mdot
.49041 .61397 Mdot
.46944 .60508 Mdot
.40293 .57693 Mdot
.19967 .49241 Mdot
.76951 .35218 Mdot
.5763 .49862 Mdot
.4932 .56668 Mdot
.39991 .56038 Mdot
.1662 .47359 Mdot
.50027 .00012 Mdot
.50088 .00037 Mdot
.50279 .00118 Mdot
.50889 .00377 Mdot
.52833 .01201 Mdot
.59002 .03813 Mdot
.77967 .11721 Mdot
.20391 .2622 Mdot
.39936 .12079 Mdot
.45372 .03359 Mdot
.43962 .60932 Mdot
.33712 .55468 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52314 .00981 Mdot
.57361 .03119 Mdot
.73059 .09702 Mdot
.12452 .24347 Mdot
.35016 .13945 Mdot
.38279 .02017 Mdot
.25509 .53911 Mdot
.88877 .39164 Mdot
.67604 .48656 Mdot
.49831 .61732 Mdot
.4946 .61575 Mdot
.48281 .61074 Mdot
.44527 .59484 Mdot
.32725 .54509 Mdot
.99807 .41459 Mdot
.67179 .41638 Mdot
.55598 .54646 Mdot
.52242 .59729 Mdot
.52237 .61801 Mdot
.55578 .02065 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50698 .00296 Mdot
.52225 .00943 Mdot
.57078 .02999 Mdot
.72201 .09346 Mdot
.10828 .23873 Mdot
.34438 .14592 Mdot
.3825 .02356 Mdot
.25997 .5423 Mdot
.89916 .39504 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48029 .60968 Mdot
.43728 .59145 Mdot
.30261 .5348 Mdot
.94212 .39524 Mdot
.66655 .44772 Mdot
.59765 .57545 Mdot
.6662 .04237 Mdot
.94116 .16993 Mdot
.30238 .22325 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.5041 .00174 Mdot
.51307 .00554 Mdot
.54161 .01764 Mdot
.63187 .05578 Mdot
.89807 .16452 Mdot
.30692 .25268 Mdot
.49215 .11448 Mdot
.66561 .1072 Mdot
.04501 .23448 Mdot
.3578 .19331 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51261 .00535 Mdot
.54017 .01703 Mdot
.62735 .05388 Mdot
.88581 .15974 Mdot
.30124 .25674 Mdot
.49019 .11678 Mdot
.66443 .10769 Mdot
.04373 .23442 Mdot
.35826 .19438 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.4805 .60976 Mdot
.43793 .59173 Mdot
.30461 .53564 Mdot
.94647 .39669 Mdot
.66712 .44539 Mdot
.59486 .57338 Mdot
.65661 .03817 Mdot
.91717 .16103 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50759 .00322 Mdot
.52417 .01025 Mdot
.57686 .03257 Mdot
.74041 .10108 Mdot
.14226 .24836 Mdot
.35802 .13335 Mdot
.38796 .0185 Mdot
.26337 .54104 Mdot
.9009 .39401 Mdot
.67765 .48006 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50406 .00172 Mdot
.51295 .00549 Mdot
.54123 .01748 Mdot
.63066 .05527 Mdot
.8948 .16325 Mdot
.3055 .25383 Mdot
.49183 .11516 Mdot
.66591 .10759 Mdot
.04616 .23501 Mdot
.35814 .19281 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48275 .61072 Mdot
.44509 .59476 Mdot
.32668 .54485 Mdot
.99671 .4141 Mdot
.67168 .41715 Mdot
.55705 .54719 Mdot
.52616 .59895 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50757 .00321 Mdot
.52413 .01023 Mdot
.57673 .03251 Mdot
.74002 .10092 Mdot
.14157 .24817 Mdot
.35768 .13357 Mdot
.38765 .01852 Mdot
.26276 .54084 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57519 .03186 Mdot
.73536 .09899 Mdot
.13326 .24592 Mdot
.35382 .13631 Mdot
.38467 .01906 Mdot
.25726 .53929 Mdot
.89136 .3919 Mdot
.67606 .48497 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.49541 .61609 Mdot
.48537 .61183 Mdot
.45342 .59829 Mdot
.3526 .55572 Mdot
.06096 .43779 Mdot
.6801 .38265 Mdot
.51531 .51619 Mdot
.37346 .53037 Mdot
.06118 .42503 Mdot
.49776 .61708 Mdot
.49287 .61501 Mdot
.47727 .6084 Mdot
.4277 .5874 Mdot
.27337 .52265 Mdot
.88289 .3767 Mdot
.65264 .47573 Mdot
.61783 .59652 Mdot
.74405 .07801 Mdot
.10884 .22545 Mdot
.3228 .13223 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52198 .00932 Mdot
.56994 .02964 Mdot
.71946 .09241 Mdot
.10333 .23724 Mdot
.34287 .14804 Mdot
.38317 .02491 Mdot
.26356 .54411 Mdot
.90608 .3971 Mdot
.68144 .4792 Mdot
.49863 .61745 Mdot
.49562 .61618 Mdot
.48605 .61212 Mdot
.45557 .5992 Mdot
.35932 .55855 Mdot
.07848 .44447 Mdot
.68463 .37462 Mdot
.50966 .50989 Mdot
.34915 .51884 Mdot
.99477 .39901 Mdot
.64823 .40386 Mdot
.49811 .61723 Mdot
.49399 .61549 Mdot
.48086 .60992 Mdot
.43908 .59221 Mdot
.30812 .5371 Mdot
.95418 .39929 Mdot
.66802 .44118 Mdot
.58962 .56958 Mdot
.63866 .03031 Mdot
.87035 .14319 Mdot
.27571 .25053 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50289 .00123 Mdot
.50921 .00391 Mdot
.52935 .01244 Mdot
.59326 .0395 Mdot
.78919 .12109 Mdot
.21666 .26419 Mdot
.41061 .11987 Mdot
.47741 .04129 Mdot
.51044 .02041 Mdot
.55911 .03008 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.44211 .5935 Mdot
.31746 .541 Mdot
.97522 .40651 Mdot
.67 .4294 Mdot
.57397 .55869 Mdot
.58495 .00679 Mdot
.71739 .08185 Mdot
.08356 .22631 Mdot
.49741 .61693 Mdot
.49174 .61453 Mdot
.47369 .60688 Mdot
.41636 .5826 Mdot
.23926 .50858 Mdot
.82397 .36137 Mdot
.62209 .49326 Mdot
.58591 .59567 Mdot
.67243 .05347 Mdot
.96988 .18383 Mdot
.31224 .21159 Mdot
.49826 .61729 Mdot
.49444 .61568 Mdot
.4823 .61053 Mdot
.44366 .59415 Mdot
.32225 .543 Mdot
.9863 .4104 Mdot
.67087 .42309 Mdot
.56527 .55277 Mdot
.55485 .61159 Mdot
.62508 .04341 Mdot
.86422 .14779 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50685 .00291 Mdot
.52184 .00926 Mdot
.56947 .02944 Mdot
.71802 .09181 Mdot
.10051 .23639 Mdot
.34205 .14928 Mdot
.3837 .02574 Mdot
.26601 .5453 Mdot
.9108 .3985 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .00241 Mdot
.51807 .00766 Mdot
.55751 .02438 Mdot
.68136 .07654 Mdot
.02209 .21058 Mdot
.32979 .19017 Mdot
.42813 .06078 Mdot
.42229 .61443 Mdot
.30446 .54521 Mdot
.96174 .40622 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49146 .61441 Mdot
.47281 .6065 Mdot
.41355 .58141 Mdot
.23092 .50516 Mdot
.81126 .35867 Mdot
.61287 .49542 Mdot
.56994 .5915 Mdot
.62858 .03624 Mdot
.85979 .14289 Mdot
.4986 .61744 Mdot
.49555 .61615 Mdot
.48582 .61202 Mdot
.45486 .5989 Mdot
.35709 .55761 Mdot
.07261 .44222 Mdot
.68296 .37722 Mdot
.51117 .51186 Mdot
.35613 .52221 Mdot
.01349 .40627 Mdot
.65064 .39378 Mdot
.49974 .61792 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49165 .61449 Mdot
.4734 .60676 Mdot
.41545 .58221 Mdot
.23654 .50746 Mdot
.81975 .36045 Mdot
.61914 .49405 Mdot
.581 .59446 Mdot
.65918 .04832 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48442 .61143 Mdot
.4504 .59701 Mdot
.34316 .55176 Mdot
.03694 .42878 Mdot
.67581 .39484 Mdot
.52793 .52664 Mdot
.42172 .5524 Mdot
.20277 .48272 Mdot
.75552 .34162 Mdot
.49847 .61739 Mdot
.49514 .61597 Mdot
.48451 .61146 Mdot
.45067 .59712 Mdot
.34402 .55212 Mdot
.03909 .42958 Mdot
.67612 .3937 Mdot
.5266 .52563 Mdot
.41681 .55018 Mdot
.18785 .47652 Mdot
.73812 .34009 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48134 .61012 Mdot
.4406 .59286 Mdot
.31281 .53906 Mdot
.96465 .40286 Mdot
.66908 .43536 Mdot
.58203 .56424 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51143 .00485 Mdot
.53641 .01544 Mdot
.61554 .0489 Mdot
.85314 .14685 Mdot
.28108 .26448 Mdot
.47482 .11974 Mdot
.63094 .09649 Mdot
.96205 .20464 Mdot
.34955 .23949 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.5054 .00229 Mdot
.51721 .0073 Mdot
.55478 .02322 Mdot
.6729 .073 Mdot
.00228 .20357 Mdot
.32824 .20145 Mdot
.44374 .07138 Mdot
.4766 .02031 Mdot
.4745 .61673 Mdot
.4343 .59319 Mdot
.49872 .61749 Mdot
.49592 .6163 Mdot
.487 .61252 Mdot
.45861 .60049 Mdot
.36884 .56255 Mdot
.10385 .45426 Mdot
.69391 .36467 Mdot
.50802 .50315 Mdot
.33416 .51058 Mdot
.95418 .38319 Mdot
.64198 .42508 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50413 .00175 Mdot
.51314 .00557 Mdot
.54186 .01775 Mdot
.63264 .05611 Mdot
.90013 .16532 Mdot
.30779 .25195 Mdot
.49228 .11402 Mdot
.66519 .10686 Mdot
.04373 .23395 Mdot
.3575 .19392 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48646 .61229 Mdot
.4569 .59976 Mdot
.36347 .56029 Mdot
.08945 .44868 Mdot
.68821 .37006 Mdot
.50794 .50662 Mdot
.33956 .51397 Mdot
.96927 .38918 Mdot
.64479 .41749 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48816 .61301 Mdot
.4623 .60205 Mdot
.38043 .56743 Mdot
.1356 .46672 Mdot
.7111 .35568 Mdot
.51824 .49884 Mdot
.35268 .51571 Mdot
.99636 .39782 Mdot
.6455 .40119 Mdot
.49902 .61762 Mdot
.49687 .61671 Mdot
.49003 .61381 Mdot
.46824 .60457 Mdot
.39913 .57532 Mdot
.18865 .48795 Mdot
.75696 .35123 Mdot
.56376 .49863 Mdot
.46368 .55618 Mdot
.30959 .5228 Mdot
.9333 .38547 Mdot
.49912 .61766 Mdot
.4972 .61685 Mdot
.49107 .61425 Mdot
.47155 .60597 Mdot
.40958 .57973 Mdot
.21915 .50034 Mdot
.79446 .35556 Mdot
.59925 .49739 Mdot
.54344 .58355 Mdot
.552 .00529 Mdot
.63719 .05265 Mdot
.49828 .6173 Mdot
.49452 .61571 Mdot
.48253 .61063 Mdot
.44438 .59446 Mdot
.3245 .54394 Mdot
.99157 .41227 Mdot
.67128 .42008 Mdot
.5611 .54994 Mdot
.54034 .6052 Mdot
.57943 .02416 Mdot
.73279 .09478 Mdot
.4993 .61774 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.4275 .58731 Mdot
.27276 .5224 Mdot
.88173 .37636 Mdot
.65222 .47619 Mdot
.61779 .59675 Mdot
.74434 .07822 Mdot
.10948 .22567 Mdot
.49777 .61709 Mdot
.49288 .61501 Mdot
.47732 .60842 Mdot
.42784 .58746 Mdot
.2738 .52283 Mdot
.88369 .37693 Mdot
.65293 .47541 Mdot
.61785 .59635 Mdot
.74382 .07786 Mdot
.10834 .22529 Mdot
.32262 .13243 Mdot
.49838 .61735 Mdot
.49484 .61584 Mdot
.48355 .61106 Mdot
.44762 .59583 Mdot
.33453 .54814 Mdot
.01559 .42092 Mdot
.6733 .40649 Mdot
.54257 .53723 Mdot
.47493 .57623 Mdot
.36983 .55308 Mdot
.09053 .44542 Mdot
.5 .61803 Mdot
.49999 .61803 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48045 .60974 Mdot
.43777 .59166 Mdot
.30411 .53543 Mdot
.49846 .61738 Mdot
.49509 .61595 Mdot
.48437 .61141 Mdot
.45023 .59694 Mdot
.34266 .55155 Mdot
.03567 .42831 Mdot
.67563 .39551 Mdot
.52872 .52724 Mdot
.42466 .55372 Mdot
.21177 .48646 Mdot
.767 .34315 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47696 .60826 Mdot
.42672 .58698 Mdot
.27039 .52142 Mdot
.87729 .37508 Mdot
.65055 .4779 Mdot
.61744 .59757 Mdot
.74492 .07879 Mdot
.11102 .22626 Mdot
.32377 .13148 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47458 .60726 Mdot
.41918 .58379 Mdot
.24769 .51205 Mdot
.83749 .36452 Mdot
.63085 .49032 Mdot
.59912 .59842 Mdot
.70664 .06645 Mdot
.04408 .20855 Mdot
.31625 .16821 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51979 .00839 Mdot
.56299 .0267 Mdot
.69822 .08358 Mdot
.05966 .22338 Mdot
.33369 .16936 Mdot
.40124 .04175 Mdot
.32998 .57399 Mdot
.04949 .44469 Mdot
.69596 .39954 Mdot
.49931 .61774 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47759 .60853 Mdot
.42871 .58782 Mdot
.27642 .52392 Mdot
.88869 .3784 Mdot
.65464 .47338 Mdot
.61774 .59523 Mdot
.74176 .07665 Mdot
.10421 .224 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51216 .00516 Mdot
.53874 .01642 Mdot
.62284 .05198 Mdot
.87346 .15489 Mdot
.29451 .26022 Mdot
.4861 .11841 Mdot
.65687 .10554 Mdot
.02666 .22854 Mdot
.35664 .20394 Mdot
.50048 .0002 Mdot
.50152 .00064 Mdot
.50484 .00205 Mdot
.51542 .00654 Mdot
.5491 .02082 Mdot
.65528 .06562 Mdot
.95914 .1878 Mdot
.32362 .22526 Mdot
.47445 .09322 Mdot
.58713 .06964 Mdot
.82407 .14644 Mdot
.27435 .27829 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48645 .61229 Mdot
.45686 .59974 Mdot
.36334 .56024 Mdot
.08912 .44855 Mdot
.68809 .37019 Mdot
.50797 .50671 Mdot
.33978 .51409 Mdot
.96986 .38941 Mdot
.49821 .61728 Mdot
.49431 .61562 Mdot
.48188 .61035 Mdot
.44232 .59359 Mdot
.31813 .54128 Mdot
.97676 .40705 Mdot
.67012 .42852 Mdot
.57277 .55787 Mdot
.58082 .00498 Mdot
.70497 .07672 Mdot
.05835 .2184 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50315 .00134 Mdot
.51005 .00426 Mdot
.532 .01357 Mdot
.60164 .04304 Mdot
.81359 .13099 Mdot
.24547 .26691 Mdot
.43871 .11943 Mdot
.54227 .064 Mdot
.49895 .61759 Mdot
.49665 .61661 Mdot
.48933 .61351 Mdot
.46602 .60363 Mdot
.39214 .57237 Mdot
.16856 .47986 Mdot
.73683 .35121 Mdot
.54302 .49825 Mdot
.41294 .53764 Mdot
.1587 .4609 Mdot
.70394 .33698 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.51098 .00466 Mdot
.53498 .01483 Mdot
.61103 .047 Mdot
.84043 .14178 Mdot
.27106 .26614 Mdot
.46504 .11989 Mdot
.607 .08773 Mdot
.89763 .17962 Mdot
.33145 .26811 Mdot
.49915 .61767 Mdot
.49728 .61688 Mdot
.49134 .61436 Mdot
.47241 .60633 Mdot
.41229 .58088 Mdot
.22716 .50362 Mdot
.80576 .35759 Mdot
.60859 .49617 Mdot
.56194 .58921 Mdot
.60589 .02716 Mdot
.79722 .11825 Mdot
.49875 .6175 Mdot
.49602 .61635 Mdot
.48732 .61266 Mdot
.45961 .60091 Mdot
.37198 .56387 Mdot
.11236 .45758 Mdot
.69786 .36186 Mdot
.50939 .50155 Mdot
.33499 .51025 Mdot
.9551 .38325 Mdot
.64167 .42432 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.5091 .00386 Mdot
.52899 .01229 Mdot
.59212 .03902 Mdot
.78584 .11972 Mdot
.21226 .26355 Mdot
.40663 .12013 Mdot
.46885 .03845 Mdot
.48465 .00976 Mdot
.49979 .61794 Mdot
.49933 .61775 Mdot
.49785 .61712 Mdot
.49315 .61513 Mdot
.47818 .60878 Mdot
.43059 .58862 Mdot
.28215 .52629 Mdot
.89982 .38175 Mdot
.65804 .4686 Mdot
.61623 .5922 Mdot
.73368 .07259 Mdot
.49769 .61705 Mdot
.49263 .61491 Mdot
.47651 .60807 Mdot
.42528 .58637 Mdot
.26605 .51962 Mdot
.8693 .37283 Mdot
.64729 .48083 Mdot
.61601 .5987 Mdot
.74375 .07894 Mdot
.11003 .22638 Mdot
.3241 .1323 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50752 .00319 Mdot
.52395 .01016 Mdot
.57618 .03228 Mdot
.73837 .10024 Mdot
.13865 .24739 Mdot
.35628 .1345 Mdot
.38647 .01865 Mdot
.26043 .54014 Mdot
.89617 .39291 Mdot
.67684 .48248 Mdot
.49853 .61741 Mdot
.49533 .61605 Mdot
.48512 .61172 Mdot
.45262 .59795 Mdot
.35011 .55468 Mdot
.05455 .43537 Mdot
.67876 .38578 Mdot
.51818 .51879 Mdot
.38482 .53561 Mdot
.09337 .43791 Mdot
.66976 .35623 Mdot
.49888 .61756 Mdot
.49644 .61652 Mdot
.48866 .61322 Mdot
.46387 .60271 Mdot
.38535 .56951 Mdot
.14934 .47218 Mdot
.72078 .35317 Mdot
.52694 .49823 Mdot
.37331 .52309 Mdot
.0491 .41766 Mdot
.6524 .37286 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50324 .00137 Mdot
.51033 .00438 Mdot
.5329 .01395 Mdot
.60446 .04423 Mdot
.8217 .13426 Mdot
.25385 .26709 Mdot
.44734 .11958 Mdot
.56328 .07165 Mdot
.77166 .12879 Mdot
.21656 .27497 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51997 .00847 Mdot
.56356 .02694 Mdot
.69997 .08431 Mdot
.06341 .22462 Mdot
.33423 .16738 Mdot
.39899 .04002 Mdot
.32219 .57057 Mdot
.0308 .43795 Mdot
.6935 .40957 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.47491 .6074 Mdot
.42022 .58423 Mdot
.25081 .51333 Mdot
.84267 .36579 Mdot
.63392 .48902 Mdot
.60318 .59903 Mdot
.7166 .07009 Mdot
.0635 .2144 Mdot
.31766 .15708 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.50482 .00204 Mdot
.51534 .00651 Mdot
.54885 .02071 Mdot
.65447 .06528 Mdot
.95711 .18704 Mdot
.3233 .22632 Mdot
.47565 .09415 Mdot
.5916 .07166 Mdot
.8375 .15197 Mdot
.28695 .27778 Mdot
.49993 .618 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49774 .61708 Mdot
.49281 .61499 Mdot
.47711 .60833 Mdot
.42718 .58718 Mdot
.2718 .522 Mdot
.87991 .37584 Mdot
.65155 .4769 Mdot
.61768 .5971 Mdot
.50051 .00021 Mdot
.50161 .00068 Mdot
.50513 .00218 Mdot
.51635 .00693 Mdot
.55204 .02206 Mdot
.66442 .06945 Mdot
.98184 .19618 Mdot
.32644 .21297 Mdot
.45932 .08212 Mdot
.53184 .04482 Mdot
.65179 .07413 Mdot
.96644 .19447 Mdot
.49741 .61693 Mdot
.49173 .61453 Mdot
.47367 .60687 Mdot
.41628 .58257 Mdot
.23901 .50848 Mdot
.82358 .36129 Mdot
.62182 .49334 Mdot
.58547 .59557 Mdot
.67125 .05302 Mdot
.96714 .18287 Mdot
.31197 .21312 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50697 .00296 Mdot
.52221 .00942 Mdot
.57066 .02994 Mdot
.72166 .09332 Mdot
.10761 .23853 Mdot
.34417 .1462 Mdot
.38258 .02374 Mdot
.2604 .54252 Mdot
.89999 .39529 Mdot
.67992 .48202 Mdot
.498 .61718 Mdot
.49362 .61533 Mdot
.47966 .60941 Mdot
.43528 .5906 Mdot
.29647 .53225 Mdot
.92903 .39095 Mdot
.66455 .45458 Mdot
.60522 .58136 Mdot
.69247 .05392 Mdot
.00302 .19193 Mdot
.30904 .18913 Mdot
.49779 .61709 Mdot
.49294 .61504 Mdot
.47752 .6085 Mdot
.42849 .58773 Mdot
.27576 .52364 Mdot
.88742 .37803 Mdot
.65421 .47391 Mdot
.6178 .59553 Mdot
.74238 .077 Mdot
.10543 .22437 Mdot
.32164 .13363 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.48491 .61163 Mdot
.45194 .59766 Mdot
.34797 .55378 Mdot
.0491 .43332 Mdot
.67774 .38852 Mdot
.52092 .52112 Mdot
.3954 .54046 Mdot
.12402 .45032 Mdot
.68488 .34663 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.4998 .61795 Mdot
.49936 .61776 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47928 .60925 Mdot
.43408 .5901 Mdot
.29279 .53071 Mdot
.92134 .38847 Mdot
.66314 .45845 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52445 .01037 Mdot
.57774 .03294 Mdot
.74307 .10218 Mdot
.1469 .24958 Mdot
.36036 .13193 Mdot
.39023 .01846 Mdot
.26818 .5426 Mdot
.90895 .39602 Mdot
.67897 .4759 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.501 .00043 Mdot
.5032 .00136 Mdot
.51018 .00432 Mdot
.53243 .01375 Mdot
.60298 .0436 Mdot
.81745 .13255 Mdot
.24953 .26704 Mdot
.44288 .1195 Mdot
.55239 .06768 Mdot
.73906 .11537 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50698 .00296 Mdot
.52224 .00943 Mdot
.57074 .02998 Mdot
.7219 .09342 Mdot
.10809 .23867 Mdot
.34432 .146 Mdot
.38253 .02361 Mdot
.26009 .54236 Mdot
.8994 .39512 Mdot
.67976 .48229 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50486 .00206 Mdot
.51548 .00657 Mdot
.5493 .0209 Mdot
.65588 .06587 Mdot
.96065 .18836 Mdot
.32385 .22447 Mdot
.47355 .09252 Mdot
.58377 .06812 Mdot
.81393 .14224 Mdot
.26381 .27805 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52053 .0087 Mdot
.56532 .02768 Mdot
.70536 .08655 Mdot
.0748 .22833 Mdot
.33613 .16151 Mdot
.39283 .03505 Mdot
.30067 .56107 Mdot
.98177 .42094 Mdot
.49894 .61758 Mdot
.49661 .6166 Mdot
.48921 .61346 Mdot
.46563 .60346 Mdot
.3909 .57185 Mdot
.16503 .47844 Mdot
.73365 .35143 Mdot
.53975 .4982 Mdot
.40486 .53466 Mdot
.1356 .45162 Mdot
.68667 .34058 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.49272 .61494 Mdot
.47679 .60819 Mdot
.42619 .58676 Mdot
.26879 .52076 Mdot
.87433 .37424 Mdot
.64938 .47901 Mdot
.61703 .59804 Mdot
.74483 .07898 Mdot
.11123 .22645 Mdot
.49911 .61766 Mdot
.49716 .61683 Mdot
.49097 .6142 Mdot
.47122 .60583 Mdot
.40854 .5793 Mdot
.21611 .4991 Mdot
.79033 .35489 Mdot
.59566 .49772 Mdot
.536 .58116 Mdot
.52989 .61426 Mdot
.56835 .02377 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50327 .00139 Mdot
.51042 .00442 Mdot
.53318 .01407 Mdot
.60536 .04461 Mdot
.82428 .1353 Mdot
.25641 .26707 Mdot
.44999 .11964 Mdot
.56979 .07404 Mdot
.79094 .13668 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47426 .60712 Mdot
.41817 .58336 Mdot
.24466 .5108 Mdot
.83255 .36334 Mdot
.62778 .49148 Mdot
.59473 .59761 Mdot
.69555 .06231 Mdot
.02126 .2013 Mdot
.49812 .61724 Mdot
.49401 .6155 Mdot
.48093 .60995 Mdot
.43931 .59231 Mdot
.30883 .5374 Mdot
.95575 .39982 Mdot
.66819 .44031 Mdot
.58852 .56879 Mdot
.63487 .02865 Mdot
.86018 .13925 Mdot
.26926 .25283 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47565 .60771 Mdot
.42255 .58522 Mdot
.2578 .51621 Mdot
.85461 .36885 Mdot
.64041 .48565 Mdot
.61055 .59958 Mdot
.7335 .07599 Mdot
.09391 .22274 Mdot
.32148 .14065 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51961 .00831 Mdot
.5624 .02645 Mdot
.69641 .08282 Mdot
.05576 .22209 Mdot
.33316 .17145 Mdot
.4037 .04359 Mdot
.33843 .5777 Mdot
.07035 .45235 Mdot
.70014 .38924 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48593 .61207 Mdot
.4552 .59904 Mdot
.35815 .55806 Mdot
.0754 .44329 Mdot
.68373 .37597 Mdot
.5104 .51091 Mdot
.35266 .52054 Mdot
.49797 .61717 Mdot
.49352 .61529 Mdot
.47935 .60928 Mdot
.43431 .59019 Mdot
.29349 .53101 Mdot
.92281 .38894 Mdot
.66342 .45773 Mdot
.60831 .58397 Mdot
.70341 .05878 Mdot
.0271 .20005 Mdot
.31033 .17505 Mdot
.49872 .61749 Mdot
.49591 .6163 Mdot
.48697 .61251 Mdot
.4585 .60044 Mdot
.36848 .5624 Mdot
.10289 .45389 Mdot
.69349 .36501 Mdot
.50793 .50335 Mdot
.33426 .5107 Mdot
.95454 .38335 Mdot
.64209 .42493 Mdot
.49937 .61777 Mdot
.49801 .61719 Mdot
.49365 .61534 Mdot
.47977 .60946 Mdot
.43562 .59075 Mdot
.29752 .53268 Mdot
.93125 .39167 Mdot
.66493 .45344 Mdot
.60403 .5804 Mdot
.68831 .05209 Mdot
.99362 .18869 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.5028 .00119 Mdot
.50893 .00379 Mdot
.52846 .01207 Mdot
.59044 .03831 Mdot
.7809 .11771 Mdot
.20561 .26248 Mdot
.40081 .12064 Mdot
.45667 .03452 Mdot
.44834 .61289 Mdot
.36388 .56583 Mdot
.49793 .61716 Mdot
.49342 .61524 Mdot
.47903 .60914 Mdot
.43326 .58975 Mdot
.29031 .52968 Mdot
.91623 .38684 Mdot
.66209 .46096 Mdot
.61117 .58657 Mdot
.71378 .06342 Mdot
.04897 .20716 Mdot
.31186 .16248 Mdot
.49915 .61768 Mdot
.49731 .61689 Mdot
.49142 .6144 Mdot
.47267 .60645 Mdot
.41313 .58124 Mdot
.22966 .50464 Mdot
.8094 .3583 Mdot
.61144 .49569 Mdot
.56732 .59076 Mdot
.62119 .03329 Mdot
.83978 .1351 Mdot
.49875 .6175 Mdot
.49602 .61635 Mdot
.48732 .61266 Mdot
.45963 .60092 Mdot
.37202 .56389 Mdot
.11248 .45763 Mdot
.69792 .36182 Mdot
.50941 .50153 Mdot
.33503 .51026 Mdot
.95517 .38327 Mdot
.64167 .42428 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51513 .00642 Mdot
.54817 .02042 Mdot
.65237 .0644 Mdot
.95176 .18504 Mdot
.32241 .22907 Mdot
.47862 .09654 Mdot
.60285 .07678 Mdot
.87084 .16563 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50652 .00277 Mdot
.52079 .00881 Mdot
.56614 .02803 Mdot
.70786 .08759 Mdot
.07999 .22999 Mdot
.33713 .15892 Mdot
.39042 .03294 Mdot
.29202 .55722 Mdot
.96315 .41479 Mdot
.68907 .44864 Mdot
.50057 .00024 Mdot
.5018 .00076 Mdot
.50574 .00243 Mdot
.51829 .00776 Mdot
.55821 .02467 Mdot
.68352 .07744 Mdot
.02703 .2123 Mdot
.33019 .18737 Mdot
.42429 .05816 Mdot
.40906 .60862 Mdot
.26473 .52883 Mdot
.88269 .38192 Mdot
.49897 .6176 Mdot
.49672 .61664 Mdot
.48954 .6136 Mdot
.46669 .60391 Mdot
.39424 .57326 Mdot
.17456 .48227 Mdot
.74247 .35099 Mdot
.54885 .49837 Mdot
.42736 .54295 Mdot
.20064 .47792 Mdot
.74658 .33741 Mdot
.49753 .61698 Mdot
.49212 .61469 Mdot
.47489 .60739 Mdot
.42015 .5842 Mdot
.2506 .51325 Mdot
.84232 .3657 Mdot
.63372 .48911 Mdot
.60292 .599 Mdot
.71597 .06987 Mdot
.06231 .21405 Mdot
.31756 .15775 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50791 .00336 Mdot
.52521 .01069 Mdot
.58017 .03396 Mdot
.75035 .10518 Mdot
.15927 .25272 Mdot
.36721 .12851 Mdot
.39827 .0192 Mdot
.28693 .54922 Mdot
.94326 .40563 Mdot
.6829 .45713 Mdot
.49765 .61704 Mdot
.49251 .61486 Mdot
.47614 .60792 Mdot
.42412 .58588 Mdot
.26253 .51817 Mdot
.86296 .37108 Mdot
.64447 .483 Mdot
.61413 .59928 Mdot
.74067 .07821 Mdot
.10554 .2255 Mdot
.32345 .13467 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.53111 .01319 Mdot
.59882 .04185 Mdot
.80542 .12769 Mdot
.23643 .26638 Mdot
.42957 .11937 Mdot
.52047 .05618 Mdot
.642 .07511 Mdot
.94938 .18997 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50387 .00164 Mdot
.51234 .00523 Mdot
.53931 .01667 Mdot
.62465 .05274 Mdot
.87842 .15684 Mdot
.29734 .2589 Mdot
.488 .11784 Mdot
.66068 .10672 Mdot
.03547 .23163 Mdot
.3575 .19902 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50183 .00078 Mdot
.50583 .00247 Mdot
.51858 .00788 Mdot
.55912 .02506 Mdot
.68633 .07862 Mdot
.03343 .21452 Mdot
.33075 .18375 Mdot
.41941 .05479 Mdot
.39228 .60127 Mdot
.21563 .50886 Mdot
.50037 .00016 Mdot
.50117 .00049 Mdot
.50372 .00158 Mdot
.51184 .00502 Mdot
.53771 .01599 Mdot
.61962 .05062 Mdot
.86453 .15136 Mdot
.28898 .26233 Mdot
.48183 .11919 Mdot
.64748 .10238 Mdot
.00402 .22036 Mdot
.35453 .21663 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47983 .60948 Mdot
.43582 .59083 Mdot
.29812 .53293 Mdot
.93253 .39208 Mdot
.66514 .45278 Mdot
.60333 .57984 Mdot
.68587 .05101 Mdot
.98801 .18674 Mdot
.30812 .19784 Mdot
.49938 .61777 Mdot
.49804 .6172 Mdot
.49375 .61539 Mdot
.4801 .6096 Mdot
.43669 .5912 Mdot
.30079 .53404 Mdot
.93821 .39395 Mdot
.66601 .4498 Mdot
.60005 .57727 Mdot
.67449 .046 Mdot
.96128 .17725 Mdot
.49983 .61796 Mdot
.49945 .6178 Mdot
.49823 .61729 Mdot
.49438 .61565 Mdot
.48208 .61044 Mdot
.44297 .59386 Mdot
.32014 .54212 Mdot
.98139 .40867 Mdot
.67049 .42589 Mdot
.56914 .5554 Mdot
.56828 .6175 Mdot
.50029 .00012 Mdot
.50094 .0004 Mdot
.50299 .00127 Mdot
.50953 .00404 Mdot
.53036 .01287 Mdot
.59645 .04085 Mdot
.79852 .12488 Mdot
.22831 .26563 Mdot
.42158 .11945 Mdot
.50194 .04966 Mdot
.5852 .05146 Mdot
.79024 .12672 Mdot
.49871 .61749 Mdot
.49588 .61629 Mdot
.48689 .61247 Mdot
.45824 .60033 Mdot
.36768 .56206 Mdot
.10072 .45305 Mdot
.69257 .36578 Mdot
.50777 .50382 Mdot
.33462 .51102 Mdot
.95569 .38384 Mdot
.64237 .42439 Mdot
.50067 .00029 Mdot
.50215 .00091 Mdot
.50685 .0029 Mdot
.52181 .00925 Mdot
.56938 .0294 Mdot
.71775 .0917 Mdot
.09997 .23622 Mdot
.3419 .14952 Mdot
.38381 .0259 Mdot
.26652 .54554 Mdot
.91177 .39879 Mdot
.68269 .47646 Mdot
.49923 .61771 Mdot
.49756 .617 Mdot
.49221 .61473 Mdot
.4752 .60752 Mdot
.42113 .58462 Mdot
.25354 .51446 Mdot
.84727 .36695 Mdot
.63652 .48778 Mdot
.60635 .59939 Mdot
.72409 .07277 Mdot
.07741 .21836 Mdot
.4996 .61786 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.48692 .61249 Mdot
.45835 .60038 Mdot
.36801 .5622 Mdot
.10161 .45339 Mdot
.69294 .36546 Mdot
.50783 .50363 Mdot
.33445 .51088 Mdot
.95516 .38362 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50625 .00265 Mdot
.5199 .00844 Mdot
.56334 .02684 Mdot
.69929 .08402 Mdot
.06197 .22414 Mdot
.33402 .16814 Mdot
.39984 .04068 Mdot
.32515 .57187 Mdot
.03785 .44047 Mdot
.69431 .40571 Mdot
.49864 .61746 Mdot
.49567 .6162 Mdot
.48621 .61219 Mdot
.45608 .59941 Mdot
.36091 .55921 Mdot
.08266 .44607 Mdot
.68592 .37283 Mdot
.50883 .50858 Mdot
.34496 .51676 Mdot
.98361 .39471 Mdot
.6468 .40988 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48652 .61232 Mdot
.45708 .59984 Mdot
.36405 .56053 Mdot
.091 .44928 Mdot
.68877 .36944 Mdot
.50781 .5062 Mdot
.33858 .51344 Mdot
.96665 .38817 Mdot
.64438 .41886 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47781 .60862 Mdot
.4294 .58812 Mdot
.27854 .52479 Mdot
.89277 .37961 Mdot
.65595 .47167 Mdot
.61738 .5942 Mdot
.73935 .07538 Mdot
.09952 .2226 Mdot
.31995 .13623 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50592 .00251 Mdot
.51884 .00799 Mdot
.55997 .02542 Mdot
.68895 .07971 Mdot
.03931 .21653 Mdot
.3313 .18046 Mdot
.41504 .05175 Mdot
.37731 .59472 Mdot
.17324 .49191 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50813 .00345 Mdot
.52589 .01098 Mdot
.58231 .03487 Mdot
.75678 .10783 Mdot
.16976 .25524 Mdot
.37371 .12605 Mdot
.4075 .02088 Mdot
.31021 .5579 Mdot
.99106 .42079 Mdot
.49925 .61772 Mdot
.49762 .61702 Mdot
.4924 .61481 Mdot
.4758 .60777 Mdot
.42304 .58543 Mdot
.25928 .51683 Mdot
.8572 .36953 Mdot
.64171 .48485 Mdot
.6118 .59955 Mdot
.73613 .07684 Mdot
.09828 .22382 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48618 .61218 Mdot
.456 .59938 Mdot
.36067 .55911 Mdot
.08203 .44583 Mdot
.68572 .3731 Mdot
.50894 .50877 Mdot
.34555 .51706 Mdot
.98518 .39531 Mdot
.64701 .40903 Mdot
.49899 .6176 Mdot
.49677 .61666 Mdot
.4897 .61367 Mdot
.46721 .60413 Mdot
.39587 .57394 Mdot
.17924 .48415 Mdot
.74709 .35095 Mdot
.55363 .49847 Mdot
.4391 .54725 Mdot
.23544 .49217 Mdot
.79405 .34524 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50657 .00279 Mdot
.52094 .00888 Mdot
.56664 .02824 Mdot
.70939 .08823 Mdot
.08315 .231 Mdot
.33778 .15737 Mdot
.38908 .0317 Mdot
.28713 .55503 Mdot
.95293 .41148 Mdot
.49939 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48043 .60974 Mdot
.43772 .59164 Mdot
.30396 .53536 Mdot
.94505 .39622 Mdot
.66694 .44615 Mdot
.59579 .57406 Mdot
.65979 .03956 Mdot
.9252 .16403 Mdot
.49836 .61734 Mdot
.49478 .61582 Mdot
.48338 .61099 Mdot
.44709 .5956 Mdot
.33287 .54745 Mdot
.01157 .41946 Mdot
.67293 .40874 Mdot
.54556 .53932 Mdot
.48562 .58099 Mdot
.40413 .56767 Mdot
.18738 .48407 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50661 .0028 Mdot
.52105 .00892 Mdot
.56696 .02838 Mdot
.71038 .08864 Mdot
.08517 .23163 Mdot
.33822 .15639 Mdot
.38827 .03094 Mdot
.28417 .55369 Mdot
.94682 .40954 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.5209 .00886 Mdot
.56649 .02818 Mdot
.70893 .08804 Mdot
.08221 .2307 Mdot
.33758 .15783 Mdot
.38947 .03207 Mdot
.28856 .55567 Mdot
.95589 .41243 Mdot
.68854 .45281 Mdot
.50045 .00019 Mdot
.50145 .00061 Mdot
.50461 .00196 Mdot
.51469 .00623 Mdot
.54679 .01983 Mdot
.64805 .06259 Mdot
.94072 .18088 Mdot
.32027 .23457 Mdot
.48397 .10118 Mdot
.62368 .08634 Mdot
.9308 .18981 Mdot
.33848 .25196 Mdot
.49982 .61796 Mdot
.49944 .6178 Mdot
.4982 .61727 Mdot
.49428 .61561 Mdot
.48178 .61031 Mdot
.442 .59345 Mdot
.31712 .54086 Mdot
.97443 .40624 Mdot
.66993 .42984 Mdot
.57458 .5591 Mdot
.58705 .00771 Mdot
.5 0 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.5357 .01514 Mdot
.6133 .04796 Mdot
.84685 .14434 Mdot
.27628 .2654 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.50482 .00204 Mdot
.51536 .00651 Mdot
.5489 .02073 Mdot
.65463 .06535 Mdot
.9575 .18718 Mdot
.32337 .22612 Mdot
.47542 .09397 Mdot
.49899 .61761 Mdot
.4968 .61668 Mdot
.48979 .6137 Mdot
.46748 .60425 Mdot
.39674 .57431 Mdot
.18174 .48516 Mdot
.74964 .35098 Mdot
.55626 .49852 Mdot
.44553 .5496 Mdot
.25467 .50008 Mdot
.82519 .3526 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.50482 .00204 Mdot
.51534 .00651 Mdot
.54885 .02071 Mdot
.65447 .06528 Mdot
.9571 .18704 Mdot
.3233 .22632 Mdot
.47565 .09415 Mdot
.59161 .07167 Mdot
.83752 .15198 Mdot
.28696 .27777 Mdot
.49868 .61747 Mdot
.49578 .61624 Mdot
.48655 .61233 Mdot
.45718 .59988 Mdot
.36435 .56066 Mdot
.09181 .44959 Mdot
.68906 .36912 Mdot
.50776 .50598 Mdot
.3381 .51318 Mdot
.96536 .38767 Mdot
.64417 .41953 Mdot
.50016 7e-05 Mdot
.50053 .00022 Mdot
.50167 .00071 Mdot
.50533 .00226 Mdot
.51699 .00721 Mdot
.55409 .02293 Mdot
.67079 .07212 Mdot
.99724 .20176 Mdot
.32784 .20432 Mdot
.44768 .07407 Mdot
.49046 .02644 Mdot
.51893 .0176 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50761 .00323 Mdot
.52424 .01028 Mdot
.57709 .03267 Mdot
.74112 .10137 Mdot
.14351 .24869 Mdot
.35864 .13296 Mdot
.38853 .01847 Mdot
.26455 .54141 Mdot
.90284 .39448 Mdot
.67798 .47906 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49278 .61497 Mdot
.477 .60828 Mdot
.42683 .58703 Mdot
.27073 .52156 Mdot
.87792 .37526 Mdot
.65079 .47766 Mdot
.61751 .59746 Mdot
.74489 .07873 Mdot
.11089 .2262 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.49332 .6152 Mdot
.47871 .609 Mdot
.43225 .58932 Mdot
.28721 .52839 Mdot
.90993 .38486 Mdot
.66066 .46397 Mdot
.61348 .58888 Mdot
.72247 .06736 Mdot
.06663 .2127 Mdot
.49926 .61772 Mdot
.49763 .61703 Mdot
.49246 .61484 Mdot
.47597 .60785 Mdot
.42359 .58566 Mdot
.26094 .51751 Mdot
.86012 .37031 Mdot
.64313 .48393 Mdot
.61305 .59944 Mdot
.73864 .07762 Mdot
.10236 .22479 Mdot
.50034 .00014 Mdot
.50109 .00046 Mdot
.50347 .00147 Mdot
.51105 .00469 Mdot
.53521 .01493 Mdot
.61174 .0473 Mdot
.84245 .14259 Mdot
.27273 .26593 Mdot
.46672 .11989 Mdot
.61114 .08926 Mdot
.90906 .18412 Mdot
.33608 .26392 Mdot
.49885 .61755 Mdot
.49633 .61648 Mdot
.48831 .61307 Mdot
.46276 .60224 Mdot
.38185 .56803 Mdot
.13954 .46828 Mdot
.71373 .35487 Mdot
.52048 .4986 Mdot
.35786 .51753 Mdot
.00928 .4026 Mdot
.64678 .394 Mdot
.50044 .00018 Mdot
.50139 .00059 Mdot
.50442 .00187 Mdot
.51407 .00597 Mdot
.5448 .01899 Mdot
.64184 .05998 Mdot
.92458 .17474 Mdot
.31626 .24207 Mdot
.4896 .10713 Mdot
.64736 .0975 Mdot
.99589 .21541 Mdot
.35059 .21921 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50345 .00146 Mdot
.511 .00466 Mdot
.53503 .01485 Mdot
.61119 .04707 Mdot
.8409 .14197 Mdot
.27145 .26609 Mdot
.46543 .11989 Mdot
.60796 .08809 Mdot
.9003 .18068 Mdot
.3326 .26717 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47446 .6072 Mdot
.41878 .58363 Mdot
.2465 .51156 Mdot
.83555 .36405 Mdot
.62966 .49079 Mdot
.59745 .59813 Mdot
.70246 .0649 Mdot
.03564 .20591 Mdot
.49758 .61701 Mdot
.4923 .61477 Mdot
.47546 .60763 Mdot
.42195 .58497 Mdot
.25601 .51548 Mdot
.8515 .36804 Mdot
.6388 .48658 Mdot
.6089 .59955 Mdot
.72989 .07478 Mdot
.08771 .22115 Mdot
.32053 .14388 Mdot
.49977 .61794 Mdot
.49928 .61773 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47662 .60812 Mdot
.42564 .58652 Mdot
.26712 .52007 Mdot
.87125 .37337 Mdot
.64812 .48013 Mdot
.61646 .59847 Mdot
.74431 .07902 Mdot
.49781 .6171 Mdot
.49302 .61507 Mdot
.47776 .6086 Mdot
.42925 .58805 Mdot
.27807 .5246 Mdot
.89187 .37935 Mdot
.65567 .47205 Mdot
.61748 .59443 Mdot
.73994 .07568 Mdot
.10066 .22293 Mdot
.32025 .13572 Mdot
.50077 .00033 Mdot
.50244 .00104 Mdot
.50778 .0033 Mdot
.52479 .01051 Mdot
.57883 .0334 Mdot
.74634 .10353 Mdot
.15252 .25103 Mdot
.36336 .13031 Mdot
.39352 .01864 Mdot
.2756 .54516 Mdot
.92204 .39952 Mdot
.68079 .46894 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50588 .00249 Mdot
.51874 .00795 Mdot
.55965 .02528 Mdot
.68797 .0793 Mdot
.03711 .21578 Mdot
.33109 .18169 Mdot
.41666 .05289 Mdot
.38286 .59714 Mdot
.18878 .49809 Mdot
.77342 .36132 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51776 .00753 Mdot
.55652 .02396 Mdot
.6783 .07526 Mdot
.015 .20809 Mdot
.32923 .1942 Mdot
.4337 .06457 Mdot
.44157 .00487 Mdot
.36376 .56994 Mdot
.10565 .45851 Mdot
.49838 .61735 Mdot
.49483 .61584 Mdot
.48353 .61105 Mdot
.44756 .59581 Mdot
.33435 .54807 Mdot
.01517 .42077 Mdot
.67326 .40673 Mdot
.54288 .53745 Mdot
.47603 .57672 Mdot
.37336 .55458 Mdot
.10016 .44919 Mdot
.49837 .61734 Mdot
.4948 .61583 Mdot
.48343 .61101 Mdot
.44725 .59568 Mdot
.3334 .54767 Mdot
.01284 .41992 Mdot
.67304 .40803 Mdot
.54461 .53866 Mdot
.48222 .57947 Mdot
.3932 .56302 Mdot
.15574 .47128 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49387 .61544 Mdot
.48048 .60976 Mdot
.43787 .5917 Mdot
.30442 .53556 Mdot
.94606 .39655 Mdot
.66707 .44561 Mdot
.59513 .57357 Mdot
.65754 .03857 Mdot
.91951 .16191 Mdot
.49911 .61766 Mdot
.49717 .61683 Mdot
.49098 .61421 Mdot
.47127 .60585 Mdot
.40871 .57937 Mdot
.2166 .4993 Mdot
.79099 .35499 Mdot
.59624 .49767 Mdot
.53722 .58155 Mdot
.53351 .61574 Mdot
.57969 .02854 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50972 .00412 Mdot
.53096 .01313 Mdot
.59836 .04165 Mdot
.80408 .12714 Mdot
.23488 .26625 Mdot
.42803 .11937 Mdot
.51685 .0549 Mdot
.63091 .07049 Mdot
.91994 .17863 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52031 .00861 Mdot
.56461 .02738 Mdot
.7032 .08565 Mdot
.07027 .22686 Mdot
.33533 .16381 Mdot
.39515 .03697 Mdot
.30882 .56468 Mdot
.99987 .42709 Mdot
.69112 .42722 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.5052 .0022 Mdot
.51656 .00702 Mdot
.55272 .02235 Mdot
.66652 .07033 Mdot
.98697 .19805 Mdot
.32694 .21011 Mdot
.45553 .07947 Mdot
.51828 .03878 Mdot
.6084 .0557 Mdot
.49781 .6171 Mdot
.49302 .61507 Mdot
.47776 .6086 Mdot
.42926 .58806 Mdot
.2781 .52461 Mdot
.89192 .37936 Mdot
.65569 .47203 Mdot
.61747 .59442 Mdot
.7399 .07567 Mdot
.10058 .22291 Mdot
.32023 .13575 Mdot
.4978 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42913 .588 Mdot
.2777 .52445 Mdot
.89115 .37913 Mdot
.65544 .47236 Mdot
.61755 .59462 Mdot
.74039 .07592 Mdot
.10152 .22319 Mdot
.32049 .13533 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50713 .00303 Mdot
.52273 .00964 Mdot
.5723 .03064 Mdot
.72662 .09538 Mdot
.11711 .24133 Mdot
.34736 .1423 Mdot
.38217 .02151 Mdot
.25595 .54002 Mdot
.89116 .39258 Mdot
.6772 .4858 Mdot
.4986 .61744 Mdot
.49553 .61614 Mdot
.48575 .61199 Mdot
.45463 .5988 Mdot
.35637 .55731 Mdot
.07074 .4415 Mdot
.68246 .37807 Mdot
.51174 .51252 Mdot
.35861 .52339 Mdot
.02021 .40889 Mdot
.65158 .39021 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50349 .00148 Mdot
.51111 .00471 Mdot
.53539 .01501 Mdot
.61233 .04755 Mdot
.84411 .14325 Mdot
.27409 .26574 Mdot
.46806 .11988 Mdot
.61446 .09048 Mdot
.91812 .18767 Mdot
.33926 .26027 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50374 .00159 Mdot
.51193 .00506 Mdot
.53799 .01611 Mdot
.6205 .05099 Mdot
.86697 .15233 Mdot
.29055 .26179 Mdot
.48311 .11901 Mdot
.65037 .10337 Mdot
.0111 .22294 Mdot
.35519 .21266 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48501 .61168 Mdot
.45227 .5978 Mdot
.349 .55421 Mdot
.05172 .4343 Mdot
.67822 .3872 Mdot
.51957 .51999 Mdot
.39021 .53808 Mdot
.10891 .44418 Mdot
.6767 .35091 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50757 .00321 Mdot
.52411 .01022 Mdot
.57668 .03249 Mdot
.73987 .10086 Mdot
.1413 .2481 Mdot
.35755 .13365 Mdot
.38754 .01853 Mdot
.26253 .54077 Mdot
.89952 .39368 Mdot
.67742 .48077 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50744 .00316 Mdot
.52371 .01005 Mdot
.5754 .03195 Mdot
.73602 .09927 Mdot
.13446 .24624 Mdot
.35435 .1359 Mdot
.38502 .01895 Mdot
.25784 .53943 Mdot
.89221 .39206 Mdot
.67619 .48453 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47427 .60712 Mdot
.41818 .58337 Mdot
.24469 .51081 Mdot
.8326 .36335 Mdot
.62781 .49147 Mdot
.59477 .59762 Mdot
.69565 .06234 Mdot
.02147 .20137 Mdot
.31518 .18152 Mdot
.50061 .00026 Mdot
.50194 .00082 Mdot
.50618 .00262 Mdot
.51969 .00835 Mdot
.56267 .02656 Mdot
.69724 .08317 Mdot
.05754 .22268 Mdot
.3334 .17049 Mdot
.40256 .04274 Mdot
.33452 .57598 Mdot
.06063 .44876 Mdot
.69798 .3939 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52199 .00932 Mdot
.56995 .02964 Mdot
.7195 .09243 Mdot
.10342 .23727 Mdot
.34289 .14801 Mdot
.38316 .02489 Mdot
.26349 .54407 Mdot
.90594 .39706 Mdot
.68141 .47927 Mdot
.49994 .61801 Mdot
.49979 .61795 Mdot
.49935 .61776 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47886 .60907 Mdot
.43275 .58953 Mdot
.28874 .52903 Mdot
.91303 .38583 Mdot
.66138 .46251 Mdot
.6124 .58776 Mdot
.50072 .0003 Mdot
.50228 .00097 Mdot
.50727 .00308 Mdot
.52317 .00982 Mdot
.5737 .03123 Mdot
.73086 .09713 Mdot
.12503 .24361 Mdot
.35036 .13926 Mdot
.38287 .02009 Mdot
.25512 .53908 Mdot
.88876 .39161 Mdot
.676 .48654 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50677 .00287 Mdot
.52157 .00915 Mdot
.56862 .02908 Mdot
.71544 .09074 Mdot
.09538 .23482 Mdot
.34066 .15159 Mdot
.38492 .02735 Mdot
.2712 .54775 Mdot
.92087 .40152 Mdot
.6844 .47189 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47658 .6081 Mdot
.42551 .58647 Mdot
.26674 .51991 Mdot
.87057 .37318 Mdot
.64783 .48038 Mdot
.61631 .59855 Mdot
.74413 .079 Mdot
.11053 .22644 Mdot
.32414 .13202 Mdot
.50026 .00011 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.5263 .01115 Mdot
.58361 .03542 Mdot
.76065 .10942 Mdot
.17589 .25663 Mdot
.37781 .1248 Mdot
.41394 .02233 Mdot
.32717 .56441 Mdot
.02919 .43387 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50407 .00173 Mdot
.51298 .0055 Mdot
.54132 .01752 Mdot
.63096 .0554 Mdot
.89561 .16356 Mdot
.30586 .25354 Mdot
.49192 .11499 Mdot
.66587 .10751 Mdot
.04598 .23492 Mdot
.35807 .19288 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.5036 .00153 Mdot
.51147 .00486 Mdot
.53653 .01549 Mdot
.61592 .04906 Mdot
.85421 .14727 Mdot
.28186 .2643 Mdot
.47555 .1197 Mdot
.63271 .09713 Mdot
.96665 .20639 Mdot
.35025 .23708 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50937 .00398 Mdot
.52986 .01266 Mdot
.59487 .04018 Mdot
.79392 .12302 Mdot
.22266 .26498 Mdot
.41619 .11961 Mdot
.48973 .04545 Mdot
.54787 .03593 Mdot
.67674 .07964 Mdot
.49907 .61764 Mdot
.49705 .61678 Mdot
.49061 .61405 Mdot
.47008 .60535 Mdot
.40492 .57777 Mdot
.20549 .49478 Mdot
.77659 .35296 Mdot
.58311 .49845 Mdot
.5087 .57205 Mdot
.44734 .58011 Mdot
.30841 .53217 Mdot
.49769 .61706 Mdot
.49265 .61492 Mdot
.47659 .60811 Mdot
.42554 .58648 Mdot
.26684 .51995 Mdot
.87073 .37323 Mdot
.6479 .48032 Mdot
.61635 .59853 Mdot
.74418 .079 Mdot
.11058 .22645 Mdot
.32414 .13199 Mdot
.50055 .00023 Mdot
.50176 .00074 Mdot
.5056 .00237 Mdot
.51783 .00756 Mdot
.55676 .02406 Mdot
.67902 .07557 Mdot
.01667 .20868 Mdot
.32936 .19325 Mdot
.43238 .06367 Mdot
.437 .00285 Mdot
.34956 .56399 Mdot
.06859 .44439 Mdot
.49778 .61709 Mdot
.49294 .61504 Mdot
.47751 .6085 Mdot
.42846 .58772 Mdot
.27567 .52361 Mdot
.88725 .37798 Mdot
.65416 .47398 Mdot
.61781 .59557 Mdot
.74246 .07704 Mdot
.10558 .22442 Mdot
.32169 .13357 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48618 .61217 Mdot
.45598 .59937 Mdot
.36061 .55909 Mdot
.08187 .44576 Mdot
.68567 .37317 Mdot
.50897 .50883 Mdot
.34571 .51713 Mdot
.9856 .39547 Mdot
.64706 .40881 Mdot
.50079 .00033 Mdot
.50252 .00107 Mdot
.50802 .0034 Mdot
.52553 .01083 Mdot
.58119 .0344 Mdot
.7534 .10644 Mdot
.1643 .25395 Mdot
.37025 .12728 Mdot
.40242 .01988 Mdot
.29721 .55301 Mdot
.9637 .41191 Mdot
.68417 .44527 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52177 .00923 Mdot
.56925 .02935 Mdot
.71737 .09154 Mdot
.09921 .23599 Mdot
.34169 .14986 Mdot
.38398 .02613 Mdot
.26724 .54588 Mdot
.91316 .3992 Mdot
.68298 .47577 Mdot
.50057 .00024 Mdot
.50182 .00077 Mdot
.50578 .00245 Mdot
.51842 .00781 Mdot
.55864 .02485 Mdot
.68484 .078 Mdot
.03004 .21335 Mdot
.33045 .18566 Mdot
.42197 .05657 Mdot
.4011 .60513 Mdot
.24123 .51923 Mdot
.84299 .37191 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50552 .00234 Mdot
.51759 .00746 Mdot
.55599 .02373 Mdot
.67665 .07457 Mdot
.01113 .20672 Mdot
.32893 .19641 Mdot
.43676 .06664 Mdot
.45222 .00955 Mdot
.49871 .61749 Mdot
.4959 .6163 Mdot
.48694 .6125 Mdot
.45841 .6004 Mdot
.36821 .56229 Mdot
.10215 .4536 Mdot
.69317 .36527 Mdot
.50787 .50351 Mdot
.33436 .5108 Mdot
.95488 .3835 Mdot
.64218 .42477 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.51009 .00428 Mdot
.53215 .01363 Mdot
.6021 .04323 Mdot
.81491 .13152 Mdot
.24687 .26697 Mdot
.44014 .11945 Mdot
.54573 .06526 Mdot
.71898 .10707 Mdot
.12644 .25183 Mdot
.50065 .00028 Mdot
.50207 .00088 Mdot
.50659 .00279 Mdot
.52098 .0089 Mdot
.56675 .02829 Mdot
.70973 .08837 Mdot
.08385 .23122 Mdot
.33793 .15703 Mdot
.3888 .03144 Mdot
.2861 .55457 Mdot
.95079 .4108 Mdot
.68812 .4557 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51494 .00634 Mdot
.54757 .02017 Mdot
.65051 .06362 Mdot
.94702 .18326 Mdot
.32155 .23147 Mdot
.48105 .09858 Mdot
.61221 .08106 Mdot
.89809 .17668 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48601 .6121 Mdot
.45546 .59915 Mdot
.35895 .55839 Mdot
.07751 .44409 Mdot
.68434 .37504 Mdot
.50988 .51021 Mdot
.35023 .51936 Mdot
.99763 .40012 Mdot
.64859 .40231 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50536 .00227 Mdot
.51707 .00724 Mdot
.55432 .02303 Mdot
.6715 .07242 Mdot
.99894 .20237 Mdot
.32798 .20335 Mdot
.44636 .07316 Mdot
.48579 .02437 Mdot
.50394 .01122 Mdot
.528 .01487 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00341 Mdot
.52565 .01088 Mdot
.58157 .03456 Mdot
.75454 .10691 Mdot
.16616 .25439 Mdot
.3714 .12685 Mdot
.40407 .02019 Mdot
.3014 .55458 Mdot
.97235 .41467 Mdot
.68456 .44017 Mdot
.4979 .61714 Mdot
.49331 .6152 Mdot
.47868 .60899 Mdot
.43216 .58928 Mdot
.28693 .52828 Mdot
.90937 .38469 Mdot
.66053 .46424 Mdot
.61367 .58908 Mdot
.72319 .06768 Mdot
.06805 .21314 Mdot
.31392 .15196 Mdot
.49897 .6176 Mdot
.49671 .61664 Mdot
.48951 .61358 Mdot
.46658 .60386 Mdot
.39388 .57311 Mdot
.17355 .48186 Mdot
.7415 .35101 Mdot
.54784 .49835 Mdot
.42488 .54204 Mdot
.19336 .47495 Mdot
.73807 .33665 Mdot
.50069 .00029 Mdot
.50218 .00093 Mdot
.50696 .00295 Mdot
.52216 .0094 Mdot
.5705 .02988 Mdot
.72118 .09312 Mdot
.10668 .23825 Mdot
.34388 .1466 Mdot
.38268 .02398 Mdot
.26103 .54285 Mdot
.90121 .39566 Mdot
.68024 .48147 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50703 .00298 Mdot
.52241 .0095 Mdot
.57129 .03021 Mdot
.72355 .0941 Mdot
.11126 .23962 Mdot
.34534 .14467 Mdot
.38227 .02282 Mdot
.25826 .54139 Mdot
.89585 .39405 Mdot
.67875 .48386 Mdot
.49971 .61791 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49072 .6141 Mdot
.47044 .6055 Mdot
.40608 .57825 Mdot
.20886 .49615 Mdot
.78085 .35351 Mdot
.5871 .49829 Mdot
.51756 .57506 Mdot
.47432 .59131 Mdot
.5001 4e-05 Mdot
.50032 .00013 Mdot
.501 .00043 Mdot
.5032 .00136 Mdot
.51019 .00432 Mdot
.53246 .01376 Mdot
.60308 .04365 Mdot
.81774 .13266 Mdot
.24983 .26705 Mdot
.44319 .1195 Mdot
.55312 .06794 Mdot
.74127 .11628 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48403 .61126 Mdot
.44914 .59648 Mdot
.33927 .55013 Mdot
.02724 .42519 Mdot
.67455 .40006 Mdot
.53426 .53133 Mdot
.44498 .56285 Mdot
.27478 .51285 Mdot
.86875 .36709 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48637 .61225 Mdot
.45659 .59963 Mdot
.36252 .55989 Mdot
.08692 .44771 Mdot
.68733 .37107 Mdot
.5082 .50733 Mdot
.34137 .51492 Mdot
.97407 .39103 Mdot
.6455 .41497 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.47982 .60947 Mdot
.43577 .59081 Mdot
.29798 .53287 Mdot
.93221 .39198 Mdot
.66508 .45294 Mdot
.60351 .57998 Mdot
.68647 .05128 Mdot
.98941 .18722 Mdot
.30822 .19704 Mdot
.49999 .61803 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48115 .61004 Mdot
.44 .5926 Mdot
.31097 .53829 Mdot
.96052 .40144 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47726 .60839 Mdot
.42766 .58738 Mdot
.27324 .5226 Mdot
.88263 .37662 Mdot
.65255 .47583 Mdot
.61782 .59657 Mdot
.74412 .07806 Mdot
.10899 .2255 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.48219 .61048 Mdot
.44332 .59401 Mdot
.32122 .54257 Mdot
.98389 .40955 Mdot
.67068 .42446 Mdot
.56717 .55406 Mdot
.56145 .6145 Mdot
.64564 .05203 Mdot
.91905 .16898 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.5203 .00861 Mdot
.56461 .02738 Mdot
.70318 .08564 Mdot
.07022 .22685 Mdot
.33532 .16384 Mdot
.39517 .03699 Mdot
.30891 .56472 Mdot
9e-05 .42717 Mdot
.69113 .42709 Mdot
.50003 1e-05 Mdot
.50011 4e-05 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.5109 .00462 Mdot
.53471 .01472 Mdot
.61019 .04664 Mdot
.83805 .14083 Mdot
.26903 .26636 Mdot
.46299 .11987 Mdot
.60193 .08587 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47726 .60839 Mdot
.42767 .58738 Mdot
.27328 .52261 Mdot
.8827 .37664 Mdot
.65257 .47581 Mdot
.61782 .59656 Mdot
.7441 .07805 Mdot
.49906 .61763 Mdot
.497 .61676 Mdot
.49044 .61398 Mdot
.46953 .60512 Mdot
.40321 .57704 Mdot
.20049 .49275 Mdot
.7705 .35228 Mdot
.57726 .49861 Mdot
.49541 .56745 Mdot
.40667 .56319 Mdot
.18583 .48155 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.4919 .6146 Mdot
.47421 .6071 Mdot
.418 .58329 Mdot
.24415 .51059 Mdot
.83173 .36315 Mdot
.62725 .49166 Mdot
.59396 .59746 Mdot
.69355 .06155 Mdot
.01702 .19991 Mdot
.49877 .61751 Mdot
.49607 .61637 Mdot
.48747 .61272 Mdot
.46008 .60111 Mdot
.37345 .56449 Mdot
.11636 .45915 Mdot
.69988 .36063 Mdot
.51038 .50092 Mdot
.33643 .51053 Mdot
.95811 .38421 Mdot
.6419 .42261 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.5045 .00191 Mdot
.51433 .00608 Mdot
.54564 .01935 Mdot
.64448 .06109 Mdot
.93148 .17738 Mdot
.31811 .23895 Mdot
.48754 .10471 Mdot
.6383 .09317 Mdot
.97137 .20585 Mdot
.34715 .23225 Mdot
.49962 .61787 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48765 .6128 Mdot
.46066 .60136 Mdot
.37527 .56526 Mdot
.12137 .46111 Mdot
.70255 .35919 Mdot
.51193 .50022 Mdot
.33918 .51127 Mdot
.96421 .38629 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51388 .00589 Mdot
.5442 .01874 Mdot
.63998 .05919 Mdot
.91969 .17287 Mdot
.31482 .2442 Mdot
.49073 .10872 Mdot
.65275 .10013 Mdot
.01031 .22098 Mdot
.35241 .21143 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.47479 .60734 Mdot
.41984 .58407 Mdot
.24966 .51286 Mdot
.84075 .36531 Mdot
.63281 .48952 Mdot
.60174 .59883 Mdot
.7131 .06883 Mdot
.05681 .21242 Mdot
.3171 .16087 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50751 .00319 Mdot
.52393 .01015 Mdot
.57612 .03225 Mdot
.73818 .10016 Mdot
.13832 .2473 Mdot
.35613 .13461 Mdot
.38634 .01867 Mdot
.26019 .54007 Mdot
.89579 .39283 Mdot
.67678 .48268 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49087 .61416 Mdot
.47091 .6057 Mdot
.40757 .57889 Mdot
.21325 .49794 Mdot
.78653 .35431 Mdot
.59228 .49798 Mdot
.52883 .57882 Mdot
.50839 .6054 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00114 Mdot
.50854 .00362 Mdot
.5272 .01153 Mdot
.58647 .03663 Mdot
.76915 .1129 Mdot
.18884 .25938 Mdot
.38721 .1226 Mdot
.4302 .02657 Mdot
.3718 .58195 Mdot
.14125 .47554 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50375 .00159 Mdot
.51195 .00507 Mdot
.53805 .01613 Mdot
.62069 .05107 Mdot
.86749 .15253 Mdot
.29088 .26167 Mdot
.48337 .11896 Mdot
.65096 .10357 Mdot
.01252 .22346 Mdot
.35532 .21186 Mdot
.49755 .61699 Mdot
.49219 .61472 Mdot
.47511 .60748 Mdot
.42084 .5845 Mdot
.25268 .5141 Mdot
.84581 .36658 Mdot
.63571 .48818 Mdot
.60539 .59929 Mdot
.72185 .07198 Mdot
.07332 .21722 Mdot
.31866 .15162 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50443 .00188 Mdot
.51412 .00599 Mdot
.54497 .01906 Mdot
.64236 .0602 Mdot
.92595 .17526 Mdot
.31665 .24147 Mdot
.48924 .10667 Mdot
.6457 .0967 Mdot
.4985 .6174 Mdot
.49522 .61601 Mdot
.48478 .61158 Mdot
.45155 .5975 Mdot
.34677 .55328 Mdot
.04605 .43218 Mdot
.67721 .39008 Mdot
.52257 .52246 Mdot
.40167 .54332 Mdot
.14249 .45785 Mdot
.697 .34271 Mdot
.49823 .61729 Mdot
.49438 .61565 Mdot
.48208 .61044 Mdot
.44297 .59386 Mdot
.32012 .54211 Mdot
.98135 .40866 Mdot
.67049 .42591 Mdot
.56918 .55542 Mdot
.5684 .61755 Mdot
.6671 .061 Mdot
.97287 .18898 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51775 .00752 Mdot
.55649 .02394 Mdot
.67819 .07521 Mdot
.01473 .20799 Mdot
.32921 .19436 Mdot
.43392 .06471 Mdot
.44233 .0052 Mdot
.36612 .57093 Mdot
.11195 .46095 Mdot
.49885 .61755 Mdot
.49634 .61648 Mdot
.48835 .6131 Mdot
.46291 .60231 Mdot
.38233 .56823 Mdot
.1409 .46882 Mdot
.71466 .35461 Mdot
.5213 .49853 Mdot
.35979 .51821 Mdot
.01412 .4044 Mdot
.6473 .39133 Mdot
.49786 .61713 Mdot
.49319 .61515 Mdot
.4783 .60883 Mdot
.43097 .58878 Mdot
.28332 .52678 Mdot
.90215 .38246 Mdot
.65868 .46756 Mdot
.61571 .59148 Mdot
.73141 .07151 Mdot
.08422 .21805 Mdot
.31651 .14356 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50276 .00117 Mdot
.50881 .00373 Mdot
.52805 .01189 Mdot
.58916 .03777 Mdot
.77712 .11617 Mdot
.20036 .26157 Mdot
.39638 .12115 Mdot
.44773 .03173 Mdot
.42207 .60217 Mdot
.28412 .53278 Mdot
.49982 .61796 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49432 .61563 Mdot
.4819 .61036 Mdot
.4424 .59362 Mdot
.31838 .54138 Mdot
.97733 .40725 Mdot
.67017 .4282 Mdot
.57233 .55757 Mdot
.57928 .0043 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47949 .60934 Mdot
.43475 .59038 Mdot
.29486 .53158 Mdot
.92566 .38985 Mdot
.66396 .45629 Mdot
.60694 .5828 Mdot
.69853 .05661 Mdot
.01649 .19651 Mdot
.30975 .18125 Mdot
.49849 .61739 Mdot
.49519 .61599 Mdot
.48467 .61153 Mdot
.45118 .59734 Mdot
.3456 .55278 Mdot
.04308 .43106 Mdot
.67672 .39162 Mdot
.52425 .5238 Mdot
.408 .54619 Mdot
.16133 .46558 Mdot
.71202 .34035 Mdot
.49813 .61724 Mdot
.49406 .61551 Mdot
.48107 .61001 Mdot
.43974 .59249 Mdot
.31017 .53796 Mdot
.95873 .40083 Mdot
.6685 .43866 Mdot
.58639 .56728 Mdot
.62758 .02546 Mdot
.84029 .13147 Mdot
.25434 .2559 Mdot
.49742 .61694 Mdot
.49177 .61455 Mdot
.47379 .60692 Mdot
.41668 .58274 Mdot
.24023 .50898 Mdot
.82549 .36171 Mdot
.62313 .49297 Mdot
.58758 .59606 Mdot
.67687 .05519 Mdot
.98014 .18743 Mdot
.31312 .20579 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51573 .00667 Mdot
.55007 .02122 Mdot
.65827 .06687 Mdot
.96664 .19058 Mdot
.32468 .22128 Mdot
.4698 .08969 Mdot
.5699 .06186 Mdot
.7715 .1246 Mdot
.20966 .2708 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.5061 .00259 Mdot
.51943 .00824 Mdot
.56183 .0262 Mdot
.69465 .08209 Mdot
.05192 .2208 Mdot
.33268 .17352 Mdot
.40621 .04544 Mdot
.34705 .58147 Mdot
.09218 .46052 Mdot
.70665 .37976 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50636 .0027 Mdot
.52027 .00859 Mdot
.56449 .02733 Mdot
.70281 .08549 Mdot
.06946 .2266 Mdot
.33519 .16423 Mdot
.39558 .03732 Mdot
.31034 .56535 Mdot
.00332 .42829 Mdot
.69132 .42521 Mdot
.49863 .61745 Mdot
.49564 .61619 Mdot
.48612 .61215 Mdot
.45581 .5993 Mdot
.36006 .55886 Mdot
.08043 .44521 Mdot
.68522 .37378 Mdot
.50924 .50927 Mdot
.34712 .51783 Mdot
.98934 .39692 Mdot
.64754 .40679 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49293 .61504 Mdot
.47749 .60849 Mdot
.4284 .58769 Mdot
.27548 .52353 Mdot
.88689 .37787 Mdot
.65404 .47412 Mdot
.61782 .59565 Mdot
.74262 .07713 Mdot
.1059 .22452 Mdot
.49792 .61715 Mdot
.49337 .61522 Mdot
.47888 .60908 Mdot
.4328 .58956 Mdot
.2889 .5291 Mdot
.91337 .38594 Mdot
.66146 .46235 Mdot
.61228 .58764 Mdot
.71789 .06527 Mdot
.05739 .20982 Mdot
.31266 .15776 Mdot
.50058 .00025 Mdot
.50185 .00079 Mdot
.5059 .0025 Mdot
.51881 .00798 Mdot
.55987 .02538 Mdot
.68864 .07958 Mdot
.03861 .21629 Mdot
.33123 .18085 Mdot
.41556 .05211 Mdot
.37907 .59549 Mdot
.17816 .49386 Mdot
.76242 .36109 Mdot
.4989 .61757 Mdot
.4965 .61655 Mdot
.48885 .61331 Mdot
.4645 .60298 Mdot
.38734 .57034 Mdot
.15494 .47441 Mdot
.72515 .3524 Mdot
.53118 .49815 Mdot
.38368 .52687 Mdot
.07682 .42839 Mdot
.65915 .3599 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52247 .00953 Mdot
.57147 .03028 Mdot
.7241 .09433 Mdot
.11232 .23993 Mdot
.3457 .14424 Mdot
.38221 .02257 Mdot
.25774 .54111 Mdot
.89482 .39374 Mdot
.67843 .4843 Mdot
.49971 .61791 Mdot
.49906 .61764 Mdot
.49701 .61677 Mdot
.49047 .61399 Mdot
.46963 .60516 Mdot
.40352 .57717 Mdot
.20139 .49311 Mdot
.77158 .35239 Mdot
.57831 .49859 Mdot
.49781 .56829 Mdot
.41403 .56626 Mdot
.49805 .61721 Mdot
.49378 .6154 Mdot
.4802 .60964 Mdot
.43699 .59133 Mdot
.30171 .53443 Mdot
.94019 .3946 Mdot
.66629 .44875 Mdot
.59885 .57635 Mdot
.67034 .04418 Mdot
.95127 .17362 Mdot
.30416 .2181 Mdot
.49873 .61749 Mdot
.49595 .61631 Mdot
.48708 .61256 Mdot
.45886 .60059 Mdot
.36962 .56288 Mdot
.10596 .45508 Mdot
.69485 .36395 Mdot
.50827 .50272 Mdot
.33409 .51038 Mdot
.95372 .38296 Mdot
.6418 .42526 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.48219 .61048 Mdot
.4433 .594 Mdot
.32117 .54255 Mdot
.98377 .40951 Mdot
.67067 .42453 Mdot
.56727 .55413 Mdot
.5618 .61465 Mdot
.64671 .05248 Mdot
.49858 .61743 Mdot
.49547 .61611 Mdot
.48556 .61191 Mdot
.45401 .59854 Mdot
.35443 .55649 Mdot
.0657 .43959 Mdot
.68119 .38039 Mdot
.51345 .51436 Mdot
.36586 .52682 Mdot
.04005 .41667 Mdot
.6548 .37994 Mdot
.50077 .00032 Mdot
.50244 .00104 Mdot
.50778 .0033 Mdot
.52478 .01051 Mdot
.5788 .03339 Mdot
.74626 .1035 Mdot
.15239 .251 Mdot
.36329 .13034 Mdot
.39343 .01863 Mdot
.27541 .54509 Mdot
.92168 .39942 Mdot
.68075 .46913 Mdot
.49961 .61787 Mdot
.49875 .6175 Mdot
.496 .61634 Mdot
.48727 .61263 Mdot
.45945 .60084 Mdot
.37145 .56365 Mdot
.11094 .45702 Mdot
.69716 .36231 Mdot
.50909 .5018 Mdot
.33464 .51022 Mdot
.95443 .38305 Mdot
.49797 .61717 Mdot
.49353 .61529 Mdot
.47939 .60929 Mdot
.43442 .59024 Mdot
.29383 .53115 Mdot
.92351 .38916 Mdot
.66356 .45738 Mdot
.60798 .58369 Mdot
.70224 .05825 Mdot
.02456 .1992 Mdot
.31019 .17653 Mdot
.49809 .61722 Mdot
.49391 .61545 Mdot
.48059 .6098 Mdot
.43822 .59185 Mdot
.3055 .53601 Mdot
.94841 .39734 Mdot
.66736 .44433 Mdot
.59357 .57243 Mdot
.6522 .03623 Mdot
.90588 .15678 Mdot
.29266 .23904 Mdot
.49895 .61759 Mdot
.49664 .61661 Mdot
.48931 .6135 Mdot
.46595 .6036 Mdot
.39191 .57227 Mdot
.16791 .4796 Mdot
.73624 .35124 Mdot
.54241 .49824 Mdot
.41143 .53709 Mdot
.15436 .45915 Mdot
.70038 .33746 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00325 Mdot
.52445 .01037 Mdot
.57776 .03295 Mdot
.74311 .1022 Mdot
.14698 .2496 Mdot
.36041 .1319 Mdot
.39027 .01846 Mdot
.26828 .54264 Mdot
.90912 .39606 Mdot
.679 .47581 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50834 .00354 Mdot
.52656 .01126 Mdot
.58443 .03577 Mdot
.76309 .11042 Mdot
.17967 .25746 Mdot
.38045 .12409 Mdot
.41831 .0234 Mdot
.33894 .56898 Mdot
.05715 .44388 Mdot
.69147 .39203 Mdot
.5007 .0003 Mdot
.50223 .00094 Mdot
.50709 .00301 Mdot
.52259 .00958 Mdot
.57185 .03045 Mdot
.72526 .09482 Mdot
.11453 .24058 Mdot
.34645 .14333 Mdot
.38215 .02206 Mdot
.25679 .54056 Mdot
.89292 .39315 Mdot
.67782 .48509 Mdot
.49819 .61726 Mdot
.49422 .61558 Mdot
.48158 .61022 Mdot
.44137 .59318 Mdot
.31519 .54005 Mdot
.97002 .40471 Mdot
.66956 .43234 Mdot
.57798 .56144 Mdot
.59875 .01284 Mdot
.75832 .09862 Mdot
.1563 .24596 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52399 .01017 Mdot
.57631 .03233 Mdot
.73875 .10039 Mdot
.13933 .24757 Mdot
.3566 .13428 Mdot
.38673 .01862 Mdot
.26093 .54029 Mdot
.89696 .39309 Mdot
.67698 .48208 Mdot
.49844 .61737 Mdot
.49503 .61593 Mdot
.48417 .61132 Mdot
.4496 .59667 Mdot
.34068 .55072 Mdot
.03074 .42648 Mdot
.67498 .39816 Mdot
.53191 .52961 Mdot
.43638 .559 Mdot
.24796 .50158 Mdot
.82082 .35405 Mdot
.49768 .61705 Mdot
.49262 .61491 Mdot
.47649 .60807 Mdot
.42524 .58636 Mdot
.26592 .51957 Mdot
.86906 .37276 Mdot
.64719 .48091 Mdot
.61596 .59873 Mdot
.74367 .07893 Mdot
.10993 .22636 Mdot
.3241 .13236 Mdot
.49882 .61753 Mdot
.49623 .61643 Mdot
.48798 .61294 Mdot
.46171 .6018 Mdot
.37857 .56665 Mdot
.13044 .46468 Mdot
.70783 .35685 Mdot
.51563 .49924 Mdot
.34683 .51371 Mdot
.98213 .39264 Mdot
.64418 .40917 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50352 .00149 Mdot
.51121 .00475 Mdot
.53569 .01513 Mdot
.61326 .04794 Mdot
.84674 .1443 Mdot
.27619 .26542 Mdot
.47014 .11986 Mdot
.61956 .09234 Mdot
.93191 .19305 Mdot
.34331 .25426 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50562 .00238 Mdot
.5179 .00759 Mdot
.55698 .02415 Mdot
.67971 .07585 Mdot
.01826 .20924 Mdot
.32948 .19235 Mdot
.43113 .06282 Mdot
.43268 .00096 Mdot
.33623 .55842 Mdot
.03524 .43201 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50762 .00323 Mdot
.52428 .01029 Mdot
.57721 .03271 Mdot
.74147 .10152 Mdot
.14412 .24885 Mdot
.35894 .13277 Mdot
.38882 .01846 Mdot
.26516 .54161 Mdot
.90385 .39473 Mdot
.67815 .47854 Mdot
.49959 .61786 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48672 .6124 Mdot
.45772 .60011 Mdot
.36604 .56137 Mdot
.09631 .45134 Mdot
.69078 .3674 Mdot
.50763 .50485 Mdot
.33594 .51192 Mdot
.95948 .38537 Mdot
.49957 .61785 Mdot
.49865 .61746 Mdot
.49568 .6162 Mdot
.48625 .6122 Mdot
.45621 .59947 Mdot
.36131 .55938 Mdot
.08373 .44648 Mdot
.68626 .37239 Mdot
.50865 .50826 Mdot
.344 .51627 Mdot
.98106 .39372 Mdot
.50068 .00029 Mdot
.50218 .00092 Mdot
.50694 .00294 Mdot
.5221 .00937 Mdot
.5703 .02979 Mdot
.72056 .09287 Mdot
.10549 .2379 Mdot
.34351 .14711 Mdot
.38284 .02431 Mdot
.26188 .54328 Mdot
.90285 .39614 Mdot
.68066 .48072 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50615 .00261 Mdot
.51958 .0083 Mdot
.56232 .02641 Mdot
.69617 .08272 Mdot
.05522 .22191 Mdot
.33309 .17174 Mdot
.40404 .04385 Mdot
.49891 .61757 Mdot
.49654 .61657 Mdot
.48897 .61336 Mdot
.46486 .60314 Mdot
.38847 .57082 Mdot
.15815 .47569 Mdot
.72776 .35204 Mdot
.53377 .49815 Mdot
.39007 .52922 Mdot
.09428 .43523 Mdot
.6652 .35284 Mdot
.49822 .61728 Mdot
.49433 .61563 Mdot
.48193 .61037 Mdot
.4425 .59366 Mdot
.31868 .54151 Mdot
.97801 .40749 Mdot
.67022 .42781 Mdot
.57179 .5572 Mdot
.57745 .00349 Mdot
.69473 .07249 Mdot
.0365 .21123 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50326 .00138 Mdot
.51039 .00441 Mdot
.5331 .01404 Mdot
.60511 .0445 Mdot
.82357 .13501 Mdot
.2557 .26708 Mdot
.44926 .11963 Mdot
.56799 .07338 Mdot
.49886 .61755 Mdot
.49635 .61649 Mdot
.48838 .61311 Mdot
.463 .60235 Mdot
.38261 .56835 Mdot
.14166 .46912 Mdot
.71519 .35446 Mdot
.52177 .49849 Mdot
.3609 .51861 Mdot
.01694 .40546 Mdot
.64762 .38978 Mdot
.4991 .61765 Mdot
.49713 .61682 Mdot
.49085 .61415 Mdot
.47086 .60568 Mdot
.40739 .57881 Mdot
.21271 .49771 Mdot
.78582 .3542 Mdot
.59164 .49803 Mdot
.52746 .57837 Mdot
.50425 .60369 Mdot
.48742 .60763 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50395 .00168 Mdot
.5126 .00534 Mdot
.54012 .01701 Mdot
.62719 .05381 Mdot
.88538 .15957 Mdot
.30102 .25688 Mdot
.49008 .11685 Mdot
.66428 .10766 Mdot
.0434 .23431 Mdot
.35823 .19457 Mdot
.4995 .61782 Mdot
.49842 .61736 Mdot
.49497 .6159 Mdot
.48397 .61124 Mdot
.44897 .5964 Mdot
.33872 .5499 Mdot
.02588 .42469 Mdot
.67439 .4008 Mdot
.5352 .53201 Mdot
.44839 .56438 Mdot
.28551 .51737 Mdot
.49814 .61725 Mdot
.49408 .61552 Mdot
.48113 .61003 Mdot
.43994 .59258 Mdot
.31078 .53821 Mdot
.96009 .40129 Mdot
.66864 .43791 Mdot
.5854 .56659 Mdot
.6242 .02398 Mdot
.83097 .12779 Mdot
.24623 .25665 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47488 .60738 Mdot
.42011 .58419 Mdot
.25048 .5132 Mdot
.84211 .36565 Mdot
.6336 .48917 Mdot
.60277 .59898 Mdot
.71561 .06974 Mdot
.06162 .21385 Mdot
.3175 .15814 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.51481 .00628 Mdot
.54716 .01999 Mdot
.64923 .06308 Mdot
.94374 .18202 Mdot
.3209 .2331 Mdot
.48262 .09995 Mdot
.61833 .08387 Mdot
.91562 .18374 Mdot
.33364 .25835 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49507 .61595 Mdot
.48431 .61138 Mdot
.45004 .59686 Mdot
.34206 .5513 Mdot
.03419 .42776 Mdot
.67543 .39631 Mdot
.52966 .52795 Mdot
.42814 .55529 Mdot
.22246 .49091 Mdot
.49854 .61742 Mdot
.49536 .61606 Mdot
.48521 .61176 Mdot
.4529 .59807 Mdot
.35096 .55503 Mdot
.05673 .43619 Mdot
.6792 .38471 Mdot
.51716 .51789 Mdot
.38081 .53377 Mdot
.08193 .43332 Mdot
.66551 .36067 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51996 .00846 Mdot
.56352 .02692 Mdot
.69985 .08426 Mdot
.06317 .22454 Mdot
.3342 .16751 Mdot
.39913 .04013 Mdot
.32269 .57079 Mdot
.03198 .43837 Mdot
.69362 .40892 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51748 .00741 Mdot
.55565 .02359 Mdot
.67561 .07414 Mdot
.00869 .20586 Mdot
.32874 .1978 Mdot
.43869 .06795 Mdot
.45893 .01251 Mdot
.41825 .59289 Mdot
.26027 .52039 Mdot
.49845 .61738 Mdot
.49505 .61594 Mdot
.48424 .61135 Mdot
.44982 .59676 Mdot
.34138 .55101 Mdot
.03249 .42713 Mdot
.6752 .39722 Mdot
.53076 .52877 Mdot
.43218 .55711 Mdot
.23492 .49612 Mdot
.8 .34924 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48205 .61042 Mdot
.44286 .59381 Mdot
.31978 .54197 Mdot
.98055 .40838 Mdot
.67042 .42637 Mdot
.56981 .55585 Mdot
.57058 .00048 Mdot
.67377 .06378 Mdot
.98884 .19472 Mdot
.50016 7e-05 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00225 Mdot
.51694 .00718 Mdot
.55393 .02286 Mdot
.67027 .0719 Mdot
.996 .20132 Mdot
.32773 .20502 Mdot
.44864 .07473 Mdot
.49385 .02794 Mdot
.52982 .02223 Mdot
.49799 .61718 Mdot
.4936 .61532 Mdot
.47961 .60939 Mdot
.43513 .59054 Mdot
.296 .53205 Mdot
.92805 .39063 Mdot
.66438 .45508 Mdot
.60573 .58179 Mdot
.69427 .05472 Mdot
.00706 .19331 Mdot
.30926 .18677 Mdot
.49931 .61774 Mdot
.4978 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42911 .58799 Mdot
.27765 .52443 Mdot
.89106 .37911 Mdot
.65541 .47239 Mdot
.61756 .59464 Mdot
.74044 .07595 Mdot
.10162 .22322 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48443 .61143 Mdot
.45044 .59702 Mdot
.3433 .55182 Mdot
.03728 .42891 Mdot
.67585 .39466 Mdot
.52772 .52648 Mdot
.42094 .55204 Mdot
.20039 .48173 Mdot
.75261 .34129 Mdot
.49831 .61732 Mdot
.49461 .61575 Mdot
.48282 .61075 Mdot
.4453 .59485 Mdot
.32735 .54513 Mdot
.99831 .41468 Mdot
.6718 .41624 Mdot
.55579 .54633 Mdot
.52177 .597 Mdot
.52029 .61712 Mdot
.54915 .01784 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50333 .00141 Mdot
.5106 .00449 Mdot
.53375 .01431 Mdot
.60714 .04536 Mdot
.82937 .13735 Mdot
.26126 .26692 Mdot
.45501 .11975 Mdot
.58218 .07859 Mdot
.82721 .15144 Mdot
.28342 .28196 Mdot
.49976 .61793 Mdot
.49924 .61771 Mdot
.49757 .617 Mdot
.49226 .61475 Mdot
.47536 .60759 Mdot
.42164 .58483 Mdot
.25506 .51509 Mdot
.84988 .36762 Mdot
.63794 .48705 Mdot
.60796 .59951 Mdot
.72779 .07406 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .0014 Mdot
.5105 .00445 Mdot
.53343 .01417 Mdot
.60614 .04494 Mdot
.82651 .1362 Mdot
.25855 .26702 Mdot
.45221 .11969 Mdot
.57527 .07605 Mdot
.80706 .14326 Mdot
.26241 .28142 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50644 .00273 Mdot
.52052 .0087 Mdot
.56528 .02767 Mdot
.70524 .0865 Mdot
.07456 .22825 Mdot
.33608 .16163 Mdot
.39295 .03515 Mdot
.30109 .56126 Mdot
.98268 .42125 Mdot
.6902 .43727 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.50199 .00085 Mdot
.50635 .00269 Mdot
.52023 .00858 Mdot
.56438 .02728 Mdot
.70248 .08535 Mdot
.06875 .22637 Mdot
.33507 .1646 Mdot
.39597 .03763 Mdot
.31169 .56595 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.50729 .00309 Mdot
.52321 .00984 Mdot
.57384 .03129 Mdot
.73129 .09731 Mdot
.12582 .24384 Mdot
.35068 .13897 Mdot
.38299 .01997 Mdot
.25519 .53905 Mdot
.88877 .39158 Mdot
.67595 .4865 Mdot
.49955 .61784 Mdot
.49857 .61743 Mdot
.49545 .6161 Mdot
.48549 .61188 Mdot
.4538 .59845 Mdot
.35377 .55621 Mdot
.06399 .43894 Mdot
.68079 .3812 Mdot
.5141 .51501 Mdot
.36853 .52807 Mdot
.04742 .41958 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.503 .00127 Mdot
.50956 .00405 Mdot
.53043 .0129 Mdot
.59669 .04095 Mdot
.79922 .12517 Mdot
.22916 .26572 Mdot
.42241 .11943 Mdot
.50382 .05032 Mdot
.59097 .05386 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51606 .00681 Mdot
.55114 .02168 Mdot
.6616 .06827 Mdot
.9749 .19363 Mdot
.3257 .2168 Mdot
.46426 .08563 Mdot
.54966 .05278 Mdot
.70833 .09807 Mdot
.09761 .24059 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50503 .00213 Mdot
.51604 .0068 Mdot
.55106 .02164 Mdot
.66136 .06817 Mdot
.9743 .19341 Mdot
.32563 .21713 Mdot
.46467 .08593 Mdot
.55116 .05345 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48765 .6128 Mdot
.46067 .60136 Mdot
.3753 .56527 Mdot
.12143 .46114 Mdot
.70258 .35917 Mdot
.51195 .50022 Mdot
.33922 .51128 Mdot
.9643 .38632 Mdot
.64248 .41914 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50465 .00197 Mdot
.5148 .00628 Mdot
.54714 .01998 Mdot
.64915 .06305 Mdot
.94355 .18195 Mdot
.32086 .23319 Mdot
.48271 .10003 Mdot
.61869 .08404 Mdot
.4975 .61697 Mdot
.49202 .61465 Mdot
.47459 .60726 Mdot
.41919 .5838 Mdot
.24772 .51206 Mdot
.83754 .36453 Mdot
.63088 .49031 Mdot
.59916 .59843 Mdot
.70674 .06649 Mdot
.04428 .20861 Mdot
.31626 .16809 Mdot
.49801 .61719 Mdot
.49367 .61535 Mdot
.47984 .60948 Mdot
.43584 .59084 Mdot
.2982 .53297 Mdot
.93269 .39214 Mdot
.66516 .45269 Mdot
.60324 .57977 Mdot
.68555 .05087 Mdot
.98728 .18648 Mdot
.30807 .19826 Mdot
.49761 .61702 Mdot
.4924 .61481 Mdot
.47578 .60776 Mdot
.42297 .5854 Mdot
.25908 .51674 Mdot
.85685 .36944 Mdot
.64154 .48496 Mdot
.61164 .59955 Mdot
.73579 .07673 Mdot
.09773 .22369 Mdot
.32211 .13868 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52601 .01103 Mdot
.58268 .03503 Mdot
.75788 .10828 Mdot
.17151 .25564 Mdot
.37486 .12568 Mdot
.40925 .02126 Mdot
.31478 .55965 Mdot
.00107 .42415 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48377 .61115 Mdot
.44832 .59613 Mdot
.3367 .54905 Mdot
.02091 .42286 Mdot
.67384 .40353 Mdot
.53869 .53451 Mdot
.46102 .57003 Mdot
.32544 .53425 Mdot
.97746 .40297 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50699 .00296 Mdot
.52226 .00944 Mdot
.57083 .03001 Mdot
.72216 .09353 Mdot
.10857 .23882 Mdot
.34447 .14579 Mdot
.38248 .02349 Mdot
.25978 .54221 Mdot
.89881 .39494 Mdot
.6796 .48255 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.5064 .00272 Mdot
.5204 .00865 Mdot
.5649 .02751 Mdot
.70409 .08602 Mdot
.07215 .22747 Mdot
.33565 .16285 Mdot
.39417 .03616 Mdot
.30537 .56316 Mdot
.99216 .42445 Mdot
.6907 .43172 Mdot
.49765 .61704 Mdot
.49252 .61486 Mdot
.47618 .60793 Mdot
.42424 .58594 Mdot
.26292 .51833 Mdot
.86364 .37127 Mdot
.64478 .48277 Mdot
.61436 .59923 Mdot
.7411 .07833 Mdot
.10619 .22564 Mdot
.32356 .13434 Mdot
.49778 .61709 Mdot
.49293 .61504 Mdot
.47749 .60849 Mdot
.42839 .58769 Mdot
.27547 .52352 Mdot
.88686 .37786 Mdot
.65403 .47414 Mdot
.61782 .59566 Mdot
.74263 .07714 Mdot
.10593 .22453 Mdot
.3218 .13342 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52632 .01116 Mdot
.58367 .03544 Mdot
.76082 .10948 Mdot
.17615 .25669 Mdot
.37799 .12475 Mdot
.41422 .02239 Mdot
.32793 .5647 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.5093 .00394 Mdot
.52962 .01256 Mdot
.59411 .03986 Mdot
.79168 .12211 Mdot
.21985 .26462 Mdot
.41355 .11972 Mdot
.48387 .04346 Mdot
.53003 .02853 Mdot
.62095 .0562 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50629 .00267 Mdot
.52003 .00849 Mdot
.56373 .02701 Mdot
.7005 .08453 Mdot
.06455 .22499 Mdot
.33441 .16678 Mdot
.39832 .0395 Mdot
.31989 .56956 Mdot
.02538 .43602 Mdot
.69296 .41258 Mdot
.49937 .61776 Mdot
.49798 .61718 Mdot
.49356 .6153 Mdot
.47948 .60933 Mdot
.43471 .59037 Mdot
.29474 .53153 Mdot
.9254 .38977 Mdot
.66391 .45642 Mdot
.60707 .5829 Mdot
.69898 .05681 Mdot
.01747 .19683 Mdot
.49787 .61713 Mdot
.49321 .61515 Mdot
.47835 .60886 Mdot
.43114 .58885 Mdot
.28381 .52698 Mdot
.90313 .38276 Mdot
.65894 .46712 Mdot
.61547 .59117 Mdot
.73041 .07103 Mdot
.08227 .21746 Mdot
.31615 .14455 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52547 .0108 Mdot
.58098 .03431 Mdot
.75278 .10618 Mdot
.16328 .2537 Mdot
.36962 .12752 Mdot
.40153 .01973 Mdot
.295 .55219 Mdot
.95921 .4105 Mdot
.68394 .44791 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50822 .00348 Mdot
.52618 .0111 Mdot
.58322 .03526 Mdot
.75949 .10894 Mdot
.17406 .25622 Mdot
.37657 .12515 Mdot
.41193 .02186 Mdot
.32183 .56235 Mdot
.01691 .42958 Mdot
.68667 .41393 Mdot
.50056 .00024 Mdot
.5018 .00076 Mdot
.50572 .00243 Mdot
.51823 .00773 Mdot
.55804 .0246 Mdot
.68297 .07722 Mdot
.02578 .21187 Mdot
.33009 .18807 Mdot
.42525 .05881 Mdot
.41237 .61007 Mdot
.27458 .53288 Mdot
.9009 .38709 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.4818 .61032 Mdot
.44209 .59349 Mdot
.31741 .54098 Mdot
.97509 .40647 Mdot
.66998 .42947 Mdot
.57407 .55876 Mdot
.5853 .00694 Mdot
.71845 .08229 Mdot
.08566 .22695 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50336 .00142 Mdot
.5107 .00454 Mdot
.53407 .01445 Mdot
.60816 .04579 Mdot
.8323 .13852 Mdot
.26395 .26678 Mdot
.45779 .1198 Mdot
.58905 .08113 Mdot
.84704 .15944 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49651 .61656 Mdot
.48889 .61332 Mdot
.46462 .60303 Mdot
.38771 .5705 Mdot
.15599 .47483 Mdot
.72599 .35228 Mdot
.53201 .49815 Mdot
.38573 .52763 Mdot
.0824 .43056 Mdot
.49759 .61701 Mdot
.49231 .61477 Mdot
.47551 .60765 Mdot
.42211 .58503 Mdot
.25649 .51567 Mdot
.85233 .36825 Mdot
.63924 .48634 Mdot
.60936 .59957 Mdot
.7309 .07512 Mdot
.08947 .2216 Mdot
.32079 .14296 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52196 .00931 Mdot
.56985 .0296 Mdot
.7192 .0923 Mdot
.10282 .23709 Mdot
.34272 .14827 Mdot
.38326 .02506 Mdot
.26398 .54431 Mdot
.90689 .39734 Mdot
.49892 .61758 Mdot
.49656 .61658 Mdot
.48904 .61339 Mdot
.46509 .60323 Mdot
.38919 .57113 Mdot
.16018 .4765 Mdot
.72946 .35183 Mdot
.53549 .49815 Mdot
.3943 .53078 Mdot
.10597 .43983 Mdot
.67017 .3487 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50682 .00289 Mdot
.52172 .00921 Mdot
.5691 .02928 Mdot
.71692 .09135 Mdot
.09832 .23572 Mdot
.34145 .15026 Mdot
.38418 .02641 Mdot
.26811 .5463 Mdot
.91485 .39971 Mdot
.68331 .47493 Mdot
.49746 .61696 Mdot
.49192 .61461 Mdot
.47426 .60712 Mdot
.41815 .58336 Mdot
.24462 .51078 Mdot
.83249 .36332 Mdot
.62774 .49149 Mdot
.59467 .5976 Mdot
.6954 .06225 Mdot
.02093 .20119 Mdot
.31516 .18184 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51252 .00531 Mdot
.53988 .01691 Mdot
.62643 .05349 Mdot
.88329 .15875 Mdot
.29995 .25751 Mdot
.48953 .11717 Mdot
.49868 .61747 Mdot
.49579 .61625 Mdot
.48659 .61235 Mdot
.45731 .59994 Mdot
.36476 .56083 Mdot
.09289 .45001 Mdot
.68946 .3687 Mdot
.50771 .5057 Mdot
.33751 .51285 Mdot
.96376 .38705 Mdot
.6439 .42035 Mdot
.49871 .61749 Mdot
.49589 .61629 Mdot
.48689 .61248 Mdot
.45826 .60034 Mdot
.36772 .56208 Mdot
.10084 .45309 Mdot
.69262 .36574 Mdot
.50778 .5038 Mdot
.33459 .511 Mdot
.95561 .38381 Mdot
.64235 .42443 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50539 .00228 Mdot
.51716 .00728 Mdot
.55461 .02315 Mdot
.67239 .07279 Mdot
.00107 .20314 Mdot
.32815 .20214 Mdot
.44469 .07203 Mdot
.47994 .02178 Mdot
.48517 .00323 Mdot
.46818 .60753 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.5015 .00064 Mdot
.50479 .00203 Mdot
.51526 .00647 Mdot
.54858 .02059 Mdot
.65364 .06493 Mdot
.95501 .18625 Mdot
.32296 .22741 Mdot
.47684 .0951 Mdot
.59611 .07371 Mdot
.85093 .15749 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47726 .60839 Mdot
.42768 .58739 Mdot
.2733 .52262 Mdot
.88275 .37666 Mdot
.65259 .47579 Mdot
.61782 .59655 Mdot
.74409 .07804 Mdot
.10893 .22548 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48405 .61127 Mdot
.44921 .5965 Mdot
.33947 .55021 Mdot
.02774 .42537 Mdot
.67461 .39979 Mdot
.53393 .53109 Mdot
.44375 .5623 Mdot
.27093 .51123 Mdot
.86145 .36496 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.513 .00551 Mdot
.54141 .01755 Mdot
.63122 .05551 Mdot
.89631 .16383 Mdot
.30616 .2533 Mdot
.49199 .11485 Mdot
.66582 .10743 Mdot
.04577 .23482 Mdot
.358 .19297 Mdot
.49759 .61701 Mdot
.49232 .61478 Mdot
.47553 .60766 Mdot
.42219 .58506 Mdot
.25671 .51577 Mdot
.85272 .36835 Mdot
.63944 .48622 Mdot
.60957 .59957 Mdot
.73137 .07528 Mdot
.09028 .22181 Mdot
.32091 .14254 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50321 .00136 Mdot
.51023 .00434 Mdot
.53259 .01382 Mdot
.60351 .04383 Mdot
.81896 .13316 Mdot
.25109 .26707 Mdot
.44448 .11953 Mdot
.55629 .0691 Mdot
.75078 .1202 Mdot
.184 .26774 Mdot
.49908 .61764 Mdot
.49708 .61679 Mdot
.49068 .61408 Mdot
.47032 .60545 Mdot
.40571 .5781 Mdot
.20779 .49571 Mdot
.77949 .35333 Mdot
.58583 .49835 Mdot
.51477 .57411 Mdot
.46583 .58779 Mdot
.36602 .55635 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47698 .60827 Mdot
.42678 .58701 Mdot
.27058 .5215 Mdot
.87765 .37519 Mdot
.65069 .47777 Mdot
.61748 .59751 Mdot
.74491 .07876 Mdot
.11095 .22623 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52384 .01011 Mdot
.57582 .03213 Mdot
.73729 .09979 Mdot
.13673 .24687 Mdot
.35539 .13514 Mdot
.38577 .01877 Mdot
.25913 .53977 Mdot
.89416 .39247 Mdot
.6765 .48352 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51143 .00485 Mdot
.5364 .01543 Mdot
.61551 .04889 Mdot
.85306 .14681 Mdot
.28101 .26449 Mdot
.47476 .11974 Mdot
.6308 .09644 Mdot
.96168 .2045 Mdot
.34949 .23968 Mdot
.49913 .61767 Mdot
.49723 .61686 Mdot
.49117 .61429 Mdot
.47188 .60611 Mdot
.41062 .58018 Mdot
.22223 .5016 Mdot
.79874 .3563 Mdot
.60287 .49698 Mdot
.55077 .58584 Mdot
.57356 .01408 Mdot
.70278 .07987 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50385 .00163 Mdot
.51226 .0052 Mdot
.53905 .01655 Mdot
.62381 .05239 Mdot
.87612 .15594 Mdot
.29605 .25953 Mdot
.48716 .11812 Mdot
.65905 .10623 Mdot
.50048 .0002 Mdot
.50151 .00064 Mdot
.50482 .00205 Mdot
.51537 .00652 Mdot
.54894 .02075 Mdot
.65476 .0654 Mdot
.95784 .18731 Mdot
.32342 .22594 Mdot
.47522 .09382 Mdot
.59 .07094 Mdot
.8327 .15 Mdot
.28262 .27807 Mdot
.49817 .61726 Mdot
.49416 .61556 Mdot
.48141 .61015 Mdot
.44082 .59295 Mdot
.31349 .53934 Mdot
.96618 .40338 Mdot
.66922 .4345 Mdot
.58089 .56344 Mdot
.60873 .01721 Mdot
.78727 .11034 Mdot
.19802 .25386 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50669 .00284 Mdot
.52132 .00904 Mdot
.56785 .02875 Mdot
.71308 .08976 Mdot
.09066 .23336 Mdot
.33948 .15378 Mdot
.38632 .02895 Mdot
.27677 .55033 Mdot
.93186 .40487 Mdot
.68606 .46612 Mdot
.4999 .61799 Mdot
.4997 .61791 Mdot
.49904 .61762 Mdot
.49693 .61673 Mdot
.49021 .61388 Mdot
.46881 .60481 Mdot
.40093 .57608 Mdot
.19386 .49006 Mdot
.76276 .3516 Mdot
.56962 .49867 Mdot
.4776 .56117 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.44211 .5935 Mdot
.31748 .54101 Mdot
.97525 .40653 Mdot
.67 .42938 Mdot
.57395 .55867 Mdot
.58486 .00675 Mdot
.71713 .08174 Mdot
.08305 .22615 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50597 .00253 Mdot
.51903 .00807 Mdot
.56057 .02567 Mdot
.69079 .08048 Mdot
.04341 .21793 Mdot
.33172 .17818 Mdot
.41208 .04966 Mdot
.36716 .59027 Mdot
.14533 .48093 Mdot
.73456 .36416 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50825 .0035 Mdot
.52627 .01114 Mdot
.58351 .03538 Mdot
.76035 .10929 Mdot
.17542 .25653 Mdot
.37749 .12489 Mdot
.41341 .0222 Mdot
.32577 .56387 Mdot
.02594 .43273 Mdot
.68737 .40879 Mdot
.49981 .61796 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49399 .61548 Mdot
.48085 .60991 Mdot
.43904 .5922 Mdot
.30802 .53706 Mdot
.95395 .39921 Mdot
.668 .44131 Mdot
.58979 .5697 Mdot
.63922 .03055 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50809 .00343 Mdot
.52578 .01093 Mdot
.58196 .03472 Mdot
.75573 .1074 Mdot
.16808 .25484 Mdot
.37263 .12642 Mdot
.40587 .02054 Mdot
.30599 .55631 Mdot
.98201 .4178 Mdot
.50018 8e-05 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50577 .00245 Mdot
.51839 .0078 Mdot
.55852 .02481 Mdot
.68448 .07785 Mdot
.02923 .21307 Mdot
.33038 .18612 Mdot
.4226 .05699 Mdot
.40323 .60607 Mdot
.24749 .52178 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50399 .00169 Mdot
.51271 .00539 Mdot
.54048 .01716 Mdot
.62832 .05429 Mdot
.88846 .16077 Mdot
.30254 .25592 Mdot
.49079 .11634 Mdot
.66522 .10781 Mdot
.04531 .23491 Mdot
.35835 .19347 Mdot
.50024 .0001 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.50762 .00323 Mdot
.52429 .0103 Mdot
.57724 .03273 Mdot
.74156 .10156 Mdot
.14428 .24889 Mdot
.35903 .13272 Mdot
.3889 .01846 Mdot
.26533 .54166 Mdot
.90413 .3948 Mdot
.4977 .61706 Mdot
.49267 .61492 Mdot
.47664 .60813 Mdot
.42569 .58655 Mdot
.26729 .52014 Mdot
.87156 .37346 Mdot
.64825 .48002 Mdot
.61652 .59843 Mdot
.74438 .07902 Mdot
.11082 .22647 Mdot
.32414 .13184 Mdot
.49864 .61746 Mdot
.49568 .6162 Mdot
.48624 .6122 Mdot
.45619 .59946 Mdot
.36124 .55935 Mdot
.08352 .4464 Mdot
.6862 .37247 Mdot
.50868 .50832 Mdot
.34418 .51636 Mdot
.98153 .39391 Mdot
.64653 .41099 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50637 .0027 Mdot
.52029 .0086 Mdot
.56455 .02736 Mdot
.70301 .08557 Mdot
.06986 .22673 Mdot
.33526 .16402 Mdot
.39536 .03715 Mdot
.30958 .56502 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.50668 .00283 Mdot
.52129 .00903 Mdot
.56773 .0287 Mdot
.71273 .08961 Mdot
.08994 .23313 Mdot
.33931 .15412 Mdot
.38656 .0292 Mdot
.27769 .55075 Mdot
.93369 .40543 Mdot
.6863 .46514 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47444 .6072 Mdot
.41874 .58361 Mdot
.24637 .5115 Mdot
.83533 .364 Mdot
.62952 .49084 Mdot
.59726 .59809 Mdot
.70197 .06471 Mdot
.03462 .20559 Mdot
.31575 .17375 Mdot
.50008 4e-05 Mdot
.50026 .00011 Mdot
.50084 .00036 Mdot
.50268 .00113 Mdot
.50852 .00361 Mdot
.52715 .01151 Mdot
.58631 .03656 Mdot
.76868 .11271 Mdot
.18814 .25924 Mdot
.38667 .1227 Mdot
.42922 .0263 Mdot
.36908 .58086 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48465 .61152 Mdot
.45112 .59731 Mdot
.34541 .55271 Mdot
.04261 .43089 Mdot
.67665 .39186 Mdot
.52452 .52401 Mdot
.40902 .54665 Mdot
.16436 .46683 Mdot
.71471 .34013 Mdot
.50006 2e-05 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51875 .00795 Mdot
.55967 .02529 Mdot
.68803 .07933 Mdot
.03725 .21583 Mdot
.3311 .18161 Mdot
.41656 .05281 Mdot
.3825 .59699 Mdot
.49776 .61708 Mdot
.49286 .61501 Mdot
.47727 .60839 Mdot
.42768 .58739 Mdot
.27332 .52263 Mdot
.88278 .37667 Mdot
.6526 .47577 Mdot
.61783 .59654 Mdot
.74408 .07803 Mdot
.10891 .22547 Mdot
.32282 .13221 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.50562 .00238 Mdot
.51791 .0076 Mdot
.55701 .02417 Mdot
.67982 .0759 Mdot
.01852 .20933 Mdot
.3295 .1922 Mdot
.43092 .06268 Mdot
.43195 .00064 Mdot
.334 .55749 Mdot
.02979 .43003 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50632 .00268 Mdot
.52014 .00854 Mdot
.56409 .02716 Mdot
.7016 .08499 Mdot
.06689 .22576 Mdot
.33477 .16556 Mdot
.39699 .03846 Mdot
.31527 .56753 Mdot
.01461 .43222 Mdot
.69207 .41869 Mdot
.49744 .61695 Mdot
.49183 .61457 Mdot
.47398 .607 Mdot
.41726 .58298 Mdot
.24194 .50968 Mdot
.8282 .36233 Mdot
.62495 .49242 Mdot
.59045 .59671 Mdot
.68445 .05809 Mdot
.99722 .1933 Mdot
.31416 .19588 Mdot
.49887 .61756 Mdot
.49641 .61651 Mdot
.48856 .61318 Mdot
.46356 .60259 Mdot
.38439 .5691 Mdot
.14666 .47111 Mdot
.71878 .35359 Mdot
.52505 .4983 Mdot
.36873 .52142 Mdot
.03708 .41307 Mdot
.65032 .379 Mdot
.5003 .00013 Mdot
.50097 .00041 Mdot
.50309 .00131 Mdot
.50984 .00417 Mdot
.53135 .01329 Mdot
.59956 .04216 Mdot
.80758 .12856 Mdot
.23887 .26655 Mdot
.43201 .11937 Mdot
.52625 .05824 Mdot
.65969 .08247 Mdot
.99445 .20689 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.508 .00339 Mdot
.52548 .0108 Mdot
.58102 .03432 Mdot
.7529 .10623 Mdot
.16348 .25375 Mdot
.36974 .12748 Mdot
.40171 .01976 Mdot
.29542 .55235 Mdot
.96007 .41077 Mdot
.68398 .4474 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.50511 .00217 Mdot
.51628 .0069 Mdot
.55183 .02197 Mdot
.66377 .06918 Mdot
.98024 .19559 Mdot
.32628 .21386 Mdot
.46048 .08294 Mdot
.536 .04668 Mdot
.49804 .6172 Mdot
.49375 .61538 Mdot
.48008 .60959 Mdot
.43662 .59117 Mdot
.30057 .53395 Mdot
.93774 .39379 Mdot
.66594 .45005 Mdot
.60033 .57749 Mdot
.67545 .04643 Mdot
.96359 .17808 Mdot
.30587 .21154 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51747 .00741 Mdot
.55562 .02358 Mdot
.67552 .0741 Mdot
.00847 .20578 Mdot
.32873 .19793 Mdot
.43886 .06807 Mdot
.45953 .01277 Mdot
.42014 .59369 Mdot
.26594 .52273 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50812 .00344 Mdot
.52588 .01097 Mdot
.58227 .03485 Mdot
.75665 .10777 Mdot
.16956 .25519 Mdot
.37358 .12609 Mdot
.4073 .02084 Mdot
.30969 .55771 Mdot
.98994 .42042 Mdot
.68527 .42974 Mdot
.49772 .61707 Mdot
.49273 .61495 Mdot
.47683 .60821 Mdot
.42629 .5868 Mdot
.26909 .52088 Mdot
.87488 .3744 Mdot
.6496 .47881 Mdot
.61712 .59796 Mdot
.74488 .07896 Mdot
.11124 .22643 Mdot
.324 .13149 Mdot
.49987 .61798 Mdot
.49958 .61786 Mdot
.49866 .61746 Mdot
.49572 .61622 Mdot
.48636 .61225 Mdot
.45656 .59962 Mdot
.36242 .55985 Mdot
.08667 .44761 Mdot
.68724 .37118 Mdot
.50823 .5074 Mdot
.34156 .51502 Mdot
.49853 .61741 Mdot
.4953 .61604 Mdot
.48504 .61169 Mdot
.45235 .59784 Mdot
.34927 .55432 Mdot
.0524 .43456 Mdot
.67834 .38685 Mdot
.51923 .5197 Mdot
.38889 .53748 Mdot
.1051 .44264 Mdot
.67487 .35214 Mdot
.49867 .61747 Mdot
.49576 .61624 Mdot
.4865 .61231 Mdot
.45701 .59981 Mdot
.36382 .56044 Mdot
.0904 .44905 Mdot
.68855 .36968 Mdot
.50786 .50636 Mdot
.33895 .51364 Mdot
.96763 .38855 Mdot
.64453 .41835 Mdot
.49959 .61786 Mdot
.4987 .61748 Mdot
.49587 .61628 Mdot
.48683 .61245 Mdot
.45807 .60026 Mdot
.36712 .56183 Mdot
.09923 .45247 Mdot
.69195 .36632 Mdot
.50769 .50416 Mdot
.33497 .51129 Mdot
.95675 .38428 Mdot
.49954 .61784 Mdot
.49854 .61742 Mdot
.49535 .61606 Mdot
.48519 .61176 Mdot
.45286 .59805 Mdot
.35084 .55498 Mdot
.05643 .43608 Mdot
.67914 .38485 Mdot
.5173 .51801 Mdot
.38135 .53402 Mdot
.08347 .43393 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52546 .0108 Mdot
.58095 .0343 Mdot
.75271 .10615 Mdot
.16316 .25367 Mdot
.36954 .12755 Mdot
.40143 .01971 Mdot
.29474 .55209 Mdot
.95868 .41034 Mdot
.68391 .44822 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.51117 .00474 Mdot
.53558 .01508 Mdot
.6129 .04779 Mdot
.84573 .1439 Mdot
.27539 .26555 Mdot
.46935 .11987 Mdot
.61762 .09164 Mdot
.92671 .19102 Mdot
.34188 .25659 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51264 .00536 Mdot
.54026 .01707 Mdot
.62763 .054 Mdot
.88656 .16003 Mdot
.30161 .25651 Mdot
.49037 .11666 Mdot
.66469 .10773 Mdot
.49943 .61779 Mdot
.49819 .61727 Mdot
.49425 .61559 Mdot
.48167 .61026 Mdot
.44165 .5933 Mdot
.31606 .54041 Mdot
.97201 .4054 Mdot
.66973 .43121 Mdot
.57645 .56039 Mdot
.59349 .01053 Mdot
.74284 .0923 Mdot
.49962 .61787 Mdot
.49878 .61752 Mdot
.49612 .61639 Mdot
.48764 .61279 Mdot
.46063 .60134 Mdot
.37517 .56522 Mdot
.12109 .461 Mdot
.70239 .35927 Mdot
.51183 .50026 Mdot
.339 .51122 Mdot
.9638 .38615 Mdot
.49999 .61803 Mdot
.49995 .61801 Mdot
.49986 .61797 Mdot
.49954 .61784 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.4851 .61172 Mdot
.45257 .59793 Mdot
.34995 .55461 Mdot
.05415 .43522 Mdot
.67868 .38598 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.50818 .00347 Mdot
.52606 .01105 Mdot
.58286 .0351 Mdot
.75841 .1085 Mdot
.17236 .25584 Mdot
.37542 .1255 Mdot
.41013 .02145 Mdot
.31708 .56053 Mdot
.0062 .4259 Mdot
.68602 .42015 Mdot
.49905 .61763 Mdot
.49696 .61674 Mdot
.49031 .61393 Mdot
.46915 .60495 Mdot
.40199 .57653 Mdot
.19695 .49131 Mdot
.76631 .35189 Mdot
.57315 .49866 Mdot
.4859 .56411 Mdot
.37753 .55106 Mdot
.10307 .4484 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51553 .00659 Mdot
.54945 .02096 Mdot
.65635 .06607 Mdot
.96185 .1888 Mdot
.32402 .22384 Mdot
.47282 .09196 Mdot
.58106 .06689 Mdot
.80569 .13883 Mdot
.5002 8e-05 Mdot
.50063 .00027 Mdot
.502 .00085 Mdot
.50638 .00271 Mdot
.52033 .00862 Mdot
.56469 .02742 Mdot
.70343 .08575 Mdot
.07075 .22702 Mdot
.33541 .16357 Mdot
.39489 .03676 Mdot
.30793 .56429 Mdot
.99787 .42641 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50798 .00338 Mdot
.52542 .01078 Mdot
.58084 .03425 Mdot
.75236 .10601 Mdot
.16259 .25354 Mdot
.3692 .12769 Mdot
.40095 .01963 Mdot
.29354 .55165 Mdot
.95628 .40959 Mdot
.68378 .44962 Mdot
.49755 .61699 Mdot
.49218 .61472 Mdot
.47509 .60747 Mdot
.42079 .58447 Mdot
.25251 .51403 Mdot
.84553 .36651 Mdot
.63555 .48826 Mdot
.6052 .59927 Mdot
.72141 .07182 Mdot
.0725 .21699 Mdot
.31857 .15208 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.5217 .0092 Mdot
.56904 .02926 Mdot
.71672 .09127 Mdot
.09793 .2356 Mdot
.34134 .15044 Mdot
.38427 .02653 Mdot
.26851 .54649 Mdot
.91563 .39994 Mdot
.68346 .47455 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50237 .00101 Mdot
.50757 .00321 Mdot
.5241 .01022 Mdot
.57665 .03248 Mdot
.73977 .10082 Mdot
.14113 .24806 Mdot
.35747 .1337 Mdot
.38747 .01854 Mdot
.26238 .54073 Mdot
.89929 .39363 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49715 .61683 Mdot
.49093 .61419 Mdot
.47112 .60579 Mdot
.40824 .57917 Mdot
.21521 .49873 Mdot
.78913 .3547 Mdot
.5946 .49781 Mdot
.53376 .58044 Mdot
.5232 .6115 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.5068 .00288 Mdot
.52167 .00919 Mdot
.56895 .02922 Mdot
.71644 .09116 Mdot
.09738 .23543 Mdot
.34119 .15068 Mdot
.3844 .0267 Mdot
.26906 .54675 Mdot
.9167 .40026 Mdot
.68366 .47401 Mdot
.49779 .6171 Mdot
.49296 .61505 Mdot
.47756 .60852 Mdot
.42862 .58779 Mdot
.27616 .52381 Mdot
.88819 .37826 Mdot
.65447 .47359 Mdot
.61776 .59535 Mdot
.74201 .07679 Mdot
.1047 .22415 Mdot
.32142 .13394 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.52661 .01128 Mdot
.58459 .03583 Mdot
.76357 .11061 Mdot
.18041 .25762 Mdot
.38098 .12396 Mdot
.4192 .02362 Mdot
.34136 .56992 Mdot
.06304 .44603 Mdot
.49938 .61777 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.47981 .60947 Mdot
.43577 .59081 Mdot
.29796 .53287 Mdot
.93219 .39197 Mdot
.66508 .45295 Mdot
.60352 .57999 Mdot
.68652 .0513 Mdot
.98952 .18726 Mdot
.49964 .61788 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48837 .6131 Mdot
.46296 .60233 Mdot
.38249 .5683 Mdot
.14133 .46899 Mdot
.71496 .35452 Mdot
.52157 .49851 Mdot
.36042 .51844 Mdot
.01572 .405 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51919 .00814 Mdot
.56107 .02589 Mdot
.69234 .08112 Mdot
.04683 .21909 Mdot
.33209 .1763 Mdot
.40967 .04795 Mdot
.35892 .58667 Mdot
.1232 .47235 Mdot
.72059 .36921 Mdot
.49953 .61783 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48466 .61153 Mdot
.45115 .59733 Mdot
.34552 .55275 Mdot
.04287 .43099 Mdot
.67669 .39173 Mdot
.52437 .52389 Mdot
.40846 .5464 Mdot
.16268 .46614 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50768 .00326 Mdot
.52446 .01037 Mdot
.57779 .03296 Mdot
.74322 .10224 Mdot
.14717 .24965 Mdot
.3605 .13185 Mdot
.39037 .01846 Mdot
.26849 .54271 Mdot
.90949 .39616 Mdot
.67905 .47561 Mdot
.49747 .61696 Mdot
.49194 .61462 Mdot
.47433 .60715 Mdot
.41839 .58346 Mdot
.24532 .51107 Mdot
.83363 .36359 Mdot
.62846 .49123 Mdot
.59573 .59781 Mdot
.69809 .06326 Mdot
.0266 .20303 Mdot
.31539 .17848 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.5064 .00271 Mdot
.52039 .00865 Mdot
.5649 .0275 Mdot
.70407 .08601 Mdot
.0721 .22746 Mdot
.33564 .16288 Mdot
.39419 .03618 Mdot
.30546 .5632 Mdot
.99235 .42452 Mdot
.69071 .43161 Mdot
.50033 .00014 Mdot
.50105 .00045 Mdot
.50335 .00142 Mdot
.51068 .00453 Mdot
.53402 .01443 Mdot
.60802 .04573 Mdot
.83188 .13835 Mdot
.26357 .2668 Mdot
.4574 .11979 Mdot
.58808 .08077 Mdot
.84424 .15832 Mdot
.29849 .28074 Mdot
.49966 .61789 Mdot
.49892 .61758 Mdot
.49655 .61657 Mdot
.48901 .61337 Mdot
.46501 .6032 Mdot
.38893 .57102 Mdot
.15945 .47621 Mdot
.72885 .3519 Mdot
.53487 .49815 Mdot
.39277 .53021 Mdot
.10172 .43816 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50675 .00286 Mdot
.52151 .00912 Mdot
.56842 .029 Mdot
.71485 .09049 Mdot
.0942 .23445 Mdot
.34036 .15213 Mdot
.38524 .02774 Mdot
.27252 .54837 Mdot
.92345 .4023 Mdot
.49976 .61793 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47572 .60774 Mdot
.4228 .58532 Mdot
.25856 .51653 Mdot
.85593 .36919 Mdot
.64108 .48525 Mdot
.6112 .59957 Mdot
.73488 .07644 Mdot
.49844 .61737 Mdot
.49503 .61593 Mdot
.48416 .61132 Mdot
.44957 .59666 Mdot
.34059 .55068 Mdot
.03052 .4264 Mdot
.67495 .39828 Mdot
.53205 .52972 Mdot
.43692 .55924 Mdot
.24961 .50227 Mdot
.82358 .35473 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49715 .61683 Mdot
.49093 .61419 Mdot
.47111 .60578 Mdot
.40819 .57915 Mdot
.21507 .49868 Mdot
.78894 .35467 Mdot
.59444 .49782 Mdot
.53342 .58032 Mdot
.52216 .61108 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48977 .6137 Mdot
.46741 .60422 Mdot
.39651 .57421 Mdot
.18108 .48489 Mdot
.74895 .35097 Mdot
.55556 .49851 Mdot
.44381 .54897 Mdot
.24952 .49796 Mdot
.8165 .35041 Mdot
.5006 .00025 Mdot
.50191 .00081 Mdot
.50609 .00258 Mdot
.5194 .00823 Mdot
.56174 .02617 Mdot
.69438 .08198 Mdot
.05133 .2206 Mdot
.33261 .17384 Mdot
.4066 .04573 Mdot
.3484 .58207 Mdot
.09567 .46184 Mdot
.70792 .37839 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51417 .00601 Mdot
.54511 .01912 Mdot
.6428 .06038 Mdot
.9271 .1757 Mdot
.31696 .24095 Mdot
.48891 .10627 Mdot
.64425 .096 Mdot
.98752 .21215 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49839 .61735 Mdot
.49488 .61586 Mdot
.4837 .61112 Mdot
.44812 .59604 Mdot
.33609 .54879 Mdot
.0194 .42231 Mdot
.67369 .40437 Mdot
.53978 .53528 Mdot
.46493 .57177 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48801 .61295 Mdot
.46183 .60185 Mdot
.37893 .5668 Mdot
.13143 .46507 Mdot
.70845 .35661 Mdot
.5161 .49916 Mdot
.34787 .51406 Mdot
.98464 .39354 Mdot
.64441 .40776 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50765 .00324 Mdot
.52436 .01033 Mdot
.57748 .03283 Mdot
.74229 .10186 Mdot
.14555 .24923 Mdot
.35967 .13233 Mdot
.38953 .01845 Mdot
.26666 .5421 Mdot
.90637 .39536 Mdot
.67856 .47724 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50739 .00313 Mdot
.52355 .00998 Mdot
.57489 .03173 Mdot
.73447 .09863 Mdot
.13165 .24547 Mdot
.35312 .13687 Mdot
.38423 .01923 Mdot
.25659 .53915 Mdot
.89042 .39173 Mdot
.67594 .48548 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47458 .60725 Mdot
.41916 .58378 Mdot
.24762 .51202 Mdot
.83739 .36449 Mdot
.63079 .49035 Mdot
.59903 .59841 Mdot
.70641 .06637 Mdot
.04363 .20841 Mdot
.31622 .16847 Mdot
.49931 .61774 Mdot
.49781 .6171 Mdot
.49301 .61507 Mdot
.47772 .60859 Mdot
.42914 .588 Mdot
.27773 .52446 Mdot
.8912 .37915 Mdot
.65546 .47234 Mdot
.61755 .5946 Mdot
.74036 .0759 Mdot
.10146 .22317 Mdot
.50062 .00026 Mdot
.50198 .00084 Mdot
.50632 .00268 Mdot
.52014 .00854 Mdot
.56408 .02716 Mdot
.70157 .08497 Mdot
.06683 .22574 Mdot
.33476 .16559 Mdot
.39702 .03848 Mdot
.31537 .56757 Mdot
.01485 .4323 Mdot
.69208 .41855 Mdot
.49887 .61755 Mdot
.4964 .61651 Mdot
.48853 .61317 Mdot
.46346 .60254 Mdot
.38408 .56897 Mdot
.14578 .47076 Mdot
.71813 .35373 Mdot
.52444 .49833 Mdot
.36728 .5209 Mdot
.03332 .41163 Mdot
.64974 .38097 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00321 Mdot
.52413 .01023 Mdot
.57675 .03252 Mdot
.7401 .10095 Mdot
.14171 .24821 Mdot
.35775 .13352 Mdot
.38772 .01852 Mdot
.26288 .54088 Mdot
.9001 .39382 Mdot
.50072 .00031 Mdot
.5023 .00097 Mdot
.50732 .0031 Mdot
.52332 .00989 Mdot
.57418 .03143 Mdot
.73234 .09774 Mdot
.12775 .24438 Mdot
.35147 .13826 Mdot
.38334 .0197 Mdot
.25548 .53901 Mdot
.88902 .39155 Mdot
.67587 .4863 Mdot
.49747 .61696 Mdot
.49193 .61461 Mdot
.47428 .60713 Mdot
.41824 .58339 Mdot
.24486 .51088 Mdot
.83288 .36342 Mdot
.62799 .4914 Mdot
.59504 .59767 Mdot
.69634 .0626 Mdot
.02292 .20184 Mdot
.31524 .18066 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52001 .00849 Mdot
.56368 .02699 Mdot
.70033 .08446 Mdot
.06419 .22487 Mdot
.33435 .16697 Mdot
.39853 .03967 Mdot
.32062 .56988 Mdot
.0271 .43663 Mdot
.69312 .41163 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50978 .00415 Mdot
.53115 .01321 Mdot
.59894 .0419 Mdot
.80577 .12783 Mdot
.23683 .26641 Mdot
.42996 .11937 Mdot
.52141 .05651 Mdot
.64486 .0763 Mdot
.95683 .19281 Mdot
.50069 .00029 Mdot
.5022 .00093 Mdot
.50701 .00297 Mdot
.52233 .00947 Mdot
.57103 .0301 Mdot
.72276 .09378 Mdot
.10975 .23917 Mdot
.34485 .1453 Mdot
.38237 .02319 Mdot
.25908 .54184 Mdot
.89745 .39453 Mdot
.67922 .48316 Mdot
.49808 .61722 Mdot
.4939 .61545 Mdot
.48055 .60979 Mdot
.43811 .5918 Mdot
.30516 .53587 Mdot
.94767 .39709 Mdot
.66727 .44474 Mdot
.59406 .57279 Mdot
.65388 .03697 Mdot
.91021 .15842 Mdot
.29419 .23731 Mdot
.49829 .61731 Mdot
.49456 .61573 Mdot
.48266 .61068 Mdot
.44481 .59464 Mdot
.32583 .5445 Mdot
.99469 .41338 Mdot
.67152 .4183 Mdot
.55864 .54827 Mdot
.53173 .60141 Mdot
.55211 .01259 Mdot
.64926 .06004 Mdot
.49868 .61747 Mdot
.49578 .61624 Mdot
.48656 .61233 Mdot
.4572 .59989 Mdot
.36441 .56069 Mdot
.09196 .44965 Mdot
.68912 .36906 Mdot
.50775 .50595 Mdot
.33802 .51313 Mdot
.96514 .38758 Mdot
.64413 .41964 Mdot
.49891 .61757 Mdot
.49652 .61656 Mdot
.48891 .61333 Mdot
.46468 .60306 Mdot
.3879 .57058 Mdot
.15655 .47505 Mdot
.72644 .35222 Mdot
.53246 .49815 Mdot
.38683 .52803 Mdot
.0854 .43174 Mdot
.66193 .35631 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50302 .00128 Mdot
.50961 .00408 Mdot
.53062 .01298 Mdot
.59726 .04119 Mdot
.80088 .12584 Mdot
.23114 .26591 Mdot
.42434 .1194 Mdot
.50827 .05187 Mdot
.60459 .05953 Mdot
.84674 .14966 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52517 .01067 Mdot
.58003 .0339 Mdot
.74993 .10501 Mdot
.15857 .25255 Mdot
.36679 .12869 Mdot
.39774 .01912 Mdot
.28563 .54875 Mdot
.94075 .40488 Mdot
.6827 .45856 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50505 .00214 Mdot
.51607 .00682 Mdot
.55117 .02169 Mdot
.66171 .06832 Mdot
.97517 .19373 Mdot
.32573 .21665 Mdot
.46407 .0855 Mdot
.54897 .05247 Mdot
.70618 .09716 Mdot
.09312 .23915 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00344 Mdot
.52581 .01094 Mdot
.58205 .03476 Mdot
.75599 .1075 Mdot
.1685 .25494 Mdot
.37289 .12632 Mdot
.40626 .02062 Mdot
.30702 .5567 Mdot
.98419 .41852 Mdot
.68504 .43315 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.51688 .00716 Mdot
.55373 .02277 Mdot
.66964 .07164 Mdot
.9945 .20077 Mdot
.32761 .20587 Mdot
.44981 .07552 Mdot
.49796 .02976 Mdot
.54305 .02787 Mdot
.65192 .06729 Mdot
.49941 .61779 Mdot
.49813 .61724 Mdot
.49406 .61551 Mdot
.48106 .61 Mdot
.43973 .59249 Mdot
.31015 .53795 Mdot
.95869 .40082 Mdot
.6685 .43869 Mdot
.58642 .56731 Mdot
.62768 .0255 Mdot
.84058 .13158 Mdot
.49911 .61766 Mdot
.49718 .61684 Mdot
.49101 .61422 Mdot
.47137 .60589 Mdot
.409 .57949 Mdot
.21746 .49965 Mdot
.79215 .35518 Mdot
.59725 .49758 Mdot
.53933 .58223 Mdot
.5398 .00029 Mdot
.59936 .03681 Mdot
.50034 .00015 Mdot
.5011 .00046 Mdot
.50349 .00148 Mdot
.51113 .00472 Mdot
.53544 .01503 Mdot
.61249 .04762 Mdot
.84456 .14343 Mdot
.27446 .26569 Mdot
.46843 .11988 Mdot
.61536 .09081 Mdot
.92057 .18863 Mdot
.34004 .25925 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51918 .00813 Mdot
.56103 .02587 Mdot
.69221 .08107 Mdot
.04655 .21899 Mdot
.33206 .17645 Mdot
.40987 .04809 Mdot
.35959 .58696 Mdot
.12499 .47304 Mdot
.72158 .36872 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49718 .61684 Mdot
.491 .61422 Mdot
.47133 .60588 Mdot
.40889 .57944 Mdot
.21713 .49952 Mdot
.79171 .35511 Mdot
.59687 .49762 Mdot
.53854 .58198 Mdot
.53744 .61736 Mdot
.49899 .61761 Mdot
.49679 .61667 Mdot
.48977 .6137 Mdot
.46742 .60422 Mdot
.39654 .57423 Mdot
.18117 .48493 Mdot
.74904 .35097 Mdot
.55565 .49851 Mdot
.44403 .54905 Mdot
.25019 .49823 Mdot
.81762 .35069 Mdot
.49916 .61768 Mdot
.49732 .6169 Mdot
.49145 .61441 Mdot
.47277 .60649 Mdot
.41345 .58137 Mdot
.23061 .50503 Mdot
.81081 .35858 Mdot
.61252 .49549 Mdot
.56931 .59133 Mdot
.6268 .03553 Mdot
.855 .14103 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.5257 .0109 Mdot
.58172 .03462 Mdot
.75501 .1071 Mdot
.16692 .25457 Mdot
.37188 .12668 Mdot
.40477 .02033 Mdot
.30319 .55525 Mdot
.97608 .41587 Mdot
.68472 .43796 Mdot
.49822 .61728 Mdot
.49434 .61564 Mdot
.48198 .61039 Mdot
.44264 .59372 Mdot
.31912 .54169 Mdot
.97903 .40785 Mdot
.6703 .42723 Mdot
.571 .55666 Mdot
.57469 .00228 Mdot
.68636 .06901 Mdot
.01792 .20492 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50278 .00118 Mdot
.50886 .00376 Mdot
.52823 .01197 Mdot
.58974 .03801 Mdot
.77882 .11686 Mdot
.20274 .26199 Mdot
.39837 .12091 Mdot
.4517 .03296 Mdot
.4337 .60691 Mdot
.31909 .5472 Mdot
.49949 .61782 Mdot
.49837 .61734 Mdot
.49479 .61583 Mdot
.48342 .611 Mdot
.44721 .59566 Mdot
.33325 .54761 Mdot
.01249 .41979 Mdot
.67301 .40823 Mdot
.54488 .53884 Mdot
.48316 .57989 Mdot
.39625 .56432 Mdot
.50077 .00032 Mdot
.50244 .00103 Mdot
.50777 .0033 Mdot
.52476 .0105 Mdot
.57872 .03335 Mdot
.74602 .10339 Mdot
.15197 .25089 Mdot
.36306 .13046 Mdot
.39317 .01861 Mdot
.27479 .54487 Mdot
.92057 .39911 Mdot
.68061 .46973 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48863 .61321 Mdot
.4638 .60269 Mdot
.38514 .56942 Mdot
.14876 .47194 Mdot
.72034 .35326 Mdot
.52652 .49825 Mdot
.3723 .52272 Mdot
.04643 .41663 Mdot
.6519 .3742 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.50808 .00343 Mdot
.52575 .01092 Mdot
.58187 .03468 Mdot
.75545 .10728 Mdot
.16762 .25474 Mdot
.37233 .12652 Mdot
.40543 .02046 Mdot
.30487 .55589 Mdot
.97963 .41703 Mdot
.68486 .43585 Mdot
.49991 .618 Mdot
.49973 .61792 Mdot
.49913 .61767 Mdot
.49724 .61686 Mdot
.4912 .6143 Mdot
.47198 .60615 Mdot
.41095 .58031 Mdot
.22319 .502 Mdot
.80008 .35654 Mdot
.60399 .49684 Mdot
.553 .58652 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50551 .00233 Mdot
.51754 .00744 Mdot
.55583 .02366 Mdot
.67615 .07436 Mdot
.00995 .2063 Mdot
.32884 .19708 Mdot
.43769 .06728 Mdot
.45546 .01098 Mdot
.40728 .58826 Mdot
.22774 .50708 Mdot
.49796 .61717 Mdot
.4935 .61528 Mdot
.47931 .60926 Mdot
.43416 .59013 Mdot
.29304 .53082 Mdot
.92186 .38863 Mdot
.66324 .4582 Mdot
.60875 .58436 Mdot
.70499 .05948 Mdot
.03048 .20116 Mdot
.31053 .17308 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51253 .00531 Mdot
.53989 .01691 Mdot
.62646 .05351 Mdot
.88339 .15879 Mdot
.3 .25748 Mdot
.48956 .11715 Mdot
.66346 .10748 Mdot
.04166 .23374 Mdot
.35808 .19556 Mdot
.49838 .61735 Mdot
.49484 .61585 Mdot
.48356 .61106 Mdot
.44765 .59584 Mdot
.33463 .54818 Mdot
.01583 .42101 Mdot
.67333 .40636 Mdot
.54239 .53711 Mdot
.47428 .57594 Mdot
.36777 .5522 Mdot
.08495 .44324 Mdot
.49815 .61725 Mdot
.49412 .61554 Mdot
.48126 .61009 Mdot
.44036 .59276 Mdot
.31208 .53875 Mdot
.96299 .40229 Mdot
.66892 .43629 Mdot
.58327 .5651 Mdot
.6169 .02078 Mdot
.81052 .11967 Mdot
.22583 .25667 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.4808 .60989 Mdot
.43891 .59214 Mdot
.30761 .53689 Mdot
.95305 .3989 Mdot
.6679 .4418 Mdot
.59041 .57014 Mdot
.64136 .03149 Mdot
.87755 .14597 Mdot
.27982 .24862 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50726 .00308 Mdot
.52312 .0098 Mdot
.57353 .03116 Mdot
.73036 .09693 Mdot
.12411 .24335 Mdot
.35 .1396 Mdot
.38274 .02024 Mdot
.25507 .53913 Mdot
.8888 .39166 Mdot
.67608 .48657 Mdot
.49846 .61738 Mdot
.49511 .61596 Mdot
.48441 .61142 Mdot
.45038 .597 Mdot
.3431 .55173 Mdot
.03679 .42872 Mdot
.67578 .39492 Mdot
.52802 .52671 Mdot
.42208 .55256 Mdot
.20387 .48317 Mdot
.75688 .34178 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49105 .61424 Mdot
.47149 .60595 Mdot
.40939 .57966 Mdot
.21861 .50012 Mdot
.79372 .35544 Mdot
.59861 .49745 Mdot
.54214 .58313 Mdot
.54813 .0037 Mdot
.62522 .04765 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50421 .00179 Mdot
.51341 .00569 Mdot
.54272 .01811 Mdot
.63533 .05724 Mdot
.90733 .16811 Mdot
.31062 .24924 Mdot
.49228 .11227 Mdot
.66237 .10512 Mdot
.03591 .23086 Mdot
.35604 .19785 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50171 .00072 Mdot
.50544 .00231 Mdot
.51734 .00735 Mdot
.55518 .02339 Mdot
.67415 .07353 Mdot
.00526 .20463 Mdot
.32848 .19976 Mdot
.4414 .06979 Mdot
.46841 .01669 Mdot
.44833 .60563 Mdot
.5 .61803 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49985 .61797 Mdot
.49951 .61783 Mdot
.49845 .61738 Mdot
.49506 .61594 Mdot
.48427 .61136 Mdot
.44993 .59681 Mdot
.34171 .55115 Mdot
.0333 .42743 Mdot
.49986 .61797 Mdot
.49954 .61784 Mdot
.49854 .61741 Mdot
.49535 .61606 Mdot
.48517 .61175 Mdot
.45278 .59802 Mdot
.3506 .55488 Mdot
.05581 .43584 Mdot
.67901 .38516 Mdot
.51758 .51827 Mdot
.38248 .53454 Mdot
.49897 .6176 Mdot
.49673 .61665 Mdot
.48957 .61361 Mdot
.46678 .60395 Mdot
.39453 .57338 Mdot
.17539 .4826 Mdot
.74328 .35097 Mdot
.54968 .49839 Mdot
.42941 .5437 Mdot
.2067 .48039 Mdot
.75403 .33827 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.489 .61337 Mdot
.46497 .60318 Mdot
.38882 .57097 Mdot
.15913 .47608 Mdot
.72858 .35194 Mdot
.5346 .49815 Mdot
.3921 .52997 Mdot
.09988 .43743 Mdot
.66748 .35079 Mdot
.49821 .61727 Mdot
.4943 .61562 Mdot
.48183 .61033 Mdot
.44217 .59352 Mdot
.31767 .54109 Mdot
.9757 .40668 Mdot
.67003 .42912 Mdot
.5736 .55843 Mdot
.58367 .00622 Mdot
.71353 .08026 Mdot
.07589 .22395 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48384 .61118 Mdot
.44855 .59623 Mdot
.33743 .54936 Mdot
.02271 .42352 Mdot
.67404 .40254 Mdot
.53742 .5336 Mdot
.49812 .61724 Mdot
.49401 .61549 Mdot
.48093 .60995 Mdot
.43929 .5923 Mdot
.3088 .53738 Mdot
.95567 .39979 Mdot
.66818 .44036 Mdot
.58857 .56883 Mdot
.63506 .02873 Mdot
.86069 .13945 Mdot
.2696 .25272 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.50681 .00289 Mdot
.52168 .00919 Mdot
.56899 .02923 Mdot
.71656 .0912 Mdot
.09761 .2355 Mdot
.34126 .15058 Mdot
.38435 .02663 Mdot
.26883 .54664 Mdot
.91625 .40013 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.5043 .00182 Mdot
.5137 .00581 Mdot
.54364 .0185 Mdot
.63821 .05845 Mdot
.91502 .17107 Mdot
.31332 .24617 Mdot
.49154 .11015 Mdot
.65709 .10231 Mdot
.02182 .22542 Mdot
.35393 .20525 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50449 .0019 Mdot
.51431 .00607 Mdot
.54557 .01932 Mdot
.64425 .06099 Mdot
.93086 .17714 Mdot
.31796 .23924 Mdot
.48775 .10494 Mdot
.63918 .09359 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50595 .00252 Mdot
.51896 .00804 Mdot
.56033 .02557 Mdot
.69005 .08017 Mdot
.04175 .21737 Mdot
.33155 .1791 Mdot
.41327 .0505 Mdot
.37123 .59205 Mdot
.15643 .48528 Mdot
.74298 .36251 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00327 Mdot
.5246 .01043 Mdot
.57823 .03314 Mdot
.74452 .10278 Mdot
.14941 .25024 Mdot
.36168 .13119 Mdot
.39162 .01851 Mdot
.27128 .54366 Mdot
.91433 .39743 Mdot
.49881 .61753 Mdot
.4962 .61642 Mdot
.4879 .6129 Mdot
.46147 .6017 Mdot
.37782 .56633 Mdot
.12837 .46387 Mdot
.70658 .35735 Mdot
.51468 .49944 Mdot
.34478 .51303 Mdot
.97725 .39088 Mdot
.64373 .41191 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50331 .0014 Mdot
.51054 .00447 Mdot
.53357 .01423 Mdot
.60657 .04512 Mdot
.82776 .1367 Mdot
.25975 .26698 Mdot
.45345 .11971 Mdot
.57832 .07717 Mdot
.81597 .14688 Mdot
.27215 .28193 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51298 .00551 Mdot
.54135 .01753 Mdot
.63104 .05543 Mdot
.89582 .16364 Mdot
.30595 .25347 Mdot
.49194 .11495 Mdot
.66586 .10749 Mdot
.04592 .23489 Mdot
.35805 .19291 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50686 .00291 Mdot
.52186 .00927 Mdot
.56955 .02947 Mdot
.71827 .09192 Mdot
.10101 .23654 Mdot
.34219 .14906 Mdot
.3836 .02559 Mdot
.26556 .54508 Mdot
.90992 .39824 Mdot
.68231 .47736 Mdot
.4978 .6171 Mdot
.49299 .61506 Mdot
.47768 .60857 Mdot
.429 .58795 Mdot
.27733 .52429 Mdot
.89043 .37892 Mdot
.65521 .47266 Mdot
.61761 .5948 Mdot
.74082 .07614 Mdot
.10235 .22344 Mdot
.32073 .13496 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50832 .00353 Mdot
.5265 .01124 Mdot
.58426 .03569 Mdot
.76257 .1102 Mdot
.17887 .25729 Mdot
.37989 .12424 Mdot
.41736 .02316 Mdot
.33637 .56798 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50173 .00073 Mdot
.50551 .00234 Mdot
.51757 .00745 Mdot
.55591 .0237 Mdot
.67642 .07447 Mdot
.01059 .20653 Mdot
.32889 .19672 Mdot
.43719 .06693 Mdot
.4537 .01021 Mdot
.40175 .58592 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50798 .00338 Mdot
.52541 .01077 Mdot
.58079 .03423 Mdot
.75222 .10595 Mdot
.16235 .25348 Mdot
.36905 .12775 Mdot
.40075 .01959 Mdot
.29304 .55147 Mdot
.95528 .40929 Mdot
.68372 .4502 Mdot
.50062 .00026 Mdot
.50196 .00083 Mdot
.50626 .00265 Mdot
.51993 .00845 Mdot
.56343 .02688 Mdot
.69958 .08415 Mdot
.06259 .22435 Mdot
.33411 .16781 Mdot
.39947 .0404 Mdot
.32387 .57131 Mdot
.0348 .43938 Mdot
.69394 .40737 Mdot
.49851 .6174 Mdot
.49526 .61602 Mdot
.48489 .61163 Mdot
.4519 .59764 Mdot
.34786 .55373 Mdot
.04881 .43321 Mdot
.67769 .38867 Mdot
.52108 .52124 Mdot
.39599 .54072 Mdot
.12575 .45102 Mdot
.68591 .3462 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51877 .00796 Mdot
.55973 .02531 Mdot
.68819 .07939 Mdot
.0376 .21595 Mdot
.33114 .18142 Mdot
.4163 .05263 Mdot
.38161 .5966 Mdot
.18528 .49669 Mdot
.76968 .36118 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.4933 .61519 Mdot
.47866 .60899 Mdot
.43211 .58926 Mdot
.28679 .52822 Mdot
.90908 .3846 Mdot
.66046 .46437 Mdot
.61376 .58918 Mdot
.72355 .06785 Mdot
.06877 .21336 Mdot
.49934 .61775 Mdot
.4979 .61714 Mdot
.49331 .6152 Mdot
.4787 .609 Mdot
.43224 .58932 Mdot
.28718 .52838 Mdot
.90988 .38485 Mdot
.66065 .464 Mdot
.6135 .5889 Mdot
.72254 .06739 Mdot
.06677 .21275 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50409 .00173 Mdot
.51302 .00552 Mdot
.54147 .01758 Mdot
.63142 .05559 Mdot
.89684 .16404 Mdot
.3064 .25312 Mdot
.49205 .11474 Mdot
.66577 .10737 Mdot
.04557 .23473 Mdot
.35794 .19306 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50806 .00342 Mdot
.52566 .01088 Mdot
.58159 .03457 Mdot
.75461 .10693 Mdot
.16626 .25442 Mdot
.37147 .12683 Mdot
.40417 .02021 Mdot
.30165 .55468 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47763 .60855 Mdot
.42885 .58789 Mdot
.27687 .5241 Mdot
.88955 .37866 Mdot
.65492 .47303 Mdot
.61768 .59502 Mdot
.74131 .07641 Mdot
.10332 .22373 Mdot
.32101 .13454 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.48482 .6116 Mdot
.45166 .59754 Mdot
.34709 .55341 Mdot
.04686 .43248 Mdot
.67735 .38966 Mdot
.52213 .5221 Mdot
.39998 .54255 Mdot
.1375 .45581 Mdot
.69348 .34362 Mdot
.4987 .61748 Mdot
.49587 .61628 Mdot
.48685 .61246 Mdot
.45814 .60029 Mdot
.36735 .56192 Mdot
.09983 .4527 Mdot
.69219 .3661 Mdot
.50772 .50402 Mdot
.33482 .51118 Mdot
.9563 .38409 Mdot
.64251 .4241 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49494 .61589 Mdot
.48387 .61119 Mdot
.44864 .59626 Mdot
.33769 .54947 Mdot
.02334 .42375 Mdot
.67411 .4022 Mdot
.53697 .53328 Mdot
.4548 .56725 Mdot
.30573 .5259 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.49202 .61465 Mdot
.47457 .60725 Mdot
.41913 .58377 Mdot
.24754 .51198 Mdot
.83724 .36446 Mdot
.6307 .49039 Mdot
.59891 .59838 Mdot
.70611 .06625 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49778 .61709 Mdot
.49292 .61503 Mdot
.47746 .60848 Mdot
.4283 .58765 Mdot
.27519 .52341 Mdot
.88634 .37771 Mdot
.65385 .47435 Mdot
.61783 .59578 Mdot
.74286 .07727 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.51211 .00514 Mdot
.53857 .01635 Mdot
.62233 .05177 Mdot
.87204 .15433 Mdot
.29367 .26058 Mdot
.4855 .11856 Mdot
.6556 .10513 Mdot
.02367 .22748 Mdot
.35636 .20561 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50265 .00112 Mdot
.50843 .00358 Mdot
.52686 .01139 Mdot
.58539 .03617 Mdot
.76596 .1116 Mdot
.18406 .2584 Mdot
.38362 .12334 Mdot
.42377 .02481 Mdot
.35389 .57485 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50516 .00219 Mdot
.51644 .00697 Mdot
.55234 .02219 Mdot
.66533 .06983 Mdot
.98407 .19699 Mdot
.32666 .21174 Mdot
.45769 .08098 Mdot
.52599 .04221 Mdot
.63311 .0662 Mdot
.91742 .17571 Mdot
.49835 .61733 Mdot
.49473 .6158 Mdot
.48321 .61091 Mdot
.44655 .59538 Mdot
.33121 .54675 Mdot
.00755 .418 Mdot
.67257 .411 Mdot
.54862 .54143 Mdot
.49646 .5858 Mdot
.43901 .58252 Mdot
.29229 .52736 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.47491 .60739 Mdot
.42021 .58423 Mdot
.25079 .51332 Mdot
.84264 .36578 Mdot
.6339 .48903 Mdot
.60316 .59903 Mdot
.71654 .07007 Mdot
.0634 .21437 Mdot
.31765 .15714 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50513 .00217 Mdot
.51633 .00692 Mdot
.55199 .02204 Mdot
.66424 .06938 Mdot
.98141 .19602 Mdot
.3264 .21321 Mdot
.45963 .08234 Mdot
.53297 .04532 Mdot
.6554 .07567 Mdot
.97561 .1979 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52124 .00901 Mdot
.56759 .02864 Mdot
.7123 .08943 Mdot
.08907 .23286 Mdot
.3391 .15453 Mdot
.38685 .02951 Mdot
.27882 .55127 Mdot
.93596 .40614 Mdot
.68659 .46391 Mdot
.49792 .61715 Mdot
.49336 .61522 Mdot
.47886 .60907 Mdot
.43275 .58953 Mdot
.28873 .52903 Mdot
.91301 .38583 Mdot
.66138 .46252 Mdot
.61241 .58777 Mdot
.71838 .0655 Mdot
.0584 .21014 Mdot
.31277 .15721 Mdot
.4999 .61799 Mdot
.49967 .6179 Mdot
.49896 .61759 Mdot
.49669 .61663 Mdot
.48946 .61357 Mdot
.46644 .60381 Mdot
.39346 .57293 Mdot
.17234 .48137 Mdot
.74035 .35105 Mdot
.54665 .49832 Mdot
.42192 .54095 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48415 .61131 Mdot
.44954 .59664 Mdot
.34049 .55064 Mdot
.03028 .42631 Mdot
.67492 .39841 Mdot
.53222 .52984 Mdot
.43751 .5595 Mdot
.25147 .50305 Mdot
.82671 .35551 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.5225 .00954 Mdot
.57157 .03033 Mdot
.72442 .09447 Mdot
.11292 .24011 Mdot
.3459 .14399 Mdot
.38219 .02243 Mdot
.25746 .54095 Mdot
.89426 .39357 Mdot
.67826 .48454 Mdot
.49858 .61743 Mdot
.49548 .61612 Mdot
.48559 .61193 Mdot
.45413 .59859 Mdot
.35481 .55665 Mdot
.06667 .43996 Mdot
.68143 .37994 Mdot
.5131 .514 Mdot
.3644 .52613 Mdot
.03604 .41509 Mdot
.65408 .38197 Mdot
.49876 .61751 Mdot
.49605 .61636 Mdot
.4874 .61269 Mdot
.45988 .60102 Mdot
.3728 .56422 Mdot
.11461 .45846 Mdot
.69898 .36116 Mdot
.50992 .50119 Mdot
.33572 .51037 Mdot
.95658 .38372 Mdot
.64177 .42347 Mdot
.49922 .6177 Mdot
.4975 .61698 Mdot
.49205 .61466 Mdot
.47467 .6073 Mdot
.41947 .58392 Mdot
.24856 .5124 Mdot
.83892 .36487 Mdot
.63172 .48997 Mdot
.60029 .59861 Mdot
.70955 .06752 Mdot
.04987 .21033 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50806 .00342 Mdot
.52569 .01089 Mdot
.58168 .03461 Mdot
.75489 .10705 Mdot
.16672 .25452 Mdot
.37176 .12672 Mdot
.40459 .02029 Mdot
.30273 .55508 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50595 .00252 Mdot
.51895 .00803 Mdot
.56029 .02556 Mdot
.68994 .08012 Mdot
.04152 .21729 Mdot
.33152 .17923 Mdot
.41344 .05063 Mdot
.37182 .59231 Mdot
.15804 .48591 Mdot
.74429 .36232 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50333 .00141 Mdot
.51062 .00451 Mdot
.53384 .01435 Mdot
.60744 .04548 Mdot
.83022 .13769 Mdot
.26205 .26688 Mdot
.45583 .11976 Mdot
.5842 .07934 Mdot
.5005 .00021 Mdot
.50159 .00068 Mdot
.50508 .00215 Mdot
.51619 .00687 Mdot
.55154 .02185 Mdot
.66285 .0688 Mdot
.978 .19477 Mdot
.32604 .2151 Mdot
.46208 .08408 Mdot
.54178 .04926 Mdot
.68343 .08755 Mdot
.04323 .22237 Mdot
.49983 .61796 Mdot
.49944 .6178 Mdot
.49823 .61728 Mdot
.49436 .61564 Mdot
.48204 .61042 Mdot
.44283 .5938 Mdot
.31969 .54193 Mdot
.98035 .40831 Mdot
.67041 .42648 Mdot
.56996 .55595 Mdot
.5711 .00071 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50746 .00316 Mdot
.52377 .01008 Mdot
.57561 .03204 Mdot
.73665 .09953 Mdot
.13558 .24655 Mdot
.35486 .13552 Mdot
.38538 .01886 Mdot
.25845 .53958 Mdot
.89312 .39225 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.48752 .61274 Mdot
.46027 .60119 Mdot
.37404 .56474 Mdot
.11799 .45978 Mdot
.70072 .36015 Mdot
.51084 .50068 Mdot
.33721 .51072 Mdot
.9598 .38478 Mdot
.64205 .42166 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48275 .61072 Mdot
.44509 .59476 Mdot
.32669 .54486 Mdot
.99675 .41412 Mdot
.67168 .41713 Mdot
.55702 .54717 Mdot
.52607 .59891 Mdot
.53405 .00493 Mdot
.49745 .61695 Mdot
.49186 .61458 Mdot
.47407 .60704 Mdot
.41756 .58311 Mdot
.24286 .51006 Mdot
.82966 .36266 Mdot
.62591 .49211 Mdot
.59193 .59703 Mdot
.68832 .05957 Mdot
.00572 .19617 Mdot
.31455 .19086 Mdot
.49833 .61732 Mdot
.49467 .61577 Mdot
.48302 .61083 Mdot
.44593 .59512 Mdot
.3293 .54595 Mdot
.00297 .41635 Mdot
.67218 .41359 Mdot
.55215 .54385 Mdot
.50895 .59134 Mdot
.47918 .59963 Mdot
.41828 .58039 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50663 .00281 Mdot
.52112 .00896 Mdot
.5672 .02848 Mdot
.7111 .08894 Mdot
.08664 .2321 Mdot
.33854 .15569 Mdot
.38772 .03039 Mdot
.28211 .55276 Mdot
.50058 .00024 Mdot
.50183 .00078 Mdot
.50584 .00248 Mdot
.51861 .00789 Mdot
.55922 .0251 Mdot
.68662 .07874 Mdot
.03408 .21474 Mdot
.33081 .18339 Mdot
.41892 .05446 Mdot
.3906 .60053 Mdot
.21081 .50692 Mdot
.79949 .36382 Mdot
.49845 .61738 Mdot
.49507 .61594 Mdot
.4843 .61137 Mdot
.45 .59684 Mdot
.34194 .55125 Mdot
.03389 .42765 Mdot
.67539 .39647 Mdot
.52986 .52809 Mdot
.42885 .55561 Mdot
.22463 .49182 Mdot
.78471 .34615 Mdot
.50082 .00035 Mdot
.50261 .00111 Mdot
.50831 .00352 Mdot
.52647 .01122 Mdot
.58415 .03565 Mdot
.76226 .11008 Mdot
.1784 .25719 Mdot
.37955 .12432 Mdot
.4168 .02302 Mdot
.33486 .56739 Mdot
.04733 .44033 Mdot
.68984 .3971 Mdot
.50002 1e-05 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50515 .00218 Mdot
.51641 .00696 Mdot
.55223 .02214 Mdot
.665 .0697 Mdot
.98327 .1967 Mdot
.32658 .21218 Mdot
.45828 .08139 Mdot
.4976 .61702 Mdot
.49234 .61479 Mdot
.47561 .60769 Mdot
.42244 .58517 Mdot
.25748 .51608 Mdot
.85405 .3687 Mdot
.64013 .48582 Mdot
.61027 .59958 Mdot
.7329 .07579 Mdot
.09289 .22248 Mdot
.32132 .14118 Mdot
.49899 .6176 Mdot
.49677 .61667 Mdot
.48972 .61367 Mdot
.46725 .60415 Mdot
.39601 .574 Mdot
.17964 .48431 Mdot
.7475 .35095 Mdot
.55405 .49848 Mdot
.44013 .54763 Mdot
.23851 .49343 Mdot
.79878 .34627 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50657 .00279 Mdot
.52094 .00888 Mdot
.56664 .02824 Mdot
.7094 .08823 Mdot
.08316 .231 Mdot
.33778 .15737 Mdot
.38907 .0317 Mdot
.28712 .55502 Mdot
.9529 .41148 Mdot
.6883 .4545 Mdot
.49753 .61698 Mdot
.49211 .61469 Mdot
.47488 .60738 Mdot
.42012 .58419 Mdot
.25052 .51321 Mdot
.84219 .36567 Mdot
.63364 .48915 Mdot
.60283 .59899 Mdot
.71574 .06978 Mdot
.06188 .21392 Mdot
.31752 .15799 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50569 .00241 Mdot
.51813 .00769 Mdot
.5577 .02445 Mdot
.68192 .07678 Mdot
.02338 .21103 Mdot
.32989 .18944 Mdot
.42712 .06009 Mdot
.41882 .6129 Mdot
.29395 .54086 Mdot
.9394 .39891 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.48052 .60977 Mdot
.438 .59176 Mdot
.30483 .53573 Mdot
.94694 .39685 Mdot
.66718 .44513 Mdot
.59455 .57315 Mdot
.65554 .0377 Mdot
.91445 .16001 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.50868 .00368 Mdot
.52766 .01173 Mdot
.58793 .03725 Mdot
.77348 .11468 Mdot
.19517 .26062 Mdot
.39216 .12174 Mdot
.43947 .02924 Mdot
.39817 .59251 Mdot
.21433 .50442 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51414 .006 Mdot
.54504 .01909 Mdot
.64259 .06029 Mdot
.92654 .17549 Mdot
.31681 .2412 Mdot
.48907 .10647 Mdot
.64496 .09634 Mdot
.98945 .21291 Mdot
.34975 .22268 Mdot
.49994 .61801 Mdot
.49981 .61796 Mdot
.49941 .61778 Mdot
.49812 .61724 Mdot
.49401 .61549 Mdot
.48091 .60994 Mdot
.43924 .59228 Mdot
.30864 .53732 Mdot
.95533 .39968 Mdot
.66815 .44054 Mdot
.58881 .569 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51802 .00764 Mdot
.55736 .02431 Mdot
.68089 .07634 Mdot
.02099 .2102 Mdot
.3297 .19079 Mdot
.42899 .06136 Mdot
.42525 .61572 Mdot
.31346 .54895 Mdot
.98167 .41298 Mdot
.50051 .00022 Mdot
.50162 .00069 Mdot
.50515 .00218 Mdot
.51641 .00696 Mdot
.55223 .02214 Mdot
.66499 .06969 Mdot
.98322 .19668 Mdot
.32658 .21221 Mdot
.45831 .08141 Mdot
.52821 .0432 Mdot
.64021 .06922 Mdot
.93637 .18303 Mdot
.49866 .61747 Mdot
.49574 .61623 Mdot
.48643 .61228 Mdot
.45679 .59971 Mdot
.36312 .56014 Mdot
.08853 .44833 Mdot
.68788 .37042 Mdot
.50802 .50687 Mdot
.34019 .51431 Mdot
.97094 .38983 Mdot
.64504 .41661 Mdot
.50031 .00013 Mdot
.50097 .00041 Mdot
.5031 .00132 Mdot
.50989 .00419 Mdot
.5315 .01335 Mdot
.60004 .04236 Mdot
.80895 .12912 Mdot
.24041 .26665 Mdot
.43356 .11938 Mdot
.52994 .05956 Mdot
.67095 .08715 Mdot
.02185 .21687 Mdot
.49932 .61775 Mdot
.49784 .61712 Mdot
.49312 .61512 Mdot
.47809 .60874 Mdot
.43031 .5885 Mdot
.28129 .52593 Mdot
.89813 .38123 Mdot
.65756 .46935 Mdot
.61657 .5927 Mdot
.73521 .07332 Mdot
.09155 .22023 Mdot
.49825 .61729 Mdot
.49444 .61567 Mdot
.48228 .61052 Mdot
.44358 .59412 Mdot
.32203 .54291 Mdot
.98578 .41022 Mdot
.67083 .42339 Mdot
.56569 .55305 Mdot
.5563 .61223 Mdot
.6296 .0453 Mdot
.87652 .1526 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .0034 Mdot
.52557 .01084 Mdot
.5813 .03444 Mdot
.75375 .10658 Mdot
.16486 .25408 Mdot
.37059 .12715 Mdot
.40291 .01997 Mdot
.29844 .55347 Mdot
.96623 .41271 Mdot
.68429 .44379 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48863 .61321 Mdot
.4638 .60269 Mdot
.38513 .56942 Mdot
.14874 .47194 Mdot
.72033 .35326 Mdot
.52651 .49825 Mdot
.37227 .52271 Mdot
.04634 .4166 Mdot
.65188 .37425 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47575 .60775 Mdot
.42287 .58535 Mdot
.25878 .51662 Mdot
.85631 .3693 Mdot
.64127 .48513 Mdot
.61139 .59956 Mdot
.73527 .07656 Mdot
.09687 .22348 Mdot
.5008 .00034 Mdot
.50255 .00108 Mdot
.50814 .00345 Mdot
.52592 .01099 Mdot
.58242 .03492 Mdot
.75711 .10796 Mdot
.17028 .25536 Mdot
.37405 .12594 Mdot
.40801 .02099 Mdot
.31155 .55841 Mdot
.99397 .42176 Mdot
.68544 .42735 Mdot
.49969 .6179 Mdot
.499 .61761 Mdot
.49682 .61669 Mdot
.48988 .61374 Mdot
.46777 .60437 Mdot
.39765 .57469 Mdot
.18436 .48622 Mdot
.75236 .35104 Mdot
.55906 .49857 Mdot
.45234 .55208 Mdot
.27519 .50855 Mdot
.49967 .6179 Mdot
.49896 .61759 Mdot
.49669 .61663 Mdot
.48947 .61357 Mdot
.46646 .60381 Mdot
.39351 .57295 Mdot
.17248 .48143 Mdot
.74048 .35104 Mdot
.54678 .49832 Mdot
.42226 .54107 Mdot
.1857 .47183 Mdot
.49817 .61726 Mdot
.49417 .61556 Mdot
.48142 .61016 Mdot
.44088 .59298 Mdot
.31368 .53942 Mdot
.9666 .40353 Mdot
.66926 .43426 Mdot
.58057 .56322 Mdot
.60764 .01673 Mdot
.78413 .10908 Mdot
.19389 .25325 Mdot
.50081 .00034 Mdot
.50257 .00109 Mdot
.5082 .00348 Mdot
.52612 .01107 Mdot
.58304 .03518 Mdot
.75894 .10871 Mdot
.17319 .25602 Mdot
.37598 .12533 Mdot
.411 .02164 Mdot
.31938 .56141 Mdot
.01134 .42766 Mdot
.68631 .41715 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.50721 .00306 Mdot
.52298 .00975 Mdot
.5731 .03098 Mdot
.72907 .09639 Mdot
.1217 .24266 Mdot
.34906 .14052 Mdot
.38246 .02064 Mdot
.25513 .53934 Mdot
.8892 .39188 Mdot
.67637 .48649 Mdot
.49945 .6178 Mdot
.49825 .61729 Mdot
.49442 .61567 Mdot
.48222 .61049 Mdot
.44339 .59404 Mdot
.32144 .54266 Mdot
.98441 .40974 Mdot
.67072 .42417 Mdot
.56676 .55378 Mdot
.56004 .61388 Mdot
.64125 .05019 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50577 .00245 Mdot
.51837 .00779 Mdot
.55847 .02478 Mdot
.68433 .07778 Mdot
.02888 .21294 Mdot
.33035 .18632 Mdot
.42287 .05718 Mdot
.40417 .60648 Mdot
.25024 .5229 Mdot
.85758 .37536 Mdot
.49788 .61714 Mdot
.49325 .61517 Mdot
.47851 .60892 Mdot
.43163 .58906 Mdot
.28532 .52761 Mdot
.90612 .38368 Mdot
.65972 .46575 Mdot
.61466 .59019 Mdot
.72711 .06949 Mdot
.07581 .21551 Mdot
.31505 .14786 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52144 .00909 Mdot
.56821 .0289 Mdot
.71418 .09022 Mdot
.09287 .23404 Mdot
.34002 .15275 Mdot
.38563 .02819 Mdot
.27407 .54909 Mdot
.92651 .40323 Mdot
.68531 .46896 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50093 .00039 Mdot
.50296 .00125 Mdot
.50943 .004 Mdot
.53003 .01273 Mdot
.5954 .0404 Mdot
.79545 .12364 Mdot
.22456 .26521 Mdot
.41799 .11954 Mdot
.49377 .04684 Mdot
.56022 .04107 Mdot
.49979 .61794 Mdot
.49932 .61774 Mdot
.49782 .61711 Mdot
.49305 .61509 Mdot
.47787 .60865 Mdot
.4296 .5882 Mdot
.27914 .52504 Mdot
.89393 .37996 Mdot
.65631 .47118 Mdot
.61724 .59389 Mdot
.73855 .07497 Mdot
.49965 .61789 Mdot
.4989 .61757 Mdot
.49649 .61655 Mdot
.48882 .61329 Mdot
.4644 .60294 Mdot
.38702 .57021 Mdot
.15406 .47405 Mdot
.72444 .35251 Mdot
.53048 .49816 Mdot
.38197 .52625 Mdot
.07221 .42659 Mdot
.49809 .61722 Mdot
.49392 .61546 Mdot
.48063 .60982 Mdot
.43835 .59191 Mdot
.3059 .53617 Mdot
.94929 .39764 Mdot
.66746 .44385 Mdot
.59298 .572 Mdot
.65017 .03534 Mdot
.90063 .1548 Mdot
.29066 .24105 Mdot
.49772 .61707 Mdot
.49274 .61496 Mdot
.47688 .60823 Mdot
.42647 .58688 Mdot
.26964 .52111 Mdot
.8759 .37469 Mdot
.65001 .47842 Mdot
.61726 .5978 Mdot
.74493 .0789 Mdot
.1112 .22637 Mdot
.32392 .13147 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50647 .00274 Mdot
.5206 .00873 Mdot
.56554 .02778 Mdot
.70605 .08684 Mdot
.07624 .22879 Mdot
.3364 .16078 Mdot
.39214 .03445 Mdot
.29818 .55997 Mdot
.97635 .41913 Mdot
.50021 9e-05 Mdot
.50067 .00028 Mdot
.50212 .0009 Mdot
.50675 .00286 Mdot
.52152 .00912 Mdot
.56846 .02901 Mdot
.71495 .09054 Mdot
.09442 .23452 Mdot
.34042 .15204 Mdot
.38518 .02767 Mdot
.27228 .54826 Mdot
.92298 .40215 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50655 .00278 Mdot
.52086 .00885 Mdot
.56639 .02813 Mdot
.70862 .08791 Mdot
.08157 .2305 Mdot
.33745 .15814 Mdot
.38973 .03231 Mdot
.28953 .55611 Mdot
.95793 .41309 Mdot
.6887 .45164 Mdot
.49938 .61777 Mdot
.49801 .61719 Mdot
.49366 .61535 Mdot
.4798 .60947 Mdot
.43573 .5908 Mdot
.29787 .53283 Mdot
.93198 .3919 Mdot
.66505 .45306 Mdot
.60364 .58008 Mdot
.68692 .05147 Mdot
.99044 .18758 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48667 .61238 Mdot
.45757 .60004 Mdot
.36556 .56117 Mdot
.09502 .45084 Mdot
.69027 .36789 Mdot
.50764 .50516 Mdot
.33648 .51225 Mdot
.96096 .38595 Mdot
.64342 .42178 Mdot
.49978 .61794 Mdot
.49931 .61774 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.47778 .60861 Mdot
.42932 .58808 Mdot
.27828 .52469 Mdot
.89226 .37946 Mdot
.65579 .47189 Mdot
.61744 .59433 Mdot
.73969 .07555 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52196 .00931 Mdot
.56986 .0296 Mdot
.71921 .09231 Mdot
.10285 .2371 Mdot
.34273 .14825 Mdot
.38325 .02505 Mdot
.26395 .5443 Mdot
.90683 .39732 Mdot
.68162 .47884 Mdot
.49787 .61713 Mdot
.49321 .61515 Mdot
.47836 .60886 Mdot
.43116 .58886 Mdot
.28387 .52701 Mdot
.90324 .38279 Mdot
.65897 .46707 Mdot
.61544 .59113 Mdot
.73028 .07098 Mdot
.08203 .21739 Mdot
.31611 .14467 Mdot
.50065 .00027 Mdot
.50206 .00088 Mdot
.50658 .00279 Mdot
.52095 .00888 Mdot
.56667 .02825 Mdot
.70949 .08827 Mdot
.08334 .23106 Mdot
.33782 .15728 Mdot
.389 .03163 Mdot
.28685 .5549 Mdot
.95233 .41129 Mdot
.68826 .45482 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49855 .61742 Mdot
.49538 .61608 Mdot
.48529 .6118 Mdot
.45316 .59818 Mdot
.35179 .55538 Mdot
.05887 .437 Mdot
.67964 .38366 Mdot
.51621 .51702 Mdot
.37703 .53202 Mdot
.49985 .61797 Mdot
.49952 .61783 Mdot
.49847 .61738 Mdot
.49512 .61597 Mdot
.48446 .61144 Mdot
.45051 .59706 Mdot
.34353 .55192 Mdot
.03787 .42913 Mdot
.67594 .39435 Mdot
.52735 .5262 Mdot
.41959 .55143 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50833 .00353 Mdot
.52654 .01125 Mdot
.58438 .03575 Mdot
.76294 .11036 Mdot
.17945 .25741 Mdot
.38029 .12413 Mdot
.41804 .02333 Mdot
.33821 .5687 Mdot
.05539 .44324 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50404 .00171 Mdot
.51286 .00545 Mdot
.54096 .01737 Mdot
.62983 .05492 Mdot
.89256 .16237 Mdot
.30448 .25458 Mdot
.49152 .1156 Mdot
.66586 .10774 Mdot
.04633 .23514 Mdot
.35828 .1928 Mdot
.49991 .618 Mdot
.49972 .61791 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49083 .61415 Mdot
.47081 .60566 Mdot
.40723 .57874 Mdot
.21226 .49753 Mdot
.78523 .35412 Mdot
.59111 .49806 Mdot
.52631 .57799 Mdot
.50007 3e-05 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50215 .00091 Mdot
.50686 .00291 Mdot
.52184 .00926 Mdot
.56949 .02945 Mdot
.71809 .09184 Mdot
.10064 .23643 Mdot
.34209 .14923 Mdot
.38367 .0257 Mdot
.26589 .54524 Mdot
.49874 .6175 Mdot
.496 .61634 Mdot
.48725 .61263 Mdot
.45938 .60081 Mdot
.37125 .56357 Mdot
.11039 .45681 Mdot
.6969 .36248 Mdot
.50898 .50189 Mdot
.33453 .51022 Mdot
.95423 .383 Mdot
.64164 .42484 Mdot
.50065 .00028 Mdot
.50208 .00088 Mdot
.50664 .00282 Mdot
.52116 .00897 Mdot
.56731 .02853 Mdot
.71146 .08909 Mdot
.08737 .23232 Mdot
.33871 .15534 Mdot
.38745 .03013 Mdot
.2811 .5523 Mdot
.94056 .40757 Mdot
.68712 .4614 Mdot
.4994 .61778 Mdot
.49809 .61722 Mdot
.49392 .61546 Mdot
.48063 .60982 Mdot
.43837 .59191 Mdot
.30594 .53619 Mdot
.94939 .39767 Mdot
.66748 .4438 Mdot
.59292 .57195 Mdot
.64995 .03525 Mdot
.90008 .15459 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52351 .00997 Mdot
.57478 .03169 Mdot
.73413 .09849 Mdot
.13103 .2453 Mdot
.35285 .13709 Mdot
.38407 .01929 Mdot
.25636 .53911 Mdot
.89012 .39168 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50344 .00146 Mdot
.51096 .00465 Mdot
.53489 .01479 Mdot
.61075 .04688 Mdot
.83965 .14147 Mdot
.2704 .26622 Mdot
.46437 .11988 Mdot
.60534 .08713 Mdot
.89304 .17781 Mdot
.32937 .26967 Mdot
.49967 .61789 Mdot
.49895 .61759 Mdot
.49667 .61662 Mdot
.48939 .61354 Mdot
.46621 .60371 Mdot
.39273 .57262 Mdot
.17025 .48053 Mdot
.73839 .35113 Mdot
.54462 .49828 Mdot
.41692 .53911 Mdot
.17017 .46554 Mdot
.50075 .00032 Mdot
.50237 .00101 Mdot
.50756 .00321 Mdot
.52409 .01022 Mdot
.57663 .03247 Mdot
.73971 .10079 Mdot
.14103 .24803 Mdot
.35742 .13374 Mdot
.38743 .01854 Mdot
.2623 .5407 Mdot
.89915 .3936 Mdot
.67736 .48096 Mdot
.5 0 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50008 4e-05 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.50868 .00368 Mdot
.52766 .01173 Mdot
.58791 .03724 Mdot
.77344 .11466 Mdot
.19511 .26061 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00099 Mdot
.50741 .00314 Mdot
.5236 .01 Mdot
.57505 .0318 Mdot
.73494 .09882 Mdot
.1325 .24571 Mdot
.35349 .13658 Mdot
.38445 .01914 Mdot
.25692 .53922 Mdot
.89089 .39181 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.5053 .00225 Mdot
.51687 .00715 Mdot
.55371 .02277 Mdot
.66959 .07162 Mdot
.99438 .20073 Mdot
.3276 .20594 Mdot
.4499 .07559 Mdot
.49828 .0299 Mdot
.54409 .02831 Mdot
.6552 .06867 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49067 .61408 Mdot
.4703 .60544 Mdot
.40562 .57806 Mdot
.20753 .49561 Mdot
.77916 .35328 Mdot
.58552 .49836 Mdot
.51408 .57388 Mdot
.46372 .58691 Mdot
.35942 .55357 Mdot
.50018 8e-05 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51875 .00795 Mdot
.55969 .0253 Mdot
.68806 .07934 Mdot
.03732 .21585 Mdot
.33111 .18157 Mdot
.4165 .05278 Mdot
.38232 .59691 Mdot
.18728 .49749 Mdot
.49873 .61749 Mdot
.49594 .61631 Mdot
.48708 .61255 Mdot
.45885 .60059 Mdot
.36958 .56286 Mdot
.10585 .45504 Mdot
.69479 .36399 Mdot
.50825 .50275 Mdot
.33409 .51039 Mdot
.95374 .38297 Mdot
.64181 .42525 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50353 .0015 Mdot
.51125 .00477 Mdot
.53583 .01519 Mdot
.6137 .04813 Mdot
.84797 .14479 Mdot
.27716 .26525 Mdot
.47108 .11985 Mdot
.62185 .09318 Mdot
.93806 .19543 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50613 .0026 Mdot
.51953 .00828 Mdot
.56215 .02634 Mdot
.69566 .08251 Mdot
.05411 .22154 Mdot
.33295 .17234 Mdot
.40476 .04438 Mdot
.3421 .5793 Mdot
.07956 .45578 Mdot
.70259 .38505 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50332 .00141 Mdot
.51059 .00449 Mdot
.53374 .01431 Mdot
.60712 .04535 Mdot
.82932 .13733 Mdot
.26121 .26692 Mdot
.45496 .11975 Mdot
.58205 .07855 Mdot
.82685 .15129 Mdot
.28308 .28197 Mdot
.49823 .61728 Mdot
.49437 .61564 Mdot
.48205 .61042 Mdot
.44287 .59382 Mdot
.31983 .54199 Mdot
.98066 .40842 Mdot
.67043 .4263 Mdot
.56972 .55579 Mdot
.57026 .00034 Mdot
.67282 .06338 Mdot
.98658 .19392 Mdot
.50029 .00012 Mdot
.50091 .00039 Mdot
.5029 .00123 Mdot
.50924 .00392 Mdot
.52945 .01248 Mdot
.59356 .03963 Mdot
.79008 .12145 Mdot
.2178 .26434 Mdot
.41165 .11981 Mdot
.47969 .04205 Mdot
.51736 .02328 Mdot
.58101 .03934 Mdot
.49944 .6178 Mdot
.49822 .61728 Mdot
.49431 .61562 Mdot
.48188 .61035 Mdot
.44233 .59359 Mdot
.31816 .54129 Mdot
.97682 .40707 Mdot
.67013 .42849 Mdot
.57273 .55784 Mdot
.58066 .0049 Mdot
.70448 .07652 Mdot
.49857 .61743 Mdot
.49544 .6161 Mdot
.48546 .61187 Mdot
.45369 .5984 Mdot
.35344 .55608 Mdot
.06314 .43861 Mdot
.68059 .38161 Mdot
.51443 .51534 Mdot
.36988 .5287 Mdot
.05119 .42107 Mdot
.65703 .37443 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51252 .00531 Mdot
.53987 .0169 Mdot
.62639 .05347 Mdot
.88319 .15871 Mdot
.29989 .25754 Mdot
.4895 .11718 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52305 .00977 Mdot
.57331 .03106 Mdot
.72968 .09664 Mdot
.12284 .24299 Mdot
.3495 .14008 Mdot
.38258 .02044 Mdot
.25507 .53923 Mdot
.88896 .39176 Mdot
.67622 .48655 Mdot
.50068 .00029 Mdot
.50216 .00091 Mdot
.50687 .00291 Mdot
.52188 .00928 Mdot
.56961 .0295 Mdot
.71847 .092 Mdot
.10139 .23666 Mdot
.3423 .14889 Mdot
.38352 .02548 Mdot
.26521 .54491 Mdot
.90926 .39804 Mdot
.68216 .47768 Mdot
.50031 .00013 Mdot
.50098 .00042 Mdot
.50313 .00133 Mdot
.50997 .00423 Mdot
.53176 .01347 Mdot
.60089 .04272 Mdot
.81141 .13011 Mdot
.24311 .26681 Mdot
.43631 .1194 Mdot
.53649 .06192 Mdot
.69093 .09545 Mdot
.06785 .23295 Mdot
.49867 .61747 Mdot
.49575 .61623 Mdot
.48647 .6123 Mdot
.45693 .59977 Mdot
.36356 .56033 Mdot
.08968 .44877 Mdot
.68829 .36996 Mdot
.50792 .50655 Mdot
.33941 .51389 Mdot
.96885 .38902 Mdot
.64472 .41771 Mdot
.49756 .617 Mdot
.49222 .61474 Mdot
.47523 .60753 Mdot
.42122 .58465 Mdot
.2538 .51457 Mdot
.84772 .36706 Mdot
.63677 .48766 Mdot
.60664 .59941 Mdot
.72475 .073 Mdot
.07861 .21869 Mdot
.31929 .14875 Mdot
.50004 2e-05 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50413 .00175 Mdot
.51314 .00557 Mdot
.54186 .01774 Mdot
.63263 .0561 Mdot
.90011 .16531 Mdot
.30778 .25195 Mdot
.49228 .11403 Mdot
.66519 .10687 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47593 .60783 Mdot
.42344 .5856 Mdot
.26049 .51733 Mdot
.85933 .3701 Mdot
.64275 .48418 Mdot
.61273 .59948 Mdot
.73801 .07743 Mdot
.10134 .22455 Mdot
.32273 .13682 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50069 .00029 Mdot
.50219 .00093 Mdot
.50697 .00295 Mdot
.52219 .00941 Mdot
.57059 .02991 Mdot
.72145 .09323 Mdot
.10721 .23841 Mdot
.34404 .14637 Mdot
.38262 .02384 Mdot
.26067 .54266 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50522 .00221 Mdot
.51663 .00705 Mdot
.55294 .02244 Mdot
.6672 .07062 Mdot
.98862 .19864 Mdot
.32709 .20919 Mdot
.45429 .07862 Mdot
.51388 .03683 Mdot
.59425 .04967 Mdot
.50012 5e-05 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50387 .00164 Mdot
.51232 .00522 Mdot
.53922 .01663 Mdot
.62437 .05262 Mdot
.87765 .15654 Mdot
.29691 .25911 Mdot
.48773 .11793 Mdot
.66016 .10657 Mdot
.03428 .23122 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50799 .00339 Mdot
.52546 .01079 Mdot
.58095 .0343 Mdot
.7527 .10615 Mdot
.16315 .25367 Mdot
.36954 .12756 Mdot
.40142 .01971 Mdot
.29471 .55208 Mdot
.50066 .00028 Mdot
.50211 .0009 Mdot
.50673 .00285 Mdot
.52145 .00909 Mdot
.56823 .02891 Mdot
.71426 .09025 Mdot
.09302 .23409 Mdot
.34006 .15268 Mdot
.38559 .02814 Mdot
.27389 .549 Mdot
.92616 .40312 Mdot
.68525 .46915 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51501 .00637 Mdot
.54781 .02027 Mdot
.65123 .06392 Mdot
.94887 .18395 Mdot
.32189 .23054 Mdot
.48013 .09779 Mdot
.60863 .07942 Mdot
.88773 .17249 Mdot
.32161 .26815 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48652 .61232 Mdot
.45708 .59984 Mdot
.36404 .56053 Mdot
.09099 .44927 Mdot
.68876 .36945 Mdot
.50782 .5062 Mdot
.33859 .51345 Mdot
.96666 .38817 Mdot
.64438 .41885 Mdot
.50072 .00031 Mdot
.50229 .00097 Mdot
.50731 .0031 Mdot
.52329 .00987 Mdot
.57407 .03139 Mdot
.73199 .0976 Mdot
.12712 .2442 Mdot
.35121 .13849 Mdot
.38322 .01979 Mdot
.25536 .53901 Mdot
.88891 .39155 Mdot
.67589 .48638 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.5077 .00327 Mdot
.52454 .0104 Mdot
.57803 .03306 Mdot
.74394 .10254 Mdot
.1484 .24997 Mdot
.36115 .13148 Mdot
.39105 .01848 Mdot
.26999 .54322 Mdot
.91208 .39683 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.48482 .6116 Mdot
.45166 .59754 Mdot
.34709 .55341 Mdot
.04686 .43248 Mdot
.67735 .38966 Mdot
.52212 .5221 Mdot
.39997 .54254 Mdot
.13746 .45579 Mdot
.69345 .34362 Mdot
.49938 .61777 Mdot
.49801 .61719 Mdot
.49366 .61534 Mdot
.4798 .60947 Mdot
.43571 .59079 Mdot
.29779 .53279 Mdot
.93182 .39185 Mdot
.66502 .45314 Mdot
.60372 .58015 Mdot
.68723 .05161 Mdot
.99115 .18783 Mdot
.49862 .61745 Mdot
.49561 .61617 Mdot
.48603 .61211 Mdot
.45551 .59917 Mdot
.35913 .55847 Mdot
.07798 .44427 Mdot
.68448 .37484 Mdot
.50977 .51006 Mdot
.3497 .51911 Mdot
.99624 .39958 Mdot
.64841 .40307 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48968 .61366 Mdot
.46712 .60409 Mdot
.39561 .57383 Mdot
.17849 .48385 Mdot
.74633 .35095 Mdot
.55285 .49845 Mdot
.43719 .54655 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50714 .00303 Mdot
.52274 .00964 Mdot
.57234 .03065 Mdot
.72674 .09543 Mdot
.11734 .2414 Mdot
.34744 .14221 Mdot
.38218 .02147 Mdot
.25589 .53998 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52601 .01103 Mdot
.58269 .03503 Mdot
.75791 .10829 Mdot
.17157 .25565 Mdot
.3749 .12567 Mdot
.40931 .02127 Mdot
.31493 .5597 Mdot
.00141 .42427 Mdot
.68578 .42296 Mdot
.49743 .61694 Mdot
.49181 .61456 Mdot
.47391 .60697 Mdot
.41705 .58289 Mdot
.24131 .50942 Mdot
.8272 .3621 Mdot
.62428 .49262 Mdot
.58941 .59648 Mdot
.68172 .05705 Mdot
.99112 .19122 Mdot
.31383 .19945 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50793 .00336 Mdot
.52526 .01071 Mdot
.58032 .03403 Mdot
.75082 .10537 Mdot
.16005 .25292 Mdot
.36767 .12832 Mdot
.39888 .01929 Mdot
.28842 .54976 Mdot
.94615 .4065 Mdot
.68312 .45548 Mdot
.50018 8e-05 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00249 Mdot
.51867 .00792 Mdot
.55942 .02518 Mdot
.68724 .079 Mdot
.03547 .21522 Mdot
.33094 .18261 Mdot
.41788 .05373 Mdot
.38703 .59897 Mdot
.20059 .50281 Mdot
.49778 .61709 Mdot
.49293 .61503 Mdot
.47746 .60848 Mdot
.42831 .58766 Mdot
.27522 .52342 Mdot
.88639 .37772 Mdot
.65387 .47433 Mdot
.61783 .59576 Mdot
.74284 .07726 Mdot
.10633 .22465 Mdot
.32193 .13325 Mdot
.49907 .61764 Mdot
.49705 .61678 Mdot
.4906 .61405 Mdot
.47006 .60534 Mdot
.40487 .57774 Mdot
.20533 .49471 Mdot
.7764 .35294 Mdot
.58292 .49846 Mdot
.50828 .5719 Mdot
.44605 .57958 Mdot
.30445 .53052 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.50381 .00161 Mdot
.51212 .00514 Mdot
.53861 .01637 Mdot
.62244 .05181 Mdot
.87234 .15445 Mdot
.29385 .26051 Mdot
.48563 .11853 Mdot
.65588 .10522 Mdot
.02432 .22771 Mdot
.35642 .20525 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51265 .00536 Mdot
.54028 .01708 Mdot
.62769 .05402 Mdot
.88672 .1601 Mdot
.30169 .25646 Mdot
.49041 .11663 Mdot
.66474 .10774 Mdot
.04436 .23462 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50283 .0012 Mdot
.50903 .00383 Mdot
.52877 .0122 Mdot
.59142 .03872 Mdot
.78379 .11889 Mdot
.20954 .26312 Mdot
.40422 .12032 Mdot
.46375 .03679 Mdot
.46938 .00348 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48801 .61295 Mdot
.46181 .60184 Mdot
.37887 .56677 Mdot
.13127 .46501 Mdot
.70834 .35665 Mdot
.51602 .49917 Mdot
.34769 .514 Mdot
.98421 .39339 Mdot
.64437 .408 Mdot
.49835 .61734 Mdot
.49475 .61581 Mdot
.48327 .61094 Mdot
.44674 .59546 Mdot
.3318 .547 Mdot
.00898 .41852 Mdot
.67269 .4102 Mdot
.54753 .54068 Mdot
.4926 .58409 Mdot
.42657 .57723 Mdot
.25425 .51154 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50798 .00338 Mdot
.52541 .01078 Mdot
.58081 .03424 Mdot
.75228 .10597 Mdot
.16246 .2535 Mdot
.36911 .12772 Mdot
.40084 .01961 Mdot
.29326 .55155 Mdot
.95571 .40942 Mdot
.68374 .44995 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50805 .00341 Mdot
.52563 .01087 Mdot
.5815 .03453 Mdot
.75435 .10683 Mdot
.16585 .25432 Mdot
.37121 .12692 Mdot
.40379 .02014 Mdot
.30069 .55431 Mdot
.97086 .41419 Mdot
.6845 .44105 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51217 .00516 Mdot
.53875 .01643 Mdot
.62288 .052 Mdot
.87357 .15493 Mdot
.29457 .2602 Mdot
.48615 .1184 Mdot
.65697 .10557 Mdot
.0269 .22862 Mdot
.35667 .20381 Mdot
.49887 .61755 Mdot
.49639 .6165 Mdot
.48849 .61315 Mdot
.46334 .60249 Mdot
.38368 .5688 Mdot
.14467 .47032 Mdot
.71733 .35392 Mdot
.5237 .49837 Mdot
.3655 .52026 Mdot
.02872 .40989 Mdot
.64909 .38341 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48374 .61114 Mdot
.44822 .59609 Mdot
.33641 .54893 Mdot
.02018 .4226 Mdot
.67377 .40394 Mdot
.53922 .53488 Mdot
.4629 .57087 Mdot
.33144 .53679 Mdot
.99182 .40814 Mdot
.50038 .00016 Mdot
.50123 .00052 Mdot
.50391 .00166 Mdot
.51245 .00528 Mdot
.53964 .01681 Mdot
.62567 .05317 Mdot
.88123 .15794 Mdot
.29886 .25811 Mdot
.48892 .11746 Mdot
.66238 .1072 Mdot
.03929 .23294 Mdot
.35786 .19689 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50488 .00207 Mdot
.51555 .00659 Mdot
.54949 .02098 Mdot
.65649 .06613 Mdot
.96217 .18893 Mdot
.32407 .22366 Mdot
.47262 .09181 Mdot
.58031 .06655 Mdot
.80341 .13788 Mdot
.25193 .2772 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50746 .00316 Mdot
.52375 .01007 Mdot
.57553 .03201 Mdot
.73642 .09943 Mdot
.13516 .24644 Mdot
.35467 .13566 Mdot
.38524 .01889 Mdot
.25821 .53952 Mdot
.89276 .39217 Mdot
.50079 .00034 Mdot
.50252 .00107 Mdot
.50803 .00341 Mdot
.52558 .01085 Mdot
.58134 .03446 Mdot
.75388 .10663 Mdot
.16508 .25413 Mdot
.37073 .1271 Mdot
.4031 .02001 Mdot
.29894 .55366 Mdot
.96724 .41303 Mdot
.68434 .44319 Mdot
.49922 .6177 Mdot
.49753 .61699 Mdot
.49212 .61469 Mdot
.4749 .60739 Mdot
.42018 .58422 Mdot
.25068 .51328 Mdot
.84246 .36574 Mdot
.6338 .48908 Mdot
.60303 .59901 Mdot
.71622 .06996 Mdot
.06279 .21419 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50285 .00121 Mdot
.50908 .00385 Mdot
.52891 .01226 Mdot
.59187 .03891 Mdot
.78511 .11943 Mdot
.2113 .2634 Mdot
.40578 .12019 Mdot
.46704 .03786 Mdot
.47922 .00752 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.4818 .61032 Mdot
.44209 .59349 Mdot
.3174 .54097 Mdot
.97508 .40646 Mdot
.66998 .42948 Mdot
.57408 .55876 Mdot
.58533 .00695 Mdot
.71854 .08232 Mdot
.08582 .227 Mdot
.49967 .6179 Mdot
.49896 .61759 Mdot
.49668 .61663 Mdot
.48942 .61355 Mdot
.4663 .60374 Mdot
.39299 .57273 Mdot
.171 .48084 Mdot
.73909 .3511 Mdot
.54535 .49829 Mdot
.41871 .53977 Mdot
.17538 .46765 Mdot
.49929 .61773 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47698 .60827 Mdot
.42679 .58701 Mdot
.2706 .52151 Mdot
.87768 .37519 Mdot
.6507 .47776 Mdot
.61748 .5975 Mdot
.74491 .07875 Mdot
.11094 .22622 Mdot
.50007 3e-05 Mdot
.50022 .0001 Mdot
.50071 .0003 Mdot
.50228 .00097 Mdot
.50725 .00308 Mdot
.5231 .0098 Mdot
.57348 .03114 Mdot
.7302 .09686 Mdot
.12381 .24326 Mdot
.34988 .13972 Mdot
.3827 .02028 Mdot
.25507 .53915 Mdot
.49835 .61733 Mdot
.49473 .6158 Mdot
.48321 .61091 Mdot
.44654 .59538 Mdot
.3312 .54675 Mdot
.00752 .41799 Mdot
.67257 .41102 Mdot
.54864 .54144 Mdot
.49655 .58584 Mdot
.43927 .58264 Mdot
.2931 .5277 Mdot
.50054 .00023 Mdot
.50172 .00073 Mdot
.50549 .00233 Mdot
.51749 .00741 Mdot
.55566 .02359 Mdot
.67563 .07415 Mdot
.00875 .20588 Mdot
.32875 .19777 Mdot
.43864 .06792 Mdot
.45877 .01244 Mdot
.41774 .59268 Mdot
.25875 .51977 Mdot
.49888 .61756 Mdot
.49644 .61652 Mdot
.48865 .61322 Mdot
.46384 .6027 Mdot
.38525 .56946 Mdot
.14907 .47207 Mdot
.72057 .35321 Mdot
.52674 .49824 Mdot
.37283 .52291 Mdot
.04784 .41717 Mdot
.65216 .37349 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48501 .61168 Mdot
.45227 .5978 Mdot
.34899 .55421 Mdot
.0517 .43429 Mdot
.67821 .38721 Mdot
.51958 .52 Mdot
.39026 .53811 Mdot
.10905 .44424 Mdot
.67677 .35087 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49775 .61708 Mdot
.49284 .615 Mdot
.47719 .60836 Mdot
.42743 .58728 Mdot
.27256 .52232 Mdot
.88135 .37625 Mdot
.65208 .47634 Mdot
.61777 .59683 Mdot
.74443 .07828 Mdot
.4987 .61748 Mdot
.49587 .61628 Mdot
.48685 .61246 Mdot
.45812 .60028 Mdot
.3673 .5619 Mdot
.0997 .45265 Mdot
.69214 .36615 Mdot
.50771 .50405 Mdot
.33485 .5112 Mdot
.95639 .38413 Mdot
.64253 .42406 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50392 .00166 Mdot
.51248 .00529 Mdot
.53974 .01685 Mdot
.626 .05331 Mdot
.88212 .15829 Mdot
.29933 .25785 Mdot
.48919 .11734 Mdot
.66285 .10732 Mdot
.04033 .2333 Mdot
.35796 .19631 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52366 .01003 Mdot
.57527 .03189 Mdot
.73561 .0991 Mdot
.13371 .24604 Mdot
.35402 .13616 Mdot
.3848 .01902 Mdot
.25747 .53934 Mdot
.89167 .39196 Mdot
.67611 .48481 Mdot
.4988 .61752 Mdot
.49618 .61641 Mdot
.48782 .61287 Mdot
.4612 .60158 Mdot
.37695 .56597 Mdot
.12597 .46292 Mdot
.70516 .35796 Mdot
.51366 .49968 Mdot
.34263 .51233 Mdot
.97218 .38908 Mdot
.64324 .41474 Mdot
.49883 .61754 Mdot
.49626 .61645 Mdot
.4881 .61299 Mdot
.4621 .60196 Mdot
.37978 .56716 Mdot
.1338 .46601 Mdot
.70994 .35607 Mdot
.51729 .49897 Mdot
.35051 .51496 Mdot
.99106 .39588 Mdot
.64501 .40416 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51351 .00573 Mdot
.54302 .01824 Mdot
.63628 .05764 Mdot
.90988 .16909 Mdot
.31155 .24825 Mdot
.49212 .1116 Mdot
.66088 .1043 Mdot
.0319 .22931 Mdot
.35539 .19993 Mdot
.49851 .6174 Mdot
.49524 .61602 Mdot
.48483 .6116 Mdot
.45171 .59756 Mdot
.34726 .55348 Mdot
.04727 .43263 Mdot
.67742 .38945 Mdot
.5219 .52192 Mdot
.39912 .54215 Mdot
.13496 .45477 Mdot
.69176 .34412 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52599 .01102 Mdot
.58263 .03501 Mdot
.75774 .10822 Mdot
.17129 .25559 Mdot
.37471 .12572 Mdot
.40903 .02121 Mdot
.31419 .55942 Mdot
.99978 .42372 Mdot
.6857 .42392 Mdot
.4978 .6171 Mdot
.493 .61507 Mdot
.4777 .60858 Mdot
.42905 .58797 Mdot
.27748 .52436 Mdot
.89072 .379 Mdot
.6553 .47254 Mdot
.61759 .59473 Mdot
.74064 .07605 Mdot
.10202 .22334 Mdot
.32063 .13511 Mdot
.49748 .61696 Mdot
.49196 .61463 Mdot
.4744 .60718 Mdot
.4186 .58355 Mdot
.24596 .51133 Mdot
.83466 .36384 Mdot
.62911 .491 Mdot
.59666 .59798 Mdot
.70046 .06415 Mdot
.03152 .20461 Mdot
.31561 .17558 Mdot
.4996 .61787 Mdot
.49873 .6175 Mdot
.49595 .61632 Mdot
.48711 .61257 Mdot
.45896 .60063 Mdot
.36992 .56301 Mdot
.10677 .4554 Mdot
.69521 .36368 Mdot
.50838 .50256 Mdot
.33411 .51033 Mdot
.95367 .38291 Mdot
.4992 .61769 Mdot
.49745 .61695 Mdot
.49187 .61459 Mdot
.47411 .60705 Mdot
.41767 .58316 Mdot
.24319 .5102 Mdot
.83019 .36279 Mdot
.62625 .492 Mdot
.59246 .59715 Mdot
.68967 .06008 Mdot
.00867 .19715 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.47878 .60904 Mdot
.43248 .58942 Mdot
.28791 .52869 Mdot
.91136 .38531 Mdot
.661 .4633 Mdot
.613 .58837 Mdot
.72062 .06651 Mdot
.06291 .21155 Mdot
.31328 .15473 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50894 .00379 Mdot
.52849 .01208 Mdot
.59054 .03835 Mdot
.78119 .11783 Mdot
.20601 .26255 Mdot
.40115 .12061 Mdot
.45737 .03475 Mdot
.45041 .61373 Mdot
.37027 .5685 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51977 .00838 Mdot
.56292 .02667 Mdot
.69802 .08349 Mdot
.05922 .22324 Mdot
.33363 .16959 Mdot
.40151 .04195 Mdot
.33091 .5744 Mdot
.05177 .44551 Mdot
.69633 .39837 Mdot
.49836 .61734 Mdot
.49479 .61582 Mdot
.4834 .611 Mdot
.44716 .59563 Mdot
.3331 .54754 Mdot
.01212 .41966 Mdot
.67298 .40843 Mdot
.54515 .53903 Mdot
.48414 .58033 Mdot
.39938 .56565 Mdot
.17355 .47846 Mdot
.50027 .00011 Mdot
.50086 .00037 Mdot
.50275 .00117 Mdot
.50877 .00372 Mdot
.52792 .01184 Mdot
.58875 .03759 Mdot
.77592 .11567 Mdot
.19865 .26127 Mdot
.39498 .12133 Mdot
.44495 .03089 Mdot
.41399 .5989 Mdot
.26019 .52298 Mdot
.49897 .6176 Mdot
.4967 .61664 Mdot
.4895 .61358 Mdot
.46656 .60385 Mdot
.39382 .57308 Mdot
.17336 .48178 Mdot
.74132 .35102 Mdot
.54766 .49834 Mdot
.42441 .54187 Mdot
.19201 .4744 Mdot
.73654 .33654 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49083 .61415 Mdot
.47079 .60565 Mdot
.40719 .57872 Mdot
.21212 .49747 Mdot
.78505 .35409 Mdot
.59094 .49807 Mdot
.52595 .57787 Mdot
.49972 .60182 Mdot
.47307 .60156 Mdot
.49739 .61693 Mdot
.49169 .61451 Mdot
.47353 .60681 Mdot
.41585 .58238 Mdot
.23773 .50795 Mdot
.8216 .36085 Mdot
.62044 .49371 Mdot
.58319 .59501 Mdot
.66511 .05063 Mdot
.95262 .17769 Mdot
.31015 .22097 Mdot
.50055 .00024 Mdot
.50177 .00075 Mdot
.50563 .00239 Mdot
.51795 .00761 Mdot
.55712 .02421 Mdot
.68015 .07604 Mdot
.01929 .2096 Mdot
.32956 .19176 Mdot
.43032 .06227 Mdot
.42987 .61775 Mdot
.32759 .55482 Mdot
.01438 .42446 Mdot
.49746 .61696 Mdot
.4919 .6146 Mdot
.47419 .60709 Mdot
.41794 .58327 Mdot
.24398 .51052 Mdot
.83146 .36308 Mdot
.62708 .49172 Mdot
.59369 .5974 Mdot
.69287 .06129 Mdot
.01556 .19943 Mdot
.31495 .18503 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47916 .6092 Mdot
.43368 .58993 Mdot
.29158 .53021 Mdot
.91885 .38767 Mdot
.66264 .45969 Mdot
.61009 .58556 Mdot
.70982 .06163 Mdot
.04071 .2045 Mdot
.3112 .16718 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00032 Mdot
.50244 .00104 Mdot
.50778 .0033 Mdot
.52477 .0105 Mdot
.57878 .03338 Mdot
.74618 .10346 Mdot
.15224 .25096 Mdot
.36321 .13039 Mdot
.39334 .01862 Mdot
.27519 .54501 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50443 .00188 Mdot
.51411 .00598 Mdot
.54494 .01905 Mdot
.64229 .06016 Mdot
.92575 .17519 Mdot
.31659 .24155 Mdot
.48929 .10674 Mdot
.64595 .09682 Mdot
.9921 .21394 Mdot
.49885 .61755 Mdot
.49635 .61649 Mdot
.48838 .6131 Mdot
.46298 .60234 Mdot
.38254 .56832 Mdot
.14149 .46906 Mdot
.71507 .35449 Mdot
.52166 .4985 Mdot
.36065 .51852 Mdot
.01631 .40522 Mdot
.64755 .39013 Mdot
.49824 .61729 Mdot
.4944 .61566 Mdot
.48216 .61047 Mdot
.4432 .59396 Mdot
.32085 .54242 Mdot
.98303 .40925 Mdot
.67062 .42495 Mdot
.56785 .55452 Mdot
.5638 .61553 Mdot
.65292 .05508 Mdot
.93772 .17602 Mdot
.49881 .61753 Mdot
.49622 .61643 Mdot
.48796 .61293 Mdot
.46165 .60177 Mdot
.37836 .56656 Mdot
.12986 .46445 Mdot
.70748 .35699 Mdot
.51536 .4993 Mdot
.34624 .51351 Mdot
.98071 .39213 Mdot
.64405 .40997 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48966 .61365 Mdot
.46707 .60407 Mdot
.39545 .57377 Mdot
.17803 .48366 Mdot
.74588 .35095 Mdot
.55238 .49844 Mdot
.43603 .54613 Mdot
.22629 .48841 Mdot
.78047 .3425 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50153 .00065 Mdot
.50489 .00207 Mdot
.51556 .0066 Mdot
.54955 .02101 Mdot
.65667 .0662 Mdot
.96264 .1891 Mdot
.32414 .22342 Mdot
.47233 .09159 Mdot
.57923 .06607 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50753 .00319 Mdot
.52399 .01017 Mdot
.57629 .03232 Mdot
.7387 .10037 Mdot
.13923 .24755 Mdot
.35656 .13431 Mdot
.38669 .01862 Mdot
.26086 .54026 Mdot
.89685 .39306 Mdot
.67696 .48214 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48863 .61321 Mdot
.46379 .60268 Mdot
.38509 .5694 Mdot
.14863 .47189 Mdot
.72024 .35328 Mdot
.52642 .49825 Mdot
.37206 .52263 Mdot
.04581 .4164 Mdot
.65178 .37452 Mdot
.49855 .61742 Mdot
.49539 .61608 Mdot
.4853 .6118 Mdot
.45319 .59819 Mdot
.35188 .55542 Mdot
.0591 .43709 Mdot
.67969 .38355 Mdot
.5161 .51693 Mdot
.37662 .53183 Mdot
.07005 .42856 Mdot
.66177 .3657 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50047 .0002 Mdot
.5015 .00063 Mdot
.50477 .00202 Mdot
.51519 .00644 Mdot
.54836 .0205 Mdot
.65296 .06464 Mdot
.95327 .1856 Mdot
.32267 .22831 Mdot
.47781 .09588 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.51388 .00589 Mdot
.54421 .01874 Mdot
.64001 .0592 Mdot
.91976 .17289 Mdot
.31484 .24417 Mdot
.49072 .1087 Mdot
.65269 .1001 Mdot
.50072 .00031 Mdot
.50231 .00098 Mdot
.50735 .00312 Mdot
.52342 .00993 Mdot
.5745 .03157 Mdot
.7333 .09814 Mdot
.12951 .24487 Mdot
.3522 .13763 Mdot
.38371 .01947 Mdot
.25589 .53904 Mdot
.8895 .39159 Mdot
.67586 .486 Mdot
.49802 .61719 Mdot
.49368 .61535 Mdot
.47986 .60949 Mdot
.4359 .59087 Mdot
.29837 .53304 Mdot
.93305 .39225 Mdot
.66522 .45251 Mdot
.60304 .57961 Mdot
.68486 .05057 Mdot
.9857 .18593 Mdot
.30796 .19917 Mdot
.50056 .00024 Mdot
.50179 .00076 Mdot
.50571 .00242 Mdot
.51819 .00771 Mdot
.55791 .02454 Mdot
.68258 .07705 Mdot
.02488 .21155 Mdot
.33001 .18859 Mdot
.42596 .0593 Mdot
.4148 .61114 Mdot
.28186 .53587 Mdot
.91495 .39127 Mdot
.50026 .00011 Mdot
.50081 .00035 Mdot
.50259 .0011 Mdot
.50826 .0035 Mdot
.52632 .01116 Mdot
.58367 .03545 Mdot
.76082 .10949 Mdot
.17616 .25669 Mdot
.378 .12474 Mdot
.41424 .0224 Mdot
.32796 .56471 Mdot
.03103 .43452 Mdot
.50041 .00018 Mdot
.50132 .00056 Mdot
.50419 .00178 Mdot
.51336 .00566 Mdot
.54254 .01803 Mdot
.63476 .057 Mdot
.90582 .16753 Mdot
.31005 .24983 Mdot
.49234 .11266 Mdot
.66314 .10556 Mdot
.03799 .23167 Mdot
.3564 .19679 Mdot
.49978 .61794 Mdot
.4993 .61774 Mdot
.49776 .61708 Mdot
.49285 .615 Mdot
.47723 .60838 Mdot
.42756 .58734 Mdot
.27293 .52247 Mdot
.88205 .37646 Mdot
.65234 .47606 Mdot
.6178 .59669 Mdot
.74427 .07816 Mdot
.50006 3e-05 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52056 .00872 Mdot
.56543 .02773 Mdot
.70571 .0867 Mdot
.07554 .22857 Mdot
.33626 .16114 Mdot
.39247 .03474 Mdot
.29938 .5605 Mdot
.49909 .61765 Mdot
.4971 .6168 Mdot
.49076 .61412 Mdot
.47058 .60556 Mdot
.4065 .57843 Mdot
.21011 .49666 Mdot
.78245 .35372 Mdot
.58857 .49821 Mdot
.5208 .57615 Mdot
.48414 .59538 Mdot
.42372 .58069 Mdot
.50041 .00017 Mdot
.5013 .00055 Mdot
.50413 .00175 Mdot
.51316 .00558 Mdot
.54192 .01777 Mdot
.63284 .05619 Mdot
.90066 .16553 Mdot
.30801 .25175 Mdot
.4923 .1139 Mdot
.66505 .10677 Mdot
.04333 .23379 Mdot
.35741 .19411 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50648 .00275 Mdot
.52064 .00875 Mdot
.56566 .02783 Mdot
.70641 .08699 Mdot
.07699 .22903 Mdot
.33654 .16041 Mdot
.39178 .03414 Mdot
.29692 .5594 Mdot
.97362 .41822 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50037 .00016 Mdot
.50117 .0005 Mdot
.50373 .00158 Mdot
.51189 .00504 Mdot
.53787 .01605 Mdot
.62011 .05083 Mdot
.8659 .15191 Mdot
.28987 .26203 Mdot
.48256 .11909 Mdot
.64914 .10295 Mdot
.49852 .6174 Mdot
.49527 .61603 Mdot
.48494 .61165 Mdot
.45205 .59771 Mdot
.34832 .55392 Mdot
.04998 .43365 Mdot
.6779 .38807 Mdot
.52046 .52073 Mdot
.39364 .53965 Mdot
.11889 .44823 Mdot
.68193 .34798 Mdot
.49843 .61737 Mdot
.495 .61591 Mdot
.48406 .61127 Mdot
.44924 .59652 Mdot
.33957 .55025 Mdot
.02799 .42547 Mdot
.67464 .39965 Mdot
.53375 .53096 Mdot
.44312 .56202 Mdot
.26898 .51041 Mdot
.8578 .36391 Mdot
.49757 .61701 Mdot
.49227 .61476 Mdot
.47538 .6076 Mdot
.42172 .58487 Mdot
.2553 .51518 Mdot
.85028 .36772 Mdot
.63815 .48693 Mdot
.6082 .59952 Mdot
.72832 .07424 Mdot
.08497 .22042 Mdot
.32013 .14534 Mdot
.49863 .61745 Mdot
.49565 .61619 Mdot
.48613 .61215 Mdot
.45583 .59931 Mdot
.36012 .55888 Mdot
.08057 .44527 Mdot
.68527 .37372 Mdot
.50921 .50923 Mdot
.34698 .51777 Mdot
.98897 .39677 Mdot
.6475 .40699 Mdot
.49765 .61704 Mdot
.4925 .61486 Mdot
.47612 .60791 Mdot
.42405 .58585 Mdot
.26233 .51808 Mdot
.86259 .37098 Mdot
.6443 .48312 Mdot
.61399 .59931 Mdot
.74043 .07814 Mdot
.10517 .22542 Mdot
.32339 .13486 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50715 .00303 Mdot
.52276 .00965 Mdot
.57241 .03068 Mdot
.72697 .09552 Mdot
.11777 .24153 Mdot
.3476 .14204 Mdot
.38219 .02138 Mdot
.25577 .5399 Mdot
.89078 .39246 Mdot
.67706 .48595 Mdot
.50038 .00016 Mdot
.50122 .00052 Mdot
.50389 .00165 Mdot
.51239 .00525 Mdot
.53944 .01672 Mdot
.62506 .05291 Mdot
.87954 .15728 Mdot
.29795 .25859 Mdot
.48838 .11769 Mdot
.6614 .10693 Mdot
.03709 .23219 Mdot
.35765 .19812 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51126 .00478 Mdot
.53587 .01521 Mdot
.61383 .04818 Mdot
.84835 .14494 Mdot
.27745 .2652 Mdot
.47136 .11984 Mdot
.62255 .09344 Mdot
.93992 .19615 Mdot
.34529 .25053 Mdot
.49791 .61715 Mdot
.49334 .61521 Mdot
.4788 .60904 Mdot
.43254 .58944 Mdot
.28808 .52876 Mdot
.91169 .38541 Mdot
.66107 .46314 Mdot
.61288 .58825 Mdot
.72017 .06631 Mdot
.06201 .21127 Mdot
.31317 .15523 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50234 .00099 Mdot
.50747 .00317 Mdot
.52379 .01009 Mdot
.57568 .03207 Mdot
.73685 .09961 Mdot
.13594 .24665 Mdot
.35503 .1354 Mdot
.3855 .01883 Mdot
.25865 .53964 Mdot
.89343 .39231 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51352 .00573 Mdot
.54305 .01825 Mdot
.63636 .05767 Mdot
.91009 .16918 Mdot
.31163 .24816 Mdot
.4921 .11154 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48413 .6113 Mdot
.44946 .59661 Mdot
.34026 .55054 Mdot
.02969 .42609 Mdot
.67485 .39873 Mdot
.53261 .53013 Mdot
.43895 .56015 Mdot
.25595 .50493 Mdot
.83438 .35749 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50129 .00054 Mdot
.50409 .00174 Mdot
.51304 .00553 Mdot
.54154 .01761 Mdot
.63164 .05568 Mdot
.89744 .16427 Mdot
.30665 .25291 Mdot
.4921 .11461 Mdot
.6657 .10729 Mdot
.04532 .23462 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50336 .00143 Mdot
.51071 .00454 Mdot
.53412 .01446 Mdot
.6083 .04585 Mdot
.8327 .13868 Mdot
.26431 .26675 Mdot
.45816 .11981 Mdot
.58998 .08146 Mdot
.84968 .1605 Mdot
.3028 .28005 Mdot
.4994 .61778 Mdot
.49808 .61722 Mdot
.4939 .61545 Mdot
.48055 .60979 Mdot
.43811 .5918 Mdot
.30515 .53586 Mdot
.94766 .39709 Mdot
.66727 .44474 Mdot
.59407 .5728 Mdot
.65392 .03698 Mdot
.91029 .15845 Mdot
.49927 .61772 Mdot
.49768 .61705 Mdot
.4926 .6149 Mdot
.47642 .60804 Mdot
.42501 .58626 Mdot
.26522 .51928 Mdot
.86779 .37241 Mdot
.64664 .48136 Mdot
.61563 .59887 Mdot
.74319 .07884 Mdot
.10928 .22625 Mdot
.5007 .0003 Mdot
.50222 .00094 Mdot
.50706 .00299 Mdot
.5225 .00954 Mdot
.57157 .03033 Mdot
.72441 .09446 Mdot
.11291 .24011 Mdot
.3459 .14399 Mdot
.38219 .02243 Mdot
.25747 .54095 Mdot
.89427 .39357 Mdot
.67826 .48453 Mdot
.50074 .00031 Mdot
.50237 .001 Mdot
.50754 .0032 Mdot
.52402 .01018 Mdot
.57639 .03237 Mdot
.73899 .10049 Mdot
.13976 .24769 Mdot
.35681 .13414 Mdot
.3869 .0186 Mdot
.26126 .54038 Mdot
.89749 .39321 Mdot
.67707 .48181 Mdot
.50071 .0003 Mdot
.50225 .00095 Mdot
.50716 .00304 Mdot
.5228 .00967 Mdot
.57254 .03074 Mdot
.72736 .09568 Mdot
.1185 .24174 Mdot
.34787 .14175 Mdot
.38222 .02123 Mdot
.25561 .53978 Mdot
.8904 .39233 Mdot
.67691 .48609 Mdot
.50053 .00023 Mdot
.5017 .00072 Mdot
.50541 .00229 Mdot
.51724 .00731 Mdot
.55488 .02326 Mdot
.67321 .07314 Mdot
.00303 .20384 Mdot
.3283 .20103 Mdot
.44315 .07098 Mdot
.47454 .0194 Mdot
.46788 .61392 Mdot
.41338 .58435 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50159 .00067 Mdot
.50507 .00215 Mdot
.51615 .00685 Mdot
.55143 .0218 Mdot
.6625 .06865 Mdot
.97713 .19445 Mdot
.32595 .21558 Mdot
.46269 .08451 Mdot
.544 .05025 Mdot
.69045 .09052 Mdot
.49844 .61737 Mdot
.49504 .61593 Mdot
.48419 .61133 Mdot
.44966 .5967 Mdot
.34089 .55081 Mdot
.03127 .42668 Mdot
.67504 .39788 Mdot
.53156 .52936 Mdot
.43512 .55843 Mdot
.24403 .49993 Mdot
.81437 .35249 Mdot
.49898 .6176 Mdot
.49676 .61666 Mdot
.48966 .61365 Mdot
.46707 .60407 Mdot
.39544 .57376 Mdot
.17801 .48366 Mdot
.74586 .35095 Mdot
.55236 .49844 Mdot
.43599 .54611 Mdot
.22616 .48835 Mdot
.78027 .34246 Mdot
.49896 .61759 Mdot
.49667 .61662 Mdot
.4894 .61354 Mdot
.46624 .60372 Mdot
.39283 .57266 Mdot
.17053 .48065 Mdot
.73865 .35112 Mdot
.54489 .49829 Mdot
.41759 .53935 Mdot
.17211 .46632 Mdot
.71593 .3361 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47917 .6092 Mdot
.43373 .58995 Mdot
.29173 .53027 Mdot
.91915 .38777 Mdot
.6627 .45954 Mdot
.60996 .58544 Mdot
.70933 .06142 Mdot
.03969 .20417 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47347 .60678 Mdot
.41566 .5823 Mdot
.23717 .50772 Mdot
.82073 .36066 Mdot
.61983 .49387 Mdot
.58216 .59476 Mdot
.66234 .04955 Mdot
.94595 .17528 Mdot
.30908 .22443 Mdot
.49878 .61752 Mdot
.49611 .61639 Mdot
.48761 .61278 Mdot
.46056 .60131 Mdot
.37494 .56512 Mdot
.12044 .46075 Mdot
.70204 .35945 Mdot
.51161 .50034 Mdot
.33859 .5111 Mdot
.96288 .38583 Mdot
.64234 .41993 Mdot
.4977 .61706 Mdot
.49266 .61492 Mdot
.47661 .60812 Mdot
.4256 .58651 Mdot
.26701 .52002 Mdot
.87105 .37332 Mdot
.64804 .4802 Mdot
.61642 .59849 Mdot
.74426 .07901 Mdot
.11068 .22646 Mdot
.32414 .13193 Mdot
.49908 .61764 Mdot
.49707 .61679 Mdot
.49068 .61408 Mdot
.47031 .60544 Mdot
.40565 .57807 Mdot
.20761 .49564 Mdot
.77926 .3533 Mdot
.58562 .49836 Mdot
.51429 .57395 Mdot
.46438 .58719 Mdot
.36149 .55444 Mdot
.49777 .61709 Mdot
.4929 .61502 Mdot
.47737 .60844 Mdot
.42801 .58753 Mdot
.27431 .52304 Mdot
.88465 .37721 Mdot
.65326 .47503 Mdot
.61785 .59615 Mdot
.7435 .07766 Mdot
.10769 .22508 Mdot
.32239 .13269 Mdot
.50006 2e-05 Mdot
.50019 8e-05 Mdot
.5006 .00025 Mdot
.5019 .0008 Mdot
.50605 .00256 Mdot
.51926 .00817 Mdot
.5613 .02598 Mdot
.69305 .08142 Mdot
.0484 .21962 Mdot
.33227 .17544 Mdot
.40859 .04717 Mdot
.35522 .58505 Mdot
.49921 .6177 Mdot
.49749 .61697 Mdot
.49201 .61465 Mdot
.47455 .60724 Mdot
.41908 .58375 Mdot
.24738 .51192 Mdot
.83699 .3644 Mdot
.63055 .49045 Mdot
.5987 .59835 Mdot
.70558 .06606 Mdot
.04195 .20789 Mdot
.49854 .61742 Mdot
.49536 .61607 Mdot
.48522 .61176 Mdot
.45293 .59808 Mdot
.35106 .55508 Mdot
.05699 .43629 Mdot
.67925 .38458 Mdot
.51704 .51778 Mdot
.38035 .53355 Mdot
.08061 .43279 Mdot
.66506 .36121 Mdot
.49966 .61789 Mdot
.49892 .61758 Mdot
.49656 .61658 Mdot
.48906 .61339 Mdot
.46514 .60326 Mdot
.38936 .5712 Mdot
.16067 .4767 Mdot
.72988 .35179 Mdot
.53591 .49815 Mdot
.39534 .53116 Mdot
.10885 .44098 Mdot
.49752 .61698 Mdot
.49209 .61468 Mdot
.47482 .60736 Mdot
.41992 .58411 Mdot
.2499 .51296 Mdot
.84115 .36541 Mdot
.63304 .48941 Mdot
.60205 .59888 Mdot
.71385 .0691 Mdot
.05826 .21285 Mdot
.31721 .16005 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48122 .61007 Mdot
.44023 .5927 Mdot
.31167 .53858 Mdot
.96208 .40197 Mdot
.66883 .4368 Mdot
.58394 .56557 Mdot
.61921 .02179 Mdot
.81702 .12226 Mdot
.23272 .25691 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50779 .0033 Mdot
.52482 .01052 Mdot
.57892 .03344 Mdot
.7466 .10363 Mdot
.15296 .25114 Mdot
.3636 .13019 Mdot
.3938 .01866 Mdot
.27625 .54539 Mdot
.92322 .39984 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50393 .00167 Mdot
.51252 .00531 Mdot
.53988 .01691 Mdot
.62643 .05349 Mdot
.88329 .15875 Mdot
.29995 .25751 Mdot
.48953 .11717 Mdot
.66341 .10747 Mdot
.04156 .23371 Mdot
.35807 .19562 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00322 Mdot
.52416 .01024 Mdot
.57684 .03256 Mdot
.74035 .10105 Mdot
.14215 .24833 Mdot
.35797 .13338 Mdot
.38791 .01851 Mdot
.26328 .54101 Mdot
.90074 .39398 Mdot
.50047 .0002 Mdot
.50151 .00064 Mdot
.5048 .00203 Mdot
.51529 .00648 Mdot
.54867 .02063 Mdot
.65393 .06505 Mdot
.95573 .18652 Mdot
.32308 .22704 Mdot
.47643 .09478 Mdot
.59456 .07301 Mdot
.84634 .15561 Mdot
.29443 .27694 Mdot
.50037 .00016 Mdot
.50118 .0005 Mdot
.50375 .00159 Mdot
.51196 .00507 Mdot
.53808 .01615 Mdot
.62078 .05111 Mdot
.86776 .15264 Mdot
.29105 .26161 Mdot
.4835 .11894 Mdot
.65125 .10368 Mdot
.01324 .22372 Mdot
.35539 .21146 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50476 .00202 Mdot
.51517 .00643 Mdot
.54829 .02047 Mdot
.65275 .06456 Mdot
.95274 .18541 Mdot
.32258 .22857 Mdot
.47809 .09611 Mdot
.60084 .07586 Mdot
.86493 .16322 Mdot
.30816 .27393 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51144 .00485 Mdot
.53645 .01545 Mdot
.61565 .04895 Mdot
.85347 .14698 Mdot
.28132 .26443 Mdot
.47504 .11973 Mdot
.63148 .09668 Mdot
.96346 .20518 Mdot
.34977 .23875 Mdot
.50076 .00032 Mdot
.50243 .00103 Mdot
.50776 .00329 Mdot
.52471 .01048 Mdot
.57858 .03329 Mdot
.74559 .10322 Mdot
.15125 .25071 Mdot
.36267 .13066 Mdot
.39272 .01857 Mdot
.27376 .54452 Mdot
.91873 .39861 Mdot
.68037 .47072 Mdot
.49805 .61721 Mdot
.49379 .6154 Mdot
.48022 .60965 Mdot
.43706 .59136 Mdot
.30192 .53451 Mdot
.94064 .39475 Mdot
.66635 .44852 Mdot
.59857 .57615 Mdot
.66938 .04376 Mdot
.94895 .17278 Mdot
.30379 .2193 Mdot
.50013 6e-05 Mdot
.50042 .00018 Mdot
.50135 .00057 Mdot
.50431 .00183 Mdot
.51374 .00582 Mdot
.54374 .01854 Mdot
.63852 .05858 Mdot
.91584 .17139 Mdot
.31359 .24583 Mdot
.49142 .1099 Mdot
.65638 .10195 Mdot
.01996 .2247 Mdot
.49952 .61783 Mdot
.49847 .61738 Mdot
.49511 .61596 Mdot
.48443 .61143 Mdot
.45044 .59703 Mdot
.34331 .55182 Mdot
.03732 .42892 Mdot
.67586 .39464 Mdot
.52769 .52646 Mdot
.42085 .552 Mdot
.20013 .48162 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.50271 .00115 Mdot
.50865 .00367 Mdot
.52754 .01168 Mdot
.58753 .03708 Mdot
.7723 .1142 Mdot
.19347 .26029 Mdot
.3908 .12196 Mdot
.43689 .02848 Mdot
.39078 .58953 Mdot
.19339 .49604 Mdot
.50042 .00018 Mdot
.50132 .00056 Mdot
.50421 .00179 Mdot
.51342 .00569 Mdot
.54275 .01812 Mdot
.63543 .05728 Mdot
.9076 .16821 Mdot
.31072 .24914 Mdot
.49227 .1122 Mdot
.66222 .10504 Mdot
.03552 .23071 Mdot
.35597 .19805 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50418 .00177 Mdot
.51331 .00564 Mdot
.54239 .01797 Mdot
.63429 .0568 Mdot
.90457 .16704 Mdot
.30957 .2503 Mdot
.49236 .11297 Mdot
.6637 .10589 Mdot
.03952 .23227 Mdot
.49811 .61723 Mdot
.49398 .61548 Mdot
.48083 .60991 Mdot
.439 .59218 Mdot
.3079 .53701 Mdot
.95368 .39912 Mdot
.66797 .44145 Mdot
.58997 .56983 Mdot
.63986 .03083 Mdot
.87355 .14443 Mdot
.27759 .24971 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50169 .00071 Mdot
.50537 .00228 Mdot
.51711 .00726 Mdot
.55447 .02309 Mdot
.67195 .07261 Mdot
3e-05 .20276 Mdot
.32806 .20274 Mdot
.44551 .07259 Mdot
.48282 .02306 Mdot
.49439 .00716 Mdot
.49961 .61787 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.48751 .61274 Mdot
.46021 .60116 Mdot
.37385 .56466 Mdot
.11747 .45958 Mdot
.70045 .3603 Mdot
.51069 .50075 Mdot
.33695 .51066 Mdot
.95923 .38459 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50014 6e-05 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50464 .00197 Mdot
.51478 .00627 Mdot
.54705 .01995 Mdot
.64887 .06293 Mdot
.94283 .18168 Mdot
.32071 .23354 Mdot
.50017 7e-05 Mdot
.50055 .00023 Mdot
.50176 .00075 Mdot
.5056 .00238 Mdot
.51785 .00757 Mdot
.55681 .02408 Mdot
.6792 .07564 Mdot
.01707 .20882 Mdot
.32939 .19302 Mdot
.43206 .06346 Mdot
.4359 .00237 Mdot
.34617 .56258 Mdot
.49869 .61748 Mdot
.49582 .61626 Mdot
.48669 .61239 Mdot
.45762 .60007 Mdot
.36573 .56124 Mdot
.09549 .45102 Mdot
.69046 .36771 Mdot
.50764 .50505 Mdot
.33627 .51212 Mdot
.9604 .38573 Mdot
.64332 .42207 Mdot
.49844 .61737 Mdot
.49504 .61593 Mdot
.48419 .61133 Mdot
.44968 .5967 Mdot
.34094 .55083 Mdot
.0314 .42672 Mdot
.67506 .39781 Mdot
.53148 .52929 Mdot
.4348 .55828 Mdot
.24304 .49952 Mdot
.81277 .35211 Mdot
.49773 .61707 Mdot
.49275 .61496 Mdot
.47691 .60824 Mdot
.42656 .58692 Mdot
.26993 .52123 Mdot
.87643 .37484 Mdot
.65022 .47823 Mdot
.61733 .59771 Mdot
.74494 .07886 Mdot
.11115 .22633 Mdot
.32387 .13147 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50129 .00055 Mdot
.50412 .00175 Mdot
.51313 .00557 Mdot
.54183 .01773 Mdot
.63254 .05606 Mdot
.89987 .16522 Mdot
.30768 .25204 Mdot
.49226 .11408 Mdot
.66525 .10691 Mdot
.04392 .23403 Mdot
.49791 .61715 Mdot
.49335 .61521 Mdot
.47881 .60905 Mdot
.43257 .58946 Mdot
.2882 .5288 Mdot
.91193 .38549 Mdot
.66113 .46303 Mdot
.6128 .58817 Mdot
.71986 .06616 Mdot
.06138 .21107 Mdot
.3131 .15557 Mdot
.5001 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50979 .00415 Mdot
.53118 .01322 Mdot
.59906 .04195 Mdot
.8061 .12796 Mdot
.2372 .26643 Mdot
.43034 .11937 Mdot
.52229 .05683 Mdot
.64757 .07743 Mdot
.49912 .61766 Mdot
.49719 .61684 Mdot
.49106 .61424 Mdot
.47151 .60595 Mdot
.40946 .57968 Mdot
.2188 .5002 Mdot
.79398 .35548 Mdot
.59884 .49743 Mdot
.5426 .58328 Mdot
.5495 .00427 Mdot
.62947 .04942 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.50728 .00309 Mdot
.5232 .00984 Mdot
.57381 .03127 Mdot
.73119 .09727 Mdot
.12565 .24379 Mdot
.35061 .13903 Mdot
.38296 .02 Mdot
.25517 .53905 Mdot
.88877 .39158 Mdot
.67596 .48651 Mdot
.49903 .61762 Mdot
.49692 .61673 Mdot
.49019 .61387 Mdot
.46874 .60478 Mdot
.40071 .57599 Mdot
.19321 .4898 Mdot
.76202 .35154 Mdot
.56888 .49867 Mdot
.47587 .56055 Mdot
.3468 .53826 Mdot
.0218 .41718 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50558 .00237 Mdot
.51778 .00754 Mdot
.5566 .02399 Mdot
.67855 .07537 Mdot
.01557 .20829 Mdot
.32927 .19388 Mdot
.43325 .06426 Mdot
.44002 .00418 Mdot
.35894 .56792 Mdot
.09289 .45361 Mdot
.50008 3e-05 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50814 .00345 Mdot
.52594 .011 Mdot
.58248 .03494 Mdot
.75728 .10803 Mdot
.17056 .25542 Mdot
.37424 .12588 Mdot
.40829 .02105 Mdot
.31227 .55869 Mdot
.49853 .61741 Mdot
.49532 .61605 Mdot
.48509 .61171 Mdot
.45254 .59791 Mdot
.34985 .55457 Mdot
.05388 .43512 Mdot
.67863 .38611 Mdot
.5185 .51907 Mdot
.38607 .53618 Mdot
.09696 .43935 Mdot
.67124 .35493 Mdot
.49923 .61771 Mdot
.49753 .61699 Mdot
.49214 .6147 Mdot
.47496 .60742 Mdot
.42038 .5843 Mdot
.25128 .51353 Mdot
.84347 .36599 Mdot
.63438 .48881 Mdot
.60376 .59911 Mdot
.71798 .07059 Mdot
.06613 .21516 Mdot
.50034 .00014 Mdot
.50107 .00046 Mdot
.50342 .00145 Mdot
.5109 .00462 Mdot
.53471 .01471 Mdot
.61016 .04663 Mdot
.83798 .1408 Mdot
.26898 .26637 Mdot
.46293 .11987 Mdot
.60178 .08582 Mdot
.88311 .17387 Mdot
.32443 .27275 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50782 .00332 Mdot
.52491 .01056 Mdot
.57921 .03356 Mdot
.74748 .104 Mdot
.15446 .25152 Mdot
.36444 .12978 Mdot
.39479 .01876 Mdot
.27858 .54621 Mdot
.92747 .40104 Mdot
.68143 .46597 Mdot
.50051 .00022 Mdot
.50164 .0007 Mdot
.50523 .00222 Mdot
.51665 .00706 Mdot
.55299 .02246 Mdot
.66737 .07069 Mdot
.98902 .19879 Mdot
.32713 .20896 Mdot
.45399 .07841 Mdot
.51279 .03634 Mdot
.59077 .04819 Mdot
.79764 .12785 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50319 .00135 Mdot
.51016 .00431 Mdot
.53237 .01373 Mdot
.60281 .04353 Mdot
.81695 .13235 Mdot
.24901 .26703 Mdot
.44235 .11949 Mdot
.55108 .0672 Mdot
.73512 .11374 Mdot
.15684 .26064 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00321 Mdot
.52414 .01023 Mdot
.57676 .03253 Mdot
.74012 .10096 Mdot
.14175 .24822 Mdot
.35777 .13351 Mdot
.38774 .01852 Mdot
.26292 .5409 Mdot
.90016 .39384 Mdot
.67753 .48044 Mdot
.49942 .61779 Mdot
.49814 .61724 Mdot
.49407 .61552 Mdot
.4811 .61002 Mdot
.43984 .59254 Mdot
.31049 .53809 Mdot
.95943 .40107 Mdot
.66857 .43827 Mdot
.58587 .56692 Mdot
.62583 .02469 Mdot
.83546 .12956 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50287 .00122 Mdot
.50915 .00388 Mdot
.52914 .01235 Mdot
.59259 .03922 Mdot
.78723 .12029 Mdot
.2141 .26382 Mdot
.40829 .12001 Mdot
.47239 .03962 Mdot
.49529 .01415 Mdot
.51113 .00979 Mdot
.49784 .61712 Mdot
.49313 .61512 Mdot
.47813 .60876 Mdot
.43041 .58855 Mdot
.28161 .52607 Mdot
.89877 .38143 Mdot
.65774 .46907 Mdot
.61644 .59251 Mdot
.73464 .07305 Mdot
.09046 .21991 Mdot
.31778 .14049 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51415 .006 Mdot
.54504 .01909 Mdot
.6426 .0603 Mdot
.92657 .1755 Mdot
.31682 .24119 Mdot
.48906 .10645 Mdot
.64492 .09632 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52059 .00873 Mdot
.56552 .02777 Mdot
.70596 .0868 Mdot
.07607 .22874 Mdot
.33636 .16087 Mdot
.39222 .03452 Mdot
.29849 .5601 Mdot
.97701 .41935 Mdot
.6899 .44059 Mdot
.49772 .61707 Mdot
.49274 .61496 Mdot
.47688 .60823 Mdot
.42646 .58687 Mdot
.26961 .5211 Mdot
.87584 .37467 Mdot
.64998 .47845 Mdot
.61726 .59781 Mdot
.74493 .0789 Mdot
.11121 .22637 Mdot
.32392 .13147 Mdot
.50056 .00024 Mdot
.50178 .00076 Mdot
.50568 .00241 Mdot
.5181 .00768 Mdot
.55761 .02442 Mdot
.68166 .07667 Mdot
.02277 .21082 Mdot
.32984 .18978 Mdot
.42759 .06041 Mdot
.42045 .61362 Mdot
.29888 .5429 Mdot
.94975 .40226 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46984 .60524 Mdot
.40417 .57745 Mdot
.20329 .49388 Mdot
.77388 .35265 Mdot
.58053 .49853 Mdot
.50287 .57004 Mdot
.42953 .5727 Mdot
.25389 .50949 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00226 Mdot
.51701 .00721 Mdot
.55416 .02296 Mdot
.67098 .0722 Mdot
.9977 .20193 Mdot
.32787 .20406 Mdot
.44732 .07382 Mdot
.4892 .02588 Mdot
.51488 .01587 Mdot
.56284 .02964 Mdot
.49994 .61801 Mdot
.49982 .61796 Mdot
.49942 .61779 Mdot
.49816 .61725 Mdot
.49414 .61555 Mdot
.48133 .61012 Mdot
.44057 .59285 Mdot
.31273 .53902 Mdot
.96446 .40279 Mdot
.66906 .43546 Mdot
.58217 .56434 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51263 .00535 Mdot
.54021 .01705 Mdot
.62748 .05393 Mdot
.88615 .15987 Mdot
.30141 .25664 Mdot
.49027 .11673 Mdot
.66455 .10771 Mdot
.04398 .2345 Mdot
.35827 .19425 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50443 .00188 Mdot
.51413 .00599 Mdot
.54498 .01907 Mdot
.64241 .06021 Mdot
.92607 .17531 Mdot
.31668 .24141 Mdot
.48921 .10663 Mdot
.64555 .09663 Mdot
.99104 .21352 Mdot
.34996 .22183 Mdot
.49993 .618 Mdot
.49978 .61794 Mdot
.49929 .61773 Mdot
.49774 .61707 Mdot
.49279 .61497 Mdot
.47702 .60829 Mdot
.42689 .58706 Mdot
.27092 .52164 Mdot
.87828 .37537 Mdot
.65093 .47753 Mdot
.61754 .5974 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50288 .00122 Mdot
.50919 .0039 Mdot
.52927 .01241 Mdot
.59302 .0394 Mdot
.78847 .1208 Mdot
.21572 .26405 Mdot
.40975 .11992 Mdot
.47556 .04067 Mdot
.50484 .0181 Mdot
.49958 .61786 Mdot
.49867 .61747 Mdot
.49577 .61624 Mdot
.48653 .61232 Mdot
.45711 .59985 Mdot
.36413 .56057 Mdot
.09121 .44936 Mdot
.68884 .36936 Mdot
.5078 .50614 Mdot
.33845 .51337 Mdot
.9663 .38803 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50722 .00306 Mdot
.52301 .00976 Mdot
.57319 .03101 Mdot
.72931 .09649 Mdot
.12216 .24279 Mdot
.34924 .14034 Mdot
.3825 .02056 Mdot
.2551 .5393 Mdot
.88909 .39183 Mdot
.6763 .48652 Mdot
.50072 .00031 Mdot
.50231 .00098 Mdot
.50735 .00311 Mdot
.5234 .00992 Mdot
.57442 .03154 Mdot
.73306 .09804 Mdot
.12908 .24475 Mdot
.35202 .13778 Mdot
.38361 .01953 Mdot
.25577 .53903 Mdot
.88936 .39158 Mdot
.67586 .48608 Mdot
.49913 .61766 Mdot
.49721 .61685 Mdot
.49112 .61427 Mdot
.47172 .60604 Mdot
.41012 .57996 Mdot
.22076 .501 Mdot
.79668 .35594 Mdot
.60114 .49718 Mdot
.5473 .58476 Mdot
.56337 .00993 Mdot
.67201 .06714 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47697 .60827 Mdot
.42674 .58699 Mdot
.27045 .52144 Mdot
.87739 .37511 Mdot
.65059 .47786 Mdot
.61745 .59755 Mdot
.74492 .07878 Mdot
.111 .22625 Mdot
.32375 .13149 Mdot
.49857 .61743 Mdot
.49543 .6161 Mdot
.48545 .61186 Mdot
.45366 .59839 Mdot
.35334 .55603 Mdot
.06287 .43851 Mdot
.68053 .38173 Mdot
.51453 .51544 Mdot
.37031 .5289 Mdot
.05237 .42154 Mdot
.65729 .37386 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.5079 .00335 Mdot
.52515 .01067 Mdot
.57998 .03389 Mdot
.7498 .10495 Mdot
.15834 .2525 Mdot
.36667 .12875 Mdot
.39757 .0191 Mdot
.28522 .5486 Mdot
.93997 .40465 Mdot
.68264 .459 Mdot
.50004 1e-05 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50114 .00048 Mdot
.50364 .00154 Mdot
.5116 .00492 Mdot
.53695 .01567 Mdot
.61723 .04961 Mdot
.85787 .14873 Mdot
.28448 .26366 Mdot
.47794 .11956 Mdot
.63841 .09918 Mdot
.49936 .61776 Mdot
.49795 .61716 Mdot
.49347 .61526 Mdot
.47919 .60921 Mdot
.4338 .58998 Mdot
.29193 .53036 Mdot
.91957 .3879 Mdot
.66278 .45933 Mdot
.60978 .58527 Mdot
.70868 .06113 Mdot
.03831 .20373 Mdot
.49882 .61753 Mdot
.49623 .61643 Mdot
.48797 .61293 Mdot
.4617 .6018 Mdot
.37853 .56663 Mdot
.13033 .46464 Mdot
.70777 .35687 Mdot
.51558 .49925 Mdot
.34672 .51367 Mdot
.98186 .39254 Mdot
.64416 .40932 Mdot
.50014 6e-05 Mdot
.50044 .00018 Mdot
.50139 .00059 Mdot
.50442 .00188 Mdot
.51409 .00597 Mdot
.54486 .01902 Mdot
.64202 .06005 Mdot
.92504 .17492 Mdot
.31639 .24187 Mdot
.48948 .10697 Mdot
.6468 .09723 Mdot
.99441 .21483 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00248 Mdot
.51866 .00791 Mdot
.5594 .02518 Mdot
.68717 .07897 Mdot
.03532 .21517 Mdot
.33092 .18269 Mdot
.41799 .05381 Mdot
.38742 .59914 Mdot
.2017 .50326 Mdot
.78817 .36245 Mdot
.49888 .61756 Mdot
.49645 .61653 Mdot
.48868 .61323 Mdot
.46394 .60274 Mdot
.38556 .56959 Mdot
.14993 .47241 Mdot
.72123 .35308 Mdot
.52737 .49822 Mdot
.37435 .52347 Mdot
.05185 .41871 Mdot
.65294 .37149 Mdot
.50041 .00017 Mdot
.50131 .00055 Mdot
.50416 .00176 Mdot
.51325 .00562 Mdot
.54219 .01789 Mdot
.63367 .05654 Mdot
.90291 .1664 Mdot
.30892 .25093 Mdot
.49236 .11338 Mdot
.66435 .1063 Mdot
.04133 .23299 Mdot
.35701 .1951 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50329 .0014 Mdot
.5105 .00445 Mdot
.53344 .01418 Mdot
.60616 .04495 Mdot
.82658 .13622 Mdot
.25862 .26702 Mdot
.45228 .11969 Mdot
.57544 .07611 Mdot
.80756 .14346 Mdot
.26297 .28146 Mdot
.50047 .0002 Mdot
.50149 .00063 Mdot
.50475 .00201 Mdot
.51512 .00641 Mdot
.54813 .0204 Mdot
.65226 .06435 Mdot
.95148 .18493 Mdot
.32236 .22922 Mdot
.47877 .09666 Mdot
.60342 .07704 Mdot
.87251 .16631 Mdot
.31303 .27226 Mdot
.49973 .61792 Mdot
.49913 .61767 Mdot
.49724 .61687 Mdot
.49122 .61431 Mdot
.47202 .60617 Mdot
.41108 .58037 Mdot
.2236 .50216 Mdot
.80066 .35664 Mdot
.60446 .49678 Mdot
.55394 .58681 Mdot
.58278 .01783 Mdot
.49961 .61787 Mdot
.49876 .61751 Mdot
.49605 .61636 Mdot
.48741 .6127 Mdot
.45992 .60104 Mdot
.37293 .56427 Mdot
.11495 .45859 Mdot
.69915 .36106 Mdot
.51 .50113 Mdot
.33585 .5104 Mdot
.95686 .3838 Mdot
.50062 .00026 Mdot
.50199 .00084 Mdot
.50633 .00268 Mdot
.52015 .00854 Mdot
.56412 .02718 Mdot
.70169 .08502 Mdot
.06708 .22582 Mdot
.3348 .16546 Mdot
.39688 .03837 Mdot
.31489 .56736 Mdot
.01373 .43191 Mdot
.692 .41919 Mdot
.49892 .61758 Mdot
.49656 .61657 Mdot
.48903 .61338 Mdot
.46505 .60322 Mdot
.38908 .57108 Mdot
.15986 .47637 Mdot
.72919 .35186 Mdot
.53521 .49815 Mdot
.39363 .53053 Mdot
.10411 .4391 Mdot
.66932 .34932 Mdot
.50035 .00015 Mdot
.50111 .00047 Mdot
.50354 .0015 Mdot
.51128 .00479 Mdot
.53594 .01524 Mdot
.61405 .04827 Mdot
.84897 .14519 Mdot
.27793 .26511 Mdot
.47182 .11983 Mdot
.62367 .09385 Mdot
.94292 .1973 Mdot
.34596 .2491 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00114 Mdot
.50859 .00364 Mdot
.52737 .0116 Mdot
.587 .03685 Mdot
.77071 .11354 Mdot
.19115 .25984 Mdot
.38898 .12227 Mdot
.43347 .0275 Mdot
.38106 .58564 Mdot
.16638 .48535 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.49419 .61557 Mdot
.4815 .61019 Mdot
.44113 .59308 Mdot
.31446 .53975 Mdot
.96837 .40414 Mdot
.66941 .43327 Mdot
.57923 .5623 Mdot
.60305 .01472 Mdot
.77088 .10372 Mdot
.5004 .00017 Mdot
.50126 .00054 Mdot
.50402 .00171 Mdot
.51281 .00543 Mdot
.5408 .0173 Mdot
.62932 .05471 Mdot
.89116 .16183 Mdot
.30383 .25505 Mdot
.4913 .11586 Mdot
.66572 .1078 Mdot
.04617 .23513 Mdot
.35834 .19293 Mdot
.4989 .61757 Mdot
.4965 .61655 Mdot
.48884 .6133 Mdot
.46447 .60297 Mdot
.38724 .5703 Mdot
.15466 .47429 Mdot
.72492 .35244 Mdot
.53095 .49816 Mdot
.38313 .52667 Mdot
.07533 .4278 Mdot
.65871 .36055 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51225 .00519 Mdot
.53901 .01654 Mdot
.6237 .05234 Mdot
.87581 .15581 Mdot
.29587 .25961 Mdot
.48704 .11815 Mdot
.65881 .10615 Mdot
.03117 .23013 Mdot
.35708 .20142 Mdot
.49975 .61793 Mdot
.4992 .6177 Mdot
.49746 .61696 Mdot
.49191 .6146 Mdot
.47423 .60711 Mdot
.41807 .58332 Mdot
.24437 .51068 Mdot
.83209 .36323 Mdot
.62748 .49158 Mdot
.59429 .59752 Mdot
.69441 .06188 Mdot
.49951 .61783 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48414 .61131 Mdot
.4495 .59663 Mdot
.34037 .55059 Mdot
.02998 .4262 Mdot
.67488 .39857 Mdot
.53242 .52999 Mdot
.43825 .55983 Mdot
.25376 .50401 Mdot
.49854 .61742 Mdot
.49536 .61607 Mdot
.48521 .61176 Mdot
.45291 .59807 Mdot
.35101 .55506 Mdot
.05687 .43625 Mdot
.67923 .38463 Mdot
.51709 .51783 Mdot
.38055 .53365 Mdot
.0812 .43302 Mdot
.66526 .36097 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50013 6e-05 Mdot
.50043 .00018 Mdot
.50137 .00058 Mdot
.50436 .00185 Mdot
.5139 .00589 Mdot
.54426 .01876 Mdot
.64016 .05927 Mdot
.92017 .17305 Mdot
.31496 .24399 Mdot
.4999 .61799 Mdot
.49968 .6179 Mdot
.49897 .6176 Mdot
.49673 .61665 Mdot
.48957 .61361 Mdot
.46678 .60395 Mdot
.39454 .57338 Mdot
.17542 .48261 Mdot
.7433 .35097 Mdot
.54971 .49839 Mdot
.42947 .54372 Mdot
.50064 .00027 Mdot
.50202 .00086 Mdot
.50645 .00273 Mdot
.52054 .00871 Mdot
.56537 .0277 Mdot
.70552 .08662 Mdot
.07515 .22844 Mdot
.33619 .16134 Mdot
.39266 .0349 Mdot
.30007 .5608 Mdot
.98045 .4205 Mdot
.69009 .43858 Mdot
.50057 .00024 Mdot
.50181 .00077 Mdot
.50578 .00245 Mdot
.51841 .00781 Mdot
.55859 .02484 Mdot
.6847 .07794 Mdot
.02971 .21323 Mdot
.33042 .18585 Mdot
.42223 .05674 Mdot
.40196 .60551 Mdot
.24376 .52026 Mdot
.84701 .37283 Mdot
.49857 .61743 Mdot
.49545 .6161 Mdot
.48549 .61188 Mdot
.45381 .59845 Mdot
.35381 .55623 Mdot
.06408 .43897 Mdot
.68081 .38116 Mdot
.51406 .51498 Mdot
.36838 .528 Mdot
.04701 .41942 Mdot
.65615 .37647 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50666 .00282 Mdot
.52122 .009 Mdot
.56751 .02861 Mdot
.71205 .08933 Mdot
.08857 .2327 Mdot
.33899 .15477 Mdot
.38703 .02969 Mdot
.27948 .55157 Mdot
.93729 .40655 Mdot
.68675 .46319 Mdot
.49756 .617 Mdot
.49222 .61474 Mdot
.47522 .60753 Mdot
.42119 .58464 Mdot
.25373 .51454 Mdot
.8476 .36703 Mdot
.6367 .48769 Mdot
.60656 .5994 Mdot
.72458 .07294 Mdot
.0783 .21861 Mdot
.31925 .14892 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50307 .0013 Mdot
.50977 .00414 Mdot
.53112 .01319 Mdot
.59885 .04186 Mdot
.80549 .12771 Mdot
.2365 .26638 Mdot
.42964 .11937 Mdot
.52065 .05625 Mdot
.64255 .07534 Mdot
.49989 .61799 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49653 .61656 Mdot
.48896 .61335 Mdot
.46484 .60313 Mdot
.38841 .5708 Mdot
.15796 .47561 Mdot
.72761 .35206 Mdot
.53362 .49815 Mdot
.3897 .52908 Mdot
.49843 .61737 Mdot
.49499 .61591 Mdot
.48405 .61127 Mdot
.44923 .59651 Mdot
.33955 .55025 Mdot
.02794 .42545 Mdot
.67463 .39968 Mdot
.53379 .53099 Mdot
.44324 .56207 Mdot
.26935 .51056 Mdot
.85849 .36411 Mdot
.4987 .61748 Mdot
.49585 .61627 Mdot
.48676 .61242 Mdot
.45785 .60017 Mdot
.36646 .56155 Mdot
.09744 .45177 Mdot
.69122 .36698 Mdot
.50764 .50458 Mdot
.33553 .51166 Mdot
.95833 .38491 Mdot
.64292 .42311 Mdot
.49795 .61716 Mdot
.49346 .61526 Mdot
.47916 .6092 Mdot
.43368 .58993 Mdot
.29157 .53021 Mdot
.91884 .38767 Mdot
.66263 .45969 Mdot
.61009 .58556 Mdot
.70983 .06164 Mdot
.04074 .20451 Mdot
.3112 .16716 Mdot
.49765 .61704 Mdot
.49253 .61487 Mdot
.4762 .60794 Mdot
.4243 .58596 Mdot
.26308 .51839 Mdot
.86393 .37135 Mdot
.64492 .48268 Mdot
.61446 .59921 Mdot
.74127 .07837 Mdot
.10646 .2257 Mdot
.3236 .1342 Mdot
.49907 .61764 Mdot
.49704 .61678 Mdot
.49057 .61403 Mdot
.46996 .6053 Mdot
.40456 .57762 Mdot
.20444 .49435 Mdot
.77529 .35281 Mdot
.58188 .49849 Mdot
.50592 .57109 Mdot
.43885 .57658 Mdot
.2823 .52128 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50766 .00325 Mdot
.5244 .01035 Mdot
.5776 .03288 Mdot
.74265 .102 Mdot
.14617 .24939 Mdot
.35999 .13215 Mdot
.38985 .01845 Mdot
.26735 .54233 Mdot
.90754 .39566 Mdot
.67875 .47663 Mdot
.49946 .61781 Mdot
.49829 .61731 Mdot
.49454 .61572 Mdot
.4826 .61065 Mdot
.44461 .59455 Mdot
.32519 .54423 Mdot
.9932 .41285 Mdot
.6714 .41915 Mdot
.55982 .54907 Mdot
.53586 .60323 Mdot
.56524 .01816 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49427 .6156 Mdot
.48175 .61029 Mdot
.44191 .59341 Mdot
.31686 .54075 Mdot
.97383 .40603 Mdot
.66988 .43018 Mdot
.57505 .55942 Mdot
.58865 .00841 Mdot
.72847 .08641 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50723 .00307 Mdot
.52304 .00977 Mdot
.57329 .03106 Mdot
.72963 .09662 Mdot
.12274 .24296 Mdot
.34946 .14012 Mdot
.38257 .02046 Mdot
.25508 .53924 Mdot
.88897 .39177 Mdot
.67623 .48655 Mdot
.49851 .6174 Mdot
.49527 .61603 Mdot
.48493 .61164 Mdot
.45201 .59769 Mdot
.34818 .55387 Mdot
.04962 .43351 Mdot
.67783 .38826 Mdot
.52065 .52089 Mdot
.39436 .53998 Mdot
.12098 .44908 Mdot
.68311 .34742 Mdot
.49793 .61716 Mdot
.49342 .61524 Mdot
.47903 .60914 Mdot
.43327 .58975 Mdot
.29033 .52969 Mdot
.91628 .38686 Mdot
.6621 .46094 Mdot
.61115 .58655 Mdot
.71372 .06339 Mdot
.04883 .20711 Mdot
.31184 .16255 Mdot
.50027 .00011 Mdot
.50086 .00036 Mdot
.50273 .00116 Mdot
.50869 .00369 Mdot
.52768 .01174 Mdot
.58799 .03727 Mdot
.77367 .11476 Mdot
.19545 .26067 Mdot
.39238 .12171 Mdot
.4399 .02937 Mdot
.3994 .593 Mdot
.21785 .50583 Mdot
.49989 .61799 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49654 .61657 Mdot
.48898 .61336 Mdot
.46489 .60315 Mdot
.38856 .57086 Mdot
.1584 .47579 Mdot
.72797 .35201 Mdot
.53398 .49815 Mdot
.39059 .52941 Mdot
.50051 .00022 Mdot
.50163 .00069 Mdot
.5052 .00221 Mdot
.51657 .00703 Mdot
.55275 .02236 Mdot
.66663 .07038 Mdot
.98722 .19814 Mdot
.32696 .20997 Mdot
.45534 .07934 Mdot
.5176 .03848 Mdot
.60622 .05477 Mdot
.84261 .14609 Mdot
.50063 .00027 Mdot
.50202 .00086 Mdot
.50643 .00273 Mdot
.52048 .00868 Mdot
.56517 .02762 Mdot
.7049 .08636 Mdot
.07385 .22802 Mdot
.33595 .16199 Mdot
.3933 .03544 Mdot
.30233 .56181 Mdot
.98541 .42217 Mdot
.69035 .43567 Mdot
.49822 .61728 Mdot
.49431 .61562 Mdot
.48189 .61035 Mdot
.44235 .5936 Mdot
.31823 .54132 Mdot
.97697 .40713 Mdot
.67014 .4284 Mdot
.57261 .55776 Mdot
.58025 .00472 Mdot
.70323 .07601 Mdot
.0547 .21722 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.5266 .01128 Mdot
.58458 .03583 Mdot
.76353 .1106 Mdot
.18036 .25761 Mdot
.38094 .12397 Mdot
.41914 .02361 Mdot
.34119 .56986 Mdot
.06264 .44588 Mdot
.69253 .3893 Mdot
.5007 .0003 Mdot
.50224 .00095 Mdot
.50712 .00302 Mdot
.52269 .00962 Mdot
.57218 .03059 Mdot
.72627 .09523 Mdot
.11645 .24114 Mdot
.34712 .14257 Mdot
.38216 .02165 Mdot
.25614 .54015 Mdot
.89157 .39272 Mdot
.67735 .48564 Mdot
.49758 .61701 Mdot
.49228 .61476 Mdot
.47541 .60761 Mdot
.42179 .5849 Mdot
.25553 .51528 Mdot
.85068 .36782 Mdot
.63837 .48682 Mdot
.60843 .59953 Mdot
.72884 .07442 Mdot
.08588 .22066 Mdot
.32026 .14485 Mdot
.50071 .0003 Mdot
.50227 .00096 Mdot
.50724 .00307 Mdot
.52306 .00978 Mdot
.57335 .03108 Mdot
.72981 .0967 Mdot
.12309 .24306 Mdot
.3496 .13999 Mdot
.38261 .0204 Mdot
.25507 .53921 Mdot
.88892 .39174 Mdot
.67619 .48656 Mdot
.4979 .61715 Mdot
.49332 .6152 Mdot
.47872 .60901 Mdot
.43231 .58935 Mdot
.28738 .52847 Mdot
.91028 .38497 Mdot
.66074 .46381 Mdot
.61337 .58875 Mdot
.72202 .06715 Mdot
.06573 .21242 Mdot
.31362 .15321 Mdot
.50064 .00027 Mdot
.50205 .00087 Mdot
.50653 .00277 Mdot
.52081 .00882 Mdot
.56621 .02806 Mdot
.70809 .08769 Mdot
.08048 .23015 Mdot
.33722 .15868 Mdot
.3902 .03274 Mdot
.29125 .55687 Mdot
.96153 .41426 Mdot
.68896 .44958 Mdot
.4999 .61799 Mdot
.49969 .6179 Mdot
.49901 .61761 Mdot
.49683 .61669 Mdot
.48991 .61375 Mdot
.46785 .6044 Mdot
.39791 .5748 Mdot
.18511 .48652 Mdot
.75315 .35107 Mdot
.55987 .49858 Mdot
.4543 .55279 Mdot
.49975 .61793 Mdot
.49921 .6177 Mdot
.49748 .61697 Mdot
.49198 .61463 Mdot
.47444 .6072 Mdot
.41874 .58361 Mdot
.24638 .51151 Mdot
.83535 .364 Mdot
.62954 .49083 Mdot
.59728 .5981 Mdot
.70202 .06473 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.5067 .00284 Mdot
.52133 .00905 Mdot
.56788 .02876 Mdot
.71318 .0898 Mdot
.09085 .23341 Mdot
.33953 .15369 Mdot
.38626 .02888 Mdot
.27654 .55022 Mdot
.9314 .40473 Mdot
.686 .46637 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.52351 .00997 Mdot
.57477 .03168 Mdot
.73409 .09847 Mdot
.13096 .24528 Mdot
.35282 .13711 Mdot
.38405 .0193 Mdot
.25634 .5391 Mdot
.89008 .39168 Mdot
.49933 .61775 Mdot
.49786 .61713 Mdot
.49318 .61514 Mdot
.47828 .60883 Mdot
.43091 .58876 Mdot
.28312 .5267 Mdot
.90176 .38234 Mdot
.65857 .46774 Mdot
.6158 .5916 Mdot
.73181 .0717 Mdot
.085 .21828 Mdot
.49947 .61781 Mdot
.49831 .61732 Mdot
.49462 .61575 Mdot
.48286 .61076 Mdot
.44543 .5949 Mdot
.32774 .5453 Mdot
.99924 .41501 Mdot
.67188 .41571 Mdot
.55506 .54584 Mdot
.51921 .59587 Mdot
.51209 .61363 Mdot
.50013 5e-05 Mdot
.5004 .00017 Mdot
.50129 .00055 Mdot
.5041 .00174 Mdot
.51306 .00554 Mdot
.54158 .01763 Mdot
.63176 .05574 Mdot
.89778 .16441 Mdot
.3068 .25279 Mdot
.49213 .11454 Mdot
.66565 .10724 Mdot
.04516 .23455 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50303 .00128 Mdot
.50964 .00409 Mdot
.53071 .01302 Mdot
.59756 .04132 Mdot
.80177 .1262 Mdot
.23219 .26601 Mdot
.42537 .11939 Mdot
.51065 .05271 Mdot
.6119 .06258 Mdot
.86751 .15798 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50795 .00337 Mdot
.52531 .01073 Mdot
.58048 .0341 Mdot
.75129 .10556 Mdot
.16082 .2531 Mdot
.36813 .12812 Mdot
.3995 .01939 Mdot
.28993 .55032 Mdot
.94911 .40739 Mdot
.68333 .45377 Mdot
.49741 .61693 Mdot
.49174 .61453 Mdot
.47368 .60688 Mdot
.41634 .58259 Mdot
.23919 .50855 Mdot
.82386 .36135 Mdot
.62202 .49329 Mdot
.58579 .59564 Mdot
.6721 .05334 Mdot
.96911 .18356 Mdot
.31217 .21202 Mdot
.50024 .0001 Mdot
.50076 .00032 Mdot
.50242 .00103 Mdot
.50772 .00328 Mdot
.5246 .01043 Mdot
.57824 .03315 Mdot
.74456 .10279 Mdot
.14948 .25025 Mdot
.36172 .13117 Mdot
.39166 .01851 Mdot
.27136 .54368 Mdot
.91448 .39747 Mdot
.49981 .61795 Mdot
.49939 .61777 Mdot
.49805 .61721 Mdot
.49378 .6154 Mdot
.48019 .60963 Mdot
.43695 .59131 Mdot
.3016 .53438 Mdot
.93995 .39452 Mdot
.66625 .44888 Mdot
.599 .57647 Mdot
.67084 .0444 Mdot
.50061 .00026 Mdot
.50193 .00082 Mdot
.50616 .00261 Mdot
.51962 .00832 Mdot
.56243 .02646 Mdot
.69651 .08286 Mdot
.05596 .22215 Mdot
.33319 .17134 Mdot
.40357 .0435 Mdot
.33799 .5775 Mdot
.06924 .45194 Mdot
.69988 .38976 Mdot
.49918 .61769 Mdot
.49738 .61692 Mdot
.49166 .6145 Mdot
.47342 .60676 Mdot
.41551 .58224 Mdot
.23673 .50754 Mdot
.82005 .36051 Mdot
.61934 .49399 Mdot
.58135 .59455 Mdot
.66014 .04869 Mdot
.9406 .17334 Mdot
.49824 .61729 Mdot
.49439 .61566 Mdot
.48214 .61046 Mdot
.44316 .59394 Mdot
.32071 .54236 Mdot
.9827 .40914 Mdot
.67059 .42514 Mdot
.56811 .5547 Mdot
.5647 .61593 Mdot
.6557 .05624 Mdot
.94473 .17863 Mdot
.50025 .00011 Mdot
.5008 .00034 Mdot
.50256 .00108 Mdot
.50814 .00345 Mdot
.52594 .011 Mdot
.58249 .03494 Mdot
.75729 .10804 Mdot
.17058 .25543 Mdot
.37425 .12587 Mdot
.40831 .02105 Mdot
.31231 .55871 Mdot
.99565 .42232 Mdot
.5008 .00034 Mdot
.50254 .00108 Mdot
.5081 .00343 Mdot
.5258 .01094 Mdot
.58203 .03475 Mdot
.75594 .10748 Mdot
.16842 .25492 Mdot
.37284 .12634 Mdot
.40618 .02061 Mdot
.30681 .55662 Mdot
.98376 .41838 Mdot
.68502 .4334 Mdot
.49834 .61733 Mdot
.4947 .61578 Mdot
.4831 .61087 Mdot
.44621 .59523 Mdot
.33016 .54631 Mdot
.00501 .41708 Mdot
.67235 .41244 Mdot
.55057 .54277 Mdot
.50338 .58887 Mdot
.46125 .592 Mdot
.36157 .55643 Mdot
.49825 .61729 Mdot
.49441 .61566 Mdot
.4822 .61049 Mdot
.44334 .59402 Mdot
.32128 .5426 Mdot
.98404 .40961 Mdot
.6707 .42438 Mdot
.56705 .55398 Mdot
.56104 .61432 Mdot
.64437 .0515 Mdot
.91575 .16772 Mdot
.50037 .00016 Mdot
.50119 .00051 Mdot
.5038 .00161 Mdot
.51212 .00514 Mdot
.53859 .01636 Mdot
.62239 .05179 Mdot
.8722 .15439 Mdot
.29377 .26054 Mdot
.48557 .11854 Mdot
.65575 .10518 Mdot
.02402 .2276 Mdot
.35639 .20542 Mdot
.50073 .00031 Mdot
.50234 .00099 Mdot
.50745 .00316 Mdot
.52373 .01006 Mdot
.57547 .03198 Mdot
.73623 .09935 Mdot
.13483 .24635 Mdot
.35452 .13578 Mdot
.38514 .01892 Mdot
.25803 .53948 Mdot
.8925 .39212 Mdot
.67623 .48437 Mdot
.49869 .61748 Mdot
.49583 .61626 Mdot
.48671 .6124 Mdot
.45767 .60009 Mdot
.36588 .56131 Mdot
.09589 .45117 Mdot
.69061 .36756 Mdot
.50764 .50495 Mdot
.33611 .51202 Mdot
.95994 .38555 Mdot
.64323 .4223 Mdot
.49772 .61707 Mdot
.49272 .61495 Mdot
.47681 .6082 Mdot
.42624 .58678 Mdot
.26896 .52083 Mdot
.87464 .37433 Mdot
.64951 .4789 Mdot
.61708 .59799 Mdot
.74486 .07897 Mdot
.11124 .22644 Mdot
.32402 .13151 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50564 .00239 Mdot
.51797 .00762 Mdot
.55721 .02425 Mdot
.68042 .07615 Mdot
.01992 .20982 Mdot
.32961 .1914 Mdot
.42983 .06194 Mdot
.42816 .617 Mdot
.32235 .55264 Mdot
.00205 .42008 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.4803 .60968 Mdot
.43731 .59146 Mdot
.30268 .53483 Mdot
.94229 .3953 Mdot
.66658 .44763 Mdot
.59754 .57537 Mdot
.66584 .04221 Mdot
.50049 .00021 Mdot
.50157 .00066 Mdot
.50499 .00212 Mdot
.51589 .00674 Mdot
.55059 .02145 Mdot
.65992 .06757 Mdot
.97074 .1921 Mdot
.32521 .21907 Mdot
.4671 .08769 Mdot
.55999 .05741 Mdot
.74076 .11172 Mdot
.15986 .25902 Mdot
.49824 .61729 Mdot
.49439 .61566 Mdot
.48214 .61046 Mdot
.44316 .59394 Mdot
.32072 .54236 Mdot
.98272 .40914 Mdot
.67059 .42513 Mdot
.56809 .55469 Mdot
.56465 .6159 Mdot
.65553 .05617 Mdot
.94432 .17848 Mdot
.49842 .61736 Mdot
.49496 .61589 Mdot
.48393 .61122 Mdot
.44884 .59635 Mdot
.33831 .54973 Mdot
.02487 .42432 Mdot
.67428 .40136 Mdot
.5359 .53251 Mdot
.45092 .56551 Mdot
.29348 .52073 Mdot
.90617 .37866 Mdot
.49785 .61712 Mdot
.49316 .61513 Mdot
.47821 .60879 Mdot
.43068 .58866 Mdot
.28242 .5264 Mdot
.90036 .38191 Mdot
.65819 .46837 Mdot
.61612 .59203 Mdot
.73318 .07235 Mdot
.08764 .21907 Mdot
.31718 .14187 Mdot
.49947 .61781 Mdot
.49831 .61732 Mdot
.4946 .61575 Mdot
.48281 .61075 Mdot
.44529 .59484 Mdot
.3273 .54511 Mdot
.99819 .41463 Mdot
.67179 .41631 Mdot
.55588 .5464 Mdot
.52209 .59715 Mdot
.52132 .61756 Mdot
.50015 6e-05 Mdot
.50046 .0002 Mdot
.50148 .00063 Mdot
.50471 .002 Mdot
.51501 .00637 Mdot
.54779 .02026 Mdot
.6512 .06391 Mdot
.94879 .18392 Mdot
.32188 .23058 Mdot
.48017 .09783 Mdot
.6088 .0795 Mdot
.88821 .17268 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50095 .0004 Mdot
.50304 .00129 Mdot
.50969 .00411 Mdot
.53086 .01309 Mdot
.59804 .04152 Mdot
.80316 .12677 Mdot
.23382 .26616 Mdot
.42697 .11938 Mdot
.51439 .05403 Mdot
.49799 .61718 Mdot
.49359 .61531 Mdot
.47956 .60937 Mdot
.43497 .59048 Mdot
.29553 .53186 Mdot
.92706 .39031 Mdot
.66421 .45558 Mdot
.60624 .5822 Mdot
.69604 .0555 Mdot
.011 .19465 Mdot
.30947 .18446 Mdot
.49943 .61779 Mdot
.4982 .61727 Mdot
.49426 .6156 Mdot
.4817 .61028 Mdot
.44177 .59335 Mdot
.31642 .54056 Mdot
.97283 .40568 Mdot
.6698 .43075 Mdot
.57582 .55995 Mdot
.59132 .00958 Mdot
.7364 .08966 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50743 .00315 Mdot
.52365 .01003 Mdot
.57523 .03188 Mdot
.7355 .09905 Mdot
.13352 .24599 Mdot
.35393 .13622 Mdot
.38474 .01904 Mdot
.25738 .53932 Mdot
.89153 .39193 Mdot
.67609 .48488 Mdot
.49766 .61704 Mdot
.49254 .61487 Mdot
.47624 .60796 Mdot
.42443 .58602 Mdot
.26349 .51857 Mdot
.86467 .37155 Mdot
.64525 .48243 Mdot
.6147 .59915 Mdot
.7417 .07849 Mdot
.1071 .22583 Mdot
.32371 .13387 Mdot
.49868 .61747 Mdot
.4958 .61625 Mdot
.48661 .61236 Mdot
.45736 .59996 Mdot
.36493 .5609 Mdot
.09334 .45019 Mdot
.68963 .36853 Mdot
.50769 .50559 Mdot
.33727 .51271 Mdot
.96313 .3868 Mdot
.6438 .42067 Mdot
.49763 .61703 Mdot
.49245 .61483 Mdot
.47594 .60783 Mdot
.42347 .58561 Mdot
.26057 .51736 Mdot
.85946 .37014 Mdot
.64282 .48414 Mdot
.61278 .59947 Mdot
.73812 .07746 Mdot
.10152 .22459 Mdot
.32276 .13673 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51485 .0063 Mdot
.54728 .02004 Mdot
.64958 .06323 Mdot
.94464 .18236 Mdot
.32108 .23265 Mdot
.4822 .09958 Mdot
.61668 .08311 Mdot
.91092 .18185 Mdot
.33191 .26019 Mdot
.49948 .61782 Mdot
.49836 .61734 Mdot
.49476 .61581 Mdot
.48331 .61096 Mdot
.44688 .59552 Mdot
.33223 .54718 Mdot
.01002 .41889 Mdot
.67279 .40961 Mdot
.54674 .54013 Mdot
.4898 .58284 Mdot
.41756 .57339 Mdot
.49877 .61751 Mdot
.49607 .61637 Mdot
.48747 .61272 Mdot
.46011 .60112 Mdot
.37354 .56453 Mdot
.11661 .45924 Mdot
.7 .36056 Mdot
.51044 .50088 Mdot
.33654 .51056 Mdot
.95834 .38429 Mdot
.64192 .42247 Mdot
.5006 .00026 Mdot
.50192 .00081 Mdot
.50612 .0026 Mdot
.5195 .00827 Mdot
.56205 .0263 Mdot
.69533 .08237 Mdot
.0534 .2213 Mdot
.33286 .17272 Mdot
.40523 .04472 Mdot
.34368 .58 Mdot
.08358 .45728 Mdot
.70379 .38331 Mdot
.50018 8e-05 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.50598 .00254 Mdot
.51905 .00808 Mdot
.56064 .0257 Mdot
.691 .08057 Mdot
.04388 .21809 Mdot
.33177 .17792 Mdot
.41174 .04943 Mdot
.36602 .58977 Mdot
.14223 .47973 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50292 .00124 Mdot
.50931 .00395 Mdot
.52966 .01258 Mdot
.59425 .03992 Mdot
.7921 .12228 Mdot
.22038 .26469 Mdot
.41405 .11969 Mdot
.48497 .04383 Mdot
.53337 .02991 Mdot
.63145 .06062 Mdot
.49906 .61763 Mdot
.49699 .61676 Mdot
.49041 .61397 Mdot
.46945 .60508 Mdot
.40295 .57693 Mdot
.19972 .49243 Mdot
.76958 .35219 Mdot
.57636 .49862 Mdot
.49334 .56673 Mdot
.40034 .56056 Mdot
.16744 .47409 Mdot
.50019 8e-05 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50612 .0026 Mdot
.51951 .00827 Mdot
.56209 .02632 Mdot
.69546 .08243 Mdot
.05369 .2214 Mdot
.3329 .17256 Mdot
.40504 .04458 Mdot
.34303 .57971 Mdot
.08193 .45667 Mdot
.50008 3e-05 Mdot
.50025 .0001 Mdot
.50079 .00033 Mdot
.5025 .00106 Mdot
.50798 .00338 Mdot
.52541 .01077 Mdot
.58079 .03423 Mdot
.75221 .10595 Mdot
.16234 .25348 Mdot
.36905 .12775 Mdot
.40074 .01959 Mdot
.29302 .55146 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50565 .0024 Mdot
.51801 .00763 Mdot
.55731 .02429 Mdot
.68073 .07628 Mdot
.02062 .21007 Mdot
.32967 .191 Mdot
.42927 .06156 Mdot
.42625 .61616 Mdot
.31651 .55021 Mdot
.98859 .41537 Mdot
.50059 .00025 Mdot
.50187 .00079 Mdot
.50597 .00253 Mdot
.51902 .00806 Mdot
.56052 .02565 Mdot
.69064 .08042 Mdot
.04307 .21782 Mdot
.33168 .17837 Mdot
.41232 .04984 Mdot
.36799 .59064 Mdot
.14758 .48181 Mdot
.73619 .36378 Mdot
.50052 .00022 Mdot
.50166 .00071 Mdot
.5053 .00225 Mdot
.5169 .00717 Mdot
.55379 .0228 Mdot
.66986 .07173 Mdot
.99501 .20096 Mdot
.32765 .20558 Mdot
.44941 .07525 Mdot
.49655 .02914 Mdot
.53852 .02594 Mdot
.63772 .06131 Mdot
.49938 .61777 Mdot
.49802 .61719 Mdot
.49369 .61536 Mdot
.47991 .60951 Mdot
.43607 .59094 Mdot
.29888 .53325 Mdot
.93414 .39261 Mdot
.66539 .45194 Mdot
.60243 .57912 Mdot
.68272 .04962 Mdot
.98074 .18418 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50741 .00314 Mdot
.52361 .01001 Mdot
.57508 .03181 Mdot
.73504 .09886 Mdot
.13268 .24575 Mdot
.35356 .13651 Mdot
.3845 .01912 Mdot
.257 .53923 Mdot
.891 .39183 Mdot
.50044 .00019 Mdot
.50139 .00059 Mdot
.50444 .00188 Mdot
.51414 .006 Mdot
.54503 .01909 Mdot
.64257 .06028 Mdot
.92648 .17547 Mdot
.31679 .24123 Mdot
.48909 .10648 Mdot
.64503 .09638 Mdot
.98963 .21298 Mdot
.34978 .22258 Mdot
.49957 .61785 Mdot
.49863 .61745 Mdot
.49563 .61618 Mdot
.48607 .61212 Mdot
.45563 .59922 Mdot
.35949 .55862 Mdot
.07893 .44464 Mdot
.68476 .37443 Mdot
.50956 .50975 Mdot
.34868 .51861 Mdot
.9935 .39852 Mdot
.50048 .00021 Mdot
.50154 .00065 Mdot
.50491 .00208 Mdot
.51565 .00664 Mdot
.54982 .02112 Mdot
.65752 .06656 Mdot
.96477 .18989 Mdot
.32443 .22228 Mdot
.471 .09058 Mdot
.57431 .06385 Mdot
.78507 .13026 Mdot
.22879 .27424 Mdot
.49801 .61719 Mdot
.49366 .61534 Mdot
.47979 .60946 Mdot
.43569 .59078 Mdot
.29772 .53276 Mdot
.93166 .3918 Mdot
.66499 .45322 Mdot
.60381 .58022 Mdot
.68753 .05174 Mdot
.99182 .18806 Mdot
.30838 .19564 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50791 .00336 Mdot
.5252 .01069 Mdot
.58014 .03395 Mdot
.75028 .10515 Mdot
.15916 .2527 Mdot
.36714 .12854 Mdot
.39819 .01919 Mdot
.28673 .54915 Mdot
.94286 .40551 Mdot
.49751 .61698 Mdot
.49206 .61467 Mdot
.4747 .60731 Mdot
.41957 .58396 Mdot
.24885 .51253 Mdot
.83941 .36498 Mdot
.63201 .48985 Mdot
.60068 .59868 Mdot
.71051 .06788 Mdot
.05177 .21091 Mdot
.31673 .16376 Mdot
.50058 .00024 Mdot
.50184 .00078 Mdot
.50586 .00248 Mdot
.51866 .00791 Mdot
.55939 .02517 Mdot
.68715 .07896 Mdot
.03527 .21515 Mdot
.33092 .18272 Mdot
.41802 .05384 Mdot
.38753 .59919 Mdot
.20204 .50339 Mdot
.78857 .3625 Mdot
.49772 .61707 Mdot
.49274 .61496 Mdot
.47688 .60823 Mdot
.42647 .58688 Mdot
.26965 .52111 Mdot
.87591 .37469 Mdot
.65001 .47842 Mdot
.61726 .5978 Mdot
.74493 .0789 Mdot
.1112 .22637 Mdot
.32392 .13147 Mdot
.49947 .61781 Mdot
.49832 .61732 Mdot
.49463 .61576 Mdot
.4829 .61078 Mdot
.44556 .59496 Mdot
.32816 .54547 Mdot
.00024 .41537 Mdot
.67196 .41515 Mdot
.55428 .54531 Mdot
.51646 .59466 Mdot
.50329 .60989 Mdot
.50079 .00033 Mdot
.50251 .00106 Mdot
.50798 .00339 Mdot
.52543 .01078 Mdot
.58087 .03426 Mdot
.75245 .10605 Mdot
.16274 .25357 Mdot
.36929 .12765 Mdot
.40108 .01965 Mdot
.29386 .55177 Mdot
.95692 .40979 Mdot
.68381 .44924 Mdot
.49775 .61708 Mdot
.49283 .61499 Mdot
.47715 .60834 Mdot
.42731 .58723 Mdot
.27218 .52216 Mdot
.88064 .37605 Mdot
.65182 .47661 Mdot
.61773 .59696 Mdot
.74456 .07839 Mdot
.10999 .22585 Mdot
.32325 .1318 Mdot
.50027 .00012 Mdot
.50087 .00037 Mdot
.50276 .00117 Mdot
.50879 .00373 Mdot
.52799 .01187 Mdot
.58896 .03768 Mdot
.77653 .11592 Mdot
.19952 .26142 Mdot
.39569 .12124 Mdot
.44636 .03131 Mdot
.41807 .60055 Mdot
.27225 .52791 Mdot
.49808 .61722 Mdot
.49388 .61544 Mdot
.48049 .60976 Mdot
.43792 .59172 Mdot
.30456 .53562 Mdot
.94637 .39666 Mdot
.66711 .44544 Mdot
.59492 .57342 Mdot
.65683 .03826 Mdot
.91772 .16124 Mdot
.29661 .23416 Mdot
.49796 .61717 Mdot
.49349 .61527 Mdot
.47927 .60924 Mdot
.43404 .59008 Mdot
.29269 .53067 Mdot
.92115 .38841 Mdot
.6631 .45855 Mdot
.60908 .58465 Mdot
.70616 .06 Mdot
.03297 .20198 Mdot
.31068 .17164 Mdot
.49979 .61794 Mdot
.49932 .61775 Mdot
.49783 .61711 Mdot
.49309 .61511 Mdot
.478 .60871 Mdot
.43001 .58838 Mdot
.28039 .52556 Mdot
.89637 .3807 Mdot
.65705 .47012 Mdot
.61688 .59321 Mdot
.73668 .07405 Mdot
.50081 .00034 Mdot
.50258 .00109 Mdot
.50821 .00348 Mdot
.52614 .01108 Mdot
.5831 .0352 Mdot
.75913 .10879 Mdot
.17349 .25609 Mdot
.37618 .12527 Mdot
.41132 .02172 Mdot
.32022 .56173 Mdot
.01326 .42832 Mdot
.68643 .41604 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50526 .00223 Mdot
.51675 .0071 Mdot
.55332 .0226 Mdot
.66837 .07111 Mdot
.99145 .19967 Mdot
.32734 .2076 Mdot
.45215 .07713 Mdot
.50625 .03344 Mdot
.56972 .03923 Mdot
.73447 .10182 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.49941 .61778 Mdot
.49811 .61723 Mdot
.49397 .61548 Mdot
.4808 .60989 Mdot
.4389 .59214 Mdot
.30757 .53687 Mdot
.95296 .39887 Mdot
.66789 .44185 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.522 .00933 Mdot
.56997 .02965 Mdot
.71957 .09245 Mdot
.10354 .23731 Mdot
.34293 .14795 Mdot
.38314 .02485 Mdot
.26339 .54402 Mdot
.90575 .397 Mdot
.68137 .47936 Mdot
.49817 .61726 Mdot
.49418 .61557 Mdot
.48147 .61018 Mdot
.44102 .59304 Mdot
.31412 .5396 Mdot
.96759 .40387 Mdot
.66934 .43371 Mdot
.57982 .56271 Mdot
.60508 .01561 Mdot
.77675 .1061 Mdot
.18379 .25156 Mdot
.50075 .00032 Mdot
.5024 .00102 Mdot
.50766 .00325 Mdot
.5244 .01034 Mdot
.57758 .03287 Mdot
.74259 .10198 Mdot
.14608 .24937 Mdot
.35994 .13217 Mdot
.3898 .01845 Mdot
.26725 .54229 Mdot
.90736 .39561 Mdot
.67872 .47673 Mdot
.5003 .00013 Mdot
.50094 .0004 Mdot
.50301 .00128 Mdot
.50958 .00406 Mdot
.53052 .01294 Mdot
.59696 .04106 Mdot
.80002 .1255 Mdot
.23012 .26581 Mdot
.42334 .11942 Mdot
.50597 .05107 Mdot
.59755 .0566 Mdot
.82645 .14147 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.50051 .00022 Mdot
.50164 .00069 Mdot
.50521 .00221 Mdot
.51661 .00704 Mdot
.55286 .02241 Mdot
.66696 .07052 Mdot
.98803 .19843 Mdot
.32704 .20952 Mdot
.45474 .07892 Mdot
.51545 .03752 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50073 .00031 Mdot
.50232 .00098 Mdot
.50738 .00313 Mdot
.5235 .00996 Mdot
.57473 .03167 Mdot
.734 .09843 Mdot
.13079 .24523 Mdot
.35274 .13718 Mdot
.38401 .01932 Mdot
.49838 .61735 Mdot
.49485 .61585 Mdot
.48359 .61108 Mdot
.44776 .59589 Mdot
.33496 .54832 Mdot
.01665 .42131 Mdot
.67341 .4059 Mdot
.54179 .53669 Mdot
.47212 .57498 Mdot
.36086 .54927 Mdot
.06648 .43609 Mdot
.49875 .6175 Mdot
.49601 .61634 Mdot
.48729 .61264 Mdot
.45952 .60087 Mdot
.37167 .56374 Mdot
.11153 .45726 Mdot
.69745 .36212 Mdot
.50921 .50169 Mdot
.33478 .51023 Mdot
.95469 .38313 Mdot
.64165 .42457 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50397 .00168 Mdot
.51265 .00537 Mdot
.5403 .01708 Mdot
.62774 .05404 Mdot
.88688 .16015 Mdot
.30177 .25642 Mdot
.49044 .11661 Mdot
.66479 .10775 Mdot
.04445 .23465 Mdot
.3583 .19397 Mdot
.49944 .61779 Mdot
.4982 .61727 Mdot
.49427 .6156 Mdot
.48175 .61029 Mdot
.44191 .59341 Mdot
.31685 .54075 Mdot
.97382 .40603 Mdot
.66988 .43019 Mdot
.57505 .55943 Mdot
.58868 .00842 Mdot
.72855 .08644 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .00099 Mdot
.50747 .00317 Mdot
.5238 .01009 Mdot
.57571 .03208 Mdot
.73695 .09965 Mdot
.13612 .2467 Mdot
.35511 .13534 Mdot
.38556 .01882 Mdot
.25876 .53967 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48592 .61206 Mdot
.45516 .59903 Mdot
.35804 .55801 Mdot
.0751 .44317 Mdot
.68365 .3761 Mdot
.51048 .51101 Mdot
.35302 .52072 Mdot
.00512 .40302 Mdot
.64954 .39828 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.50648 .00275 Mdot
.52066 .00876 Mdot
.56573 .02786 Mdot
.70663 .08708 Mdot
.07745 .22918 Mdot
.33663 .16018 Mdot
.39157 .03396 Mdot
.29616 .55907 Mdot
.97198 .41768 Mdot
.68962 .44353 Mdot
.49909 .61765 Mdot
.49709 .6168 Mdot
.49072 .6141 Mdot
.47045 .6055 Mdot
.4061 .57826 Mdot
.20893 .49617 Mdot
.78093 .35352 Mdot
.58717 .49828 Mdot
.51772 .57511 Mdot
.4748 .59151 Mdot
.39425 .56825 Mdot
.49813 .61724 Mdot
.49405 .61551 Mdot
.48105 .61 Mdot
.43968 .59247 Mdot
.30997 .53787 Mdot
.95829 .40068 Mdot
.66846 .43891 Mdot
.5867 .56751 Mdot
.62866 .02593 Mdot
.84327 .13264 Mdot
.25678 .25556 Mdot
.49873 .6175 Mdot
.49597 .61632 Mdot
.48715 .61258 Mdot
.45908 .60069 Mdot
.3703 .56317 Mdot
.1078 .4558 Mdot
.69568 .36333 Mdot
.50853 .50237 Mdot
.33417 .51027 Mdot
.95369 .38289 Mdot
.6417 .42521 Mdot
.50052 .00022 Mdot
.50166 .0007 Mdot
.50529 .00224 Mdot
.51685 .00714 Mdot
.55363 .02273 Mdot
.66934 .07151 Mdot
.99377 .20051 Mdot
.32754 .20629 Mdot
.45037 .07591 Mdot
.49995 .03064 Mdot
.54945 .03059 Mdot
.67193 .0757 Mdot
.50027 .00011 Mdot
.50085 .00036 Mdot
.5027 .00115 Mdot
.5086 .00365 Mdot
.52741 .01162 Mdot
.58712 .0369 Mdot
.77109 .1137 Mdot
.19169 .25995 Mdot
.38941 .12219 Mdot
.43427 .02773 Mdot
.38332 .58654 Mdot
.1726 .4878 Mdot
.49743 .61694 Mdot
.4918 .61456 Mdot
.47389 .60696 Mdot
.41699 .58287 Mdot
.24114 .50935 Mdot
.82693 .36204 Mdot
.6241 .49268 Mdot
.58912 .59642 Mdot
.68095 .05675 Mdot
.9894 .19063 Mdot
.31374 .20045 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61007 Mdot
.44021 .59269 Mdot
.31161 .53856 Mdot
.96195 .40193 Mdot
.66882 .43687 Mdot
.58404 .56563 Mdot
.61953 .02194 Mdot
.81794 .12262 Mdot
.23366 .25693 Mdot
.49925 .61771 Mdot
.4976 .61702 Mdot
.49235 .61479 Mdot
.47562 .6077 Mdot
.42246 .58518 Mdot
.25754 .51611 Mdot
.85415 .36873 Mdot
.64018 .48579 Mdot
.61032 .59958 Mdot
.73301 .07583 Mdot
.09307 .22253 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50287 .00122 Mdot
.50913 .00387 Mdot
.52908 .01233 Mdot
.59242 .03914 Mdot
.78672 .12008 Mdot
.21343 .26372 Mdot
.40768 .12005 Mdot
.47108 .03919 Mdot
.49135 .01253 Mdot
.49865 .00451 Mdot
.4984 .61736 Mdot
.49492 .61588 Mdot
.48381 .61117 Mdot
.44844 .59618 Mdot
.33709 .54922 Mdot
.02187 .42322 Mdot
.67395 .403 Mdot
.53801 .53402 Mdot
.45854 .56892 Mdot
.31759 .53092 Mdot
.95912 .39649 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50807 .00342 Mdot
.5257 .0109 Mdot
.58171 .03461 Mdot
.75496 .10708 Mdot
.16683 .25455 Mdot
.37183 .1267 Mdot
.40469 .02031 Mdot
.30298 .55517 Mdot
.97564 .41573 Mdot
.49971 .61791 Mdot
.49906 .61764 Mdot
.49702 .61677 Mdot
.4905 .614 Mdot
.46973 .6052 Mdot
.40382 .5773 Mdot
.20226 .49346 Mdot
.77262 .35251 Mdot
.57932 .49856 Mdot
.50012 .56909 Mdot
.4211 .5692 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50317 .00134 Mdot
.51009 .00428 Mdot
.53213 .01362 Mdot
.60205 .04321 Mdot
.81478 .13147 Mdot
.24673 .26696 Mdot
.44 .11945 Mdot
.5454 .06514 Mdot
.49863 .61745 Mdot
.49563 .61618 Mdot
.48607 .61213 Mdot
.45566 .59923 Mdot
.35958 .55866 Mdot
.07916 .44472 Mdot
.68483 .37433 Mdot
.50951 .50968 Mdot
.34844 .51849 Mdot
.99286 .39827 Mdot
.64799 .40489 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50789 .00335 Mdot
.52515 .01066 Mdot
.57997 .03388 Mdot
.74976 .10494 Mdot
.15828 .25248 Mdot
.36663 .12877 Mdot
.39752 .01909 Mdot
.28511 .54856 Mdot
.93974 .40459 Mdot
.68262 .45912 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.50692 .00293 Mdot
.52205 .00935 Mdot
.57014 .02972 Mdot
.72006 .09266 Mdot
.10451 .2376 Mdot
.34322 .14753 Mdot
.38298 .02458 Mdot
.26262 .54364 Mdot
.90427 .39656 Mdot
.68101 .48006 Mdot
.4974 .61693 Mdot
.49171 .61452 Mdot
.4736 .60684 Mdot
.41608 .58248 Mdot
.23843 .50824 Mdot
.82268 .36109 Mdot
.6212 .49351 Mdot
.58445 .59532 Mdot
.6685 .05195 Mdot
.96067 .18057 Mdot
.31123 .21666 Mdot
.49762 .61702 Mdot
.49241 .61482 Mdot
.47582 .60778 Mdot
.4231 .58545 Mdot
.25947 .5169 Mdot
.85752 .36962 Mdot
.64187 .48475 Mdot
.61194 .59954 Mdot
.73642 .07693 Mdot
.09877 .22394 Mdot
.32229 .13814 Mdot
.50035 .00015 Mdot
.5011 .00047 Mdot
.50351 .00149 Mdot
.5112 .00475 Mdot
.53566 .01512 Mdot
.61317 .0479 Mdot
.84649 .1442 Mdot
.276 .26545 Mdot
.46995 .11987 Mdot
.61908 .09217 Mdot
.93063 .19255 Mdot
.34297 .25484 Mdot
.4983 .61731 Mdot
.49458 .61573 Mdot
.48273 .61071 Mdot
.44502 .59473 Mdot
.32647 .54477 Mdot
.99623 .41393 Mdot
.67164 .41743 Mdot
.55743 .54745 Mdot
.5275 .59954 Mdot
.53861 .00687 Mdot
.60708 .04231 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50188 .0008 Mdot
.506 .00254 Mdot
.5191 .0081 Mdot
.56079 .02577 Mdot
.69148 .08077 Mdot
.04493 .21845 Mdot
.33188 .17734 Mdot
.411 .0489 Mdot
.36348 .58866 Mdot
.13537 .47706 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50142 .0006 Mdot
.50451 .00191 Mdot
.51438 .0061 Mdot
.5458 .01942 Mdot
.64496 .06129 Mdot
.93273 .17785 Mdot
.31843 .23837 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.49861 .61744 Mdot
.49557 .61616 Mdot
.48589 .61205 Mdot
.45508 .59899 Mdot
.35777 .55789 Mdot
.07439 .4429 Mdot
.68345 .37642 Mdot
.51067 .51125 Mdot
.35388 .52113 Mdot
.49889 .61756 Mdot
.49646 .61653 Mdot
.48873 .61326 Mdot
.46412 .60282 Mdot
.38615 .56984 Mdot
.15159 .47307 Mdot
.7225 .35284 Mdot
.52859 .49819 Mdot
.37734 .52456 Mdot
.05978 .42177 Mdot
.65464 .36765 Mdot
.49888 .61756 Mdot
.49642 .61652 Mdot
.48861 .6132 Mdot
.46371 .60265 Mdot
.38485 .56929 Mdot
.14794 .47162 Mdot
.71972 .35338 Mdot
.52594 .49827 Mdot
.37088 .5222 Mdot
.0427 .41521 Mdot
.65124 .3761 Mdot
.49925 .61772 Mdot
.49762 .61703 Mdot
.49243 .61482 Mdot
.47587 .6078 Mdot
.42327 .58552 Mdot
.25998 .51712 Mdot
.85843 .36986 Mdot
.64232 .48447 Mdot
.61235 .59951 Mdot
.73724 .07719 Mdot
.10011 .22426 Mdot
.4985 .6174 Mdot
.49523 .61601 Mdot
.48479 .61159 Mdot
.45158 .59751 Mdot
.34686 .55331 Mdot
.04626 .43226 Mdot
.67725 .38997 Mdot
.52245 .52237 Mdot
.40122 .54311 Mdot
.14116 .45731 Mdot
.69604 .34294 Mdot
.49986 .61797 Mdot
.49955 .61784 Mdot
.49856 .61742 Mdot
.4954 .61608 Mdot
.48534 .61182 Mdot
.45333 .59825 Mdot
.35231 .5556 Mdot
.06022 .43751 Mdot
.67994 .38301 Mdot
.51562 .51648 Mdot
.3747 .53094 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.50209 .00089 Mdot
.50667 .00283 Mdot
.52125 .00901 Mdot
.5676 .02865 Mdot
.71234 .08945 Mdot
.08916 .23289 Mdot
.33913 .15449 Mdot
.38682 .02948 Mdot
.2787 .55121 Mdot
.93571 .40606 Mdot
.4992 .61769 Mdot
.49745 .61695 Mdot
.49187 .61459 Mdot
.47411 .60706 Mdot
.41768 .58316 Mdot
.24321 .5102 Mdot
.83022 .36279 Mdot
.62628 .49199 Mdot
.59249 .59715 Mdot
.68976 .06011 Mdot
.00885 .19721 Mdot
.49773 .61707 Mdot
.49275 .61496 Mdot
.47691 .60825 Mdot
.42657 .58692 Mdot
.26994 .52123 Mdot
.87646 .37485 Mdot
.65023 .47822 Mdot
.61734 .59771 Mdot
.74494 .07886 Mdot
.11115 .22633 Mdot
.32386 .13147 Mdot
.49798 .61718 Mdot
.49358 .61531 Mdot
.47954 .60936 Mdot
.43491 .59045 Mdot
.29533 .53177 Mdot
.92664 .39017 Mdot
.66413 .4558 Mdot
.60645 .58238 Mdot
.6968 .05584 Mdot
.01267 .19522 Mdot
.30955 .18349 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.5076 .00322 Mdot
.5242 .01026 Mdot
.57698 .03262 Mdot
.74077 .10123 Mdot
.14289 .24852 Mdot
.35833 .13315 Mdot
.38824 .01849 Mdot
.26396 .54122 Mdot
.90186 .39424 Mdot
.67782 .47957 Mdot
.49817 .61726 Mdot
.49416 .61556 Mdot
.4814 .61015 Mdot
.4408 .59294 Mdot
.31345 .53932 Mdot
.96608 .40335 Mdot
.66921 .43456 Mdot
.58097 .5635 Mdot
.609 .01733 Mdot
.78806 .11066 Mdot
.19905 .25401 Mdot
.49956 .61785 Mdot
.49859 .61744 Mdot
.49551 .61613 Mdot
.48571 .61197 Mdot
.45448 .59874 Mdot
.35592 .55712 Mdot
.06956 .44106 Mdot
.68215 .3786 Mdot
.51211 .51294 Mdot
.36022 .52416 Mdot
.0246 .41061 Mdot
.50028 .00012 Mdot
.50091 .00038 Mdot
.50289 .00122 Mdot
.50919 .0039 Mdot
.52928 .01242 Mdot
.59305 .03941 Mdot
.78857 .12084 Mdot
.21585 .26407 Mdot
.40987 .11991 Mdot
.47581 .04075 Mdot
.50561 .01842 Mdot
.54382 .02361 Mdot
.49966 .61789 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.48899 .61337 Mdot
.46495 .60317 Mdot
.38874 .57094 Mdot
.15891 .47599 Mdot
.72839 .35196 Mdot
.53441 .49815 Mdot
.39165 .5298 Mdot
.09862 .43693 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52199 .00933 Mdot
.56996 .02965 Mdot
.71953 .09244 Mdot
.10347 .23729 Mdot
.34291 .14798 Mdot
.38315 .02487 Mdot
.26344 .54405 Mdot
.90586 .39703 Mdot
.68139 .47931 Mdot
.49971 .61791 Mdot
.49907 .61764 Mdot
.49703 .61677 Mdot
.49053 .61402 Mdot
.46985 .60525 Mdot
.4042 .57746 Mdot
.20339 .49392 Mdot
.774 .35266 Mdot
.58064 .49853 Mdot
.50313 .57013 Mdot
.43032 .57303 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50434 .00184 Mdot
.51381 .00586 Mdot
.54398 .01864 Mdot
.63928 .0589 Mdot
.91784 .17216 Mdot
.31424 .24499 Mdot
.49109 .1093 Mdot
.65457 .10104 Mdot
.01515 .22285 Mdot
.35304 .20883 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60202 Mdot
.38022 .56734 Mdot
.13501 .46649 Mdot
.71072 .35581 Mdot
.51792 .49888 Mdot
.35195 .51546 Mdot
.99458 .39717 Mdot
.5006 .00026 Mdot
.50192 .00082 Mdot
.50612 .0026 Mdot
.51951 .00827 Mdot
.56208 .02631 Mdot
.69543 .08242 Mdot
.05362 .22137 Mdot
.33289 .1726 Mdot
.40508 .04462 Mdot
.34319 .57978 Mdot
.08234 .45682 Mdot
.70342 .38384 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50392 .00166 Mdot
.5125 .0053 Mdot
.53981 .01688 Mdot
.62621 .0534 Mdot
.8827 .15852 Mdot
.29964 .25768 Mdot
.48936 .11726 Mdot
.66313 .1074 Mdot
.04095 .2335 Mdot
.35802 .19596 Mdot
.50014 6e-05 Mdot
.50044 .00018 Mdot
.50139 .00059 Mdot
.50442 .00187 Mdot
.51407 .00597 Mdot
.5448 .01899 Mdot
.64185 .05998 Mdot
.92461 .17475 Mdot
.31627 .24206 Mdot
.4896 .10712 Mdot
.64732 .09748 Mdot
.9958 .21537 Mdot
.50052 .00022 Mdot
.50167 .00071 Mdot
.50532 .00226 Mdot
.51695 .00719 Mdot
.55396 .02287 Mdot
.67036 .07194 Mdot
.99622 .20139 Mdot
.32775 .2049 Mdot
.44848 .07461 Mdot
.49327 .02768 Mdot
.52796 .02144 Mdot
.60436 .04722 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.4927 .61494 Mdot
.47675 .60817 Mdot
.42604 .5867 Mdot
.26835 .52057 Mdot
.87351 .37401 Mdot
.64905 .47931 Mdot
.61689 .59816 Mdot
.74473 .07901 Mdot
.11117 .22647 Mdot
.49874 .6175 Mdot
.49599 .61633 Mdot
.48722 .61262 Mdot
.45931 .60078 Mdot
.37102 .56347 Mdot
.10975 .45656 Mdot
.6966 .36269 Mdot
.50886 .50201 Mdot
.33442 .51022 Mdot
.95404 .38295 Mdot
.64165 .42497 Mdot
.49892 .61757 Mdot
.49655 .61657 Mdot
.48901 .61337 Mdot
.46501 .6032 Mdot
.38893 .57102 Mdot
.15945 .47621 Mdot
.72884 .3519 Mdot
.53486 .49815 Mdot
.39276 .53021 Mdot
.1017 .43815 Mdot
.66826 .35016 Mdot
.50005 2e-05 Mdot
.50017 7e-05 Mdot
.50053 .00022 Mdot
.50168 .00071 Mdot
.50534 .00227 Mdot
.51702 .00722 Mdot
.55419 .02297 Mdot
.67109 .07225 Mdot
.99798 .20203 Mdot
.3279 .2039 Mdot
.44711 .07368 Mdot
.48845 .02555 Mdot
.4974 .61693 Mdot
.49172 .61452 Mdot
.47361 .60684 Mdot
.4161 .58249 Mdot
.2385 .50827 Mdot
.82279 .36111 Mdot
.62127 .49349 Mdot
.58457 .59535 Mdot
.66883 .05208 Mdot
.96144 .18084 Mdot
.31133 .21624 Mdot
.49761 .61702 Mdot
.49239 .61481 Mdot
.47577 .60776 Mdot
.42293 .58538 Mdot
.25894 .51669 Mdot
.8566 .36937 Mdot
.64141 .48504 Mdot
.61152 .59956 Mdot
.73555 .07666 Mdot
.09733 .22359 Mdot
.32205 .13888 Mdot
.50053 .00022 Mdot
.50169 .00072 Mdot
.50538 .00228 Mdot
.51712 .00726 Mdot
.55451 .02311 Mdot
.67207 .07266 Mdot
.00032 .20287 Mdot
.32809 .20257 Mdot
.44528 .07243 Mdot
.48201 .0227 Mdot
.49183 .00606 Mdot
.48938 .61652 Mdot
.50067 .00028 Mdot
.50214 .00091 Mdot
.5068 .00289 Mdot
.52167 .00919 Mdot
.56895 .02922 Mdot
.71646 .09116 Mdot
.09742 .23544 Mdot
.3412 .15067 Mdot
.38439 .02669 Mdot
.26903 .54673 Mdot
.91664 .40024 Mdot
.68365 .47404 Mdot
.50026 .00011 Mdot
.50083 .00035 Mdot
.50264 .00112 Mdot
.5084 .00356 Mdot
.52676 .01135 Mdot
.58509 .03604 Mdot
.76504 .11122 Mdot
.18266 .2581 Mdot
.3826 .12357 Mdot
.42199 .02434 Mdot
.34899 .57292 Mdot
.08196 .453 Mdot
.50079 .00033 Mdot
.50251 .00107 Mdot
.50801 .0034 Mdot
.52551 .01082 Mdot
.58113 .03437 Mdot
.75322 .10636 Mdot
.164 .25388 Mdot
.37006 .12735 Mdot
.40216 .01984 Mdot
.29656 .55277 Mdot
.96238 .4115 Mdot
.6841 .44605 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50343 .00145 Mdot
.51092 .00463 Mdot
.53477 .01474 Mdot
.61035 .04671 Mdot
.83851 .14101 Mdot
.26943 .26632 Mdot
.46339 .11988 Mdot
.60292 .08623 Mdot
.88629 .17513 Mdot
.32608 .27181 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00321 Mdot
.52413 .01023 Mdot
.57675 .03252 Mdot
.74009 .10095 Mdot
.14169 .2482 Mdot
.35774 .13353 Mdot
.38771 .01852 Mdot
.26286 .54088 Mdot
.90007 .39381 Mdot
.67751 .48049 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.51081 .00458 Mdot
.53442 .0146 Mdot
.60927 .04626 Mdot
.83545 .13979 Mdot
.26677 .26657 Mdot
.46069 .11984 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50105 .00044 Mdot
.50334 .00141 Mdot
.51063 .00451 Mdot
.53386 .01436 Mdot
.60749 .04551 Mdot
.83037 .13775 Mdot
.26219 .26688 Mdot
.45597 .11977 Mdot
.58455 .07947 Mdot
.83406 .15421 Mdot
.49754 .61699 Mdot
.49217 .61471 Mdot
.47506 .60746 Mdot
.42069 .58443 Mdot
.25221 .51391 Mdot
.84502 .36638 Mdot
.63526 .4884 Mdot
.60485 .59924 Mdot
.72058 .07152 Mdot
.07097 .21655 Mdot
.3184 .15292 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50029 .00012 Mdot
.50092 .00039 Mdot
.50294 .00125 Mdot
.50936 .00397 Mdot
.52983 .01265 Mdot
.59477 .04014 Mdot
.79363 .1229 Mdot
.2223 .26493 Mdot
.41584 .11962 Mdot
.48896 .04519 Mdot
.50015 7e-05 Mdot
.50049 .00021 Mdot
.50157 .00067 Mdot
.50501 .00212 Mdot
.51596 .00677 Mdot
.5508 .02153 Mdot
.66056 .06783 Mdot
.97233 .19268 Mdot
.3254 .21821 Mdot
.46603 .08691 Mdot
.55609 .05566 Mdot
.72856 .10659 Mdot
.49799 .61718 Mdot
.49361 .61532 Mdot
.47964 .6094 Mdot
.43522 .59058 Mdot
.29628 .53217 Mdot
.92863 .39081 Mdot
.66448 .45478 Mdot
.60543 .58154 Mdot
.69321 .05425 Mdot
.00468 .1925 Mdot
.30913 .18816 Mdot
.49881 .61753 Mdot
.49621 .61642 Mdot
.48791 .61291 Mdot
.4615 .60171 Mdot
.3779 .56637 Mdot
.12859 .46395 Mdot
.70671 .3573 Mdot
.51478 .49942 Mdot
.34499 .5131 Mdot
.97774 .39106 Mdot
.64377 .41163 Mdot
.49783 .61711 Mdot
.49309 .6151 Mdot
.47798 .6087 Mdot
.42994 .58835 Mdot
.28018 .52548 Mdot
.89596 .38058 Mdot
.65692 .4703 Mdot
.61694 .59332 Mdot
.73701 .07421 Mdot
.09502 .22126 Mdot
.31882 .13831 Mdot
.50038 .00016 Mdot
.5012 .00051 Mdot
.50382 .00162 Mdot
.51217 .00516 Mdot
.53875 .01643 Mdot
.62288 .052 Mdot
.87356 .15493 Mdot
.29457 .2602 Mdot
.48615 .1184 Mdot
.65697 .10557 Mdot
.02688 .22862 Mdot
.35667 .20382 Mdot
.49939 .61778 Mdot
.49806 .61721 Mdot
.49381 .61541 Mdot
.48027 .60967 Mdot
.43721 .59142 Mdot
.3024 .53471 Mdot
.94167 .39509 Mdot
.66649 .44796 Mdot
.59793 .57566 Mdot
.66717 .04279 Mdot
.94353 .1708 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50319 .00135 Mdot
.51016 .00431 Mdot
.53237 .01372 Mdot
.6028 .04353 Mdot
.81693 .13234 Mdot
.24899 .26703 Mdot
.44232 .11949 Mdot
.55102 .06718 Mdot
.73494 .11367 Mdot
.15652 .26055 Mdot
.49879 .61752 Mdot
.49614 .6164 Mdot
.48769 .61282 Mdot
.46081 .60142 Mdot
.37573 .56545 Mdot
.12261 .4616 Mdot
.70323 .35885 Mdot
.51236 .50007 Mdot
.34002 .51152 Mdot
.96613 .38696 Mdot
.64266 .41812 Mdot
.49929 .61773 Mdot
.49774 .61708 Mdot
.4928 .61498 Mdot
.47706 .6083 Mdot
.42702 .58711 Mdot
.2713 .52179 Mdot
.87898 .37557 Mdot
.6512 .47726 Mdot
.61761 .59727 Mdot
.7448 .07861 Mdot
.11061 .22608 Mdot
.49802 .6172 Mdot
.4937 .61536 Mdot
.47992 .60952 Mdot
.4361 .59095 Mdot
.29898 .53329 Mdot
.93434 .39268 Mdot
.66542 .45183 Mdot
.60231 .57903 Mdot
.68232 .04944 Mdot
.97979 .18385 Mdot
.3075 .20254 Mdot
.49946 .6178 Mdot
.49827 .6173 Mdot
.49448 .61569 Mdot
.48242 .61058 Mdot
.44404 .59431 Mdot
.32343 .5435 Mdot
.98906 .41138 Mdot
.67108 .42152 Mdot
.56309 .55129 Mdot
.54728 .60826 Mdot
.60135 .03342 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.50398 .00169 Mdot
.51268 .00538 Mdot
.54039 .01713 Mdot
.62805 .05417 Mdot
.88771 .16048 Mdot
.30218 .25616 Mdot
.49063 .11647 Mdot
.66503 .10778 Mdot
.04493 .2348 Mdot
.35833 .19369 Mdot
.49926 .61772 Mdot
.49765 .61704 Mdot
.49252 .61486 Mdot
.47618 .60793 Mdot
.42424 .58594 Mdot
.26292 .51833 Mdot
.86364 .37127 Mdot
.64478 .48277 Mdot
.61436 .59923 Mdot
.7411 .07833 Mdot
.1062 .22564 Mdot
.49778 .61709 Mdot
.49293 .61504 Mdot
.47749 .60849 Mdot
.42839 .58769 Mdot
.27547 .52352 Mdot
.88687 .37786 Mdot
.65403 .47413 Mdot
.61782 .59565 Mdot
.74263 .07714 Mdot
.10592 .22453 Mdot
.3218 .13342 Mdot
.50012 5e-05 Mdot
.5004 .00017 Mdot
.50126 .00054 Mdot
.50403 .00171 Mdot
.51282 .00544 Mdot
.54084 .01731 Mdot
.62944 .05476 Mdot
.89149 .16196 Mdot
.30399 .25494 Mdot
.49135 .1158 Mdot
.66576 .10779 Mdot
.04623 .23514 Mdot
.50055 .00023 Mdot
.50174 .00074 Mdot
.50555 .00235 Mdot
.51768 .0075 Mdot
.55626 .02385 Mdot
.6775 .07493 Mdot
.01312 .20743 Mdot
.32908 .19528 Mdot
.43519 .06557 Mdot
.44673 .00714 Mdot
.37987 .57671 Mdot
.14943 .47561 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50339 .00144 Mdot
.51079 .00458 Mdot
.53437 .01457 Mdot
.60909 .04618 Mdot
.83493 .13958 Mdot
.26631 .26661 Mdot
.46021 .11984 Mdot
.59506 .08334 Mdot
.86416 .16631 Mdot
.31317 .2775 Mdot
.4979 .61714 Mdot
.49329 .61519 Mdot
.47864 .60898 Mdot
.43204 .58923 Mdot
.28657 .52813 Mdot
.90863 .38446 Mdot
.66035 .46458 Mdot
.61391 .58933 Mdot
.72411 .06811 Mdot
.06988 .2137 Mdot
.31417 .15098 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50621 .00263 Mdot
.51978 .00839 Mdot
.56293 .02667 Mdot
.69805 .08351 Mdot
.05929 .22326 Mdot
.33364 .16956 Mdot
.40147 .04192 Mdot
.33076 .57434 Mdot
.05141 .44538 Mdot
.69627 .39855 Mdot
.50062 .00026 Mdot
.50199 .00084 Mdot
.50634 .00269 Mdot
.52021 .00857 Mdot
.5643 .02725 Mdot
.70224 .08525 Mdot
.06825 .2262 Mdot
.33499 .16486 Mdot
.39624 .03785 Mdot
.31264 .56637 Mdot
.00856 .4301 Mdot
.69165 .42217 Mdot
.4984 .61736 Mdot
.49491 .61588 Mdot
.48379 .61116 Mdot
.44839 .59616 Mdot
.33692 .54914 Mdot
.02144 .42306 Mdot
.6739 .40324 Mdot
.53831 .53424 Mdot
.45965 .56941 Mdot
.32109 .5324 Mdot
.96723 .39934 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50627 .00266 Mdot
.51999 .00848 Mdot
.56361 .02696 Mdot
.70011 .08437 Mdot
.06372 .22472 Mdot
.33428 .16722 Mdot
.39881 .03988 Mdot
.32156 .5703 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50567 .0024 Mdot
.51805 .00766 Mdot
.55747 .02436 Mdot
.68121 .07648 Mdot
.02174 .21046 Mdot
.32976 .19036 Mdot
.4284 .06096 Mdot
.42322 .61483 Mdot
.30728 .54638 Mdot
.9679 .40829 Mdot
.49927 .61773 Mdot
.49768 .61705 Mdot
.49262 .6149 Mdot
.47648 .60806 Mdot
.4252 .58634 Mdot
.26581 .51952 Mdot
.86886 .37271 Mdot
.6471 .48098 Mdot
.61591 .59875 Mdot
.7436 .07892 Mdot
.10983 .22634 Mdot
.50017 7e-05 Mdot
.50054 .00023 Mdot
.50171 .00073 Mdot
.50545 .00231 Mdot
.51735 .00736 Mdot
.55524 .02342 Mdot
.67434 .0736 Mdot
.00569 .20479 Mdot
.32851 .19951 Mdot
.44106 .06956 Mdot
.46721 .01616 Mdot
.44451 .60401 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48618 .61217 Mdot
.45599 .59938 Mdot
.36062 .55909 Mdot
.0819 .44577 Mdot
.68568 .37316 Mdot
.50896 .50882 Mdot
.34568 .51712 Mdot
.98553 .39545 Mdot
.50011 5e-05 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00147 Mdot
.51108 .0047 Mdot
.53528 .01496 Mdot
.61197 .0474 Mdot
.84309 .14284 Mdot
.27326 .26586 Mdot
.46725 .11989 Mdot
.61245 .08974 Mdot
.91263 .18552 Mdot
.49882 .61753 Mdot
.49623 .61643 Mdot
.48797 .61293 Mdot
.4617 .6018 Mdot
.37853 .56663 Mdot
.13034 .46464 Mdot
.70777 .35687 Mdot
.51558 .49925 Mdot
.34672 .51367 Mdot
.98188 .39255 Mdot
.64416 .40931 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50626 .00266 Mdot
.51995 .00846 Mdot
.56347 .0269 Mdot
.69971 .0842 Mdot
.06285 .22443 Mdot
.33415 .16767 Mdot
.39932 .04028 Mdot
.32334 .57108 Mdot
.03353 .43892 Mdot
.6938 .40807 Mdot
.49756 .617 Mdot
.49221 .61473 Mdot
.47519 .60751 Mdot
.42111 .58461 Mdot
.25347 .51443 Mdot
.84715 .36692 Mdot
.63645 .48782 Mdot
.60627 .59938 Mdot
.72391 .0727 Mdot
.07708 .21827 Mdot
.3191 .14958 Mdot
.50062 .00026 Mdot
.50197 .00083 Mdot
.50627 .00266 Mdot
.51998 .00847 Mdot
.56358 .02695 Mdot
.70004 .08433 Mdot
.06356 .22467 Mdot
.33426 .1673 Mdot
.3989 .03995 Mdot
.32189 .57044 Mdot
.0301 .43769 Mdot
.69342 .40996 Mdot
.4974 .61693 Mdot
.49172 .61452 Mdot
.47362 .60685 Mdot
.41612 .5825 Mdot
.23856 .50829 Mdot
.82288 .36113 Mdot
.62134 .49347 Mdot
.58467 .59537 Mdot
.66911 .05218 Mdot
.96209 .18108 Mdot
.31141 .21589 Mdot
.50001 1e-05 Mdot
.50005 2e-05 Mdot
.50015 6e-05 Mdot
.50048 .0002 Mdot
.50154 .00065 Mdot
.50489 .00207 Mdot
.51559 .00661 Mdot
.54963 .02104 Mdot
.6569 .0663 Mdot
.96321 .18931 Mdot
.32422 .22311 Mdot
.47198 .09132 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50689 .00292 Mdot
.52194 .0093 Mdot
.56979 .02957 Mdot
.71899 .09221 Mdot
.10241 .23697 Mdot
.3426 .14844 Mdot
.38333 .02517 Mdot
.26432 .54448 Mdot
.90755 .39753 Mdot
.68178 .4785 Mdot
.49988 .61799 Mdot
.49963 .61788 Mdot
.49883 .61754 Mdot
.49628 .61646 Mdot
.48814 .61301 Mdot
.46224 .60203 Mdot
.38023 .56735 Mdot
.13506 .46651 Mdot
.71075 .3558 Mdot
.51795 .49888 Mdot
.35201 .51548 Mdot
.49878 .61752 Mdot
.49611 .61638 Mdot
.4876 .61277 Mdot
.4605 .60129 Mdot
.37476 .56504 Mdot
.11994 .46055 Mdot
.70177 .35959 Mdot
.51145 .50041 Mdot
.33829 .51102 Mdot
.96221 .3856 Mdot
.64228 .42031 Mdot
.49816 .61725 Mdot
.49413 .61554 Mdot
.48129 .6101 Mdot
.44046 .5928 Mdot
.31238 .53888 Mdot
.96367 .40252 Mdot
.66898 .43591 Mdot
.58276 .56475 Mdot
.61517 .02003 Mdot
.80563 .11771 Mdot
.22039 .25634 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50558 .00237 Mdot
.51778 .00754 Mdot
.5566 .02399 Mdot
.67854 .07536 Mdot
.01555 .20828 Mdot
.32927 .19389 Mdot
.43327 .06427 Mdot
.44007 .00421 Mdot
.35909 .56799 Mdot
.09331 .45377 Mdot
.50066 .00028 Mdot
.50212 .0009 Mdot
.50674 .00286 Mdot
.52147 .00911 Mdot
.56832 .02895 Mdot
.71452 .09036 Mdot
.09355 .23425 Mdot
.3402 .15243 Mdot
.38543 .02796 Mdot
.27327 .54871 Mdot
.92492 .40274 Mdot
.68506 .46979 Mdot
.49966 .61789 Mdot
.49893 .61758 Mdot
.49659 .61659 Mdot
.48913 .61342 Mdot
.46537 .60335 Mdot
.39008 .5715 Mdot
.16271 .47751 Mdot
.73162 .35161 Mdot
.53768 .49817 Mdot
.39972 .53277 Mdot
.1211 .44584 Mdot
.49972 .61792 Mdot
.49911 .61766 Mdot
.49717 .61683 Mdot
.49098 .61421 Mdot
.47127 .60585 Mdot
.40869 .57936 Mdot
.21655 .49928 Mdot
.79093 .35499 Mdot
.59619 .49768 Mdot
.53711 .58152 Mdot
.53319 .61561 Mdot
.50039 .00016 Mdot
.50123 .00052 Mdot
.50392 .00166 Mdot
.51248 .00529 Mdot
.53974 .01685 Mdot
.62598 .0533 Mdot
.88207 .15827 Mdot
.29931 .25787 Mdot
.48918 .11735 Mdot
.66282 .10732 Mdot
.04027 .23328 Mdot
.35796 .19634 Mdot
.49754 .61699 Mdot
.49216 .61471 Mdot
.47503 .60745 Mdot
.42061 .5844 Mdot
.25197 .51381 Mdot
.84462 .36628 Mdot
.63504 .48851 Mdot
.60457 .59921 Mdot
.71992 .07129 Mdot
.06976 .21621 Mdot
.31827 .15359 Mdot
.50009 4e-05 Mdot
.5003 .00013 Mdot
.50096 .00041 Mdot
.50305 .00129 Mdot
.50971 .00412 Mdot
.53092 .01311 Mdot
.59824 .0416 Mdot
.80372 .127 Mdot
.23447 .26622 Mdot
.42762 .11937 Mdot
.51589 .05456 Mdot
.62798 .06927 Mdot
.49869 .61748 Mdot
.49583 .61627 Mdot
.48671 .6124 Mdot
.45769 .6001 Mdot
.36595 .56134 Mdot
.09608 .45125 Mdot
.69069 .36749 Mdot
.50763 .5049 Mdot
.33603 .51198 Mdot
.95973 .38547 Mdot
.64319 .4224 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48384 .61118 Mdot
.44856 .59623 Mdot
.33744 .54936 Mdot
.02273 .42353 Mdot
.67404 .40253 Mdot
.5374 .53359 Mdot
.45635 .56794 Mdot
.31065 .52798 Mdot
.94334 .39102 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48364 .6111 Mdot
.44793 .59596 Mdot
.33549 .54854 Mdot
.01793 .42177 Mdot
.67354 .40519 Mdot
.54085 .53603 Mdot
.46876 .57348 Mdot
.3501 .5447 Mdot
.0384 .42539 Mdot
.4984 .61736 Mdot
.4949 .61587 Mdot
.48376 .61115 Mdot
.4483 .59612 Mdot
.33666 .54903 Mdot
.0208 .42283 Mdot
.67383 .40359 Mdot
.53877 .53456 Mdot
.46129 .57015 Mdot
.32632 .53462 Mdot
.97955 .40372 Mdot
.50025 .0001 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00336 Mdot
.52528 .01072 Mdot
.58038 .03405 Mdot
.75098 .10544 Mdot
.16032 .25298 Mdot
.36783 .12825 Mdot
.3991 .01932 Mdot
.28895 .54996 Mdot
.94718 .40681 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50466 .00198 Mdot
.51485 .0063 Mdot
.54727 .02004 Mdot
.64956 .06322 Mdot
.9446 .18234 Mdot
.32107 .23267 Mdot
.48222 .0996 Mdot
.61676 .08315 Mdot
.91116 .18195 Mdot
.332 .26009 Mdot
.50021 9e-05 Mdot
.50067 .00029 Mdot
.50214 .00091 Mdot
.50683 .0029 Mdot
.52177 .00923 Mdot
.56926 .02935 Mdot
.7174 .09155 Mdot
.09928 .23601 Mdot
.34171 .14983 Mdot
.38396 .02611 Mdot
.26717 .54585 Mdot
.91303 .39917 Mdot
.50069 .00029 Mdot
.50221 .00094 Mdot
.50705 .00299 Mdot
.52245 .00952 Mdot
.57142 .03027 Mdot
.72397 .09428 Mdot
.11207 .23986 Mdot
.34561 .14434 Mdot
.38222 .02263 Mdot
.25786 .54117 Mdot
.89505 .39381 Mdot
.67851 .4842 Mdot
.50045 .00019 Mdot
.50144 .00061 Mdot
.5046 .00195 Mdot
.51465 .00621 Mdot
.54666 .01978 Mdot
.64766 .06242 Mdot
.93972 .1805 Mdot
.32005 .23506 Mdot
.4844 .10158 Mdot
.6254 .08714 Mdot
.93563 .19173 Mdot
.3398 .24979 Mdot
.5004 .00017 Mdot
.50128 .00054 Mdot
.50408 .00173 Mdot
.51299 .00551 Mdot
.54137 .01754 Mdot
.63111 .05546 Mdot
.89601 .16372 Mdot
.30603 .25341 Mdot
.49196 .11491 Mdot
.66585 .10747 Mdot
.04586 .23486 Mdot
.35803 .19293 Mdot
.50042 .00018 Mdot
.50133 .00056 Mdot
.50424 .0018 Mdot
.51352 .00573 Mdot
.54305 .01825 Mdot
.63638 .05768 Mdot
.91014 .16919 Mdot
.31164 .24814 Mdot
.4921 .11153 Mdot
.66071 .10421 Mdot
.03146 .22914 Mdot
.35533 .20016 Mdot
.50069 .00029 Mdot
.50218 .00093 Mdot
.50696 .00295 Mdot
.52217 .0094 Mdot
.57053 .02989 Mdot
.72127 .09316 Mdot
.10686 .23831 Mdot
.34393 .14652 Mdot
.38266 .02394 Mdot
.2609 .54278 Mdot
.90097 .39558 Mdot
.68018 .48158 Mdot
.49877 .61751 Mdot
.49608 .61637 Mdot
.4875 .61274 Mdot
.46021 .60116 Mdot
.37384 .56466 Mdot
.11745 .45957 Mdot
.70044 .36031 Mdot
.51068 .50076 Mdot
.33694 .51065 Mdot
.95921 .38458 Mdot
.642 .42199 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50556 .00236 Mdot
.51772 .00751 Mdot
.55641 .02391 Mdot
.67794 .07511 Mdot
.01415 .20779 Mdot
.32916 .19469 Mdot
.43438 .06502 Mdot
.44392 .0059 Mdot
.37106 .57301 Mdot
.12528 .46613 Mdot
.49882 .61753 Mdot
.49624 .61644 Mdot
.48802 .61295 Mdot
.46185 .60186 Mdot
.37899 .56682 Mdot
.1316 .46514 Mdot
.70855 .35658 Mdot
.51618 .49914 Mdot
.34805 .51412 Mdot
.98507 .3937 Mdot
.64445 .40752 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50791 .00335 Mdot
.5252 .01068 Mdot
.58013 .03395 Mdot
.75023 .10513 Mdot
.15906 .25267 Mdot
.36708 .12857 Mdot
.39812 .01918 Mdot
.28655 .54908 Mdot
.94251 .40541 Mdot
.49799 .61718 Mdot
.49358 .61531 Mdot
.47955 .60936 Mdot
.43492 .59045 Mdot
.29538 .53179 Mdot
.92674 .3902 Mdot
.66415 .45575 Mdot
.6064 .58234 Mdot
.69662 .05576 Mdot
.01228 .19509 Mdot
.30953 .18371 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50835 .00354 Mdot
.5266 .01128 Mdot
.58457 .03583 Mdot
.76351 .11059 Mdot
.18032 .2576 Mdot
.38092 .12398 Mdot
.41909 .02359 Mdot
.34107 .56981 Mdot
.06233 .44577 Mdot
.69247 .38945 Mdot
.49933 .61775 Mdot
.49787 .61713 Mdot
.49321 .61516 Mdot
.47838 .60886 Mdot
.4312 .58888 Mdot
.28402 .52707 Mdot
.90353 .38288 Mdot
.65905 .46693 Mdot
.61537 .59104 Mdot
.72998 .07083 Mdot
.08143 .21721 Mdot
.49849 .61739 Mdot
.49518 .61599 Mdot
.48465 .61153 Mdot
.45114 .59732 Mdot
.34549 .55274 Mdot
.0428 .43096 Mdot
.67668 .39176 Mdot
.52441 .52392 Mdot
.4086 .54646 Mdot
.1631 .46631 Mdot
.71358 .34022 Mdot
.50028 .00012 Mdot
.50089 .00038 Mdot
.50284 .0012 Mdot
.50905 .00384 Mdot
.52881 .01222 Mdot
.59157 .03878 Mdot
.78421 .11906 Mdot
.2101 .26321 Mdot
.40472 .12028 Mdot
.46479 .03713 Mdot
.47249 .00476 Mdot
.43914 .59742 Mdot
.49876 .61751 Mdot
.49606 .61637 Mdot
.48746 .61272 Mdot
.46007 .6011 Mdot
.37341 .56447 Mdot
.11625 .45911 Mdot
.69982 .36066 Mdot
.51035 .50093 Mdot
.33638 .51052 Mdot
.958 .38418 Mdot
.64189 .42266 Mdot
.49916 .61768 Mdot
.49734 .6169 Mdot
.49151 .61444 Mdot
.47297 .60657 Mdot
.41408 .58164 Mdot
.23247 .50579 Mdot
.81357 .35914 Mdot
.61462 .49507 Mdot
.5731 .59238 Mdot
.63743 .03976 Mdot
.88323 .15191 Mdot
.50026 .00011 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52636 .01118 Mdot
.58381 .0355 Mdot
.76124 .10966 Mdot
.1768 .25683 Mdot
.37844 .12462 Mdot
.41497 .02257 Mdot
.32992 .56547 Mdot
.03561 .43614 Mdot
.49957 .61785 Mdot
.49864 .61746 Mdot
.49566 .61619 Mdot
.48618 .61218 Mdot
.456 .59938 Mdot
.36067 .55911 Mdot
.08203 .44583 Mdot
.68572 .3731 Mdot
.50894 .50878 Mdot
.34555 .51706 Mdot
.98519 .39532 Mdot
.49773 .61707 Mdot
.49277 .61497 Mdot
.47696 .60826 Mdot
.4267 .58697 Mdot
.27034 .5214 Mdot
.87719 .37506 Mdot
.65051 .47794 Mdot
.61743 .59758 Mdot
.74493 .0788 Mdot
.11104 .22627 Mdot
.32378 .13148 Mdot
.49815 .61725 Mdot
.4941 .61553 Mdot
.48121 .61006 Mdot
.44018 .59268 Mdot
.31154 .53853 Mdot
.96178 .40187 Mdot
.6688 .43696 Mdot
.58416 .56572 Mdot
.61995 .02212 Mdot
.8191 .12308 Mdot
.23484 .25694 Mdot
.49979 .61794 Mdot
.49932 .61775 Mdot
.49785 .61712 Mdot
.49314 .61512 Mdot
.47814 .60876 Mdot
.43045 .58856 Mdot
.28171 .52611 Mdot
.89897 .38149 Mdot
.6578 .46898 Mdot
.61641 .59245 Mdot
.73447 .07296 Mdot
.50045 .00019 Mdot
.50142 .0006 Mdot
.50452 .00192 Mdot
.5144 .0061 Mdot
.54584 .01943 Mdot
.6451 .06134 Mdot
.93308 .17798 Mdot
.31851 .23821 Mdot
.48699 .10413 Mdot
.63597 .09208 Mdot
.965 .20335 Mdot
.3461 .23554 Mdot
.49889 .61757 Mdot
.49648 .61654 Mdot
.48877 .61327 Mdot
.46425 .60288 Mdot
.38654 .57001 Mdot
.15271 .47351 Mdot
.72337 .35269 Mdot
.52944 .49818 Mdot
.37941 .52531 Mdot
.06531 .42391 Mdot
.65597 .36505 Mdot
.50003 1e-05 Mdot
.5001 4e-05 Mdot
.50033 .00014 Mdot
.50104 .00044 Mdot
.50331 .0014 Mdot
.51055 .00447 Mdot
.53359 .01424 Mdot
.60666 .04516 Mdot
.82801 .1368 Mdot
.25998 .26697 Mdot
.45369 .11972 Mdot
.57891 .07739 Mdot
.50006 3e-05 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50656 .00278 Mdot
.5209 .00886 Mdot
.56651 .02819 Mdot
.709 .08806 Mdot
.08235 .23074 Mdot
.33761 .15776 Mdot
.38941 .03201 Mdot
.28835 .55558 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50829 .00352 Mdot
.52641 .0112 Mdot
.58395 .03556 Mdot
.76165 .10983 Mdot
.17745 .25698 Mdot
.37889 .1245 Mdot
.4157 .02275 Mdot
.3319 .56624 Mdot
.04028 .4378 Mdot
.68888 .40086 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50245 .00104 Mdot
.50781 .00331 Mdot
.52488 .01055 Mdot
.57912 .03352 Mdot
.74722 .10389 Mdot
.15401 .25141 Mdot
.36419 .1299 Mdot
.39449 .01873 Mdot
.27788 .54596 Mdot
.50044 .00019 Mdot
.5014 .00059 Mdot
.50445 .00189 Mdot
.51419 .00602 Mdot
.54517 .01915 Mdot
.64301 .06047 Mdot
.92765 .17592 Mdot
.31711 .2407 Mdot
.48875 .10608 Mdot
.64353 .09566 Mdot
.98559 .21141 Mdot
.34923 .22474 Mdot
.5002 9e-05 Mdot
.50065 .00027 Mdot
.50206 .00087 Mdot
.50655 .00278 Mdot
.52088 .00885 Mdot
.56643 .02815 Mdot
.70875 .08796 Mdot
.08184 .23058 Mdot
.3375 .15801 Mdot
.38962 .03221 Mdot
.28913 .55593 Mdot
.95708 .41282 Mdot
.50038 .00016 Mdot
.50121 .00051 Mdot
.50384 .00163 Mdot
.51224 .00519 Mdot
.53897 .01652 Mdot
.62357 .05229 Mdot
.87547 .15568 Mdot
.29567 .2597 Mdot
.48691 .11819 Mdot
.65854 .10607 Mdot
.03055 .22992 Mdot
.35702 .20177 Mdot
.50035 .00015 Mdot
.50112 .00048 Mdot
.50358 .00152 Mdot
.5114 .00483 Mdot
.5363 .01539 Mdot
.61519 .04875 Mdot
.85216 .14646 Mdot
.28035 .26464 Mdot
.47413 .11977 Mdot
.62928 .09589 Mdot
.95772 .20299 Mdot
.34884 .24172 Mdot
.49995 .61801 Mdot
.49984 .61797 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49492 .61588 Mdot
.48381 .61117 Mdot
.44846 .59619 Mdot
.33715 .54924 Mdot
.02201 .42327 Mdot
.67396 .40293 Mdot
.53791 .53395 Mdot
.50078 .00033 Mdot
.50249 .00106 Mdot
.50794 .00337 Mdot
.52531 .01073 Mdot
.58047 .03409 Mdot
.75127 .10556 Mdot
.16079 .2531 Mdot
.36811 .12813 Mdot
.39947 .01938 Mdot
.28987 .5503 Mdot
.94898 .40736 Mdot
.68332 .45385 Mdot
.50019 8e-05 Mdot
.50059 .00025 Mdot
.50189 .0008 Mdot
.50602 .00255 Mdot
.51919 .00814 Mdot
.56106 .02588 Mdot
.69229 .0811 Mdot
.04672 .21905 Mdot
.33208 .17636 Mdot
.40975 .048 Mdot
.35918 .58678 Mdot
.12389 .47262 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.5036 .00153 Mdot
.51146 .00486 Mdot
.5365 .01547 Mdot
.6158 .04901 Mdot
.85388 .14714 Mdot
.28162 .26436 Mdot
.47532 .11972 Mdot
.63216 .09693 Mdot
.96522 .20584 Mdot
.35004 .23783 Mdot
.49799 .61718 Mdot
.4936 .61532 Mdot
.47962 .60939 Mdot
.43515 .59055 Mdot
.29608 .53208 Mdot
.92822 .39068 Mdot
.66441 .45499 Mdot
.60565 .58171 Mdot
.69396 .05458 Mdot
.00637 .19308 Mdot
.30922 .18718 Mdot
.50043 .00018 Mdot
.50138 .00058 Mdot
.50439 .00186 Mdot
.51399 .00593 Mdot
.54454 .01888 Mdot
.64105 .05964 Mdot
.92249 .17394 Mdot
.31566 .24299 Mdot
.49012 .10782 Mdot
.64977 .09867 Mdot
.00236 .21791 Mdot
.35141 .21572 Mdot
.50073 .00031 Mdot
.50233 .00099 Mdot
.50742 .00315 Mdot
.52364 .01002 Mdot
.57519 .03186 Mdot
.73539 .09901 Mdot
.13331 .24593 Mdot
.35384 .1363 Mdot
.38468 .01906 Mdot
.25728 .5393 Mdot
.89139 .39191 Mdot
.67607 .48495 Mdot
.49974 .61792 Mdot
.49916 .61768 Mdot
.49733 .6169 Mdot
.49149 .61443 Mdot
.4729 .60654 Mdot
.41385 .58154 Mdot
.2318 .50552 Mdot
.81258 .35894 Mdot
.61387 .49522 Mdot
.57176 .59201 Mdot
.63369 .03827 Mdot
.50046 .00019 Mdot
.50146 .00062 Mdot
.50464 .00197 Mdot
.51477 .00626 Mdot
.54703 .01994 Mdot
.64882 .06291 Mdot
.94271 .18163 Mdot
.32069 .2336 Mdot
.48309 .10037 Mdot
.62019 .08473 Mdot
.92092 .18586 Mdot
.33545 .25619 Mdot
.49794 .61716 Mdot
.49342 .61525 Mdot
.47905 .60915 Mdot
.43333 .58978 Mdot
.29052 .52977 Mdot
.91668 .38698 Mdot
.66218 .46075 Mdot
.61099 .5864 Mdot
.71312 .06312 Mdot
.04761 .20672 Mdot
.31174 .16324 Mdot
.50004 2e-05 Mdot
.50013 5e-05 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50418 .00177 Mdot
.51333 .00565 Mdot
.54245 .01799 Mdot
.63448 .05688 Mdot
.90507 .16723 Mdot
.30976 .25011 Mdot
.49235 .11285 Mdot
.66348 .10576 Mdot
.49938 .61777 Mdot
.49803 .6172 Mdot
.49371 .61537 Mdot
.47996 .60954 Mdot
.43622 .591 Mdot
.29935 .53345 Mdot
.93514 .39294 Mdot
.66555 .45142 Mdot
.60186 .57867 Mdot
.68073 .04875 Mdot
.97608 .18254 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50217 .00092 Mdot
.5069 .00293 Mdot
.52198 .00932 Mdot
.56993 .02963 Mdot
.71942 .09239 Mdot
.10326 .23722 Mdot
.34285 .14807 Mdot
.38318 .02493 Mdot
.26361 .54414 Mdot
.90619 .39713 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50247 .00105 Mdot
.50787 .00334 Mdot
.52506 .01063 Mdot
.5797 .03377 Mdot
.74896 .10461 Mdot
.15695 .25215 Mdot
.36585 .12911 Mdot
.39654 .01896 Mdot
.28273 .54769 Mdot
.93521 .40326 Mdot
.50042 .00018 Mdot
.50134 .00057 Mdot
.50426 .00181 Mdot
.51358 .00576 Mdot
.54326 .01834 Mdot
.63702 .05795 Mdot
.91184 .16985 Mdot
.31224 .24746 Mdot
.49194 .11106 Mdot
.65955 .10359 Mdot
.02836 .22794 Mdot
.35486 .20179 Mdot
.49786 .61713 Mdot
.49318 .61514 Mdot
.47827 .60882 Mdot
.43086 .58873 Mdot
.28298 .52664 Mdot
.90147 .38225 Mdot
.65849 .46787 Mdot
.61587 .59169 Mdot
.7321 .07183 Mdot
.08555 .21845 Mdot
.31677 .1429 Mdot
.49795 .61716 Mdot
.49347 .61526 Mdot
.47919 .60921 Mdot
.4338 .58998 Mdot
.29194 .53036 Mdot
.9196 .38791 Mdot
.66279 .45932 Mdot
.60976 .58526 Mdot
.70864 .06111 Mdot
.03823 .2037 Mdot
.31103 .1686 Mdot
.49795 .61716 Mdot
.49345 .61526 Mdot
.47914 .60919 Mdot
.43363 .58991 Mdot
.29144 .53015 Mdot
.91856 .38758 Mdot
.66258 .45983 Mdot
.61021 .58567 Mdot
.71026 .06183 Mdot
.04164 .2048 Mdot
.31127 .16664 Mdot
.50043 .00018 Mdot
.50136 .00058 Mdot
.50434 .00184 Mdot
.51384 .00587 Mdot
.54408 .01869 Mdot
.63959 .05903 Mdot
.91866 .17247 Mdot
.31449 .24464 Mdot
.49094 .10905 Mdot
.65379 .10065 Mdot
.01306 .22204 Mdot
.35277 .20995 Mdot
.50008 3e-05 Mdot
.50024 .0001 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50791 .00335 Mdot
.5252 .01068 Mdot
.58013 .03395 Mdot
.75024 .10513 Mdot
.15908 .25268 Mdot
.3671 .12856 Mdot
.39813 .01918 Mdot
.28658 .54909 Mdot
.49918 .61769 Mdot
.49739 .61693 Mdot
.49167 .6145 Mdot
.47347 .60679 Mdot
.41567 .58231 Mdot
.23721 .50774 Mdot
.82079 .36067 Mdot
.61988 .49386 Mdot
.58224 .59478 Mdot
.66256 .04964 Mdot
.94648 .17547 Mdot
.49993 .618 Mdot
.49977 .61793 Mdot
.49926 .61772 Mdot
.49763 .61703 Mdot
.49244 .61483 Mdot
.47592 .60783 Mdot
.42343 .58559 Mdot
.26046 .51731 Mdot
.85927 .37009 Mdot
.64272 .4842 Mdot
.6127 .59948 Mdot
.49753 .61699 Mdot
.49213 .6147 Mdot
.47494 .60741 Mdot
.42032 .58427 Mdot
.2511 .51345 Mdot
.84316 .36591 Mdot
.63421 .48889 Mdot
.60354 .59908 Mdot
.71746 .07041 Mdot
.06514 .21488 Mdot
.31781 .15616 Mdot
.50055 .00023 Mdot
.50175 .00074 Mdot
.50557 .00236 Mdot
.51775 .00753 Mdot
.5565 .02395 Mdot
.67825 .07524 Mdot
.01486 .20804 Mdot
.32922 .19428 Mdot
.43381 .06464 Mdot
.44195 .00503 Mdot
.36494 .57044 Mdot
.1088 .45973 Mdot
.50058 .00025 Mdot
.50186 .00079 Mdot
.50591 .00251 Mdot
.51884 .00799 Mdot
.55996 .02541 Mdot
.68892 .0797 Mdot
.03924 .21651 Mdot
.3313 .1805 Mdot
.41509 .05179 Mdot
.37749 .59479 Mdot
.17375 .49211 Mdot
.75815 .36118 Mdot
.50002 1e-05 Mdot
.50006 3e-05 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50622 .00264 Mdot
.5198 .0084 Mdot
.56301 .0267 Mdot
.69828 .0836 Mdot
.05979 .22342 Mdot
.33371 .16929 Mdot
.40116 .04169 Mdot
.49956 .61785 Mdot
.49861 .61745 Mdot
.49558 .61616 Mdot
.48593 .61207 Mdot
.4552 .59904 Mdot
.35816 .55806 Mdot
.07543 .4433 Mdot
.68374 .37596 Mdot
.51039 .5109 Mdot
.35263 .52053 Mdot
.00407 .40261 Mdot
.49799 .61718 Mdot
.4936 .61532 Mdot
.47963 .6094 Mdot
.43517 .59056 Mdot
.29615 .53211 Mdot
.92835 .39072 Mdot
.66444 .45493 Mdot
.60558 .58166 Mdot
.69372 .05448 Mdot
.00583 .19289 Mdot
.30919 .18749 Mdot
.50039 .00016 Mdot
.50124 .00052 Mdot
.50394 .00167 Mdot
.51256 .00532 Mdot
.53998 .01695 Mdot
.62675 .05363 Mdot
.88419 .1591 Mdot
.30041 .25724 Mdot
.48977 .11703 Mdot
.6638 .10756 Mdot
.04241 .23399 Mdot
.35815 .19514 Mdot
.50041 .00017 Mdot
.50131 .00056 Mdot
.50417 .00177 Mdot
.51329 .00564 Mdot
.54232 .01794 Mdot
.6341 .05672 Mdot
.90405 .16684 Mdot
.30937 .2505 Mdot
.49237 .1131 Mdot
.66392 .10602 Mdot
.04012 .23251 Mdot
.35678 .1957 Mdot
.49986 .61798 Mdot
.49956 .61785 Mdot
.49861 .61744 Mdot
.49556 .61615 Mdot
.48587 .61204 Mdot
.455 .59896 Mdot
.35753 .55779 Mdot
.07376 .44266 Mdot
.68327 .3767 Mdot
.51084 .51147 Mdot
.35466 .52151 Mdot
.50028 .00012 Mdot
.50088 .00037 Mdot
.50281 .00119 Mdot
.50896 .0038 Mdot
.52855 .01211 Mdot
.59074 .03844 Mdot
.78179 .11807 Mdot
.20682 .26269 Mdot
.40186 .12054 Mdot
.45883 .03521 Mdot
.45473 .6155 Mdot
.38363 .57409 Mdot
.50076 .00032 Mdot
.50241 .00102 Mdot
.50767 .00325 Mdot
.52445 .01037 Mdot
.57775 .03294 Mdot
.74308 .10218 Mdot
.14693 .24959 Mdot
.36038 .13192 Mdot
.39024 .01846 Mdot
.26822 .54262 Mdot
.90902 .39604 Mdot
.67898 .47586 Mdot
.50023 .0001 Mdot
.50075 .00032 Mdot
.50238 .00101 Mdot
.50758 .00321 Mdot
.52414 .01024 Mdot
.57677 .03253 Mdot
.74014 .10097 Mdot
.14178 .24823 Mdot
.35778 .1335 Mdot
.38775 .01852 Mdot
.26294 .5409 Mdot
.90019 .39384 Mdot
.50074 .00031 Mdot
.50236 .001 Mdot
.50752 .00319 Mdot
.52396 .01016 Mdot
.5762 .03229 Mdot
.73843 .10026 Mdot
.13876 .24742 Mdot
.35633 .13447 Mdot
.38651 .01865 Mdot
.26051 .54016 Mdot
.89629 .39294 Mdot
.67686 .48242 Mdot
.49888 .61756 Mdot
.49642 .61651 Mdot
.48859 .61319 Mdot
.46365 .60262 Mdot
.38466 .56922 Mdot
.14741 .47141 Mdot
.71933 .35347 Mdot
.52557 .49828 Mdot
.36999 .52188 Mdot
.04037 .41432 Mdot
.65084 .37729 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49088 .61417 Mdot
.47096 .60572 Mdot
.40772 .57895 Mdot
.21367 .49811 Mdot
.78709 .35439 Mdot
.59278 .49795 Mdot
.5299 .57917 Mdot
.51162 .60673 Mdot
.51074 .61749 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52637 .01118 Mdot
.58384 .03552 Mdot
.76134 .1097 Mdot
.17697 .25687 Mdot
.37856 .12459 Mdot
.41516 .02262 Mdot
.33043 .56567 Mdot
.03682 .43657 Mdot
.68847 .40274 Mdot
.4984 .61735 Mdot
.49489 .61587 Mdot
.48371 .61113 Mdot
.44814 .59605 Mdot
.33616 .54882 Mdot
.01958 .42238 Mdot
.6737 .40427 Mdot
.53965 .53518 Mdot
.46446 .57156 Mdot
.3364 .53889 Mdot
.00393 .41256 Mdot
.49839 .61735 Mdot
.49487 .61586 Mdot
.48365 .6111 Mdot
.44796 .59597 Mdot
.33559 .54859 Mdot
.01818 .42187 Mdot
.67356 .40505 Mdot
.54066 .5359 Mdot
.4681 .57319 Mdot
.348 .54381 Mdot
.033 .42336 Mdot
.49852 .61741 Mdot
.4953 .61604 Mdot
.48502 .61168 Mdot
.45231 .59782 Mdot
.34914 .55427 Mdot
.05208 .43444 Mdot
.67828 .38702 Mdot
.51939 .51983 Mdot
.38952 .53777 Mdot
.10691 .44337 Mdot
.67573 .35155 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50646 .00274 Mdot
.52057 .00872 Mdot
.56544 .02773 Mdot
.70574 .08671 Mdot
.07559 .22858 Mdot
.33627 .16111 Mdot
.39245 .03472 Mdot
.29929 .56046 Mdot
.97877 .41994 Mdot
.69 .43956 Mdot
.49966 .61789 Mdot
.49891 .61757 Mdot
.49654 .61656 Mdot
.48896 .61335 Mdot
.46484 .60313 Mdot
.38842 .5708 Mdot
.15801 .47563 Mdot
.72764 .35205 Mdot
.53366 .49815 Mdot
.38979 .52912 Mdot
.09349 .43491 Mdot
.50024 .0001 Mdot
.50077 .00033 Mdot
.50246 .00104 Mdot
.50784 .00332 Mdot
.52497 .01059 Mdot
.5794 .03364 Mdot
.74805 .10423 Mdot
.15542 .25177 Mdot
.36498 .12952 Mdot
.39545 .01883 Mdot
.28014 .54677 Mdot
.93036 .40186 Mdot
.50062 .00026 Mdot
.50197 .00084 Mdot
.50628 .00266 Mdot
.52002 .00849 Mdot
.56369 .02699 Mdot
.70038 .08448 Mdot
.0643 .22491 Mdot
.33437 .16691 Mdot
.39847 .03962 Mdot
.3204 .56978 Mdot
.02658 .43644 Mdot
.69307 .41192 Mdot
.49947 .61781 Mdot
.49832 .61732 Mdot
.49464 .61576 Mdot
.48294 .6108 Mdot
.44569 .59501 Mdot
.32854 .54563 Mdot
.00115 .4157 Mdot
.67203 .41463 Mdot
.55357 .54482 Mdot
.51394 .59354 Mdot
.4952 .60645 Mdot
.4995 .61782 Mdot
.49841 .61736 Mdot
.49493 .61588 Mdot
.48384 .61118 Mdot
.44857 .59623 Mdot
.33748 .54938 Mdot
.02283 .42357 Mdot
.67405 .40248 Mdot
.53733 .53354 Mdot
.4561 .56783 Mdot
.30985 .52765 Mdot
.50052 .00022 Mdot
.50165 .0007 Mdot
.50526 .00223 Mdot
.51675 .0071 Mdot
.55333 .02261 Mdot
.66841 .07113 Mdot
.99154 .1997 Mdot
.32735 .20754 Mdot
.45207 .07708 Mdot
.50599 .03332 Mdot
.56889 .03887 Mdot
.73193 .10076 Mdot
.49749 .61697 Mdot
.492 .61464 Mdot
.47451 .60723 Mdot
.41895 .5837 Mdot
.24702 .51177 Mdot
.83639 .36425 Mdot
.63018 .49059 Mdot
.59818 .59826 Mdot
.70429 .06558 Mdot
.03935 .20708 Mdot
.31599 .17097 Mdot
.50064 .00027 Mdot
.50204 .00086 Mdot
.5065 .00276 Mdot
.5207 .00878 Mdot
.56586 .02791 Mdot
.70702 .08724 Mdot
.07826 .22944 Mdot
.33678 .15978 Mdot
.39119 .03363 Mdot
.29481 .55847 Mdot
.9691 .41673 Mdot
.68945 .4452 Mdot
.5008 .00034 Mdot
.50256 .00109 Mdot
.50816 .00346 Mdot
.52601 .01103 Mdot
.58269 .03503 Mdot
.75791 .10829 Mdot
.17156 .25565 Mdot
.37489 .12567 Mdot
.40931 .02127 Mdot
.31492 .5597 Mdot
.00139 .42426 Mdot
.68577 .42297 Mdot
.50032 .00014 Mdot
.50103 .00044 Mdot
.50328 .00139 Mdot
.51046 .00444 Mdot
.53332 .01413 Mdot
.60578 .04479 Mdot
.82549 .13579 Mdot
.25758 .26704 Mdot
.4512 .11967 Mdot
.57277 .07513 Mdot
.79974 .14027 Mdot
.25388 .28067 Mdot
.49888 .61756 Mdot
.49643 .61652 Mdot
.48862 .61321 Mdot
.46376 .60267 Mdot
.385 .56936 Mdot
.14837 .47179 Mdot
.72004 .35332 Mdot
.52624 .49826 Mdot
.37161 .52247 Mdot
.04462 .41594 Mdot
.65157 .37512 Mdot
.4981 .61723 Mdot
.49396 .61547 Mdot
.48074 .60987 Mdot
.43871 .59206 Mdot
.30701 .53664 Mdot
.95174 .39846 Mdot
.66775 .44252 Mdot
.59132 .5708 Mdot
.64447 .03285 Mdot
.88577 .14913 Mdot
.28408 .24617 Mdot
.50002 1e-05 Mdot
.50007 3e-05 Mdot
.50023 .0001 Mdot
.50074 .00031 Mdot
.50235 .001 Mdot
.50748 .00317 Mdot
.52384 .01011 Mdot
.57582 .03213 Mdot
.73729 .09979 Mdot
.13673 .24687 Mdot
.35539 .13514 Mdot
.38577 .01877 Mdot
.49752 .61698 Mdot
.4921 .61468 Mdot
.47483 .60736 Mdot
.41997 .58413 Mdot
.25006 .51302 Mdot
.84141 .36548 Mdot
.63319 .48935 Mdot
.60225 .59891 Mdot
.71433 .06927 Mdot
.05918 .21313 Mdot
.31729 .15952 Mdot
.4991 .61765 Mdot
.49712 .61681 Mdot
.49084 .61415 Mdot
.47082 .60566 Mdot
.40726 .57875 Mdot
.21233 .49756 Mdot
.78533 .35413 Mdot
.5912 .49806 Mdot
.52651 .57805 Mdot
.5014 .60251 Mdot
.47838 .60381 Mdot
.49998 .61803 Mdot
.49995 .61801 Mdot
.49983 .61796 Mdot
.49947 .61781 Mdot
.4983 .61731 Mdot
.49459 .61574 Mdot
.48275 .61072 Mdot
.44509 .59476 Mdot
.3267 .54486 Mdot
.99677 .41413 Mdot
.67168 .41712 Mdot
.50011 5e-05 Mdot
.50034 .00014 Mdot
.50108 .00046 Mdot
.50344 .00146 Mdot
.51097 .00465 Mdot
.53493 .01481 Mdot
.61088 .04694 Mdot
.84001 .14161 Mdot
.2707 .26618 Mdot
.46468 .11988 Mdot
.60611 .08741 Mdot
.89517 .17865 Mdot
.5004 .00017 Mdot
.50127 .00054 Mdot
.50405 .00172 Mdot
.51291 .00547 Mdot
.54111 .01743 Mdot
.63029 .05512 Mdot
.89381 .16286 Mdot
.30505 .25416 Mdot
.4917 .11536 Mdot
.66591 .10767 Mdot
.0463 .23509 Mdot
.35821 .19277 Mdot
.50082 .00035 Mdot
.50262 .00111 Mdot
.50836 .00354 Mdot
.52662 .01129 Mdot
.58462 .03585 Mdot
.76366 .11065 Mdot
.18055 .25765 Mdot
.38108 .12393 Mdot
.41937 .02367 Mdot
.34183 .57011 Mdot
.06421 .44646 Mdot
.69286 .38853 Mdot
.5 0 Mdot
.50001 1e-05 Mdot
.50004 2e-05 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50125 .00053 Mdot
.504 .00169 Mdot
.51273 .0054 Mdot
.54055 .01719 Mdot
.62853 .05438 Mdot
.88904 .161 Mdot
.30282 .25573 Mdot
.49932 .61774 Mdot
.49782 .61711 Mdot
.49306 .61509 Mdot
.4779 .60866 Mdot
.4297 .58825 Mdot
.27945 .52518 Mdot
.89455 .38015 Mdot
.6565 .47091 Mdot
.61715 .59372 Mdot
.73809 .07475 Mdot
.0971 .22188 Mdot
.50008 3e-05 Mdot
.50026 .00011 Mdot
.50081 .00034 Mdot
.50259 .0011 Mdot
.50825 .0035 Mdot
.52628 .01114 Mdot
.58354 .03539 Mdot
.76043 .10933 Mdot
.17554 .25655 Mdot
.37758 .12486 Mdot
.41355 .02223 Mdot
.32614 .56401 Mdot
.50046 .0002 Mdot
.50147 .00062 Mdot
.50469 .00199 Mdot
.51493 .00633 Mdot
.54754 .02015 Mdot
.65041 .06358 Mdot
.94678 .18316 Mdot
.3215 .23159 Mdot
.48118 .09869 Mdot
.61269 .08128 Mdot
.89945 .17723 Mdot
.3272 .26437 Mdot
.50019 8e-05 Mdot
.50061 .00026 Mdot
.50195 .00083 Mdot
.50622 .00264 Mdot
.51983 .00841 Mdot
.56309 .02674 Mdot
.69854 .08371 Mdot
.06034 .22361 Mdot
.33379 .169 Mdot
.40082 .04143 Mdot
.32854 .57336 Mdot
.046 .44342 Mdot
.50072 .0003 Mdot
.50229 .00097 Mdot
.50728 .00309 Mdot
.52319 .00983 Mdot
.57377 .03126 Mdot
.73109 .09723 Mdot
.12547 .24373 Mdot
.35053 .1391 Mdot
.38294 .02003 Mdot
.25515 .53906 Mdot
.88876 .39159 Mdot
.67597 .48652 Mdot
.50066 .00028 Mdot
.50211 .00089 Mdot
.50672 .00285 Mdot
.52142 .00908 Mdot
.56814 .02888 Mdot
.71398 .09013 Mdot
.09246 .23391 Mdot
.33992 .15294 Mdot
.38576 .02833 Mdot
.27456 .54931 Mdot
.92748 .40352 Mdot
.68545 .46845 Mdot
.50067 .00028 Mdot
.50213 .0009 Mdot
.50677 .00287 Mdot
.52158 .00915 Mdot
.56866 .0291 Mdot
.71556 .09079 Mdot
.09563 .23489 Mdot
.34073 .15148 Mdot
.38485 .02727 Mdot
.27093 .54763 Mdot
.92033 .40135 Mdot
.68431 .47216 Mdot
.49851 .6174 Mdot
.49526 .61603 Mdot
.48491 .61164 Mdot
.45196 .59767 Mdot
.34803 .5538 Mdot
.04924 .43337 Mdot
.67776 .38845 Mdot
.52085 .52106 Mdot
.39513 .54033 Mdot
.12323 .44999 Mdot
.68441 .34683 Mdot
.50005 2e-05 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.5016 .00068 Mdot
.50509 .00216 Mdot
.51623 .00688 Mdot
.55167 .0219 Mdot
.66327 .06897 Mdot
.97901 .19514 Mdot
.32615 .21454 Mdot
.46136 .08356 Mdot
.53917 .04809 Mdot
.49783 .61711 Mdot
.49309 .61511 Mdot
.478 .60871 Mdot
.43001 .58837 Mdot
.28039 .52556 Mdot
.89637 .3807 Mdot
.65704 .47012 Mdot
.61688 .59321 Mdot
.73669 .07405 Mdot
.0944 .22108 Mdot
.31867 .13861 Mdot
.50063 .00027 Mdot
.50201 .00085 Mdot
.50641 .00272 Mdot
.52041 .00865 Mdot
.56493 .02752 Mdot
.70417 .08606 Mdot
.07232 .22753 Mdot
.33568 .16277 Mdot
.39408 .03609 Mdot
.30507 .56302 Mdot
.99147 .42422 Mdot
.69066 .43213 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49088 .61417 Mdot
.47094 .60571 Mdot
.40766 .57892 Mdot
.21351 .49804 Mdot
.78687 .35436 Mdot
.59259 .49796 Mdot
.52949 .57903 Mdot
.51036 .60621 Mdot
.50676 .61581 Mdot
.50007 3e-05 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50225 .00096 Mdot
.50718 .00305 Mdot
.52288 .0097 Mdot
.57277 .03084 Mdot
.72807 .09598 Mdot
.11983 .24212 Mdot
.34835 .14124 Mdot
.3823 .02098 Mdot
.25536 .53958 Mdot
.49943 .61779 Mdot
.49818 .61726 Mdot
.49421 .61558 Mdot
.48154 .61021 Mdot
.44125 .59313 Mdot
.31481 .53989 Mdot
.96916 .40441 Mdot
.66948 .43282 Mdot
.57863 .56188 Mdot
.60099 .01382 Mdot
.76486 .10128 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50161 .00068 Mdot
.50512 .00217 Mdot
.51631 .00692 Mdot
.55192 .02201 Mdot
.66403 .06929 Mdot
.98088 .19582 Mdot
.32634 .21351 Mdot
.46002 .08262 Mdot
.53435 .04594 Mdot
.65982 .07754 Mdot
.49837 .61734 Mdot
.49481 .61583 Mdot
.48347 .61102 Mdot
.44737 .59573 Mdot
.33377 .54782 Mdot
.01374 .42025 Mdot
.67313 .40752 Mdot
.54394 .53819 Mdot
.47982 .57841 Mdot
.38552 .55975 Mdot
.13392 .46254 Mdot
.49752 .61698 Mdot
.49211 .61469 Mdot
.47485 .60737 Mdot
.42003 .58415 Mdot
.25025 .5131 Mdot
.84174 .36556 Mdot
.63338 .48926 Mdot
.60249 .59894 Mdot
.71493 .06949 Mdot
.06032 .21347 Mdot
.31739 .15887 Mdot
.49928 .61773 Mdot
.49771 .61706 Mdot
.49271 .61494 Mdot
.47677 .60819 Mdot
.42613 .58673 Mdot
.2686 .52068 Mdot
.87397 .37414 Mdot
.64924 .47914 Mdot
.61697 .59809 Mdot
.74479 .079 Mdot
.11121 .22646 Mdot
.49878 .61752 Mdot
.49611 .61639 Mdot
.48761 .61278 Mdot
.46055 .60131 Mdot
.37492 .56511 Mdot
.12039 .46073 Mdot
.70201 .35946 Mdot
.5116 .50035 Mdot
.33856 .51109 Mdot
.96281 .38581 Mdot
.64234 .41997 Mdot
.50032 .00014 Mdot
.50102 .00043 Mdot
.50323 .00137 Mdot
.5103 .00437 Mdot
.53282 .01391 Mdot
.60421 .04412 Mdot
.82099 .13398 Mdot
.25314 .26709 Mdot
.44661 .11957 Mdot
.56149 .071 Mdot
.76632 .12659 Mdot
.20862 .27336 Mdot
.49981 .61795 Mdot
.4994 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48045 .60975 Mdot
.43779 .59167 Mdot
.30418 .53546 Mdot
.94555 .39638 Mdot
.667 .44589 Mdot
.59546 .57382 Mdot
.65868 .03907 Mdot
.5002 8e-05 Mdot
.50064 .00027 Mdot
.50203 .00086 Mdot
.50647 .00274 Mdot
.52061 .00874 Mdot
.56557 .02779 Mdot
.70613 .08687 Mdot
.0764 .22884 Mdot
.33643 .1607 Mdot
.39206 .03438 Mdot
.29791 .55985 Mdot
.97576 .41894 Mdot
.49878 .61752 Mdot
.49613 .61639 Mdot
.48766 .6128 Mdot
.46069 .60137 Mdot
.37537 .5653 Mdot
.12163 .46121 Mdot
.70269 .35912 Mdot
.51202 .50019 Mdot
.33935 .51132 Mdot
.9646 .38643 Mdot
.64251 .41897 Mdot
.49838 .61735 Mdot
.49482 .61584 Mdot
.48351 .61104 Mdot
.44751 .59578 Mdot
.3342 .548 Mdot
.01479 .42063 Mdot
.67323 .40694 Mdot
.54316 .53764 Mdot
.47703 .57716 Mdot
.37656 .55594 Mdot
.10894 .45264 Mdot
.49787 .61713 Mdot
.4932 .61515 Mdot
.47834 .60885 Mdot
.4311 .58884 Mdot
.28371 .52694 Mdot
.90293 .3827 Mdot
.65889 .46721 Mdot
.61552 .59123 Mdot
.73061 .07113 Mdot
.08267 .21758 Mdot
.31622 .14434 Mdot
.49775 .61708 Mdot
.49285 .615 Mdot
.47721 .60837 Mdot
.42752 .58732 Mdot
.27282 .52242 Mdot
.88184 .37639 Mdot
.65226 .47615 Mdot
.61779 .59673 Mdot
.74432 .0782 Mdot
.10943 .22565 Mdot
.32302 .13201 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49807 .61721 Mdot
.49385 .61542 Mdot
.48039 .60972 Mdot
.4376 .59159 Mdot
.3036 .53521 Mdot
.94427 .39596 Mdot
.66684 .44657 Mdot
.59629 .57443 Mdot
.50012 5e-05 Mdot
.50039 .00017 Mdot
.50124 .00053 Mdot
.50396 .00168 Mdot
.51261 .00535 Mdot
.54015 .01702 Mdot
.62727 .05384 Mdot
.88559 .15965 Mdot
.30112 .25681 Mdot
.49013 .11681 Mdot
.66436 .10767 Mdot
.04357 .23437 Mdot
.49821 .61727 Mdot
.49429 .61561 Mdot
.48181 .61032 Mdot
.44212 .5935 Mdot
.3175 .54102 Mdot
.97531 .40655 Mdot
.67 .42934 Mdot
.5739 .55864 Mdot
.5847 .00668 Mdot
.71665 .08155 Mdot
.08211 .22586 Mdot
.49827 .6173 Mdot
.49449 .6157 Mdot
.48246 .6106 Mdot
.44417 .59437 Mdot
.32385 .54367 Mdot
.99004 .41173 Mdot
.67116 .42096 Mdot
.56231 .55076 Mdot
.54457 .60707 Mdot
.59282 .02982 Mdot
.77254 .11107 Mdot
.50014 6e-05 Mdot
.50044 .00019 Mdot
.50141 .0006 Mdot
.50448 .0019 Mdot
.51427 .00605 Mdot
.54544 .01926 Mdot
.64385 .06082 Mdot
.92982 .17674 Mdot
.31769 .23971 Mdot
.48809 .10531 Mdot
.64063 .09428 Mdot
.97772 .20833 Mdot
.49925 .61772 Mdot
.49761 .61702 Mdot
.49238 .6148 Mdot
.47572 .60774 Mdot
.42278 .58532 Mdot
.25851 .51651 Mdot
.85584 .36917 Mdot
.64104 .48528 Mdot
.61116 .59957 Mdot
.7348 .07641 Mdot
.09608 .22328 Mdot
.50021 9e-05 Mdot
.50068 .00029 Mdot
.50216 .00092 Mdot
.50688 .00292 Mdot
.52193 .0093 Mdot
.56976 .02956 Mdot
.71892 .09218 Mdot
.10227 .23692 Mdot
.34256 .14851 Mdot
.38336 .02522 Mdot
.26444 .54454 Mdot
.90778 .3976 Mdot
.49781 .61711 Mdot
.49303 .61508 Mdot
.4778 .60862 Mdot
.42937 .5881 Mdot
.27843 .52475 Mdot
.89257 .37956 Mdot
.65589 .47176 Mdot
.6174 .59425 Mdot
.73948 .07545 Mdot
.09978 .22267 Mdot
.32002 .13612 Mdot
.50033 .00014 Mdot
.50106 .00045 Mdot
.50337 .00143 Mdot
.51074 .00455 Mdot
.53421 .0145 Mdot
.60859 .04597 Mdot
.83351 .13901 Mdot
.26505 .2667 Mdot
.45892 .11982 Mdot
.59185 .08216 Mdot
.85504 .16266 Mdot
.30682 .27922 Mdot
.49752 .61698 Mdot
.4921 .61468 Mdot
.47484 .60736 Mdot
.41998 .58413 Mdot
.2501 .51304 Mdot
.84149 .3655 Mdot
.63324 .48933 Mdot
.6023 .59892 Mdot
.71447 .06932 Mdot
.05944 .2132 Mdot
.31731 .15937 Mdot
.49783 .61711 Mdot
.49308 .6151 Mdot
.47796 .60869 Mdot
.42989 .58833 Mdot
.28004 .52542 Mdot
.89568 .38049 Mdot
.65684 .47042 Mdot
.61699 .5934 Mdot
.73723 .07432 Mdot
.09544 .22139 Mdot
.31892 .13811 Mdot
.50032 .00013 Mdot
.50101 .00043 Mdot
.50322 .00137 Mdot
.51026 .00435 Mdot
.53267 .01385 Mdot
.60375 .04393 Mdot
.81966 .13344 Mdot
.2518 .26708 Mdot
.44522 .11954 Mdot
.55808 .06975 Mdot
.75614 .12241 Mdot
.19276 .26984 Mdot
.49793 .61715 Mdot
.49339 .61523 Mdot
.47896 .60911 Mdot
.43304 .58966 Mdot
.28962 .5294 Mdot
.91484 .3864 Mdot
.66178 .46164 Mdot
.61172 .58709 Mdot
.71582 .06433 Mdot
.05316 .20849 Mdot
.31224 .16012 Mdot
.50056 .00024 Mdot
.50178 .00075 Mdot
.50566 .0024 Mdot
.51803 .00765 Mdot
.55739 .02433 Mdot
.68099 .07639 Mdot
.02123 .21028 Mdot
.32972 .19065 Mdot
.4288 .06123 Mdot
.42459 .61544 Mdot
.31147 .54812 Mdot
.9772 .41144 Mdot
.49768 .61705 Mdot
.49261 .6149 Mdot
.47645 .60805 Mdot
.42509 .58629 Mdot
.26546 .51938 Mdot
.86823 .37253 Mdot
.64683 .4812 Mdot
.61575 .59882 Mdot
.74337 .07888 Mdot
.10952 .22629 Mdot
.32405 .13259 Mdot
.4991 .61765 Mdot
.49714 .61682 Mdot
.49088 .61417 Mdot
.47095 .60572 Mdot
.40768 .57893 Mdot
.21356 .49806 Mdot
.78694 .35437 Mdot
.59266 .49796 Mdot
.52963 .57908 Mdot
.51079 .60639 Mdot
.50813 .61639 Mdot
.50056 .00024 Mdot
.50177 .00075 Mdot
.50565 .0024 Mdot
.51801 .00764 Mdot
.55732 .02429 Mdot
.68076 .07629 Mdot
.02069 .21009 Mdot
.32967 .19096 Mdot
.42922 .06152 Mdot
.42607 .61609 Mdot
.31597 .54999 Mdot
.98736 .41494 Mdot
.49813 .61724 Mdot
.49406 .61551 Mdot
.48106 .61 Mdot
.43973 .59249 Mdot
.31014 .53794 Mdot
.95865 .40081 Mdot
.66849 .43871 Mdot
.58644 .56732 Mdot
.62776 .02554 Mdot
.8408 .13166 Mdot
.25476 .25584 Mdot
.50016 7e-05 Mdot
.5005 .00021 Mdot
.50158 .00067 Mdot
.50504 .00214 Mdot
.51605 .00681 Mdot
.5511 .02166 Mdot
.66149 .06823 Mdot
.97465 .19354 Mdot
.32567 .21694 Mdot
.46443 .08576 Mdot
.5503 .05307 Mdot
.71035 .09892 Mdot
.50034 .00015 Mdot
.50109 .00046 Mdot
.50348 .00147 Mdot
.51108 .0047 Mdot
.53529 .01496 Mdot
.61199 .04741 Mdot
.84317 .14287 Mdot
.27332 .26585 Mdot
.46731 .11989 Mdot
.6126 .08979 Mdot
.91304 .18568 Mdot
.33753 .26235 Mdot
.50011 5e-05 Mdot
.50036 .00015 Mdot
.50116 .00049 Mdot
.50368 .00156 Mdot
.51173 .00498 Mdot
.53737 .01584 Mdot
.61855 .05017 Mdot
.86156 .15019 Mdot
.28702 .26295 Mdot
.48017 .11937 Mdot
.64365 .10104 Mdot
.99453 .21685 Mdot
.50075 .00032 Mdot
.50239 .00101 Mdot
.5076 .00322 Mdot
.52421 .01027 Mdot
.57701 .03263 Mdot
.74086 .10127 Mdot
.14306 .24857 Mdot
.35841 .1331 Mdot
.38832 .01848 Mdot
.26412 .54127 Mdot
.90212 .39431 Mdot
.67786 .47943 Mdot
.5 0 Mdot
.5 0 Mdot
.50001 0 Mdot
.50003 1e-05 Mdot
.50009 4e-05 Mdot
.50028 .00012 Mdot
.5009 .00038 Mdot
.50286 .00121 Mdot
.50911 .00386 Mdot
.52902 .01231 Mdot
.59222 .03906 Mdot
.78615 .11985 Mdot
.50022 9e-05 Mdot
.50071 .0003 Mdot
.50226 .00096 Mdot
.5072 .00305 Mdot
.52294 .00973 Mdot
.57296 .03092 Mdot
.72864 .09621 Mdot
.12089 .24243 Mdot
.34875 .14083 Mdot
.38238 .02078 Mdot
.25521 .53944 Mdot
.88943 .39197 Mdot
.4978 .6171 Mdot
.49298 .61506 Mdot
.47762 .60855 Mdot
.42882 .58787 Mdot
.27676 .52406 Mdot
.88934 .37859 Mdot
.65485 .47312 Mdot
.6177 .59507 Mdot
.74143 .07647 Mdot
.10354 .2238 Mdot
.32107 .13444 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49359 .61532 Mdot
.47959 .60938 Mdot
.43505 .59051 Mdot
.29576 .53195 Mdot
.92755 .39046 Mdot
.6643 .45533 Mdot
.60599 .582 Mdot
.69517 .05512 Mdot
.00906 .19399 Mdot
.49917 .61768 Mdot
.49735 .61691 Mdot
.49155 .61445 Mdot
.47307 .60661 Mdot
.41439 .58177 Mdot
.23339 .50617 Mdot
.81496 .35943 Mdot
.61565 .49485 Mdot
.57495 .59288 Mdot
.64256 .04178 Mdot
.89653 .15697 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49807 .61722 Mdot
.49385 .61543 Mdot
.48042 .60973 Mdot
.4377 .59163 Mdot
.30389 .53534 Mdot
.94491 .39617 Mdot
.66692 .44623 Mdot
.59587 .57412 Mdot
.6601 .03969 Mdot
.49998 .61803 Mdot
.49994 .61801 Mdot
.49981 .61795 Mdot
.49939 .61778 Mdot
.49807 .61722 Mdot
.49386 .61543 Mdot
.48043 .60974 Mdot
.43772 .59164 Mdot
.30396 .53537 Mdot
.94506 .39622 Mdot
.66694 .44615 Mdot
.49749 .61697 Mdot
.49201 .61465 Mdot
.47455 .60724 Mdot
.41908 .58375 Mdot
.24739 .51192 Mdot
.83699 .3644 Mdot
.63055 .49044 Mdot
.5987 .59835 Mdot
.70559 .06606 Mdot
.04197 .2079 Mdot
.31613 .16944 Mdot
.50035 .00015 Mdot
.50112 .00047 Mdot
.50356 .00151 Mdot
.51133 .0048 Mdot
.53609 .0153 Mdot
.61451 .04847 Mdot
.85026 .1457 Mdot
.27892 .26492 Mdot
.47278 .11981 Mdot
.626 .0947 Mdot
.94908 .19968 Mdot
.34725 .24608 Mdot
.49937 .61777 Mdot
.49799 .61718 Mdot
.49361 .61532 Mdot
.47964 .6094 Mdot
.4352 .59057 Mdot
.29624 .53215 Mdot
.92855 .39079 Mdot
.66447 .45482 Mdot
.60547 .58157 Mdot
.69335 .05431 Mdot
.005 .19261 Mdot
.50049 .00021 Mdot
.50155 .00066 Mdot
.50494 .00209 Mdot
.51574 .00667 Mdot
.5501 .02124 Mdot
.65839 .06693 Mdot
.96695 .1907 Mdot
.32473 .22112 Mdot
.4696 .08954 Mdot
.56917 .06153 Mdot
.76924 .12365 Mdot
.20631 .27012 Mdot
.50082 .00035 Mdot
.5026 .0011 Mdot
.50828 .00351 Mdot
.52638 .01118 Mdot
.58386 .03553 Mdot
.76139 .10972 Mdot
.17704 .25689 Mdot
.37861 .12458 Mdot
.41524 .02264 Mdot
.33065 .56575 Mdot
.03732 .43675 Mdot
.68853 .40247 Mdot
.50021 9e-05 Mdot
.50066 .00028 Mdot
.5021 .00089 Mdot
.5067 .00284 Mdot
.52135 .00905 Mdot
.56793 .02879 Mdot
.71333 .08986 Mdot
.09115 .23351 Mdot
.3396 .15355 Mdot
.38616 .02878 Mdot
.27616 .55005 Mdot
.93063 .40449 Mdot
.50031 .00013 Mdot
.50099 .00042 Mdot
.50314 .00133 Mdot
.51002 .00425 Mdot
.53191 .01353 Mdot
.60136 .04292 Mdot
.81277 .13066 Mdot
.24458 .26688 Mdot
.43781 .11942 Mdot
.54009 .06322 Mdot
.70189 .09999 Mdot
.09159 .24085 Mdot
.50031 .00013 Mdot
.501 .00042 Mdot
.50318 .00135 Mdot
.51012 .00429 Mdot
.53222 .01366 Mdot
.60234 .04333 Mdot
.8156 .1318 Mdot
.2476 .26699 Mdot
.4409 .11946 Mdot
.54756 .06592 Mdot
.72452 .10936 Mdot
.13715 .25502 Mdot
.4982 .61727 Mdot
.49425 .6156 Mdot
.48168 .61027 Mdot
.4417 .59332 Mdot
.3162 .54047 Mdot
.97233 .40551 Mdot
.66975 .43103 Mdot
.57621 .56022 Mdot
.59265 .01016 Mdot
.74034 .09128 Mdot
.12633 .23855 Mdot
.50011 5e-05 Mdot
.50035 .00015 Mdot
.50113 .00048 Mdot
.50359 .00152 Mdot
.51144 .00485 Mdot
.53642 .01544 Mdot
.61556 .04891 Mdot
.8532 .14687 Mdot
.28112 .26447 Mdot
.47486 .11974 Mdot
.63104 .09653 Mdot
.96232 .20474 Mdot
.49926 .61772 Mdot
.49764 .61703 Mdot
.49247 .61484 Mdot
.47602 .60786 Mdot
.42372 .58571 Mdot
.26134 .51768 Mdot
.86084 .37051 Mdot
.64348 .4837 Mdot
.61334 .59941 Mdot
.7392 .07779 Mdot
.10324 .22499 Mdot
.50058 .00025 Mdot
.50185 .00078 Mdot
.50589 .0025 Mdot
.51878 .00796 Mdot
.55975 .02533 Mdot
.68828 .07943 Mdot
.0378 .21602 Mdot
.33116 .1813 Mdot
.41615 .05253 Mdot
.38111 .59638 Mdot
.18385 .49612 Mdot
.76819 .36114 Mdot
.49743 .61695 Mdot
.49182 .61457 Mdot
.47396 .60699 Mdot
.4172 .58295 Mdot
.24176 .50961 Mdot
.82791 .36226 Mdot
.62475 .49248 Mdot
.59015 .59665 Mdot
.68365 .05779 Mdot
.99543 .19269 Mdot
.31407 .19693 Mdot
.50078 .00033 Mdot
.50248 .00105 Mdot
.50792 .00336 Mdot
.52522 .01069 Mdot
.58018 .03397 Mdot
.75039 .1052 Mdot
.15933 .25274 Mdot
.36724 .1285 Mdot
.39832 .01921 Mdot
.28706 .54927 Mdot
.9435 .4057 Mdot
.68292 .45699 Mdot
.50025 .00011 Mdot
.50079 .00034 Mdot
.50253 .00107 Mdot
.50806 .00342 Mdot
.52568 .01089 Mdot
.58164 .03459 Mdot
.75477 .107 Mdot
.16653 .25448 Mdot
.37164 .12677 Mdot
.40441 .02026 Mdot
.30227 .55491 Mdot
.97415 .41525 Mdot
.49886 .61755 Mdot
.49637 .61649 Mdot
.48843 .61313 Mdot
.46314 .6024 Mdot
.38305 .56854 Mdot
.14289 .46961 Mdot
.71606 .35424 Mdot
.52255 .49844 Mdot
.36274 .51927 Mdot
.02163 .40722 Mdot
.64818 .38723 Mdot
.49768 .61705 Mdot
.49259 .61489 Mdot
.4764 .60803 Mdot
.42495 .58624 Mdot
.26506 .51921 Mdot
.8675 .37233 Mdot
.64651 .48146 Mdot
.61555 .5989 Mdot
.74307 .07882 Mdot
.10911 .22622 Mdot
.324 .13281 Mdot
.49985 .61797 Mdot
.49954 .61784 Mdot
.49852 .61741 Mdot
.49529 .61604 Mdot
.48501 .61168 Mdot
.45227 .5978 Mdot
.349 .55421 Mdot
.05171 .4343 Mdot
.67822 .3872 Mdot
.51957 .51999 Mdot
.39022 .53809 Mdot
.49746 .61696 Mdot
.4919 .6146 Mdot
.4742 .60709 Mdot
.41796 .58328 Mdot
.24403 .51054 Mdot
.83154 .3631 Mdot
.62713 .4917 Mdot
.59378 .59742 Mdot
.69308 .06138 Mdot
.01602 .19959 Mdot
.31497 .18476 Mdot
.49844 .61737 Mdot
.49502 .61592 Mdot
.48414 .61131 Mdot
.4495 .59663 Mdot
.34037 .55059 Mdot
.02996 .42619 Mdot
.67488 .39858 Mdot
.53243 .52999 Mdot
.43828 .55985 Mdot
.25384 .50405 Mdot
.83075 .35655 Mdot
.50029 .00012 Mdot
.50093 .0004 Mdot
.50297 .00126 Mdot
.50948 .00402 Mdot
.53019 .0128 Mdot
.59591 .04062 Mdot
.79694 .12425 Mdot
.2264 .26542 Mdot
.41974 .11949 Mdot
.49774 .0482 Mdot
.57235 .04611 Mdot
.75177 .11089 Mdot
.49806 .61721 Mdot
.49382 .61541 Mdot
.48031 .60969 Mdot
.43734 .59148 Mdot
.3028 .53488 Mdot
.94254 .39538 Mdot
.66661 .4475 Mdot
.59739 .57525 Mdot
.66529 .04197 Mdot
.93891 .16911 Mdot
.30193 .22436 Mdot
1 0 0 r
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .0019 Mdot
.49552 .00606 Mdot
.48572 .01928 Mdot
.45452 .06087 Mdot
.35603 .17686 Mdot
.06986 .23957 Mdot
.68223 .1052 Mdot
.51202 .09407 Mdot
.35981 .20787 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49445 .00749 Mdot
.48233 .02384 Mdot
.44375 .07491 Mdot
.32255 .20738 Mdot
.987 .19535 Mdot
.67093 .06564 Mdot
.56472 .00728 Mdot
.55293 .57715 Mdot
.61909 .47676 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49583 .00563 Mdot
.48672 .01793 Mdot
.45771 .05667 Mdot
.36601 .16673 Mdot
.09624 .25061 Mdot
.69075 .11317 Mdot
.50763 .10609 Mdot
.33597 .23263 Mdot
.95956 .19555 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61507 Mdot
.507 .60858 Mdot
.52229 .58798 Mdot
.57091 .5244 Mdot
.72242 .37906 Mdot
.10908 .47245 Mdot
.34463 .59467 Mdot
.38243 .07599 Mdot
.25948 .22327 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50882 .60612 Mdot
.5281 .5802 Mdot
.58932 .50168 Mdot
.77759 .35634 Mdot
.20101 .49695 Mdot
.39692 .58597 Mdot
.4488 .01459 Mdot
.4252 .08141 Mdot
.29348 .22348 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48894 .01494 Mdot
.46477 .04733 Mdot
.3882 .14266 Mdot
.15738 .26591 Mdot
.72712 .11989 Mdot
.53314 .08939 Mdot
.3885 .18451 Mdot
.08996 .26354 Mdot
.66355 .13723 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00183 Mdot
.49569 .00583 Mdot
.48626 .01855 Mdot
.45625 .0586 Mdot
.36143 .17144 Mdot
.08403 .24577 Mdot
.68637 .10987 Mdot
.5086 .1019 Mdot
.34373 .22459 Mdot
.98033 .2064 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49212 .01064 Mdot
.47491 .03381 Mdot
.42021 .10471 Mdot
.25078 .25226 Mdot
.84262 .129 Mdot
.63389 .019 Mdot
.60314 .54797 Mdot
.7165 .40368 Mdot
.06333 .46086 Mdot
.50004 .61798 Mdot
.50013 .61785 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.50429 .61223 Mdot
.51368 .59956 Mdot
.54357 .55967 Mdot
.638 .44718 Mdot
.91444 .37163 Mdot
.31313 .50772 Mdot
.49162 .51548 Mdot
.50074 .61704 Mdot
.50235 .61485 Mdot
.5075 .60791 Mdot
.52388 .58585 Mdot
.57596 .51807 Mdot
.7377 .37097 Mdot
.13746 .48314 Mdot
.35573 .59931 Mdot
.38603 .07813 Mdot
.2596 .22541 Mdot
.89488 .13489 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48962 .01401 Mdot
.46695 .04443 Mdot
.39507 .13481 Mdot
.17695 .26708 Mdot
.74481 .11961 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50739 .60805 Mdot
.52353 .58632 Mdot
.57485 .51945 Mdot
.73436 .37262 Mdot
.13145 .48109 Mdot
.35303 .59879 Mdot
.38417 .0789 Mdot
.25651 .22632 Mdot
.89032 .1325 Mdot
.50099 .61669 Mdot
.50316 .61376 Mdot
.51008 .60442 Mdot
.5321 .57486 Mdot
.60195 .48668 Mdot
.81449 .35108 Mdot
.24643 .49859 Mdot
.43969 .55317 Mdot
.54464 .51233 Mdot
.71567 .3682 Mdot
.1199 .46914 Mdot
.50035 .61757 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.5112 .60291 Mdot
.53568 .57011 Mdot
.61322 .47378 Mdot
.84664 .3526 Mdot
.27611 .49817 Mdot
.47006 .52576 Mdot
.61936 .4252 Mdot
.93138 .36353 Mdot
.50002 .61801 Mdot
.50007 .61794 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50685 .60878 Mdot
.52183 .5886 Mdot
.56946 .52623 Mdot
.71801 .38165 Mdot
.10049 .46874 Mdot
.34205 .59229 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60904 Mdot
.52121 .58944 Mdot
.56747 .52875 Mdot
.71194 .3854 Mdot
.08834 .46316 Mdot
.33893 .58826 Mdot
.3871 .06633 Mdot
.27978 .2113 Mdot
.93789 .15517 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50702 .60855 Mdot
.52236 .58789 Mdot
.57113 .52412 Mdot
.72309 .37868 Mdot
.11037 .47299 Mdot
.34505 .595 Mdot
.38233 .07638 Mdot
.5011 .61655 Mdot
.50349 .61331 Mdot
.51113 .603 Mdot
.53545 .57041 Mdot
.6125 .47459 Mdot
.84461 .35235 Mdot
.27449 .49815 Mdot
.46847 .5272 Mdot
.61545 .42931 Mdot
.9208 .35889 Mdot
.34011 .48341 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50561 .61046 Mdot
.51787 .59392 Mdot
.55689 .5423 Mdot
.67943 .40903 Mdot
.01761 .42532 Mdot
.32943 .55486 Mdot
.43165 .6163 Mdot
.43445 .05733 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49246 .01019 Mdot
.47597 .03238 Mdot
.42359 .10053 Mdot
.26093 .24772 Mdot
.8601 .1341 Mdot
.64312 .01859 Mdot
.61305 .54042 Mdot
.73863 .39325 Mdot
.10234 .48172 Mdot
.50011 .61788 Mdot
.50035 .61756 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .60261 Mdot
.53639 .56917 Mdot
.61546 .47128 Mdot
.85291 .35352 Mdot
.28091 .49829 Mdot
.47466 .52168 Mdot
.63056 .41377 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00438 Mdot
.48967 .01395 Mdot
.46711 .04422 Mdot
.39556 .13424 Mdot
.17836 .26709 Mdot
.7462 .11958 Mdot
.55271 .07161 Mdot
.43685 .12863 Mdot
.22873 .27485 Mdot
.784 .13066 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.49309 .00934 Mdot
.47798 .02969 Mdot
.42995 .09255 Mdot
.2802 .23745 Mdot
.896 .14775 Mdot
.65693 .02472 Mdot
.61694 .54384 Mdot
.73698 .39679 Mdot
.09497 .4797 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00543 Mdot
.48719 .0173 Mdot
.45919 .05472 Mdot
.37065 .16186 Mdot
.10875 .25502 Mdot
.69613 .11584 Mdot
.50869 .1078 Mdot
.33427 .23514 Mdot
.95381 .19292 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48908 .01475 Mdot
.46522 .04674 Mdot
.38959 .14108 Mdot
.16133 .26631 Mdot
.73043 .11988 Mdot
.53647 .08636 Mdot
.39673 .17553 Mdot
.11272 .2715 Mdot
.67342 .14071 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50867 .60632 Mdot
.52763 .58083 Mdot
.58782 .50348 Mdot
.77317 .3575 Mdot
.19472 .49623 Mdot
.3918 .58899 Mdot
.43878 .02632 Mdot
.39619 .11588 Mdot
.20869 .25848 Mdot
.50106 .61661 Mdot
.50336 .61349 Mdot
.51071 .60357 Mdot
.53411 .57219 Mdot
.60829 .47937 Mdot
.83265 .35128 Mdot
.26428 .49823 Mdot
.45812 .5366 Mdot
.58988 .45764 Mdot
.8494 .33795 Mdot
.30259 .47751 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50724 .60826 Mdot
.52305 .58697 Mdot
.57332 .52137 Mdot
.72972 .37503 Mdot
.12291 .47798 Mdot
.34953 .5976 Mdot
.38259 .07881 Mdot
.25507 .22628 Mdot
.88894 .13148 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00267 Mdot
.49371 .0085 Mdot
.47996 .02702 Mdot
.43624 .08457 Mdot
.2994 .22506 Mdot
.93525 .16667 Mdot
.66556 .03941 Mdot
.60179 .56938 Mdot
.68052 .43568 Mdot
.97558 .41312 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50628 .60955 Mdot
.52001 .59105 Mdot
.56367 .53358 Mdot
.70031 .39317 Mdot
.06415 .45104 Mdot
.33434 .57835 Mdot
.39856 .04812 Mdot
.3207 .18134 Mdot
.02728 .20651 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.505 .61128 Mdot
.51593 .59654 Mdot
.5507 .55033 Mdot
.66026 .42562 Mdot
.97159 .39942 Mdot
.32531 .53075 Mdot
.46653 .56155 Mdot
.55792 .50903 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50528 .61089 Mdot
.51684 .59532 Mdot
.55359 .54657 Mdot
.66923 .41762 Mdot
.99351 .4116 Mdot
.32752 .54199 Mdot
.45057 .58708 Mdot
.50065 .58648 Mdot
.50066 .61714 Mdot
.50212 .61518 Mdot
.50674 .60893 Mdot
.52148 .58908 Mdot
.56832 .52767 Mdot
.71454 .38377 Mdot
.09359 .46562 Mdot
.34021 .59009 Mdot
.38542 .06934 Mdot
.27323 .21531 Mdot
.92484 .1482 Mdot
.50121 .61641 Mdot
.50384 .61284 Mdot
.51224 .60151 Mdot
.53897 .56574 Mdot
.62358 .46235 Mdot
.87548 .35833 Mdot
.29568 .49984 Mdot
.48692 .51196 Mdot
.65855 .38811 Mdot
.03057 .41628 Mdot
.35702 .5317 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48822 .01591 Mdot
.46247 .05038 Mdot
.38095 .15074 Mdot
.13705 .26266 Mdot
.71206 .11929 Mdot
.51904 .10168 Mdot
.35452 .21854 Mdot
.00092 .21939 Mdot
.64594 .10227 Mdot
.50076 .61701 Mdot
.50242 .61476 Mdot
.50772 .6076 Mdot
.52461 .58488 Mdot
.57826 .51522 Mdot
.74461 .36776 Mdot
.14957 .48689 Mdot
.36177 .59952 Mdot
.39172 .07431 Mdot
.27148 .22051 Mdot
.91469 .14516 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51012 .60437 Mdot
.53222 .57471 Mdot
.60233 .48625 Mdot
.81556 .35104 Mdot
.24756 .49857 Mdot
.44086 .55215 Mdot
.54746 .5088 Mdot
.72421 .36319 Mdot
.13655 .47481 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49527 .00639 Mdot
.48492 .02035 Mdot
.45199 .06418 Mdot
.34814 .18456 Mdot
.04952 .22973 Mdot
.67781 .0971 Mdot
.5207 .07797 Mdot
.39455 .16873 Mdot
.12154 .27077 Mdot
.50014 .61784 Mdot
.50046 .61742 Mdot
.50146 .61606 Mdot
.50464 .61176 Mdot
.5148 .59806 Mdot
.54712 .55502 Mdot
.64908 .43616 Mdot
.94336 .38475 Mdot
.32082 .51793 Mdot
.4828 .53384 Mdot
.61902 .43351 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48761 .01672 Mdot
.46056 .05291 Mdot
.37494 .15728 Mdot
.12045 .25859 Mdot
.70204 .11769 Mdot
.51162 .10693 Mdot
.3386 .2322 Mdot
.96289 .19811 Mdot
.64234 .08305 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48716 .01733 Mdot
.45912 .05482 Mdot
.37043 .1621 Mdot
.10814 .25481 Mdot
.69584 .11573 Mdot
.50859 .10777 Mdot
.3342 .23515 Mdot
.95373 .19285 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01037 Mdot
.47555 .03295 Mdot
.42223 .10221 Mdot
.25685 .24962 Mdot
.85296 .13189 Mdot
.63956 .01846 Mdot
.6097 .54266 Mdot
.73165 .3961 Mdot
.5013 .61628 Mdot
.50413 .61246 Mdot
.51315 .60028 Mdot
.54188 .5619 Mdot
.6327 .45265 Mdot
.90029 .36614 Mdot
.30785 .50405 Mdot
.49229 .5112 Mdot
.66515 .38413 Mdot
.04362 .42406 Mdot
.35747 .53922 Mdot
.50085 .61689 Mdot
.5027 .61438 Mdot
.50861 .6064 Mdot
.52743 .5811 Mdot
.58718 .50426 Mdot
.77127 .35803 Mdot
.19196 .49588 Mdot
.38962 .59019 Mdot
.43467 .03104 Mdot
.38444 .12901 Mdot
.1757 .26076 Mdot
.50082 .61693 Mdot
.5026 .61451 Mdot
.5083 .60682 Mdot
.52644 .58243 Mdot
.58405 .50808 Mdot
.76195 .36096 Mdot
.17791 .49362 Mdot
.37921 .59515 Mdot
.41624 .05124 Mdot
.33333 .17901 Mdot
.04368 .219 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49446 .00748 Mdot
.48236 .0238 Mdot
.44385 .07478 Mdot
.32286 .20713 Mdot
.98772 .19575 Mdot
.67098 .06602 Mdot
.56415 .00815 Mdot
.55096 .57974 Mdot
.61292 .48362 Mdot
.50065 .61715 Mdot
.50207 .61523 Mdot
.50661 .60911 Mdot
.52106 .58964 Mdot
.56699 .52936 Mdot
.71047 .38634 Mdot
.08537 .46174 Mdot
.33826 .58717 Mdot
.3882 .06446 Mdot
.2839 .20867 Mdot
.94625 .15979 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00354 Mdot
.49166 .01126 Mdot
.47344 .03576 Mdot
.41558 .11041 Mdot
.23693 .25746 Mdot
.82035 .12409 Mdot
.61956 .02339 Mdot
.58171 .56896 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61024 Mdot
.51837 .59325 Mdot
.55847 .54025 Mdot
.68432 .4051 Mdot
.02887 .43171 Mdot
.33035 .56085 Mdot
.42288 .01155 Mdot
.4042 .09509 Mdot
.25033 .24264 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01038 Mdot
.47552 .03298 Mdot
.42216 .10229 Mdot
.25665 .24971 Mdot
.85261 .13178 Mdot
.63938 .01846 Mdot
.60951 .5428 Mdot
.50092 .61679 Mdot
.50294 .61407 Mdot
.50935 .6054 Mdot
.52979 .57795 Mdot
.59466 .49528 Mdot
.79328 .35315 Mdot
.22187 .4984 Mdot
.41544 .57315 Mdot
.48806 .58421 Mdot
.54278 .54503 Mdot
.6609 .42001 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.5054 .61074 Mdot
.51719 .59483 Mdot
.55473 .54509 Mdot
.67277 .41458 Mdot
.00197 .4164 Mdot
.32822 .54648 Mdot
.44399 .59734 Mdot
.47747 .00012 Mdot
.47727 .02112 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49555 .00602 Mdot
.48581 .01915 Mdot
.45483 .06047 Mdot
.35699 .17591 Mdot
.07237 .24071 Mdot
.68289 .10609 Mdot
.51124 .09567 Mdot
.35644 .21143 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50642 .60937 Mdot
.52044 .59047 Mdot
.56504 .53183 Mdot
.70452 .39027 Mdot
.07304 .45564 Mdot
.33581 .58225 Mdot
.39371 .05559 Mdot
.30376 .1948 Mdot
.98858 .18422 Mdot
.49982 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49433 .00766 Mdot
.48194 .02437 Mdot
.4425 .07652 Mdot
.31869 .21053 Mdot
.97805 .19024 Mdot
.67022 .06085 Mdot
.57177 .61458 Mdot
.57735 .54567 Mdot
.69444 .40702 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01312 Mdot
.46905 .04163 Mdot
.4017 .12707 Mdot
.19609 .26623 Mdot
.76531 .11937 Mdot
.57217 .05474 Mdot
.48359 .06992 Mdot
.37045 .17719 Mdot
.08375 .2513 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61085 Mdot
.51693 .59518 Mdot
.55391 .54616 Mdot
.6702 .41678 Mdot
.99584 .41292 Mdot
.32772 .54322 Mdot
.44877 .5899 Mdot
.49429 .59519 Mdot
.53125 .56641 Mdot
.50075 .61702 Mdot
.5024 .6148 Mdot
.50763 .60772 Mdot
.52432 .58527 Mdot
.57733 .51637 Mdot
.74183 .36902 Mdot
.14475 .48546 Mdot
.35926 .59958 Mdot
.38913 .07621 Mdot
.26581 .22303 Mdot
.90494 .14005 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.4977 .00311 Mdot
.49266 .00991 Mdot
.47662 .03151 Mdot
.42563 .09797 Mdot
.26711 .24467 Mdot
.87122 .13789 Mdot
.64811 .01956 Mdot
.61645 .53902 Mdot
.7443 .39157 Mdot
.11073 .48614 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.4873 .01715 Mdot
.45956 .05424 Mdot
.37179 .16065 Mdot
.11186 .25602 Mdot
.69761 .1164 Mdot
.50928 .1078 Mdot
.33486 .23486 Mdot
.95484 .19356 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50865 .60635 Mdot
.52756 .58092 Mdot
.58761 .50374 Mdot
.77255 .35767 Mdot
.19382 .49612 Mdot
.39108 .58939 Mdot
.43742 .02789 Mdot
.3923 .12029 Mdot
.19767 .25993 Mdot
.49997 5e-05 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00468 Mdot
.48895 .01492 Mdot
.46482 .04727 Mdot
.38834 .1425 Mdot
.15777 .26595 Mdot
.72745 .11989 Mdot
.53346 .08909 Mdot
.38931 .18364 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51484 .59801 Mdot
.54724 .55486 Mdot
.64945 .43579 Mdot
.94433 .38523 Mdot
.32102 .51833 Mdot
.48235 .53466 Mdot
.61726 .43552 Mdot
.91257 .35848 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00214 Mdot
.49495 .00683 Mdot
.4839 .02173 Mdot
.44873 .06844 Mdot
.338 .194 Mdot
.0241 .21626 Mdot
.67419 .08514 Mdot
.53644 .05165 Mdot
.45286 .09471 Mdot
.29961 .23515 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00332 Mdot
.49217 .01058 Mdot
.47505 .03361 Mdot
.42067 .10414 Mdot
.25217 .25167 Mdot
.84496 .12962 Mdot
.63523 .0188 Mdot
.60481 .54655 Mdot
.49962 .00051 Mdot
.4988 .00161 Mdot
.49619 .00514 Mdot
.48787 .01638 Mdot
.46136 .05185 Mdot
.37747 .15455 Mdot
.1274 .26044 Mdot
.706 .1185 Mdot
.51426 .1053 Mdot
.34389 .22791 Mdot
.97513 .20494 Mdot
.64353 .0892 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50496 .61133 Mdot
.5158 .59671 Mdot
.5503 .55085 Mdot
.65901 .42676 Mdot
.96849 .39775 Mdot
.32493 .52924 Mdot
.4686 .55817 Mdot
.56546 .49917 Mdot
.75778 .35181 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49786 .00289 Mdot
.49318 .00922 Mdot
.47826 .02931 Mdot
.43084 .09143 Mdot
.2829 .23583 Mdot
.90132 .1501 Mdot
.65845 .0263 Mdot
.50043 .61745 Mdot
.50138 .61618 Mdot
.50438 .61211 Mdot
.51397 .59918 Mdot
.54447 .55849 Mdot
.64081 .44433 Mdot
.92187 .37478 Mdot
.31548 .51001 Mdot
.49026 .51903 Mdot
.65045 .39942 Mdot
.00419 .4033 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50686 .60877 Mdot
.52185 .58858 Mdot
.56951 .52617 Mdot
.71814 .38158 Mdot
.10074 .46885 Mdot
.34212 .59236 Mdot
.38365 .07284 Mdot
.2658 .21965 Mdot
.9104 .14091 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.5118 .6021 Mdot
.53759 .56757 Mdot
.61925 .46708 Mdot
.8635 .35549 Mdot
.28831 .49878 Mdot
.48127 .5161 Mdot
.6462 .39884 Mdot
.00085 .39963 Mdot
.35423 .51665 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48716 .01734 Mdot
.4591 .05484 Mdot
.37037 .16216 Mdot
.10799 .25476 Mdot
.69577 .1157 Mdot
.50856 .10777 Mdot
.33419 .23515 Mdot
.95371 .19284 Mdot
.64169 .07816 Mdot
.50119 .61643 Mdot
.50379 .61292 Mdot
.51207 .60174 Mdot
.53844 .56645 Mdot
.62191 .46416 Mdot
.87089 .35717 Mdot
.29298 .49937 Mdot
.48499 .51327 Mdot
.6545 .39149 Mdot
.02106 .41096 Mdot
.35612 .5269 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49817 .00248 Mdot
.49416 .00789 Mdot
.4814 .02509 Mdot
.44079 .07872 Mdot
.31341 .21471 Mdot
.966 .18343 Mdot
.6692 .0545 Mdot
.58102 .60063 Mdot
.60919 .50716 Mdot
.78858 .36393 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00467 Mdot
.489 .01486 Mdot
.46496 .04708 Mdot
.38878 .142 Mdot
.15902 .26609 Mdot
.72848 .11989 Mdot
.5345 .08815 Mdot
.39187 .18086 Mdot
.09922 .267 Mdot
.6672 .13898 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00647 Mdot
.48475 .02058 Mdot
.45144 .0649 Mdot
.34643 .18618 Mdot
.04518 .2275 Mdot
.67707 .09518 Mdot
.52306 .07388 Mdot
.40351 .15796 Mdot
.14793 .27618 Mdot
.5 .61803 Mdot
.5 .61803 Mdot
.50001 .61801 Mdot
.50005 .61797 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.5047 .61168 Mdot
.51499 .59781 Mdot
.54771 .55423 Mdot
.65094 .43436 Mdot
.50012 .61787 Mdot
.50038 .61753 Mdot
.5012 .61641 Mdot
.50382 .61288 Mdot
.51217 .60161 Mdot
.53874 .56605 Mdot
.62286 .46313 Mdot
.8735 .35782 Mdot
.29453 .49963 Mdot
.48612 .51248 Mdot
.65691 .38946 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60706 Mdot
.52587 .58319 Mdot
.58225 .51028 Mdot
.7566 .36286 Mdot
.16947 .49192 Mdot
.37352 .59722 Mdot
.40721 .06041 Mdot
.30946 .19778 Mdot
.98945 .18801 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49732 .00362 Mdot
.49147 .01152 Mdot
.47284 .03657 Mdot
.41367 .11273 Mdot
.23127 .25926 Mdot
.81178 .12269 Mdot
.61327 .02633 Mdot
.57067 .58098 Mdot
.63062 .47303 Mdot
.86525 .36251 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60702 Mdot
.52597 .58305 Mdot
.58257 .50989 Mdot
.75755 .36251 Mdot
.171 .49225 Mdot
.37452 .59689 Mdot
.40873 .05891 Mdot
.31341 .1949 Mdot
.99806 .1931 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50702 .60855 Mdot
.52236 .58789 Mdot
.57113 .52412 Mdot
.72309 .37868 Mdot
.11038 .473 Mdot
.34505 .595 Mdot
.38232 .07638 Mdot
.25873 .22371 Mdot
.89676 .13457 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50639 .6094 Mdot
.52037 .59056 Mdot
.56482 .53212 Mdot
.70384 .39073 Mdot
.07162 .45491 Mdot
.33556 .58165 Mdot
.39444 .05445 Mdot
.30633 .19285 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50891 .60599 Mdot
.5284 .57981 Mdot
.59025 .50056 Mdot
.78033 .35568 Mdot
.20482 .49732 Mdot
.40014 .58394 Mdot
.45529 .00681 Mdot
.44427 .05742 Mdot
.35136 .17605 Mdot
.50128 .61631 Mdot
.50407 .61254 Mdot
.51295 .60055 Mdot
.54125 .56273 Mdot
.63073 .45472 Mdot
.89498 .36427 Mdot
.30558 .50291 Mdot
.49185 .51046 Mdot
.6659 .38304 Mdot
.04613 .42521 Mdot
.35813 .53999 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49465 .00722 Mdot
.48297 .02298 Mdot
.44578 .07228 Mdot
.32882 .2021 Mdot
.00181 .20378 Mdot
.67209 .07357 Mdot
.55305 .02529 Mdot
.51213 .01406 Mdot
.48938 .0239 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.5108 .60344 Mdot
.53441 .57179 Mdot
.60923 .47829 Mdot
.83534 .35146 Mdot
.26668 .49819 Mdot
.46059 .53436 Mdot
.59598 .45067 Mdot
.86678 .3411 Mdot
.31488 .47655 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51666 .59555 Mdot
.55304 .54728 Mdot
.66752 .41911 Mdot
.98938 .40927 Mdot
.32716 .53981 Mdot
.45372 .58212 Mdot
.50003 .618 Mdot
.50009 .61792 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50877 .60619 Mdot
.52793 .58043 Mdot
.58878 .50232 Mdot
.776 .35674 Mdot
.19878 .49671 Mdot
.39508 .58709 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49791 .00283 Mdot
.49333 .00901 Mdot
.47876 .02864 Mdot
.43242 .08943 Mdot
.28772 .23285 Mdot
.91096 .15455 Mdot
.6609 .02952 Mdot
.61314 .55129 Mdot
.72114 .40616 Mdot
.06395 .46387 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01028 Mdot
.47576 .03266 Mdot
.42291 .10136 Mdot
.2589 .24868 Mdot
.85653 .13297 Mdot
.64138 .01847 Mdot
.61149 .5414 Mdot
.73548 .39447 Mdot
.09722 .47909 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .0054 Mdot
.48727 .01718 Mdot
.45947 .05435 Mdot
.37152 .16094 Mdot
.11113 .25579 Mdot
.69726 .11627 Mdot
.50913 .10781 Mdot
.33468 .23496 Mdot
.95451 .19336 Mdot
.64165 .07871 Mdot
.50092 .61679 Mdot
.50293 .61407 Mdot
.50934 .60542 Mdot
.52976 .57799 Mdot
.59454 .49541 Mdot
.79295 .35321 Mdot
.22145 .49838 Mdot
.41505 .57345 Mdot
.48719 .58532 Mdot
.54012 .54852 Mdot
.6526 .42775 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49261 .00998 Mdot
.47645 .03173 Mdot
.42511 .09863 Mdot
.26552 .24548 Mdot
.86833 .13687 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00805 Mdot
.48101 .02561 Mdot
.43958 .08029 Mdot
.30967 .21758 Mdot
.95761 .17875 Mdot
.66839 .05018 Mdot
.58719 .59137 Mdot
.63033 .48361 Mdot
.84784 .36307 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01801 Mdot
.45753 .05691 Mdot
.36544 .16732 Mdot
.09471 .25003 Mdot
.69015 .11279 Mdot
.50765 .10571 Mdot
.33661 .23194 Mdot
.96134 .19644 Mdot
.64348 .08073 Mdot
.50106 .61661 Mdot
.50337 .61349 Mdot
.51072 .60355 Mdot
.53416 .57213 Mdot
.60844 .4792 Mdot
.83307 .3513 Mdot
.26465 .49822 Mdot
.45851 .53625 Mdot
.59084 .45653 Mdot
.85216 .33835 Mdot
.30469 .47727 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49231 .01038 Mdot
.47551 .03299 Mdot
.42213 .10234 Mdot
.25655 .24976 Mdot
.85243 .13173 Mdot
.63929 .01847 Mdot
.60941 .54287 Mdot
.73103 .39637 Mdot
.08969 .47519 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49159 .01136 Mdot
.47321 .03608 Mdot
.41483 .11132 Mdot
.23471 .25819 Mdot
.81695 .12351 Mdot
.61712 .02447 Mdot
.57752 .57344 Mdot
.64967 .45426 Mdot
.91467 .37889 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.5049 .61141 Mdot
.51562 .59695 Mdot
.54973 .5516 Mdot
.65723 .42842 Mdot
.96403 .39536 Mdot
.32433 .5271 Mdot
.47146 .55341 Mdot
.57602 .48559 Mdot
.79032 .34275 Mdot
.49992 .00011 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49726 .00371 Mdot
.49126 .01181 Mdot
.47216 .03749 Mdot
.4115 .11536 Mdot
.22484 .26107 Mdot
.80242 .12146 Mdot
.6059 .03037 Mdot
.55677 .59688 Mdot
.591 .51705 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50457 .61186 Mdot
.51456 .59839 Mdot
.54635 .55602 Mdot
.64669 .43849 Mdot
.9372 .38177 Mdot
.31949 .51547 Mdot
.48544 .52895 Mdot
.62957 .42167 Mdot
.94729 .3737 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01324 Mdot
.46876 .04202 Mdot
.40078 .12816 Mdot
.19342 .26647 Mdot
.76225 .11937 Mdot
.56911 .05729 Mdot
.47642 .07907 Mdot
.34848 .19926 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49158 .01137 Mdot
.47319 .03611 Mdot
.41476 .11141 Mdot
.23449 .25826 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60703 Mdot
.52596 .58307 Mdot
.58253 .50994 Mdot
.75743 .36256 Mdot
.1708 .49221 Mdot
.37439 .59693 Mdot
.40853 .05911 Mdot
.3129 .19528 Mdot
.50108 .61657 Mdot
.50345 .61337 Mdot
.511 .60318 Mdot
.53505 .57095 Mdot
.61123 .47602 Mdot
.84101 .35195 Mdot
.27154 .49815 Mdot
.46553 .52986 Mdot
.6082 .4371 Mdot
.90095 .35109 Mdot
.33287 .47908 Mdot
.50082 .61692 Mdot
.50263 .61449 Mdot
.50837 .60673 Mdot
.52666 .58213 Mdot
.58475 .50722 Mdot
.76404 .36025 Mdot
.18114 .4942 Mdot
.3815 .59418 Mdot
.42009 .04715 Mdot
.3438 .16981 Mdot
.06904 .23182 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51438 .59862 Mdot
.54579 .55676 Mdot
.64493 .44021 Mdot
.93266 .37963 Mdot
.31841 .51375 Mdot
.48714 .52566 Mdot
.6366 .41402 Mdot
.96671 .38337 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50974 .60488 Mdot
.53103 .57629 Mdot
.59858 .49064 Mdot
.80471 .35172 Mdot
.23561 .49867 Mdot
.42876 .56253 Mdot
.51856 .54536 Mdot
.63615 .43398 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50923 .60557 Mdot
.52939 .57848 Mdot
.5934 .49677 Mdot
.78961 .35377 Mdot
.21719 .49819 Mdot
.41109 .57639 Mdot
.47847 .59629 Mdot
.51365 .58366 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60316 Mdot
.53509 .57089 Mdot
.61138 .47585 Mdot
.84143 .35199 Mdot
.27189 .49815 Mdot
.46588 .52954 Mdot
.60906 .43616 Mdot
.90334 .35196 Mdot
.33386 .4795 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49703 .00401 Mdot
.49054 .01277 Mdot
.46988 .04052 Mdot
.40431 .12398 Mdot
.2037 .26533 Mdot
.77439 .11951 Mdot
.58101 .04761 Mdot
.50397 .04394 Mdot
.43288 .10433 Mdot
.26406 .2513 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48933 .0144 Mdot
.46603 .04566 Mdot
.39214 .13817 Mdot
.16857 .26683 Mdot
.73684 .11978 Mdot
.54303 .08038 Mdot
.41297 .1571 Mdot
.15878 .28107 Mdot
.70401 .13964 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48761 .01673 Mdot
.46053 .05295 Mdot
.37486 .15737 Mdot
.12023 .25853 Mdot
.70192 .11766 Mdot
.51154 .10697 Mdot
.33846 .2323 Mdot
.96259 .19794 Mdot
.50051 .61735 Mdot
.50162 .61584 Mdot
.50517 .61104 Mdot
.51648 .59579 Mdot
.55247 .54802 Mdot
.66575 .42067 Mdot
.98508 .40687 Mdot
.32676 .53758 Mdot
.45694 .57702 Mdot
.5233 .5555 Mdot
.62448 .45151 Mdot
.49969 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48982 .01375 Mdot
.46757 .04361 Mdot
.39701 .13255 Mdot
.18254 .26704 Mdot
.75045 .1195 Mdot
.5571 .06769 Mdot
.44758 .11541 Mdot
.26086 .26261 Mdot
.83595 .13606 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49345 .00885 Mdot
.47912 .02816 Mdot
.43356 .08798 Mdot
.2912 .23061 Mdot
.91807 .15796 Mdot
.66248 .03217 Mdot
.61042 .55586 Mdot
.71102 .41272 Mdot
.04322 .4523 Mdot
.50095 .61675 Mdot
.50302 .61395 Mdot
.50964 .60502 Mdot
.53069 .57674 Mdot
.5975 .4919 Mdot
.80158 .35204 Mdot
.23197 .49864 Mdot
.42515 .5655 Mdot
.51016 .55609 Mdot
.61038 .46177 Mdot
.86323 .35001 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00314 Mdot
.4926 .00999 Mdot
.47644 .03175 Mdot
.42507 .09867 Mdot
.26541 .24553 Mdot
.86814 .1368 Mdot
.64679 .0192 Mdot
.61572 .53916 Mdot
.74333 .39175 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .01391 Mdot
.4672 .0441 Mdot
.39585 .1339 Mdot
.17919 .26708 Mdot
.74704 .11957 Mdot
.55358 .07083 Mdot
.43897 .12604 Mdot
.23504 .27293 Mdot
.79343 .13084 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00517 Mdot
.48781 .01646 Mdot
.46118 .05209 Mdot
.3769 .15517 Mdot
.12583 .26004 Mdot
.70508 .11834 Mdot
.51361 .10574 Mdot
.34252 .22905 Mdot
.97192 .20315 Mdot
.50038 .61752 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .60139 Mdot
.53925 .56537 Mdot
.62445 .4614 Mdot
.87789 .35898 Mdot
.29704 .50013 Mdot
.48781 .51142 Mdot
.66032 .38668 Mdot
.03466 .41856 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00312 Mdot
.49264 .00995 Mdot
.47654 .03162 Mdot
.42538 .09829 Mdot
.26635 .24505 Mdot
.86985 .1374 Mdot
.64753 .0194 Mdot
.61615 .53906 Mdot
.74393 .39162 Mdot
.11026 .48586 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00236 Mdot
.49444 .00752 Mdot
.48227 .02392 Mdot
.44357 .07514 Mdot
.32199 .20785 Mdot
.98568 .1946 Mdot
.67082 .06493 Mdot
.56576 .00569 Mdot
.55654 .5724 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.5394 .56518 Mdot
.62492 .4609 Mdot
.87916 .35934 Mdot
.29774 .50029 Mdot
.48825 .51117 Mdot
.66116 .38602 Mdot
.03656 .41962 Mdot
.3576 .53471 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60082 Mdot
.54061 .56357 Mdot
.62873 .45683 Mdot
.88957 .36247 Mdot
.30308 .50189 Mdot
.49101 .51022 Mdot
.66546 .383 Mdot
.04575 .42483 Mdot
.35836 .53948 Mdot
.5009 .61681 Mdot
.50288 .61415 Mdot
.50917 .60565 Mdot
.5292 .57873 Mdot
.59279 .4975 Mdot
.78782 .3541 Mdot
.21487 .49807 Mdot
.40898 .57792 Mdot
.47388 .60202 Mdot
.49979 .60222 Mdot
.52537 .5788 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .60219 Mdot
.53737 .56787 Mdot
.61854 .46786 Mdot
.86152 .35508 Mdot
.28699 .49866 Mdot
.48015 .51702 Mdot
.6436 .40123 Mdot
.99439 .39603 Mdot
.35359 .51341 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.4884 .01566 Mdot
.46306 .04959 Mdot
.38282 .14867 Mdot
.14226 .26368 Mdot
.71561 .11957 Mdot
.52214 .09911 Mdot
.36179 .21173 Mdot
.0192 .22949 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.4883 .0158 Mdot
.46272 .05004 Mdot
.38175 .14986 Mdot
.13928 .26311 Mdot
.71355 .11942 Mdot
.52032 .10063 Mdot
.3575 .21578 Mdot
.00835 .22352 Mdot
.64669 .10599 Mdot
.49961 .00053 Mdot
.49875 .00168 Mdot
.49603 .00537 Mdot
.48735 .01709 Mdot
.4597 .05405 Mdot
.37225 .16017 Mdot
.11309 .25641 Mdot
.69822 .1166 Mdot
.50955 .10775 Mdot
.33521 .23465 Mdot
.95553 .19396 Mdot
.64169 .07928 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00264 Mdot
.49377 .00842 Mdot
.48014 .02679 Mdot
.4368 .08385 Mdot
.30112 .22385 Mdot
.93892 .16861 Mdot
.66611 .04109 Mdot
.59962 .57268 Mdot
.67301 .44207 Mdot
.95772 .40334 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .60891 Mdot
.52152 .58902 Mdot
.56848 .52748 Mdot
.715 .38348 Mdot
.09451 .46604 Mdot
.34044 .5904 Mdot
.38516 .06983 Mdot
.27217 .21594 Mdot
.92276 .14712 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00494 Mdot
.48836 .01572 Mdot
.46292 .04978 Mdot
.38238 .14916 Mdot
.14103 .26345 Mdot
.71476 .11951 Mdot
.52138 .09975 Mdot
.35998 .21345 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46745 .04377 Mdot
.39663 .133 Mdot
.18143 .26706 Mdot
.74932 .11952 Mdot
.55593 .06873 Mdot
.44473 .11894 Mdot
.25227 .26647 Mdot
.82111 .13341 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48977 .01382 Mdot
.46741 .04382 Mdot
.3965 .13315 Mdot
.18106 .26707 Mdot
.74893 .11953 Mdot
.55553 .06908 Mdot
.44376 .12014 Mdot
.24936 .26769 Mdot
.81623 .13274 Mdot
.50039 .61751 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51265 .60096 Mdot
.54027 .56402 Mdot
.62767 .45796 Mdot
.88667 .36155 Mdot
.30166 .50139 Mdot
.49039 .51029 Mdot
.66472 .38343 Mdot
.04432 .42399 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48929 .01446 Mdot
.46589 .04585 Mdot
.3917 .13867 Mdot
.16733 .26676 Mdot
.73571 .11981 Mdot
.54186 .08145 Mdot
.41008 .16044 Mdot
.15048 .28007 Mdot
.69732 .14053 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49806 .00262 Mdot
.49382 .00835 Mdot
.48031 .02655 Mdot
.43735 .08314 Mdot
.30283 .22263 Mdot
.9426 .17057 Mdot
.66662 .04281 Mdot
.59735 .57612 Mdot
.66517 .44904 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.5134 .59994 Mdot
.54268 .56085 Mdot
.6352 .45005 Mdot
.90701 .36866 Mdot
.3105 .50568 Mdot
.4923 .51282 Mdot
.66254 .38699 Mdot
.03637 .42042 Mdot
.35612 .53637 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49067 .01261 Mdot
.47027 .04001 Mdot
.40553 .12254 Mdot
.20725 .26479 Mdot
.77881 .11966 Mdot
.58519 .0444 Mdot
.51335 .03203 Mdot
.46152 .06736 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49784 .00292 Mdot
.49311 .00931 Mdot
.47804 .0296 Mdot
.43014 .0923 Mdot
.2808 .23709 Mdot
.89717 .14826 Mdot
.65728 .02505 Mdot
.61674 .54431 Mdot
.73603 .39733 Mdot
.09313 .47883 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00554 Mdot
.48693 .01765 Mdot
.45837 .0558 Mdot
.36809 .16456 Mdot
.10182 .25265 Mdot
.69303 .11445 Mdot
.50784 .10719 Mdot
.33441 .23446 Mdot
.95505 .19334 Mdot
.64222 .07835 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .6042 Mdot
.53264 .57415 Mdot
.60364 .48473 Mdot
.81933 .35096 Mdot
.25147 .4985 Mdot
.44488 .54858 Mdot
.55725 .49665 Mdot
.75366 .34914 Mdot
.18873 .48589 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00533 Mdot
.48744 .01695 Mdot
.46001 .05364 Mdot
.37322 .15913 Mdot
.11575 .25722 Mdot
.69956 .11702 Mdot
.51021 .10756 Mdot
.33617 .23401 Mdot
.95753 .1951 Mdot
.64185 .08034 Mdot
.50027 .61768 Mdot
.50085 .61689 Mdot
.50269 .6144 Mdot
.50858 .60645 Mdot
.52733 .58123 Mdot
.58688 .50463 Mdot
.77036 .35829 Mdot
.19063 .49569 Mdot
.38858 .59075 Mdot
.43273 .03323 Mdot
.37896 .13494 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50775 .60757 Mdot
.52467 .58479 Mdot
.57847 .51496 Mdot
.74525 .36748 Mdot
.15066 .4872 Mdot
.36235 .59949 Mdot
.39236 .0738 Mdot
.27295 .21981 Mdot
.91728 .14654 Mdot
.49995 6e-05 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00197 Mdot
.49534 .00629 Mdot
.48517 .02002 Mdot
.45278 .06315 Mdot
.35059 .1822 Mdot
.05579 .23287 Mdot
.67901 .09976 Mdot
.51759 .08348 Mdot
.38252 .18277 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48852 .0155 Mdot
.46345 .04908 Mdot
.38404 .14732 Mdot
.14568 .26428 Mdot
.71806 .1197 Mdot
.52438 .09719 Mdot
.36712 .20655 Mdot
.03291 .23685 Mdot
.64968 .11765 Mdot
.50033 .61758 Mdot
.50107 .61659 Mdot
.50339 .61345 Mdot
.51081 .60343 Mdot
.53444 .57176 Mdot
.60932 .4782 Mdot
.83557 .35147 Mdot
.26688 .49819 Mdot
.4608 .53417 Mdot
.5965 .45009 Mdot
.86824 .34142 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51203 .60179 Mdot
.53832 .56661 Mdot
.62153 .46458 Mdot
.86982 .35691 Mdot
.29233 .49927 Mdot
.4845 .51362 Mdot
.65344 .39241 Mdot
.01852 .40953 Mdot
.35588 .52561 Mdot
.50003 .618 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61692 Mdot
.50264 .61447 Mdot
.5084 .60668 Mdot
.52677 .58198 Mdot
.5851 .50679 Mdot
.7651 .35991 Mdot
.18275 .49448 Mdot
.38267 .59366 Mdot
.50055 .61729 Mdot
.50176 .61565 Mdot
.50562 .61044 Mdot
.5179 .59388 Mdot
.55697 .54219 Mdot
.6797 .40881 Mdot
.01823 .42567 Mdot
.32948 .5552 Mdot
.43115 .61705 Mdot
.43274 .05953 Mdot
.33641 .18586 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61581 Mdot
.50524 .61096 Mdot
.51669 .59551 Mdot
.55313 .54717 Mdot
.66778 .41888 Mdot
.99001 .40963 Mdot
.32722 .54015 Mdot
.45324 .58288 Mdot
.51012 .5735 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51123 .60287 Mdot
.53578 .56998 Mdot
.61353 .47343 Mdot
.84751 .35272 Mdot
.2768 .49818 Mdot
.47073 .52516 Mdot
.621 .42348 Mdot
.93579 .36556 Mdot
.3443 .48795 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49782 .00295 Mdot
.49304 .0094 Mdot
.47783 .02989 Mdot
.42947 .09316 Mdot
.27874 .2383 Mdot
.89316 .14653 Mdot
.65607 .02394 Mdot
.61734 .54279 Mdot
.73909 .39559 Mdot
.09901 .48157 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .60141 Mdot
.53922 .56541 Mdot
.62437 .4615 Mdot
.87765 .35892 Mdot
.29691 .5001 Mdot
.48773 .51147 Mdot
.66016 .38681 Mdot
.03428 .41835 Mdot
.35738 .53356 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48934 .0144 Mdot
.46604 .04565 Mdot
.39218 .13813 Mdot
.16869 .26683 Mdot
.73695 .11978 Mdot
.54314 .08028 Mdot
.41324 .15678 Mdot
.15957 .28114 Mdot
.70467 .13954 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60723 Mdot
.52548 .58371 Mdot
.58103 .51179 Mdot
.75292 .36427 Mdot
.16351 .49057 Mdot
.36976 .59827 Mdot
.40174 .06566 Mdot
.2955 .20721 Mdot
.96022 .17072 Mdot
.49969 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48982 .01375 Mdot
.46757 .0436 Mdot
.39702 .13254 Mdot
.18256 .26704 Mdot
.75048 .1195 Mdot
.55713 .06766 Mdot
.44766 .11531 Mdot
.26107 .2625 Mdot
.83634 .13614 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00217 Mdot
.49489 .0069 Mdot
.48373 .02196 Mdot
.4482 .06913 Mdot
.33635 .19549 Mdot
.02005 .21402 Mdot
.67375 .08309 Mdot
.53932 .04701 Mdot
.46326 .08077 Mdot
.33257 .2089 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.48659 .0181 Mdot
.45731 .0572 Mdot
.36476 .16802 Mdot
.0929 .24933 Mdot
.68947 .11233 Mdot
.50771 .10519 Mdot
.33751 .23099 Mdot
.96376 .19768 Mdot
.6439 .08172 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00475 Mdot
.4888 .01512 Mdot
.46433 .04791 Mdot
.38681 .14422 Mdot
.15345 .26544 Mdot
.72396 .11987 Mdot
.53001 .09221 Mdot
.3808 .19267 Mdot
.06906 .2547 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48987 .01368 Mdot
.46774 .04338 Mdot
.39754 .13195 Mdot
.18405 .267 Mdot
.75203 .11947 Mdot
.55872 .06626 Mdot
.45152 .11051 Mdot
.27271 .25655 Mdot
.8576 .14146 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51128 .60281 Mdot
.53591 .56979 Mdot
.61397 .47294 Mdot
.84874 .35289 Mdot
.27775 .4982 Mdot
.47165 .52434 Mdot
.62326 .42116 Mdot
.94181 .36841 Mdot
.34572 .49006 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50694 .60866 Mdot
.52211 .58823 Mdot
.57034 .52512 Mdot
.72067 .38008 Mdot
.10569 .47101 Mdot
.34358 .59378 Mdot
.38281 .07483 Mdot
.26173 .22198 Mdot
.90256 .13718 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00526 Mdot
.48759 .01676 Mdot
.46046 .05304 Mdot
.37465 .1576 Mdot
.11965 .25836 Mdot
.70161 .11758 Mdot
.51135 .10707 Mdot
.33812 .23257 Mdot
.96181 .19751 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00294 Mdot
.49308 .00935 Mdot
.47795 .02973 Mdot
.42985 .09268 Mdot
.27989 .23763 Mdot
.89541 .14749 Mdot
.65676 .02455 Mdot
.61703 .54361 Mdot
.73745 .39652 Mdot
.09586 .48011 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51038 .60402 Mdot
.53306 .57358 Mdot
.60498 .48316 Mdot
.82321 .35096 Mdot
.25535 .49842 Mdot
.4489 .54498 Mdot
.5671 .4846 Mdot
.78299 .34022 Mdot
.23251 .48687 Mdot
.49972 .00038 Mdot
.49909 .00123 Mdot
.49711 .0039 Mdot
.49079 .01243 Mdot
.47067 .03947 Mdot
.40682 .121 Mdot
.21103 .26415 Mdot
.78364 .11988 Mdot
.58966 .04109 Mdot
.52317 .01969 Mdot
.49132 .02773 Mdot
.44645 .07644 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61024 Mdot
.51839 .59323 Mdot
.55852 .54019 Mdot
.68448 .40497 Mdot
.02922 .43191 Mdot
.33038 .56104 Mdot
.4226 .01196 Mdot
.40325 .09623 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.50799 .60724 Mdot
.52546 .58373 Mdot
.58096 .51188 Mdot
.75273 .36435 Mdot
.1632 .49049 Mdot
.36957 .59832 Mdot
.40146 .06591 Mdot
.29482 .20765 Mdot
.95884 .16991 Mdot
.50083 .61692 Mdot
.50264 .61447 Mdot
.5084 .60669 Mdot
.52677 .58199 Mdot
.58509 .50681 Mdot
.76505 .35993 Mdot
.18267 .49447 Mdot
.38261 .59369 Mdot
.422 .04511 Mdot
.34902 .165 Mdot
.08204 .23773 Mdot
.50008 .61792 Mdot
.50027 .61767 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50867 .60633 Mdot
.52761 .58086 Mdot
.58776 .50357 Mdot
.77297 .35755 Mdot
.19444 .4962 Mdot
.39157 .58912 Mdot
.43835 .02682 Mdot
.50032 .6176 Mdot
.50101 .61666 Mdot
.50323 .61367 Mdot
.5103 .60412 Mdot
.53281 .57392 Mdot
.60419 .48408 Mdot
.82093 .35095 Mdot
.25308 .49847 Mdot
.44654 .5471 Mdot
.56132 .49164 Mdot
.76583 .34483 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49428 .00773 Mdot
.48177 .02459 Mdot
.44199 .07718 Mdot
.31711 .2118 Mdot
.9744 .18817 Mdot
.66993 .05891 Mdot
.57461 .61029 Mdot
.58714 .53348 Mdot
.72395 .38791 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48933 .01441 Mdot
.46602 .04567 Mdot
.39211 .13821 Mdot
.16849 .26682 Mdot
.73677 .11979 Mdot
.54295 .08045 Mdot
.41278 .15732 Mdot
.15823 .28101 Mdot
.70355 .1397 Mdot
.50125 .61635 Mdot
.50397 .61266 Mdot
.51266 .60094 Mdot
.54033 .56395 Mdot
.62784 .45778 Mdot
.88713 .3617 Mdot
.30189 .50147 Mdot
.4905 .51027 Mdot
.66486 .38334 Mdot
.04461 .42415 Mdot
.35831 .53883 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50545 .61067 Mdot
.51737 .59459 Mdot
.55531 .54434 Mdot
.67454 .41308 Mdot
.00617 .41879 Mdot
.32855 .54873 Mdot
.44069 .60245 Mdot
.4659 .01579 Mdot
.44034 .06981 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49617 .00518 Mdot
.48779 .01649 Mdot
.4611 .0522 Mdot
.37664 .15544 Mdot
.12513 .25986 Mdot
.70467 .11826 Mdot
.51332 .10592 Mdot
.34194 .22952 Mdot
.97056 .20239 Mdot
.64309 .0869 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49047 .01287 Mdot
.46964 .04085 Mdot
.40354 .1249 Mdot
.20144 .26563 Mdot
.77164 .11945 Mdot
.57837 .0497 Mdot
.49795 .0516 Mdot
.41445 .12714 Mdot
.20873 .26976 Mdot
.50097 .61672 Mdot
.5031 .61385 Mdot
.50987 .6047 Mdot
.53145 .57574 Mdot
.59988 .4891 Mdot
.8085 .35141 Mdot
.23991 .49866 Mdot
.43306 .55891 Mdot
.52873 .53242 Mdot
.66726 .40436 Mdot
.01299 .41639 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.51091 .6033 Mdot
.53474 .57135 Mdot
.61027 .47711 Mdot
.8383 .35169 Mdot
.26925 .49816 Mdot
.46321 .53197 Mdot
.60247 .4434 Mdot
.88503 .34585 Mdot
.32543 .47713 Mdot
.50112 .61651 Mdot
.50358 .61319 Mdot
.51142 .60261 Mdot
.53637 .56919 Mdot
.6154 .47134 Mdot
.85275 .35349 Mdot
.28079 .49828 Mdot
.47455 .52178 Mdot
.63029 .41404 Mdot
.96035 .37766 Mdot
.34927 .49742 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50903 .60584 Mdot
.52876 .57933 Mdot
.59139 .49918 Mdot
.7837 .35493 Mdot
.20941 .4977 Mdot
.40411 .58132 Mdot
.46351 .61485 Mdot
.46866 .02568 Mdot
.42711 .09092 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50983 .60477 Mdot
.53129 .57594 Mdot
.5994 .48966 Mdot
.80711 .35152 Mdot
.23835 .49867 Mdot
.43149 .56024 Mdot
.52501 .53715 Mdot
.65588 .41466 Mdot
.98494 .40072 Mdot
.5001 .6179 Mdot
.5003 .61762 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50984 .60475 Mdot
.53134 .57588 Mdot
.59955 .48949 Mdot
.80755 .35148 Mdot
.23883 .49866 Mdot
.43198 .55982 Mdot
.52617 .53567 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.5081 .6071 Mdot
.52579 .5833 Mdot
.58199 .51061 Mdot
.75581 .36316 Mdot
.16821 .49165 Mdot
.37271 .59747 Mdot
.40598 .06161 Mdot
.3063 .20002 Mdot
.98266 .18398 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .6029 Mdot
.53569 .5701 Mdot
.61325 .47374 Mdot
.84672 .35262 Mdot
.27618 .49817 Mdot
.47012 .52571 Mdot
.61951 .42504 Mdot
.93179 .36372 Mdot
.34328 .48664 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48943 .01427 Mdot
.46634 .04525 Mdot
.39313 .13705 Mdot
.17138 .26695 Mdot
.73944 .11973 Mdot
.54571 .07793 Mdot
.41961 .14933 Mdot
.178 .28203 Mdot
.72167 .13682 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.4973 .00364 Mdot
.49141 .0116 Mdot
.47264 .03684 Mdot
.41304 .1135 Mdot
.2294 .25981 Mdot
.80902 .12229 Mdot
.61115 .02743 Mdot
.56676 .58537 Mdot
.61962 .48462 Mdot
.83548 .35785 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51587 .59662 Mdot
.55052 .55057 Mdot
.65968 .42615 Mdot
.97015 .39864 Mdot
.32513 .53005 Mdot
.4675 .55997 Mdot
.56145 .5044 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00536 Mdot
.48737 .01705 Mdot
.45978 .05394 Mdot
.37251 .15989 Mdot
.1138 .25662 Mdot
.69857 .11672 Mdot
.50972 .10771 Mdot
.33543 .23451 Mdot
.95599 .19423 Mdot
.64172 .07953 Mdot
.50119 .61642 Mdot
.5038 .61291 Mdot
.51209 .60171 Mdot
.53851 .56636 Mdot
.62212 .46394 Mdot
.87146 .35731 Mdot
.29332 .49942 Mdot
.48524 .51308 Mdot
.65505 .39103 Mdot
.02236 .41168 Mdot
.35624 .52756 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .60489 Mdot
.531 .57634 Mdot
.59847 .49077 Mdot
.80439 .35175 Mdot
.23524 .49866 Mdot
.42839 .56284 Mdot
.5177 .54646 Mdot
.6335 .43671 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50702 .60855 Mdot
.52238 .58787 Mdot
.57118 .52406 Mdot
.72324 .37859 Mdot
.11067 .47312 Mdot
.34515 .59507 Mdot
.3823 .07647 Mdot
.25857 .2238 Mdot
.89645 .13444 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49242 .01024 Mdot
.47586 .03253 Mdot
.42323 .10097 Mdot
.25985 .24824 Mdot
.85819 .13349 Mdot
.6422 .01852 Mdot
.61224 .54091 Mdot
.73703 .39385 Mdot
.09976 .4804 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .00299 Mdot
.49294 .00954 Mdot
.4775 .03033 Mdot
.42843 .09446 Mdot
.2756 .2401 Mdot
.88711 .144 Mdot
.65411 .02244 Mdot
.61781 .54096 Mdot
.74252 .39358 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51327 .60011 Mdot
.54227 .56138 Mdot
.63393 .45137 Mdot
.90361 .36737 Mdot
.30919 .50483 Mdot
.49237 .5119 Mdot
.66409 .38533 Mdot
.04061 .42257 Mdot
.35687 .53808 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.4928 .00972 Mdot
.47707 .0309 Mdot
.42707 .09617 Mdot
.27147 .24237 Mdot
.87931 .1409 Mdot
.65132 .02082 Mdot
.61763 .53946 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.467 .04437 Mdot
.39521 .13465 Mdot
.17734 .26708 Mdot
.74519 .11961 Mdot
.55166 .07255 Mdot
.43428 .13176 Mdot
.2211 .27687 Mdot
.7731 .13088 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49857 .00193 Mdot
.49546 .00614 Mdot
.48552 .01954 Mdot
.4539 .06168 Mdot
.3541 .17877 Mdot
.06484 .23723 Mdot
.68099 .10334 Mdot
.51377 .09059 Mdot
.36719 .19991 Mdot
.49983 .00024 Mdot
.49945 .00075 Mdot
.49823 .00239 Mdot
.49437 .00761 Mdot
.48206 .02421 Mdot
.44288 .07603 Mdot
.31987 .20958 Mdot
.98075 .19178 Mdot
.67044 .06229 Mdot
.56965 .6178 Mdot
.57002 .55496 Mdot
.67207 .42475 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00263 Mdot
.49379 .00838 Mdot
.48023 .02666 Mdot
.43708 .08348 Mdot
.30201 .22322 Mdot
.94083 .16962 Mdot
.66638 .04198 Mdot
.59846 .57445 Mdot
.66898 .44561 Mdot
.50124 .61635 Mdot
.50396 .61268 Mdot
.51262 .60099 Mdot
.5402 .56411 Mdot
.62745 .45819 Mdot
.88607 .36137 Mdot
.30137 .5013 Mdot
.49025 .51033 Mdot
.66452 .38355 Mdot
.04392 .42376 Mdot
.35827 .53846 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50215 .61512 Mdot
.50687 .60876 Mdot
.52187 .58855 Mdot
.56958 .52607 Mdot
.71838 .38143 Mdot
.10121 .46906 Mdot
.34225 .59251 Mdot
.38356 .07304 Mdot
.26538 .2199 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00417 Mdot
.49017 .01328 Mdot
.46867 .04214 Mdot
.4005 .12849 Mdot
.1926 .26654 Mdot
.76133 .11937 Mdot
.56819 .05807 Mdot
.47424 .08185 Mdot
.3418 .20552 Mdot
.50001 .61802 Mdot
.50003 .618 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50893 .60598 Mdot
.52843 .57976 Mdot
.59037 .50041 Mdot
.78068 .3556 Mdot
.20531 .49737 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49014 .01331 Mdot
.4686 .04223 Mdot
.40027 .12875 Mdot
.19194 .26659 Mdot
.76059 .11937 Mdot
.56744 .0587 Mdot
.47246 .08411 Mdot
.33637 .21046 Mdot
.99584 .2066 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.50578 .61022 Mdot
.51843 .59318 Mdot
.55865 .54003 Mdot
.68486 .40467 Mdot
.03008 .43239 Mdot
.33045 .56149 Mdot
.42195 .01294 Mdot
.401 .09892 Mdot
.24095 .24622 Mdot
.50093 .61678 Mdot
.50295 .61405 Mdot
.5094 .60534 Mdot
.52993 .57775 Mdot
.59511 .49474 Mdot
.79461 .35295 Mdot
.22352 .49846 Mdot
.417 .57196 Mdot
.49154 .5798 Mdot
.5534 .53122 Mdot
.69388 .39275 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50545 .61068 Mdot
.51735 .59463 Mdot
.55522 .54445 Mdot
.67428 .41329 Mdot
.00556 .41844 Mdot
.3285 .5484 Mdot
.44117 .60171 Mdot
.46758 .01352 Mdot
.4457 .06289 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01028 Mdot
.47576 .03266 Mdot
.42291 .10136 Mdot
.2589 .24868 Mdot
.85653 .13297 Mdot
.64138 .01847 Mdot
.61149 .5414 Mdot
.73548 .39447 Mdot
.09722 .4791 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.5029 .61412 Mdot
.50924 .60556 Mdot
.52942 .57844 Mdot
.59348 .49667 Mdot
.78985 .35373 Mdot
.2175 .49821 Mdot
.41138 .57618 Mdot
.4791 .5955 Mdot
.51557 .58109 Mdot
.50045 .61743 Mdot
.50142 .61611 Mdot
.50453 .61191 Mdot
.51444 .59854 Mdot
.54597 .55651 Mdot
.64552 .43964 Mdot
.93417 .38033 Mdot
.31878 .51431 Mdot
.4866 .52672 Mdot
.63434 .41646 Mdot
.9605 .38021 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00406 Mdot
.49043 .01293 Mdot
.46951 .04102 Mdot
.40314 .12537 Mdot
.20029 .26578 Mdot
.77026 .11942 Mdot
.57703 .05077 Mdot
.49487 .05553 Mdot
.40503 .13844 Mdot
.18103 .27234 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49157 .01139 Mdot
.47314 .03618 Mdot
.4146 .1116 Mdot
.23402 .25841 Mdot
.81591 .12333 Mdot
.61636 .02482 Mdot
.57619 .57489 Mdot
.646 .45774 Mdot
.90537 .37509 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50426 .61228 Mdot
.51358 .5997 Mdot
.54323 .56011 Mdot
.63695 .44825 Mdot
.91166 .3705 Mdot
.31218 .50693 Mdot
.49196 .51438 Mdot
.65968 .38996 Mdot
.0287 .41643 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48802 .01617 Mdot
.46186 .05119 Mdot
.37903 .15285 Mdot
.13172 .26149 Mdot
.70863 .1189 Mdot
.51624 .10387 Mdot
.34818 .22422 Mdot
.98538 .21069 Mdot
.64448 .0944 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00425 Mdot
.48999 .01352 Mdot
.46811 .04288 Mdot
.39873 .13055 Mdot
.18749 .26686 Mdot
.75569 .11941 Mdot
.56248 .06297 Mdot
.46059 .09913 Mdot
.30019 .2394 Mdot
.50124 .61636 Mdot
.50395 .61269 Mdot
.5126 .60103 Mdot
.54012 .56423 Mdot
.62718 .45847 Mdot
.88536 .36115 Mdot
.301 .50118 Mdot
.49008 .51038 Mdot
.66427 .38372 Mdot
.04339 .42345 Mdot
.35823 .53818 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49302 .00942 Mdot
.47778 .02996 Mdot
.4293 .09336 Mdot
.27824 .23859 Mdot
.89219 .14612 Mdot
.65577 .02369 Mdot
.61745 .54246 Mdot
.73973 .39522 Mdot
.10025 .48213 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.4882 .01593 Mdot
.46243 .05044 Mdot
.38082 .15088 Mdot
.13668 .26258 Mdot
.71181 .11927 Mdot
.51883 .10185 Mdot
.35404 .21897 Mdot
.99974 .21873 Mdot
.64583 .10168 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60315 Mdot
.5351 .57088 Mdot
.6114 .47583 Mdot
.8415 .352 Mdot
.27195 .49815 Mdot
.46593 .52949 Mdot
.60921 .43601 Mdot
.90373 .3521 Mdot
.33401 .47956 Mdot
.50094 .61677 Mdot
.50298 .614 Mdot
.50951 .6052 Mdot
.53028 .57729 Mdot
.5962 .49345 Mdot
.79779 .3525 Mdot
.22743 .49856 Mdot
.42073 .56905 Mdot
.49999 .56906 Mdot
.57924 .49859 Mdot
.7725 .35252 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60736 Mdot
.52518 .58411 Mdot
.58007 .51298 Mdot
.75005 .36543 Mdot
.15877 .48939 Mdot
.36691 .59889 Mdot
.39789 .06915 Mdot
.286 .21294 Mdot
.94145 .15988 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50729 .60819 Mdot
.52322 .58674 Mdot
.57386 .5207 Mdot
.73134 .37417 Mdot
.12593 .4791 Mdot
.35072 .59808 Mdot
.38301 .07899 Mdot
.2552 .22646 Mdot
.88878 .13154 Mdot
.49998 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00666 Mdot
.48431 .02118 Mdot
.45003 .06674 Mdot
.34204 .1903 Mdot
.03413 .2217 Mdot
.67542 .09006 Mdot
.5297 .06269 Mdot
.50102 .61666 Mdot
.50324 .61365 Mdot
.51034 .60408 Mdot
.53292 .57378 Mdot
.60453 .48369 Mdot
.8219 .35095 Mdot
.25406 .49844 Mdot
.44756 .54619 Mdot
.56381 .48861 Mdot
.77323 .34263 Mdot
.21884 .48736 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.4923 .01041 Mdot
.47546 .03307 Mdot
.42195 .10256 Mdot
.256 .25 Mdot
.85149 .13145 Mdot
.63879 .01848 Mdot
.60889 .54326 Mdot
.72987 .3969 Mdot
.08768 .47413 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46876 .04202 Mdot
.40077 .12817 Mdot
.19339 .26648 Mdot
.76222 .11937 Mdot
.56908 .05732 Mdot
.47634 .07918 Mdot
.34823 .1995 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51288 .60064 Mdot
.54102 .56303 Mdot
.63001 .45547 Mdot
.89305 .36362 Mdot
.30471 .50253 Mdot
.4916 .51032 Mdot
.66589 .3829 Mdot
.04634 .42525 Mdot
.35826 .53996 Mdot
.50066 .61714 Mdot
.50212 .61518 Mdot
.50674 .60893 Mdot
.52147 .58909 Mdot
.56831 .52769 Mdot
.71448 .38381 Mdot
.09347 .46556 Mdot
.34018 .59005 Mdot
.38545 .06927 Mdot
.27336 .21523 Mdot
.92511 .14834 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48873 .01522 Mdot
.46411 .04821 Mdot
.38611 .14501 Mdot
.15147 .26517 Mdot
.5001 .6179 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61383 Mdot
.50993 .60463 Mdot
.53161 .57551 Mdot
.60041 .48848 Mdot
.81004 .35131 Mdot
.24161 .49865 Mdot
.43478 .55743 Mdot
.53283 .52721 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48083 .02586 Mdot
.43899 .08104 Mdot
.30787 .21894 Mdot
.95361 .17654 Mdot
.66796 .04817 Mdot
.59002 .58713 Mdot
.64002 .47343 Mdot
.87399 .36844 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.50089 .61683 Mdot
.50285 .61418 Mdot
.50908 .60577 Mdot
.52892 .57911 Mdot
.59189 .49858 Mdot
.78516 .35463 Mdot
.21137 .49784 Mdot
.40584 .58013 Mdot
.46716 .61037 Mdot
.50104 .61663 Mdot
.5033 .61357 Mdot
.51052 .60383 Mdot
.53351 .57299 Mdot
.60639 .48155 Mdot
.82723 .35103 Mdot
.25924 .49833 Mdot
.45293 .54134 Mdot
.57703 .47268 Mdot
.81221 .33627 Mdot
.26811 .48286 Mdot
.50098 .61672 Mdot
.50311 .61384 Mdot
.5099 .60466 Mdot
.53153 .57562 Mdot
.60015 .48878 Mdot
.80928 .35136 Mdot
.24078 .49865 Mdot
.43394 .55816 Mdot
.53082 .52976 Mdot
.67365 .39887 Mdot
.02828 .42494 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46847 .04241 Mdot
.39985 .12925 Mdot
.19072 .26668 Mdot
.75923 .11938 Mdot
.56607 .05987 Mdot
.46919 .08826 Mdot
.32639 .21913 Mdot
.97184 .19315 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00557 Mdot
.48685 .01775 Mdot
.45814 .05611 Mdot
.36735 .16534 Mdot
.09983 .25193 Mdot
.69219 .11401 Mdot
.50772 .10686 Mdot
.33482 .23394 Mdot
.9563 .19393 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.49281 .00972 Mdot
.47708 .03089 Mdot
.42709 .09614 Mdot
.27153 .24234 Mdot
.87941 .14094 Mdot
.65136 .02084 Mdot
.61764 .53948 Mdot
.74475 .39201 Mdot
.11046 .48639 Mdot
.50083 .61691 Mdot
.50264 .61446 Mdot
.50842 .60666 Mdot
.52683 .5819 Mdot
.58529 .50657 Mdot
.76564 .35974 Mdot
.18357 .49462 Mdot
.38327 .59339 Mdot
.42315 .04386 Mdot
.35217 .16203 Mdot
.09 .24109 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56787 .52824 Mdot
.71316 .38463 Mdot
.09082 .46433 Mdot
.33952 .58914 Mdot
.38627 .0678 Mdot
.27657 .21329 Mdot
.93146 .1517 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48958 .01407 Mdot
.46681 .04462 Mdot
.39462 .13533 Mdot
.17564 .26706 Mdot
.74352 .11964 Mdot
.54994 .0741 Mdot
.43004 .13689 Mdot
.20855 .27946 Mdot
.5013 .61627 Mdot
.50415 .61242 Mdot
.51323 .60017 Mdot
.54214 .56155 Mdot
.63353 .45178 Mdot
.90254 .36697 Mdot
.30877 .50457 Mdot
.49236 .51165 Mdot
.66448 .3849 Mdot
.0417 .42312 Mdot
.35708 .53851 Mdot
.50067 .61713 Mdot
.50212 .61516 Mdot
.50677 .60889 Mdot
.52155 .58897 Mdot
.56857 .52735 Mdot
.7153 .3833 Mdot
.09511 .46632 Mdot
.3406 .5906 Mdot
.38499 .07014 Mdot
.2715 .21634 Mdot
.92144 .14644 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50913 .6057 Mdot
.52908 .5789 Mdot
.59241 .49796 Mdot
.78669 .35432 Mdot
.21339 .49798 Mdot
.40764 .57887 Mdot
.47101 .6056 Mdot
.49113 .61382 Mdot
.49796 .61571 Mdot
.50007 .61794 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50687 .60875 Mdot
.5219 .58851 Mdot
.56967 .52597 Mdot
.71863 .38128 Mdot
.1017 .46928 Mdot
.34239 .59265 Mdot
.38347 .07325 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49188 .01097 Mdot
.47412 .03486 Mdot
.41773 .10778 Mdot
.24334 .25519 Mdot
.83043 .12609 Mdot
.62641 .02084 Mdot
.5927 .55771 Mdot
.6903 .42043 Mdot
.01003 .42972 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51293 .60058 Mdot
.54118 .56283 Mdot
.6305 .45495 Mdot
.89437 .36406 Mdot
.3053 .50279 Mdot
.49177 .51041 Mdot
.66591 .38298 Mdot
.04623 .42524 Mdot
.35817 .54 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48777 .01652 Mdot
.46104 .05227 Mdot
.37647 .15563 Mdot
.12465 .25973 Mdot
.7044 .11821 Mdot
.51314 .10604 Mdot
.34156 .22984 Mdot
.96967 .20189 Mdot
.50037 .61753 Mdot
.50119 .61642 Mdot
.5038 .61291 Mdot
.51209 .60171 Mdot
.53851 .56635 Mdot
.62214 .46391 Mdot
.87151 .35732 Mdot
.29335 .49943 Mdot
.48526 .51307 Mdot
.6551 .39098 Mdot
.02248 .41175 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60044 Mdot
.54151 .56239 Mdot
.63154 .45386 Mdot
.89718 .36503 Mdot
.30654 .50337 Mdot
.49208 .51071 Mdot
.66573 .38337 Mdot
.04543 .42491 Mdot
.35791 .53983 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50814 .60704 Mdot
.52593 .5831 Mdot
.58246 .51003 Mdot
.75721 .36264 Mdot
.17044 .49213 Mdot
.37416 .59701 Mdot
.40817 .05946 Mdot
.31196 .19596 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49897 .00139 Mdot
.49673 .00441 Mdot
.48959 .01406 Mdot
.46684 .04458 Mdot
.39472 .13521 Mdot
.17594 .26707 Mdot
.74381 .11964 Mdot
.55024 .07383 Mdot
.43077 .136 Mdot
.21071 .27908 Mdot
.50104 .61664 Mdot
.5033 .61358 Mdot
.51051 .60384 Mdot
.53348 .57304 Mdot
.60628 .48167 Mdot
.82693 .35103 Mdot
.25896 .49834 Mdot
.45263 .5416 Mdot
.5763 .47354 Mdot
.81009 .33639 Mdot
.2658 .48321 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00527 Mdot
.48757 .01678 Mdot
.46041 .05311 Mdot
.37448 .15778 Mdot
.11918 .25823 Mdot
.70136 .11752 Mdot
.51121 .10714 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46218 .05077 Mdot
.38003 .15175 Mdot
.13449 .26211 Mdot
.71038 .11912 Mdot
.51765 .10279 Mdot
.35133 .22143 Mdot
.99306 .21499 Mdot
.64519 .0983 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46591 .04582 Mdot
.39177 .1386 Mdot
.16752 .26677 Mdot
.73588 .1198 Mdot
.54204 .08128 Mdot
.41052 .15993 Mdot
.15175 .28024 Mdot
.69831 .14041 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49616 .00519 Mdot
.48777 .01651 Mdot
.46106 .05225 Mdot
.37652 .15558 Mdot
.12478 .25977 Mdot
.70447 .11822 Mdot
.51319 .10601 Mdot
.34166 .22976 Mdot
.96991 .20202 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60706 Mdot
.52587 .58319 Mdot
.58225 .51028 Mdot
.7566 .36287 Mdot
.16947 .49192 Mdot
.37352 .59722 Mdot
.4072 .06042 Mdot
.30944 .19779 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49168 .01124 Mdot
.47349 .0357 Mdot
.41572 .11023 Mdot
.23736 .25731 Mdot
.82102 .12422 Mdot
.62003 .02319 Mdot
.58251 .56812 Mdot
.66328 .44194 Mdot
.9482 .39476 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51265 .60096 Mdot
.54028 .56401 Mdot
.62769 .45793 Mdot
.88675 .36158 Mdot
.3017 .50141 Mdot
.49041 .51029 Mdot
.66474 .38341 Mdot
.04437 .42402 Mdot
.3583 .5387 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48683 .01777 Mdot
.45808 .05619 Mdot
.36716 .16553 Mdot
.09932 .25175 Mdot
.69199 .1139 Mdot
.5077 .10676 Mdot
.33495 .23378 Mdot
.95668 .19412 Mdot
.64259 .07892 Mdot
.49989 .00015 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48818 .01596 Mdot
.46235 .05054 Mdot
.38058 .15114 Mdot
.13603 .26245 Mdot
.71138 .11922 Mdot
.51847 .10214 Mdot
.35321 .21973 Mdot
.99768 .21758 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.49671 .00445 Mdot
.48952 .01416 Mdot
.46661 .04489 Mdot
.39398 .13606 Mdot
.17383 .26703 Mdot
.74177 .11968 Mdot
.54812 .07575 Mdot
.42556 .14227 Mdot
.19536 .28121 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.47611 .0322 Mdot
.424 .10001 Mdot
.26219 .24712 Mdot
.86234 .13483 Mdot
.64418 .01871 Mdot
.61391 .53994 Mdot
.74027 .39267 Mdot
.10492 .48304 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50356 .61323 Mdot
.51134 .60272 Mdot
.53611 .56953 Mdot
.6146 .47224 Mdot
.8505 .35314 Mdot
.2791 .49823 Mdot
.47295 .52319 Mdot
.62641 .41793 Mdot
.95018 .3725 Mdot
.49989 .00015 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48888 .01502 Mdot
.46457 .04759 Mdot
.38757 .14337 Mdot
.1556 .26571 Mdot
.72567 .11988 Mdot
.5317 .09069 Mdot
.38495 .1883 Mdot
.08027 .2596 Mdot
.50033 .61758 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60342 Mdot
.53448 .5717 Mdot
.60945 .47805 Mdot
.83594 .3515 Mdot
.26721 .49818 Mdot
.46113 .53386 Mdot
.59732 .44916 Mdot
.87057 .34196 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .00429 Mdot
.48988 .01367 Mdot
.46777 .04335 Mdot
.39763 .13184 Mdot
.18431 .26699 Mdot
.75231 .11946 Mdot
.55901 .066 Mdot
.45222 .10963 Mdot
.27483 .25539 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48943 .01428 Mdot
.46633 .04526 Mdot
.3931 .13708 Mdot
.1713 .26695 Mdot
.73937 .11973 Mdot
.54563 .07801 Mdot
.41942 .14956 Mdot
.17743 .28203 Mdot
.72109 .13691 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49118 .01192 Mdot
.4719 .03783 Mdot
.41069 .11635 Mdot
.22243 .26169 Mdot
.79901 .12108 Mdot
.60309 .03205 Mdot
.55123 .60341 Mdot
.57489 .53652 Mdot
.70678 .39438 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51249 .60117 Mdot
.53978 .56467 Mdot
.62612 .45961 Mdot
.88246 .36028 Mdot
.29951 .50074 Mdot
.48929 .51067 Mdot
.66301 .38462 Mdot
.04069 .42193 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48721 .01727 Mdot
.45927 .05462 Mdot
.37089 .1616 Mdot
.10941 .25523 Mdot
.69644 .11597 Mdot
.5088 .10781 Mdot
.33436 .23511 Mdot
.95395 .19301 Mdot
.64165 .07835 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49072 .01253 Mdot
.47046 .03976 Mdot
.40613 .12183 Mdot
.20901 .2645 Mdot
.78103 .11975 Mdot
.58726 .04285 Mdot
.51793 .02626 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47323 .03605 Mdot
.4149 .11123 Mdot
.23493 .25811 Mdot
.81729 .12356 Mdot
.61736 .02436 Mdot
.57795 .57298 Mdot
.65085 .45315 Mdot
.91764 .38016 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00513 Mdot
.48791 .01632 Mdot
.4615 .05166 Mdot
.37791 .15407 Mdot
.12862 .26075 Mdot
.70673 .11862 Mdot
.51479 .10493 Mdot
.34502 .22694 Mdot
.97782 .20645 Mdot
.64378 .09056 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50393 .61272 Mdot
.51252 .60113 Mdot
.53988 .56454 Mdot
.62643 .45928 Mdot
.88329 .36053 Mdot
.29995 .50087 Mdot
.48953 .51057 Mdot
.66341 .38433 Mdot
.04156 .42242 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50203 .61529 Mdot
.50647 .6093 Mdot
.5206 .59025 Mdot
.56556 .53117 Mdot
.7061 .38921 Mdot
.07635 .45731 Mdot
.33642 .58363 Mdot
.39208 .05815 Mdot
.298 .19903 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61069 Mdot
.51732 .59467 Mdot
.55512 .54459 Mdot
.67396 .41357 Mdot
.00479 .41801 Mdot
.32844 .54799 Mdot
.44177 .60078 Mdot
.46969 .01067 Mdot
.45243 .05412 Mdot
.5013 .61627 Mdot
.50416 .61242 Mdot
.51324 .60016 Mdot
.54217 .56152 Mdot
.6336 .45171 Mdot
.90272 .36704 Mdot
.30884 .50461 Mdot
.49236 .51169 Mdot
.66442 .38497 Mdot
.04152 .42303 Mdot
.35705 .53844 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50376 .61295 Mdot
.51198 .60185 Mdot
.53816 .56681 Mdot
.62104 .46511 Mdot
.86847 .35659 Mdot
.29149 .49915 Mdot
.48385 .51409 Mdot
.65203 .39363 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01025 Mdot
.47583 .03256 Mdot
.42314 .10108 Mdot
.2596 .24835 Mdot
.85775 .13335 Mdot
.64198 .0185 Mdot
.61205 .54103 Mdot
.73663 .39401 Mdot
.09911 .48007 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48943 .01427 Mdot
.46634 .04524 Mdot
.39314 .13703 Mdot
.17142 .26695 Mdot
.73948 .11973 Mdot
.54575 .0779 Mdot
.41971 .14921 Mdot
.17829 .28203 Mdot
.72196 .13677 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50811 .60708 Mdot
.52583 .58323 Mdot
.58214 .51042 Mdot
.75626 .36299 Mdot
.16893 .49181 Mdot
.37317 .59732 Mdot
.40668 .06093 Mdot
.3081 .19875 Mdot
.98652 .18626 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50199 .61535 Mdot
.50632 .60949 Mdot
.52015 .59086 Mdot
.56411 .53302 Mdot
.70167 .39223 Mdot
.06703 .45255 Mdot
.33479 .57964 Mdot
.39691 .05063 Mdot
.31498 .18605 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49213 .01064 Mdot
.47492 .0338 Mdot
.42023 .10469 Mdot
.25085 .25223 Mdot
.84274 .12903 Mdot
.63396 .01899 Mdot
.60323 .5479 Mdot
.71672 .40357 Mdot
.06373 .46108 Mdot
.50065 .61716 Mdot
.50207 .61524 Mdot
.5066 .60912 Mdot
.52101 .5897 Mdot
.56686 .52952 Mdot
.71008 .38659 Mdot
.08456 .46135 Mdot
.33808 .58687 Mdot
.38851 .06394 Mdot
.28506 .20792 Mdot
.94864 .16113 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49346 .00884 Mdot
.47916 .0281 Mdot
.43368 .08782 Mdot
.29159 .23036 Mdot
.91887 .15836 Mdot
.66264 .03249 Mdot
.61008 .55641 Mdot
.70978 .41356 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00168 Mdot
.49603 .00536 Mdot
.48736 .01707 Mdot
.45974 .054 Mdot
.37237 .16003 Mdot
.11343 .25651 Mdot
.69839 .11666 Mdot
.50963 .10774 Mdot
.33531 .23459 Mdot
.95574 .19408 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50202 .6153 Mdot
.50644 .60934 Mdot
.52051 .59038 Mdot
.56525 .53157 Mdot
.70516 .38984 Mdot
.07439 .45632 Mdot
.33605 .58281 Mdot
.39304 .05664 Mdot
.30139 .19656 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00455 Mdot
.48927 .01448 Mdot
.46584 .04591 Mdot
.39156 .13884 Mdot
.1669 .26673 Mdot
.73532 .11981 Mdot
.54147 .0818 Mdot
.4091 .16156 Mdot
.14769 .27966 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60722 Mdot
.52549 .58369 Mdot
.58106 .51175 Mdot
.75303 .36423 Mdot
.16369 .49061 Mdot
.36987 .59825 Mdot
.40188 .06552 Mdot
.29587 .20698 Mdot
.96097 .17116 Mdot
.50125 .61635 Mdot
.50397 .61266 Mdot
.51266 .60094 Mdot
.54032 .56396 Mdot
.62782 .45779 Mdot
.88709 .36169 Mdot
.30187 .50146 Mdot
.49049 .51027 Mdot
.66485 .38335 Mdot
.04459 .42414 Mdot
.35831 .53882 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49726 .00371 Mdot
.49125 .01181 Mdot
.47214 .03751 Mdot
.41145 .11542 Mdot
.22469 .26111 Mdot
.80221 .12143 Mdot
.60573 .03046 Mdot
.55644 .59726 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.492 .0108 Mdot
.47452 .03432 Mdot
.41898 .10623 Mdot
.24711 .25375 Mdot
.83654 .12748 Mdot
.63027 .01975 Mdot
.59831 .55234 Mdot
.70461 .41075 Mdot
.04 .44744 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49063 .01266 Mdot
.47015 .04017 Mdot
.40515 .12298 Mdot
.20616 .26497 Mdot
.77744 .11961 Mdot
.58391 .04538 Mdot
.51048 .03567 Mdot
.45277 .07881 Mdot
.32526 .21016 Mdot
.50118 .61644 Mdot
.50377 .61295 Mdot
.512 .60183 Mdot
.53821 .56675 Mdot
.6212 .46494 Mdot
.86891 .3567 Mdot
.29177 .49919 Mdot
.48406 .51394 Mdot
.6525 .39322 Mdot
.01625 .40826 Mdot
.35567 .52446 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.4866 .01809 Mdot
.45733 .05718 Mdot
.3648 .16798 Mdot
.09301 .24938 Mdot
.68951 .11236 Mdot
.5077 .10523 Mdot
.33744 .23105 Mdot
.96359 .19759 Mdot
.64388 .08165 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00553 Mdot
.48695 .01762 Mdot
.45845 .0557 Mdot
.36832 .16432 Mdot
.10245 .25287 Mdot
.6933 .11459 Mdot
.50789 .10728 Mdot
.33432 .23459 Mdot
.95473 .19319 Mdot
.64214 .07826 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00455 Mdot
.48926 .0145 Mdot
.4658 .04596 Mdot
.39144 .13898 Mdot
.16657 .26671 Mdot
.73503 .11982 Mdot
.54116 .08208 Mdot
.40835 .16243 Mdot
.14553 .27931 Mdot
.69359 .14094 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49461 .00727 Mdot
.48284 .02315 Mdot
.44539 .07279 Mdot
.32761 .20313 Mdot
.99893 .20215 Mdot
.67185 .07203 Mdot
.5553 .02179 Mdot
.52004 .00326 Mdot
.51476 .60763 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49802 .00267 Mdot
.4937 .00851 Mdot
.47992 .02707 Mdot
.43612 .08472 Mdot
.29904 .22531 Mdot
.93448 .16627 Mdot
.66544 .03906 Mdot
.60224 .56871 Mdot
.68205 .4344 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00213 Mdot
.49497 .0068 Mdot
.48397 .02163 Mdot
.44898 .06812 Mdot
.33876 .19331 Mdot
.02598 .21728 Mdot
.6744 .08607 Mdot
.53513 .05377 Mdot
.44814 .101 Mdot
.28472 .24505 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48947 .01421 Mdot
.46648 .04506 Mdot
.39357 .13654 Mdot
.17264 .267 Mdot
.74064 .11971 Mdot
.54695 .07681 Mdot
.42266 .14572 Mdot
.18688 .28181 Mdot
.7309 .13533 Mdot
.50068 .61712 Mdot
.50216 .61511 Mdot
.50689 .60873 Mdot
.52194 .58845 Mdot
.56981 .52578 Mdot
.71908 .38102 Mdot
.10258 .46966 Mdot
.34265 .59291 Mdot
.3833 .07362 Mdot
.26418 .22058 Mdot
.90728 .1394 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00333 Mdot
.49215 .0106 Mdot
.47501 .03367 Mdot
.42053 .10432 Mdot
.25173 .25186 Mdot
.84421 .12942 Mdot
.63481 .01886 Mdot
.60429 .54699 Mdot
.71925 .40219 Mdot
.06849 .46374 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00336 Mdot
.49208 .01069 Mdot
.47478 .03397 Mdot
.41981 .10521 Mdot
.24958 .25275 Mdot
.84062 .12848 Mdot
.63273 .01921 Mdot
.60164 .5493 Mdot
.71285 .40575 Mdot
.05633 .45689 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.49482 .007 Mdot
.48349 .02228 Mdot
.44745 .07011 Mdot
.33401 .19758 Mdot
.01432 .21084 Mdot
.67318 .08015 Mdot
.5435 .04032 Mdot
.47827 .06039 Mdot
.38055 .16102 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49732 .00363 Mdot
.49145 .01155 Mdot
.47276 .03668 Mdot
.41342 .11304 Mdot
.23052 .25948 Mdot
.81068 .12253 Mdot
.61242 .02676 Mdot
.56912 .58271 Mdot
.62628 .47754 Mdot
.8536 .36017 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45725 .05728 Mdot
.36457 .16821 Mdot
.0924 .24914 Mdot
.68928 .1122 Mdot
.50773 .10504 Mdot
.33777 .23071 Mdot
.96448 .19805 Mdot
.64402 .08202 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00456 Mdot
.48925 .01452 Mdot
.46576 .04601 Mdot
.39132 .13912 Mdot
.16622 .26669 Mdot
.73471 .11982 Mdot
.54084 .08238 Mdot
.40755 .16335 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51033 .60409 Mdot
.53289 .57382 Mdot
.60443 .4838 Mdot
.82163 .35095 Mdot
.25378 .49845 Mdot
.44727 .54644 Mdot
.56311 .48945 Mdot
.77116 .34321 Mdot
.21583 .48737 Mdot
.50087 .61685 Mdot
.50278 .61427 Mdot
.50887 .60605 Mdot
.52826 .57999 Mdot
.58981 .50108 Mdot
.77905 .35599 Mdot
.20305 .49716 Mdot
.39863 .5849 Mdot
.45224 .01048 Mdot
.43527 .06885 Mdot
.32388 .20078 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00084 Mdot
.49801 .00269 Mdot
.49366 .00857 Mdot
.47979 .02726 Mdot
.43568 .08528 Mdot
.2977 .22624 Mdot
.93163 .1648 Mdot
.66499 .0378 Mdot
.60383 .56627 Mdot
.68758 .42992 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01505 Mdot
.4645 .04769 Mdot
.38734 .14363 Mdot
.15494 .26563 Mdot
.72515 .11988 Mdot
.53118 .09116 Mdot
.38368 .18965 Mdot
.07682 .25813 Mdot
.65915 .13398 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48887 .01503 Mdot
.46455 .04762 Mdot
.38749 .14345 Mdot
.15539 .26568 Mdot
.7255 .11988 Mdot
.53153 .09084 Mdot
.38454 .18874 Mdot
.07916 .25913 Mdot
.65988 .13462 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60498 Mdot
.53078 .57663 Mdot
.59778 .49158 Mdot
.80239 .35195 Mdot
.23291 .49865 Mdot
.42608 .56474 Mdot
.51232 .55333 Mdot
.61701 .45436 Mdot
.88184 .35461 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .60139 Mdot
.53925 .56538 Mdot
.62444 .46141 Mdot
.87786 .35898 Mdot
.29703 .50013 Mdot
.4878 .51142 Mdot
.6603 .3867 Mdot
.03461 .41853 Mdot
.35741 .53373 Mdot
.50102 .61666 Mdot
.50323 .61366 Mdot
.51031 .60412 Mdot
.53282 .5739 Mdot
.60423 .48403 Mdot
.82105 .35095 Mdot
.2532 .49846 Mdot
.44667 .54698 Mdot
.56164 .49126 Mdot
.76676 .34453 Mdot
.2093 .48728 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.51169 .60224 Mdot
.53724 .56803 Mdot
.61815 .46828 Mdot
.86046 .35487 Mdot
.28627 .4986 Mdot
.47952 .51753 Mdot
.64214 .40259 Mdot
.99072 .394 Mdot
.35322 .51159 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51112 .60302 Mdot
.53541 .57047 Mdot
.61238 .47473 Mdot
.84425 .35231 Mdot
.2742 .49815 Mdot
.46818 .52745 Mdot
.61474 .43006 Mdot
.91889 .35808 Mdot
.33951 .4829 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51227 .60147 Mdot
.53908 .5656 Mdot
.62392 .46198 Mdot
.87643 .35859 Mdot
.29622 .49995 Mdot
.48728 .51173 Mdot
.65928 .38752 Mdot
.03226 .41722 Mdot
.35718 .53255 Mdot
.50098 .61672 Mdot
.50311 .61384 Mdot
.5099 .60466 Mdot
.53154 .57562 Mdot
.60017 .48877 Mdot
.80932 .35135 Mdot
.24082 .49865 Mdot
.43398 .55812 Mdot
.53092 .52963 Mdot
.67396 .39861 Mdot
.029 .42535 Mdot
.50088 .61684 Mdot
.50282 .61423 Mdot
.50898 .60591 Mdot
.5286 .57954 Mdot
.59089 .49979 Mdot
.78221 .35525 Mdot
.2074 .49755 Mdot
.40235 .5825 Mdot
.45986 .00128 Mdot
.45778 .03997 Mdot
.39311 .13178 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50971 .60491 Mdot
.53094 .57641 Mdot
.59829 .49097 Mdot
.80389 .3518 Mdot
.23466 .49866 Mdot
.42781 .56331 Mdot
.51635 .54818 Mdot
.62939 .44101 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50808 .60712 Mdot
.52573 .58337 Mdot
.58182 .51081 Mdot
.75531 .36335 Mdot
.1674 .49147 Mdot
.37219 .59762 Mdot
.40522 .06235 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61167 Mdot
.515 .59779 Mdot
.54775 .55419 Mdot
.65105 .43425 Mdot
.94842 .38726 Mdot
.32181 .52004 Mdot
.48036 .53821 Mdot
.60952 .4445 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50605 .60986 Mdot
.51927 .59204 Mdot
.56133 .53658 Mdot
.69313 .39835 Mdot
.04858 .4427 Mdot
.33229 .57096 Mdot
.40846 .03318 Mdot
.35477 .14989 Mdot
.11224 .24553 Mdot
.50095 .61675 Mdot
.50302 .61396 Mdot
.50961 .60505 Mdot
.53062 .57683 Mdot
.59729 .49216 Mdot
.80096 .35211 Mdot
.23123 .49863 Mdot
.42443 .56608 Mdot
.50849 .55822 Mdot
.60527 .46759 Mdot
.8487 .34752 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00204 Mdot
.49519 .0065 Mdot
.48467 .02069 Mdot
.45118 .06524 Mdot
.34562 .18695 Mdot
.04312 .22644 Mdot
.67673 .09426 Mdot
.52422 .07189 Mdot
.4079 .15259 Mdot
.16101 .27766 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49594 .00549 Mdot
.48706 .01746 Mdot
.45881 .05523 Mdot
.36945 .16313 Mdot
.10549 .25392 Mdot
.69463 .11522 Mdot
.50821 .10761 Mdot
.33409 .23504 Mdot
.95379 .1928 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49292 .00957 Mdot
.47743 .03042 Mdot
.42822 .09473 Mdot
.27494 .24047 Mdot
.88585 .14349 Mdot
.65368 .02215 Mdot
.61784 .54065 Mdot
.74306 .39324 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61167 Mdot
.51501 .59778 Mdot
.54779 .55414 Mdot
.65118 .43413 Mdot
.94874 .38743 Mdot
.32187 .52018 Mdot
.4802 .53849 Mdot
.6089 .44523 Mdot
.88851 .35012 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49516 .00654 Mdot
.48457 .02082 Mdot
.45089 .06563 Mdot
.3447 .18781 Mdot
.04081 .22524 Mdot
.67637 .0932 Mdot
.52557 .0696 Mdot
.41296 .14632 Mdot
.17621 .27829 Mdot
.50103 .61664 Mdot
.50328 .6136 Mdot
.51045 .60392 Mdot
.53329 .57328 Mdot
.60571 .48233 Mdot
.82528 .35099 Mdot
.25737 .49837 Mdot
.45099 .54309 Mdot
.57225 .47839 Mdot
.79819 .33756 Mdot
.25201 .48509 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.5009 .61681 Mdot
.50288 .61414 Mdot
.50918 .60563 Mdot
.52925 .57866 Mdot
.59296 .4973 Mdot
.78831 .35401 Mdot
.21551 .4981 Mdot
.40956 .57751 Mdot
.47513 .60047 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.50929 .60548 Mdot
.5296 .5782 Mdot
.59406 .49599 Mdot
.79153 .35344 Mdot
.21965 .49831 Mdot
.41337 .57471 Mdot
.48347 .59001 Mdot
.52881 .56345 Mdot
.61713 .4644 Mdot
.50104 .61662 Mdot
.50333 .61354 Mdot
.5106 .60371 Mdot
.53377 .57264 Mdot
.60722 .48059 Mdot
.82961 .35112 Mdot
.26148 .49828 Mdot
.45524 .53923 Mdot
.58275 .46593 Mdot
.82885 .33613 Mdot
.28499 .48012 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60703 Mdot
.52595 .58308 Mdot
.5825 .50999 Mdot
.75732 .3626 Mdot
.17063 .49217 Mdot
.37428 .59697 Mdot
.40836 .05928 Mdot
.31245 .19561 Mdot
.99594 .19185 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49548 .00611 Mdot
.4856 .01944 Mdot
.45416 .06135 Mdot
.35489 .178 Mdot
.06689 .23819 Mdot
.68148 .10411 Mdot
.51302 .09205 Mdot
.36408 .20329 Mdot
.50129 .61629 Mdot
.50411 .61249 Mdot
.51308 .60037 Mdot
.54166 .56219 Mdot
.63203 .45335 Mdot
.89849 .3655 Mdot
.3071 .50365 Mdot
.49218 .51089 Mdot
.66554 .38365 Mdot
.04478 .42462 Mdot
.35774 .53963 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .60219 Mdot
.53737 .56787 Mdot
.61854 .46786 Mdot
.86153 .35508 Mdot
.287 .49866 Mdot
.48015 .51701 Mdot
.64361 .40122 Mdot
.99442 .39605 Mdot
.3536 .51343 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51129 .60278 Mdot
.53597 .56972 Mdot
.61413 .47275 Mdot
.8492 .35295 Mdot
.27811 .4982 Mdot
.472 .52403 Mdot
.6241 .42029 Mdot
.94405 .36949 Mdot
.34621 .49089 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61757 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60315 Mdot
.53509 .57088 Mdot
.61139 .47585 Mdot
.84145 .352 Mdot
.27191 .49815 Mdot
.46589 .52953 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00487 Mdot
.48851 .01551 Mdot
.46341 .04913 Mdot
.38392 .14745 Mdot
.14533 .26423 Mdot
.71781 .11969 Mdot
.52414 .09739 Mdot
.36656 .2071 Mdot
.03146 .23608 Mdot
.64947 .117 Mdot
.50127 .61631 Mdot
.50405 .61256 Mdot
.51292 .6006 Mdot
.54113 .56289 Mdot
.63035 .45512 Mdot
.89395 .36392 Mdot
.30512 .50271 Mdot
.49172 .51038 Mdot
.66591 .38295 Mdot
.04629 .42526 Mdot
.3582 .54 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00511 Mdot
.48794 .01629 Mdot
.46159 .05155 Mdot
.37818 .15378 Mdot
.12937 .26093 Mdot
.70718 .11869 Mdot
.51513 .10469 Mdot
.34574 .22633 Mdot
.97954 .20741 Mdot
.64394 .09143 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50482 .61153 Mdot
.51535 .59732 Mdot
.54886 .55274 Mdot
.6545 .43097 Mdot
.95718 .39175 Mdot
.32332 .52392 Mdot
.4756 .54645 Mdot
.59143 .46627 Mdot
.83699 .34022 Mdot
.49997 5e-05 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00466 Mdot
.48901 .01485 Mdot
.46499 .04704 Mdot
.38887 .1419 Mdot
.15928 .26611 Mdot
.7287 .11989 Mdot
.53472 .08796 Mdot
.3924 .18028 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49867 .0018 Mdot
.49575 .00574 Mdot
.48646 .01828 Mdot
.45687 .05778 Mdot
.36338 .16944 Mdot
.08922 .24789 Mdot
.68813 .11135 Mdot
.50796 .10398 Mdot
.33972 .2287 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00371 Mdot
.49124 .01183 Mdot
.4721 .03756 Mdot
.41133 .11558 Mdot
.22432 .26121 Mdot
.80167 .12137 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51222 .60153 Mdot
.53892 .56581 Mdot
.62341 .46253 Mdot
.87503 .35822 Mdot
.29542 .49979 Mdot
.48674 .51207 Mdot
.65819 .3884 Mdot
.02975 .41582 Mdot
.35694 .53129 Mdot
.50027 .61767 Mdot
.50087 .61687 Mdot
.50276 .61431 Mdot
.50878 .60617 Mdot
.52798 .58037 Mdot
.58892 .50216 Mdot
.7764 .35664 Mdot
.19934 .49678 Mdot
.39554 .58681 Mdot
.44606 .01784 Mdot
.4172 .09118 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49002 .01347 Mdot
.46823 .04273 Mdot
.39908 .13014 Mdot
.18851 .26681 Mdot
.7568 .1194 Mdot
.5636 .06199 Mdot
.4633 .09572 Mdot
.30842 .23344 Mdot
.93071 .17121 Mdot
.49971 .0004 Mdot
.49907 .00126 Mdot
.49702 .00402 Mdot
.49052 .0128 Mdot
.46981 .04062 Mdot
.40408 .12426 Mdot
.20302 .26542 Mdot
.77355 .11949 Mdot
.58021 .04824 Mdot
.50215 .04625 Mdot
.42731 .11132 Mdot
.24719 .25884 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.50099 .6167 Mdot
.50316 .61377 Mdot
.51005 .60446 Mdot
.53202 .57497 Mdot
.6017 .48698 Mdot
.81375 .35111 Mdot
.24564 .4986 Mdot
.43888 .55388 Mdot
.54269 .51477 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.5115 .60251 Mdot
.53662 .56885 Mdot
.6162 .47045 Mdot
.85499 .35386 Mdot
.28243 .49836 Mdot
.47607 .52046 Mdot
.63396 .41042 Mdot
.96988 .38267 Mdot
.35071 .50164 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50832 .6068 Mdot
.5265 .58234 Mdot
.58426 .50783 Mdot
.76257 .36074 Mdot
.17888 .4938 Mdot
.37989 .59487 Mdot
.41737 .05005 Mdot
.33639 .17639 Mdot
.05099 .22285 Mdot
.4998 .00027 Mdot
.49936 .00086 Mdot
.49797 .00275 Mdot
.49352 .00875 Mdot
.47936 .02783 Mdot
.43434 .08699 Mdot
.29359 .22903 Mdot
.923 .16041 Mdot
.66346 .03414 Mdot
.60822 .5594 Mdot
.70309 .41822 Mdot
.02639 .44257 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45743 .05704 Mdot
.36514 .16763 Mdot
.09391 .24972 Mdot
.68985 .11259 Mdot
.50767 .10548 Mdot
.33699 .23153 Mdot
.96237 .19697 Mdot
.64367 .08115 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48875 .01519 Mdot
.46418 .04812 Mdot
.38632 .14477 Mdot
.15208 .26526 Mdot
.72288 .11985 Mdot
.52896 .09315 Mdot
.37824 .19534 Mdot
.06218 .25152 Mdot
.6552 .12938 Mdot
.5011 .61655 Mdot
.50351 .6133 Mdot
.51117 .60295 Mdot
.53558 .57024 Mdot
.6129 .47414 Mdot
.84573 .35249 Mdot
.27539 .49816 Mdot
.46935 .5264 Mdot
.61762 .42702 Mdot
.92669 .36143 Mdot
.34188 .48507 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48813 .01602 Mdot
.46221 .05073 Mdot
.38012 .15165 Mdot
.13475 .26217 Mdot
.71055 .11914 Mdot
.51779 .10268 Mdot
.35164 .22115 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .616 Mdot
.50479 .61156 Mdot
.51527 .59743 Mdot
.54861 .55306 Mdot
.65373 .4317 Mdot
.95523 .39074 Mdot
.323 .52303 Mdot
.47671 .54455 Mdot
.59562 .46114 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49659 .00461 Mdot
.48912 .01469 Mdot
.46535 .04655 Mdot
.39003 .14058 Mdot
.16256 .26641 Mdot
.73149 .11987 Mdot
.53754 .08539 Mdot
.39938 .17257 Mdot
.12016 .27368 Mdot
.67734 .14125 Mdot
.50127 .61632 Mdot
.50405 .61257 Mdot
.51289 .60063 Mdot
.54105 .563 Mdot
.6301 .45538 Mdot
.89328 .36369 Mdot
.30481 .50257 Mdot
.49163 .51033 Mdot
.6659 .38291 Mdot
.04633 .42526 Mdot
.35825 .53997 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.50099 .61669 Mdot
.50316 .61377 Mdot
.51007 .60444 Mdot
.53206 .57492 Mdot
.60182 .48684 Mdot
.8141 .3511 Mdot
.24601 .4986 Mdot
.43927 .55354 Mdot
.54362 .51361 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48771 .01659 Mdot
.46086 .05251 Mdot
.37589 .15626 Mdot
.12306 .25931 Mdot
.70349 .11802 Mdot
.51253 .10642 Mdot
.34035 .23082 Mdot
.96687 .20033 Mdot
.64273 .08505 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48716 .01734 Mdot
.4591 .05484 Mdot
.37036 .16217 Mdot
.10797 .25476 Mdot
.69576 .1157 Mdot
.50856 .10777 Mdot
.33419 .23515 Mdot
.95371 .19284 Mdot
.64169 .07816 Mdot
.50132 .61625 Mdot
.50421 .61234 Mdot
.51343 .59991 Mdot
.54276 .56074 Mdot
.63547 .44978 Mdot
.90771 .36894 Mdot
.31076 .50586 Mdot
.49226 .51303 Mdot
.66217 .38739 Mdot
.03536 .4199 Mdot
.35595 .53594 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45872 .05535 Mdot
.36916 .16343 Mdot
.10472 .25366 Mdot
.69429 .11506 Mdot
.50812 .10754 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00494 Mdot
.48836 .01572 Mdot
.46293 .04977 Mdot
.3824 .14914 Mdot
.14109 .26347 Mdot
.7148 .11952 Mdot
.52142 .09972 Mdot
.36007 .21337 Mdot
.01483 .2271 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61075 Mdot
.51718 .59485 Mdot
.55469 .54514 Mdot
.67264 .41469 Mdot
.00166 .41623 Mdot
.32819 .54632 Mdot
.44423 .59697 Mdot
.47832 .61701 Mdot
.50013 .61786 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50417 .6124 Mdot
.51329 .60009 Mdot
.54233 .56131 Mdot
.63411 .45118 Mdot
.90408 .36755 Mdot
.30938 .50494 Mdot
.49237 .51202 Mdot
.66391 .38554 Mdot
.50129 .61629 Mdot
.50412 .61246 Mdot
.51314 .6003 Mdot
.54184 .56196 Mdot
.63257 .45279 Mdot
.89994 .36602 Mdot
.30771 .50397 Mdot
.49227 .51113 Mdot
.66524 .38403 Mdot
.04387 .42418 Mdot
.35753 .53931 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.49229 .01042 Mdot
.47544 .0331 Mdot
.42188 .10264 Mdot
.2558 .25009 Mdot
.85114 .13135 Mdot
.63861 .01849 Mdot
.60869 .54341 Mdot
.72944 .3971 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .60131 Mdot
.53946 .5651 Mdot
.6251 .4607 Mdot
.87967 .35948 Mdot
.29802 .50036 Mdot
.48842 .51108 Mdot
.66148 .38578 Mdot
.03727 .42002 Mdot
.35767 .53507 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.49309 .00933 Mdot
.47799 .02968 Mdot
.42997 .09253 Mdot
.28025 .23742 Mdot
.8961 .1478 Mdot
.65697 .02475 Mdot
.61692 .54388 Mdot
.7369 .39684 Mdot
.5009 .61681 Mdot
.50288 .61415 Mdot
.50916 .60566 Mdot
.52919 .57875 Mdot
.59275 .49756 Mdot
.78768 .35413 Mdot
.21469 .49806 Mdot
.40882 .57804 Mdot
.47353 .60246 Mdot
.49873 .60363 Mdot
.52203 .58327 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51004 .60447 Mdot
.53199 .57501 Mdot
.6016 .4871 Mdot
.81346 .35113 Mdot
.24532 .49861 Mdot
.43856 .55416 Mdot
.54192 .51575 Mdot
.70742 .37345 Mdot
.10317 .46253 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00533 Mdot
.48744 .01696 Mdot
.45999 .05366 Mdot
.37317 .15918 Mdot
.1156 .25718 Mdot
.69948 .117 Mdot
.51017 .10758 Mdot
.33611 .23405 Mdot
.9574 .19503 Mdot
.64184 .08027 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50297 .61403 Mdot
.50945 .60527 Mdot
.53009 .57754 Mdot
.59561 .49415 Mdot
.79606 .35274 Mdot
.22532 .49851 Mdot
.41871 .57064 Mdot
.49539 .57491 Mdot
.56516 .51618 Mdot
.50022 .61774 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50697 .60862 Mdot
.52219 .58811 Mdot
.57061 .52478 Mdot
.72149 .3796 Mdot
.10729 .4717 Mdot
.34407 .59421 Mdot
.38261 .0754 Mdot
.26061 .22262 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60459 Mdot
.53172 .57538 Mdot
.60074 .4881 Mdot
.81097 .35125 Mdot
.24263 .49864 Mdot
.43582 .55654 Mdot
.53532 .52406 Mdot
.68737 .38779 Mdot
.05991 .44203 Mdot
.5012 .61642 Mdot
.50381 .61289 Mdot
.51214 .60164 Mdot
.53866 .56616 Mdot
.62259 .46342 Mdot
.87277 .35763 Mdot
.2941 .49955 Mdot
.48581 .51269 Mdot
.65626 .39 Mdot
.02523 .41329 Mdot
.35651 .52901 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61094 Mdot
.51672 .59547 Mdot
.55323 .54703 Mdot
.66811 .41859 Mdot
.99082 .41009 Mdot
.32729 .54057 Mdot
.45262 .58385 Mdot
.50794 .57649 Mdot
.57516 .50937 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.4899 .01364 Mdot
.46784 .04325 Mdot
.39785 .13158 Mdot
.18495 .26697 Mdot
.75298 .11945 Mdot
.5597 .06539 Mdot
.45389 .10754 Mdot
.27988 .2525 Mdot
.87133 .14579 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00212 Mdot
.495 .00676 Mdot
.48407 .0215 Mdot
.44928 .06772 Mdot
.3397 .19245 Mdot
.02832 .21856 Mdot
.67468 .08723 Mdot
.53353 .05638 Mdot
.44232 .10869 Mdot
.26645 .25545 Mdot
.50094 .61676 Mdot
.503 .61398 Mdot
.50956 .60512 Mdot
.53046 .57705 Mdot
.59677 .49277 Mdot
.79945 .35229 Mdot
.22944 .4986 Mdot
.42268 .5675 Mdot
.50444 .56338 Mdot
.59287 .48209 Mdot
.81284 .34589 Mdot
.50057 .61726 Mdot
.50182 .61557 Mdot
.50581 .61018 Mdot
.51852 .59305 Mdot
.55893 .53966 Mdot
.68574 .40398 Mdot
.03209 .43353 Mdot
.33063 .56254 Mdot
.42041 .01525 Mdot
.39574 .10514 Mdot
.22561 .25096 Mdot
.50023 .61772 Mdot
.50074 .61703 Mdot
.50236 .61484 Mdot
.50753 .60786 Mdot
.524 .5857 Mdot
.57632 .51763 Mdot
.73877 .37045 Mdot
.13937 .48376 Mdot
.35662 .59942 Mdot
.38674 .07774 Mdot
.26096 .22493 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49384 .00833 Mdot
.48036 .02648 Mdot
.43751 .08294 Mdot
.30332 .22228 Mdot
.94367 .17114 Mdot
.66676 .04332 Mdot
.59667 .57714 Mdot
.66284 .45117 Mdot
.93283 .39073 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50895 .60594 Mdot
.52852 .57964 Mdot
.59064 .50009 Mdot
.78147 .35542 Mdot
.20639 .49746 Mdot
.40148 .58307 Mdot
.45806 .00347 Mdot
.45245 .0469 Mdot
.37657 .1502 Mdot
.50058 .61726 Mdot
.50183 .61556 Mdot
.50584 .61015 Mdot
.5186 .59295 Mdot
.55918 .53934 Mdot
.68652 .40337 Mdot
.03385 .43452 Mdot
.33079 .56346 Mdot
.41909 .01724 Mdot
.3912 .11043 Mdot
.21252 .2539 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48931 .01443 Mdot
.46596 .04575 Mdot
.39192 .13842 Mdot
.16795 .26679 Mdot
.73627 .11979 Mdot
.54244 .08091 Mdot
.41152 .15878 Mdot
.15461 .28061 Mdot
.70058 .14012 Mdot
.50108 .61658 Mdot
.50343 .61339 Mdot
.51094 .60326 Mdot
.53485 .5712 Mdot
.61063 .47671 Mdot
.8393 .35178 Mdot
.2701 .49815 Mdot
.46407 .53118 Mdot
.60461 .44103 Mdot
.89101 .3477 Mdot
.32841 .4777 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49806 .00263 Mdot
.49381 .00837 Mdot
.48027 .02661 Mdot
.43721 .08332 Mdot
.3024 .22294 Mdot
.94167 .17007 Mdot
.66649 .04237 Mdot
.59793 .57524 Mdot
.66718 .44723 Mdot
.94355 .39598 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00379 Mdot
.49107 .01206 Mdot
.47157 .03828 Mdot
.40964 .11762 Mdot
.21932 .26243 Mdot
.7947 .12067 Mdot
.59946 .03435 Mdot
.54387 .61223 Mdot
.55327 .56376 Mdot
.64109 .44943 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48963 .01401 Mdot
.46696 .04442 Mdot
.39509 .13478 Mdot
.17701 .26708 Mdot
.74487 .11961 Mdot
.55133 .07285 Mdot
.43346 .13275 Mdot
.21866 .27745 Mdot
.76974 .13104 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00394 Mdot
.4907 .01256 Mdot
.47038 .03986 Mdot
.40589 .12211 Mdot
.20832 .26462 Mdot
.78015 .11972 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49487 .00693 Mdot
.48366 .02205 Mdot
.44797 .06943 Mdot
.33564 .19613 Mdot
.0183 .21305 Mdot
.67357 .08219 Mdot
.54058 .04498 Mdot
.4678 .07463 Mdot
.34704 .19559 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56787 .52824 Mdot
.71317 .38463 Mdot
.09083 .46433 Mdot
.33952 .58914 Mdot
.38627 .0678 Mdot
.27656 .21329 Mdot
.93145 .15169 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49392 .00822 Mdot
.48062 .02614 Mdot
.43834 .08188 Mdot
.30585 .22044 Mdot
.94918 .17412 Mdot
.66745 .04598 Mdot
.59306 .58257 Mdot
.65044 .46297 Mdot
.90134 .37725 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51058 .60375 Mdot
.53369 .57274 Mdot
.60697 .48087 Mdot
.8289 .35109 Mdot
.26082 .4983 Mdot
.45456 .53985 Mdot
.58106 .46791 Mdot
.82397 .33602 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48082 .02587 Mdot
.43896 .08108 Mdot
.30777 .21901 Mdot
.95341 .17643 Mdot
.66794 .04807 Mdot
.59016 .58692 Mdot
.64051 .47294 Mdot
.87528 .36879 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01313 Mdot
.46903 .04166 Mdot
.40163 .12716 Mdot
.19588 .26625 Mdot
.76507 .11937 Mdot
.57192 .05494 Mdot
.48303 .07065 Mdot
.36872 .17901 Mdot
.07907 .24933 Mdot
.50051 .61734 Mdot
.50163 .61584 Mdot
.50519 .61103 Mdot
.51652 .59574 Mdot
.55259 .54787 Mdot
.66611 .42035 Mdot
.98596 .40736 Mdot
.32684 .53804 Mdot
.45628 .57806 Mdot
.52096 .55868 Mdot
.617 .45973 Mdot
.50067 .61713 Mdot
.50214 .61514 Mdot
.50682 .60883 Mdot
.52172 .58876 Mdot
.56909 .5267 Mdot
.71686 .38234 Mdot
.09822 .46773 Mdot
.34142 .59159 Mdot
.3842 .07169 Mdot
.26821 .21827 Mdot
.91505 .1432 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00636 Mdot
.48501 .02023 Mdot
.45227 .06382 Mdot
.34901 .18372 Mdot
.05174 .23085 Mdot
.67822 .09806 Mdot
.51956 .07997 Mdot
.39017 .1739 Mdot
.10879 .26708 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49516 .00653 Mdot
.4846 .02079 Mdot
.45096 .06554 Mdot
.34491 .18762 Mdot
.04134 .22551 Mdot
.67645 .09344 Mdot
.52526 .07012 Mdot
.41181 .14776 Mdot
.50018 .61779 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50583 .61016 Mdot
.51857 .59298 Mdot
.5591 .53944 Mdot
.68626 .40357 Mdot
.03327 .43419 Mdot
.33073 .56315 Mdot
.41953 .01658 Mdot
.3927 .10869 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49836 .00221 Mdot
.49478 .00705 Mdot
.48338 .02243 Mdot
.4471 .07057 Mdot
.33291 .19854 Mdot
.01166 .20934 Mdot
.67294 .07876 Mdot
.5455 .03716 Mdot
.48538 .05069 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49174 .01116 Mdot
.47367 .03546 Mdot
.4163 .10953 Mdot
.23908 .25673 Mdot
.82369 .12471 Mdot
.6219 .02244 Mdot
.58559 .5649 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50612 .60976 Mdot
.51951 .59172 Mdot
.56209 .53561 Mdot
.69546 .39664 Mdot
.05368 .44547 Mdot
.3329 .57345 Mdot
.40504 .03831 Mdot
.34306 .16134 Mdot
.082 .23404 Mdot
.50127 .61631 Mdot
.50405 .61256 Mdot
.51292 .60059 Mdot
.54114 .56288 Mdot
.63039 .45508 Mdot
.89405 .36396 Mdot
.30516 .50273 Mdot
.49173 .51039 Mdot
.66591 .38296 Mdot
.04627 .42525 Mdot
.3582 .54 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00379 Mdot
.49107 .01206 Mdot
.47156 .03828 Mdot
.40962 .11763 Mdot
.21929 .26244 Mdot
.79465 .12066 Mdot
.59942 .03438 Mdot
.54379 .61233 Mdot
.55303 .56407 Mdot
.64033 .45019 Mdot
.50036 .61754 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51175 .60217 Mdot
.53741 .56782 Mdot
.61866 .46772 Mdot
.86187 .35515 Mdot
.28723 .49868 Mdot
.48035 .51685 Mdot
.64407 .4008 Mdot
.99556 .39669 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48683 .01778 Mdot
.45807 .0562 Mdot
.36715 .16554 Mdot
.09929 .25174 Mdot
.69197 .11389 Mdot
.5077 .10676 Mdot
.33496 .23378 Mdot
.9567 .19413 Mdot
.64259 .07893 Mdot
.501 .61668 Mdot
.50319 .61373 Mdot
.51015 .60432 Mdot
.53234 .57454 Mdot
.60271 .4858 Mdot
.81667 .35101 Mdot
.24872 .49855 Mdot
.44205 .5511 Mdot
.55035 .5052 Mdot
.73292 .3585 Mdot
.15286 .47941 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00272 Mdot
.49358 .00867 Mdot
.47956 .02757 Mdot
.43495 .08621 Mdot
.29546 .22777 Mdot
.92692 .16238 Mdot
.66418 .03577 Mdot
.60631 .56241 Mdot
.69631 .42318 Mdot
.01158 .43391 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49643 .00483 Mdot
.48861 .01538 Mdot
.46373 .04871 Mdot
.38492 .14634 Mdot
.14814 .26468 Mdot
.71988 .11977 Mdot
.52608 .0957 Mdot
.37123 .20247 Mdot
.04362 .24241 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .60559 Mdot
.52935 .57854 Mdot
.59325 .49695 Mdot
.78918 .35385 Mdot
.21663 .49816 Mdot
.41059 .57676 Mdot
.47736 .59768 Mdot
.5103 .58813 Mdot
.55868 .53496 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50707 .60848 Mdot
.52253 .58766 Mdot
.57168 .52343 Mdot
.72475 .37774 Mdot
.11356 .47431 Mdot
.34612 .59575 Mdot
.38217 .07724 Mdot
.25719 .22464 Mdot
.89371 .13327 Mdot
.5007 .61709 Mdot
.50224 .61501 Mdot
.50713 .60841 Mdot
.5227 .58743 Mdot
.57222 .52275 Mdot
.7264 .37682 Mdot
.11668 .47556 Mdot
.34721 .59643 Mdot
.38216 .07793 Mdot
.25607 .22537 Mdot
.89142 .13233 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00505 Mdot
.4881 .01607 Mdot
.46211 .05086 Mdot
.37981 .15199 Mdot
.13388 .26198 Mdot
.70999 .11907 Mdot
.51733 .10304 Mdot
.35061 .22208 Mdot
.99128 .214 Mdot
.64503 .0974 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48906 .01477 Mdot
.46517 .0468 Mdot
.38944 .14125 Mdot
.16089 .26627 Mdot
.73006 .11988 Mdot
.53609 .08671 Mdot
.39579 .17656 Mdot
.11011 .27069 Mdot
.67213 .14045 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49035 .01303 Mdot
.46926 .04135 Mdot
.40236 .12629 Mdot
.19801 .26604 Mdot
.76755 .11939 Mdot
.57438 .05292 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49035 .01303 Mdot
.46927 .04134 Mdot
.40238 .12627 Mdot
.19808 .26603 Mdot
.76764 .11939 Mdot
.57446 .05285 Mdot
.48895 .06309 Mdot
.38687 .15935 Mdot
.12903 .26629 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50758 .6078 Mdot
.52413 .58551 Mdot
.57675 .51709 Mdot
.74008 .36983 Mdot
.14169 .48451 Mdot
.35774 .59951 Mdot
.38771 .07716 Mdot
.26286 .22422 Mdot
.90006 .13754 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51224 .60151 Mdot
.53898 .56573 Mdot
.6236 .46232 Mdot
.87554 .35835 Mdot
.29572 .49985 Mdot
.48694 .51194 Mdot
.6586 .38807 Mdot
.03069 .41634 Mdot
.35703 .53176 Mdot
.50079 .61697 Mdot
.5025 .61465 Mdot
.50797 .60727 Mdot
.52539 .58383 Mdot
.58073 .51215 Mdot
.75205 .36462 Mdot
.16208 .49022 Mdot
.36889 .59848 Mdot
.40053 .06678 Mdot
.29248 .2091 Mdot
.95416 .16718 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00407 Mdot
.49041 .01295 Mdot
.46946 .04109 Mdot
.40296 .12558 Mdot
.19977 .26584 Mdot
.76963 .11941 Mdot
.57642 .05126 Mdot
.49347 .05731 Mdot
.40073 .14349 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00505 Mdot
.48809 .01608 Mdot
.46207 .05091 Mdot
.3797 .15212 Mdot
.13356 .26191 Mdot
.70979 .11905 Mdot
.51717 .10316 Mdot
.35024 .2224 Mdot
.50003 .61799 Mdot
.5001 .61791 Mdot
.5003 .61762 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50981 .60479 Mdot
.53124 .57601 Mdot
.59924 .48985 Mdot
.80664 .35155 Mdot
.23782 .49867 Mdot
.43096 .56069 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.4977 .0031 Mdot
.49269 .00988 Mdot
.4767 .0314 Mdot
.4259 .09764 Mdot
.26792 .24425 Mdot
.87272 .13844 Mdot
.64873 .01976 Mdot
.61675 .53901 Mdot
.74461 .39155 Mdot
.11107 .48636 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51208 .60172 Mdot
.53847 .5664 Mdot
.62202 .46404 Mdot
.87118 .35724 Mdot
.29315 .49939 Mdot
.48512 .51317 Mdot
.65479 .39125 Mdot
.02173 .41133 Mdot
.35618 .52724 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.5417 .56214 Mdot
.63214 .45324 Mdot
.89878 .3656 Mdot
.30722 .50371 Mdot
.4922 .51094 Mdot
.66548 .38372 Mdot
.04462 .42454 Mdot
.3577 .53957 Mdot
.50075 .61702 Mdot
.5024 .6148 Mdot
.50763 .60772 Mdot
.52432 .58527 Mdot
.57733 .51637 Mdot
.74183 .36902 Mdot
.14474 .48546 Mdot
.35926 .59958 Mdot
.38912 .07622 Mdot
.2658 .22303 Mdot
.90492 .14004 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00287 Mdot
.49322 .00916 Mdot
.47841 .02911 Mdot
.4313 .09084 Mdot
.28432 .23497 Mdot
.90413 .15137 Mdot
.65921 .02719 Mdot
.61521 .5475 Mdot
.72933 .4012 Mdot
.08018 .47243 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50755 .60783 Mdot
.52407 .5856 Mdot
.57654 .51735 Mdot
.73945 .37013 Mdot
.14057 .48415 Mdot
.3572 .59947 Mdot
.38723 .07745 Mdot
.26191 .22458 Mdot
.89853 .13676 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48711 .0174 Mdot
.45895 .05503 Mdot
.36991 .16265 Mdot
.10674 .25435 Mdot
.6952 .11546 Mdot
.50837 .1077 Mdot
.33411 .23512 Mdot
.95367 .19278 Mdot
.50072 .61706 Mdot
.50231 .61492 Mdot
.50735 .60811 Mdot
.5234 .5865 Mdot
.57443 .51998 Mdot
.73308 .37327 Mdot
.12912 .48026 Mdot
.35203 .59851 Mdot
.38362 .07901 Mdot
.25578 .22646 Mdot
.88937 .13196 Mdot
.49989 .00015 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48892 .01497 Mdot
.4647 .04742 Mdot
.38798 .14291 Mdot
.15675 .26584 Mdot
.72661 .11989 Mdot
.53262 .08985 Mdot
.38724 .18586 Mdot
.08651 .26217 Mdot
.50005 .61797 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50165 .6158 Mdot
.50526 .61093 Mdot
.51675 .59543 Mdot
.55333 .54691 Mdot
.66842 .41832 Mdot
.99156 .4105 Mdot
.32735 .54096 Mdot
.45206 .58473 Mdot
.50128 .61631 Mdot
.50407 .61253 Mdot
.51298 .60051 Mdot
.54134 .56261 Mdot
.63102 .45441 Mdot
.89576 .36454 Mdot
.30592 .50307 Mdot
.49194 .51054 Mdot
.66586 .38314 Mdot
.04594 .42513 Mdot
.35806 .53996 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51159 .60239 Mdot
.5369 .56849 Mdot
.61707 .46949 Mdot
.85742 .35429 Mdot
.28416 .49845 Mdot
.47765 .5191 Mdot
.63773 .40677 Mdot
.97957 .38788 Mdot
.35197 .50616 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60555 Mdot
.52945 .5784 Mdot
.59359 .49655 Mdot
.79015 .35368 Mdot
.21789 .49823 Mdot
.41173 .57592 Mdot
.47987 .59454 Mdot
.51789 .57799 Mdot
.50067 .61712 Mdot
.50215 .61513 Mdot
.50684 .60879 Mdot
.52181 .58864 Mdot
.56937 .52634 Mdot
.71773 .38182 Mdot
.09994 .4685 Mdot
.34189 .59212 Mdot
.38382 .07248 Mdot
.26654 .21923 Mdot
.91182 .1416 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.53639 .56916 Mdot
.61547 .47126 Mdot
.85297 .35353 Mdot
.28095 .49829 Mdot
.4747 .52165 Mdot
.63065 .41369 Mdot
.96129 .37815 Mdot
.34943 .49783 Mdot
.50089 .61683 Mdot
.50285 .61419 Mdot
.50907 .60579 Mdot
.52889 .57915 Mdot
.5918 .49869 Mdot
.7849 .35468 Mdot
.21102 .49782 Mdot
.40553 .58035 Mdot
.46651 .61116 Mdot
.47763 .01379 Mdot
.45531 .05468 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49678 .00435 Mdot
.48975 .01385 Mdot
.46734 .04391 Mdot
.39629 .13339 Mdot
.18046 .26708 Mdot
.74832 .11954 Mdot
.55491 .06964 Mdot
.44222 .12203 Mdot
.24477 .2695 Mdot
.80871 .13188 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53083 .57656 Mdot
.59794 .49138 Mdot
.80287 .3519 Mdot
.23348 .49865 Mdot
.42664 .56428 Mdot
.51361 .55168 Mdot
.62096 .45003 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46941 .04115 Mdot
.40284 .12573 Mdot
.19939 .26588 Mdot
.76919 .11941 Mdot
.57598 .05161 Mdot
.49247 .0586 Mdot
.39766 .14707 Mdot
.1597 .27149 Mdot
.50101 .61667 Mdot
.50323 .61367 Mdot
.51028 .60415 Mdot
.53275 .574 Mdot
.60401 .4843 Mdot
.8204 .35095 Mdot
.25255 .49848 Mdot
.44599 .54759 Mdot
.55998 .49329 Mdot
.76181 .34616 Mdot
.20172 .48696 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.4985 .00202 Mdot
.49523 .00644 Mdot
.4848 .02051 Mdot
.45161 .06468 Mdot
.34696 .18568 Mdot
.04652 .2282 Mdot
.67729 .09578 Mdot
.52231 .07517 Mdot
.40068 .16138 Mdot
.13956 .27481 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49768 .00314 Mdot
.49259 .01 Mdot
.47641 .0318 Mdot
.42496 .09881 Mdot
.26508 .2457 Mdot
.86753 .13659 Mdot
.64653 .01914 Mdot
.61556 .53921 Mdot
.74309 .39181 Mdot
.10913 .48523 Mdot
.50049 .61737 Mdot
.50158 .6159 Mdot
.50502 .61125 Mdot
.51601 .59643 Mdot
.55097 .54999 Mdot
.66107 .42488 Mdot
.9736 .40052 Mdot
.32555 .53175 Mdot
.46516 .56379 Mdot
.55293 .51562 Mdot
.71864 .37093 Mdot
.49989 .00015 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48893 .01495 Mdot
.46475 .04736 Mdot
.38812 .14275 Mdot
.15715 .26589 Mdot
.72694 .11989 Mdot
.53295 .08956 Mdot
.38805 .18499 Mdot
.08873 .26305 Mdot
.49966 .00046 Mdot
.49893 .00145 Mdot
.49658 .00463 Mdot
.48909 .01473 Mdot
.46525 .04669 Mdot
.3897 .14096 Mdot
.16162 .26633 Mdot
.73068 .11987 Mdot
.53672 .08613 Mdot
.39735 .17483 Mdot
.11447 .27203 Mdot
.67431 .14086 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00256 Mdot
.49397 .00815 Mdot
.48078 .02593 Mdot
.43883 .08125 Mdot
.30736 .21931 Mdot
.9525 .17593 Mdot
.66784 .04762 Mdot
.59079 .58598 Mdot
.64266 .47074 Mdot
.88099 .37041 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50538 .61076 Mdot
.51715 .59489 Mdot
.5546 .54526 Mdot
.67235 .41493 Mdot
.00098 .41584 Mdot
.32814 .54595 Mdot
.44477 .59614 Mdot
.4802 .61444 Mdot
.48601 .00937 Mdot
.50023 .61772 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50748 .60793 Mdot
.52382 .58593 Mdot
.57576 .51832 Mdot
.73711 .37126 Mdot
.13641 .48279 Mdot
.35524 .59924 Mdot
.38565 .07832 Mdot
.25893 .22563 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50932 .60545 Mdot
.52969 .57808 Mdot
.59433 .49566 Mdot
.79234 .35331 Mdot
.22068 .49835 Mdot
.41433 .574 Mdot
.48558 .58734 Mdot
.53524 .55494 Mdot
.63733 .44285 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49565 .00587 Mdot
.48615 .0187 Mdot
.45589 .05907 Mdot
.36032 .17256 Mdot
.0811 .24454 Mdot
.68543 .10897 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00544 Mdot
.48718 .01731 Mdot
.45917 .05475 Mdot
.37058 .16194 Mdot
.10855 .25495 Mdot
.69603 .11581 Mdot
.50865 .10779 Mdot
.33425 .23514 Mdot
.95378 .19289 Mdot
.50083 .61691 Mdot
.50265 .61445 Mdot
.50846 .60661 Mdot
.52693 .58176 Mdot
.58562 .50616 Mdot
.76663 .35942 Mdot
.18507 .49486 Mdot
.38437 .59287 Mdot
.42509 .04175 Mdot
.35754 .15687 Mdot
.10372 .24636 Mdot
.49998 3e-05 Mdot
.49994 9e-05 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49791 .00282 Mdot
.49335 .00898 Mdot
.47883 .02855 Mdot
.43264 .08914 Mdot
.28841 .23241 Mdot
.91236 .15521 Mdot
.66123 .03003 Mdot
.61265 .55213 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60075 Mdot
.54077 .56337 Mdot
.62921 .45632 Mdot
.89087 .36289 Mdot
.3037 .50212 Mdot
.49125 .51023 Mdot
.66568 .38291 Mdot
.04612 .42507 Mdot
.35834 .53973 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49645 .0048 Mdot
.48868 .01529 Mdot
.46395 .04843 Mdot
.38559 .14559 Mdot
.15003 .26497 Mdot
.7213 .11982 Mdot
.52743 .09451 Mdot
.37452 .19915 Mdot
.05228 .24675 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51032 .60409 Mdot
.53288 .57383 Mdot
.6044 .48383 Mdot
.82154 .35095 Mdot
.2537 .49845 Mdot
.44719 .54652 Mdot
.5629 .48972 Mdot
.77052 .3434 Mdot
.21489 .48737 Mdot
.50097 .61672 Mdot
.50311 .61384 Mdot
.5099 .60467 Mdot
.53152 .57563 Mdot
.60013 .48881 Mdot
.80921 .35136 Mdot
.2407 .49866 Mdot
.43386 .55822 Mdot
.53063 .53001 Mdot
.67306 .39937 Mdot
.02687 .42416 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.47612 .03219 Mdot
.42404 .09996 Mdot
.2623 .24707 Mdot
.86254 .1349 Mdot
.64427 .01873 Mdot
.61398 .5399 Mdot
.7404 .39262 Mdot
.10512 .48314 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49514 .00657 Mdot
.48451 .02091 Mdot
.45067 .06591 Mdot
.34402 .18846 Mdot
.03909 .22433 Mdot
.67612 .0924 Mdot
.52661 .06785 Mdot
.41682 .1415 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00517 Mdot
.4878 .01647 Mdot
.46115 .05213 Mdot
.3768 .15528 Mdot
.12555 .25997 Mdot
.70491 .1183 Mdot
.51349 .10581 Mdot
.34228 .22924 Mdot
.97136 .20284 Mdot
.64317 .0873 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56788 .52823 Mdot
.71318 .38462 Mdot
.09085 .46434 Mdot
.33953 .58915 Mdot
.38626 .06781 Mdot
.27654 .21331 Mdot
.9314 .15166 Mdot
.50029 .61765 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60547 Mdot
.52962 .57817 Mdot
.59412 .49592 Mdot
.7917 .35341 Mdot
.21987 .49832 Mdot
.41357 .57457 Mdot
.4839 .58946 Mdot
.53013 .5617 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49462 .00727 Mdot
.48287 .02312 Mdot
.44546 .0727 Mdot
.32783 .20295 Mdot
.99946 .20245 Mdot
.6719 .07231 Mdot
.55489 .02243 Mdot
.5186 .00523 Mdot
.51013 .61388 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00383 Mdot
.49097 .01219 Mdot
.47124 .03871 Mdot
.4086 .11886 Mdot
.21627 .26311 Mdot
.79056 .12033 Mdot
.59586 .03674 Mdot
.53642 .00327 Mdot
.53113 .59263 Mdot
.57224 .52793 Mdot
.49994 8e-05 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00268 Mdot
.49367 .00855 Mdot
.47983 .0272 Mdot
.43582 .0851 Mdot
.29812 .22595 Mdot
.93253 .16526 Mdot
.66514 .0382 Mdot
.60333 .56702 Mdot
.68587 .4313 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01346 Mdot
.46824 .04271 Mdot
.39914 .13008 Mdot
.18867 .2668 Mdot
.75697 .1194 Mdot
.56378 .06184 Mdot
.46371 .09519 Mdot
.30969 .23248 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50972 .60491 Mdot
.53096 .57638 Mdot
.59836 .49089 Mdot
.80409 .35178 Mdot
.23489 .49866 Mdot
.42804 .56313 Mdot
.51688 .54751 Mdot
.631 .43932 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60737 Mdot
.52516 .58414 Mdot
.58001 .51305 Mdot
.74988 .3655 Mdot
.15848 .48932 Mdot
.36675 .59892 Mdot
.39768 .06934 Mdot
.28548 .21324 Mdot
.94045 .15931 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49547 .00612 Mdot
.48557 .01948 Mdot
.45405 .06149 Mdot
.35455 .17833 Mdot
.06601 .23778 Mdot
.68127 .10378 Mdot
.51334 .09143 Mdot
.3654 .20186 Mdot
.03877 .23746 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48945 .01425 Mdot
.4664 .04517 Mdot
.39332 .13682 Mdot
.17194 .26697 Mdot
.73997 .11972 Mdot
.54626 .07744 Mdot
.42096 .14774 Mdot
.18191 .28199 Mdot
.72565 .13617 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51112 .60302 Mdot
.53542 .57045 Mdot
.61241 .47469 Mdot
.84434 .35232 Mdot
.27428 .49815 Mdot
.46825 .52739 Mdot
.61493 .42986 Mdot
.91939 .35829 Mdot
.33967 .48303 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00335 Mdot
.4921 .01067 Mdot
.47483 .03391 Mdot
.41995 .10503 Mdot
.25001 .25258 Mdot
.84133 .12867 Mdot
.63315 .01914 Mdot
.60219 .54881 Mdot
.71419 .40499 Mdot
.0589 .45836 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48717 .01733 Mdot
.45913 .0548 Mdot
.37046 .16206 Mdot
.10825 .25485 Mdot
.69589 .11575 Mdot
.5086 .10778 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53084 .57655 Mdot
.59796 .49136 Mdot
.80292 .3519 Mdot
.23354 .49865 Mdot
.4267 .56423 Mdot
.51375 .5515 Mdot
.62141 .44955 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61075 Mdot
.51717 .59486 Mdot
.55467 .54517 Mdot
.67256 .41475 Mdot
.00147 .41612 Mdot
.32818 .54622 Mdot
.44438 .59674 Mdot
.47884 .61629 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.4971 .00392 Mdot
.49075 .01249 Mdot
.47053 .03966 Mdot
.40637 .12154 Mdot
.20971 .26438 Mdot
.78194 .1198 Mdot
.5881 .04223 Mdot
.51977 .02395 Mdot
.48102 .04151 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01781 Mdot
.45798 .05632 Mdot
.36685 .16585 Mdot
.0985 .25145 Mdot
.69165 .11371 Mdot
.50767 .1066 Mdot
.33518 .23351 Mdot
.95735 .19445 Mdot
.64273 .07917 Mdot
.50036 .61754 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51176 .60215 Mdot
.53745 .56775 Mdot
.61881 .46756 Mdot
.86228 .35523 Mdot
.2875 .4987 Mdot
.48058 .51666 Mdot
.64461 .4003 Mdot
.99691 .39744 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49179 .01109 Mdot
.47385 .03522 Mdot
.41686 .10884 Mdot
.24076 .25613 Mdot
.82633 .12523 Mdot
.6237 .02176 Mdot
.58849 .56192 Mdot
.67928 .42871 Mdot
.98562 .41539 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.50231 .61492 Mdot
.50735 .6081 Mdot
.52342 .58647 Mdot
.5745 .5199 Mdot
.73329 .37316 Mdot
.1295 .4804 Mdot
.3522 .59856 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49036 .01302 Mdot
.4693 .04131 Mdot
.40246 .12617 Mdot
.19831 .266 Mdot
.76791 .11939 Mdot
.57472 .05264 Mdot
.48956 .06231 Mdot
.38874 .15725 Mdot
.1343 .2675 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00306 Mdot
.49278 .00975 Mdot
.477 .03099 Mdot
.42685 .09644 Mdot
.27081 .24273 Mdot
.87806 .14043 Mdot
.65085 .0206 Mdot
.61752 .53932 Mdot
.74488 .39185 Mdot
.50067 .61713 Mdot
.50213 .61516 Mdot
.50677 .60889 Mdot
.52157 .58895 Mdot
.56863 .52728 Mdot
.71547 .38319 Mdot
.09546 .46647 Mdot
.34068 .59071 Mdot
.3849 .07032 Mdot
.27112 .21657 Mdot
.9207 .14606 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48958 .01407 Mdot
.4668 .04463 Mdot
.3946 .13535 Mdot
.17559 .26706 Mdot
.74347 .11964 Mdot
.54988 .07415 Mdot
.4299 .13706 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49082 .0124 Mdot
.47075 .03937 Mdot
.40705 .12072 Mdot
.21172 .26402 Mdot
.78453 .11993 Mdot
.59047 .0405 Mdot
.52493 .01748 Mdot
.49664 .02059 Mdot
.50081 .61693 Mdot
.5026 .61453 Mdot
.50827 .60686 Mdot
.52634 .58255 Mdot
.58375 .50845 Mdot
.76107 .36126 Mdot
.17654 .49336 Mdot
.37826 .59553 Mdot
.41466 .05288 Mdot
.32911 .18257 Mdot
.03371 .21359 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00562 Mdot
.48676 .01788 Mdot
.45783 .05652 Mdot
.36638 .16634 Mdot
.09724 .25098 Mdot
.69115 .11341 Mdot
.50764 .10633 Mdot
.33559 .23305 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00231 Mdot
.49455 .00736 Mdot
.48263 .02343 Mdot
.44472 .07366 Mdot
.32553 .2049 Mdot
.994 .19934 Mdot
.67147 .06939 Mdot
.55918 .01578 Mdot
.53364 .60286 Mdot
.55819 .55011 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51256 .60108 Mdot
.53999 .56439 Mdot
.62679 .4589 Mdot
.88428 .36082 Mdot
.30046 .50101 Mdot
.4898 .51047 Mdot
.66384 .38402 Mdot
.04249 .42294 Mdot
.35816 .53771 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49794 .00278 Mdot
.49345 .00884 Mdot
.47914 .02813 Mdot
.43363 .08788 Mdot
.29143 .23046 Mdot
.91855 .1582 Mdot
.66258 .03236 Mdot
.61022 .55619 Mdot
.71028 .41322 Mdot
.5009 .61682 Mdot
.50286 .61418 Mdot
.5091 .60575 Mdot
.52898 .57903 Mdot
.59209 .49834 Mdot
.78577 .3545 Mdot
.21217 .4979 Mdot
.40655 .57964 Mdot
.46868 .60848 Mdot
.48414 .00513 Mdot
.47583 .02745 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.5001 .61789 Mdot
.50033 .61759 Mdot
.50105 .61661 Mdot
.50336 .6135 Mdot
.5107 .60358 Mdot
.53409 .57222 Mdot
.60822 .47945 Mdot
.83246 .35127 Mdot
.2641 .49823 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50363 .61312 Mdot
.51158 .6024 Mdot
.53688 .56851 Mdot
.61701 .46955 Mdot
.85726 .35426 Mdot
.28405 .49844 Mdot
.47755 .51918 Mdot
.6375 .40699 Mdot
.97897 .38755 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .0021 Mdot
.49504 .0067 Mdot
.4842 .02132 Mdot
.4497 .06718 Mdot
.341 .19126 Mdot
.03153 .2203 Mdot
.67508 .0888 Mdot
.53139 .05989 Mdot
.43448 .11893 Mdot
.24204 .26629 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.5364 .56914 Mdot
.61551 .47121 Mdot
.85307 .35354 Mdot
.28102 .49829 Mdot
.47477 .52159 Mdot
.63082 .41351 Mdot
.96174 .37839 Mdot
.3495 .49803 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00231 Mdot
.49455 .00736 Mdot
.48264 .02342 Mdot
.44475 .07361 Mdot
.32565 .2048 Mdot
.99427 .19949 Mdot
.67149 .06954 Mdot
.55897 .01611 Mdot
.5329 .60386 Mdot
.55583 .55316 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .004 Mdot
.49058 .01273 Mdot
.46999 .04038 Mdot
.40464 .12359 Mdot
.20467 .26519 Mdot
.77558 .11955 Mdot
.58215 .04673 Mdot
.50654 .04066 Mdot
.44075 .09433 Mdot
.28812 .23766 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50546 .61066 Mdot
.51738 .59458 Mdot
.55533 .54431 Mdot
.67461 .41301 Mdot
.00635 .41889 Mdot
.32856 .54883 Mdot
.44054 .60267 Mdot
.4654 .01646 Mdot
.43876 .07185 Mdot
.49989 .00016 Mdot
.49963 .00049 Mdot
.49883 .00158 Mdot
.49629 .00502 Mdot
.48816 .01598 Mdot
.46231 .0506 Mdot
.38043 .15131 Mdot
.13561 .26236 Mdot
.71111 .1192 Mdot
.51825 .10232 Mdot
.35269 .2202 Mdot
.99641 .21687 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.51091 .6033 Mdot
.53475 .57135 Mdot
.61029 .47709 Mdot
.83834 .3517 Mdot
.26928 .49816 Mdot
.46324 .53193 Mdot
.60256 .4433 Mdot
.88529 .34593 Mdot
.32557 .47715 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49696 .0041 Mdot
.49032 .01307 Mdot
.46917 .04148 Mdot
.40205 .12666 Mdot
.19711 .26613 Mdot
.7665 .11938 Mdot
.57334 .05377 Mdot
.48635 .06641 Mdot
.37889 .16816 Mdot
.10681 .25991 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46277 .04998 Mdot
.38191 .14969 Mdot
.13971 .2632 Mdot
.71385 .11944 Mdot
.52058 .10042 Mdot
.3581 .21522 Mdot
.00986 .22436 Mdot
.64684 .10673 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47146 .03842 Mdot
.4093 .11802 Mdot
.21833 .26266 Mdot
.79334 .12055 Mdot
.59829 .03512 Mdot
.54147 .61514 Mdot
.54615 .57295 Mdot
.61909 .47257 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49723 .00374 Mdot
.49117 .01193 Mdot
.47187 .03787 Mdot
.4106 .11646 Mdot
.22217 .26175 Mdot
.79865 .12105 Mdot
.6028 .03224 Mdot
.55063 .60412 Mdot
.57314 .53867 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.51341 .59993 Mdot
.54271 .56081 Mdot
.63531 .44994 Mdot
.90728 .36877 Mdot
.3106 .50575 Mdot
.49228 .5129 Mdot
.6624 .38715 Mdot
.03598 .42022 Mdot
.35605 .5362 Mdot
.5004 .6175 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.54089 .5632 Mdot
.62962 .45589 Mdot
.89197 .36326 Mdot
.30421 .50232 Mdot
.49143 .51026 Mdot
.66581 .38289 Mdot
.04629 .42519 Mdot
.49993 .0001 Mdot
.49978 .0003 Mdot
.49929 .00097 Mdot
.49772 .00308 Mdot
.49274 .0098 Mdot
.47689 .03115 Mdot
.42648 .09691 Mdot
.26967 .24333 Mdot
.87594 .13962 Mdot
.65003 .02024 Mdot
.61727 .53914 Mdot
.74493 .39167 Mdot
.50115 .61648 Mdot
.50368 .61307 Mdot
.51171 .60222 Mdot
.53729 .56797 Mdot
.6183 .46813 Mdot
.86085 .35495 Mdot
.28654 .49862 Mdot
.47975 .51734 Mdot
.64269 .40208 Mdot
.9921 .39476 Mdot
.35336 .51227 Mdot
.50028 .61766 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52884 .57922 Mdot
.59164 .49888 Mdot
.78443 .35478 Mdot
.21039 .49778 Mdot
.40497 .58073 Mdot
.46533 .61262 Mdot
.47408 .01851 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .60559 Mdot
.52935 .57853 Mdot
.59327 .49693 Mdot
.78921 .35384 Mdot
.21668 .49817 Mdot
.41063 .57673 Mdot
.47746 .59756 Mdot
.51059 .58775 Mdot
.55958 .5338 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60118 Mdot
.53975 .56472 Mdot
.62601 .45973 Mdot
.88216 .36019 Mdot
.29936 .5007 Mdot
.4892 .5107 Mdot
.66287 .38472 Mdot
.04037 .42175 Mdot
.35797 .53663 Mdot
.50037 .61754 Mdot
.50116 .61646 Mdot
.50371 .61303 Mdot
.51181 .60209 Mdot
.53761 .56755 Mdot
.6193 .46702 Mdot
.86365 .35552 Mdot
.28841 .49879 Mdot
.48135 .51604 Mdot
.64639 .39867 Mdot
.00133 .3999 Mdot
.50037 .61754 Mdot
.50117 .61645 Mdot
.50374 .61299 Mdot
.5119 .60196 Mdot
.53791 .56714 Mdot
.62026 .46597 Mdot
.8663 .3561 Mdot
.29013 .49898 Mdot
.48277 .51492 Mdot
.64961 .39577 Mdot
.00924 .40433 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49782 .00295 Mdot
.49304 .0094 Mdot
.47783 .02989 Mdot
.42947 .09315 Mdot
.27875 .23829 Mdot
.89319 .14654 Mdot
.65608 .02395 Mdot
.61733 .5428 Mdot
.73906 .3956 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48993 .0136 Mdot
.46792 .04314 Mdot
.39813 .13126 Mdot
.18574 .26694 Mdot
.75382 .11944 Mdot
.56056 .06464 Mdot
.45597 .10494 Mdot
.28618 .24869 Mdot
.88379 .15028 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .0133 Mdot
.46862 .0422 Mdot
.40033 .12868 Mdot
.19213 .26658 Mdot
.7608 .11937 Mdot
.56765 .05853 Mdot
.47296 .08348 Mdot
.33789 .20909 Mdot
.99957 .2087 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49581 .00566 Mdot
.48665 .01802 Mdot
.45748 .05697 Mdot
.3653 .16746 Mdot
.09434 .24989 Mdot
.69001 .1127 Mdot
.50766 .1056 Mdot
.33679 .23175 Mdot
.96181 .19668 Mdot
.64357 .08092 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48932 .01442 Mdot
.46599 .04571 Mdot
.39202 .13831 Mdot
.16824 .26681 Mdot
.73654 .11979 Mdot
.54271 .08067 Mdot
.41219 .15801 Mdot
.15653 .28083 Mdot
.70214 .13991 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00341 Mdot
.49195 .01087 Mdot
.47436 .03453 Mdot
.41849 .10684 Mdot
.24561 .25433 Mdot
.8341 .12691 Mdot
.62875 .02015 Mdot
.59616 .55436 Mdot
.69918 .41428 Mdot
.02886 .44089 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52883 .57923 Mdot
.59161 .49891 Mdot
.78436 .35479 Mdot
.21029 .49777 Mdot
.40488 .58079 Mdot
.46515 .61284 Mdot
.47354 .01923 Mdot
.44244 .07143 Mdot
.50094 .61677 Mdot
.50299 .614 Mdot
.50952 .60517 Mdot
.53034 .57722 Mdot
.59638 .49323 Mdot
.79832 .35243 Mdot
.22807 .49858 Mdot
.42136 .56855 Mdot
.50141 .56724 Mdot
.58359 .49326 Mdot
.78548 .34937 Mdot
.49992 .00011 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49732 .00362 Mdot
.49146 .01154 Mdot
.47279 .03664 Mdot
.4135 .11294 Mdot
.23076 .25941 Mdot
.81103 .12258 Mdot
.6127 .02662 Mdot
.56963 .58215 Mdot
.62769 .47607 Mdot
.5009 .61682 Mdot
.50286 .61417 Mdot
.50912 .60572 Mdot
.52905 .57893 Mdot
.59232 .49806 Mdot
.78644 .35437 Mdot
.21306 .49796 Mdot
.40735 .57908 Mdot
.47037 .60639 Mdot
.48921 .61639 Mdot
.49187 .00589 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51159 .60238 Mdot
.53693 .56845 Mdot
.61715 .46939 Mdot
.85766 .35434 Mdot
.28433 .49846 Mdot
.4778 .51897 Mdot
.63809 .40642 Mdot
.98049 .38838 Mdot
.35208 .5066 Mdot
.50057 .61727 Mdot
.5018 .6156 Mdot
.50575 .61027 Mdot
.51832 .59332 Mdot
.55831 .54046 Mdot
.68383 .40549 Mdot
.02773 .43107 Mdot
.33025 .56025 Mdot
.42375 .01024 Mdot
.40718 .09148 Mdot
.25916 .23879 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49555 .00601 Mdot
.48583 .01912 Mdot
.4549 .06038 Mdot
.3572 .1757 Mdot
.07291 .24095 Mdot
.68304 .10628 Mdot
.51108 .09601 Mdot
.35574 .21217 Mdot
.01244 .22369 Mdot
.50046 .61742 Mdot
.50145 .61607 Mdot
.50463 .61178 Mdot
.51474 .59814 Mdot
.54693 .55525 Mdot
.64851 .4367 Mdot
.94191 .38404 Mdot
.32052 .51734 Mdot
.48345 .53265 Mdot
.62161 .43057 Mdot
.92493 .36353 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.50291 .61411 Mdot
.50926 .60553 Mdot
.5295 .57833 Mdot
.59373 .49637 Mdot
.79058 .3536 Mdot
.21844 .49826 Mdot
.41225 .57554 Mdot
.481 .59311 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.50579 .61021 Mdot
.51845 .59314 Mdot
.55873 .53993 Mdot
.6851 .40448 Mdot
.03064 .43271 Mdot
.3305 .56178 Mdot
.42152 .01359 Mdot
.39953 .10066 Mdot
.23665 .24769 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51586 .59663 Mdot
.55048 .55061 Mdot
.65957 .42625 Mdot
.96988 .3985 Mdot
.3251 .52992 Mdot
.46768 .55968 Mdot
.5621 .50355 Mdot
.74734 .35603 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49345 .00885 Mdot
.47913 .02814 Mdot
.43361 .08792 Mdot
.29136 .23051 Mdot
.91839 .15812 Mdot
.66254 .0323 Mdot
.61028 .55608 Mdot
.71053 .41305 Mdot
.0422 .45171 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50266 .61444 Mdot
.50847 .6066 Mdot
.52697 .58172 Mdot
.58573 .50603 Mdot
.76695 .35932 Mdot
.18556 .49494 Mdot
.38473 .5927 Mdot
.42573 .04104 Mdot
.35932 .15513 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.4967 .00445 Mdot
.4895 .01418 Mdot
.46655 .04497 Mdot
.39378 .13629 Mdot
.17326 .26701 Mdot
.74122 .11969 Mdot
.54755 .07626 Mdot
.42416 .14394 Mdot
.19127 .28155 Mdot
.73572 .1346 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50922 .60559 Mdot
.52936 .57853 Mdot
.59328 .49691 Mdot
.78926 .35384 Mdot
.21674 .49817 Mdot
.41068 .57669 Mdot
.47757 .59742 Mdot
.51093 .58729 Mdot
.56067 .5324 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00237 Mdot
.49442 .00753 Mdot
.48223 .02397 Mdot
.44344 .07531 Mdot
.3216 .20817 Mdot
.98477 .19407 Mdot
.67075 .06444 Mdot
.56648 .00459 Mdot
.55905 .56912 Mdot
.63819 .45652 Mdot
.50122 .61638 Mdot
.50389 .61277 Mdot
.5124 .60129 Mdot
.5395 .56504 Mdot
.62525 .46055 Mdot
.88006 .35959 Mdot
.29823 .50041 Mdot
.48855 .51101 Mdot
.66171 .3856 Mdot
.03781 .42032 Mdot
.35772 .53533 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00338 Mdot
.49202 .01078 Mdot
.47457 .03425 Mdot
.41915 .10602 Mdot
.24761 .25355 Mdot
.83736 .12768 Mdot
.63077 .01963 Mdot
.59901 .55169 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49346 .00884 Mdot
.47916 .02811 Mdot
.43368 .08782 Mdot
.29158 .23036 Mdot
.91885 .15835 Mdot
.66264 .03248 Mdot
.61009 .5564 Mdot
.70981 .41354 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47146 .03842 Mdot
.4093 .11803 Mdot
.21832 .26266 Mdot
.79333 .12055 Mdot
.59828 .03512 Mdot
.54145 .61516 Mdot
.54609 .57303 Mdot
.61891 .47276 Mdot
.50087 .61686 Mdot
.50276 .6143 Mdot
.5088 .60615 Mdot
.52804 .58029 Mdot
.58911 .50193 Mdot
.77697 .3565 Mdot
.20015 .49686 Mdot
.39621 .58641 Mdot
.44738 .01627 Mdot
.42105 .08649 Mdot
.2811 .23123 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00382 Mdot
.49098 .01218 Mdot
.47128 .03866 Mdot
.40873 .1187 Mdot
.21667 .26302 Mdot
.79109 .12037 Mdot
.59633 .03642 Mdot
.53739 .00207 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49517 .00652 Mdot
.48462 .02076 Mdot
.45102 .06545 Mdot
.34512 .18742 Mdot
.04186 .22578 Mdot
.67653 .09368 Mdot
.52495 .07064 Mdot
.41065 .14919 Mdot
.16926 .27815 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56446 Mdot
.62662 .45908 Mdot
.88382 .36068 Mdot
.30022 .50094 Mdot
.48967 .51051 Mdot
.66365 .38416 Mdot
.04207 .4227 Mdot
.35812 .53749 Mdot
.5013 .61628 Mdot
.50414 .61243 Mdot
.5132 .60021 Mdot
.54205 .56168 Mdot
.63324 .45209 Mdot
.90174 .36668 Mdot
.30845 .50438 Mdot
.49234 .51148 Mdot
.66474 .38461 Mdot
.04244 .42348 Mdot
.35723 .53879 Mdot
.5003 .61763 Mdot
.50095 .61674 Mdot
.50304 .61392 Mdot
.50969 .60495 Mdot
.53087 .57651 Mdot
.59805 .49126 Mdot
.80318 .35187 Mdot
.23384 .49866 Mdot
.427 .56398 Mdot
.51445 .5506 Mdot
.62356 .44722 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.51131 .60277 Mdot
.53601 .56967 Mdot
.61427 .47261 Mdot
.84957 .35301 Mdot
.27839 .49821 Mdot
.47227 .52379 Mdot
.62477 .41961 Mdot
.94583 .37035 Mdot
.34659 .49155 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00425 Mdot
.48997 .01355 Mdot
.46804 .04298 Mdot
.39851 .13082 Mdot
.18684 .2669 Mdot
.755 .11942 Mdot
.56177 .06359 Mdot
.45888 .10129 Mdot
.29499 .24298 Mdot
.90184 .15764 Mdot
.49963 .00049 Mdot
.49883 .00158 Mdot
.49628 .00502 Mdot
.48816 .01599 Mdot
.46228 .05063 Mdot
.38036 .15139 Mdot
.13541 .26231 Mdot
.71098 .11918 Mdot
.51814 .10241 Mdot
.35244 .22043 Mdot
.99578 .21652 Mdot
.64545 .09968 Mdot
.50106 .6166 Mdot
.50337 .61348 Mdot
.51074 .60352 Mdot
.53422 .57204 Mdot
.60864 .47897 Mdot
.83364 .35134 Mdot
.26516 .49821 Mdot
.45904 .53577 Mdot
.59214 .45505 Mdot
.85586 .33895 Mdot
.30742 .477 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50732 .60814 Mdot
.52333 .58659 Mdot
.57421 .52025 Mdot
.73243 .37361 Mdot
.12791 .47983 Mdot
.35153 .59836 Mdot
.38337 .07902 Mdot
.25551 .22648 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01653 Mdot
.46102 .05231 Mdot
.37639 .15572 Mdot
.12442 .25967 Mdot
.70426 .11818 Mdot
.51304 .1061 Mdot
.34137 .22999 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50709 .60846 Mdot
.52258 .5876 Mdot
.57182 .52325 Mdot
.72519 .37749 Mdot
.11439 .47464 Mdot
.3464 .59594 Mdot
.38215 .07744 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .0036 Mdot
.4915 .01148 Mdot
.47292 .03646 Mdot
.41392 .11243 Mdot
.232 .25903 Mdot
.81288 .12285 Mdot
.6141 .02591 Mdot
.57217 .57931 Mdot
.63483 .46874 Mdot
.8764 .36533 Mdot
.50106 .6166 Mdot
.50338 .61346 Mdot
.51078 .60348 Mdot
.53432 .57191 Mdot
.60894 .47862 Mdot
.83452 .3514 Mdot
.26595 .4982 Mdot
.45984 .53504 Mdot
.59414 .45277 Mdot
.86154 .34 Mdot
.31141 .4767 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49189 .01095 Mdot
.47417 .0348 Mdot
.41786 .10761 Mdot
.24374 .25504 Mdot
.83108 .12623 Mdot
.62683 .02071 Mdot
.59333 .5571 Mdot
.69193 .41926 Mdot
.01354 .4318 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.51149 .60251 Mdot
.53661 .56887 Mdot
.61615 .4705 Mdot
.85487 .35384 Mdot
.28234 .49835 Mdot
.47599 .52053 Mdot
.63376 .41061 Mdot
.96938 .3824 Mdot
.35064 .50141 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00486 Mdot
.48855 .01546 Mdot
.46353 .04898 Mdot
.38429 .14704 Mdot
.14636 .2644 Mdot
.71856 .11972 Mdot
.52484 .09679 Mdot
.36824 .20545 Mdot
.03581 .23837 Mdot
.65012 .11894 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48811 .01606 Mdot
.46212 .05085 Mdot
.37985 .15195 Mdot
.13398 .262 Mdot
.71006 .11908 Mdot
.51738 .103 Mdot
.35073 .22196 Mdot
.99159 .21417 Mdot
.64506 .09755 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51092 .60329 Mdot
.53478 .5713 Mdot
.6104 .47696 Mdot
.83867 .35173 Mdot
.26956 .49816 Mdot
.46353 .53167 Mdot
.60326 .44252 Mdot
.88724 .34652 Mdot
.32656 .47732 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51254 .6011 Mdot
.53995 .56445 Mdot
.62665 .45905 Mdot
.88389 .36071 Mdot
.30025 .50096 Mdot
.48969 .5105 Mdot
.66368 .38414 Mdot
.04213 .42274 Mdot
.35812 .53753 Mdot
.50027 .61766 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.52831 .57993 Mdot
.58996 .5009 Mdot
.77949 .35588 Mdot
.20366 .49722 Mdot
.39915 .58458 Mdot
.45328 .00924 Mdot
.43834 .06498 Mdot
.50036 .61755 Mdot
.50113 .6165 Mdot
.50361 .61315 Mdot
.51151 .60249 Mdot
.53666 .56881 Mdot
.61631 .47033 Mdot
.8553 .35392 Mdot
.28265 .49837 Mdot
.47628 .52028 Mdot
.63446 .40994 Mdot
.97117 .38335 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52048 .59042 Mdot
.56515 .53169 Mdot
.70486 .39004 Mdot
.07375 .45599 Mdot
.33594 .58255 Mdot
.39335 .05615 Mdot
.3025 .19574 Mdot
.9858 .18259 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49029 .01312 Mdot
.46907 .04161 Mdot
.40174 .12703 Mdot
.19621 .26622 Mdot
.76545 .11937 Mdot
.5723 .05463 Mdot
.48391 .06951 Mdot
.37144 .17615 Mdot
.08642 .25239 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49022 .0132 Mdot
.46886 .04189 Mdot
.40108 .1278 Mdot
.1943 .2664 Mdot
.76325 .11937 Mdot
.57012 .05645 Mdot
.47878 .07606 Mdot
.35571 .19224 Mdot
.04465 .2331 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00213 Mdot
.49499 .00677 Mdot
.48403 .02155 Mdot
.44916 .06789 Mdot
.33931 .19281 Mdot
.02734 .21803 Mdot
.67456 .08675 Mdot
.5342 .05529 Mdot
.44474 .10549 Mdot
.27405 .25136 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57437 .52006 Mdot
.73289 .37337 Mdot
.12877 .48014 Mdot
.35189 .59847 Mdot
.38355 .07902 Mdot
.2557 .22647 Mdot
.88927 .13189 Mdot
.49971 .0004 Mdot
.49907 .00126 Mdot
.49703 .00401 Mdot
.49054 .01278 Mdot
.46986 .04055 Mdot
.40424 .12407 Mdot
.20349 .26536 Mdot
.77414 .11951 Mdot
.58077 .0478 Mdot
.50342 .04463 Mdot
.4312 .10644 Mdot
.25898 .25375 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61718 Mdot
.50203 .6153 Mdot
.50645 .60932 Mdot
.52056 .59031 Mdot
.56542 .53135 Mdot
.70567 .38949 Mdot
.07546 .45686 Mdot
.33625 .58326 Mdot
.39251 .05747 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00387 Mdot
.49087 .01233 Mdot
.47092 .03914 Mdot
.40759 .12008 Mdot
.2133 .26372 Mdot
.7866 .12006 Mdot
.59234 .03917 Mdot
.52897 .01247 Mdot
.5088 .00431 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60118 Mdot
.53976 .5647 Mdot
.62605 .45968 Mdot
.88227 .36023 Mdot
.29941 .50072 Mdot
.48923 .51069 Mdot
.66292 .38468 Mdot
.04049 .42182 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49652 .0047 Mdot
.48893 .01495 Mdot
.46473 .04738 Mdot
.38807 .1428 Mdot
.15702 .26587 Mdot
.72683 .11989 Mdot
.53285 .08965 Mdot
.38779 .18527 Mdot
.08802 .26277 Mdot
.66285 .1368 Mdot
.50033 .61759 Mdot
.50105 .61662 Mdot
.50335 .61351 Mdot
.51066 .60364 Mdot
.53394 .57241 Mdot
.60776 .47997 Mdot
.83115 .35119 Mdot
.26291 .49825 Mdot
.45671 .53789 Mdot
.58639 .46167 Mdot
.83939 .33679 Mdot
.50082 .61693 Mdot
.5026 .61452 Mdot
.50829 .60684 Mdot
.52641 .58247 Mdot
.58395 .5082 Mdot
.76167 .36105 Mdot
.17747 .49354 Mdot
.37891 .59528 Mdot
.41573 .05177 Mdot
.33197 .18017 Mdot
.04044 .21726 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49167 .01125 Mdot
.47347 .03573 Mdot
.41565 .11032 Mdot
.23714 .25739 Mdot
.82068 .12415 Mdot
.61979 .02329 Mdot
.58211 .56854 Mdot
.66219 .44289 Mdot
.94558 .39341 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50168 .61576 Mdot
.50536 .61079 Mdot
.51708 .59499 Mdot
.55437 .54556 Mdot
.67165 .41553 Mdot
.9993 .41488 Mdot
.328 .54506 Mdot
.44608 .5941 Mdot
.48481 .60815 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02203 Mdot
.44804 .06935 Mdot
.33583 .19596 Mdot
.01876 .21331 Mdot
.67362 .08243 Mdot
.54024 .04552 Mdot
.46659 .07627 Mdot
.50108 .61657 Mdot
.50344 .61338 Mdot
.51097 .60322 Mdot
.53493 .5711 Mdot
.61088 .47643 Mdot
.84 .35185 Mdot
.27069 .49815 Mdot
.46467 .53063 Mdot
.60609 .43941 Mdot
.89511 .34906 Mdot
.33032 .47821 Mdot
.5013 .61627 Mdot
.50415 .61242 Mdot
.51323 .60017 Mdot
.54214 .56156 Mdot
.63353 .45179 Mdot
.90252 .36696 Mdot
.30876 .50457 Mdot
.49236 .51165 Mdot
.66449 .38489 Mdot
.04172 .42313 Mdot
.35708 .53852 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50364 .61311 Mdot
.5116 .60237 Mdot
.53695 .56842 Mdot
.61723 .4693 Mdot
.85789 .35438 Mdot
.28449 .49847 Mdot
.47795 .51885 Mdot
.63843 .40609 Mdot
.98136 .38885 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00488 Mdot
.4885 .01553 Mdot
.46336 .0492 Mdot
.38375 .14764 Mdot
.14486 .26415 Mdot
.71747 .11967 Mdot
.52383 .09766 Mdot
.36581 .20784 Mdot
.02951 .23504 Mdot
.50093 .61678 Mdot
.50295 .61404 Mdot
.50941 .60533 Mdot
.52997 .57771 Mdot
.59522 .49461 Mdot
.79493 .3529 Mdot
.22392 .49847 Mdot
.41738 .57167 Mdot
.4924 .57872 Mdot
.55602 .52785 Mdot
.70194 .38698 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00472 Mdot
.48886 .01504 Mdot
.46452 .04767 Mdot
.38739 .14356 Mdot
.1551 .26565 Mdot
.72528 .11988 Mdot
.53131 .09105 Mdot
.38399 .18932 Mdot
.07767 .2585 Mdot
.65941 .13421 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50455 .61189 Mdot
.5145 .59846 Mdot
.54617 .55626 Mdot
.64612 .43904 Mdot
.93574 .38107 Mdot
.31915 .51491 Mdot
.48601 .52787 Mdot
.6319 .41911 Mdot
.95377 .37685 Mdot
.50069 .6171 Mdot
.50221 .61504 Mdot
.50705 .60851 Mdot
.52247 .58774 Mdot
.57149 .52368 Mdot
.72416 .37807 Mdot
.11242 .47384 Mdot
.34573 .59549 Mdot
.38221 .07696 Mdot
.25769 .22433 Mdot
.89472 .13369 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00325 Mdot
.49234 .01034 Mdot
.47561 .03287 Mdot
.42242 .10198 Mdot
.25742 .24936 Mdot
.85395 .13218 Mdot
.64007 .01845 Mdot
.61022 .54228 Mdot
.73278 .3956 Mdot
.09269 .47675 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49871 .00174 Mdot
.49589 .00556 Mdot
.48689 .0177 Mdot
.45826 .05595 Mdot
.36773 .16494 Mdot
.10085 .2523 Mdot
.69262 .11424 Mdot
.50778 .10703 Mdot
.33459 .23423 Mdot
.9556 .1936 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60695 Mdot
.52614 .58282 Mdot
.58312 .50922 Mdot
.75919 .36192 Mdot
.1736 .49279 Mdot
.37625 .59629 Mdot
.41144 .05619 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51076 .60351 Mdot
.53427 .57198 Mdot
.60878 .47881 Mdot
.83405 .35137 Mdot
.26553 .49821 Mdot
.45941 .53543 Mdot
.59307 .45398 Mdot
.85852 .33942 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.51081 .60344 Mdot
.53443 .57177 Mdot
.60928 .47824 Mdot
.83547 .35146 Mdot
.26679 .49819 Mdot
.46071 .53425 Mdot
.59628 .45034 Mdot
.86761 .34128 Mdot
.31541 .47654 Mdot
.5002 .61777 Mdot
.50063 .61719 Mdot
.502 .61533 Mdot
.50637 .60943 Mdot
.5203 .59065 Mdot
.5646 .53239 Mdot
.70317 .39119 Mdot
.07021 .45419 Mdot
.33532 .58104 Mdot
.39518 .0533 Mdot
.30893 .19085 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .0137 Mdot
.4677 .04343 Mdot
.39742 .13208 Mdot
.18371 .26701 Mdot
.75167 .11948 Mdot
.55836 .06658 Mdot
.45064 .11161 Mdot
.27005 .25799 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48929 .01447 Mdot
.46588 .04586 Mdot
.39168 .1387 Mdot
.16727 .26675 Mdot
.73566 .11981 Mdot
.54181 .08149 Mdot
.40994 .1606 Mdot
.1501 .28001 Mdot
.69702 .14057 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61708 Mdot
.50224 .61501 Mdot
.50713 .6084 Mdot
.52272 .58741 Mdot
.57227 .52269 Mdot
.72654 .37675 Mdot
.11695 .47567 Mdot
.3473 .59649 Mdot
.50114 .6165 Mdot
.50362 .61314 Mdot
.51154 .60246 Mdot
.53674 .5687 Mdot
.61656 .47005 Mdot
.856 .35404 Mdot
.28316 .49839 Mdot
.47674 .51988 Mdot
.63556 .40886 Mdot
.97401 .38487 Mdot
.35127 .50354 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00236 Mdot
.49444 .00752 Mdot
.48227 .02392 Mdot
.44358 .07513 Mdot
.32201 .20783 Mdot
.98574 .19463 Mdot
.67083 .06496 Mdot
.56571 .00576 Mdot
.55639 .5726 Mdot
.6299 .46511 Mdot
.49998 3e-05 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49808 .0026 Mdot
.49387 .00828 Mdot
.48047 .02634 Mdot
.43785 .08251 Mdot
.30434 .22154 Mdot
.94589 .17234 Mdot
.66705 .04438 Mdot
.59524 .5793 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50538 .61076 Mdot
.51716 .59489 Mdot
.55461 .54525 Mdot
.67238 .41491 Mdot
.00104 .41587 Mdot
.32814 .54599 Mdot
.44472 .59622 Mdot
.48002 .61469 Mdot
.48543 .01014 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50641 .60937 Mdot
.52042 .59049 Mdot
.56499 .5319 Mdot
.70435 .39038 Mdot
.0727 .45546 Mdot
.33575 .5821 Mdot
.39388 .05532 Mdot
.30438 .19433 Mdot
.98995 .18502 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50621 .60965 Mdot
.51978 .59136 Mdot
.56293 .53453 Mdot
.69804 .39478 Mdot
.05927 .44847 Mdot
.33364 .5761 Mdot
.40148 .04368 Mdot
.3308 .17261 Mdot
.05151 .21954 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48755 .01681 Mdot
.46035 .05318 Mdot
.3743 .15797 Mdot
.1187 .25809 Mdot
.7011 .11745 Mdot
.51106 .10721 Mdot
.33758 .23297 Mdot
.96062 .19684 Mdot
.64213 .08191 Mdot
.50078 .61699 Mdot
.50247 .6147 Mdot
.50787 .6074 Mdot
.52507 .58426 Mdot
.57973 .5134 Mdot
.74903 .36586 Mdot
.15706 .48895 Mdot
.36592 .59906 Mdot
.39662 .07027 Mdot
.28293 .21466 Mdot
.9356 .15657 Mdot
.50065 .61715 Mdot
.50208 .61522 Mdot
.50663 .60908 Mdot
.52112 .58955 Mdot
.56721 .52908 Mdot
.71114 .38591 Mdot
.08672 .46239 Mdot
.33856 .58767 Mdot
.38769 .06533 Mdot
.28199 .2099 Mdot
.94236 .15763 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49658 .00462 Mdot
.48911 .0147 Mdot
.46532 .0466 Mdot
.38993 .1407 Mdot
.16227 .26639 Mdot
.73124 .11987 Mdot
.53729 .08562 Mdot
.39876 .17327 Mdot
.11841 .27319 Mdot
.67638 .14115 Mdot
.50045 .61742 Mdot
.50145 .61608 Mdot
.50462 .6118 Mdot
.5147 .59819 Mdot
.54682 .55541 Mdot
.64814 .43707 Mdot
.94095 .38357 Mdot
.32032 .51695 Mdot
.48387 .53188 Mdot
.62328 .42868 Mdot
.92967 .36558 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51192 .60195 Mdot
.53795 .5671 Mdot
.62036 .46585 Mdot
.8666 .35616 Mdot
.29031 .499 Mdot
.48292 .51481 Mdot
.64994 .39547 Mdot
.01006 .40479 Mdot
.3551 .52132 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50432 .6122 Mdot
.51376 .59946 Mdot
.5438 .55937 Mdot
.63873 .44644 Mdot
.91637 .37243 Mdot
.31377 .50829 Mdot
.49134 .51632 Mdot
.65591 .39381 Mdot
.01871 .41112 Mdot
.49994 8e-05 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00268 Mdot
.49367 .00855 Mdot
.47985 .02718 Mdot
.43587 .08503 Mdot
.29828 .22584 Mdot
.93287 .16543 Mdot
.66519 .03835 Mdot
.60314 .56731 Mdot
.68521 .43183 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51101 .60316 Mdot
.53508 .5709 Mdot
.61134 .4759 Mdot
.84133 .35198 Mdot
.27181 .49815 Mdot
.46579 .52962 Mdot
.60885 .43639 Mdot
.90276 .35175 Mdot
.33362 .47939 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50612 .60977 Mdot
.5195 .59174 Mdot
.56204 .53567 Mdot
.69531 .39675 Mdot
.05335 .44529 Mdot
.33286 .57329 Mdot
.40526 .03799 Mdot
.34379 .16065 Mdot
.08386 .23484 Mdot
.49984 .00021 Mdot
.49951 .00067 Mdot
.49842 .00213 Mdot
.49498 .00678 Mdot
.484 .02159 Mdot
.44906 .06801 Mdot
.33901 .19308 Mdot
.02661 .21763 Mdot
.67448 .08639 Mdot
.5347 .05448 Mdot
.44655 .1031 Mdot
.27972 .24808 Mdot
.50105 .61662 Mdot
.50335 .61351 Mdot
.51066 .60364 Mdot
.53395 .5724 Mdot
.60779 .47994 Mdot
.83122 .3512 Mdot
.26297 .49825 Mdot
.45678 .53783 Mdot
.58655 .46149 Mdot
.83983 .33684 Mdot
.29482 .47857 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49817 .00247 Mdot
.49418 .00786 Mdot
.48147 .02499 Mdot
.44103 .07842 Mdot
.31414 .21415 Mdot
.96764 .18436 Mdot
.66935 .05535 Mdot
.57978 .60248 Mdot
.60495 .51209 Mdot
.77636 .36657 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50876 .6062 Mdot
.52792 .58045 Mdot
.58873 .50238 Mdot
.77586 .35678 Mdot
.19858 .49669 Mdot
.39491 .58719 Mdot
.44482 .01929 Mdot
.41362 .09549 Mdot
.25911 .2428 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52049 .5904 Mdot
.5652 .53164 Mdot
.70499 .38995 Mdot
.07403 .45613 Mdot
.33599 .58266 Mdot
.39321 .05636 Mdot
.30202 .1961 Mdot
.98472 .18196 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54006 .5643 Mdot
.627 .45867 Mdot
.88486 .361 Mdot
.30075 .5011 Mdot
.48995 .51042 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49731 .00363 Mdot
.49144 .01156 Mdot
.47274 .0367 Mdot
.41336 .11312 Mdot
.23033 .25954 Mdot
.81039 .12249 Mdot
.6122 .02687 Mdot
.56872 .58317 Mdot
.62513 .47875 Mdot
.8505 .35966 Mdot
.49985 .00021 Mdot
.49952 .00065 Mdot
.49846 .00208 Mdot
.49509 .00663 Mdot
.48436 .02111 Mdot
.4502 .06653 Mdot
.34254 .18983 Mdot
.0354 .22237 Mdot
.67559 .09066 Mdot
.5289 .06402 Mdot
.42531 .13075 Mdot
.21375 .27449 Mdot
.50082 .61692 Mdot
.50262 .61449 Mdot
.50835 .60676 Mdot
.5266 .58221 Mdot
.58456 .50746 Mdot
.76348 .36044 Mdot
.18027 .49405 Mdot
.38088 .59446 Mdot
.41903 .04829 Mdot
.3409 .17241 Mdot
.06193 .22839 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.4761 .0322 Mdot
.424 .10001 Mdot
.26218 .24712 Mdot
.86233 .13483 Mdot
.64418 .01871 Mdot
.6139 .53994 Mdot
.74026 .39267 Mdot
.1049 .48303 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.5055 .6106 Mdot
.51753 .59439 Mdot
.55578 .54373 Mdot
.67602 .41184 Mdot
.00965 .42078 Mdot
.32882 .5506 Mdot
.43793 .60669 Mdot
.4563 .02866 Mdot
.40992 .10778 Mdot
.50031 .61761 Mdot
.50099 .61669 Mdot
.50316 .61377 Mdot
.51007 .60444 Mdot
.53206 .57492 Mdot
.60182 .48684 Mdot
.8141 .3511 Mdot
.24601 .4986 Mdot
.43927 .55354 Mdot
.54361 .51362 Mdot
.71257 .37013 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00488 Mdot
.48849 .01555 Mdot
.46333 .04925 Mdot
.38365 .14776 Mdot
.14457 .2641 Mdot
.71726 .11966 Mdot
.52364 .09783 Mdot
.36534 .20829 Mdot
.02832 .23441 Mdot
.64904 .11557 Mdot
.49999 1e-05 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49742 .00349 Mdot
.49176 .01112 Mdot
.47377 .03533 Mdot
.41659 .10916 Mdot
.23996 .25642 Mdot
.82507 .12498 Mdot
.62285 .02207 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.5045 .61196 Mdot
.51433 .5987 Mdot
.54562 .55698 Mdot
.6444 .44074 Mdot
.93127 .37898 Mdot
.31806 .51324 Mdot
.48761 .52471 Mdot
.63861 .41185 Mdot
.97221 .38623 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60623 Mdot
.52785 .58054 Mdot
.58851 .50265 Mdot
.77521 .35695 Mdot
.19765 .49659 Mdot
.39416 .58763 Mdot
.44334 .02102 Mdot
.40933 .1006 Mdot
.24656 .24811 Mdot
.49985 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49531 .00634 Mdot
.48505 .02018 Mdot
.45241 .06364 Mdot
.34943 .18332 Mdot
.05282 .23139 Mdot
.67842 .09851 Mdot
.51902 .08092 Mdot
.38809 .17632 Mdot
.1028 .26513 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00381 Mdot
.49101 .01214 Mdot
.47138 .03853 Mdot
.40904 .11834 Mdot
.21756 .26283 Mdot
.79229 .12046 Mdot
.59737 .03572 Mdot
.53958 .61744 Mdot
.54053 .58027 Mdot
.50131 .61626 Mdot
.50419 .61238 Mdot
.51334 .60003 Mdot
.54246 .56113 Mdot
.63454 .45074 Mdot
.90522 .36798 Mdot
.30982 .50522 Mdot
.49235 .51231 Mdot
.66341 .38607 Mdot
.03874 .42163 Mdot
.35653 .53734 Mdot
.50101 .61667 Mdot
.50323 .61367 Mdot
.51028 .60415 Mdot
.53275 .57401 Mdot
.60398 .48432 Mdot
.82033 .35095 Mdot
.25248 .49848 Mdot
.44592 .54765 Mdot
.5598 .49351 Mdot
.76128 .34634 Mdot
.20089 .48691 Mdot
.50044 .61744 Mdot
.50139 .61615 Mdot
.50444 .61203 Mdot
.51416 .59892 Mdot
.54509 .55768 Mdot
.64275 .44239 Mdot
.92695 .37702 Mdot
.31692 .51171 Mdot
.48895 .52194 Mdot
.64443 .40568 Mdot
.98802 .39459 Mdot
.50124 .61635 Mdot
.50396 .61268 Mdot
.51262 .601 Mdot
.54018 .56414 Mdot
.62739 .45825 Mdot
.88592 .36132 Mdot
.30129 .50127 Mdot
.49021 .51034 Mdot
.66447 .38359 Mdot
.04381 .42369 Mdot
.35826 .5384 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48887 .01503 Mdot
.46454 .04763 Mdot
.38747 .14348 Mdot
.15532 .26567 Mdot
.72545 .11988 Mdot
.53148 .09089 Mdot
.38441 .18887 Mdot
.07881 .25899 Mdot
.65977 .13453 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00394 Mdot
.49071 .01255 Mdot
.4704 .03983 Mdot
.40595 .12203 Mdot
.2085 .26459 Mdot
.78038 .11973 Mdot
.58666 .0433 Mdot
.5166 .02794 Mdot
.4714 .05431 Mdot
.38353 .1529 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.4873 .01715 Mdot
.45954 .05425 Mdot
.37176 .16068 Mdot
.11177 .25599 Mdot
.69757 .11638 Mdot
.50926 .1078 Mdot
.33484 .23488 Mdot
.9548 .19353 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00487 Mdot
.48851 .01552 Mdot
.46339 .04916 Mdot
.38385 .14753 Mdot
.14514 .26419 Mdot
.71766 .11968 Mdot
.52401 .09751 Mdot
.36624 .20741 Mdot
.03064 .23564 Mdot
.64936 .11663 Mdot
.5008 .61695 Mdot
.50255 .61458 Mdot
.50814 .60704 Mdot
.52592 .58312 Mdot
.58241 .51009 Mdot
.75706 .36269 Mdot
.17021 .49208 Mdot
.37401 .59706 Mdot
.40794 .05969 Mdot
.31136 .1964 Mdot
.99358 .19045 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.4954 .00622 Mdot
.48534 .01979 Mdot
.45331 .06246 Mdot
.35224 .1806 Mdot
.06003 .23493 Mdot
.67989 .10147 Mdot
.5157 .08694 Mdot
.37503 .19125 Mdot
.06559 .25035 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50967 .60497 Mdot
.5308 .5766 Mdot
.59784 .4915 Mdot
.80258 .35193 Mdot
.23314 .49865 Mdot
.42631 .56455 Mdot
.51284 .55266 Mdot
.61862 .45259 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.505 .61128 Mdot
.51594 .59652 Mdot
.55074 .55028 Mdot
.66037 .42552 Mdot
.97187 .39958 Mdot
.32534 .53089 Mdot
.46634 .56187 Mdot
.55722 .50996 Mdot
.50032 .6176 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51032 .60409 Mdot
.53288 .57383 Mdot
.6044 .48384 Mdot
.82152 .35095 Mdot
.25368 .49845 Mdot
.44716 .54654 Mdot
.56284 .48979 Mdot
.77034 .34345 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00557 Mdot
.48685 .01775 Mdot
.45814 .05611 Mdot
.36734 .16534 Mdot
.09982 .25193 Mdot
.69219 .11401 Mdot
.50772 .10686 Mdot
.33482 .23394 Mdot
.9563 .19393 Mdot
.64251 .07878 Mdot
.5008 .61695 Mdot
.50255 .61458 Mdot
.50814 .60704 Mdot
.52593 .58311 Mdot
.58243 .51006 Mdot
.75713 .36267 Mdot
.17032 .49211 Mdot
.37408 .59704 Mdot
.40805 .05958 Mdot
.31165 .1962 Mdot
.99419 .19081 Mdot
.49986 .00018 Mdot
.49957 .00058 Mdot
.49862 .00186 Mdot
.49562 .00592 Mdot
.48604 .01885 Mdot
.45554 .05953 Mdot
.35921 .17368 Mdot
.07819 .24329 Mdot
.68454 .10805 Mdot
.50972 .09904 Mdot
.34948 .21869 Mdot
.99563 .21464 Mdot
.5011 .61654 Mdot
.50351 .61329 Mdot
.51119 .60292 Mdot
.53565 .57015 Mdot
.61313 .47389 Mdot
.84636 .35257 Mdot
.2759 .49817 Mdot
.46985 .52595 Mdot
.61884 .42574 Mdot
.92998 .3629 Mdot
.3428 .48607 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49715 .00385 Mdot
.49091 .01227 Mdot
.47105 .03896 Mdot
.40802 .11956 Mdot
.21456 .26347 Mdot
.78826 .12016 Mdot
.59383 .03813 Mdot
.53214 .00853 Mdot
.51834 .60961 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.5062 .60966 Mdot
.51975 .59139 Mdot
.56286 .53463 Mdot
.69781 .39494 Mdot
.05878 .4482 Mdot
.33357 .57587 Mdot
.40179 .04322 Mdot
.33186 .17167 Mdot
.05409 .22086 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50933 .60544 Mdot
.52971 .57806 Mdot
.59439 .4956 Mdot
.79249 .35328 Mdot
.22087 .49836 Mdot
.4145 .57386 Mdot
.48597 .58685 Mdot
.53642 .55338 Mdot
.64103 .43909 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49324 .00913 Mdot
.47847 .02903 Mdot
.43151 .09058 Mdot
.28494 .23458 Mdot
.90538 .15194 Mdot
.65953 .0276 Mdot
.61488 .54815 Mdot
.72796 .40201 Mdot
.07748 .47104 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50592 .61003 Mdot
.51887 .59258 Mdot
.56006 .53821 Mdot
.68923 .40129 Mdot
.03994 .43792 Mdot
.33136 .5666 Mdot
.41458 .02401 Mdot
.37574 .12785 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00109 Mdot
.49744 .00346 Mdot
.49184 .01103 Mdot
.474 .03503 Mdot
.41732 .10827 Mdot
.24214 .25564 Mdot
.82851 .12568 Mdot
.62515 .02125 Mdot
.59077 .55963 Mdot
.68527 .42412 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49583 .00563 Mdot
.48673 .01792 Mdot
.45773 .05665 Mdot
.36607 .16667 Mdot
.0964 .25067 Mdot
.69081 .11321 Mdot
.50763 .10613 Mdot
.33591 .2327 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00282 Mdot
.49336 .00897 Mdot
.47885 .02852 Mdot
.4327 .08907 Mdot
.28859 .2323 Mdot
.91272 .15538 Mdot
.66131 .03016 Mdot
.61251 .55236 Mdot
.71878 .40765 Mdot
.05919 .46126 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50503 .61124 Mdot
.51603 .5964 Mdot
.55104 .54989 Mdot
.66131 .42466 Mdot
.97419 .40084 Mdot
.32562 .53204 Mdot
.46475 .56445 Mdot
.55145 .51758 Mdot
.71399 .3738 Mdot
.50064 .61718 Mdot
.50202 .6153 Mdot
.50645 .60932 Mdot
.52054 .59034 Mdot
.56536 .53144 Mdot
.70547 .38963 Mdot
.07504 .45665 Mdot
.33617 .58309 Mdot
.39272 .05715 Mdot
.30025 .1974 Mdot
.98085 .17969 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00204 Mdot
.4952 .00648 Mdot
.48471 .02064 Mdot
.45132 .06507 Mdot
.34603 .18656 Mdot
.04416 .22698 Mdot
.6769 .09473 Mdot
.52363 .0729 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47146 .03842 Mdot
.40929 .11803 Mdot
.21832 .26266 Mdot
.79332 .12055 Mdot
.59827 .03513 Mdot
.54143 .61518 Mdot
.54604 .57309 Mdot
.61876 .47293 Mdot
.50009 .61792 Mdot
.50027 .61766 Mdot
.50087 .61686 Mdot
.50278 .61428 Mdot
.50884 .60609 Mdot
.52816 .58012 Mdot
.58951 .50144 Mdot
.77816 .3562 Mdot
.20181 .49704 Mdot
.39759 .58556 Mdot
.45014 .01299 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49038 .01299 Mdot
.46936 .04122 Mdot
.40266 .12594 Mdot
.19888 .26594 Mdot
.76857 .1194 Mdot
.57538 .0521 Mdot
.49108 .06037 Mdot
.39339 .15197 Mdot
.49992 .0001 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00329 Mdot
.49225 .01047 Mdot
.47532 .03326 Mdot
.42151 .10311 Mdot
.25467 .25059 Mdot
.84921 .13079 Mdot
.63758 .01855 Mdot
.60756 .54429 Mdot
.72687 .3983 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.48839 .01567 Mdot
.46303 .04964 Mdot
.38272 .14878 Mdot
.14199 .26363 Mdot
.71542 .11956 Mdot
.52197 .09925 Mdot
.36138 .21212 Mdot
.01817 .22892 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.4975 .00338 Mdot
.49202 .01078 Mdot
.47458 .03424 Mdot
.41917 .106 Mdot
.24766 .25353 Mdot
.83745 .1277 Mdot
.63083 .01962 Mdot
.59908 .55162 Mdot
.70654 .40954 Mdot
.04389 .44971 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.5074 .60804 Mdot
.52357 .58627 Mdot
.57497 .5193 Mdot
.73472 .37244 Mdot
.13211 .48132 Mdot
.35331 .59886 Mdot
.38434 .07885 Mdot
.25676 .22626 Mdot
.89066 .13269 Mdot
.50093 .61678 Mdot
.50297 .61403 Mdot
.50945 .60527 Mdot
.53011 .57752 Mdot
.59565 .49409 Mdot
.79619 .35272 Mdot
.22548 .49852 Mdot
.41887 .57052 Mdot
.49575 .57445 Mdot
.56627 .51478 Mdot
.73333 .36805 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50657 .60916 Mdot
.52093 .58981 Mdot
.56661 .52984 Mdot
.7093 .3871 Mdot
.08296 .46057 Mdot
.33774 .58626 Mdot
.38915 .06288 Mdot
.28742 .20636 Mdot
.95352 .16388 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00351 Mdot
.49171 .01119 Mdot
.4736 .03555 Mdot
.41607 .1098 Mdot
.23841 .25695 Mdot
.82265 .12452 Mdot
.62118 .02272 Mdot
.58441 .56612 Mdot
.66841 .43754 Mdot
.96046 .40126 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51271 .60087 Mdot
.54049 .56374 Mdot
.62834 .45724 Mdot
.88852 .36213 Mdot
.30257 .5017 Mdot
.4908 .51023 Mdot
.66523 .38312 Mdot
.04533 .42458 Mdot
.35835 .53923 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50386 .61281 Mdot
.51231 .60141 Mdot
.53921 .56543 Mdot
.62431 .46155 Mdot
.8775 .35888 Mdot
.29683 .50008 Mdot
.48767 .5115 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50883 .6061 Mdot
.52813 .58016 Mdot
.58942 .50156 Mdot
.77788 .35627 Mdot
.20142 .497 Mdot
.39727 .58576 Mdot
.44949 .01377 Mdot
.42722 .07891 Mdot
.29953 .21937 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52554 .58362 Mdot
.58122 .51155 Mdot
.75351 .36404 Mdot
.16448 .49079 Mdot
.37036 .59812 Mdot
.40257 .06487 Mdot
.2976 .20587 Mdot
.9645 .17323 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00294 Mdot
.49306 .00937 Mdot
.47789 .0298 Mdot
.42967 .0929 Mdot
.27936 .23794 Mdot
.89437 .14705 Mdot
.65644 .02427 Mdot
.61718 .54322 Mdot
.73823 .39608 Mdot
.09736 .48081 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51436 .59864 Mdot
.54574 .55682 Mdot
.64478 .44037 Mdot
.93225 .37944 Mdot
.3183 .5136 Mdot
.48728 .52538 Mdot
.63719 .41337 Mdot
.96834 .38422 Mdot
.50021 .61775 Mdot
.50067 .61713 Mdot
.50214 .61515 Mdot
.50681 .60884 Mdot
.52168 .5888 Mdot
.56898 .52684 Mdot
.71654 .38254 Mdot
.09758 .46744 Mdot
.34125 .59139 Mdot
.38435 .07138 Mdot
.26886 .21789 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49271 .00985 Mdot
.47676 .03132 Mdot
.42609 .0974 Mdot
.26849 .24395 Mdot
.87377 .13882 Mdot
.64916 .01991 Mdot
.61694 .53903 Mdot
.74477 .39157 Mdot
.1112 .48647 Mdot
.50089 .61683 Mdot
.50285 .61418 Mdot
.50908 .60577 Mdot
.52891 .57912 Mdot
.59188 .4986 Mdot
.78513 .35463 Mdot
.21133 .49784 Mdot
.4058 .58016 Mdot
.46708 .61046 Mdot
.47934 .01152 Mdot
.4607 .04758 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49236 .01032 Mdot
.47567 .03278 Mdot
.42262 .10172 Mdot
.25803 .24908 Mdot
.85501 .1325 Mdot
.64062 .01846 Mdot
.61076 .5419 Mdot
.73394 .39511 Mdot
.09464 .47776 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00198 Mdot
.49532 .00632 Mdot
.4851 .02012 Mdot
.45254 .06346 Mdot
.34986 .1829 Mdot
.05392 .23194 Mdot
.67864 .09898 Mdot
.51849 .08188 Mdot
.386 .17875 Mdot
.09677 .26304 Mdot
.50011 .61788 Mdot
.50035 .61756 Mdot
.50113 .61651 Mdot
.50359 .61318 Mdot
.51144 .60258 Mdot
.53644 .56909 Mdot
.61563 .47108 Mdot
.85342 .3536 Mdot
.28128 .4983 Mdot
.47501 .52138 Mdot
.63139 .41294 Mdot
.49967 .00045 Mdot
.49893 .00144 Mdot
.4966 .00459 Mdot
.48918 .01462 Mdot
.46552 .04633 Mdot
.39056 .13997 Mdot
.16408 .26654 Mdot
.73282 .11985 Mdot
.5389 .08415 Mdot
.40274 .16881 Mdot
.12961 .27611 Mdot
.68285 .14151 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50629 .60954 Mdot
.52004 .59101 Mdot
.56376 .53348 Mdot
.70058 .39299 Mdot
.06471 .45134 Mdot
.33443 .5786 Mdot
.39823 .04861 Mdot
.31958 .18228 Mdot
.02464 .20503 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49083 .01239 Mdot
.47079 .03932 Mdot
.40717 .12058 Mdot
.21206 .26396 Mdot
.78497 .11996 Mdot
.59087 .04022 Mdot
.5258 .0164 Mdot
.49926 .01708 Mdot
.47162 .04326 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01782 Mdot
.45797 .05633 Mdot
.36684 .16587 Mdot
.09846 .25143 Mdot
.69164 .1137 Mdot
.50767 .10659 Mdot
.3352 .2335 Mdot
.95739 .19446 Mdot
.64274 .07918 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50565 .6104 Mdot
.518 .59375 Mdot
.55728 .54179 Mdot
.68064 .40804 Mdot
.02042 .42692 Mdot
.32965 .55637 Mdot
.42943 .00163 Mdot
.42679 .06714 Mdot
.31816 .20136 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49527 .00639 Mdot
.48492 .02035 Mdot
.45199 .06419 Mdot
.34813 .18456 Mdot
.0495 .22972 Mdot
.67781 .09709 Mdot
.52071 .07795 Mdot
.39459 .16867 Mdot
.12167 .2708 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50793 .60733 Mdot
.52525 .58402 Mdot
.58028 .51272 Mdot
.75068 .36517 Mdot
.15982 .48966 Mdot
.36753 .59877 Mdot
.3987 .06843 Mdot
.28798 .21179 Mdot
.9453 .16207 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50824 .60691 Mdot
.52624 .5827 Mdot
.58341 .50886 Mdot
.76006 .36161 Mdot
.17496 .49306 Mdot
.37718 .59595 Mdot
.41291 .05468 Mdot
.32443 .18638 Mdot
.02286 .2075 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60223 Mdot
.53727 .56799 Mdot
.61824 .46819 Mdot
.86069 .35491 Mdot
.28643 .49861 Mdot
.47966 .51742 Mdot
.64246 .4023 Mdot
.99153 .39444 Mdot
.3533 .51199 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49258 .01002 Mdot
.47636 .03186 Mdot
.42482 .09899 Mdot
.26465 .24591 Mdot
.86676 .13632 Mdot
.64619 .01906 Mdot
.61534 .53929 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01634 Mdot
.46147 .05171 Mdot
.3778 .15419 Mdot
.12831 .26067 Mdot
.70654 .11859 Mdot
.51466 .10502 Mdot
.34472 .2272 Mdot
.97711 .20605 Mdot
.64371 .0902 Mdot
.5003 .61763 Mdot
.50096 .61673 Mdot
.50307 .61389 Mdot
.50978 .60483 Mdot
.53115 .57613 Mdot
.59895 .4902 Mdot
.80579 .35163 Mdot
.23684 .49867 Mdot
.42998 .56151 Mdot
.52144 .54169 Mdot
.64498 .42512 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51244 .60124 Mdot
.53962 .56488 Mdot
.62563 .46014 Mdot
.8811 .35989 Mdot
.29879 .50055 Mdot
.48888 .51085 Mdot
.66231 .38514 Mdot
.03913 .42106 Mdot
.35785 .536 Mdot
.50122 .61639 Mdot
.50387 .6128 Mdot
.51234 .60137 Mdot
.5393 .5653 Mdot
.62463 .46122 Mdot
.87836 .35911 Mdot
.2973 .50019 Mdot
.48798 .51132 Mdot
.66064 .38643 Mdot
.03538 .41896 Mdot
.35749 .53412 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00317 Mdot
.49252 .0101 Mdot
.47618 .0321 Mdot
.42423 .09972 Mdot
.26288 .24678 Mdot
.86358 .13524 Mdot
.64476 .0188 Mdot
.61434 .53972 Mdot
.74106 .3924 Mdot
.10614 .48367 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.5085 .60655 Mdot
.52709 .58155 Mdot
.58612 .50556 Mdot
.7681 .35897 Mdot
.18728 .4952 Mdot
.38602 .59206 Mdot
.42804 .03849 Mdot
.36577 .14869 Mdot
.12518 .25314 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50593 .61003 Mdot
.51889 .59256 Mdot
.5601 .53815 Mdot
.68935 .40119 Mdot
.04021 .43807 Mdot
.33139 .56674 Mdot
.41439 .0243 Mdot
.37507 .12859 Mdot
.16701 .25652 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49438 .00759 Mdot
.48209 .02416 Mdot
.44301 .07587 Mdot
.32025 .20927 Mdot
.98164 .19229 Mdot
.67051 .06277 Mdot
.56895 .00083 Mdot
.5676 .55806 Mdot
.66464 .43124 Mdot
.50038 .61752 Mdot
.50121 .61641 Mdot
.50384 .61285 Mdot
.51223 .60152 Mdot
.53896 .56576 Mdot
.62354 .46239 Mdot
.87537 .35831 Mdot
.29562 .49983 Mdot
.48687 .51199 Mdot
.65846 .38818 Mdot
.03038 .41617 Mdot
.50023 .61772 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50747 .60794 Mdot
.5238 .58596 Mdot
.57569 .51841 Mdot
.73689 .37136 Mdot
.13602 .48266 Mdot
.35506 .59921 Mdot
.38552 .07838 Mdot
.2587 .22571 Mdot
.50102 .61666 Mdot
.50323 .61366 Mdot
.51031 .60412 Mdot
.53282 .5739 Mdot
.60422 .48404 Mdot
.82103 .35095 Mdot
.25318 .49846 Mdot
.44665 .547 Mdot
.56158 .49132 Mdot
.7666 .34458 Mdot
.20906 .48727 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48856 .01544 Mdot
.46358 .04891 Mdot
.38443 .14688 Mdot
.14677 .26446 Mdot
.71886 .11974 Mdot
.52512 .09654 Mdot
.36892 .20478 Mdot
.03757 .23929 Mdot
.65039 .11971 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49506 .00667 Mdot
.48427 .02122 Mdot
.44993 .06688 Mdot
.34172 .19059 Mdot
.03334 .22127 Mdot
.67531 .08968 Mdot
.53021 .06184 Mdot
.43015 .12453 Mdot
.22865 .27075 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01652 Mdot
.46103 .05229 Mdot
.37643 .15567 Mdot
.12455 .25971 Mdot
.70433 .11819 Mdot
.51309 .10607 Mdot
.34147 .22991 Mdot
.96947 .20178 Mdot
.64298 .08635 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50768 .60767 Mdot
.52445 .58509 Mdot
.57776 .51583 Mdot
.74312 .36843 Mdot
.147 .48614 Mdot
.36041 .59958 Mdot
.39028 .07539 Mdot
.2683 .22196 Mdot
.90915 .14224 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49573 .00577 Mdot
.48639 .01837 Mdot
.45666 .05805 Mdot
.36273 .17011 Mdot
.08749 .24719 Mdot
.68752 .11087 Mdot
.50813 .10333 Mdot
.34094 .22744 Mdot
.97294 .20247 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49711 .00391 Mdot
.49078 .01245 Mdot
.47064 .03952 Mdot
.4067 .12114 Mdot
.21068 .26421 Mdot
.78318 .11986 Mdot
.58925 .04139 Mdot
.52228 .02081 Mdot
.48861 .03136 Mdot
.43787 .08751 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.48751 .01687 Mdot
.46022 .05336 Mdot
.37387 .15843 Mdot
.11752 .25775 Mdot
.70048 .11729 Mdot
.51071 .10737 Mdot
.33698 .23343 Mdot
.95929 .19609 Mdot
.642 .08123 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48857 .01543 Mdot
.46361 .04887 Mdot
.38453 .14678 Mdot
.14704 .26451 Mdot
.71906 .11974 Mdot
.52531 .09638 Mdot
.36936 .20434 Mdot
.03873 .23989 Mdot
.65058 .12021 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48701 .01754 Mdot
.45863 .05547 Mdot
.36888 .16373 Mdot
.10397 .2534 Mdot
.69396 .11491 Mdot
.50803 .10746 Mdot
.33415 .23486 Mdot
.95415 .19293 Mdot
.64197 .07809 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49631 .00498 Mdot
.48824 .01587 Mdot
.46256 .05026 Mdot
.38124 .15042 Mdot
.13785 .26283 Mdot
.71259 .11934 Mdot
.51949 .10131 Mdot
.35556 .21758 Mdot
.00352 .22084 Mdot
.49978 .0003 Mdot
.49928 .00097 Mdot
.49772 .00309 Mdot
.49272 .00983 Mdot
.47682 .03124 Mdot
.42628 .09716 Mdot
.26908 .24364 Mdot
.87485 .13922 Mdot
.64959 .02007 Mdot
.61711 .53907 Mdot
.74487 .39161 Mdot
.11124 .48654 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49696 .0041 Mdot
.49032 .01307 Mdot
.46918 .04146 Mdot
.40209 .12661 Mdot
.19723 .26612 Mdot
.76664 .11938 Mdot
.57348 .05365 Mdot
.48667 .066 Mdot
.37988 .16708 Mdot
.10953 .2608 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50119 .61642 Mdot
.5038 .6129 Mdot
.5121 .60169 Mdot
.53854 .56631 Mdot
.62223 .46381 Mdot
.87177 .35738 Mdot
.29351 .49945 Mdot
.48538 .51299 Mdot
.65534 .39078 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .00681 Mdot
.48393 .02169 Mdot
.44884 .0683 Mdot
.33834 .19369 Mdot
.02493 .21671 Mdot
.67428 .08555 Mdot
.53586 .05259 Mdot
.45076 .09752 Mdot
.29298 .23971 Mdot
.50031 .61762 Mdot
.50098 .61672 Mdot
.50311 .61383 Mdot
.50991 .60465 Mdot
.53156 .57559 Mdot
.60023 .48869 Mdot
.80951 .35134 Mdot
.24102 .49865 Mdot
.43418 .55794 Mdot
.53141 .52901 Mdot
.67545 .39736 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49134 .0117 Mdot
.4724 .03716 Mdot
.41227 .11444 Mdot
.22711 .26046 Mdot
.80568 .12185 Mdot
.60852 .02886 Mdot
.56183 .59101 Mdot
.60555 .50018 Mdot
.79625 .35882 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57437 .52005 Mdot
.73291 .37336 Mdot
.1288 .48015 Mdot
.3519 .59847 Mdot
.38355 .07901 Mdot
.2557 .22646 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.4649 .04715 Mdot
.38861 .14219 Mdot
.15854 .26604 Mdot
.72809 .11989 Mdot
.5341 .08852 Mdot
.39088 .18193 Mdot
.0965 .26602 Mdot
.66608 .13851 Mdot
.50079 .61696 Mdot
.50253 .61462 Mdot
.50806 .60715 Mdot
.52567 .58345 Mdot
.58163 .51105 Mdot
.75472 .36357 Mdot
.16645 .49125 Mdot
.37159 .59779 Mdot
.40434 .0632 Mdot
.30208 .20291 Mdot
.97376 .1787 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .01561 Mdot
.46319 .04943 Mdot
.3832 .14825 Mdot
.14333 .26388 Mdot
.71637 .11961 Mdot
.52283 .09853 Mdot
.36341 .21017 Mdot
.49983 .00023 Mdot
.49946 .00074 Mdot
.49826 .00235 Mdot
.49447 .00747 Mdot
.48238 .02377 Mdot
.44392 .07469 Mdot
.32307 .20695 Mdot
.98822 .19604 Mdot
.67102 .06629 Mdot
.56376 .00876 Mdot
.54959 .58156 Mdot
.60861 .4885 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .0019 Mdot
.49552 .00605 Mdot
.48574 .01925 Mdot
.45458 .06079 Mdot
.35623 .17667 Mdot
.07037 .2398 Mdot
.68236 .10538 Mdot
.51185 .0944 Mdot
.3591 .20862 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00328 Mdot
.49226 .01045 Mdot
.47534 .03322 Mdot
.42159 .103 Mdot
.25493 .25048 Mdot
.84966 .13092 Mdot
.63782 .01854 Mdot
.60783 .54408 Mdot
.72749 .39801 Mdot
.08349 .47191 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.5064 .60938 Mdot
.5204 .59052 Mdot
.56492 .53199 Mdot
.70415 .39052 Mdot
.07228 .45524 Mdot
.33567 .58192 Mdot
.3941 .05498 Mdot
.30514 .19375 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49245 .01019 Mdot
.47596 .0324 Mdot
.42353 .10059 Mdot
.26078 .2478 Mdot
.85983 .13401 Mdot
.64299 .01858 Mdot
.61293 .54048 Mdot
.73841 .39333 Mdot
.102 .48154 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .00421 Mdot
.49008 .0134 Mdot
.46839 .04251 Mdot
.39961 .12952 Mdot
.19004 .26672 Mdot
.75848 .11939 Mdot
.56531 .06052 Mdot
.46738 .09056 Mdot
.32086 .22372 Mdot
.95887 .18601 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47147 .03841 Mdot
.40932 .11799 Mdot
.21841 .26264 Mdot
.79345 .12056 Mdot
.59838 .03506 Mdot
.54166 .61491 Mdot
.54671 .57223 Mdot
.62083 .47067 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50779 .60751 Mdot
.52481 .58461 Mdot
.5789 .51442 Mdot
.74654 .36691 Mdot
.15286 .48782 Mdot
.36355 .59938 Mdot
.39374 .0727 Mdot
.27611 .21826 Mdot
.92296 .14959 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51018 .60429 Mdot
.53242 .57444 Mdot
.60295 .48552 Mdot
.81736 .35099 Mdot
.24944 .49854 Mdot
.44279 .55044 Mdot
.55216 .50295 Mdot
.73837 .3558 Mdot
.16268 .48169 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60082 Mdot
.5406 .56359 Mdot
.62869 .45687 Mdot
.88946 .36244 Mdot
.30303 .50187 Mdot
.49099 .51022 Mdot
.66544 .38301 Mdot
.04571 .42481 Mdot
.35836 .53946 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .00421 Mdot
.49008 .01339 Mdot
.46841 .04249 Mdot
.39966 .12947 Mdot
.19017 .26671 Mdot
.75862 .11938 Mdot
.56545 .0604 Mdot
.46772 .09012 Mdot
.3219 .22287 Mdot
.96129 .18733 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61025 Mdot
.51836 .59327 Mdot
.55842 .54032 Mdot
.68416 .40522 Mdot
.0285 .4315 Mdot
.33032 .56066 Mdot
.42316 .01112 Mdot
.40516 .09393 Mdot
.25317 .24145 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50972 .60491 Mdot
.53095 .5764 Mdot
.59832 .49094 Mdot
.80396 .35179 Mdot
.23474 .49866 Mdot
.42789 .56325 Mdot
.51654 .54794 Mdot
.62994 .44042 Mdot
.91732 .36718 Mdot
.50029 .61764 Mdot
.50094 .61677 Mdot
.50299 .614 Mdot
.50951 .60519 Mdot
.53029 .57727 Mdot
.59624 .49339 Mdot
.79792 .35248 Mdot
.22759 .49857 Mdot
.42089 .56892 Mdot
.50035 .5686 Mdot
.58034 .49725 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.51081 .60344 Mdot
.53443 .57177 Mdot
.60929 .47822 Mdot
.83552 .35147 Mdot
.26683 .49819 Mdot
.46074 .53421 Mdot
.59637 .45023 Mdot
.86788 .34134 Mdot
.31558 .47654 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50198 .61535 Mdot
.50632 .6095 Mdot
.52014 .59088 Mdot
.56407 .53307 Mdot
.70155 .39231 Mdot
.06678 .45241 Mdot
.33475 .57953 Mdot
.39706 .05041 Mdot
.31549 .18564 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00666 Mdot
.4843 .02119 Mdot
.45 .06678 Mdot
.34194 .19039 Mdot
.03389 .22157 Mdot
.67539 .08994 Mdot
.52985 .06243 Mdot
.42884 .12623 Mdot
.2246 .2719 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49457 .00733 Mdot
.48272 .02332 Mdot
.44498 .07332 Mdot
.32635 .2042 Mdot
.99594 .20045 Mdot
.67162 .07044 Mdot
.55765 .01815 Mdot
.52828 .6101 Mdot
.54111 .57241 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00244 Mdot
.49425 .00777 Mdot
.48167 .02473 Mdot
.44167 .0776 Mdot
.3161 .2126 Mdot
.97211 .18687 Mdot
.66974 .0577 Mdot
.57638 .60761 Mdot
.59324 .52604 Mdot
.7421 .37867 Mdot
.49991 .00012 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .00379 Mdot
.49106 .01207 Mdot
.47153 .03833 Mdot
.40951 .11777 Mdot
.21896 .26251 Mdot
.7942 .12062 Mdot
.59903 .03463 Mdot
.543 .61328 Mdot
.55069 .56708 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50622 .60963 Mdot
.51982 .5913 Mdot
.56307 .53435 Mdot
.69846 .39448 Mdot
.06019 .44895 Mdot
.33377 .57653 Mdot
.40092 .04453 Mdot
.32887 .17433 Mdot
.0468 .21709 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01062 Mdot
.47496 .03373 Mdot
.42038 .1045 Mdot
.2513 .25204 Mdot
.84349 .12923 Mdot
.6344 .01892 Mdot
.60378 .54742 Mdot
.71803 .40285 Mdot
.06621 .46247 Mdot
.49999 1e-05 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .00491 Mdot
.48842 .01564 Mdot
.46312 .04952 Mdot
.38299 .14849 Mdot
.14273 .26377 Mdot
.71595 .11959 Mdot
.52244 .09885 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51179 .60212 Mdot
.53754 .56764 Mdot
.61908 .46726 Mdot
.86303 .35539 Mdot
.288 .49875 Mdot
.481 .51632 Mdot
.64559 .3994 Mdot
.99934 .39879 Mdot
.35408 .51589 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49457 .00733 Mdot
.48271 .02332 Mdot
.44498 .07332 Mdot
.32634 .20422 Mdot
.99591 .20042 Mdot
.67161 .07042 Mdot
.55768 .01811 Mdot
.52838 .60997 Mdot
.50069 .6171 Mdot
.5022 .61507 Mdot
.507 .60858 Mdot
.5223 .58798 Mdot
.57093 .52437 Mdot
.72248 .37903 Mdot
.1092 .4725 Mdot
.34467 .59471 Mdot
.38242 .07603 Mdot
.2594 .22332 Mdot
.89807 .13515 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49393 .0082 Mdot
.48065 .02609 Mdot
.43844 .08175 Mdot
.30616 .22021 Mdot
.94985 .17448 Mdot
.66753 .04631 Mdot
.5926 .58325 Mdot
.64888 .4645 Mdot
.8973 .37577 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49632 .00497 Mdot
.48829 .01582 Mdot
.46269 .05009 Mdot
.38164 .14998 Mdot
.13898 .26305 Mdot
.71335 .11941 Mdot
.52015 .10078 Mdot
.35708 .21617 Mdot
.00732 .22295 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01028 Mdot
.47576 .03266 Mdot
.42291 .10137 Mdot
.25889 .24869 Mdot
.85651 .13296 Mdot
.64137 .01847 Mdot
.61148 .54141 Mdot
.73546 .39448 Mdot
.09718 .47907 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60311 Mdot
.53519 .57075 Mdot
.6117 .47549 Mdot
.84234 .35209 Mdot
.27264 .49815 Mdot
.46663 .52886 Mdot
.61092 .43415 Mdot
.90845 .35388 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48943 .01427 Mdot
.46634 .04525 Mdot
.39313 .13704 Mdot
.17139 .26695 Mdot
.73945 .11973 Mdot
.54572 .07793 Mdot
.41963 .14931 Mdot
.17803 .28203 Mdot
.7217 .13681 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50199 .61535 Mdot
.50634 .60947 Mdot
.52019 .59081 Mdot
.56423 .53287 Mdot
.70203 .39198 Mdot
.0678 .45295 Mdot
.33492 .57998 Mdot
.39649 .05129 Mdot
.3135 .18725 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00586 Mdot
.48619 .01864 Mdot
.45603 .05888 Mdot
.36076 .17212 Mdot
.08227 .24503 Mdot
.6858 .10933 Mdot
.50889 .10109 Mdot
.34533 .22295 Mdot
.98459 .20868 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50417 .6124 Mdot
.51329 .60009 Mdot
.54234 .5613 Mdot
.63413 .45116 Mdot
.90415 .36757 Mdot
.3094 .50496 Mdot
.49236 .51203 Mdot
.66388 .38557 Mdot
.04001 .42227 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.5128 .60075 Mdot
.54077 .56336 Mdot
.62923 .4563 Mdot
.89092 .36291 Mdot
.30372 .50213 Mdot
.49126 .51023 Mdot
.66569 .38291 Mdot
.04613 .42508 Mdot
.35834 .53973 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53084 .57655 Mdot
.59796 .49137 Mdot
.80291 .3519 Mdot
.23352 .49865 Mdot
.42668 .56424 Mdot
.51372 .55154 Mdot
.6213 .44967 Mdot
.89373 .35831 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49394 .00819 Mdot
.4807 .02604 Mdot
.43857 .08158 Mdot
.30656 .21991 Mdot
.95074 .17497 Mdot
.66763 .04674 Mdot
.592 .58416 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49615 .0052 Mdot
.48773 .01656 Mdot
.46094 .05241 Mdot
.37613 .15599 Mdot
.12373 .25949 Mdot
.70387 .1181 Mdot
.51278 .10626 Mdot
.34084 .23042 Mdot
.96802 .20097 Mdot
.64284 .08562 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48854 .01548 Mdot
.4635 .04902 Mdot
.38419 .14715 Mdot
.14609 .26435 Mdot
.71836 .11971 Mdot
.52465 .09695 Mdot
.36778 .2059 Mdot
.03463 .23775 Mdot
.64994 .11842 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00244 Mdot
.49424 .00778 Mdot
.48166 .02474 Mdot
.44163 .07765 Mdot
.31599 .21269 Mdot
.97185 .18673 Mdot
.66971 .05756 Mdot
.57658 .60731 Mdot
.59392 .52521 Mdot
.74411 .37777 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49714 .00387 Mdot
.49088 .01232 Mdot
.47094 .03911 Mdot
.40767 .11998 Mdot
.21354 .26367 Mdot
.78691 .12008 Mdot
.59262 .03897 Mdot
.52956 .01172 Mdot
.5106 .00191 Mdot
.50751 .61298 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50661 .6091 Mdot
.52107 .58963 Mdot
.56703 .52931 Mdot
.71059 .38626 Mdot
.08561 .46185 Mdot
.33831 .58726 Mdot
.38811 .06462 Mdot
.28355 .2089 Mdot
.94555 .1594 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50775 .60757 Mdot
.52468 .58479 Mdot
.57847 .51495 Mdot
.74525 .36748 Mdot
.15067 .4872 Mdot
.36235 .59949 Mdot
.39237 .0738 Mdot
.27295 .21981 Mdot
.91729 .14654 Mdot
.50103 .61664 Mdot
.5033 .61358 Mdot
.5105 .60385 Mdot
.53345 .57307 Mdot
.60621 .48175 Mdot
.82672 .35102 Mdot
.25875 .49834 Mdot
.45242 .5418 Mdot
.57578 .47417 Mdot
.80855 .3365 Mdot
.26409 .48347 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48083 .02586 Mdot
.43898 .08105 Mdot
.30784 .21896 Mdot
.95356 .17651 Mdot
.66795 .04814 Mdot
.59006 .58707 Mdot
.64015 .4733 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50102 .61666 Mdot
.50325 .61365 Mdot
.51034 .60407 Mdot
.53294 .57375 Mdot
.60459 .48361 Mdot
.82209 .35095 Mdot
.25424 .49844 Mdot
.44775 .54602 Mdot
.56428 .48803 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49465 .00723 Mdot
.48296 .023 Mdot
.44574 .07233 Mdot
.32871 .20219 Mdot
.00155 .20364 Mdot
.67207 .07343 Mdot
.55325 .02498 Mdot
.51284 .01309 Mdot
.49166 .02081 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51217 .6016 Mdot
.53876 .56603 Mdot
.6229 .46308 Mdot
.87361 .35785 Mdot
.2946 .49964 Mdot
.48617 .51245 Mdot
.65701 .38938 Mdot
.02698 .41427 Mdot
.35668 .5299 Mdot
.50131 .61627 Mdot
.50416 .61241 Mdot
.51327 .60012 Mdot
.54225 .56141 Mdot
.63386 .45144 Mdot
.90342 .3673 Mdot
.30912 .50478 Mdot
.49236 .51186 Mdot
.66416 .38525 Mdot
.04081 .42267 Mdot
.35691 .53816 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50747 .60794 Mdot
.52381 .58595 Mdot
.57572 .51837 Mdot
.73697 .37132 Mdot
.13616 .4827 Mdot
.35512 .59922 Mdot
.38557 .07836 Mdot
.25878 .22568 Mdot
.89362 .13424 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.496 .0054 Mdot
.48727 .01719 Mdot
.45946 .05437 Mdot
.37149 .16098 Mdot
.11102 .25575 Mdot
.6972 .11625 Mdot
.50911 .10781 Mdot
.33466 .23497 Mdot
.95447 .19333 Mdot
.64165 .07868 Mdot
.50024 .61772 Mdot
.50075 .61702 Mdot
.50239 .6148 Mdot
.50762 .60774 Mdot
.52428 .58531 Mdot
.57723 .51649 Mdot
.74152 .36916 Mdot
.14421 .48529 Mdot
.35899 .59957 Mdot
.38886 .07639 Mdot
.26525 .22326 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60801 Mdot
.52365 .58616 Mdot
.57522 .519 Mdot
.73545 .37207 Mdot
.13343 .48178 Mdot
.35389 .59899 Mdot
.38471 .07873 Mdot
.25733 .22611 Mdot
.89147 .13312 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49703 .00401 Mdot
.49055 .01276 Mdot
.4699 .0405 Mdot
.40438 .12391 Mdot
.20389 .2653 Mdot
.77463 .11952 Mdot
.58124 .04744 Mdot
.50448 .04328 Mdot
.43445 .10234 Mdot
.26886 .24885 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51129 .60279 Mdot
.53596 .56973 Mdot
.61411 .47278 Mdot
.84914 .35295 Mdot
.27806 .4982 Mdot
.47195 .52407 Mdot
.62399 .4204 Mdot
.94377 .36935 Mdot
.34615 .49078 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00553 Mdot
.48695 .01762 Mdot
.45844 .05571 Mdot
.36831 .16433 Mdot
.10242 .25286 Mdot
.69329 .11458 Mdot
.50789 .10727 Mdot
.33432 .23459 Mdot
.95475 .1932 Mdot
.64214 .07826 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .00229 Mdot
.49459 .0073 Mdot
.48278 .02324 Mdot
.44518 .07306 Mdot
.32697 .20368 Mdot
.9974 .20127 Mdot
.67173 .07121 Mdot
.55651 .01992 Mdot
.52427 .61554 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49457 .00733 Mdot
.4827 .02334 Mdot
.44495 .07336 Mdot
.32624 .2043 Mdot
.99568 .2003 Mdot
.6716 .0703 Mdot
.50118 .61644 Mdot
.50375 .61297 Mdot
.51194 .60191 Mdot
.53803 .56699 Mdot
.62062 .46557 Mdot
.86732 .35633 Mdot
.29077 .49906 Mdot
.48328 .51452 Mdot
.65077 .39474 Mdot
.01206 .40591 Mdot
.35528 .52234 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49072 .01253 Mdot
.47045 .03977 Mdot
.4061 .12185 Mdot
.20895 .26451 Mdot
.78095 .11975 Mdot
.58719 .0429 Mdot
.51778 .02646 Mdot
.47497 .04957 Mdot
.39477 .14016 Mdot
.50122 .61639 Mdot
.50388 .6128 Mdot
.51235 .60135 Mdot
.53934 .56525 Mdot
.62475 .46109 Mdot
.87869 .3592 Mdot
.29748 .50023 Mdot
.48809 .51126 Mdot
.66085 .38626 Mdot
.03587 .41923 Mdot
.35753 .53436 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00057 Mdot
.49864 .00183 Mdot
.49568 .00584 Mdot
.48624 .01858 Mdot
.45618 .05869 Mdot
.36122 .17165 Mdot
.08348 .24554 Mdot
.68619 .1097 Mdot
.50869 .10165 Mdot
.34422 .22409 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50995 .6046 Mdot
.53169 .57542 Mdot
.60065 .48821 Mdot
.81071 .35127 Mdot
.24235 .49864 Mdot
.43553 .55678 Mdot
.53464 .52493 Mdot
.68529 .38941 Mdot
.05521 .43957 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50993 .60462 Mdot
.53164 .57548 Mdot
.60049 .48839 Mdot
.81026 .35129 Mdot
.24186 .49865 Mdot
.43503 .55722 Mdot
.53343 .52645 Mdot
.68161 .39232 Mdot
.04681 .4351 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52555 .58361 Mdot
.58125 .51151 Mdot
.75361 .36401 Mdot
.16463 .49083 Mdot
.37045 .5981 Mdot
.4027 .06475 Mdot
.29794 .20565 Mdot
.96518 .17363 Mdot
.50054 .6173 Mdot
.50172 .61571 Mdot
.50549 .61062 Mdot
.51748 .59446 Mdot
.55563 .54393 Mdot
.67553 .41225 Mdot
.0085 .42012 Mdot
.32873 .54998 Mdot
.43884 .60529 Mdot
.45946 .02443 Mdot
.41994 .09556 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48875 .01519 Mdot
.46417 .04813 Mdot
.38629 .1448 Mdot
.15199 .26525 Mdot
.72282 .11985 Mdot
.5289 .09321 Mdot
.37808 .1955 Mdot
.06177 .25133 Mdot
.65511 .12924 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51288 .60064 Mdot
.54103 .56302 Mdot
.63004 .45544 Mdot
.89312 .36364 Mdot
.30474 .50254 Mdot
.49161 .51032 Mdot
.66589 .38291 Mdot
.04633 .42526 Mdot
.35826 .53996 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00479 Mdot
.48871 .01524 Mdot
.46405 .04829 Mdot
.38591 .14523 Mdot
.15093 .2651 Mdot
.72199 .11983 Mdot
.5281 .09392 Mdot
.37613 .1975 Mdot
.05657 .24885 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00381 Mdot
.49101 .01214 Mdot
.47137 .03854 Mdot
.40902 .11836 Mdot
.21751 .26284 Mdot
.79223 .12046 Mdot
.59732 .03575 Mdot
.53947 .61757 Mdot
.54022 .58069 Mdot
.60064 .49348 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50755 .60783 Mdot
.52406 .58561 Mdot
.57652 .51737 Mdot
.73939 .37016 Mdot
.14047 .48412 Mdot
.35715 .59947 Mdot
.38719 .07748 Mdot
.26183 .22461 Mdot
.8984 .13669 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45943 .0544 Mdot
.37141 .16106 Mdot
.11082 .25569 Mdot
.69711 .11622 Mdot
.50907 .10782 Mdot
.33462 .23499 Mdot
.95439 .19329 Mdot
.64164 .07864 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01444 Mdot
.46593 .04579 Mdot
.39185 .13851 Mdot
.16774 .26678 Mdot
.73608 .1198 Mdot
.54224 .08109 Mdot
.41103 .15934 Mdot
.15321 .28043 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46948 .04105 Mdot
.40306 .12547 Mdot
.20004 .26581 Mdot
.76996 .11942 Mdot
.57673 .05101 Mdot
.4942 .05638 Mdot
.40298 .14086 Mdot
.50067 .61712 Mdot
.50214 .61514 Mdot
.50683 .60881 Mdot
.52176 .5887 Mdot
.56923 .52652 Mdot
.7173 .38208 Mdot
.09908 .46811 Mdot
.34166 .59186 Mdot
.38401 .07209 Mdot
.26736 .21876 Mdot
.91341 .14238 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49465 .00722 Mdot
.48297 .02298 Mdot
.44579 .07227 Mdot
.32886 .20207 Mdot
.00191 .20384 Mdot
.67209 .07362 Mdot
.55298 .0254 Mdot
.51187 .01441 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50267 .61442 Mdot
.50852 .60653 Mdot
.52713 .5815 Mdot
.58625 .5054 Mdot
.76849 .35885 Mdot
.18786 .49529 Mdot
.38646 .59185 Mdot
.42883 .03761 Mdot
.36798 .14644 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00297 Mdot
.49299 .00947 Mdot
.47766 .03011 Mdot
.42894 .09382 Mdot
.27713 .23923 Mdot
.89006 .14522 Mdot
.65509 .02314 Mdot
.61764 .54178 Mdot
.74103 .39447 Mdot
.10276 .48325 Mdot
.50089 .61684 Mdot
.50282 .61422 Mdot
.50899 .60589 Mdot
.52865 .57947 Mdot
.59104 .4996 Mdot
.78266 .35516 Mdot
.20801 .49759 Mdot
.40288 .58214 Mdot
.46096 .61798 Mdot
.46105 .03569 Mdot
.40329 .11993 Mdot
.49994 9e-05 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49337 .00896 Mdot
.47887 .02849 Mdot
.43278 .08897 Mdot
.28882 .23215 Mdot
.91319 .1556 Mdot
.66142 .03033 Mdot
.61234 .55265 Mdot
.71814 .40805 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49092 .01227 Mdot
.47106 .03895 Mdot
.40805 .11953 Mdot
.21465 .26345 Mdot
.78838 .12017 Mdot
.59394 .03805 Mdot
.53237 .00825 Mdot
.51902 .6087 Mdot
.53413 .5773 Mdot
.50065 .61715 Mdot
.50207 .61523 Mdot
.50661 .6091 Mdot
.52106 .58964 Mdot
.567 .52935 Mdot
.7105 .38632 Mdot
.08541 .46176 Mdot
.33827 .58719 Mdot
.38818 .06449 Mdot
.28383 .20872 Mdot
.94612 .15972 Mdot
.50103 .61664 Mdot
.5033 .61358 Mdot
.51051 .60385 Mdot
.53346 .57306 Mdot
.60624 .48172 Mdot
.82679 .35102 Mdot
.25883 .49834 Mdot
.45249 .54173 Mdot
.57596 .47395 Mdot
.80909 .33646 Mdot
.26468 .48338 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49374 .00845 Mdot
.48006 .02689 Mdot
.43655 .08416 Mdot
.30038 .22437 Mdot
.93734 .16777 Mdot
.66588 .04036 Mdot
.60057 .57124 Mdot
.67629 .43924 Mdot
.96558 .40758 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49202 .01078 Mdot
.47457 .03426 Mdot
.41913 .10605 Mdot
.24753 .25358 Mdot
.83723 .12765 Mdot
.63069 .01965 Mdot
.5989 .55179 Mdot
.70609 .40982 Mdot
.04298 .44918 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00233 Mdot
.49451 .00741 Mdot
.48251 .02359 Mdot
.44434 .07414 Mdot
.32438 .20587 Mdot
.99127 .19778 Mdot
.67125 .06793 Mdot
.56134 .01246 Mdot
.54117 .59276 Mdot
.58207 .52 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.4871 .01741 Mdot
.45893 .05507 Mdot
.36983 .16273 Mdot
.10653 .25428 Mdot
.6951 .11542 Mdot
.50834 .10769 Mdot
.3341 .23511 Mdot
.95368 .19277 Mdot
.64176 .07805 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49726 .0037 Mdot
.49128 .01178 Mdot
.47222 .03741 Mdot
.41169 .11514 Mdot
.22539 .26092 Mdot
.8032 .12155 Mdot
.60653 .03 Mdot
.558 .59544 Mdot
.59455 .51286 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01098 Mdot
.47409 .03489 Mdot
.41763 .10789 Mdot
.24307 .25529 Mdot
.82999 .126 Mdot
.62613 .02093 Mdot
.59226 .55814 Mdot
.68917 .42124 Mdot
.50024 .6177 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60736 Mdot
.52517 .58412 Mdot
.58005 .513 Mdot
.75 .36545 Mdot
.15868 .48937 Mdot
.36686 .5989 Mdot
.39783 .06921 Mdot
.28585 .21303 Mdot
.50116 .61646 Mdot
.50371 .61303 Mdot
.51181 .60209 Mdot
.5376 .56755 Mdot
.61928 .46704 Mdot
.86359 .35551 Mdot
.28837 .49878 Mdot
.48132 .51606 Mdot
.64631 .39874 Mdot
.00113 .39979 Mdot
.35426 .5168 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.49309 .00933 Mdot
.47799 .02967 Mdot
.42999 .0925 Mdot
.28032 .23737 Mdot
.89625 .14786 Mdot
.65701 .02479 Mdot
.6169 .54394 Mdot
.73679 .3969 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48754 .01683 Mdot
.46031 .05324 Mdot
.37417 .15812 Mdot
.11833 .25798 Mdot
.7009 .1174 Mdot
.51094 .10726 Mdot
.33739 .23312 Mdot
.96019 .1966 Mdot
.64209 .08169 Mdot
.49994 8e-05 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00268 Mdot
.49367 .00855 Mdot
.47984 .02719 Mdot
.43585 .08506 Mdot
.29821 .22589 Mdot
.93272 .16536 Mdot
.66517 .03828 Mdot
.60323 .56719 Mdot
.6855 .4316 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49711 .0039 Mdot
.4908 .01242 Mdot
.4707 .03944 Mdot
.40689 .12092 Mdot
.21124 .26411 Mdot
.78391 .1199 Mdot
.58991 .04091 Mdot
.52371 .01901 Mdot
.49295 .02555 Mdot
.45162 .06971 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .0039 Mdot
.49081 .01241 Mdot
.47074 .03938 Mdot
.40703 .12075 Mdot
.21165 .26403 Mdot
.78443 .11993 Mdot
.59039 .04056 Mdot
.52475 .01771 Mdot
.4961 .02133 Mdot
.50043 .61746 Mdot
.50136 .61619 Mdot
.50435 .61216 Mdot
.51385 .59933 Mdot
.54411 .55896 Mdot
.63968 .44547 Mdot
.91891 .3735 Mdot
.31457 .50907 Mdot
.49089 .51751 Mdot
.65354 .39624 Mdot
.01241 .40773 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00527 Mdot
.48757 .01679 Mdot
.46041 .05311 Mdot
.37447 .15779 Mdot
.11915 .25822 Mdot
.70134 .11752 Mdot
.5112 .10714 Mdot
.33783 .23279 Mdot
.96118 .19715 Mdot
.64218 .08219 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49179 .01109 Mdot
.47385 .03522 Mdot
.41687 .10882 Mdot
.24079 .25612 Mdot
.82638 .12524 Mdot
.62373 .02175 Mdot
.58854 .56187 Mdot
.67941 .4286 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51225 .6015 Mdot
.53901 .5657 Mdot
.62369 .46223 Mdot
.87579 .35842 Mdot
.29586 .49988 Mdot
.48704 .51188 Mdot
.65879 .38791 Mdot
.03113 .41659 Mdot
.35707 .53199 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .00499 Mdot
.48822 .0159 Mdot
.46249 .05036 Mdot
.381 .15068 Mdot
.13719 .26269 Mdot
.71215 .1193 Mdot
.51912 .10162 Mdot
.3547 .21837 Mdot
.00136 .21963 Mdot
.64598 .10249 Mdot
.50079 .61696 Mdot
.50252 .61463 Mdot
.50803 .60718 Mdot
.52559 .58357 Mdot
.58136 .51138 Mdot
.75392 .36388 Mdot
.16515 .49095 Mdot
.37077 .59801 Mdot
.40317 .06431 Mdot
.2991 .20489 Mdot
.96758 .17504 Mdot
.50019 .61778 Mdot
.50059 .61723 Mdot
.50188 .61549 Mdot
.506 .60992 Mdot
.51913 .59223 Mdot
.56088 .53716 Mdot
.69173 .3994 Mdot
.04549 .441 Mdot
.33194 .56942 Mdot
.41061 .02996 Mdot
.36213 .14238 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60602 Mdot
.52833 .57989 Mdot
.59005 .50079 Mdot
.77975 .35582 Mdot
.20402 .49725 Mdot
.39945 .58438 Mdot
.4539 .00849 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51076 .60351 Mdot
.53427 .57198 Mdot
.60878 .47881 Mdot
.83404 .35136 Mdot
.26552 .49821 Mdot
.4594 .53544 Mdot
.59305 .45401 Mdot
.85844 .33941 Mdot
.30927 .47684 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .0051 Mdot
.48797 .01624 Mdot
.46168 .05142 Mdot
.37848 .15344 Mdot
.1302 .26113 Mdot
.70769 .11877 Mdot
.51552 .10441 Mdot
.34658 .22561 Mdot
.98154 .20854 Mdot
.64413 .09245 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50483 .6115 Mdot
.5154 .59725 Mdot
.54902 .55252 Mdot
.65503 .43048 Mdot
.9585 .39244 Mdot
.32352 .52452 Mdot
.47483 .54775 Mdot
.58855 .46984 Mdot
.82833 .33981 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49802 .00268 Mdot
.49368 .00854 Mdot
.47987 .02715 Mdot
.43594 .08495 Mdot
.29849 .2257 Mdot
.93329 .16566 Mdot
.66526 .03854 Mdot
.6029 .56768 Mdot
.68438 .4325 Mdot
.98457 .41822 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50529 .61089 Mdot
.51685 .5953 Mdot
.55364 .5465 Mdot
.66938 .41749 Mdot
.99386 .4118 Mdot
.32755 .54218 Mdot
.45029 .58751 Mdot
.49968 .5878 Mdot
.5486 .54344 Mdot
.50068 .61711 Mdot
.50217 .6151 Mdot
.50691 .6087 Mdot
.52202 .58835 Mdot
.57004 .5255 Mdot
.71977 .38061 Mdot
.10394 .47026 Mdot
.34305 .5933 Mdot
.38307 .07417 Mdot
.26307 .22122 Mdot
.90513 .13838 Mdot
.50042 .61746 Mdot
.50134 .61622 Mdot
.50428 .61226 Mdot
.51363 .59964 Mdot
.54339 .55992 Mdot
.63742 .44777 Mdot
.91292 .37101 Mdot
.31262 .50728 Mdot
.49182 .51486 Mdot
.65876 .39091 Mdot
.02626 .41514 Mdot
.50097 .61672 Mdot
.5031 .61385 Mdot
.50987 .6047 Mdot
.53144 .57574 Mdot
.59988 .48911 Mdot
.80848 .35141 Mdot
.23988 .49866 Mdot
.43304 .55892 Mdot
.52868 .53248 Mdot
.6671 .4045 Mdot
.01261 .41618 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49439 .00758 Mdot
.48212 .02412 Mdot
.44309 .07577 Mdot
.32049 .20907 Mdot
.9822 .19261 Mdot
.67055 .06307 Mdot
.5685 .00151 Mdot
.56606 .56004 Mdot
.6599 .43551 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00383 Mdot
.49098 .01219 Mdot
.47126 .03869 Mdot
.40866 .11879 Mdot
.21645 .26307 Mdot
.7908 .12035 Mdot
.59607 .03659 Mdot
.53686 .00273 Mdot
.53245 .59089 Mdot
.57637 .52278 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50592 .61003 Mdot
.51887 .59258 Mdot
.56005 .53822 Mdot
.6892 .40131 Mdot
.03986 .43788 Mdot
.33136 .56656 Mdot
.41464 .02393 Mdot
.37593 .12765 Mdot
.16939 .25667 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.4955 .00608 Mdot
.48565 .01937 Mdot
.45431 .06115 Mdot
.35537 .17752 Mdot
.06813 .23877 Mdot
.68179 .10457 Mdot
.51259 .09291 Mdot
.36225 .20526 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.4934 .00892 Mdot
.47896 .02836 Mdot
.43307 .0886 Mdot
.28971 .23157 Mdot
.91502 .15648 Mdot
.66182 .03101 Mdot
.61165 .55382 Mdot
.71555 .40972 Mdot
.05262 .45761 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50642 .60937 Mdot
.52044 .59047 Mdot
.56505 .53183 Mdot
.70453 .39026 Mdot
.07307 .45565 Mdot
.33581 .58226 Mdot
.39369 .05561 Mdot
.30371 .19484 Mdot
.98846 .18415 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61085 Mdot
.51694 .59518 Mdot
.55391 .54615 Mdot
.67022 .41676 Mdot
.99588 .41294 Mdot
.32772 .54324 Mdot
.44874 .58994 Mdot
.49419 .59533 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49624 .00508 Mdot
.48802 .01618 Mdot
.46183 .05123 Mdot
.37895 .15294 Mdot
.13149 .26143 Mdot
.70848 .11888 Mdot
.51613 .10395 Mdot
.34794 .22443 Mdot
.9848 .21036 Mdot
.64443 .0941 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.5025 .61465 Mdot
.50797 .60726 Mdot
.5254 .58381 Mdot
.58078 .5121 Mdot
.75218 .36457 Mdot
.1623 .49027 Mdot
.36902 .59845 Mdot
.40071 .06661 Mdot
.29293 .20882 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.5054 .61074 Mdot
.51719 .59484 Mdot
.55472 .5451 Mdot
.67274 .4146 Mdot
.0019 .41636 Mdot
.32821 .54644 Mdot
.44405 .59726 Mdot
.47767 .61789 Mdot
.4779 .02028 Mdot
.49972 .00038 Mdot
.49909 .00123 Mdot
.49711 .00391 Mdot
.49079 .01244 Mdot
.47067 .03948 Mdot
.40679 .12104 Mdot
.21095 .26416 Mdot
.78353 .11988 Mdot
.58956 .04116 Mdot
.52296 .01996 Mdot
.49066 .02861 Mdot
.44438 .07913 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00457 Mdot
.48922 .01456 Mdot
.46567 .04614 Mdot
.39102 .13946 Mdot
.16537 .26663 Mdot
.73396 .11983 Mdot
.54006 .08309 Mdot
.40563 .16554 Mdot
.13779 .2779 Mdot
.68813 .14136 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50264 .61447 Mdot
.50841 .60668 Mdot
.52679 .58196 Mdot
.58516 .50673 Mdot
.76526 .35986 Mdot
.183 .49452 Mdot
.38285 .59358 Mdot
.42241 .04466 Mdot
.50107 .61659 Mdot
.5034 .61345 Mdot
.51082 .60343 Mdot
.53445 .57174 Mdot
.60937 .47814 Mdot
.83572 .35148 Mdot
.26701 .49819 Mdot
.46093 .53405 Mdot
.59682 .44973 Mdot
.86915 .34163 Mdot
.31638 .47653 Mdot
.50023 .61772 Mdot
.50074 .61703 Mdot
.50236 .61485 Mdot
.50752 .60788 Mdot
.52395 .58575 Mdot
.57618 .51779 Mdot
.73838 .37064 Mdot
.13866 .48353 Mdot
.35629 .59938 Mdot
.38647 .07789 Mdot
.26044 .22512 Mdot
.50018 .61779 Mdot
.50056 .61727 Mdot
.5018 .6156 Mdot
.50573 .61029 Mdot
.51826 .59341 Mdot
.5581 .54073 Mdot
.68319 .406 Mdot
.02627 .43024 Mdot
.33013 .55948 Mdot
.42487 .00853 Mdot
.41107 .08675 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50352 .61327 Mdot
.51123 .60287 Mdot
.53576 .57 Mdot
.61347 .4735 Mdot
.84733 .3527 Mdot
.27665 .49818 Mdot
.47059 .52529 Mdot
.62065 .42384 Mdot
.93486 .36513 Mdot
.50093 .61678 Mdot
.50295 .61405 Mdot
.50939 .60535 Mdot
.52992 .57777 Mdot
.59508 .49477 Mdot
.79452 .35296 Mdot
.22341 .49845 Mdot
.41689 .57204 Mdot
.49131 .5801 Mdot
.55269 .53213 Mdot
.69168 .39438 Mdot
.50108 .61657 Mdot
.50345 .61338 Mdot
.51098 .60321 Mdot
.53497 .57104 Mdot
.611 .47628 Mdot
.84037 .35189 Mdot
.271 .49815 Mdot
.46498 .53035 Mdot
.60685 .43857 Mdot
.89724 .34978 Mdot
.33127 .47851 Mdot
.49984 .00022 Mdot
.49947 .00071 Mdot
.49833 .00226 Mdot
.49466 .00721 Mdot
.483 .02294 Mdot
.44588 .07215 Mdot
.32915 .20182 Mdot
.0026 .20423 Mdot
.67215 .07399 Mdot
.55244 .02625 Mdot
.50997 .01701 Mdot
.48244 .03325 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60225 Mdot
.53722 .56806 Mdot
.61809 .46835 Mdot
.86028 .35483 Mdot
.28615 .49859 Mdot
.47941 .51762 Mdot
.64189 .40283 Mdot
.9901 .39366 Mdot
.35315 .51128 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46506 .04694 Mdot
.3891 .14163 Mdot
.15994 .26618 Mdot
.72926 .11988 Mdot
.53528 .08744 Mdot
.39379 .17876 Mdot
.10455 .26886 Mdot
.66953 .13978 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49788 .00286 Mdot
.49325 .00912 Mdot
.4785 .02899 Mdot
.43159 .09047 Mdot
.2852 .23442 Mdot
.90589 .15218 Mdot
.65966 .02777 Mdot
.61473 .54842 Mdot
.72737 .40236 Mdot
.07633 .47044 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00237 Mdot
.49441 .00755 Mdot
.48219 .02402 Mdot
.44332 .07547 Mdot
.32122 .20848 Mdot
.98388 .19357 Mdot
.67068 .06397 Mdot
.56718 .00352 Mdot
.56149 .56596 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51226 .60149 Mdot
.53903 .56566 Mdot
.62378 .46214 Mdot
.87602 .35848 Mdot
.29599 .49991 Mdot
.48713 .51183 Mdot
.65897 .38777 Mdot
.03155 .41682 Mdot
.50113 .6165 Mdot
.50361 .61315 Mdot
.51151 .6025 Mdot
.53665 .56882 Mdot
.61627 .47037 Mdot
.85521 .3539 Mdot
.28258 .49836 Mdot
.47621 .52033 Mdot
.6343 .41009 Mdot
.97077 .38314 Mdot
.35084 .50205 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50793 .60732 Mdot
.52527 .58399 Mdot
.58036 .51261 Mdot
.75094 .36507 Mdot
.16025 .48977 Mdot
.36779 .59872 Mdot
.39904 .06813 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54176 .56206 Mdot
.63232 .45305 Mdot
.89928 .36578 Mdot
.30743 .50382 Mdot
.49223 .51102 Mdot
.66538 .38384 Mdot
.04431 .42439 Mdot
.35763 .53947 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00406 Mdot
.49043 .01293 Mdot
.46952 .04101 Mdot
.40315 .12536 Mdot
.20032 .26577 Mdot
.7703 .11943 Mdot
.57706 .05074 Mdot
.49496 .05542 Mdot
.40529 .13813 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49737 .00355 Mdot
.49164 .0113 Mdot
.47336 .03588 Mdot
.4153 .11075 Mdot
.23611 .25773 Mdot
.8191 .12387 Mdot
.61867 .02378 Mdot
.5802 .57057 Mdot
.657 .44751 Mdot
.93292 .38714 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51257 .60107 Mdot
.54002 .56436 Mdot
.62687 .45881 Mdot
.8845 .36089 Mdot
.30057 .50105 Mdot
.48986 .51045 Mdot
.66394 .38395 Mdot
.04269 .42305 Mdot
.35817 .53781 Mdot
.50115 .61648 Mdot
.50365 .6131 Mdot
.51164 .60231 Mdot
.53708 .56824 Mdot
.61764 .46885 Mdot
.85903 .35459 Mdot
.28529 .49852 Mdot
.47866 .51825 Mdot
.64012 .40449 Mdot
.98563 .39119 Mdot
.35267 .50909 Mdot
.50078 .61698 Mdot
.50249 .61466 Mdot
.50795 .6073 Mdot
.52532 .58393 Mdot
.5805 .51245 Mdot
.75134 .36491 Mdot
.16091 .48993 Mdot
.36818 .59863 Mdot
.39957 .06764 Mdot
.29012 .21053 Mdot
.94949 .16448 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46847 .0424 Mdot
.39986 .12923 Mdot
.19076 .26667 Mdot
.75927 .11938 Mdot
.56611 .05984 Mdot
.50082 .61693 Mdot
.50261 .6145 Mdot
.50832 .60679 Mdot
.52651 .58233 Mdot
.58428 .5078 Mdot
.76265 .36072 Mdot
.179 .49382 Mdot
.37998 .59484 Mdot
.41751 .0499 Mdot
.33677 .17606 Mdot
.0519 .22332 Mdot
.50088 .61684 Mdot
.50282 .61423 Mdot
.50897 .60592 Mdot
.52857 .57958 Mdot
.5908 .4999 Mdot
.78195 .35531 Mdot
.20704 .49752 Mdot
.40204 .5827 Mdot
.45921 .00207 Mdot
.45585 .04247 Mdot
.38713 .13856 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00269 Mdot
.49366 .00856 Mdot
.47982 .02722 Mdot
.43578 .08515 Mdot
.298 .22604 Mdot
.93226 .16512 Mdot
.66509 .03808 Mdot
.60348 .56679 Mdot
.68639 .43088 Mdot
.98922 .42089 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .608 Mdot
.52365 .58616 Mdot
.57523 .51899 Mdot
.73549 .37205 Mdot
.1335 .4818 Mdot
.35393 .59899 Mdot
.38473 .07872 Mdot
.25737 .2261 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.49251 .01012 Mdot
.47614 .03216 Mdot
.4241 .09989 Mdot
.26248 .24698 Mdot
.86285 .135 Mdot
.64442 .01875 Mdot
.61409 .53984 Mdot
.7406 .39255 Mdot
.10544 .48331 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00266 Mdot
.49372 .00849 Mdot
.47998 .027 Mdot
.4363 .08448 Mdot
.29961 .22492 Mdot
.93568 .1669 Mdot
.66563 .03961 Mdot
.60154 .56977 Mdot
.67964 .4364 Mdot
.97352 .41197 Mdot
.50035 .61756 Mdot
.50113 .61651 Mdot
.5036 .61318 Mdot
.51145 .60257 Mdot
.53648 .56904 Mdot
.61575 .47095 Mdot
.85373 .35365 Mdot
.28151 .49831 Mdot
.47522 .52119 Mdot
.63191 .41244 Mdot
.96457 .37986 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50639 .6094 Mdot
.52036 .59058 Mdot
.56477 .53218 Mdot
.70368 .39084 Mdot
.07129 .45474 Mdot
.3355 .5815 Mdot
.39461 .05418 Mdot
.30694 .19238 Mdot
.99566 .18836 Mdot
.49984 .00021 Mdot
.49951 .00067 Mdot
.49842 .00213 Mdot
.49498 .00678 Mdot
.48401 .02158 Mdot
.4491 .06797 Mdot
.33913 .19297 Mdot
.02689 .21778 Mdot
.67451 .08653 Mdot
.53451 .05479 Mdot
.44586 .10402 Mdot
.27755 .24936 Mdot
.50123 .61637 Mdot
.50393 .61273 Mdot
.51251 .60115 Mdot
.53983 .56461 Mdot
.62627 .45945 Mdot
.88286 .3604 Mdot
.29972 .5008 Mdot
.48941 .51062 Mdot
.66321 .38447 Mdot
.04112 .42217 Mdot
.35803 .53701 Mdot
.50053 .61732 Mdot
.50168 .61576 Mdot
.50536 .61079 Mdot
.51708 .59499 Mdot
.55436 .54557 Mdot
.67162 .41556 Mdot
.99923 .41484 Mdot
.328 .54502 Mdot
.44613 .59401 Mdot
.48501 .60789 Mdot
.50142 .60657 Mdot
.50038 .61751 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51244 .60123 Mdot
.53963 .56488 Mdot
.62564 .46013 Mdot
.88114 .3599 Mdot
.29881 .50056 Mdot
.48889 .51085 Mdot
.66233 .38513 Mdot
.03918 .42108 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49632 .00497 Mdot
.48828 .01583 Mdot
.46267 .05012 Mdot
.38156 .15006 Mdot
.13876 .26301 Mdot
.7132 .11939 Mdot
.52002 .10088 Mdot
.35678 .21645 Mdot
.00656 .22253 Mdot
.6465 .1051 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60697 Mdot
.5261 .58288 Mdot
.58298 .50939 Mdot
.75876 .36207 Mdot
.17292 .49265 Mdot
.3758 .59645 Mdot
.41071 .05692 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00506 Mdot
.48806 .01612 Mdot
.46197 .05104 Mdot
.37939 .15245 Mdot
.13272 .26172 Mdot
.70925 .11898 Mdot
.51673 .1035 Mdot
.34928 .22326 Mdot
.98804 .21218 Mdot
.64473 .09575 Mdot
.50058 .61726 Mdot
.50184 .61555 Mdot
.50585 .61013 Mdot
.51865 .59288 Mdot
.55934 .53914 Mdot
.687 .403 Mdot
.03494 .43513 Mdot
.33089 .56402 Mdot
.41828 .01847 Mdot
.3884 .11366 Mdot
.2045 .25521 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50302 .61395 Mdot
.50964 .60502 Mdot
.5307 .57674 Mdot
.59752 .49188 Mdot
.80163 .35204 Mdot
.23203 .49864 Mdot
.42521 .56545 Mdot
.51029 .55591 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51165 .6023 Mdot
.53711 .56821 Mdot
.61772 .46877 Mdot
.85924 .35463 Mdot
.28543 .49853 Mdot
.47879 .51814 Mdot
.64041 .40422 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50452 .61193 Mdot
.51439 .59861 Mdot
.54583 .55671 Mdot
.64505 .4401 Mdot
.93296 .37977 Mdot
.31848 .51386 Mdot
.48703 .52587 Mdot
.63615 .4145 Mdot
.96547 .38274 Mdot
.50008 .61793 Mdot
.50024 .61771 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50774 .60758 Mdot
.52465 .58482 Mdot
.5784 .51504 Mdot
.74504 .36757 Mdot
.15031 .4871 Mdot
.36216 .5995 Mdot
.39215 .07397 Mdot
.50018 .61779 Mdot
.50058 .61726 Mdot
.50184 .61555 Mdot
.50585 .61013 Mdot
.51864 .59289 Mdot
.55932 .53916 Mdot
.68694 .40305 Mdot
.0348 .43505 Mdot
.33087 .56395 Mdot
.41838 .01831 Mdot
.38875 .11325 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50296 .61404 Mdot
.50942 .60531 Mdot
.53002 .57764 Mdot
.59537 .49443 Mdot
.79537 .35284 Mdot
.22447 .49849 Mdot
.4179 .57127 Mdot
.49356 .57724 Mdot
.55957 .52329 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51002 .6045 Mdot
.53193 .5751 Mdot
.6014 .48732 Mdot
.8129 .35115 Mdot
.24473 .49861 Mdot
.43795 .55469 Mdot
.54044 .5176 Mdot
.70294 .37646 Mdot
.09381 .45848 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48761 .01672 Mdot
.46056 .05291 Mdot
.37494 .15728 Mdot
.12045 .25859 Mdot
.70205 .11769 Mdot
.51162 .10693 Mdot
.3386 .2322 Mdot
.9629 .19811 Mdot
.64235 .08305 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50697 .60862 Mdot
.5222 .58811 Mdot
.57061 .52478 Mdot
.72151 .37959 Mdot
.10732 .47171 Mdot
.34408 .59422 Mdot
.38261 .07541 Mdot
.26059 .22263 Mdot
.90037 .13618 Mdot
.50073 .61704 Mdot
.50234 .61488 Mdot
.50744 .60798 Mdot
.52371 .58608 Mdot
.57541 .51876 Mdot
.73603 .37179 Mdot
.13447 .48213 Mdot
.35436 .59908 Mdot
.38502 .0786 Mdot
.25784 .22597 Mdot
.89222 .13351 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.50291 .61411 Mdot
.50926 .60553 Mdot
.52949 .57835 Mdot
.59369 .49643 Mdot
.79046 .35362 Mdot
.21829 .49825 Mdot
.4121 .57565 Mdot
.48068 .59352 Mdot
.52034 .57472 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00543 Mdot
.48719 .0173 Mdot
.4592 .0547 Mdot
.3707 .16182 Mdot
.10887 .25506 Mdot
.69618 .11587 Mdot
.50871 .1078 Mdot
.33429 .23513 Mdot
.5001 .6179 Mdot
.50032 .61761 Mdot
.50101 .61668 Mdot
.5032 .61371 Mdot
.5102 .60425 Mdot
.5325 .57433 Mdot
.60322 .48521 Mdot
.81814 .35098 Mdot
.25024 .49852 Mdot
.44361 .54971 Mdot
.55416 .50047 Mdot
.50003 .618 Mdot
.50009 .61792 Mdot
.50027 .61767 Mdot
.50087 .61686 Mdot
.50276 .61431 Mdot
.50879 .60616 Mdot
.528 .58034 Mdot
.58899 .50207 Mdot
.77663 .35658 Mdot
.19966 .49681 Mdot
.39581 .58665 Mdot
.50126 .61634 Mdot
.50401 .61262 Mdot
.51276 .6008 Mdot
.54065 .56353 Mdot
.62884 .45671 Mdot
.88987 .36257 Mdot
.30322 .50194 Mdot
.49107 .51022 Mdot
.66552 .38298 Mdot
.04585 .4249 Mdot
.35836 .53955 Mdot
.50057 .61726 Mdot
.50182 .61557 Mdot
.5058 .6102 Mdot
.51849 .5931 Mdot
.55884 .53979 Mdot
.68544 .40421 Mdot
.03141 .43315 Mdot
.33057 .56219 Mdot
.42093 .01447 Mdot
.39751 .10305 Mdot
.23077 .24952 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49257 .01004 Mdot
.47633 .0319 Mdot
.42472 .09912 Mdot
.26435 .24606 Mdot
.86621 .13613 Mdot
.64594 .01901 Mdot
.61518 .53935 Mdot
.7425 .39197 Mdot
.10828 .48478 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.53941 .56517 Mdot
.62494 .46087 Mdot
.87923 .35936 Mdot
.29778 .5003 Mdot
.48828 .51116 Mdot
.6612 .38599 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49395 .00817 Mdot
.48073 .026 Mdot
.43866 .08147 Mdot
.30685 .2197 Mdot
.95137 .17531 Mdot
.66771 .04705 Mdot
.59157 .5848 Mdot
.64534 .46802 Mdot
.88807 .3726 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .0156 Mdot
.46319 .04942 Mdot
.38323 .14822 Mdot
.1434 .26389 Mdot
.71641 .11962 Mdot
.52287 .09849 Mdot
.36351 .21007 Mdot
.0236 .23188 Mdot
.64842 .11338 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00388 Mdot
.49084 .01237 Mdot
.47082 .03927 Mdot
.40727 .12045 Mdot
.21237 .2639 Mdot
.78538 .11998 Mdot
.59125 .03995 Mdot
.52661 .01539 Mdot
.50171 .01381 Mdot
.47937 .03288 Mdot
.4996 .00054 Mdot
.49872 .00174 Mdot
.49591 .00553 Mdot
.48696 .01761 Mdot
.45847 .05567 Mdot
.36839 .16424 Mdot
.10264 .25293 Mdot
.69338 .11463 Mdot
.50791 .1073 Mdot
.33429 .23463 Mdot
.95465 .19316 Mdot
.64212 .07823 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49763 .00321 Mdot
.49244 .01022 Mdot
.47591 .03247 Mdot
.42337 .10079 Mdot
.26028 .24803 Mdot
.85896 .13373 Mdot
.64257 .01854 Mdot
.61257 .5407 Mdot
.7377 .3936 Mdot
.10084 .48095 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00534 Mdot
.4874 .01702 Mdot
.45987 .05383 Mdot
.37277 .15961 Mdot
.11452 .25685 Mdot
.69893 .11683 Mdot
.50989 .10767 Mdot
.33568 .23434 Mdot
.95651 .19453 Mdot
.50033 .61759 Mdot
.50105 .61662 Mdot
.50334 .61352 Mdot
.51065 .60365 Mdot
.53393 .57243 Mdot
.60772 .48002 Mdot
.83102 .35119 Mdot
.26278 .49826 Mdot
.45659 .53801 Mdot
.58608 .46204 Mdot
.83848 .33672 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.4762 .03207 Mdot
.42431 .09962 Mdot
.26312 .24666 Mdot
.86401 .13539 Mdot
.64495 .01883 Mdot
.61449 .53965 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50437 .61212 Mdot
.51394 .59922 Mdot
.54438 .55861 Mdot
.64054 .4446 Mdot
.92116 .37446 Mdot
.31526 .50978 Mdot
.49042 .51865 Mdot
.65123 .39862 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60623 Mdot
.52783 .58057 Mdot
.58845 .50273 Mdot
.77502 .357 Mdot
.19737 .49655 Mdot
.39393 .58777 Mdot
.44291 .02153 Mdot
.40806 .1021 Mdot
.24286 .2495 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48805 .01613 Mdot
.46195 .05107 Mdot
.37933 .15252 Mdot
.13254 .26168 Mdot
.70914 .11897 Mdot
.51665 .10356 Mdot
.34908 .22342 Mdot
.98757 .21192 Mdot
.64468 .09551 Mdot
.50096 .61673 Mdot
.50306 .6139 Mdot
.50976 .60485 Mdot
.53109 .57622 Mdot
.59875 .49043 Mdot
.80522 .35168 Mdot
.2362 .49867 Mdot
.42934 .56204 Mdot
.51993 .54361 Mdot
.64035 .42972 Mdot
.94504 .37978 Mdot
.50047 .61739 Mdot
.50151 .616 Mdot
.5048 .61155 Mdot
.5153 .59738 Mdot
.54872 .55292 Mdot
.65408 .43137 Mdot
.9561 .39119 Mdot
.32314 .52343 Mdot
.47622 .54539 Mdot
.59377 .4634 Mdot
.84397 .34084 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50767 .60768 Mdot
.52443 .58512 Mdot
.57768 .51593 Mdot
.74288 .36854 Mdot
.14657 .48601 Mdot
.36019 .59958 Mdot
.39006 .07555 Mdot
.26781 .22218 Mdot
.90832 .14181 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00232 Mdot
.49454 .00738 Mdot
.4826 .02347 Mdot
.44463 .07378 Mdot
.32525 .20514 Mdot
.99334 .19896 Mdot
.67141 .06904 Mdot
.55971 .01497 Mdot
.53548 .60039 Mdot
.56403 .54262 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00472 Mdot
.48886 .01504 Mdot
.46453 .04765 Mdot
.38744 .14351 Mdot
.15524 .26566 Mdot
.72538 .11988 Mdot
.53141 .09095 Mdot
.38425 .18904 Mdot
.07837 .2588 Mdot
.65963 .1344 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .0156 Mdot
.4632 .04942 Mdot
.38323 .14822 Mdot
.14341 .26389 Mdot
.71642 .11962 Mdot
.52288 .09848 Mdot
.36353 .21005 Mdot
.02366 .23191 Mdot
.64843 .1134 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49548 .00611 Mdot
.48559 .01946 Mdot
.4541 .06142 Mdot
.35473 .17816 Mdot
.06646 .238 Mdot
.68138 .10395 Mdot
.51318 .09175 Mdot
.36471 .2026 Mdot
.03689 .2365 Mdot
.50069 .6171 Mdot
.50219 .61507 Mdot
.50699 .60859 Mdot
.52226 .58802 Mdot
.57082 .52451 Mdot
.72214 .37922 Mdot
.10854 .47223 Mdot
.34446 .59454 Mdot
.38248 .07582 Mdot
.2598 .22308 Mdot
.89885 .1355 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50652 .60923 Mdot
.52077 .59003 Mdot
.56608 .53051 Mdot
.70769 .38815 Mdot
.07964 .45894 Mdot
.33706 .58496 Mdot
.39057 .06057 Mdot
.29257 .20287 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49659 .00461 Mdot
.48913 .01467 Mdot
.46539 .04651 Mdot
.39014 .14046 Mdot
.16288 .26644 Mdot
.73177 .11986 Mdot
.53782 .08513 Mdot
.40009 .17179 Mdot
.12213 .27422 Mdot
.67844 .14134 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60458 Mdot
.53173 .57535 Mdot
.60079 .48804 Mdot
.81113 .35124 Mdot
.24281 .49864 Mdot
.436 .55638 Mdot
.53575 .52352 Mdot
.68868 .38679 Mdot
.5001 .61791 Mdot
.5003 .61762 Mdot
.50096 .61673 Mdot
.50307 .61388 Mdot
.50979 .60481 Mdot
.53118 .57609 Mdot
.59906 .49007 Mdot
.80611 .3516 Mdot
.23721 .49867 Mdot
.43035 .5612 Mdot
.52231 .54059 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00535 Mdot
.48737 .01705 Mdot
.45979 .05393 Mdot
.37253 .15986 Mdot
.11387 .25665 Mdot
.6986 .11673 Mdot
.50973 .10771 Mdot
.33546 .23449 Mdot
.95604 .19425 Mdot
.64173 .07955 Mdot
.50085 .61688 Mdot
.50271 .61437 Mdot
.50864 .60637 Mdot
.52751 .58099 Mdot
.58745 .50393 Mdot
.77207 .35781 Mdot
.19313 .49603 Mdot
.39053 .5897 Mdot
.43638 .02908 Mdot
.38933 .12361 Mdot
.18933 .26056 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51249 .60117 Mdot
.53977 .56469 Mdot
.62608 .45966 Mdot
.88234 .36025 Mdot
.29945 .50073 Mdot
.48925 .51068 Mdot
.66296 .38466 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49667 .0045 Mdot
.4894 .01432 Mdot
.46622 .0454 Mdot
.39277 .13746 Mdot
.17036 .26691 Mdot
.73849 .11975 Mdot
.54472 .07883 Mdot
.41717 .1522 Mdot
.1709 .2819 Mdot
.4996 .00054 Mdot
.49872 .00174 Mdot
.49591 .00553 Mdot
.48696 .0176 Mdot
.45848 .05566 Mdot
.36842 .16421 Mdot
.10273 .25297 Mdot
.69342 .11465 Mdot
.50792 .10731 Mdot
.33428 .23465 Mdot
.95461 .19314 Mdot
.64211 .07822 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50875 .60621 Mdot
.52788 .5805 Mdot
.58861 .50254 Mdot
.77549 .35688 Mdot
.19804 .49663 Mdot
.39448 .58744 Mdot
.44397 .02029 Mdot
.41115 .09844 Mdot
.49974 .00035 Mdot
.49919 .0011 Mdot
.4974 .00351 Mdot
.49173 .01117 Mdot
.47366 .03547 Mdot
.41626 .10957 Mdot
.23898 .25676 Mdot
.82353 .12468 Mdot
.62179 .02248 Mdot
.58542 .56508 Mdot
.6711 .43529 Mdot
.96679 .40472 Mdot
.50067 .61713 Mdot
.50213 .61516 Mdot
.50678 .60887 Mdot
.52161 .5889 Mdot
.56874 .52714 Mdot
.7158 .38299 Mdot
.0961 .46677 Mdot
.34085 .59092 Mdot
.38473 .07065 Mdot
.27041 .21698 Mdot
.91933 .14536 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60226 Mdot
.53721 .56807 Mdot
.61806 .46839 Mdot
.86019 .35482 Mdot
.28609 .49858 Mdot
.47936 .51766 Mdot
.64177 .40294 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48792 .01631 Mdot
.46153 .05163 Mdot
.37799 .15398 Mdot
.12885 .2608 Mdot
.70687 .11864 Mdot
.5149 .10485 Mdot
.34524 .22676 Mdot
.97834 .20674 Mdot
.64383 .09083 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .00151 Mdot
.49645 .0048 Mdot
.48869 .01527 Mdot
.46397 .04839 Mdot
.38568 .14549 Mdot
.15028 .265 Mdot
.72149 .11982 Mdot
.52762 .09434 Mdot
.37497 .19869 Mdot
.05347 .24734 Mdot
.50052 .61733 Mdot
.50166 .6158 Mdot
.50527 .61091 Mdot
.5168 .59536 Mdot
.55349 .54669 Mdot
.66892 .41788 Mdot
.99278 .41119 Mdot
.32746 .5416 Mdot
.45113 .5862 Mdot
.50265 .58374 Mdot
.55813 .53104 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50484 .61149 Mdot
.51544 .5972 Mdot
.54914 .55237 Mdot
.6554 .43013 Mdot
.95943 .39293 Mdot
.32366 .52495 Mdot
.47428 .54869 Mdot
.58649 .4724 Mdot
.82213 .33975 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48907 .01475 Mdot
.4652 .04676 Mdot
.38955 .14113 Mdot
.1612 .2663 Mdot
.73033 .11988 Mdot
.53636 .08646 Mdot
.39647 .17581 Mdot
.112 .27128 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50224 .61501 Mdot
.50712 .60841 Mdot
.5227 .58744 Mdot
.57219 .52279 Mdot
.72631 .37687 Mdot
.11651 .47549 Mdot
.34715 .5964 Mdot
.38216 .0779 Mdot
.25612 .22533 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49134 .0117 Mdot
.47241 .03715 Mdot
.41229 .11441 Mdot
.22717 .26044 Mdot
.80577 .12186 Mdot
.6086 .02882 Mdot
.56196 .59085 Mdot
.60595 .49973 Mdot
.50025 .6177 Mdot
.50079 .61696 Mdot
.50253 .61462 Mdot
.50805 .60716 Mdot
.52565 .58349 Mdot
.58155 .51115 Mdot
.75448 .36367 Mdot
.16606 .49116 Mdot
.37134 .59786 Mdot
.40398 .06354 Mdot
.30118 .20352 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48303 .0229 Mdot
.44598 .07202 Mdot
.32945 .20156 Mdot
.00331 .20463 Mdot
.67221 .07436 Mdot
.55189 .02711 Mdot
.50803 .01967 Mdot
.4762 .04165 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.49331 .00904 Mdot
.47868 .02875 Mdot
.43215 .08976 Mdot
.28692 .23335 Mdot
.90935 .15378 Mdot
.66052 .02895 Mdot
.61368 .55034 Mdot
.72321 .40488 Mdot
.06811 .46611 Mdot
.50037 .61754 Mdot
.50118 .61645 Mdot
.50375 .61297 Mdot
.51194 .60192 Mdot
.53802 .567 Mdot
.62058 .46561 Mdot
.86721 .3563 Mdot
.29071 .49905 Mdot
.48323 .51457 Mdot
.65065 .39485 Mdot
.01177 .40575 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48703 .01751 Mdot
.45869 .05538 Mdot
.36908 .16352 Mdot
.10449 .25358 Mdot
.69419 .11502 Mdot
.50809 .10752 Mdot
.33412 .23493 Mdot
.95399 .19287 Mdot
.64192 .07806 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00336 Mdot
.49209 .01069 Mdot
.47479 .03396 Mdot
.41984 .10517 Mdot
.24967 .25272 Mdot
.84076 .12852 Mdot
.63281 .0192 Mdot
.60175 .5492 Mdot
.71312 .4056 Mdot
.05683 .45718 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50363 .61313 Mdot
.51158 .6024 Mdot
.53687 .56853 Mdot
.61696 .4696 Mdot
.85714 .35424 Mdot
.28396 .49844 Mdot
.47747 .51925 Mdot
.6373 .40718 Mdot
.97847 .38728 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48933 .01441 Mdot
.46601 .04568 Mdot
.3921 .13822 Mdot
.16845 .26682 Mdot
.73673 .11979 Mdot
.54291 .08049 Mdot
.41268 .15744 Mdot
.15794 .28098 Mdot
.7033 .13974 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51311 .60034 Mdot
.54174 .56209 Mdot
.63226 .4531 Mdot
.89913 .36573 Mdot
.30737 .50379 Mdot
.49222 .511 Mdot
.66541 .3838 Mdot
.04441 .42444 Mdot
.35765 .5395 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49013 .01333 Mdot
.46857 .04227 Mdot
.40017 .12887 Mdot
.19165 .26661 Mdot
.76027 .11937 Mdot
.56712 .05898 Mdot
.47169 .08508 Mdot
.33402 .21254 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48895 .01492 Mdot
.4648 .04729 Mdot
.3883 .14255 Mdot
.15765 .26594 Mdot
.72735 .11989 Mdot
.53336 .08918 Mdot
.38906 .1839 Mdot
.0915 .26413 Mdot
.66413 .13755 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50611 .60978 Mdot
.51947 .59178 Mdot
.56195 .53578 Mdot
.69504 .39695 Mdot
.05277 .44498 Mdot
.33279 .57301 Mdot
.40564 .03741 Mdot
.34511 .15939 Mdot
.08722 .23625 Mdot
.50125 .61634 Mdot
.50398 .61265 Mdot
.51269 .6009 Mdot
.54042 .56383 Mdot
.62812 .45747 Mdot
.88792 .36194 Mdot
.30228 .5016 Mdot
.49067 .51024 Mdot
.66508 .38321 Mdot
.04504 .42441 Mdot
.35834 .53907 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.50761 .60775 Mdot
.52424 .58537 Mdot
.5771 .51666 Mdot
.74113 .36934 Mdot
.14353 .48508 Mdot
.35865 .59956 Mdot
.38854 .07661 Mdot
.26457 .22354 Mdot
.90288 .13899 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51067 .60362 Mdot
.53399 .57235 Mdot
.6079 .47981 Mdot
.83154 .35122 Mdot
.26327 .49825 Mdot
.45708 .53755 Mdot
.58731 .46061 Mdot
.84202 .33705 Mdot
.29666 .4783 Mdot
.50126 .61633 Mdot
.50401 .61261 Mdot
.51278 .60078 Mdot
.54071 .56345 Mdot
.62902 .45652 Mdot
.89037 .36273 Mdot
.30346 .50203 Mdot
.49116 .51022 Mdot
.6656 .38294 Mdot
.046 .42499 Mdot
.35835 .53964 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49391 .00823 Mdot
.48059 .02618 Mdot
.43822 .08203 Mdot
.30549 .2207 Mdot
.9484 .17369 Mdot
.66736 .0456 Mdot
.59358 .58179 Mdot
.65223 .46122 Mdot
.50061 .6172 Mdot
.50196 .61539 Mdot
.50624 .60961 Mdot
.51987 .59124 Mdot
.56322 .53416 Mdot
.69894 .39414 Mdot
.0612 .44949 Mdot
.33391 .577 Mdot
.4003 .04547 Mdot
.32673 .17619 Mdot
.04165 .21436 Mdot
.50008 .61793 Mdot
.50024 .61771 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.50779 .60751 Mdot
.52483 .58458 Mdot
.57895 .51436 Mdot
.74669 .36685 Mdot
.15312 .48789 Mdot
.3637 .59936 Mdot
.39391 .07256 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00252 Mdot
.49405 .00803 Mdot
.48106 .02555 Mdot
.43971 .08011 Mdot
.31009 .21726 Mdot
.95855 .17927 Mdot
.66848 .05066 Mdot
.58651 .59238 Mdot
.62802 .48609 Mdot
.84151 .36227 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56788 .52824 Mdot
.71317 .38462 Mdot
.09084 .46434 Mdot
.33953 .58915 Mdot
.38626 .06781 Mdot
.27655 .2133 Mdot
.93142 .15167 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48793 .0163 Mdot
.46156 .05159 Mdot
.37809 .15387 Mdot
.12911 .26087 Mdot
.70702 .11867 Mdot
.51502 .10477 Mdot
.3455 .22654 Mdot
.97895 .20708 Mdot
.50118 .61644 Mdot
.50376 .61295 Mdot
.51199 .60185 Mdot
.53817 .5668 Mdot
.62106 .46509 Mdot
.86854 .35661 Mdot
.29153 .49916 Mdot
.48388 .51407 Mdot
.6521 .39357 Mdot
.01528 .40772 Mdot
.35558 .52397 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51023 .60422 Mdot
.53257 .57424 Mdot
.60344 .48495 Mdot
.81877 .35097 Mdot
.25089 .49851 Mdot
.44429 .54911 Mdot
.5558 .49843 Mdot
.74933 .35089 Mdot
.18158 .48501 Mdot
.49971 .00039 Mdot
.49909 .00124 Mdot
.49709 .00394 Mdot
.49072 .01254 Mdot
.47043 .0398 Mdot
.40603 .12193 Mdot
.20874 .26455 Mdot
.78069 .11974 Mdot
.58695 .04308 Mdot
.51724 .02713 Mdot
.47334 .05173 Mdot
.38964 .14604 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00505 Mdot
.48808 .01609 Mdot
.46205 .05094 Mdot
.37964 .15218 Mdot
.1334 .26187 Mdot
.70968 .11903 Mdot
.51708 .10323 Mdot
.35005 .22257 Mdot
.98993 .21324 Mdot
.6449 .09671 Mdot
.50051 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51665 .59557 Mdot
.553 .54734 Mdot
.66738 .41924 Mdot
.98904 .40908 Mdot
.32713 .53964 Mdot
.45398 .58171 Mdot
.51275 .5699 Mdot
.59063 .49036 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49303 .00942 Mdot
.47778 .02995 Mdot
.42933 .09334 Mdot
.2783 .23855 Mdot
.89232 .14617 Mdot
.65581 .02372 Mdot
.61743 .5425 Mdot
.73965 .39527 Mdot
.1001 .48206 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00414 Mdot
.49023 .01319 Mdot
.4689 .04184 Mdot
.4012 .12766 Mdot
.19464 .26637 Mdot
.76364 .11937 Mdot
.5705 .05612 Mdot
.47969 .0749 Mdot
.3585 .18946 Mdot
.05195 .23677 Mdot
.50093 .61678 Mdot
.50297 .61403 Mdot
.50945 .60527 Mdot
.53011 .57752 Mdot
.59565 .49409 Mdot
.79619 .35272 Mdot
.22548 .49852 Mdot
.41886 .57052 Mdot
.49574 .57446 Mdot
.56624 .51481 Mdot
.73325 .36809 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48814 .01602 Mdot
.46222 .05071 Mdot
.38018 .15159 Mdot
.1349 .2622 Mdot
.71065 .11915 Mdot
.51786 .10262 Mdot
.35182 .22099 Mdot
.99425 .21566 Mdot
.64531 .09891 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00414 Mdot
.49024 .01318 Mdot
.46892 .0418 Mdot
.40129 .12756 Mdot
.1949 .26635 Mdot
.76394 .11937 Mdot
.5708 .05588 Mdot
.48039 .07401 Mdot
.36065 .18731 Mdot
.05758 .23953 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .00399 Mdot
.49058 .01272 Mdot
.47 .04037 Mdot
.40468 .12355 Mdot
.20478 .26518 Mdot
.77571 .11955 Mdot
.58227 .04663 Mdot
.50682 .04031 Mdot
.44161 .09323 Mdot
.29075 .23597 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49712 .0039 Mdot
.49081 .01241 Mdot
.47073 .03939 Mdot
.407 .12078 Mdot
.21157 .26405 Mdot
.78433 .11992 Mdot
.59029 .04063 Mdot
.52455 .01797 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51264 .60096 Mdot
.54026 .56404 Mdot
.62763 .458 Mdot
.88657 .36152 Mdot
.30161 .50138 Mdot
.49037 .5103 Mdot
.66469 .38345 Mdot
.04426 .42395 Mdot
.35829 .53864 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49231 .01039 Mdot
.47551 .033 Mdot
.42211 .10236 Mdot
.25649 .24978 Mdot
.85234 .1317 Mdot
.63924 .01847 Mdot
.60936 .54291 Mdot
.73092 .39642 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49134 .01169 Mdot
.47242 .03713 Mdot
.41234 .11435 Mdot
.22733 .2604 Mdot
.806 .12189 Mdot
.60877 .02872 Mdot
.5623 .59046 Mdot
.60692 .49863 Mdot
.80011 .35834 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50494 .61136 Mdot
.51573 .5968 Mdot
.55009 .55112 Mdot
.65836 .42737 Mdot
.96686 .39687 Mdot
.32471 .52845 Mdot
.46966 .55641 Mdot
.56937 .49412 Mdot
.76987 .34772 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48852 .0155 Mdot
.46343 .04911 Mdot
.38397 .14739 Mdot
.14549 .26425 Mdot
.71792 .11969 Mdot
.52425 .0973 Mdot
.36681 .20686 Mdot
.03211 .23642 Mdot
.64957 .11729 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49445 .0075 Mdot
.48232 .02386 Mdot
.44372 .07495 Mdot
.32245 .20747 Mdot
.98675 .1952 Mdot
.67091 .0655 Mdot
.56492 .00698 Mdot
.55363 .57623 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58922 Mdot
.568 .52808 Mdot
.71355 .38438 Mdot
.09161 .4647 Mdot
.33971 .58942 Mdot
.38602 .06824 Mdot
.2756 .21389 Mdot
.92952 .15066 Mdot
.5012 .61642 Mdot
.50382 .61288 Mdot
.51216 .60162 Mdot
.53871 .56608 Mdot
.62277 .46323 Mdot
.87325 .35776 Mdot
.29439 .4996 Mdot
.48601 .51255 Mdot
.65669 .38964 Mdot
.02624 .41386 Mdot
.3566 .52952 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51222 .60153 Mdot
.53892 .56581 Mdot
.62342 .46252 Mdot
.87505 .35822 Mdot
.29544 .4998 Mdot
.48675 .51207 Mdot
.65821 .38839 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.4971 .00392 Mdot
.49075 .01249 Mdot
.47054 .03965 Mdot
.40638 .12152 Mdot
.20975 .26438 Mdot
.78198 .1198 Mdot
.58814 .0422 Mdot
.51985 .02384 Mdot
.48128 .04116 Mdot
.41467 .11653 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48656 .01815 Mdot
.4572 .05735 Mdot
.36441 .16838 Mdot
.09196 .24897 Mdot
.68912 .11209 Mdot
.50775 .1049 Mdot
.33802 .23045 Mdot
.96514 .19839 Mdot
.64413 .0823 Mdot
.50025 .6177 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50794 .60731 Mdot
.52528 .58398 Mdot
.58039 .51258 Mdot
.75102 .36504 Mdot
.16037 .4898 Mdot
.36786 .5987 Mdot
.39914 .06804 Mdot
.28906 .21116 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50267 .61442 Mdot
.50851 .60653 Mdot
.52712 .58151 Mdot
.58621 .50544 Mdot
.76839 .35888 Mdot
.18771 .49527 Mdot
.38635 .5919 Mdot
.42863 .03784 Mdot
.36741 .14702 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00814 Mdot
.48081 .02588 Mdot
.43893 .08112 Mdot
.30768 .21908 Mdot
.95321 .17632 Mdot
.66792 .04797 Mdot
.5903 .58671 Mdot
.64097 .47246 Mdot
.87652 .36913 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60548 Mdot
.52961 .57818 Mdot
.59409 .49595 Mdot
.79162 .35342 Mdot
.21977 .49832 Mdot
.41348 .57463 Mdot
.48371 .5897 Mdot
.52955 .56246 Mdot
.61947 .46181 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50967 .60497 Mdot
.53081 .57659 Mdot
.59787 .49147 Mdot
.80264 .35193 Mdot
.23321 .49865 Mdot
.42638 .5645 Mdot
.513 .55246 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.5109 .60331 Mdot
.53472 .57138 Mdot
.6102 .47719 Mdot
.83809 .35167 Mdot
.26907 .49816 Mdot
.46302 .53213 Mdot
.60201 .44391 Mdot
.88375 .34547 Mdot
.32477 .47703 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.4875 .01688 Mdot
.46018 .05341 Mdot
.37377 .15854 Mdot
.11723 .25766 Mdot
.70033 .11725 Mdot
.51062 .10741 Mdot
.33684 .23353 Mdot
.95898 .19592 Mdot
.64197 .08108 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50561 .61046 Mdot
.51787 .59393 Mdot
.55687 .54233 Mdot
.67936 .40908 Mdot
.01746 .42523 Mdot
.32942 .55478 Mdot
.43176 .61612 Mdot
.43486 .0568 Mdot
.34295 .17989 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50495 .61134 Mdot
.51579 .59673 Mdot
.55026 .55091 Mdot
.65887 .4269 Mdot
.96813 .39755 Mdot
.32488 .52907 Mdot
.46883 .55778 Mdot
.56633 .49805 Mdot
.76048 .35082 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.50931 .60546 Mdot
.52965 .57813 Mdot
.59421 .49581 Mdot
.79198 .35336 Mdot
.22022 .49833 Mdot
.4139 .57432 Mdot
.48464 .58854 Mdot
.53237 .55874 Mdot
.62831 .45226 Mdot
.50105 .61661 Mdot
.50336 .61349 Mdot
.51071 .60358 Mdot
.5341 .5722 Mdot
.60826 .47941 Mdot
.83256 .35127 Mdot
.26419 .49823 Mdot
.45803 .53669 Mdot
.58966 .45789 Mdot
.84877 .33786 Mdot
.3021 .47757 Mdot
.50015 .61782 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.50501 .61126 Mdot
.51596 .59649 Mdot
.55082 .55017 Mdot
.66063 .42528 Mdot
.97251 .39992 Mdot
.32542 .53121 Mdot
.4659 .56258 Mdot
.55564 .51204 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01026 Mdot
.47581 .0326 Mdot
.42306 .10118 Mdot
.25936 .24846 Mdot
.85733 .13322 Mdot
.64178 .01849 Mdot
.61186 .54116 Mdot
.73625 .39416 Mdot
.09848 .47975 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51012 .60437 Mdot
.53223 .57469 Mdot
.60236 .4862 Mdot
.81567 .35104 Mdot
.24767 .49857 Mdot
.44097 .55205 Mdot
.54773 .50847 Mdot
.72501 .36274 Mdot
.13809 .47529 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.4892 .01459 Mdot
.46559 .04625 Mdot
.39076 .13975 Mdot
.16464 .26658 Mdot
.7333 .11984 Mdot
.53939 .0837 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00436 Mdot
.48973 .01387 Mdot
.46728 .04399 Mdot
.39611 .1336 Mdot
.17994 .26708 Mdot
.7478 .11955 Mdot
.55436 .07013 Mdot
.44089 .12367 Mdot
.24079 .27097 Mdot
.50009 .61791 Mdot
.50029 .61764 Mdot
.50092 .61679 Mdot
.50294 .61407 Mdot
.50935 .6054 Mdot
.52979 .57795 Mdot
.59465 .49528 Mdot
.79327 .35316 Mdot
.22185 .4984 Mdot
.41543 .57317 Mdot
.48802 .58426 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60703 Mdot
.52596 .58307 Mdot
.58252 .50995 Mdot
.7574 .36257 Mdot
.17075 .4922 Mdot
.37436 .59695 Mdot
.40848 .05915 Mdot
.31277 .19537 Mdot
.99666 .19227 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01626 Mdot
.46164 .05148 Mdot
.37833 .15361 Mdot
.12979 .26103 Mdot
.70744 .11873 Mdot
.51533 .10454 Mdot
.34617 .22596 Mdot
.98055 .20798 Mdot
.64403 .09195 Mdot
.50035 .61757 Mdot
.50111 .61654 Mdot
.50352 .61328 Mdot
.51122 .60289 Mdot
.53573 .57004 Mdot
.61339 .47359 Mdot
.84709 .35266 Mdot
.27647 .49817 Mdot
.47041 .52545 Mdot
.62022 .4243 Mdot
.93369 .36459 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60848 Mdot
.52252 .58767 Mdot
.57164 .52348 Mdot
.72464 .3778 Mdot
.11334 .47422 Mdot
.34604 .5957 Mdot
.38218 .07719 Mdot
.25728 .22458 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47926 .02797 Mdot
.43401 .0874 Mdot
.29259 .2297 Mdot
.92093 .15937 Mdot
.66306 .0333 Mdot
.60917 .55788 Mdot
.7065 .41581 Mdot
.03371 .44683 Mdot
.50105 .61662 Mdot
.50335 .61351 Mdot
.51066 .60364 Mdot
.53395 .57241 Mdot
.60777 .47997 Mdot
.83116 .3512 Mdot
.26291 .49825 Mdot
.45672 .53788 Mdot
.58641 .46165 Mdot
.83944 .3368 Mdot
.29448 .47862 Mdot
.50035 .61757 Mdot
.5011 .61655 Mdot
.50351 .61329 Mdot
.51118 .60294 Mdot
.5356 .57021 Mdot
.61299 .47404 Mdot
.84598 .35252 Mdot
.27559 .49816 Mdot
.46955 .52622 Mdot
.6181 .42651 Mdot
.928 .36201 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51318 .60024 Mdot
.54198 .56177 Mdot
.63301 .45233 Mdot
.90112 .36645 Mdot
.30819 .50424 Mdot
.49232 .51136 Mdot
.66493 .38439 Mdot
.04297 .42374 Mdot
.35734 .53899 Mdot
.50042 .61747 Mdot
.50134 .61622 Mdot
.50427 .61226 Mdot
.51361 .59966 Mdot
.54334 .55998 Mdot
.63727 .44792 Mdot
.91252 .37084 Mdot
.31248 .50717 Mdot
.49187 .5147 Mdot
.65906 .3906 Mdot
.02706 .41556 Mdot
.50032 .6176 Mdot
.50101 .61667 Mdot
.50323 .61367 Mdot
.51028 .60415 Mdot
.53275 .574 Mdot
.60399 .48431 Mdot
.82036 .35095 Mdot
.25251 .49848 Mdot
.44596 .54762 Mdot
.55988 .49341 Mdot
.76153 .34625 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50767 .60768 Mdot
.52442 .58513 Mdot
.57766 .51595 Mdot
.74283 .36856 Mdot
.14649 .48598 Mdot
.36015 .59958 Mdot
.39001 .07559 Mdot
.26771 .22222 Mdot
.90815 .14172 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00527 Mdot
.48757 .01679 Mdot
.46041 .05311 Mdot
.37447 .15779 Mdot
.11916 .25822 Mdot
.70135 .11752 Mdot
.5112 .10714 Mdot
.33784 .23278 Mdot
.50067 .61713 Mdot
.50214 .61514 Mdot
.50682 .60881 Mdot
.52174 .58872 Mdot
.56917 .5266 Mdot
.71712 .38219 Mdot
.09873 .46796 Mdot
.34156 .59175 Mdot
.38408 .07193 Mdot
.26771 .21856 Mdot
.91407 .14271 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.52311 .58689 Mdot
.5735 .52115 Mdot
.73025 .37474 Mdot
.1239 .47835 Mdot
.34991 .59776 Mdot
.38271 .07889 Mdot
.25507 .22636 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00483 Mdot
.4886 .01539 Mdot
.46371 .04874 Mdot
.38484 .14643 Mdot
.14792 .26465 Mdot
.71971 .11977 Mdot
.52592 .09584 Mdot
.37085 .20286 Mdot
.04262 .2419 Mdot
.65122 .12187 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50727 .60821 Mdot
.52317 .5868 Mdot
.57371 .52088 Mdot
.7309 .3744 Mdot
.12511 .4788 Mdot
.35039 .59795 Mdot
.38288 .07896 Mdot
.25512 .22643 Mdot
.88876 .13149 Mdot
.50108 .61657 Mdot
.50344 .61338 Mdot
.51097 .60322 Mdot
.53494 .57109 Mdot
.6109 .4764 Mdot
.84006 .35186 Mdot
.27075 .49815 Mdot
.46472 .53059 Mdot
.60621 .43927 Mdot
.89546 .34918 Mdot
.33048 .47826 Mdot
.50049 .61737 Mdot
.50158 .6159 Mdot
.50502 .61125 Mdot
.516 .59644 Mdot
.55095 .55 Mdot
.66103 .42492 Mdot
.9735 .40046 Mdot
.32554 .5317 Mdot
.46523 .56368 Mdot
.55317 .5153 Mdot
.71939 .37048 Mdot
.50005 .61797 Mdot
.50015 .61783 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50493 .61137 Mdot
.5157 .59684 Mdot
.55 .55125 Mdot
.65806 .42765 Mdot
.96611 .39646 Mdot
.32461 .52809 Mdot
.47015 .5556 Mdot
.50014 .61785 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.50451 .61195 Mdot
.51436 .59865 Mdot
.54571 .55686 Mdot
.6447 .44044 Mdot
.93205 .37935 Mdot
.31825 .51353 Mdot
.48735 .52524 Mdot
.63748 .41306 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00534 Mdot
.4874 .01702 Mdot
.45987 .05383 Mdot
.37277 .15961 Mdot
.11451 .25684 Mdot
.69893 .11683 Mdot
.50989 .10767 Mdot
.33568 .23434 Mdot
.95651 .19452 Mdot
.64176 .0798 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.4919 .01094 Mdot
.47421 .03474 Mdot
.418 .10744 Mdot
.24415 .25489 Mdot
.83174 .12638 Mdot
.62726 .02058 Mdot
.59396 .55648 Mdot
.69356 .41811 Mdot
.01704 .43388 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00413 Mdot
.49026 .01316 Mdot
.46896 .04175 Mdot
.40141 .12742 Mdot
.19524 .26632 Mdot
.76433 .11937 Mdot
.57119 .05555 Mdot
.4813 .07285 Mdot
.36343 .18448 Mdot
.06494 .24302 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45873 .05533 Mdot
.3692 .16339 Mdot
.10482 .25369 Mdot
.69433 .11508 Mdot
.50813 .10755 Mdot
.3341 .23497 Mdot
.95392 .19284 Mdot
.64189 .07805 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.4927 .00986 Mdot
.47675 .03133 Mdot
.42606 .09744 Mdot
.2684 .244 Mdot
.8736 .13876 Mdot
.64909 .01989 Mdot
.61691 .53903 Mdot
.74474 .39156 Mdot
.11118 .48645 Mdot
.49971 .0004 Mdot
.49906 .00126 Mdot
.49702 .00403 Mdot
.4905 .01284 Mdot
.46973 .04073 Mdot
.40382 .12456 Mdot
.20227 .26552 Mdot
.77264 .11947 Mdot
.57934 .04893 Mdot
.50017 .04878 Mdot
.42124 .11884 Mdot
.22895 .2651 Mdot
.50002 .61801 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50191 .61545 Mdot
.50609 .60981 Mdot
.5194 .59187 Mdot
.56174 .53606 Mdot
.69438 .39743 Mdot
.05133 .44419 Mdot
.33261 .5723 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49827 .00233 Mdot
.4945 .00743 Mdot
.48248 .02364 Mdot
.44424 .07428 Mdot
.32404 .20614 Mdot
.9905 .19734 Mdot
.67119 .06751 Mdot
.56195 .01152 Mdot
.54331 .58989 Mdot
.50125 .61635 Mdot
.50398 .61266 Mdot
.51267 .60093 Mdot
.54034 .56394 Mdot
.62787 .45775 Mdot
.88722 .36172 Mdot
.30193 .50148 Mdot
.49052 .51027 Mdot
.66489 .38332 Mdot
.04466 .42418 Mdot
.35832 .53886 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00284 Mdot
.49329 .00906 Mdot
.47863 .02881 Mdot
.43201 .08995 Mdot
.28647 .23363 Mdot
.90845 .15336 Mdot
.6603 .02864 Mdot
.61396 .54982 Mdot
.72434 .40419 Mdot
.07034 .4673 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51013 .60435 Mdot
.53228 .57463 Mdot
.6025 .48604 Mdot
.81607 .35103 Mdot
.24809 .49856 Mdot
.4414 .55167 Mdot
.54878 .50715 Mdot
.7282 .36098 Mdot
.14412 .47707 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49855 .00196 Mdot
.49537 .00626 Mdot
.48524 .01992 Mdot
.45301 .06285 Mdot
.35131 .1815 Mdot
.05763 .23377 Mdot
.67938 .10051 Mdot
.51675 .08501 Mdot
.37921 .18655 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00215 Mdot
.49494 .00683 Mdot
.48388 .02175 Mdot
.44869 .0685 Mdot
.33785 .19413 Mdot
.02374 .21606 Mdot
.67415 .08496 Mdot
.53669 .05125 Mdot
.45377 .09351 Mdot
.30247 .2331 Mdot
.50035 .61757 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .6029 Mdot
.53571 .57007 Mdot
.61331 .47368 Mdot
.84688 .35264 Mdot
.2763 .49817 Mdot
.47024 .5256 Mdot
.61981 .42472 Mdot
.9326 .36409 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00466 Mdot
.48901 .01484 Mdot
.46501 .04701 Mdot
.38894 .14182 Mdot
.15948 .26613 Mdot
.72887 .11989 Mdot
.53489 .0878 Mdot
.39282 .17982 Mdot
.10187 .26794 Mdot
.66833 .1394 Mdot
.5013 .61627 Mdot
.50415 .61243 Mdot
.51322 .60018 Mdot
.54211 .5616 Mdot
.63343 .45189 Mdot
.90226 .36687 Mdot
.30866 .50451 Mdot
.49235 .51159 Mdot
.66457 .3848 Mdot
.04196 .42325 Mdot
.35713 .53861 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.505 .61128 Mdot
.51594 .59653 Mdot
.55074 .55028 Mdot
.66036 .42553 Mdot
.97184 .39956 Mdot
.32534 .53088 Mdot
.46636 .56184 Mdot
.55729 .50987 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49617 .00518 Mdot
.48779 .01649 Mdot
.46111 .05218 Mdot
.37668 .15541 Mdot
.12523 .25988 Mdot
.70472 .11827 Mdot
.51336 .1059 Mdot
.34202 .22946 Mdot
.97074 .20249 Mdot
.64311 .08699 Mdot
.4996 .00054 Mdot
.49871 .00174 Mdot
.49591 .00553 Mdot
.48696 .01761 Mdot
.45846 .05568 Mdot
.36836 .16427 Mdot
.10257 .25291 Mdot
.69335 .11461 Mdot
.5079 .10729 Mdot
.3343 .23462 Mdot
.95468 .19317 Mdot
.64212 .07824 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00318 Mdot
.4925 .01014 Mdot
.4761 .03221 Mdot
.42398 .10004 Mdot
.26211 .24716 Mdot
.8622 .13478 Mdot
.64412 .0187 Mdot
.61385 .53996 Mdot
.74017 .3927 Mdot
.10477 .48296 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50405 .61256 Mdot
.51292 .6006 Mdot
.54113 .56289 Mdot
.63035 .45511 Mdot
.89396 .36392 Mdot
.30512 .50271 Mdot
.49172 .51038 Mdot
.66591 .38295 Mdot
.04628 .42526 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01627 Mdot
.46163 .05149 Mdot
.37832 .15363 Mdot
.12975 .26102 Mdot
.70741 .11873 Mdot
.5153 .10456 Mdot
.34612 .226 Mdot
.98044 .20792 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01062 Mdot
.47495 .03374 Mdot
.42035 .10454 Mdot
.25121 .25208 Mdot
.84334 .12919 Mdot
.50045 .61743 Mdot
.50142 .61611 Mdot
.50454 .61191 Mdot
.51445 .59853 Mdot
.54602 .55646 Mdot
.64565 .43951 Mdot
.93451 .38049 Mdot
.31886 .51444 Mdot
.48647 .52697 Mdot
.63382 .41702 Mdot
.95907 .37949 Mdot
.50032 .61761 Mdot
.50101 .61668 Mdot
.5032 .61371 Mdot
.51021 .60425 Mdot
.53251 .57433 Mdot
.60322 .4852 Mdot
.81815 .35098 Mdot
.25026 .49852 Mdot
.44363 .5497 Mdot
.5542 .50042 Mdot
.74451 .35296 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49086 .01234 Mdot
.47089 .03918 Mdot
.4075 .12019 Mdot
.21303 .26377 Mdot
.78624 .12003 Mdot
.59202 .0394 Mdot
.52827 .01332 Mdot
.50671 .0071 Mdot
.49522 .01153 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00511 Mdot
.48794 .01629 Mdot
.46159 .05155 Mdot
.37818 .15378 Mdot
.12936 .26093 Mdot
.70718 .11869 Mdot
.51513 .10469 Mdot
.34574 .22633 Mdot
.97953 .20741 Mdot
.5004 .6175 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51288 .60064 Mdot
.54102 .56303 Mdot
.63001 .45547 Mdot
.89304 .36361 Mdot
.3047 .50253 Mdot
.4916 .51032 Mdot
.66589 .3829 Mdot
.04634 .42525 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00399 Mdot
.49059 .01271 Mdot
.47003 .04033 Mdot
.40476 .12345 Mdot
.20502 .26514 Mdot
.77602 .11956 Mdot
.58256 .04641 Mdot
.50747 .03949 Mdot
.44358 .0907 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.48691 .01767 Mdot
.45832 .05587 Mdot
.36792 .16473 Mdot
.10138 .25249 Mdot
.69285 .11436 Mdot
.50781 .10712 Mdot
.33449 .23436 Mdot
.95529 .19345 Mdot
.64228 .07843 Mdot
.50093 .61677 Mdot
.50298 .61401 Mdot
.50948 .60523 Mdot
.5302 .57741 Mdot
.59593 .49376 Mdot
.79702 .3526 Mdot
.22649 .49854 Mdot
.41983 .56976 Mdot
.49794 .57166 Mdot
.57297 .50636 Mdot
.75366 .35885 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49231 .01038 Mdot
.47552 .03299 Mdot
.42215 .10232 Mdot
.25659 .24973 Mdot
.85252 .13175 Mdot
.63933 .01846 Mdot
.60946 .54284 Mdot
.73113 .39633 Mdot
.08986 .47527 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.4931 .00932 Mdot
.47801 .02964 Mdot
.43005 .09242 Mdot
.2805 .23727 Mdot
.89659 .14801 Mdot
.65711 .02489 Mdot
.61684 .54408 Mdot
.73651 .39706 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50707 .60848 Mdot
.52253 .58766 Mdot
.57168 .52343 Mdot
.72475 .37774 Mdot
.11356 .4743 Mdot
.34612 .59575 Mdot
.38217 .07724 Mdot
.25719 .22464 Mdot
.89372 .13327 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60075 Mdot
.54076 .56338 Mdot
.6292 .45633 Mdot
.89084 .36288 Mdot
.30368 .50212 Mdot
.49124 .51023 Mdot
.66568 .38291 Mdot
.04611 .42506 Mdot
.35834 .53972 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50722 .60828 Mdot
.52301 .58702 Mdot
.57319 .52154 Mdot
.72933 .37523 Mdot
.12219 .4777 Mdot
.34925 .59748 Mdot
.38251 .07874 Mdot
.2551 .22621 Mdot
.88909 .13151 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49669 .00448 Mdot
.48944 .01426 Mdot
.46636 .04521 Mdot
.3932 .13695 Mdot
.17161 .26696 Mdot
.73966 .11973 Mdot
.54593 .07773 Mdot
.42016 .14868 Mdot
.17959 .28202 Mdot
.72327 .13655 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46847 .04241 Mdot
.39985 .12924 Mdot
.19073 .26668 Mdot
.75924 .11938 Mdot
.56608 .05987 Mdot
.46921 .08823 Mdot
.32646 .21907 Mdot
.97199 .19324 Mdot
.50102 .61666 Mdot
.50324 .61365 Mdot
.51033 .60408 Mdot
.53291 .57379 Mdot
.6045 .48372 Mdot
.82183 .35095 Mdot
.25398 .49845 Mdot
.44748 .54626 Mdot
.56362 .48884 Mdot
.77266 .34279 Mdot
.21802 .48736 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50745 .60797 Mdot
.52374 .58604 Mdot
.5755 .51864 Mdot
.73632 .37164 Mdot
.135 .48231 Mdot
.3546 .59913 Mdot
.38519 .07853 Mdot
.25812 .22589 Mdot
.89263 .13373 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50132 .61625 Mdot
.50421 .61234 Mdot
.51343 .59991 Mdot
.54275 .56075 Mdot
.63545 .4498 Mdot
.90766 .36891 Mdot
.31074 .50584 Mdot
.49227 .51301 Mdot
.6622 .38736 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00472 Mdot
.48886 .01504 Mdot
.46452 .04767 Mdot
.38739 .14357 Mdot
.15509 .26565 Mdot
.72526 .11988 Mdot
.53129 .09106 Mdot
.38395 .18936 Mdot
.07756 .25845 Mdot
.65938 .13418 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50992 .60463 Mdot
.53161 .57552 Mdot
.60039 .4885 Mdot
.80998 .35131 Mdot
.24155 .49865 Mdot
.43472 .55749 Mdot
.53268 .5274 Mdot
.67932 .39417 Mdot
.04154 .43225 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50478 .61157 Mdot
.51524 .59746 Mdot
.54853 .55316 Mdot
.6535 .43192 Mdot
.95464 .39043 Mdot
.3229 .52277 Mdot
.47705 .54397 Mdot
.59689 .45959 Mdot
.50106 .61661 Mdot
.50337 .61349 Mdot
.51072 .60355 Mdot
.53415 .57214 Mdot
.60842 .47922 Mdot
.83302 .3513 Mdot
.2646 .49822 Mdot
.45846 .5363 Mdot
.59071 .45668 Mdot
.85179 .3383 Mdot
.30441 .4773 Mdot
.5006 .61722 Mdot
.50191 .61545 Mdot
.50609 .6098 Mdot
.51941 .59185 Mdot
.56178 .536 Mdot
.69451 .39733 Mdot
.05161 .44435 Mdot
.33264 .57244 Mdot
.40641 .03625 Mdot
.34775 .15684 Mdot
.09399 .23899 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00467 Mdot
.489 .01486 Mdot
.46495 .04709 Mdot
.38876 .14203 Mdot
.15895 .26608 Mdot
.72843 .11989 Mdot
.53445 .0882 Mdot
.39173 .18101 Mdot
.09885 .26687 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51042 .60396 Mdot
.53319 .57342 Mdot
.60537 .48272 Mdot
.82432 .35097 Mdot
.25644 .49839 Mdot
.45003 .54396 Mdot
.56988 .48124 Mdot
.79121 .33862 Mdot
.24331 .48603 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49814 .00252 Mdot
.49407 .00802 Mdot
.48109 .0255 Mdot
.43983 .07996 Mdot
.31045 .21699 Mdot
.95936 .17972 Mdot
.66857 .05107 Mdot
.58593 .59326 Mdot
.62602 .48826 Mdot
.83599 .36174 Mdot
.50018 .6178 Mdot
.50056 .61728 Mdot
.50178 .61563 Mdot
.50567 .61038 Mdot
.51806 .59368 Mdot
.55747 .54155 Mdot
.68123 .40757 Mdot
.02177 .42768 Mdot
.32976 .55709 Mdot
.42838 .00323 Mdot
.42315 .07174 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00556 Mdot
.48688 .01772 Mdot
.45821 .05601 Mdot
.36759 .16508 Mdot
.10048 .25217 Mdot
.69247 .11416 Mdot
.50775 .10697 Mdot
.33467 .23413 Mdot
.95584 .19371 Mdot
.64241 .07862 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49292 .00956 Mdot
.47745 .03039 Mdot
.42828 .09466 Mdot
.27512 .24037 Mdot
.8862 .14363 Mdot
.6538 .02223 Mdot
.61784 .54073 Mdot
.74291 .39333 Mdot
.10649 .48485 Mdot
.50103 .61664 Mdot
.50329 .61359 Mdot
.51047 .60389 Mdot
.53336 .57319 Mdot
.60591 .48209 Mdot
.82587 .351 Mdot
.25794 .49836 Mdot
.45158 .54256 Mdot
.57371 .47664 Mdot
.80248 .33705 Mdot
.25713 .48444 Mdot
.50014 .61785 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.5045 .61195 Mdot
.51435 .59867 Mdot
.54569 .55689 Mdot
.64462 .44052 Mdot
.93185 .37925 Mdot
.3182 .51345 Mdot
.48742 .52511 Mdot
.63778 .41275 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49085 .01236 Mdot
.47086 .03922 Mdot
.4074 .1203 Mdot
.21275 .26382 Mdot
.78587 .12001 Mdot
.59169 .03963 Mdot
.52757 .0142 Mdot
.50459 .00995 Mdot
.48848 .02062 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48715 .01734 Mdot
.45909 .05485 Mdot
.37034 .16219 Mdot
.10791 .25474 Mdot
.69573 .11569 Mdot
.50855 .10777 Mdot
.33418 .23515 Mdot
.9537 .19283 Mdot
.6417 .07815 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49919 .0011 Mdot
.49741 .00351 Mdot
.49173 .01116 Mdot
.47367 .03546 Mdot
.41629 .10954 Mdot
.23906 .25673 Mdot
.82365 .12471 Mdot
.62187 .02245 Mdot
.58555 .56494 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.50779 .60751 Mdot
.52483 .58458 Mdot
.57895 .51435 Mdot
.74672 .36684 Mdot
.15316 .4879 Mdot
.36371 .59936 Mdot
.39393 .07254 Mdot
.27655 .21804 Mdot
.92376 .15003 Mdot
.49974 .00035 Mdot
.49916 .00113 Mdot
.49733 .0036 Mdot
.49151 .01147 Mdot
.47294 .03644 Mdot
.41398 .11236 Mdot
.23219 .25898 Mdot
.81315 .1229 Mdot
.6143 .02581 Mdot
.57254 .5789 Mdot
.63586 .4677 Mdot
.8791 .36609 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49338 .00894 Mdot
.47892 .02842 Mdot
.43294 .08876 Mdot
.28933 .23182 Mdot
.91424 .15611 Mdot
.66165 .03072 Mdot
.61195 .55332 Mdot
.71667 .409 Mdot
.0549 .45888 Mdot
.49989 .00015 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48819 .01595 Mdot
.46239 .05049 Mdot
.38069 .15103 Mdot
.13632 .26251 Mdot
.71157 .11924 Mdot
.51863 .10201 Mdot
.35357 .2194 Mdot
.99858 .21808 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .61231 Mdot
.51351 .5998 Mdot
.54301 .56041 Mdot
.63625 .44897 Mdot
.90979 .36975 Mdot
.31152 .50641 Mdot
.49213 .51371 Mdot
.66093 .38867 Mdot
.03205 .41818 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49463 .00726 Mdot
.48288 .0231 Mdot
.4455 .07264 Mdot
.32797 .20283 Mdot
.99977 .20262 Mdot
.67192 .07248 Mdot
.55464 .02281 Mdot
.51773 .00641 Mdot
.50737 .61761 Mdot
.49998 3e-05 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00264 Mdot
.49377 .00841 Mdot
.48016 .02676 Mdot
.43685 .08378 Mdot
.30129 .22373 Mdot
.93928 .1688 Mdot
.66616 .04126 Mdot
.5994 .57302 Mdot
.50083 .61691 Mdot
.50264 .61446 Mdot
.50842 .60666 Mdot
.52684 .5819 Mdot
.58531 .50654 Mdot
.7657 .35972 Mdot
.18367 .49463 Mdot
.38334 .59335 Mdot
.42327 .04373 Mdot
.35252 .1617 Mdot
.09088 .24145 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50193 .61543 Mdot
.50614 .60974 Mdot
.51956 .59165 Mdot
.56224 .53541 Mdot
.69594 .3963 Mdot
.05472 .44603 Mdot
.33303 .57394 Mdot
.40437 .03933 Mdot
.34074 .16354 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49816 .00249 Mdot
.49413 .00793 Mdot
.48129 .02524 Mdot
.44044 .07917 Mdot
.31234 .21554 Mdot
.96358 .18208 Mdot
.66898 .05324 Mdot
.58283 .59791 Mdot
.61539 .50006 Mdot
.50112 .61652 Mdot
.50356 .61323 Mdot
.51134 .60272 Mdot
.53611 .56953 Mdot
.61459 .47225 Mdot
.85048 .35314 Mdot
.27908 .49823 Mdot
.47293 .5232 Mdot
.62637 .41798 Mdot
.95007 .37245 Mdot
.34744 .49319 Mdot
.5011 .61655 Mdot
.5035 .6133 Mdot
.51116 .60297 Mdot
.53553 .57031 Mdot
.61275 .47431 Mdot
.84531 .35244 Mdot
.27506 .49816 Mdot
.46902 .52669 Mdot
.61681 .42787 Mdot
.92451 .36048 Mdot
.34124 .48443 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50929 .60549 Mdot
.52958 .57822 Mdot
.594 .49606 Mdot
.79135 .35347 Mdot
.21942 .4983 Mdot
.41315 .57488 Mdot
.48299 .59062 Mdot
.52734 .56539 Mdot
.61252 .46956 Mdot
.49963 .00049 Mdot
.49883 .00158 Mdot
.49628 .00502 Mdot
.48816 .01599 Mdot
.46228 .05063 Mdot
.38036 .15139 Mdot
.13541 .26231 Mdot
.71098 .11918 Mdot
.51814 .1024 Mdot
.35244 .22043 Mdot
.99578 .21652 Mdot
.64545 .09968 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00532 Mdot
.48747 .01692 Mdot
.46008 .05354 Mdot
.37345 .15888 Mdot
.11638 .25741 Mdot
.69988 .11712 Mdot
.51038 .1075 Mdot
.33644 .23382 Mdot
.95812 .19543 Mdot
.6419 .08064 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51158 .60239 Mdot
.53689 .5685 Mdot
.61704 .46951 Mdot
.85735 .35428 Mdot
.28411 .49845 Mdot
.47761 .51914 Mdot
.63763 .40686 Mdot
.97931 .38774 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00252 Mdot
.49405 .00803 Mdot
.48106 .02555 Mdot
.43972 .08011 Mdot
.3101 .21726 Mdot
.95857 .17928 Mdot
.66849 .05067 Mdot
.5865 .5924 Mdot
.62798 .48614 Mdot
.8414 .36226 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48783 .01644 Mdot
.46123 .05203 Mdot
.37704 .15501 Mdot
.12623 .26014 Mdot
.70531 .11838 Mdot
.51377 .10563 Mdot
.34286 .22877 Mdot
.97271 .20359 Mdot
.6433 .08798 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60723 Mdot
.52547 .58372 Mdot
.581 .51183 Mdot
.75284 .36431 Mdot
.16338 .49053 Mdot
.36968 .59829 Mdot
.40162 .06576 Mdot
.29521 .2074 Mdot
.95963 .17038 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50662 .6091 Mdot
.52108 .58961 Mdot
.56706 .52927 Mdot
.71069 .3862 Mdot
.08581 .46195 Mdot
.33836 .58733 Mdot
.38803 .06475 Mdot
.28327 .20908 Mdot
.94496 .15907 Mdot
.5006 .61722 Mdot
.50191 .61545 Mdot
.50609 .6098 Mdot
.51942 .59184 Mdot
.56179 .53599 Mdot
.69454 .39731 Mdot
.05168 .44439 Mdot
.33265 .57248 Mdot
.40636 .03633 Mdot
.34759 .157 Mdot
.09356 .23882 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51043 .60395 Mdot
.53321 .57339 Mdot
.60545 .48263 Mdot
.82454 .35097 Mdot
.25666 .49839 Mdot
.45025 .54376 Mdot
.57043 .48058 Mdot
.79283 .33835 Mdot
.24537 .48583 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50739 .60805 Mdot
.52354 .58631 Mdot
.57487 .51943 Mdot
.73441 .3726 Mdot
.13153 .48112 Mdot
.35306 .59879 Mdot
.38419 .07889 Mdot
.25654 .22631 Mdot
.89036 .13252 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00814 Mdot
.48081 .02588 Mdot
.43893 .08112 Mdot
.30767 .21908 Mdot
.95319 .17631 Mdot
.66791 .04796 Mdot
.59031 .58669 Mdot
.64103 .4724 Mdot
.87668 .36917 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51175 .60216 Mdot
.53744 .56778 Mdot
.61875 .46762 Mdot
.86212 .3552 Mdot
.28739 .49869 Mdot
.48049 .51673 Mdot
.6444 .40049 Mdot
.99639 .39715 Mdot
.3538 .51441 Mdot
.50054 .61731 Mdot
.50172 .61572 Mdot
.50547 .61065 Mdot
.51742 .59453 Mdot
.55545 .54416 Mdot
.67499 .4127 Mdot
.00723 .4194 Mdot
.32863 .5493 Mdot
.43984 .60375 Mdot
.46296 .01975 Mdot
.431 .08173 Mdot
.50005 .61796 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50175 .61566 Mdot
.50559 .61048 Mdot
.51781 .594 Mdot
.5567 .54255 Mdot
.67883 .40951 Mdot
.01624 .42453 Mdot
.32933 .55413 Mdot
.43273 .61465 Mdot
.5011 .61655 Mdot
.5035 .61331 Mdot
.51114 .60299 Mdot
.53547 .57038 Mdot
.61257 .47451 Mdot
.8448 .35237 Mdot
.27465 .49815 Mdot
.46862 .52706 Mdot
.61582 .42892 Mdot
.92182 .35932 Mdot
.34043 .48368 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49814 .00252 Mdot
.49406 .00802 Mdot
.48108 .02552 Mdot
.43979 .08002 Mdot
.31031 .2171 Mdot
.95904 .17954 Mdot
.66853 .05091 Mdot
.58616 .59292 Mdot
.6268 .48741 Mdot
.83815 .36193 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49168 .01124 Mdot
.47349 .0357 Mdot
.41572 .11024 Mdot
.23735 .25732 Mdot
.82101 .12421 Mdot
.62003 .02319 Mdot
.5825 .56813 Mdot
.66325 .44196 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48771 .01659 Mdot
.46086 .05251 Mdot
.3759 .15625 Mdot
.12309 .25932 Mdot
.7035 .11802 Mdot
.51254 .10641 Mdot
.34037 .2308 Mdot
.96692 .20036 Mdot
.64274 .08507 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00455 Mdot
.48926 .0145 Mdot
.46579 .04597 Mdot
.3914 .13902 Mdot
.16647 .2667 Mdot
.73493 .11982 Mdot
.54106 .08217 Mdot
.40811 .16271 Mdot
.14484 .2792 Mdot
.69309 .14099 Mdot
.50055 .61729 Mdot
.50175 .61566 Mdot
.50559 .61048 Mdot
.5178 .59401 Mdot
.55667 .54258 Mdot
.67875 .40958 Mdot
.01604 .42442 Mdot
.32931 .55402 Mdot
.43288 .61442 Mdot
.43873 .0518 Mdot
.35492 .16843 Mdot
.50125 .61635 Mdot
.50398 .61265 Mdot
.51269 .60091 Mdot
.5404 .56386 Mdot
.62805 .45755 Mdot
.88772 .36188 Mdot
.30218 .50157 Mdot
.49063 .51025 Mdot
.66503 .38324 Mdot
.04494 .42435 Mdot
.35833 .53901 Mdot
.49969 .00043 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48983 .01374 Mdot
.46759 .04357 Mdot
.39709 .13247 Mdot
.18275 .26704 Mdot
.75068 .11949 Mdot
.55733 .06749 Mdot
.44814 .11472 Mdot
.26252 .26181 Mdot
.83891 .13669 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49156 .0114 Mdot
.47311 .03622 Mdot
.41451 .11171 Mdot
.23375 .25849 Mdot
.81551 .12327 Mdot
.61606 .02496 Mdot
.57567 .57546 Mdot
.64456 .45913 Mdot
.90167 .37366 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50976 .60486 Mdot
.53107 .57624 Mdot
.5987 .49049 Mdot
.80507 .35169 Mdot
.23602 .49867 Mdot
.42916 .56219 Mdot
.51952 .54414 Mdot
.63909 .43099 Mdot
.94173 .37817 Mdot
.50109 .61656 Mdot
.50348 .61334 Mdot
.51107 .60308 Mdot
.53527 .57065 Mdot
.61195 .47522 Mdot
.84303 .35217 Mdot
.27321 .49815 Mdot
.46719 .52834 Mdot
.61231 .43265 Mdot
.91227 .35538 Mdot
.33726 .4813 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48891 .01498 Mdot
.46467 .04747 Mdot
.38787 .14303 Mdot
.15644 .26581 Mdot
.72636 .11989 Mdot
.53238 .09008 Mdot
.38663 .18651 Mdot
.08485 .2615 Mdot
.66174 .13607 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50138 .61618 Mdot
.50438 .61211 Mdot
.51397 .59918 Mdot
.54447 .55849 Mdot
.64082 .44432 Mdot
.9219 .37479 Mdot
.31548 .51002 Mdot
.49026 .51904 Mdot
.65043 .39945 Mdot
.50022 .61773 Mdot
.50071 .61708 Mdot
.50225 .615 Mdot
.50716 .60836 Mdot
.5228 .5873 Mdot
.57254 .52235 Mdot
.72735 .3763 Mdot
.11848 .47627 Mdot
.34786 .5968 Mdot
.38222 .07825 Mdot
.25561 .2257 Mdot
.50097 .61673 Mdot
.50307 .61388 Mdot
.5098 .6048 Mdot
.5312 .57606 Mdot
.59911 .49001 Mdot
.80626 .35159 Mdot
.23739 .49867 Mdot
.43053 .56105 Mdot
.52273 .54005 Mdot
.64891 .42128 Mdot
.96727 .39115 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .00239 Mdot
.49436 .00761 Mdot
.48204 .02423 Mdot
.44285 .07608 Mdot
.31975 .20968 Mdot
.98048 .19163 Mdot
.67042 .06215 Mdot
.56986 .61748 Mdot
.57075 .55403 Mdot
.67431 .42286 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60694 Mdot
.52616 .58279 Mdot
.58318 .50914 Mdot
.75938 .36185 Mdot
.17389 .49284 Mdot
.37645 .59622 Mdot
.41175 .05587 Mdot
.32134 .18884 Mdot
.0158 .20346 Mdot
.50095 .61676 Mdot
.50301 .61396 Mdot
.50961 .60506 Mdot
.5306 .57687 Mdot
.5972 .49226 Mdot
.80071 .35214 Mdot
.23093 .49863 Mdot
.42414 .56632 Mdot
.5078 .55909 Mdot
.60317 .47 Mdot
.84269 .34678 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51282 .60072 Mdot
.54083 .56328 Mdot
.62942 .45609 Mdot
.89145 .36308 Mdot
.30397 .50223 Mdot
.49135 .51024 Mdot
.66575 .38289 Mdot
.04622 .42514 Mdot
.35833 .53981 Mdot
.50004 .61798 Mdot
.50013 .61785 Mdot
.50043 .61746 Mdot
.50137 .61619 Mdot
.50435 .61216 Mdot
.51386 .59933 Mdot
.54413 .55894 Mdot
.63975 .4454 Mdot
.91907 .37357 Mdot
.31462 .50912 Mdot
.49086 .51759 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50078 .61698 Mdot
.5025 .61466 Mdot
.50795 .6073 Mdot
.52532 .58392 Mdot
.58053 .51241 Mdot
.75143 .36487 Mdot
.16106 .48997 Mdot
.36827 .59862 Mdot
.39969 .06754 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.5113 .60277 Mdot
.536 .56967 Mdot
.61425 .47262 Mdot
.84953 .353 Mdot
.27836 .49821 Mdot
.47224 .52381 Mdot
.62469 .41969 Mdot
.94563 .37025 Mdot
.34654 .49148 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00259 Mdot
.4939 .00824 Mdot
.48057 .02621 Mdot
.43816 .0821 Mdot
.30532 .22083 Mdot
.94801 .17348 Mdot
.66731 .04541 Mdot
.59384 .5814 Mdot
.6531 .46037 Mdot
.90821 .37992 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54245 .56115 Mdot
.6345 .45078 Mdot
.90512 .36794 Mdot
.30978 .5052 Mdot
.49235 .51228 Mdot
.66346 .38602 Mdot
.03887 .4217 Mdot
.35655 .53739 Mdot
.50031 .61762 Mdot
.50097 .61672 Mdot
.5031 .61385 Mdot
.50988 .6047 Mdot
.53146 .57572 Mdot
.59992 .48906 Mdot
.8086 .35141 Mdot
.24001 .49866 Mdot
.43316 .55882 Mdot
.52898 .5321 Mdot
.66803 .40369 Mdot
.50037 .61753 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51207 .60173 Mdot
.53845 .56643 Mdot
.62196 .46411 Mdot
.87101 .3572 Mdot
.29305 .49938 Mdot
.48504 .51323 Mdot
.65462 .39139 Mdot
.02133 .41111 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60457 Mdot
.53175 .57534 Mdot
.60083 .488 Mdot
.81123 .35124 Mdot
.24292 .49864 Mdot
.43611 .55629 Mdot
.53602 .52318 Mdot
.68949 .38617 Mdot
.06466 .44448 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51217 .60161 Mdot
.53875 .56604 Mdot
.62288 .46311 Mdot
.87355 .35783 Mdot
.29456 .49963 Mdot
.48614 .51246 Mdot
.65696 .38942 Mdot
.02686 .4142 Mdot
.35666 .52984 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50393 .61273 Mdot
.51251 .60115 Mdot
.53983 .56461 Mdot
.62627 .45945 Mdot
.88286 .3604 Mdot
.29972 .5008 Mdot
.4894 .51062 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51166 .6023 Mdot
.53712 .5682 Mdot
.61776 .46872 Mdot
.85936 .35465 Mdot
.28552 .49854 Mdot
.47886 .51808 Mdot
.64058 .40405 Mdot
.98681 .39184 Mdot
.3528 .50966 Mdot
.50106 .61661 Mdot
.50337 .61348 Mdot
.51074 .60354 Mdot
.53419 .57208 Mdot
.60854 .47908 Mdot
.83337 .35132 Mdot
.26492 .49822 Mdot
.45879 .536 Mdot
.59153 .45575 Mdot
.85411 .33866 Mdot
.30615 .47712 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.52831 .57992 Mdot
.58998 .50088 Mdot
.77953 .35587 Mdot
.20372 .49722 Mdot
.3992 .58455 Mdot
.45338 .00912 Mdot
.43862 .06462 Mdot
.33406 .19206 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49855 .00196 Mdot
.49538 .00625 Mdot
.48527 .01989 Mdot
.45308 .06275 Mdot
.35155 .18127 Mdot
.05824 .23407 Mdot
.67951 .10076 Mdot
.51648 .08551 Mdot
.37812 .18777 Mdot
.07429 .25418 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48845 .0156 Mdot
.46321 .04941 Mdot
.38326 .14818 Mdot
.14349 .26391 Mdot
.71648 .11962 Mdot
.52293 .09844 Mdot
.36366 .20993 Mdot
.02399 .23209 Mdot
.64847 .11356 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54176 .56206 Mdot
.63233 .45303 Mdot
.89931 .36579 Mdot
.30744 .50383 Mdot
.49223 .51103 Mdot
.66538 .38385 Mdot
.0443 .42439 Mdot
.35763 .53946 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50653 .60922 Mdot
.52079 .58999 Mdot
.56616 .53041 Mdot
.70794 .38799 Mdot
.08017 .4592 Mdot
.33716 .58517 Mdot
.39034 .06094 Mdot
.29173 .20344 Mdot
.96255 .16905 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50745 .60797 Mdot
.52374 .58604 Mdot
.57552 .51863 Mdot
.73636 .37162 Mdot
.13506 .48233 Mdot
.35462 .59913 Mdot
.38521 .07853 Mdot
.25815 .22588 Mdot
.89268 .13375 Mdot
.49999 1e-05 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00475 Mdot
.4888 .01512 Mdot
.46433 .04791 Mdot
.38681 .14422 Mdot
.15346 .26544 Mdot
.72397 .11987 Mdot
.53002 .0922 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .01369 Mdot
.46772 .04341 Mdot
.39748 .13202 Mdot
.18387 .26701 Mdot
.75184 .11947 Mdot
.55853 .06642 Mdot
.45106 .11108 Mdot
.27133 .2573 Mdot
.855 .14072 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49871 .00174 Mdot
.49589 .00556 Mdot
.4869 .01769 Mdot
.45828 .05592 Mdot
.36781 .16485 Mdot
.10107 .25238 Mdot
.69271 .11429 Mdot
.50779 .10707 Mdot
.33455 .23428 Mdot
.50125 .61634 Mdot
.50398 .61265 Mdot
.51269 .6009 Mdot
.54042 .56383 Mdot
.62813 .45746 Mdot
.88795 .36195 Mdot
.30229 .50161 Mdot
.49068 .51024 Mdot
.66509 .3832 Mdot
.04506 .42442 Mdot
.35834 .53908 Mdot
.50034 .61757 Mdot
.5011 .61655 Mdot
.5035 .6133 Mdot
.51116 .60297 Mdot
.53553 .5703 Mdot
.61277 .47428 Mdot
.84537 .35244 Mdot
.2751 .49816 Mdot
.46907 .52665 Mdot
.61693 .42775 Mdot
.92482 .36061 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49702 .00403 Mdot
.4905 .01284 Mdot
.46973 .04073 Mdot
.40382 .12457 Mdot
.20227 .26553 Mdot
.77264 .11947 Mdot
.57933 .04894 Mdot
.50015 .0488 Mdot
.42119 .11892 Mdot
.22877 .26515 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .60219 Mdot
.53737 .56786 Mdot
.61855 .46784 Mdot
.86157 .35509 Mdot
.28703 .49866 Mdot
.48018 .51699 Mdot
.64367 .40117 Mdot
.99456 .39613 Mdot
.35361 .5135 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49952 .00065 Mdot
.49846 .00209 Mdot
.49508 .00664 Mdot
.48433 .02115 Mdot
.45012 .06664 Mdot
.3423 .19006 Mdot
.03478 .22204 Mdot
.67551 .09037 Mdot
.52929 .06337 Mdot
.42675 .12891 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50565 .6104 Mdot
.518 .59375 Mdot
.5573 .54177 Mdot
.6807 .40799 Mdot
.02057 .427 Mdot
.32967 .55644 Mdot
.42932 .0018 Mdot
.4264 .06762 Mdot
.31699 .20229 Mdot
.50099 .6167 Mdot
.50315 .61377 Mdot
.51005 .60446 Mdot
.53201 .57499 Mdot
.60165 .48703 Mdot
.81361 .35112 Mdot
.24549 .4986 Mdot
.43874 .55401 Mdot
.54233 .51522 Mdot
.70868 .37262 Mdot
.10576 .46361 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51186 .60202 Mdot
.53776 .56735 Mdot
.61978 .46649 Mdot
.86497 .3558 Mdot
.28927 .49888 Mdot
.48207 .51547 Mdot
.64803 .39719 Mdot
.00537 .40216 Mdot
.35466 .51894 Mdot
.50087 .61686 Mdot
.50277 .6143 Mdot
.50881 .60613 Mdot
.52807 .58025 Mdot
.5892 .50182 Mdot
.77724 .35643 Mdot
.20052 .4969 Mdot
.39652 .58622 Mdot
.448 .01554 Mdot
.42285 .08429 Mdot
.28647 .22798 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.48841 .01565 Mdot
.46308 .04957 Mdot
.38287 .14862 Mdot
.14239 .26371 Mdot
.7157 .11957 Mdot
.52222 .09904 Mdot
.36198 .21155 Mdot
.01969 .22975 Mdot
.64794 .11152 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45742 .05706 Mdot
.3651 .16767 Mdot
.09381 .24969 Mdot
.68981 .11257 Mdot
.50767 .10546 Mdot
.33704 .23148 Mdot
.9625 .19703 Mdot
.64369 .0812 Mdot
.50129 .61628 Mdot
.50413 .61246 Mdot
.51314 .60029 Mdot
.54185 .56193 Mdot
.63262 .45273 Mdot
.9001 .36608 Mdot
.30777 .50401 Mdot
.49228 .51116 Mdot
.6652 .38407 Mdot
.04376 .42413 Mdot
.3575 .53927 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00213 Mdot
.49497 .0068 Mdot
.48398 .02163 Mdot
.44898 .06812 Mdot
.33877 .1933 Mdot
.02601 .2173 Mdot
.67441 .08609 Mdot
.53511 .0538 Mdot
.44806 .1011 Mdot
.28448 .2452 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49021 .01323 Mdot
.4688 .04196 Mdot
.4009 .12801 Mdot
.19378 .26644 Mdot
.76266 .11937 Mdot
.56952 .05695 Mdot
.47738 .07785 Mdot
.35141 .19644 Mdot
.03356 .22733 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01439 Mdot
.46607 .0456 Mdot
.39228 .13801 Mdot
.16897 .26685 Mdot
.73721 .11978 Mdot
.5434 .08004 Mdot
.4139 .15602 Mdot
.16146 .28131 Mdot
.70629 .1393 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49711 .0039 Mdot
.4908 .01242 Mdot
.4707 .03943 Mdot
.4069 .1209 Mdot
.21129 .2641 Mdot
.78397 .1199 Mdot
.58996 .04087 Mdot
.52383 .01886 Mdot
.49332 .02504 Mdot
.4528 .06816 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60042 Mdot
.54155 .56233 Mdot
.63168 .45372 Mdot
.89755 .36516 Mdot
.3067 .50344 Mdot
.49211 .51076 Mdot
.66568 .38344 Mdot
.04527 .42484 Mdot
.35786 .53978 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01579 Mdot
.46275 .05001 Mdot
.38184 .14975 Mdot
.13954 .26317 Mdot
.71373 .11944 Mdot
.52048 .10051 Mdot
.35785 .21545 Mdot
.00925 .22402 Mdot
.64678 .10643 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00437 Mdot
.48969 .01393 Mdot
.46715 .04417 Mdot
.39569 .13409 Mdot
.17873 .26709 Mdot
.74657 .11958 Mdot
.55309 .07126 Mdot
.43779 .12748 Mdot
.23152 .27403 Mdot
.78813 .1307 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49276 .00977 Mdot
.47695 .03107 Mdot
.42668 .09666 Mdot
.27027 .24301 Mdot
.87707 .14005 Mdot
.65047 .02043 Mdot
.61741 .53922 Mdot
.74493 .39175 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01061 Mdot
.47497 .03373 Mdot
.4204 .10448 Mdot
.25134 .25202 Mdot
.84356 .12925 Mdot
.63444 .01892 Mdot
.60383 .54738 Mdot
.71815 .40278 Mdot
.06645 .4626 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58923 Mdot
.56798 .5281 Mdot
.71349 .38442 Mdot
.09148 .46464 Mdot
.33968 .58937 Mdot
.38606 .06817 Mdot
.27575 .21379 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51328 .60011 Mdot
.54227 .56138 Mdot
.63394 .45136 Mdot
.90363 .36738 Mdot
.3092 .50483 Mdot
.49237 .51191 Mdot
.66408 .38534 Mdot
.04059 .42256 Mdot
.35687 .53808 Mdot
.50123 .61637 Mdot
.50391 .61274 Mdot
.51247 .60119 Mdot
.53972 .56475 Mdot
.62594 .45981 Mdot
.88195 .36013 Mdot
.29924 .50067 Mdot
.48914 .51073 Mdot
.66276 .3848 Mdot
.04013 .42161 Mdot
.35794 .53651 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47739 .03048 Mdot
.42807 .09491 Mdot
.2745 .24071 Mdot
.88502 .14315 Mdot
.65339 .02196 Mdot
.61785 .54046 Mdot
.74337 .39304 Mdot
.10742 .48523 Mdot
.50119 .61643 Mdot
.50378 .61292 Mdot
.51206 .60175 Mdot
.5384 .5665 Mdot
.62178 .46431 Mdot
.87051 .35708 Mdot
.29275 .49933 Mdot
.48481 .51339 Mdot
.65413 .39181 Mdot
.02017 .41046 Mdot
.35603 .52646 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50933 .60544 Mdot
.52971 .57806 Mdot
.59439 .49559 Mdot
.7925 .35328 Mdot
.22088 .49836 Mdot
.41452 .57385 Mdot
.486 .58681 Mdot
.53652 .55326 Mdot
.64132 .43879 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.48728 .01717 Mdot
.45951 .0543 Mdot
.37165 .16081 Mdot
.11146 .25589 Mdot
.69742 .11633 Mdot
.5092 .10781 Mdot
.33476 .23492 Mdot
.95466 .19345 Mdot
.64165 .07879 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60736 Mdot
.52516 .58413 Mdot
.58002 .51304 Mdot
.74991 .36549 Mdot
.15853 .48933 Mdot
.36677 .59891 Mdot
.39771 .06931 Mdot
.28556 .21319 Mdot
.94062 .1594 Mdot
.49978 .00029 Mdot
.49931 .00094 Mdot
.49779 .00299 Mdot
.49295 .00952 Mdot
.47755 .03026 Mdot
.42858 .09427 Mdot
.27604 .23985 Mdot
.88796 .14435 Mdot
.6544 .02263 Mdot
.61777 .54118 Mdot
.74213 .39381 Mdot
.10492 .48419 Mdot
.50125 .61634 Mdot
.504 .61264 Mdot
.51273 .60085 Mdot
.54054 .56367 Mdot
.62851 .45706 Mdot
.88897 .36228 Mdot
.30279 .50178 Mdot
.49089 .51022 Mdot
.66534 .38306 Mdot
.04553 .4247 Mdot
.35835 .53935 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00471 Mdot
.48888 .01501 Mdot
.46459 .04757 Mdot
.38761 .14331 Mdot
.15573 .26572 Mdot
.72578 .11988 Mdot
.5318 .0906 Mdot
.38521 .18802 Mdot
.08098 .2599 Mdot
.66045 .1351 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56446 Mdot
.62663 .45907 Mdot
.88384 .36069 Mdot
.30023 .50095 Mdot
.48968 .51051 Mdot
.66366 .38415 Mdot
.04209 .42272 Mdot
.35812 .5375 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00378 Mdot
.49109 .01203 Mdot
.47162 .0382 Mdot
.40982 .1174 Mdot
.21986 .26231 Mdot
.79543 .12073 Mdot
.60008 .03395 Mdot
.54515 .61068 Mdot
.55705 .55892 Mdot
.6527 .4381 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51265 .60096 Mdot
.54028 .56401 Mdot
.62769 .45793 Mdot
.88675 .36158 Mdot
.3017 .50141 Mdot
.49041 .51029 Mdot
.66474 .38341 Mdot
.04437 .42402 Mdot
.3583 .5387 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.48919 .0146 Mdot
.46557 .04626 Mdot
.39072 .13979 Mdot
.16453 .26657 Mdot
.73321 .11984 Mdot
.5393 .08378 Mdot
.40374 .16767 Mdot
.13244 .27677 Mdot
.68462 .14149 Mdot
.50041 .61749 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54179 .56202 Mdot
.63242 .45295 Mdot
.89953 .36587 Mdot
.30754 .50388 Mdot
.49225 .51106 Mdot
.66533 .38391 Mdot
.04415 .42431 Mdot
.49961 .00053 Mdot
.49876 .00167 Mdot
.49606 .00533 Mdot
.48743 .01697 Mdot
.45998 .05368 Mdot
.37312 .15923 Mdot
.11548 .25714 Mdot
.69942 .11698 Mdot
.51014 .10759 Mdot
.33606 .23409 Mdot
.9573 .19497 Mdot
.64183 .08021 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50985 .60473 Mdot
.53137 .57584 Mdot
.59964 .48938 Mdot
.8078 .35146 Mdot
.23912 .49866 Mdot
.43227 .55958 Mdot
.52685 .5348 Mdot
.66152 .40948 Mdot
.99897 .40852 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51184 .60204 Mdot
.53772 .5674 Mdot
.61964 .46665 Mdot
.86458 .35572 Mdot
.28902 .49885 Mdot
.48186 .51563 Mdot
.64754 .39762 Mdot
.00418 .4015 Mdot
.35455 .51834 Mdot
.50045 .61743 Mdot
.50142 .61612 Mdot
.50452 .61192 Mdot
.51441 .59858 Mdot
.54589 .55662 Mdot
.64526 .43989 Mdot
.93349 .38002 Mdot
.31861 .51406 Mdot
.48684 .52625 Mdot
.63535 .41536 Mdot
.96329 .38163 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54007 .5643 Mdot
.62701 .45866 Mdot
.88489 .36101 Mdot
.30077 .50111 Mdot
.48996 .51041 Mdot
.66409 .38385 Mdot
.04302 .42324 Mdot
.3582 .53798 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58922 Mdot
.56799 .52808 Mdot
.71354 .3844 Mdot
.09157 .46468 Mdot
.3397 .5894 Mdot
.38603 .06822 Mdot
.27564 .21386 Mdot
.92961 .15071 Mdot
.50007 .61795 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60898 Mdot
.52135 .58925 Mdot
.56792 .52817 Mdot
.71332 .38453 Mdot
.09114 .46448 Mdot
.3396 .58925 Mdot
.38617 .06798 Mdot
.49997 4e-05 Mdot
.49989 .00014 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49658 .00461 Mdot
.48912 .01469 Mdot
.46534 .04657 Mdot
.38999 .14062 Mdot
.16246 .26641 Mdot
.73141 .11987 Mdot
.53746 .08546 Mdot
.39918 .1728 Mdot
.49991 .00012 Mdot
.49971 .0004 Mdot
.49907 .00126 Mdot
.49702 .00402 Mdot
.49051 .01281 Mdot
.46978 .04066 Mdot
.40399 .12436 Mdot
.20277 .26546 Mdot
.77325 .11948 Mdot
.57992 .04847 Mdot
.50149 .04709 Mdot
.4253 .11382 Mdot
.50068 .61712 Mdot
.50216 .61511 Mdot
.50689 .60873 Mdot
.52194 .58846 Mdot
.56979 .52581 Mdot
.71902 .38105 Mdot
.10246 .46961 Mdot
.34261 .59287 Mdot
.38332 .07357 Mdot
.26428 .22052 Mdot
.90746 .13949 Mdot
.50016 .61782 Mdot
.50051 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51665 .59556 Mdot
.55302 .54731 Mdot
.66744 .41918 Mdot
.9892 .40917 Mdot
.32714 .53972 Mdot
.45385 .58191 Mdot
.51231 .57051 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49257 .01003 Mdot
.47634 .03189 Mdot
.42474 .09909 Mdot
.26441 .24603 Mdot
.86633 .13617 Mdot
.646 .01902 Mdot
.61522 .53934 Mdot
.74255 .39195 Mdot
.10836 .48482 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .0068 Mdot
.48395 .02166 Mdot
.44891 .06821 Mdot
.33855 .1935 Mdot
.02547 .21701 Mdot
.67434 .08582 Mdot
.53548 .0532 Mdot
.44941 .09932 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51101 .60316 Mdot
.53508 .5709 Mdot
.61134 .4759 Mdot
.84131 .35198 Mdot
.27179 .49815 Mdot
.46577 .52963 Mdot
.60881 .43643 Mdot
.90265 .35171 Mdot
.33357 .47937 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.5009 .61681 Mdot
.50287 .61415 Mdot
.50916 .60566 Mdot
.52918 .57877 Mdot
.59271 .4976 Mdot
.78758 .35415 Mdot
.21456 .49805 Mdot
.4087 .57812 Mdot
.47328 .60277 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00806 Mdot
.48098 .02565 Mdot
.43947 .08042 Mdot
.30935 .21783 Mdot
.9569 .17835 Mdot
.66831 .04982 Mdot
.5877 .5906 Mdot
.63208 .48173 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47456 .03428 Mdot
.4191 .10609 Mdot
.24744 .25361 Mdot
.83709 .12761 Mdot
.63061 .01967 Mdot
.59878 .5519 Mdot
.70579 .41001 Mdot
.04237 .44883 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51174 .60219 Mdot
.53738 .56785 Mdot
.61857 .46782 Mdot
.86162 .3551 Mdot
.28706 .49866 Mdot
.4802 .51697 Mdot
.64373 .40111 Mdot
.99472 .39622 Mdot
.35363 .51357 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49857 .00194 Mdot
.49543 .00617 Mdot
.48546 .01963 Mdot
.45369 .06196 Mdot
.35343 .17943 Mdot
.06311 .23641 Mdot
.68058 .10268 Mdot
.51444 .08931 Mdot
.36993 .19691 Mdot
.49997 4e-05 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00414 Mdot
.49023 .0132 Mdot
.46888 .04186 Mdot
.40114 .12773 Mdot
.19447 .26638 Mdot
.76345 .11937 Mdot
.57031 .05628 Mdot
.47924 .07548 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00531 Mdot
.48747 .01692 Mdot
.46009 .05353 Mdot
.37347 .15886 Mdot
.11643 .25742 Mdot
.69991 .11713 Mdot
.5104 .1075 Mdot
.33646 .2338 Mdot
.95817 .19546 Mdot
.6419 .08066 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56447 Mdot
.62661 .45908 Mdot
.8838 .36068 Mdot
.30021 .50094 Mdot
.48967 .51051 Mdot
.66364 .38416 Mdot
.04205 .42269 Mdot
.35812 .53748 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48701 .01754 Mdot
.45862 .05547 Mdot
.36888 .16373 Mdot
.10395 .25339 Mdot
.69395 .1149 Mdot
.50803 .10746 Mdot
.33416 .23486 Mdot
.95415 .19294 Mdot
.50082 .61692 Mdot
.50263 .61448 Mdot
.50837 .60673 Mdot
.52667 .58212 Mdot
.58479 .50718 Mdot
.76416 .36022 Mdot
.18131 .49423 Mdot
.38163 .59413 Mdot
.4203 .04693 Mdot
.34437 .16929 Mdot
.07046 .23249 Mdot
.49959 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45727 .05725 Mdot
.36463 .16815 Mdot
.09256 .2492 Mdot
.68934 .11224 Mdot
.50772 .10509 Mdot
.33769 .2308 Mdot
.96425 .19793 Mdot
.64399 .08193 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01453 Mdot
.46573 .04606 Mdot
.3912 .13925 Mdot
.16588 .26666 Mdot
.73441 .11983 Mdot
.54052 .08266 Mdot
.40677 .16423 Mdot
.14103 .27853 Mdot
.69037 .14122 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01062 Mdot
.47496 .03374 Mdot
.42037 .10451 Mdot
.25127 .25205 Mdot
.84344 .12921 Mdot
.63437 .01893 Mdot
.60374 .54745 Mdot
.71794 .40289 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46941 .04116 Mdot
.40281 .12577 Mdot
.19932 .26589 Mdot
.76909 .11941 Mdot
.57589 .05169 Mdot
.49226 .05887 Mdot
.39701 .14782 Mdot
.15784 .27131 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48745 .01694 Mdot
.46005 .05359 Mdot
.37333 .15901 Mdot
.11606 .25731 Mdot
.69972 .11707 Mdot
.51029 .10753 Mdot
.3363 .23392 Mdot
.95782 .19527 Mdot
.64187 .08048 Mdot
.49988 .00017 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.4872 .01727 Mdot
.45925 .05464 Mdot
.37085 .16165 Mdot
.10929 .25519 Mdot
.69638 .11594 Mdot
.50878 .10781 Mdot
.33434 .23511 Mdot
.95392 .19299 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51033 .60409 Mdot
.53289 .57381 Mdot
.60444 .48379 Mdot
.82165 .35095 Mdot
.2538 .49845 Mdot
.44729 .54642 Mdot
.56316 .4894 Mdot
.7713 .34317 Mdot
.21604 .48737 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.50492 .61139 Mdot
.51568 .59688 Mdot
.54991 .55136 Mdot
.65779 .42789 Mdot
.96545 .39611 Mdot
.32453 .52778 Mdot
.47057 .55491 Mdot
.57271 .48982 Mdot
.78015 .34492 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50389 .61278 Mdot
.51238 .60132 Mdot
.53942 .56515 Mdot
.62499 .46083 Mdot
.87936 .35939 Mdot
.29785 .50032 Mdot
.48832 .51114 Mdot
.66128 .38593 Mdot
.03684 .41977 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.52589 .58315 Mdot
.58233 .51019 Mdot
.75683 .36278 Mdot
.16984 .492 Mdot
.37376 .59714 Mdot
.40757 .06006 Mdot
.3104 .1971 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.4985 .00202 Mdot
.49523 .00644 Mdot
.48481 .0205 Mdot
.45164 .06465 Mdot
.34703 .18562 Mdot
.04669 .22828 Mdot
.67732 .09586 Mdot
.52222 .07533 Mdot
.40034 .1618 Mdot
.13854 .27462 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .00149 Mdot
.49648 .00476 Mdot
.48878 .01515 Mdot
.46427 .048 Mdot
.38661 .14444 Mdot
.1529 .26537 Mdot
.72352 .11986 Mdot
.52958 .09259 Mdot
.37976 .19375 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47455 .03428 Mdot
.41909 .1061 Mdot
.24742 .25362 Mdot
.83705 .1276 Mdot
.63059 .01968 Mdot
.59875 .55193 Mdot
.70571 .41006 Mdot
.04223 .44875 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.5159 .59657 Mdot
.55062 .55043 Mdot
.66001 .42585 Mdot
.97097 .39909 Mdot
.32523 .53045 Mdot
.46695 .56087 Mdot
.55944 .50704 Mdot
.73904 .35984 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50778 .60752 Mdot
.5248 .58463 Mdot
.57885 .51448 Mdot
.7464 .36698 Mdot
.15262 .48775 Mdot
.36342 .59939 Mdot
.39358 .07283 Mdot
.27574 .21845 Mdot
.92229 .14923 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48731 .01713 Mdot
.4596 .05417 Mdot
.37195 .16049 Mdot
.11227 .25615 Mdot
.69781 .11647 Mdot
.50937 .10779 Mdot
.33497 .2348 Mdot
.95506 .19369 Mdot
.64167 .07902 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56064 Mdot
.63571 .44953 Mdot
.90835 .36919 Mdot
.311 .50603 Mdot
.49223 .51323 Mdot
.6618 .38777 Mdot
.03438 .41939 Mdot
.35579 .53553 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58922 Mdot
.56799 .52809 Mdot
.71353 .3844 Mdot
.09157 .46468 Mdot
.3397 .5894 Mdot
.38603 .06822 Mdot
.27565 .21386 Mdot
.92962 .15072 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .0018 Mdot
.49576 .00572 Mdot
.4865 .01823 Mdot
.45701 .0576 Mdot
.36382 .169 Mdot
.09038 .24835 Mdot
.68854 .11167 Mdot
.50786 .10438 Mdot
.33896 .22947 Mdot
.96767 .19971 Mdot
.50017 .6178 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.50552 .61058 Mdot
.51757 .59433 Mdot
.55593 .54354 Mdot
.67646 .41147 Mdot
.0107 .42138 Mdot
.3289 .55116 Mdot
.4371 .60796 Mdot
.4534 .03252 Mdot
.50123 .61637 Mdot
.50393 .61272 Mdot
.51253 .60111 Mdot
.53991 .5645 Mdot
.62652 .45918 Mdot
.88355 .3606 Mdot
.30008 .5009 Mdot
.4896 .51054 Mdot
.66353 .38424 Mdot
.04181 .42256 Mdot
.3581 .53736 Mdot
.50075 .61702 Mdot
.50239 .6148 Mdot
.50762 .60774 Mdot
.52428 .58532 Mdot
.57721 .51652 Mdot
.74147 .36918 Mdot
.14412 .48526 Mdot
.35894 .59957 Mdot
.38882 .07643 Mdot
.26516 .2233 Mdot
.90385 .13949 Mdot
.50131 .61626 Mdot
.50417 .6124 Mdot
.51329 .60009 Mdot
.54233 .5613 Mdot
.63413 .45116 Mdot
.90413 .36756 Mdot
.3094 .50495 Mdot
.49236 .51203 Mdot
.66389 .38556 Mdot
.04004 .42229 Mdot
.35676 .53786 Mdot
.50067 .61713 Mdot
.50214 .61515 Mdot
.50681 .60883 Mdot
.5217 .58878 Mdot
.56904 .52676 Mdot
.71673 .38242 Mdot
.09796 .46761 Mdot
.34135 .59151 Mdot
.38426 .07156 Mdot
.26848 .21811 Mdot
.91557 .14346 Mdot
.50123 .61637 Mdot
.50392 .61273 Mdot
.5125 .60116 Mdot
.5398 .56465 Mdot
.62617 .45955 Mdot
.8826 .36032 Mdot
.29958 .50076 Mdot
.48933 .51065 Mdot
.66308 .38456 Mdot
.04084 .42202 Mdot
.35801 .53687 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50493 .61138 Mdot
.5157 .59684 Mdot
.54999 .55125 Mdot
.65804 .42766 Mdot
.96608 .39645 Mdot
.32461 .52808 Mdot
.47017 .55557 Mdot
.57123 .49172 Mdot
.77562 .34608 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.50231 .61492 Mdot
.50735 .6081 Mdot
.52342 .58647 Mdot
.5745 .51989 Mdot
.7333 .37316 Mdot
.12951 .48041 Mdot
.3522 .59856 Mdot
.38371 .079 Mdot
.25589 .22644 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50296 .61403 Mdot
.50944 .60528 Mdot
.53007 .57757 Mdot
.59555 .49421 Mdot
.79589 .35276 Mdot
.22511 .49851 Mdot
.41851 .57079 Mdot
.49495 .57547 Mdot
.56382 .51788 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51159 .60239 Mdot
.53691 .56847 Mdot
.6171 .46945 Mdot
.85752 .35431 Mdot
.28423 .49845 Mdot
.47771 .51905 Mdot
.63788 .40663 Mdot
.97994 .38808 Mdot
.35201 .50634 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00191 Mdot
.49549 .00609 Mdot
.48563 .01939 Mdot
.45426 .06122 Mdot
.35521 .17768 Mdot
.06771 .23858 Mdot
.68168 .10442 Mdot
.51274 .09262 Mdot
.36287 .20459 Mdot
.03183 .2339 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61069 Mdot
.51732 .59467 Mdot
.55512 .54459 Mdot
.67395 .41357 Mdot
.00479 .41801 Mdot
.32844 .54799 Mdot
.44177 .60077 Mdot
.4697 .01066 Mdot
.45246 .05408 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.5115 .60251 Mdot
.53661 .56887 Mdot
.61617 .47048 Mdot
.85491 .35385 Mdot
.28237 .49835 Mdot
.47602 .5205 Mdot
.63383 .41055 Mdot
.96955 .38249 Mdot
.35067 .50149 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.4982 .00244 Mdot
.49425 .00777 Mdot
.48168 .02471 Mdot
.4417 .07756 Mdot
.31621 .21252 Mdot
.97235 .18701 Mdot
.66976 .05783 Mdot
.57619 .6079 Mdot
.59259 .52683 Mdot
.74016 .37957 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50639 .6094 Mdot
.52037 .59057 Mdot
.56481 .53213 Mdot
.70381 .39076 Mdot
.07155 .45487 Mdot
.33555 .58161 Mdot
.39448 .05439 Mdot
.30646 .19275 Mdot
.99458 .18773 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39525 .1346 Mdot
.17745 .26708 Mdot
.7453 .1196 Mdot
.55178 .07244 Mdot
.43457 .1314 Mdot
.22196 .27666 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49135 .01169 Mdot
.47244 .03711 Mdot
.4124 .11428 Mdot
.22749 .26035 Mdot
.80623 .12192 Mdot
.60896 .02862 Mdot
.56266 .59005 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00476 Mdot
.48878 .01514 Mdot
.46428 .04798 Mdot
.38665 .1444 Mdot
.15299 .26538 Mdot
.7236 .11986 Mdot
.52966 .09253 Mdot
.37995 .19356 Mdot
.06676 .25365 Mdot
.65634 .13093 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01627 Mdot
.46162 .05151 Mdot
.37828 .15367 Mdot
.12964 .26099 Mdot
.70734 .11872 Mdot
.51526 .1046 Mdot
.34602 .22609 Mdot
.98019 .20778 Mdot
.644 .09176 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.50771 .60762 Mdot
.52456 .58495 Mdot
.57809 .51542 Mdot
.74412 .36798 Mdot
.14872 .48664 Mdot
.36132 .59955 Mdot
.39123 .07468 Mdot
.27039 .22102 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00698 Mdot
.48355 .0222 Mdot
.44763 .06988 Mdot
.33455 .19709 Mdot
.01565 .21158 Mdot
.67331 .08083 Mdot
.54252 .04188 Mdot
.47476 .06519 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00476 Mdot
.48879 .01514 Mdot
.46428 .04798 Mdot
.38665 .1444 Mdot
.15301 .26538 Mdot
.72361 .11986 Mdot
.52967 .09251 Mdot
.37999 .19352 Mdot
.06686 .2537 Mdot
.65637 .13096 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00225 Mdot
.49469 .00717 Mdot
.4831 .02281 Mdot
.44619 .07175 Mdot
.33009 .20101 Mdot
.00486 .20551 Mdot
.67234 .07518 Mdot
.55069 .02898 Mdot
.5038 .02546 Mdot
.46261 .05981 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.4932 .00918 Mdot
.47835 .02919 Mdot
.43111 .09108 Mdot
.28374 .23533 Mdot
.90297 .15084 Mdot
.6589 .02682 Mdot
.61551 .54692 Mdot
.73057 .40048 Mdot
.08258 .47365 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.5101 .60439 Mdot
.53218 .57476 Mdot
.60219 .48641 Mdot
.81516 .35106 Mdot
.24714 .49858 Mdot
.44042 .55253 Mdot
.54641 .51012 Mdot
.72102 .36501 Mdot
.13042 .47283 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48971 .0139 Mdot
.46722 .04408 Mdot
.3959 .13385 Mdot
.17932 .26708 Mdot
.74717 .11956 Mdot
.55372 .07071 Mdot
.43931 .12561 Mdot
.23606 .27259 Mdot
.795 .13091 Mdot
.50005 .61796 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50168 .61577 Mdot
.50535 .61081 Mdot
.51704 .59505 Mdot
.55423 .54574 Mdot
.6712 .41592 Mdot
.99823 .41427 Mdot
.32792 .54449 Mdot
.44692 .59279 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49336 .00897 Mdot
.47885 .02851 Mdot
.43272 .08904 Mdot
.28865 .23226 Mdot
.91284 .15544 Mdot
.66134 .0302 Mdot
.61247 .55243 Mdot
.71861 .40775 Mdot
.05886 .46108 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48984 .01373 Mdot
.46763 .04353 Mdot
.39719 .13235 Mdot
.18305 .26703 Mdot
.75099 .11949 Mdot
.55765 .0672 Mdot
.44891 .11375 Mdot
.26486 .26065 Mdot
.84311 .13765 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49066 .01261 Mdot
.47026 .04002 Mdot
.40551 .12256 Mdot
.20721 .2648 Mdot
.77875 .11966 Mdot
.58514 .04444 Mdot
.51324 .03218 Mdot
.46118 .06781 Mdot
.35146 .18637 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52883 .57922 Mdot
.59163 .4989 Mdot
.7844 .35478 Mdot
.21035 .49777 Mdot
.40493 .58076 Mdot
.46525 .61271 Mdot
.47386 .01881 Mdot
.44343 .07016 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51436 .59864 Mdot
.54574 .55683 Mdot
.64477 .44037 Mdot
.93224 .37943 Mdot
.3183 .5136 Mdot
.48728 .52537 Mdot
.63721 .41336 Mdot
.96839 .38424 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51056 .60377 Mdot
.53364 .57281 Mdot
.60681 .48106 Mdot
.82845 .35108 Mdot
.26039 .49831 Mdot
.45412 .54025 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49765 .00317 Mdot
.49253 .01009 Mdot
.4762 .03208 Mdot
.4243 .09964 Mdot
.26308 .24669 Mdot
.86393 .13536 Mdot
.64491 .01882 Mdot
.61446 .53966 Mdot
.74127 .39234 Mdot
.10646 .48383 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51104 .60312 Mdot
.53517 .57078 Mdot
.61162 .47558 Mdot
.84211 .35207 Mdot
.27245 .49815 Mdot
.50123 .61637 Mdot
.50393 .61272 Mdot
.51253 .60112 Mdot
.53989 .56452 Mdot
.62648 .45923 Mdot
.88342 .36057 Mdot
.30001 .50089 Mdot
.48956 .51055 Mdot
.66347 .38428 Mdot
.04169 .42249 Mdot
.35809 .5373 Mdot
.50023 .61773 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50728 .6082 Mdot
.52318 .58679 Mdot
.57374 .52085 Mdot
.73099 .37435 Mdot
.12527 .47886 Mdot
.35046 .59798 Mdot
.38291 .07897 Mdot
.25514 .22643 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .60219 Mdot
.53736 .56787 Mdot
.61852 .46788 Mdot
.86148 .35507 Mdot
.28696 .49866 Mdot
.48012 .51704 Mdot
.64354 .40129 Mdot
.99425 .39595 Mdot
.35358 .51334 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50717 .60835 Mdot
.52283 .58726 Mdot
.57263 .52224 Mdot
.72764 .37614 Mdot
.11902 .47648 Mdot
.34806 .5969 Mdot
.38225 .07834 Mdot
.2555 .22579 Mdot
.89016 .13186 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50232 .61489 Mdot
.50741 .60803 Mdot
.52359 .58624 Mdot
.57504 .51923 Mdot
.73491 .37234 Mdot
.13244 .48144 Mdot
.35346 .59889 Mdot
.38444 .07882 Mdot
.2569 .22623 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00438 Mdot
.48968 .01393 Mdot
.46714 .04418 Mdot
.39565 .13414 Mdot
.17861 .26709 Mdot
.74646 .11958 Mdot
.55298 .07137 Mdot
.4375 .12783 Mdot
.23066 .27429 Mdot
.78685 .13068 Mdot
.50094 .61677 Mdot
.50298 .61401 Mdot
.50949 .60521 Mdot
.53024 .57735 Mdot
.59607 .4936 Mdot
.79741 .35255 Mdot
.22696 .49855 Mdot
.42029 .5694 Mdot
.49898 .57035 Mdot
.57613 .50244 Mdot
.76316 .3554 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61025 Mdot
.51837 .59326 Mdot
.55846 .54027 Mdot
.68428 .40513 Mdot
.02877 .43166 Mdot
.33034 .5608 Mdot
.42295 .01144 Mdot
.40444 .0948 Mdot
.25105 .24234 Mdot
.50132 .61626 Mdot
.50419 .61237 Mdot
.51336 .6 Mdot
.54254 .56103 Mdot
.63477 .4505 Mdot
.90584 .36822 Mdot
.31006 .50538 Mdot
.49234 .51248 Mdot
.66313 .38638 Mdot
.03796 .42123 Mdot
.35639 .53702 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50476 .61161 Mdot
.51516 .59758 Mdot
.54825 .55353 Mdot
.65263 .43274 Mdot
.95244 .3893 Mdot
.32253 .52179 Mdot
.47826 .54188 Mdot
.60147 .45406 Mdot
.86679 .34449 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.52311 .58689 Mdot
.57351 .52114 Mdot
.73028 .37473 Mdot
.12396 .47837 Mdot
.34994 .59777 Mdot
.38272 .07889 Mdot
.25507 .22636 Mdot
.88881 .13146 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01025 Mdot
.47582 .03259 Mdot
.42309 .10114 Mdot
.25944 .24843 Mdot
.85748 .13327 Mdot
.64185 .0185 Mdot
.61192 .54111 Mdot
.73638 .39411 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60898 Mdot
.52135 .58925 Mdot
.56793 .52817 Mdot
.71334 .38452 Mdot
.09117 .46449 Mdot
.33961 .58926 Mdot
.38616 .068 Mdot
.27614 .21356 Mdot
.9306 .15123 Mdot
.5008 .61695 Mdot
.50255 .6146 Mdot
.50811 .60708 Mdot
.52583 .58324 Mdot
.58213 .51044 Mdot
.75622 .36301 Mdot
.16887 .49179 Mdot
.37313 .59734 Mdot
.40662 .06099 Mdot
.30794 .19886 Mdot
.98618 .18607 Mdot
.5004 .61749 Mdot
.50128 .6163 Mdot
.50409 .6125 Mdot
.51304 .60043 Mdot
.54153 .56237 Mdot
.6316 .4538 Mdot
.89734 .36509 Mdot
.30661 .5034 Mdot
.49209 .51073 Mdot
.66571 .3834 Mdot
.04536 .42488 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51054 .60379 Mdot
.53358 .57289 Mdot
.60663 .48127 Mdot
.82792 .35106 Mdot
.25989 .49832 Mdot
.4536 .54072 Mdot
.57869 .47071 Mdot
.81706 .33607 Mdot
.27329 .48204 Mdot
.5 0 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .00499 Mdot
.48822 .0159 Mdot
.4625 .05034 Mdot
.38104 .15064 Mdot
.1373 .26271 Mdot
.71222 .11931 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50482 .61152 Mdot
.51535 .59731 Mdot
.54888 .55271 Mdot
.65458 .4309 Mdot
.95738 .39185 Mdot
.32335 .524 Mdot
.47549 .54664 Mdot
.59101 .46679 Mdot
.83573 .34014 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01098 Mdot
.47411 .03487 Mdot
.41769 .10782 Mdot
.24323 .25523 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48804 .01615 Mdot
.46191 .05113 Mdot
.37918 .15268 Mdot
.13214 .26158 Mdot
.70889 .11893 Mdot
.51645 .10371 Mdot
.34864 .22382 Mdot
.98649 .21131 Mdot
.64458 .09496 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50883 .60611 Mdot
.52813 .58016 Mdot
.58941 .50157 Mdot
.77785 .35628 Mdot
.20138 .49699 Mdot
.39723 .58578 Mdot
.44941 .01386 Mdot
.42699 .07919 Mdot
.29886 .21984 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47145 .03843 Mdot
.40928 .11805 Mdot
.21828 .26267 Mdot
.79327 .12054 Mdot
.59822 .03516 Mdot
.54134 .6153 Mdot
.54577 .57345 Mdot
.6179 .47388 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49399 .00811 Mdot
.48086 .02581 Mdot
.4391 .08091 Mdot
.30819 .2187 Mdot
.95433 .17694 Mdot
.66804 .04853 Mdot
.58952 .58788 Mdot
.6383 .47521 Mdot
.86941 .36727 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50139 .61616 Mdot
.50441 .61207 Mdot
.51406 .59905 Mdot
.54478 .55808 Mdot
.6418 .44334 Mdot
.92446 .37591 Mdot
.31623 .51086 Mdot
.48963 .52047 Mdot
.6475 .40248 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50976 .60486 Mdot
.53108 .57623 Mdot
.59873 .49046 Mdot
.80515 .35168 Mdot
.23611 .49867 Mdot
.42925 .56212 Mdot
.51973 .54387 Mdot
.63972 .43035 Mdot
.9434 .37898 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50704 .60853 Mdot
.52241 .58782 Mdot
.5713 .52391 Mdot
.7236 .37839 Mdot
.11136 .4734 Mdot
.34538 .59524 Mdot
.38226 .07667 Mdot
.25821 .22401 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00182 Mdot
.49572 .00579 Mdot
.48635 .01843 Mdot
.45653 .05823 Mdot
.36232 .17053 Mdot
.0864 .24675 Mdot
.68715 .11056 Mdot
.50826 .1029 Mdot
.34177 .22659 Mdot
.97513 .20363 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50767 .60767 Mdot
.52444 .5851 Mdot
.57772 .51588 Mdot
.74301 .36848 Mdot
.14679 .48607 Mdot
.36031 .59958 Mdot
.39017 .07547 Mdot
.26806 .22207 Mdot
.90875 .14203 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48082 .02587 Mdot
.43896 .08108 Mdot
.30776 .21902 Mdot
.95339 .17642 Mdot
.66794 .04806 Mdot
.59018 .5869 Mdot
.64056 .47288 Mdot
.87541 .36883 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .00399 Mdot
.49058 .01272 Mdot
.46999 .04038 Mdot
.40466 .12357 Mdot
.20471 .26518 Mdot
.77564 .11955 Mdot
.5822 .04669 Mdot
.50666 .04052 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48953 .01414 Mdot
.46664 .04484 Mdot
.39408 .13595 Mdot
.17412 .26704 Mdot
.74204 .11968 Mdot
.54841 .07549 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .0049 Mdot
.48845 .01559 Mdot
.46322 .04938 Mdot
.38332 .14812 Mdot
.14366 .26394 Mdot
.71661 .11963 Mdot
.52304 .09834 Mdot
.36392 .20967 Mdot
.02467 .23245 Mdot
.64856 .11387 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49814 .00251 Mdot
.49407 .008 Mdot
.48112 .02546 Mdot
.43992 .07985 Mdot
.31072 .21678 Mdot
.95996 .18005 Mdot
.66863 .05138 Mdot
.58549 .59391 Mdot
.62452 .4899 Mdot
.83184 .36144 Mdot
.50077 .617 Mdot
.50244 .61474 Mdot
.50777 .60754 Mdot
.52475 .58469 Mdot
.5787 .51467 Mdot
.74595 .36717 Mdot
.15185 .48754 Mdot
.363 .59943 Mdot
.3931 .07322 Mdot
.27462 .219 Mdot
.92027 .14814 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50588 .6101 Mdot
.51872 .59278 Mdot
.55958 .53883 Mdot
.68774 .40243 Mdot
.03659 .43605 Mdot
.33104 .56488 Mdot
.41704 .02031 Mdot
.38418 .11846 Mdot
.1925 .25648 Mdot
.50042 .61746 Mdot
.50135 .61622 Mdot
.50429 .61224 Mdot
.51367 .59959 Mdot
.54351 .55975 Mdot
.63782 .44736 Mdot
.91398 .37144 Mdot
.31298 .50758 Mdot
.49169 .51529 Mdot
.65793 .39175 Mdot
.02407 .41398 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50839 .6067 Mdot
.52672 .58204 Mdot
.58496 .50697 Mdot
.76466 .36005 Mdot
.18209 .49437 Mdot
.38219 .59388 Mdot
.42127 .0459 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54176 .56206 Mdot
.63233 .45304 Mdot
.89929 .36579 Mdot
.30744 .50383 Mdot
.49223 .51102 Mdot
.66538 .38385 Mdot
.0443 .42439 Mdot
.35763 .53946 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00495 Mdot
.48833 .01576 Mdot
.46283 .0499 Mdot
.38209 .14949 Mdot
.14021 .2633 Mdot
.71419 .11947 Mdot
.52088 .10017 Mdot
.3588 .21456 Mdot
.01164 .22534 Mdot
.64703 .10761 Mdot
.50071 .61708 Mdot
.50226 .61498 Mdot
.5072 .60831 Mdot
.52293 .58712 Mdot
.57294 .52185 Mdot
.72858 .37563 Mdot
.12079 .47717 Mdot
.34871 .59723 Mdot
.38237 .07858 Mdot
.25522 .22605 Mdot
.88947 .13162 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00531 Mdot
.48749 .01689 Mdot
.46015 .05345 Mdot
.37367 .15865 Mdot
.11696 .25758 Mdot
.70019 .11721 Mdot
.51054 .10744 Mdot
.33671 .23362 Mdot
.9587 .19576 Mdot
.64195 .08093 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00697 Mdot
.48356 .02218 Mdot
.44768 .06982 Mdot
.33471 .19695 Mdot
.01604 .2118 Mdot
.67335 .08103 Mdot
.54223 .04234 Mdot
.47373 .06658 Mdot
.36599 .17665 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61025 Mdot
.51835 .59328 Mdot
.5584 .54034 Mdot
.68411 .40526 Mdot
.02838 .43143 Mdot
.33031 .56059 Mdot
.42325 .01098 Mdot
.40548 .09354 Mdot
.50056 .61727 Mdot
.50179 .61561 Mdot
.50571 .61033 Mdot
.51818 .59351 Mdot
.55786 .54105 Mdot
.68242 .4066 Mdot
.02452 .42925 Mdot
.32998 .55855 Mdot
.42623 .00648 Mdot
.41574 .081 Mdot
.28468 .22505 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00335 Mdot
.49211 .01066 Mdot
.47486 .03386 Mdot
.42007 .10488 Mdot
.25037 .25243 Mdot
.84193 .12882 Mdot
.6335 .01907 Mdot
.60264 .54842 Mdot
.71528 .40437 Mdot
.061 .45954 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49035 .01303 Mdot
.46926 .04136 Mdot
.40234 .12631 Mdot
.19797 .26604 Mdot
.7675 .11939 Mdot
.57433 .05296 Mdot
.48863 .06349 Mdot
.3859 .16044 Mdot
.1263 .26562 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .00239 Mdot
.49436 .00762 Mdot
.48203 .02424 Mdot
.44282 .07612 Mdot
.31965 .20976 Mdot
.98026 .1915 Mdot
.6704 .06203 Mdot
.57003 .61721 Mdot
.57136 .55326 Mdot
.67617 .4213 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00387 Mdot
.49087 .01234 Mdot
.47091 .03916 Mdot
.40755 .12012 Mdot
.21318 .26374 Mdot
.78644 .12005 Mdot
.59221 .03927 Mdot
.52867 .01284 Mdot
.5079 .00552 Mdot
.49896 .00648 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49581 .00567 Mdot
.48664 .01804 Mdot
.45745 .05702 Mdot
.36519 .16758 Mdot
.09404 .24977 Mdot
.6899 .11262 Mdot
.50767 .10552 Mdot
.33693 .2316 Mdot
.9622 .19688 Mdot
.50016 .61782 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61117 Mdot
.51619 .59619 Mdot
.55153 .54925 Mdot
.66281 .4233 Mdot
.9779 .40288 Mdot
.32603 .5339 Mdot
.46215 .56866 Mdot
.54205 .53013 Mdot
.50119 .61642 Mdot
.5038 .6129 Mdot
.5121 .6017 Mdot
.53853 .56633 Mdot
.6222 .46385 Mdot
.87167 .35736 Mdot
.29345 .49944 Mdot
.48534 .51302 Mdot
.65526 .39085 Mdot
.02285 .41196 Mdot
.35628 .52781 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48932 .01442 Mdot
.46599 .04571 Mdot
.39203 .1383 Mdot
.16825 .26681 Mdot
.73654 .11979 Mdot
.54272 .08066 Mdot
.41221 .15798 Mdot
.15659 .28083 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48837 .0157 Mdot
.46297 .04972 Mdot
.38252 .14901 Mdot
.14142 .26353 Mdot
.71503 .11953 Mdot
.52162 .09955 Mdot
.36055 .21291 Mdot
.01605 .22776 Mdot
.64752 .10976 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00464 Mdot
.48907 .01476 Mdot
.46518 .04678 Mdot
.38949 .14119 Mdot
.16104 .26628 Mdot
.73019 .11988 Mdot
.53622 .08659 Mdot
.39612 .1762 Mdot
.11102 .27098 Mdot
.67258 .14055 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00444 Mdot
.48953 .01413 Mdot
.46667 .04481 Mdot
.39417 .13585 Mdot
.17436 .26704 Mdot
.74228 .11967 Mdot
.54865 .07527 Mdot
.42687 .1407 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00223 Mdot
.49474 .0071 Mdot
.48325 .0226 Mdot
.44667 .07112 Mdot
.3316 .1997 Mdot
.00848 .20755 Mdot
.67265 .07709 Mdot
.54791 .03335 Mdot
.49395 .03895 Mdot
.43093 .10099 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50775 .60756 Mdot
.52469 .58476 Mdot
.57853 .51488 Mdot
.74543 .3674 Mdot
.15097 .48729 Mdot
.36252 .59947 Mdot
.39255 .07365 Mdot
.27338 .21961 Mdot
.91805 .14695 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00222 Mdot
.49475 .00709 Mdot
.48329 .02255 Mdot
.44679 .07097 Mdot
.33197 .19937 Mdot
.00937 .20806 Mdot
.67273 .07756 Mdot
.54723 .03442 Mdot
.49153 .04227 Mdot
.42315 .11078 Mdot
.50064 .61716 Mdot
.50205 .61526 Mdot
.50655 .60919 Mdot
.52086 .58991 Mdot
.56636 .53016 Mdot
.70855 .38759 Mdot
.08143 .45982 Mdot
.33742 .58566 Mdot
.38979 .06183 Mdot
.28976 .20479 Mdot
.9584 .16666 Mdot
.50038 .61751 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51245 .60123 Mdot
.53964 .56486 Mdot
.62568 .46009 Mdot
.88124 .35993 Mdot
.29886 .50057 Mdot
.48892 .51083 Mdot
.66238 .38509 Mdot
.0393 .42115 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49347 .00882 Mdot
.4792 .02805 Mdot
.43382 .08764 Mdot
.29202 .23008 Mdot
.91975 .15879 Mdot
.66282 .03283 Mdot
.6097 .55703 Mdot
.7084 .4145 Mdot
.03773 .44915 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49846 .00208 Mdot
.49509 .00663 Mdot
.48437 .0211 Mdot
.45023 .06648 Mdot
.34266 .18972 Mdot
.03569 .22253 Mdot
.67563 .0908 Mdot
.52871 .06433 Mdot
.42462 .13163 Mdot
.21163 .27491 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50476 .6116 Mdot
.51518 .59755 Mdot
.54832 .55343 Mdot
.65285 .43254 Mdot
.95299 .38959 Mdot
.32263 .52203 Mdot
.47796 .5424 Mdot
.60033 .45543 Mdot
.86343 .3438 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51016 .60431 Mdot
.53237 .57451 Mdot
.60279 .48571 Mdot
.8169 .35101 Mdot
.24896 .49855 Mdot
.44229 .55088 Mdot
.55095 .50445 Mdot
.73473 .35758 Mdot
.15615 .48021 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.47621 .03207 Mdot
.42432 .09961 Mdot
.26315 .24665 Mdot
.86407 .1354 Mdot
.64498 .01883 Mdot
.61451 .53964 Mdot
.74135 .39231 Mdot
.10658 .4839 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01782 Mdot
.45796 .05634 Mdot
.3668 .1659 Mdot
.09836 .2514 Mdot
.6916 .11368 Mdot
.50766 .10657 Mdot
.33523 .23346 Mdot
.95747 .19451 Mdot
.64275 .07921 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.49671 .00445 Mdot
.4895 .01418 Mdot
.46656 .04494 Mdot
.39384 .13622 Mdot
.17343 .26702 Mdot
.74139 .11969 Mdot
.54772 .07611 Mdot
.42458 .14344 Mdot
.19249 .28146 Mdot
.73709 .1344 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00382 Mdot
.491 .01215 Mdot
.47134 .03858 Mdot
.40892 .11848 Mdot
.21721 .26291 Mdot
.79182 .12043 Mdot
.59697 .03599 Mdot
.53874 .00043 Mdot
.53804 .58353 Mdot
.59387 .50146 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00553 Mdot
.48697 .01759 Mdot
.4585 .05563 Mdot
.36848 .16415 Mdot
.10289 .25302 Mdot
.69349 .11468 Mdot
.50793 .10733 Mdot
.33426 .23468 Mdot
.95454 .19311 Mdot
.64209 .0782 Mdot
.50098 .61672 Mdot
.50311 .61383 Mdot
.5099 .60466 Mdot
.53155 .57561 Mdot
.60019 .48874 Mdot
.8094 .35135 Mdot
.24091 .49865 Mdot
.43407 .55804 Mdot
.53114 .52936 Mdot
.67462 .39805 Mdot
.03056 .42621 Mdot
.50085 .61689 Mdot
.5027 .61439 Mdot
.5086 .60642 Mdot
.52738 .58117 Mdot
.58703 .50444 Mdot
.77083 .35816 Mdot
.19131 .49579 Mdot
.38911 .59047 Mdot
.43371 .03213 Mdot
.38173 .13195 Mdot
.16822 .26045 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00565 Mdot
.48668 .01798 Mdot
.45759 .05683 Mdot
.36564 .16711 Mdot
.09525 .25024 Mdot
.69036 .11293 Mdot
.50764 .10585 Mdot
.33637 .23219 Mdot
.96068 .19611 Mdot
.64337 .08046 Mdot
.50045 .61742 Mdot
.50145 .61608 Mdot
.50462 .6118 Mdot
.5147 .59819 Mdot
.54682 .5554 Mdot
.64816 .43705 Mdot
.94099 .38359 Mdot
.32033 .51697 Mdot
.48386 .53191 Mdot
.62322 .42875 Mdot
.92948 .36549 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49486 .00695 Mdot
.48361 .02212 Mdot
.44782 .06963 Mdot
.33516 .19655 Mdot
.01714 .21241 Mdot
.67346 .0816 Mdot
.54143 .04363 Mdot
.47084 .07051 Mdot
.35675 .18609 Mdot
.50098 .61671 Mdot
.50312 .61381 Mdot
.50995 .6046 Mdot
.53169 .57541 Mdot
.60066 .48819 Mdot
.81075 .35126 Mdot
.2424 .49864 Mdot
.43558 .55675 Mdot
.53474 .52479 Mdot
.68562 .38916 Mdot
.05595 .43996 Mdot
.50034 .61757 Mdot
.50109 .61655 Mdot
.50349 .61332 Mdot
.51111 .60303 Mdot
.53539 .57049 Mdot
.61232 .47479 Mdot
.8441 .35229 Mdot
.27408 .49815 Mdot
.46806 .52756 Mdot
.61445 .43038 Mdot
.91808 .35774 Mdot
.50027 .61766 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.52831 .57993 Mdot
.58996 .5009 Mdot
.77949 .35588 Mdot
.20367 .49722 Mdot
.39915 .58457 Mdot
.45329 .00922 Mdot
.43838 .06493 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00325 Mdot
.49233 .01036 Mdot
.47558 .03291 Mdot
.42233 .10209 Mdot
.25714 .24949 Mdot
.85345 .13203 Mdot
.63982 .01845 Mdot
.60996 .54247 Mdot
.73223 .39584 Mdot
.09174 .47626 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49212 .01064 Mdot
.4749 .03381 Mdot
.42019 .10474 Mdot
.25073 .25228 Mdot
.84253 .12898 Mdot
.63385 .01901 Mdot
.60308 .54803 Mdot
.71636 .40377 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00636 Mdot
.485 .02025 Mdot
.45224 .06386 Mdot
.34892 .18381 Mdot
.05151 .23073 Mdot
.67818 .09796 Mdot
.51968 .07976 Mdot
.39062 .17336 Mdot
.11011 .26749 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.50849 .60657 Mdot
.52705 .58161 Mdot
.58598 .50572 Mdot
.76771 .35909 Mdot
.18669 .49511 Mdot
.38558 .59228 Mdot
.42724 .03937 Mdot
.36353 .15094 Mdot
.1193 .25147 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51103 .60314 Mdot
.53514 .57082 Mdot
.61153 .47569 Mdot
.84185 .35204 Mdot
.27224 .49815 Mdot
.46622 .52923 Mdot
.60992 .43524 Mdot
.90569 .35283 Mdot
.33479 .47993 Mdot
.50044 .61744 Mdot
.50139 .61615 Mdot
.50443 .61204 Mdot
.51413 .59896 Mdot
.54498 .55781 Mdot
.64242 .44271 Mdot
.9261 .37664 Mdot
.31669 .51142 Mdot
.4892 .52143 Mdot
.64551 .40455 Mdot
.99093 .39615 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50484 .6115 Mdot
.51542 .59723 Mdot
.54909 .55244 Mdot
.65522 .43029 Mdot
.95899 .3927 Mdot
.3236 .52475 Mdot
.47454 .54825 Mdot
.58746 .47118 Mdot
.82507 .33975 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.51589 .59658 Mdot
.5506 .55046 Mdot
.65994 .42592 Mdot
.97079 .39899 Mdot
.32521 .53036 Mdot
.46707 .56068 Mdot
.55987 .50647 Mdot
.50024 .6177 Mdot
.50078 .61698 Mdot
.50249 .61468 Mdot
.50792 .60734 Mdot
.52523 .58405 Mdot
.58022 .51279 Mdot
.7505 .36525 Mdot
.15951 .48958 Mdot
.36735 .5988 Mdot
.39846 .06864 Mdot
.2874 .21213 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54179 .56202 Mdot
.63243 .45293 Mdot
.89957 .36588 Mdot
.30755 .50389 Mdot
.49225 .51107 Mdot
.66532 .38392 Mdot
.04412 .4243 Mdot
.35759 .5394 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.5259 .58315 Mdot
.58235 .51016 Mdot
.75689 .36276 Mdot
.16994 .49202 Mdot
.37383 .59712 Mdot
.40767 .05996 Mdot
.31065 .19692 Mdot
.99203 .18953 Mdot
.49986 .00018 Mdot
.49956 .00059 Mdot
.49861 .00187 Mdot
.49558 .00597 Mdot
.48592 .019 Mdot
.45517 .06002 Mdot
.35806 .17484 Mdot
.07517 .24196 Mdot
.68367 .10705 Mdot
.51046 .09736 Mdot
.35294 .2151 Mdot
.00489 .21964 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60842 Mdot
.52266 .58748 Mdot
.57209 .52291 Mdot
.726 .37704 Mdot
.11594 .47527 Mdot
.34694 .59628 Mdot
.38215 .07778 Mdot
.2563 .22521 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51017 .6043 Mdot
.53239 .57449 Mdot
.60285 .48564 Mdot
.81707 .351 Mdot
.24913 .49854 Mdot
.44247 .55072 Mdot
.55138 .50391 Mdot
.73603 .35694 Mdot
.1585 .48076 Mdot
.50036 .61754 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.51171 .60223 Mdot
.53728 .56798 Mdot
.61828 .46814 Mdot
.86081 .35494 Mdot
.28651 .49862 Mdot
.47973 .51736 Mdot
.64262 .40214 Mdot
.99194 .39467 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49516 .00654 Mdot
.48458 .02081 Mdot
.4509 .06561 Mdot
.34475 .18777 Mdot
.04093 .2253 Mdot
.67639 .09325 Mdot
.5255 .06971 Mdot
.4127 .14664 Mdot
.17543 .27829 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.50578 .61022 Mdot
.51842 .59318 Mdot
.55864 .54004 Mdot
.68483 .40469 Mdot
.03003 .43237 Mdot
.33045 .56146 Mdot
.42199 .01289 Mdot
.40113 .09876 Mdot
.24133 .24609 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46216 .05079 Mdot
.37998 .15181 Mdot
.13435 .26208 Mdot
.71029 .11911 Mdot
.51757 .10285 Mdot
.35116 .22158 Mdot
.99264 .21476 Mdot
.64516 .09809 Mdot
.50035 .61756 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51127 .60281 Mdot
.5359 .56981 Mdot
.61393 .47298 Mdot
.84864 .35288 Mdot
.27768 .49819 Mdot
.47158 .5244 Mdot
.62308 .42134 Mdot
.94134 .36818 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.504 .61263 Mdot
.51274 .60084 Mdot
.54057 .56363 Mdot
.62859 .45698 Mdot
.88919 .36235 Mdot
.30289 .50182 Mdot
.49093 .51022 Mdot
.66538 .38304 Mdot
.04561 .42475 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00341 Mdot
.49195 .01087 Mdot
.47436 .03454 Mdot
.41847 .10686 Mdot
.24557 .25435 Mdot
.83403 .12689 Mdot
.62871 .02016 Mdot
.5961 .55442 Mdot
.69903 .41437 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49737 .00355 Mdot
.49162 .01132 Mdot
.47331 .03594 Mdot
.41516 .11092 Mdot
.23569 .25787 Mdot
.81845 .12376 Mdot
.6182 .02398 Mdot
.5794 .57142 Mdot
.65482 .44948 Mdot
.92755 .38461 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.4866 .01809 Mdot
.45732 .05719 Mdot
.36479 .16799 Mdot
.09297 .24936 Mdot
.68949 .11235 Mdot
.5077 .10521 Mdot
.33747 .23103 Mdot
.96365 .19763 Mdot
.64389 .08168 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01653 Mdot
.46101 .05232 Mdot
.37635 .15576 Mdot
.12432 .25965 Mdot
.7042 .11817 Mdot
.51301 .10612 Mdot
.34129 .23005 Mdot
.96906 .20155 Mdot
.64294 .08614 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49169 .01123 Mdot
.47352 .03566 Mdot
.41581 .11012 Mdot
.23763 .25722 Mdot
.82144 .12429 Mdot
.62033 .02307 Mdot
.583 .5676 Mdot
.66461 .44078 Mdot
.95141 .39644 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50755 .60784 Mdot
.52405 .58563 Mdot
.57648 .51743 Mdot
.73927 .37022 Mdot
.14025 .48405 Mdot
.35704 .59946 Mdot
.3871 .07753 Mdot
.26165 .22468 Mdot
.89811 .13654 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50476 .61161 Mdot
.51516 .59757 Mdot
.54827 .55351 Mdot
.65267 .4327 Mdot
.95255 .38936 Mdot
.32255 .52184 Mdot
.4782 .54199 Mdot
.60124 .45434 Mdot
.86611 .34434 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49272 .00984 Mdot
.4768 .03127 Mdot
.42621 .09725 Mdot
.26887 .24376 Mdot
.87446 .13907 Mdot
.64944 .02001 Mdot
.61705 .53906 Mdot
.74484 .39159 Mdot
.11124 .48652 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .0025 Mdot
.49411 .00796 Mdot
.48123 .02532 Mdot
.44026 .07942 Mdot
.31176 .21599 Mdot
.96227 .18134 Mdot
.66885 .05257 Mdot
.5838 .59645 Mdot
.61872 .49632 Mdot
.81565 .36115 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00438 Mdot
.48966 .01396 Mdot
.46707 .04427 Mdot
.39543 .13439 Mdot
.17799 .26709 Mdot
.74583 .11959 Mdot
.55233 .07195 Mdot
.43591 .12977 Mdot
.22595 .27563 Mdot
.77997 .13069 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51337 .59998 Mdot
.54258 .56097 Mdot
.63491 .45035 Mdot
.90622 .36836 Mdot
.3102 .50548 Mdot
.49233 .51259 Mdot
.66294 .38657 Mdot
.03746 .42097 Mdot
.3563 .53681 Mdot
.50045 .61742 Mdot
.50145 .61608 Mdot
.50461 .61181 Mdot
.51468 .59823 Mdot
.54673 .55553 Mdot
.64786 .43734 Mdot
.94023 .38323 Mdot
.32016 .51666 Mdot
.48418 .5313 Mdot
.62452 .42729 Mdot
.93316 .36713 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61118 Mdot
.51617 .59621 Mdot
.55148 .54931 Mdot
.66268 .42342 Mdot
.97758 .4027 Mdot
.32599 .53374 Mdot
.46238 .56829 Mdot
.54286 .52904 Mdot
.68686 .39296 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00424 Mdot
.48999 .01352 Mdot
.46812 .04288 Mdot
.39874 .13054 Mdot
.18752 .26686 Mdot
.75573 .11941 Mdot
.56252 .06294 Mdot
.46068 .09902 Mdot
.30046 .23921 Mdot
.91341 .16284 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49179 .01109 Mdot
.47384 .03523 Mdot
.41684 .10887 Mdot
.24068 .25616 Mdot
.8262 .12521 Mdot
.62361 .02179 Mdot
.58835 .56206 Mdot
.67892 .42899 Mdot
.9848 .41492 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00598 Mdot
.48589 .01905 Mdot
.45507 .06015 Mdot
.35775 .17515 Mdot
.07434 .24159 Mdot
.68344 .10677 Mdot
.51068 .09687 Mdot
.35394 .21405 Mdot
.0076 .22109 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49667 .0045 Mdot
.48939 .01433 Mdot
.46621 .04542 Mdot
.39271 .13752 Mdot
.17019 .2669 Mdot
.73833 .11975 Mdot
.54456 .07898 Mdot
.41677 .15267 Mdot
.16975 .28185 Mdot
.71371 .13812 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00908 Mdot
.47858 .02888 Mdot
.43185 .09014 Mdot
.286 .23393 Mdot
.90749 .15292 Mdot
.66007 .02831 Mdot
.61426 .54929 Mdot
.72549 .40349 Mdot
.07264 .46851 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.505 .61129 Mdot
.51591 .59656 Mdot
.55067 .55038 Mdot
.66014 .42573 Mdot
.97129 .39926 Mdot
.32527 .53061 Mdot
.46673 .56123 Mdot
.55865 .50808 Mdot
.4996 .00054 Mdot
.49872 .00174 Mdot
.49591 .00553 Mdot
.48696 .01761 Mdot
.45847 .05567 Mdot
.36838 .16425 Mdot
.10262 .25293 Mdot
.69337 .11462 Mdot
.50791 .1073 Mdot
.33429 .23463 Mdot
.95466 .19316 Mdot
.64212 .07823 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49063 .01265 Mdot
.47016 .04015 Mdot
.40521 .12292 Mdot
.20631 .26494 Mdot
.77763 .11962 Mdot
.58408 .04524 Mdot
.51088 .03516 Mdot
.45398 .07723 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00352 Mdot
.4917 .01121 Mdot
.47357 .03559 Mdot
.41599 .10991 Mdot
.23815 .25705 Mdot
.82224 .12444 Mdot
.62089 .02284 Mdot
.58394 .56662 Mdot
.66713 .43862 Mdot
.95742 .39962 Mdot
.50113 .61651 Mdot
.5036 .61316 Mdot
.51148 .60253 Mdot
.53657 .56892 Mdot
.61604 .47063 Mdot
.85454 .35379 Mdot
.2821 .49834 Mdot
.47577 .52071 Mdot
.63324 .41112 Mdot
.96803 .38168 Mdot
.35045 .5008 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48857 .01543 Mdot
.4636 .04888 Mdot
.38451 .1468 Mdot
.14699 .2645 Mdot
.71902 .11974 Mdot
.52527 .09641 Mdot
.36927 .20443 Mdot
.0385 .23977 Mdot
.50128 .6163 Mdot
.50409 .6125 Mdot
.51304 .60043 Mdot
.54153 .56237 Mdot
.63159 .45381 Mdot
.89732 .36508 Mdot
.3066 .5034 Mdot
.49209 .51073 Mdot
.66571 .38339 Mdot
.04537 .42489 Mdot
.35789 .53981 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45742 .05706 Mdot
.3651 .16767 Mdot
.09381 .24968 Mdot
.68981 .11257 Mdot
.50767 .10546 Mdot
.33704 .23148 Mdot
.9625 .19704 Mdot
.64369 .0812 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.53641 .56913 Mdot
.61553 .47119 Mdot
.85313 .35355 Mdot
.28107 .4983 Mdot
.47481 .52155 Mdot
.63092 .41342 Mdot
.962 .37852 Mdot
.34954 .49814 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00203 Mdot
.4952 .00648 Mdot
.48472 .02062 Mdot
.45135 .06503 Mdot
.34613 .18647 Mdot
.04442 .22712 Mdot
.67694 .09485 Mdot
.52348 .07316 Mdot
.4051 .15601 Mdot
.15267 .27682 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60736 Mdot
.52516 .58413 Mdot
.58002 .51304 Mdot
.74991 .36549 Mdot
.15853 .48933 Mdot
.36678 .59891 Mdot
.39771 .06931 Mdot
.28557 .21318 Mdot
.94063 .15941 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.47621 .03206 Mdot
.42435 .09958 Mdot
.26323 .24661 Mdot
.8642 .13545 Mdot
.64504 .01884 Mdot
.61455 .53962 Mdot
.74143 .39229 Mdot
.10669 .48395 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00287 Mdot
.49322 .00916 Mdot
.4784 .02912 Mdot
.43129 .09086 Mdot
.28428 .23499 Mdot
.90405 .15133 Mdot
.65919 .02716 Mdot
.61523 .54746 Mdot
.72942 .40115 Mdot
.08035 .47251 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46507 .04694 Mdot
.38912 .14161 Mdot
.15999 .26618 Mdot
.7293 .11988 Mdot
.53533 .0874 Mdot
.3939 .17864 Mdot
.10486 .26897 Mdot
.66966 .13982 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51094 .60327 Mdot
.53483 .57124 Mdot
.61055 .4768 Mdot
.83908 .35176 Mdot
.26991 .49815 Mdot
.46388 .53135 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.4663 .0453 Mdot
.393 .13719 Mdot
.17103 .26694 Mdot
.73911 .11974 Mdot
.54537 .07824 Mdot
.41877 .15032 Mdot
.17554 .28201 Mdot
.71923 .13722 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.4933 .00905 Mdot
.47866 .02877 Mdot
.4321 .08982 Mdot
.28676 .23345 Mdot
.90903 .15364 Mdot
.66044 .02884 Mdot
.61378 .55015 Mdot
.72361 .40463 Mdot
.0689 .46653 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00286 Mdot
.49324 .00913 Mdot
.47848 .02902 Mdot
.43152 .09056 Mdot
.285 .23455 Mdot
.90548 .15199 Mdot
.65956 .02763 Mdot
.61485 .5482 Mdot
.72784 .40209 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50872 .60626 Mdot
.52776 .58065 Mdot
.58825 .50297 Mdot
.77442 .35716 Mdot
.19652 .49645 Mdot
.39324 .58817 Mdot
.44156 .0231 Mdot
.40418 .10666 Mdot
.23159 .25322 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51288 .60064 Mdot
.54102 .56303 Mdot
.63001 .45547 Mdot
.89305 .36362 Mdot
.30471 .50253 Mdot
.4916 .51032 Mdot
.66589 .3829 Mdot
.04634 .42525 Mdot
.35826 .53996 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00506 Mdot
.48806 .01612 Mdot
.46197 .05104 Mdot
.37938 .15246 Mdot
.1327 .26171 Mdot
.70924 .11898 Mdot
.51673 .1035 Mdot
.34926 .22327 Mdot
.988 .21216 Mdot
.64472 .09573 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01505 Mdot
.4645 .04769 Mdot
.38735 .14362 Mdot
.15497 .26563 Mdot
.72517 .11988 Mdot
.5312 .09114 Mdot
.38373 .18959 Mdot
.07696 .25819 Mdot
.6592 .13402 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50587 .6101 Mdot
.51871 .5928 Mdot
.55955 .53887 Mdot
.68763 .40251 Mdot
.03636 .43592 Mdot
.33102 .56476 Mdot
.41722 .02006 Mdot
.38476 .11779 Mdot
.19417 .25635 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60972 Mdot
.5196 .5916 Mdot
.56237 .53525 Mdot
.69631 .39603 Mdot
.05553 .44646 Mdot
.33313 .57433 Mdot
.40384 .04011 Mdot
.33894 .16521 Mdot
.07162 .22939 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .0024 Mdot
.49435 .00764 Mdot
.48199 .0243 Mdot
.44267 .07631 Mdot
.3192 .21013 Mdot
.97921 .19091 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .0156 Mdot
.46319 .04942 Mdot
.38323 .14822 Mdot
.1434 .26389 Mdot
.71642 .11962 Mdot
.52287 .09849 Mdot
.36352 .21006 Mdot
.02363 .23189 Mdot
.64842 .11339 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00197 Mdot
.49536 .00627 Mdot
.48521 .01996 Mdot
.45292 .06297 Mdot
.35102 .18178 Mdot
.0569 .23341 Mdot
.67923 .10021 Mdot
.51708 .08441 Mdot
.38051 .18507 Mdot
.08106 .25701 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.50099 .61669 Mdot
.50317 .61376 Mdot
.51009 .60441 Mdot
.53213 .57483 Mdot
.60203 .48659 Mdot
.8147 .35107 Mdot
.24665 .49859 Mdot
.43992 .55297 Mdot
.5452 .51162 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61545 Mdot
.5061 .60979 Mdot
.51944 .59181 Mdot
.56188 .53588 Mdot
.69481 .39711 Mdot
.05227 .4447 Mdot
.33272 .57276 Mdot
.40598 .03691 Mdot
.34626 .15828 Mdot
.50054 .6173 Mdot
.50172 .61571 Mdot
.50548 .61063 Mdot
.51747 .59446 Mdot
.55562 .54394 Mdot
.67549 .41227 Mdot
.00842 .42008 Mdot
.32872 .54994 Mdot
.4389 .6052 Mdot
.45967 .02415 Mdot
.4206 .09475 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .00179 Mdot
.49577 .00571 Mdot
.48653 .01818 Mdot
.45711 .05747 Mdot
.36412 .16868 Mdot
.09119 .24867 Mdot
.68883 .11188 Mdot
.5078 .10465 Mdot
.33847 .22999 Mdot
.96634 .19902 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60553 Mdot
.52948 .57836 Mdot
.59367 .49645 Mdot
.79039 .35363 Mdot
.21819 .49824 Mdot
.41202 .57571 Mdot
.48049 .59375 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56446 Mdot
.62662 .45907 Mdot
.88383 .36069 Mdot
.30023 .50095 Mdot
.48968 .51051 Mdot
.66365 .38415 Mdot
.04208 .42271 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.4678 .04331 Mdot
.39772 .13173 Mdot
.18458 .26698 Mdot
.75259 .11946 Mdot
.5593 .06574 Mdot
.45293 .10875 Mdot
.27696 .25418 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50423 .61232 Mdot
.51346 .59986 Mdot
.54287 .56059 Mdot
.63582 .44941 Mdot
.90866 .36931 Mdot
.31111 .50611 Mdot
.49221 .51333 Mdot
.66163 .38795 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49841 .00215 Mdot
.49492 .00686 Mdot
.48383 .02182 Mdot
.44852 .06872 Mdot
.33734 .1946 Mdot
.02247 .21536 Mdot
.67401 .08432 Mdot
.53758 .0498 Mdot
.457 .08918 Mdot
.31271 .22541 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49726 .0037 Mdot
.49128 .01178 Mdot
.47221 .03741 Mdot
.41168 .11515 Mdot
.22535 .26093 Mdot
.80316 .12154 Mdot
.6065 .03002 Mdot
.55793 .59552 Mdot
.59435 .51309 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49434 .00765 Mdot
.48197 .02432 Mdot
.44261 .07638 Mdot
.31903 .21026 Mdot
.97883 .19069 Mdot
.67029 .06127 Mdot
.57115 .61551 Mdot
.57523 .54834 Mdot
.688 .41185 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00529 Mdot
.48753 .01683 Mdot
.4603 .05325 Mdot
.37414 .15814 Mdot
.11826 .25796 Mdot
.70087 .11739 Mdot
.51092 .10727 Mdot
.33735 .23315 Mdot
.96011 .19655 Mdot
.64208 .08165 Mdot
.49975 .00033 Mdot
.49922 .00106 Mdot
.49751 .00337 Mdot
.49205 .01074 Mdot
.47468 .03411 Mdot
.41949 .1056 Mdot
.24863 .25314 Mdot
.83905 .12809 Mdot
.63179 .0194 Mdot
.6004 .55042 Mdot
.70981 .40755 Mdot
.05038 .45348 Mdot
.49971 .0004 Mdot
.49906 .00126 Mdot
.49702 .00403 Mdot
.49051 .01282 Mdot
.46976 .04068 Mdot
.40393 .12443 Mdot
.20259 .26548 Mdot
.77304 .11948 Mdot
.57971 .04863 Mdot
.50102 .04768 Mdot
.42387 .1156 Mdot
.23683 .26264 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50992 .60464 Mdot
.53158 .57556 Mdot
.60031 .4886 Mdot
.80974 .35133 Mdot
.24128 .49865 Mdot
.43444 .55772 Mdot
.53203 .52822 Mdot
.67735 .39579 Mdot
.03696 .42974 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00328 Mdot
.49227 .01044 Mdot
.47538 .03317 Mdot
.42172 .10285 Mdot
.2553 .25031 Mdot
.85028 .1311 Mdot
.63815 .01851 Mdot
.6082 .54379 Mdot
.72832 .39762 Mdot
.08497 .47269 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49262 .00996 Mdot
.4765 .03167 Mdot
.42527 .09843 Mdot
.266 .24523 Mdot
.86921 .13717 Mdot
.64726 .01932 Mdot
.61599 .53909 Mdot
.74372 .39166 Mdot
.10999 .48571 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00467 Mdot
.48899 .01486 Mdot
.46495 .0471 Mdot
.38874 .14204 Mdot
.15892 .26608 Mdot
.7284 .11989 Mdot
.53442 .08823 Mdot
.39166 .18109 Mdot
.09865 .2668 Mdot
.66696 .13888 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.50761 .60776 Mdot
.52423 .58538 Mdot
.57707 .5167 Mdot
.74103 .36939 Mdot
.14336 .48503 Mdot
.35856 .59956 Mdot
.38846 .07667 Mdot
.26441 .22361 Mdot
.9026 .13885 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49526 .0064 Mdot
.4849 .02038 Mdot
.45193 .06426 Mdot
.34796 .18473 Mdot
.04906 .22949 Mdot
.67773 .0969 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49242 .01023 Mdot
.47587 .03252 Mdot
.42325 .10094 Mdot
.25993 .2482 Mdot
.85834 .13354 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.5025 .61465 Mdot
.50797 .60726 Mdot
.5254 .58382 Mdot
.58077 .51211 Mdot
.75215 .36458 Mdot
.16225 .49026 Mdot
.36899 .59846 Mdot
.40066 .06665 Mdot
.29282 .20889 Mdot
.50056 .61727 Mdot
.50179 .61561 Mdot
.50571 .61032 Mdot
.51819 .59349 Mdot
.5579 .541 Mdot
.68255 .4065 Mdot
.02481 .42941 Mdot
.33001 .5587 Mdot
.42601 .00682 Mdot
.41497 .08195 Mdot
.28238 .22645 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .0121 Mdot
.47146 .03841 Mdot
.40931 .11802 Mdot
.21835 .26265 Mdot
.79337 .12055 Mdot
.59831 .0351 Mdot
.54152 .61507 Mdot
.54632 .57274 Mdot
.6196 .47201 Mdot
.50122 .61639 Mdot
.50389 .61278 Mdot
.51239 .60131 Mdot
.53945 .56511 Mdot
.62507 .46074 Mdot
.87958 .35945 Mdot
.29797 .50035 Mdot
.48839 .5111 Mdot
.66142 .38582 Mdot
.03715 .41995 Mdot
.35766 .535 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48713 .01737 Mdot
.45903 .05494 Mdot
.37014 .16241 Mdot
.10736 .25455 Mdot
.69548 .11558 Mdot
.50846 .10774 Mdot
.33414 .23514 Mdot
.95367 .1928 Mdot
.64172 .0781 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .00561 Mdot
.48677 .01786 Mdot
.45788 .05645 Mdot
.36653 .16618 Mdot
.09764 .25113 Mdot
.6913 .11351 Mdot
.50765 .10642 Mdot
.33546 .2332 Mdot
.95813 .19483 Mdot
.64289 .07946 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50872 .60625 Mdot
.52779 .58062 Mdot
.58831 .50289 Mdot
.77462 .35711 Mdot
.19681 .49649 Mdot
.39347 .58803 Mdot
.44201 .02257 Mdot
.40549 .10513 Mdot
.23538 .25205 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49802 .00267 Mdot
.4937 .00852 Mdot
.47992 .02709 Mdot
.43609 .08476 Mdot
.29895 .22538 Mdot
.93427 .16617 Mdot
.66541 .03897 Mdot
.60235 .56853 Mdot
.68245 .43407 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00453 Mdot
.48933 .01441 Mdot
.46601 .04568 Mdot
.39209 .13823 Mdot
.16844 .26682 Mdot
.73672 .11979 Mdot
.5429 .0805 Mdot
.41265 .15747 Mdot
.15787 .28097 Mdot
.50033 .61758 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60341 Mdot
.53449 .57168 Mdot
.60949 .478 Mdot
.83606 .35151 Mdot
.26731 .49818 Mdot
.46123 .53377 Mdot
.59758 .44887 Mdot
.8713 .34214 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49394 .00818 Mdot
.4807 .02603 Mdot
.43858 .08156 Mdot
.30661 .21987 Mdot
.95085 .17503 Mdot
.66765 .0468 Mdot
.59192 .58428 Mdot
.64654 .46683 Mdot
.8912 .37364 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39525 .1346 Mdot
.17747 .26708 Mdot
.74532 .1196 Mdot
.5518 .07243 Mdot
.43461 .13136 Mdot
.22207 .27664 Mdot
.77446 .13083 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.5409 .5632 Mdot
.62962 .45589 Mdot
.89198 .36326 Mdot
.30421 .50233 Mdot
.49143 .51026 Mdot
.66581 .38289 Mdot
.04629 .42519 Mdot
.35831 .53987 Mdot
.49986 .00018 Mdot
.49957 .00059 Mdot
.49862 .00186 Mdot
.4956 .00594 Mdot
.48599 .01891 Mdot
.4554 .05971 Mdot
.35879 .1741 Mdot
.07709 .24281 Mdot
.68422 .10769 Mdot
.50998 .09844 Mdot
.3507 .21742 Mdot
.9989 .21641 Mdot
.49978 .00029 Mdot
.49931 .00094 Mdot
.49779 .00299 Mdot
.49295 .00952 Mdot
.47755 .03026 Mdot
.4286 .09425 Mdot
.27609 .23982 Mdot
.88806 .14439 Mdot
.65443 .02266 Mdot
.61777 .54121 Mdot
.74208 .39384 Mdot
.10483 .48415 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51104 .60312 Mdot
.53518 .57078 Mdot
.61164 .47556 Mdot
.84217 .35207 Mdot
.2725 .49815 Mdot
.46649 .52898 Mdot
.61057 .43453 Mdot
.90749 .35352 Mdot
.33549 .48028 Mdot
.50087 .61685 Mdot
.50279 .61427 Mdot
.50888 .60604 Mdot
.52829 .57995 Mdot
.58991 .50096 Mdot
.77935 .35591 Mdot
.20347 .4972 Mdot
.39899 .58468 Mdot
.45295 .00963 Mdot
.43737 .0662 Mdot
.33026 .19538 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00369 Mdot
.4913 .01175 Mdot
.47228 .03732 Mdot
.41189 .11489 Mdot
.22599 .26076 Mdot
.80407 .12165 Mdot
.60723 .02959 Mdot
.55935 .59387 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48723 .01724 Mdot
.45933 .05454 Mdot
.37108 .1614 Mdot
.10992 .2554 Mdot
.69668 .11606 Mdot
.50889 .10782 Mdot
.33444 .23508 Mdot
.95409 .1931 Mdot
.64165 .07845 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50497 .61132 Mdot
.51582 .59668 Mdot
.55037 .55076 Mdot
.65923 .42656 Mdot
.96904 .39804 Mdot
.32499 .5295 Mdot
.46824 .55875 Mdot
.56415 .50088 Mdot
.75371 .35337 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60934 Mdot
.5205 .59039 Mdot
.56522 .53161 Mdot
.70506 .38991 Mdot
.07417 .45621 Mdot
.33601 .58273 Mdot
.39314 .05648 Mdot
.30176 .19629 Mdot
.98416 .18163 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.5159 .59658 Mdot
.55061 .55045 Mdot
.65997 .42589 Mdot
.97087 .39903 Mdot
.32522 .5304 Mdot
.46702 .56076 Mdot
.55969 .50671 Mdot
.73982 .35947 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50264 .61447 Mdot
.50841 .60668 Mdot
.52679 .58196 Mdot
.58515 .50673 Mdot
.76524 .35986 Mdot
.18297 .49452 Mdot
.38283 .59359 Mdot
.42238 .04469 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49159 .01136 Mdot
.4732 .03609 Mdot
.4148 .11136 Mdot
.2346 .25822 Mdot
.8168 .12348 Mdot
.617 .02452 Mdot
.57733 .57366 Mdot
.64913 .45476 Mdot
.91331 .37831 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01286 Mdot
.46967 .04081 Mdot
.40364 .12479 Mdot
.20173 .2656 Mdot
.77199 .11946 Mdot
.5787 .04943 Mdot
.49871 .05063 Mdot
.4168 .12429 Mdot
.21569 .26842 Mdot
.50125 .61634 Mdot
.504 .61263 Mdot
.51273 .60084 Mdot
.54055 .56366 Mdot
.62854 .45703 Mdot
.88904 .3623 Mdot
.30283 .50179 Mdot
.49091 .51022 Mdot
.66535 .38306 Mdot
.04556 .42471 Mdot
.35835 .53937 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49633 .00495 Mdot
.48832 .01577 Mdot
.4628 .04995 Mdot
.38197 .14961 Mdot
.1399 .26324 Mdot
.71398 .11946 Mdot
.52069 .10032 Mdot
.35837 .21497 Mdot
.01054 .22473 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.49769 .00312 Mdot
.49265 .00992 Mdot
.4766 .03154 Mdot
.42556 .09807 Mdot
.26688 .24478 Mdot
.87082 .13775 Mdot
.64794 .01951 Mdot
.61637 .53903 Mdot
.7442 .39158 Mdot
.11061 .48606 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.4678 .0433 Mdot
.39774 .13171 Mdot
.18462 .26698 Mdot
.75263 .11946 Mdot
.55934 .06571 Mdot
.45302 .10864 Mdot
.27724 .25403 Mdot
.86621 .1441 Mdot
.50123 .61637 Mdot
.50393 .61273 Mdot
.51251 .60115 Mdot
.53983 .5646 Mdot
.62629 .45943 Mdot
.88291 .36041 Mdot
.29975 .50081 Mdot
.48942 .51061 Mdot
.66323 .38446 Mdot
.04117 .4222 Mdot
.35804 .53703 Mdot
.5001 .61789 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.51081 .60344 Mdot
.53442 .57178 Mdot
.60927 .47825 Mdot
.83545 .35146 Mdot
.26677 .49819 Mdot
.46068 .53427 Mdot
.59621 .45041 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50809 .60711 Mdot
.52576 .58334 Mdot
.5819 .51072 Mdot
.75553 .36327 Mdot
.16775 .49154 Mdot
.37241 .59755 Mdot
.40555 .06203 Mdot
.30519 .20079 Mdot
.98029 .18257 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50669 .60899 Mdot
.52132 .58928 Mdot
.56785 .52827 Mdot
.71308 .38468 Mdot
.09065 .46425 Mdot
.33948 .58908 Mdot
.38632 .0677 Mdot
.27678 .21316 Mdot
.93189 .15192 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49566 .00587 Mdot
.48616 .01869 Mdot
.45593 .05902 Mdot
.36042 .17246 Mdot
.08138 .24466 Mdot
.68552 .10906 Mdot
.50906 .10066 Mdot
.34618 .22207 Mdot
.98686 .20991 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00269 Mdot
.49367 .00855 Mdot
.47983 .0272 Mdot
.43581 .08511 Mdot
.29811 .22596 Mdot
.93249 .16524 Mdot
.66513 .03818 Mdot
.60336 .56699 Mdot
.68595 .43123 Mdot
.98819 .4203 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.51589 .59658 Mdot
.5506 .55046 Mdot
.65995 .42591 Mdot
.97081 .399 Mdot
.32522 .53037 Mdot
.46705 .5607 Mdot
.55983 .50653 Mdot
.74024 .35927 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50731 .60817 Mdot
.52327 .58667 Mdot
.57402 .5205 Mdot
.73184 .37391 Mdot
.12684 .47944 Mdot
.35109 .59821 Mdot
.38317 .07902 Mdot
.25532 .22648 Mdot
.88887 .13162 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.4866 .01809 Mdot
.45732 .05718 Mdot
.3648 .16798 Mdot
.09299 .24937 Mdot
.6895 .11236 Mdot
.5077 .10522 Mdot
.33745 .23104 Mdot
.96362 .19761 Mdot
.64388 .08166 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45943 .0544 Mdot
.3714 .16106 Mdot
.1108 .25568 Mdot
.6971 .11621 Mdot
.50906 .10782 Mdot
.33461 .235 Mdot
.95438 .19328 Mdot
.64164 .07863 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.5074 .60804 Mdot
.52357 .58627 Mdot
.57496 .51932 Mdot
.73469 .37245 Mdot
.13205 .4813 Mdot
.35329 .59885 Mdot
.38433 .07885 Mdot
.25674 .22627 Mdot
.89063 .13267 Mdot
.50117 .61645 Mdot
.50373 .613 Mdot
.51188 .602 Mdot
.53783 .56726 Mdot
.61998 .46627 Mdot
.86554 .35593 Mdot
.28963 .49892 Mdot
.48237 .51523 Mdot
.6487 .39658 Mdot
.00702 .40309 Mdot
.35481 .51978 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50922 .60558 Mdot
.52938 .57849 Mdot
.59336 .49682 Mdot
.78948 .35379 Mdot
.21703 .49819 Mdot
.41095 .5765 Mdot
.47816 .59668 Mdot
.49959 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45726 .05726 Mdot
.36461 .16818 Mdot
.09249 .24917 Mdot
.68931 .11223 Mdot
.50773 .10507 Mdot
.33773 .23076 Mdot
.96435 .19799 Mdot
.644 .08197 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.4649 .04716 Mdot
.38859 .14222 Mdot
.15848 .26603 Mdot
.72803 .11989 Mdot
.53405 .08857 Mdot
.39074 .18208 Mdot
.09613 .26588 Mdot
.66593 .13844 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49749 .0034 Mdot
.49199 .01082 Mdot
.47448 .03437 Mdot
.41886 .10638 Mdot
.24674 .25389 Mdot
.83594 .12734 Mdot
.6299 .01984 Mdot
.5978 .55281 Mdot
.70332 .41157 Mdot
.03739 .44591 Mdot
.50092 .61679 Mdot
.50294 .61406 Mdot
.50937 .60538 Mdot
.52985 .57786 Mdot
.59486 .49504 Mdot
.79387 .35306 Mdot
.2226 .49843 Mdot
.41613 .57263 Mdot
.48959 .58227 Mdot
.54746 .53892 Mdot
.67548 .40725 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.49192 .01092 Mdot
.47426 .03468 Mdot
.41815 .10726 Mdot
.24461 .25472 Mdot
.83247 .12654 Mdot
.62772 .02044 Mdot
.59465 .55581 Mdot
.50107 .61659 Mdot
.5034 .61343 Mdot
.51085 .60339 Mdot
.53454 .57161 Mdot
.60965 .47781 Mdot
.83653 .35155 Mdot
.26772 .49818 Mdot
.46165 .53338 Mdot
.59862 .44769 Mdot
.87424 .34287 Mdot
.31947 .47658 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00506 Mdot
.48806 .01612 Mdot
.46197 .05104 Mdot
.37938 .15247 Mdot
.13268 .26171 Mdot
.70923 .11898 Mdot
.51672 .10351 Mdot
.34924 .22329 Mdot
.98795 .21213 Mdot
.64472 .09571 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.51009 .6044 Mdot
.53215 .5748 Mdot
.60209 .48652 Mdot
.81489 .35107 Mdot
.24685 .49858 Mdot
.44012 .55279 Mdot
.54569 .51101 Mdot
.71885 .36629 Mdot
.12619 .47139 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.46629 .04531 Mdot
.39298 .13721 Mdot
.17097 .26694 Mdot
.73906 .11974 Mdot
.54532 .07829 Mdot
.41863 .15048 Mdot
.17515 .28201 Mdot
.71885 .13728 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50474 .61163 Mdot
.5151 .59765 Mdot
.54807 .55376 Mdot
.65206 .43328 Mdot
.951 .38857 Mdot
.32228 .52116 Mdot
.47903 .54055 Mdot
.6044 .45056 Mdot
.87538 .34648 Mdot
.50114 .61649 Mdot
.50365 .61311 Mdot
.51162 .60234 Mdot
.53701 .56834 Mdot
.61743 .46909 Mdot
.85842 .35448 Mdot
.28487 .4985 Mdot
.47828 .51857 Mdot
.63923 .40534 Mdot
.98338 .38996 Mdot
.35242 .50799 Mdot
.50109 .61656 Mdot
.50346 .61335 Mdot
.51104 .60313 Mdot
.53516 .5708 Mdot
.61158 .47563 Mdot
.84199 .35205 Mdot
.27236 .49815 Mdot
.46634 .52912 Mdot
.61021 .43491 Mdot
.90651 .35314 Mdot
.33511 .48009 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50575 .61026 Mdot
.51833 .59331 Mdot
.55834 .54043 Mdot
.68391 .40542 Mdot
.02793 .43118 Mdot
.33027 .56035 Mdot
.4236 .01046 Mdot
.40667 .09211 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.51011 .60438 Mdot
.53219 .57474 Mdot
.60224 .48635 Mdot
.81531 .35105 Mdot
.2473 .49858 Mdot
.44058 .55239 Mdot
.5468 .50962 Mdot
.72221 .36432 Mdot
.13273 .47359 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49732 .00362 Mdot
.49147 .01152 Mdot
.47284 .03657 Mdot
.41367 .11273 Mdot
.23127 .25926 Mdot
.81178 .12269 Mdot
.61327 .02633 Mdot
.57067 .58098 Mdot
.63061 .47304 Mdot
.86522 .3625 Mdot
.50019 .61778 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60973 Mdot
.51958 .59163 Mdot
.5623 .53533 Mdot
.69612 .39616 Mdot
.05511 .44624 Mdot
.33308 .57413 Mdot
.40411 .03971 Mdot
.33985 .16436 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00225 Mdot
.49468 .00718 Mdot
.48306 .02285 Mdot
.44608 .07189 Mdot
.32976 .20129 Mdot
.00407 .20506 Mdot
.67227 .07477 Mdot
.5513 .02803 Mdot
.50594 .02252 Mdot
.4695 .05063 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00353 Mdot
.49166 .01126 Mdot
.47345 .03576 Mdot
.41559 .1104 Mdot
.23695 .25745 Mdot
.82039 .1241 Mdot
.61959 .02338 Mdot
.58177 .5689 Mdot
.66127 .4437 Mdot
.94335 .39228 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49243 .01023 Mdot
.47588 .03251 Mdot
.42328 .10091 Mdot
.26001 .24816 Mdot
.85847 .13358 Mdot
.64234 .01852 Mdot
.61236 .54083 Mdot
.73728 .39376 Mdot
.50018 .61778 Mdot
.50059 .61724 Mdot
.50188 .6155 Mdot
.50598 .60995 Mdot
.51906 .59233 Mdot
.56065 .53746 Mdot
.69103 .39992 Mdot
.04394 .44014 Mdot
.33177 .56863 Mdot
.41171 .02832 Mdot
.36589 .13845 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00256 Mdot
.49397 .00815 Mdot
.48079 .02591 Mdot
.43886 .08121 Mdot
.30745 .21925 Mdot
.9527 .17604 Mdot
.66786 .04772 Mdot
.59065 .58618 Mdot
.64219 .47121 Mdot
.87975 .37004 Mdot
.49993 .0001 Mdot
.49978 .0003 Mdot
.49928 .00097 Mdot
.49772 .00308 Mdot
.49273 .00981 Mdot
.47686 .03119 Mdot
.42638 .09703 Mdot
.26938 .24349 Mdot
.87541 .13942 Mdot
.64981 .02016 Mdot
.6172 .5391 Mdot
.74491 .39163 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49188 .01097 Mdot
.47412 .03486 Mdot
.41772 .10778 Mdot
.24333 .2552 Mdot
.83042 .12609 Mdot
.6264 .02084 Mdot
.59268 .55773 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01686 Mdot
.46024 .05333 Mdot
.37395 .15835 Mdot
.11773 .25781 Mdot
.70059 .11732 Mdot
.51077 .10734 Mdot
.33708 .23335 Mdot
.95951 .19622 Mdot
.64202 .08135 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49394 .00819 Mdot
.48068 .02605 Mdot
.43853 .08163 Mdot
.30645 .21999 Mdot
.95049 .17483 Mdot
.66761 .04662 Mdot
.59217 .58391 Mdot
.64739 .46598 Mdot
.89341 .37439 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00637 Mdot
.48499 .02026 Mdot
.4522 .06392 Mdot
.34878 .18394 Mdot
.05115 .23055 Mdot
.67811 .09781 Mdot
.51986 .07944 Mdot
.39132 .17255 Mdot
.11213 .26811 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49376 .00843 Mdot
.48011 .02683 Mdot
.4367 .08397 Mdot
.30083 .22406 Mdot
.9383 .16828 Mdot
.66602 .0408 Mdot
.6 .57212 Mdot
.67429 .44095 Mdot
.96082 .405 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47323 .03605 Mdot
.4149 .11124 Mdot
.23491 .25812 Mdot
.81725 .12356 Mdot
.61734 .02437 Mdot
.57791 .57303 Mdot
.65073 .45327 Mdot
.91732 .38002 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60698 Mdot
.52608 .58291 Mdot
.58292 .50947 Mdot
.75858 .36214 Mdot
.17263 .49259 Mdot
.37561 .59652 Mdot
.41041 .05722 Mdot
.31782 .19157 Mdot
.00786 .19885 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.49329 .00906 Mdot
.47864 .0288 Mdot
.43203 .08992 Mdot
.28655 .23359 Mdot
.9086 .15343 Mdot
.66034 .02869 Mdot
.61392 .5499 Mdot
.72415 .4043 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00329 Mdot
.49224 .01048 Mdot
.47529 .03329 Mdot
.42143 .10321 Mdot
.25444 .25069 Mdot
.84881 .13068 Mdot
.63736 .01857 Mdot
.60731 .54449 Mdot
.72631 .39857 Mdot
.08141 .4708 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .00681 Mdot
.48393 .02168 Mdot
.44885 .06829 Mdot
.33836 .19367 Mdot
.025 .21675 Mdot
.67429 .08559 Mdot
.53581 .05267 Mdot
.45059 .09774 Mdot
.29243 .24008 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61085 Mdot
.51694 .59518 Mdot
.55392 .54614 Mdot
.67024 .41674 Mdot
.99594 .41298 Mdot
.32773 .54328 Mdot
.44869 .59002 Mdot
.49401 .59557 Mdot
.53035 .5676 Mdot
.50065 .61715 Mdot
.50207 .61523 Mdot
.50661 .6091 Mdot
.52106 .58964 Mdot
.567 .52935 Mdot
.7105 .38632 Mdot
.08542 .46176 Mdot
.33827 .58719 Mdot
.38818 .0645 Mdot
.28381 .20873 Mdot
.94609 .1597 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49814 .00251 Mdot
.49408 .008 Mdot
.48113 .02546 Mdot
.43993 .07983 Mdot
.31076 .21675 Mdot
.96005 .18011 Mdot
.66863 .05143 Mdot
.58543 .59401 Mdot
.62429 .49015 Mdot
.83121 .3614 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49737 .00355 Mdot
.49163 .01131 Mdot
.47334 .03591 Mdot
.41523 .11083 Mdot
.23591 .2578 Mdot
.81879 .12382 Mdot
.61845 .02387 Mdot
.57982 .57097 Mdot
.65597 .44844 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49006 .01343 Mdot
.46833 .04259 Mdot
.39941 .12976 Mdot
.18946 .26676 Mdot
.75783 .11939 Mdot
.56466 .06109 Mdot
.46582 .09253 Mdot
.31609 .22754 Mdot
.94793 .18012 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60459 Mdot
.53171 .57538 Mdot
.60073 .48811 Mdot
.81094 .35125 Mdot
.2426 .49864 Mdot
.43578 .55657 Mdot
.53524 .52417 Mdot
.68712 .38799 Mdot
.05935 .44174 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.49659 .0046 Mdot
.48915 .01465 Mdot
.46544 .04645 Mdot
.39028 .14029 Mdot
.16328 .26647 Mdot
.73212 .11986 Mdot
.53818 .0848 Mdot
.40097 .17079 Mdot
.12463 .27488 Mdot
.67987 .14143 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60602 Mdot
.52834 .57988 Mdot
.59008 .50076 Mdot
.77983 .3558 Mdot
.20414 .49726 Mdot
.39955 .58432 Mdot
.45411 .00824 Mdot
.44077 .0619 Mdot
.34061 .18617 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50883 .60611 Mdot
.52812 .58018 Mdot
.58937 .50162 Mdot
.77773 .35631 Mdot
.20122 .49698 Mdot
.3971 .58586 Mdot
.44915 .01417 Mdot
.42622 .08015 Mdot
.29654 .22143 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50484 .6115 Mdot
.51541 .59723 Mdot
.54908 .55245 Mdot
.6552 .43032 Mdot
.95893 .39266 Mdot
.32359 .52472 Mdot
.47458 .54818 Mdot
.58761 .471 Mdot
.82551 .33975 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51586 .59663 Mdot
.55049 .5506 Mdot
.6596 .42623 Mdot
.96995 .39853 Mdot
.32511 .52995 Mdot
.46763 .55975 Mdot
.56193 .50378 Mdot
.74679 .35627 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49357 .00869 Mdot
.4795 .02764 Mdot
.43479 .08642 Mdot
.29496 .22812 Mdot
.92586 .16184 Mdot
.66399 .03532 Mdot
.60684 .56158 Mdot
.69818 .42179 Mdot
.01572 .43633 Mdot
.50014 .61785 Mdot
.50044 .61744 Mdot
.5014 .61614 Mdot
.50447 .61199 Mdot
.51425 .5988 Mdot
.54538 .55729 Mdot
.64366 .44147 Mdot
.92934 .3781 Mdot
.31756 .51255 Mdot
.48824 .52344 Mdot
.64129 .409 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00269 Mdot
.49366 .00856 Mdot
.47982 .02722 Mdot
.43578 .08515 Mdot
.29799 .22604 Mdot
.93225 .16511 Mdot
.66509 .03807 Mdot
.60349 .56679 Mdot
.6864 .43087 Mdot
.98924 .4209 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00325 Mdot
.49232 .01037 Mdot
.47555 .03295 Mdot
.42224 .1022 Mdot
.25688 .24961 Mdot
.85301 .1319 Mdot
.63959 .01846 Mdot
.60972 .54264 Mdot
.73171 .39607 Mdot
.09085 .4758 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49768 .00314 Mdot
.4926 .01 Mdot
.47642 .03178 Mdot
.425 .09876 Mdot
.2652 .24564 Mdot
.86775 .13666 Mdot
.64662 .01916 Mdot
.61562 .5392 Mdot
.74318 .39179 Mdot
.10926 .4853 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48093 .02573 Mdot
.4393 .08065 Mdot
.30881 .21823 Mdot
.9557 .17769 Mdot
.66819 .04922 Mdot
.58855 .58933 Mdot
.63501 .47865 Mdot
.86054 .36528 Mdot
.50117 .61646 Mdot
.50371 .61302 Mdot
.51183 .60206 Mdot
.53768 .56746 Mdot
.61952 .46678 Mdot
.86425 .35565 Mdot
.2888 .49883 Mdot
.48168 .51578 Mdot
.64713 .39799 Mdot
.00317 .40093 Mdot
.35445 .51782 Mdot
.50118 .61643 Mdot
.50377 .61294 Mdot
.51202 .6018 Mdot
.53829 .56665 Mdot
.62143 .46469 Mdot
.86954 .35684 Mdot
.29216 .49924 Mdot
.48436 .51371 Mdot
.65316 .39265 Mdot
.01783 .40915 Mdot
.35582 .52527 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48755 .01681 Mdot
.46035 .05319 Mdot
.37428 .158 Mdot
.11863 .25807 Mdot
.70107 .11744 Mdot
.51104 .10722 Mdot
.33755 .233 Mdot
.96055 .1968 Mdot
.64212 .08187 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.49771 .0031 Mdot
.49269 .00988 Mdot
.47671 .03139 Mdot
.42591 .09762 Mdot
.26796 .24422 Mdot
.8728 .13846 Mdot
.64876 .01977 Mdot
.61677 .53901 Mdot
.50005 .61797 Mdot
.50015 .61783 Mdot
.50048 .61738 Mdot
.50154 .61596 Mdot
.50489 .61143 Mdot
.51558 .597 Mdot
.54961 .55175 Mdot
.65686 .42876 Mdot
.96311 .39487 Mdot
.3242 .52666 Mdot
.47204 .55245 Mdot
.50062 .61719 Mdot
.50198 .61535 Mdot
.50632 .60949 Mdot
.52015 .59086 Mdot
.56411 .53302 Mdot
.70166 .39223 Mdot
.06702 .45254 Mdot
.33479 .57964 Mdot
.39692 .05062 Mdot
.31501 .18603 Mdot
.014 .199 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50604 .60987 Mdot
.51926 .59206 Mdot
.56129 .53664 Mdot
.69299 .39846 Mdot
.04826 .44252 Mdot
.33225 .5708 Mdot
.40868 .03285 Mdot
.35553 .14913 Mdot
.11423 .24617 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60802 Mdot
.52363 .58619 Mdot
.57515 .51908 Mdot
.73526 .37217 Mdot
.13307 .48165 Mdot
.35374 .59895 Mdot
.38461 .07876 Mdot
.25717 .22616 Mdot
.89124 .133 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50733 .60814 Mdot
.52334 .58658 Mdot
.57423 .52024 Mdot
.73247 .37359 Mdot
.12799 .47986 Mdot
.35156 .59837 Mdot
.38339 .07902 Mdot
.25552 .22648 Mdot
.88907 .13177 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01652 Mdot
.46103 .05229 Mdot
.37642 .15569 Mdot
.1245 .25969 Mdot
.70431 .11819 Mdot
.51308 .10608 Mdot
.34144 .22993 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48476 .02056 Mdot
.45149 .06484 Mdot
.34658 .18604 Mdot
.04556 .2277 Mdot
.67713 .09535 Mdot
.52284 .07425 Mdot
.4027 .15894 Mdot
.14553 .27582 Mdot
.50038 .61751 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51245 .60123 Mdot
.53963 .56487 Mdot
.62566 .46011 Mdot
.88118 .35991 Mdot
.29884 .50056 Mdot
.48891 .51084 Mdot
.66235 .38511 Mdot
.03923 .42111 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51082 .60342 Mdot
.53447 .57171 Mdot
.60942 .47808 Mdot
.83587 .35149 Mdot
.26714 .49818 Mdot
.46106 .53392 Mdot
.59716 .44934 Mdot
.87011 .34186 Mdot
.31698 .47653 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49881 .00161 Mdot
.49619 .00514 Mdot
.48787 .01638 Mdot
.46137 .05183 Mdot
.3775 .15451 Mdot
.1275 .26047 Mdot
.70606 .11851 Mdot
.5143 .10527 Mdot
.34397 .22783 Mdot
.97533 .20506 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.4977 .0031 Mdot
.49269 .00988 Mdot
.4767 .03141 Mdot
.42588 .09766 Mdot
.26786 .24428 Mdot
.87261 .1384 Mdot
.64869 .01975 Mdot
.50084 .6169 Mdot
.50268 .61442 Mdot
.50853 .60651 Mdot
.52718 .58143 Mdot
.5864 .50521 Mdot
.76895 .35871 Mdot
.18854 .49539 Mdot
.38698 .59158 Mdot
.42978 .03656 Mdot
.37062 .14372 Mdot
.13808 .25626 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.47621 .03207 Mdot
.42432 .09961 Mdot
.26315 .24665 Mdot
.86406 .1354 Mdot
.64498 .01883 Mdot
.6145 .53964 Mdot
.74135 .39231 Mdot
.10657 .48389 Mdot
.50046 .61741 Mdot
.50147 .61605 Mdot
.50467 .61173 Mdot
.51488 .59796 Mdot
.54736 .55469 Mdot
.64985 .43541 Mdot
.94534 .38573 Mdot
.32122 .51874 Mdot
.48187 .53551 Mdot
.6154 .43766 Mdot
.90724 .35646 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49275 .00979 Mdot
.47691 .03112 Mdot
.42657 .0968 Mdot
.26994 .24319 Mdot
.87646 .13982 Mdot
.65023 .02033 Mdot
.61734 .53917 Mdot
.74494 .3917 Mdot
.11115 .48657 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00268 Mdot
.49367 .00854 Mdot
.47985 .02718 Mdot
.43588 .08503 Mdot
.2983 .22583 Mdot
.93291 .16546 Mdot
.6652 .03837 Mdot
.60312 .56735 Mdot
.68513 .43189 Mdot
.98631 .41922 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .6014 Mdot
.53923 .5654 Mdot
.6244 .46146 Mdot
.87775 .35894 Mdot
.29696 .50011 Mdot
.48776 .51145 Mdot
.66022 .38676 Mdot
.03443 .41843 Mdot
.35739 .53364 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00478 Mdot
.48874 .01521 Mdot
.46413 .04818 Mdot
.38618 .14492 Mdot
.15169 .2652 Mdot
.72258 .11984 Mdot
.52867 .09341 Mdot
.37752 .19608 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.4867 .01795 Mdot
.45765 .05675 Mdot
.36583 .16691 Mdot
.09577 .25043 Mdot
.69056 .11306 Mdot
.50764 .10598 Mdot
.33616 .23243 Mdot
.96008 .19581 Mdot
.64326 .08022 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60033 Mdot
.54176 .56205 Mdot
.63234 .45302 Mdot
.89934 .3658 Mdot
.30746 .50384 Mdot
.49224 .51103 Mdot
.66537 .38386 Mdot
.04427 .42438 Mdot
.35762 .53945 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45871 .05535 Mdot
.36916 .16344 Mdot
.10471 .25366 Mdot
.69428 .11506 Mdot
.50811 .10754 Mdot
.33411 .23496 Mdot
.95394 .19285 Mdot
.6419 .07805 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51043 .60395 Mdot
.53322 .57338 Mdot
.60548 .4826 Mdot
.82462 .35097 Mdot
.25674 .49839 Mdot
.45033 .54369 Mdot
.50124 .61636 Mdot
.50396 .61269 Mdot
.51261 .60101 Mdot
.54015 .56419 Mdot
.62728 .45838 Mdot
.88561 .36123 Mdot
.30113 .50122 Mdot
.49014 .51036 Mdot
.66436 .38366 Mdot
.04358 .42356 Mdot
.35824 .53828 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51236 .60135 Mdot
.53935 .56525 Mdot
.62476 .46107 Mdot
.87873 .35922 Mdot
.29751 .50024 Mdot
.48811 .51125 Mdot
.5 .61803 Mdot
.5 .61803 Mdot
.50001 .61802 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50022 .61773 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50727 .60821 Mdot
.52317 .5868 Mdot
.57371 .52088 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50745 .60797 Mdot
.52374 .58604 Mdot
.57551 .51864 Mdot
.73633 .37164 Mdot
.135 .48232 Mdot
.3546 .59913 Mdot
.38519 .07853 Mdot
.25812 .22589 Mdot
.89263 .13373 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49784 .00292 Mdot
.49311 .00931 Mdot
.47805 .0296 Mdot
.43016 .09228 Mdot
.28084 .23707 Mdot
.89726 .1483 Mdot
.65731 .02508 Mdot
.61672 .54435 Mdot
.73595 .39738 Mdot
.09298 .47875 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50642 .60936 Mdot
.52045 .59046 Mdot
.56507 .5318 Mdot
.7046 .39022 Mdot
.07321 .45572 Mdot
.33584 .58232 Mdot
.39363 .05572 Mdot
.30347 .19501 Mdot
.98793 .18384 Mdot
.5006 .61722 Mdot
.50193 .61543 Mdot
.50614 .60975 Mdot
.51955 .59167 Mdot
.5622 .53547 Mdot
.6958 .39639 Mdot
.05442 .44587 Mdot
.33299 .5738 Mdot
.40456 .03904 Mdot
.34139 .16292 Mdot
.07778 .23219 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00203 Mdot
.4952 .00648 Mdot
.48472 .02062 Mdot
.45135 .06503 Mdot
.34613 .18646 Mdot
.04443 .22712 Mdot
.67694 .09485 Mdot
.52347 .07317 Mdot
.40509 .15603 Mdot
.15263 .27681 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51134 .60271 Mdot
.53613 .56951 Mdot
.61465 .47218 Mdot
.85065 .35317 Mdot
.27922 .49823 Mdot
.47306 .52309 Mdot
.62669 .41766 Mdot
.9509 .37286 Mdot
.3476 .49352 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48906 .01477 Mdot
.46515 .04682 Mdot
.3894 .1413 Mdot
.16077 .26626 Mdot
.72995 .11988 Mdot
.53598 .0868 Mdot
.39553 .17684 Mdot
.10939 .27046 Mdot
.67178 .14038 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50877 .60619 Mdot
.52792 .58044 Mdot
.58875 .50236 Mdot
.77592 .35677 Mdot
.19865 .4967 Mdot
.39498 .58715 Mdot
.44495 .01914 Mdot
.41398 .09506 Mdot
.26017 .2423 Mdot
.50123 .61637 Mdot
.50391 .61275 Mdot
.51246 .60121 Mdot
.53969 .56479 Mdot
.62585 .4599 Mdot
.88171 .36006 Mdot
.29912 .50064 Mdot
.48907 .51076 Mdot
.66263 .3849 Mdot
.03985 .42146 Mdot
.35792 .53637 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.494 .0081 Mdot
.48089 .02578 Mdot
.43918 .0808 Mdot
.30844 .21851 Mdot
.95488 .17724 Mdot
.6681 .0488 Mdot
.58913 .58846 Mdot
.63698 .47658 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48082 .02587 Mdot
.43897 .08107 Mdot
.30779 .219 Mdot
.95344 .17645 Mdot
.66794 .04808 Mdot
.59014 .58695 Mdot
.64044 .473 Mdot
.8751 .36874 Mdot
.50027 .61766 Mdot
.50087 .61685 Mdot
.50278 .61428 Mdot
.50886 .60606 Mdot
.52823 .58003 Mdot
.58972 .50119 Mdot
.77879 .35605 Mdot
.20269 .49712 Mdot
.39833 .5851 Mdot
.45162 .01123 Mdot
.43345 .07114 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49434 .00764 Mdot
.48197 .02432 Mdot
.44262 .07637 Mdot
.31906 .21024 Mdot
.97889 .19072 Mdot
.67029 .0613 Mdot
.57111 .61558 Mdot
.57508 .54854 Mdot
.68753 .41221 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.49191 .01093 Mdot
.47423 .03471 Mdot
.41806 .10736 Mdot
.24434 .25482 Mdot
.83204 .12644 Mdot
.62745 .02052 Mdot
.59425 .5562 Mdot
.69431 .41759 Mdot
.01863 .43482 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48685 .01775 Mdot
.45813 .05612 Mdot
.36733 .16535 Mdot
.09978 .25191 Mdot
.69217 .114 Mdot
.50772 .10685 Mdot
.33483 .23393 Mdot
.95633 .19395 Mdot
.64252 .07879 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60119 Mdot
.53973 .56474 Mdot
.62596 .45978 Mdot
.88202 .36015 Mdot
.29928 .50068 Mdot
.48916 .51072 Mdot
.6628 .38478 Mdot
.04021 .42166 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60601 Mdot
.52837 .57985 Mdot
.59015 .50067 Mdot
.78004 .35575 Mdot
.20443 .49729 Mdot
.3998 .58416 Mdot
.4546 .00764 Mdot
.44224 .06003 Mdot
.34511 .182 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49175 .01114 Mdot
.47373 .03538 Mdot
.41649 .10929 Mdot
.23966 .25652 Mdot
.8246 .12489 Mdot
.62253 .0222 Mdot
.58661 .56384 Mdot
.6743 .43268 Mdot
.97421 .40887 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00543 Mdot
.48719 .01729 Mdot
.45921 .0547 Mdot
.3707 .16181 Mdot
.10889 .25506 Mdot
.69619 .11587 Mdot
.50871 .1078 Mdot
.33429 .23513 Mdot
.95384 .19293 Mdot
.64166 .07827 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51092 .60329 Mdot
.53478 .57131 Mdot
.61038 .47699 Mdot
.8386 .35172 Mdot
.26951 .49816 Mdot
.46347 .53173 Mdot
.60311 .44269 Mdot
.88683 .34639 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49513 .00658 Mdot
.48448 .02095 Mdot
.45059 .06602 Mdot
.34376 .18869 Mdot
.03845 .22399 Mdot
.67602 .0921 Mdot
.527 .0672 Mdot
.41827 .13968 Mdot
.19227 .27762 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00314 Mdot
.4926 .00999 Mdot
.47643 .03177 Mdot
.42503 .09872 Mdot
.26529 .24559 Mdot
.86792 .13672 Mdot
.6467 .01918 Mdot
.61566 .53918 Mdot
.74325 .39177 Mdot
.10935 .48535 Mdot
.50003 .618 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50266 .61445 Mdot
.50846 .6066 Mdot
.52696 .58173 Mdot
.58569 .50608 Mdot
.76684 .35936 Mdot
.18539 .49491 Mdot
.38461 .59276 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00425 Mdot
.48997 .01355 Mdot
.46804 .04298 Mdot
.3985 .13083 Mdot
.18682 .2669 Mdot
.75497 .11942 Mdot
.56174 .06361 Mdot
.45881 .10138 Mdot
.29477 .24312 Mdot
.90139 .15745 Mdot
.50011 .61788 Mdot
.50035 .61755 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51147 .60254 Mdot
.53654 .56896 Mdot
.61595 .47073 Mdot
.8543 .35375 Mdot
.28193 .49833 Mdot
.47561 .52086 Mdot
.63284 .41151 Mdot
.50128 .61631 Mdot
.50406 .61254 Mdot
.51295 .60056 Mdot
.54122 .56276 Mdot
.63065 .4548 Mdot
.89478 .3642 Mdot
.30549 .50287 Mdot
.49183 .51045 Mdot
.66591 .38302 Mdot
.04617 .42522 Mdot
.35814 .54 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.5073 .60818 Mdot
.52324 .58671 Mdot
.57393 .5206 Mdot
.73158 .37404 Mdot
.12636 .47927 Mdot
.3509 .59814 Mdot
.38308 .07901 Mdot
.25525 .22647 Mdot
.88881 .13158 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49135 .01168 Mdot
.47244 .0371 Mdot
.41241 .11427 Mdot
.22752 .26034 Mdot
.80627 .12193 Mdot
.60899 .0286 Mdot
.56272 .58998 Mdot
.60811 .49729 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49247 .01017 Mdot
.47602 .03231 Mdot
.42374 .10034 Mdot
.26138 .24751 Mdot
.86091 .13436 Mdot
.64351 .01863 Mdot
.61337 .54023 Mdot
.73925 .39302 Mdot
.10332 .48222 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48815 .016 Mdot
.46225 .05067 Mdot
.38026 .15149 Mdot
.13514 .26226 Mdot
.7108 .11916 Mdot
.51799 .10252 Mdot
.35212 .22072 Mdot
.99499 .21607 Mdot
.64537 .09928 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50478 .61157 Mdot
.51524 .59746 Mdot
.54852 .55317 Mdot
.65347 .43194 Mdot
.95458 .3904 Mdot
.32289 .52274 Mdot
.47708 .54391 Mdot
.59701 .45944 Mdot
.85362 .34208 Mdot
.50019 .61777 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50628 .60954 Mdot
.52002 .59103 Mdot
.56371 .53353 Mdot
.70044 .39308 Mdot
.06441 .45118 Mdot
.33439 .57847 Mdot
.3984 .04835 Mdot
.32016 .18179 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49346 .00883 Mdot
.47917 .02809 Mdot
.43373 .08776 Mdot
.29172 .23027 Mdot
.91914 .15849 Mdot
.6627 .03259 Mdot
.60996 .55661 Mdot
.70935 .41385 Mdot
.03974 .4503 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.5111 .60305 Mdot
.53535 .57054 Mdot
.6122 .47493 Mdot
.84374 .35225 Mdot
.27379 .49815 Mdot
.46777 .52782 Mdot
.61373 .43114 Mdot
.91613 .35694 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49156 .01141 Mdot
.4731 .03622 Mdot
.41449 .11173 Mdot
.2337 .25851 Mdot
.81543 .12326 Mdot
.616 .02499 Mdot
.57557 .57557 Mdot
.64427 .4594 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51264 .60096 Mdot
.54027 .56403 Mdot
.62765 .45798 Mdot
.88662 .36154 Mdot
.30164 .50138 Mdot
.49038 .5103 Mdot
.66471 .38344 Mdot
.04429 .42397 Mdot
.35829 .53866 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51257 .60106 Mdot
.54004 .56433 Mdot
.62694 .45873 Mdot
.8847 .36095 Mdot
.30067 .50108 Mdot
.48991 .51043 Mdot
.66402 .3839 Mdot
.04285 .42315 Mdot
.35819 .5379 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48092 .02574 Mdot
.43926 .08069 Mdot
.30871 .21831 Mdot
.95547 .17757 Mdot
.66816 .0491 Mdot
.58871 .58909 Mdot
.63555 .47808 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .00399 Mdot
.49058 .01272 Mdot
.47 .04036 Mdot
.4047 .12353 Mdot
.20483 .26517 Mdot
.77577 .11955 Mdot
.58233 .04659 Mdot
.50695 .04014 Mdot
.442 .09273 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49852 .002 Mdot
.49528 .00638 Mdot
.48495 .02032 Mdot
.45207 .06408 Mdot
.34839 .18432 Mdot
.05015 .23005 Mdot
.67793 .09737 Mdot
.52037 .07854 Mdot
.3933 .17021 Mdot
.11789 .26978 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49022 .01321 Mdot
.46883 .04192 Mdot
.401 .12789 Mdot
.19407 .26642 Mdot
.76299 .11937 Mdot
.56985 .05667 Mdot
.47815 .07686 Mdot
.35379 .19413 Mdot
.03969 .23054 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .00301 Mdot
.49291 .00958 Mdot
.47742 .03044 Mdot
.42817 .0948 Mdot
.27478 .24056 Mdot
.88556 .14337 Mdot
.65358 .02208 Mdot
.61785 .54058 Mdot
.74317 .39317 Mdot
.10701 .48507 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48853 .01548 Mdot
.46348 .04905 Mdot
.38412 .14723 Mdot
.14589 .26432 Mdot
.71821 .11971 Mdot
.52452 .09707 Mdot
.36746 .20622 Mdot
.03379 .23731 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.5053 .61087 Mdot
.51689 .59524 Mdot
.55377 .54633 Mdot
.66979 .41714 Mdot
.99485 .41236 Mdot
.32764 .54269 Mdot
.44954 .58869 Mdot
.49701 .59146 Mdot
.54001 .55476 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50854 .6065 Mdot
.52721 .5814 Mdot
.58648 .50512 Mdot
.76918 .35864 Mdot
.18889 .49544 Mdot
.38724 .59145 Mdot
.43027 .03601 Mdot
.372 .14229 Mdot
.14177 .25701 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49587 .00557 Mdot
.48686 .01774 Mdot
.45815 .0561 Mdot
.36738 .1653 Mdot
.09991 .25196 Mdot
.69223 .11403 Mdot
.50772 .10687 Mdot
.3348 .23397 Mdot
.95623 .1939 Mdot
.64249 .07876 Mdot
.50095 .61676 Mdot
.50301 .61397 Mdot
.50959 .60508 Mdot
.53056 .57693 Mdot
.59707 .49241 Mdot
.80033 .35218 Mdot
.23048 .49862 Mdot
.4237 .56668 Mdot
.5068 .56038 Mdot
.60008 .47359 Mdot
.8338 .34603 Mdot
.50019 .61778 Mdot
.50059 .61724 Mdot
.50188 .61549 Mdot
.506 .60993 Mdot
.5191 .59227 Mdot
.5608 .53726 Mdot
.69149 .39958 Mdot
.04496 .4407 Mdot
.33188 .56915 Mdot
.41098 .0294 Mdot
.36341 .14105 Mdot
.49981 .00025 Mdot
.4994 .0008 Mdot
.4981 .00256 Mdot
.49396 .00816 Mdot
.48075 .02597 Mdot
.43873 .08138 Mdot
.30705 .21955 Mdot
.95181 .17555 Mdot
.66776 .04727 Mdot
.59127 .58525 Mdot
.64431 .46906 Mdot
.88535 .37173 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49603 .00536 Mdot
.48736 .01706 Mdot
.45976 .05396 Mdot
.37245 .15996 Mdot
.11363 .25657 Mdot
.69849 .11669 Mdot
.50968 .10772 Mdot
.33538 .23454 Mdot
.95588 .19416 Mdot
.64172 .07947 Mdot
.49966 .00047 Mdot
.4989 .00149 Mdot
.4965 .00473 Mdot
.48884 .01507 Mdot
.46446 .04774 Mdot
.38723 .14375 Mdot
.15463 .26559 Mdot
.7249 .11988 Mdot
.53093 .09138 Mdot
.38307 .19029 Mdot
.07517 .25742 Mdot
.65866 .13351 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00376 Mdot
.49114 .01196 Mdot
.47179 .03798 Mdot
.41034 .11677 Mdot
.22139 .26194 Mdot
.79757 .12094 Mdot
.60189 .0328 Mdot
.54881 .6063 Mdot
.5678 .54533 Mdot
.68544 .40975 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01616 Mdot
.46188 .05117 Mdot
.37909 .15278 Mdot
.13189 .26153 Mdot
.70873 .11891 Mdot
.51633 .10381 Mdot
.34836 .22406 Mdot
.98583 .21094 Mdot
.64452 .09463 Mdot
.50125 .61635 Mdot
.50398 .61266 Mdot
.51267 .60093 Mdot
.54035 .56392 Mdot
.62791 .4577 Mdot
.88734 .36176 Mdot
.302 .5015 Mdot
.49055 .51026 Mdot
.66492 .3833 Mdot
.04473 .42423 Mdot
.35832 .5389 Mdot
.49992 .0001 Mdot
.49975 .00033 Mdot
.49922 .00105 Mdot
.49751 .00336 Mdot
.49207 .01071 Mdot
.47475 .03401 Mdot
.41972 .10532 Mdot
.24931 .25286 Mdot
.84017 .12837 Mdot
.63246 .01927 Mdot
.60129 .54961 Mdot
.71199 .40626 Mdot
.50026 .61768 Mdot
.50082 .61692 Mdot
.50262 .61449 Mdot
.50836 .60674 Mdot
.52664 .58216 Mdot
.58469 .5073 Mdot
.76386 .36031 Mdot
.18086 .49415 Mdot
.38131 .59427 Mdot
.41975 .04752 Mdot
.34287 .17065 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52555 .58361 Mdot
.58125 .51152 Mdot
.7536 .36401 Mdot
.16462 .49083 Mdot
.37044 .5981 Mdot
.40269 .06476 Mdot
.29791 .20567 Mdot
.96512 .1736 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49573 .00576 Mdot
.48641 .01835 Mdot
.45672 .05798 Mdot
.3629 .16994 Mdot
.08794 .24737 Mdot
.68768 .111 Mdot
.50808 .1035 Mdot
.34061 .22778 Mdot
.97206 .20201 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.48671 .01794 Mdot
.45768 .05672 Mdot
.36591 .16683 Mdot
.09596 .2505 Mdot
.69064 .1131 Mdot
.50763 .10603 Mdot
.33608 .23251 Mdot
.95986 .1957 Mdot
.64322 .08013 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50343 .61339 Mdot
.51094 .60326 Mdot
.53485 .57121 Mdot
.6106 .47673 Mdot
.83923 .35178 Mdot
.27004 .49815 Mdot
.46401 .53123 Mdot
.60446 .4412 Mdot
.89059 .34757 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60601 Mdot
.52835 .57986 Mdot
.59011 .50072 Mdot
.77994 .35577 Mdot
.20428 .49727 Mdot
.39968 .58424 Mdot
.45435 .00795 Mdot
.44149 .06097 Mdot
.34284 .18412 Mdot
.50109 .61656 Mdot
.50347 .61334 Mdot
.51107 .60309 Mdot
.53525 .57068 Mdot
.61187 .4753 Mdot
.84283 .35214 Mdot
.27304 .49815 Mdot
.46703 .52849 Mdot
.61191 .43309 Mdot
.91115 .35493 Mdot
.33685 .48105 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50994 .60462 Mdot
.53165 .57547 Mdot
.60052 .48836 Mdot
.81034 .35129 Mdot
.24194 .49865 Mdot
.43511 .55715 Mdot
.53363 .5262 Mdot
.68222 .39183 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49834 .00225 Mdot
.4947 .00715 Mdot
.48313 .02276 Mdot
.4463 .07161 Mdot
.33043 .20071 Mdot
.00568 .20597 Mdot
.67241 .07562 Mdot
.55006 .02998 Mdot
.50155 .02853 Mdot
.45539 .06935 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51667 .59554 Mdot
.55307 .54725 Mdot
.66759 .41905 Mdot
.98956 .40938 Mdot
.32718 .53991 Mdot
.45358 .58233 Mdot
.51134 .57183 Mdot
.58611 .49584 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.5047 .61168 Mdot
.51498 .59781 Mdot
.5477 .55425 Mdot
.6509 .4344 Mdot
.94803 .38707 Mdot
.32174 .51988 Mdot
.48055 .53786 Mdot
.61027 .44362 Mdot
.89247 .35135 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00286 Mdot
.49326 .0091 Mdot
.47854 .02893 Mdot
.43173 .0903 Mdot
.28561 .23417 Mdot
.90672 .15256 Mdot
.65987 .02805 Mdot
.61449 .54886 Mdot
.72642 .40293 Mdot
.07446 .46947 Mdot
.50028 .61765 Mdot
.5009 .61682 Mdot
.50286 .61417 Mdot
.5091 .60574 Mdot
.52899 .57901 Mdot
.59213 .49829 Mdot
.78588 .35448 Mdot
.21232 .49791 Mdot
.40668 .57955 Mdot
.46896 .60814 Mdot
.48496 .00403 Mdot
.501 .61668 Mdot
.50318 .61373 Mdot
.51015 .60433 Mdot
.53231 .57458 Mdot
.60262 .4859 Mdot
.81642 .35102 Mdot
.24846 .49856 Mdot
.44178 .55134 Mdot
.5497 .50601 Mdot
.73095 .35952 Mdot
.14923 .47847 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .6121 Mdot
.51399 .59915 Mdot
.54455 .55838 Mdot
.64108 .44406 Mdot
.92258 .37508 Mdot
.31568 .51024 Mdot
.4901 .51941 Mdot
.64967 .40022 Mdot
.0021 .40217 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00388 Mdot
.49084 .01237 Mdot
.47082 .03927 Mdot
.40728 .12045 Mdot
.21239 .26389 Mdot
.7854 .11998 Mdot
.59126 .03994 Mdot
.52664 .01536 Mdot
.5018 .01369 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46026 .05331 Mdot
.37401 .15829 Mdot
.11789 .25785 Mdot
.70067 .11734 Mdot
.51081 .10732 Mdot
.33716 .23329 Mdot
.95969 .19632 Mdot
.64204 .08144 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50872 .60626 Mdot
.52776 .58066 Mdot
.58824 .50298 Mdot
.77439 .35717 Mdot
.19648 .49645 Mdot
.39321 .58819 Mdot
.4415 .02317 Mdot
.404 .10687 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51139 .60266 Mdot
.53626 .56934 Mdot
.61506 .47172 Mdot
.85179 .35334 Mdot
.28007 .49826 Mdot
.47387 .52237 Mdot
.62866 .41567 Mdot
.95609 .37548 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49483 .00699 Mdot
.48352 .02223 Mdot
.44755 .06998 Mdot
.33432 .1973 Mdot
.01508 .21126 Mdot
.67326 .08054 Mdot
.54295 .0412 Mdot
.47628 .06312 Mdot
.37415 .168 Mdot
.50097 .61673 Mdot
.50309 .61387 Mdot
.50983 .60476 Mdot
.53131 .57591 Mdot
.59947 .48959 Mdot
.80729 .3515 Mdot
.23855 .49867 Mdot
.43169 .56006 Mdot
.52549 .53654 Mdot
.65736 .41329 Mdot
.98864 .40277 Mdot
.50012 .61787 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.51271 .60088 Mdot
.54046 .56377 Mdot
.62825 .45733 Mdot
.88827 .36206 Mdot
.30245 .50166 Mdot
.49075 .51023 Mdot
.66517 .38315 Mdot
.50043 .61745 Mdot
.50137 .61619 Mdot
.50436 .61215 Mdot
.51388 .5993 Mdot
.54419 .55886 Mdot
.63994 .44521 Mdot
.91959 .37379 Mdot
.31478 .50928 Mdot
.49075 .51784 Mdot
.65286 .39694 Mdot
.01061 .40676 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51077 .60349 Mdot
.5343 .57194 Mdot
.60889 .47868 Mdot
.83436 .35139 Mdot
.26581 .4982 Mdot
.4597 .53517 Mdot
.59377 .45318 Mdot
.86051 .3398 Mdot
.31071 .47674 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49375 .00844 Mdot
.4801 .02684 Mdot
.43666 .08402 Mdot
.30072 .22414 Mdot
.93806 .16815 Mdot
.66598 .04069 Mdot
.60014 .57189 Mdot
.6748 .44051 Mdot
.96203 .40565 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52129 .58932 Mdot
.56775 .5284 Mdot
.71278 .38487 Mdot
.09004 .46396 Mdot
.33933 .58887 Mdot
.38653 .06734 Mdot
.27756 .21268 Mdot
.93344 .15276 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49517 .00653 Mdot
.48461 .02078 Mdot
.45099 .06549 Mdot
.34502 .18752 Mdot
.04161 .22565 Mdot
.6765 .09357 Mdot
.5251 .07039 Mdot
.41121 .1485 Mdot
.17093 .27821 Mdot
.50104 .61662 Mdot
.50333 .61354 Mdot
.51061 .60371 Mdot
.53378 .57263 Mdot
.60726 .48055 Mdot
.82971 .35113 Mdot
.26157 .49828 Mdot
.45534 .53914 Mdot
.58298 .46565 Mdot
.82954 .33615 Mdot
.28563 .48002 Mdot
.50037 .61753 Mdot
.50118 .61643 Mdot
.50377 .61294 Mdot
.51202 .6018 Mdot
.53828 .56666 Mdot
.62141 .46471 Mdot
.86948 .35683 Mdot
.29212 .49924 Mdot
.48434 .51374 Mdot
.6531 .3927 Mdot
.01769 .40907 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51124 .60286 Mdot
.53579 .56997 Mdot
.61356 .4734 Mdot
.84759 .35273 Mdot
.27686 .49818 Mdot
.47079 .52511 Mdot
.62115 .42333 Mdot
.93618 .36574 Mdot
.3444 .48809 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .0033 Mdot
.49221 .01052 Mdot
.47518 .03344 Mdot
.42107 .10365 Mdot
.25337 .25116 Mdot
.84699 .13017 Mdot
.63636 .01866 Mdot
.60617 .54542 Mdot
.72366 .39989 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00806 Mdot
.481 .02563 Mdot
.43952 .08036 Mdot
.30948 .21772 Mdot
.9572 .17852 Mdot
.66834 .04997 Mdot
.58748 .59093 Mdot
.63134 .48253 Mdot
.85059 .36349 Mdot
.49986 .00018 Mdot
.49957 .00058 Mdot
.49862 .00186 Mdot
.49561 .00593 Mdot
.48603 .01886 Mdot
.4555 .05958 Mdot
.3591 .1738 Mdot
.07789 .24316 Mdot
.68445 .10795 Mdot
.50979 .09888 Mdot
.3498 .21835 Mdot
.99651 .21511 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01006 Mdot
.47627 .03198 Mdot
.42452 .09936 Mdot
.26374 .24636 Mdot
.86512 .13576 Mdot
.64546 .01892 Mdot
.61485 .53948 Mdot
.74195 .39213 Mdot
.10747 .48436 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.50631 .60952 Mdot
.52009 .59094 Mdot
.56393 .53325 Mdot
.70111 .39262 Mdot
.06584 .45193 Mdot
.33461 .57911 Mdot
.39759 .0496 Mdot
.31733 .18414 Mdot
.01939 .20207 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48732 .01712 Mdot
.45961 .05416 Mdot
.37197 .16046 Mdot
.11234 .25617 Mdot
.69785 .11648 Mdot
.50938 .10778 Mdot
.33499 .23479 Mdot
.95509 .19371 Mdot
.64167 .07904 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50621 .60964 Mdot
.51979 .59135 Mdot
.56297 .53448 Mdot
.69815 .3947 Mdot
.05951 .4486 Mdot
.33367 .57622 Mdot
.40133 .0439 Mdot
.33029 .17307 Mdot
.05027 .2189 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01781 Mdot
.45798 .05632 Mdot
.36686 .16584 Mdot
.09852 .25145 Mdot
.69166 .11371 Mdot
.50767 .10661 Mdot
.33518 .23352 Mdot
.95734 .19444 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01558 Mdot
.46325 .04935 Mdot
.3834 .14803 Mdot
.14388 .26398 Mdot
.71676 .11964 Mdot
.52319 .09822 Mdot
.36426 .20934 Mdot
.02554 .23292 Mdot
.64867 .11428 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50365 .61311 Mdot
.51162 .60235 Mdot
.537 .56836 Mdot
.61737 .46915 Mdot
.85827 .35445 Mdot
.28476 .49849 Mdot
.47819 .51864 Mdot
.63901 .40555 Mdot
.98282 .38965 Mdot
.50052 .61734 Mdot
.50164 .61581 Mdot
.50524 .61096 Mdot
.51668 .59552 Mdot
.55311 .5472 Mdot
.66772 .41894 Mdot
.98987 .40955 Mdot
.3272 .54007 Mdot
.45335 .58271 Mdot
.51051 .57297 Mdot
.58342 .49913 Mdot
.50065 .61716 Mdot
.50206 .61524 Mdot
.50658 .60915 Mdot
.52095 .58978 Mdot
.56667 .52977 Mdot
.70948 .38698 Mdot
.08334 .46076 Mdot
.33782 .5864 Mdot
.389 .06313 Mdot
.28685 .20674 Mdot
.95235 .16322 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49834 .00224 Mdot
.49471 .00714 Mdot
.48316 .02272 Mdot
.44639 .07149 Mdot
.33072 .20046 Mdot
.00637 .20636 Mdot
.67247 .07598 Mdot
.54953 .03081 Mdot
.49968 .03111 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00197 Mdot
.49536 .00626 Mdot
.48523 .01994 Mdot
.45297 .06291 Mdot
.35118 .18163 Mdot
.0573 .23361 Mdot
.67931 .10038 Mdot
.5169 .08474 Mdot
.37979 .18588 Mdot
.07902 .25617 Mdot
.50087 .61685 Mdot
.50278 .61428 Mdot
.50886 .60607 Mdot
.52822 .58005 Mdot
.58969 .50123 Mdot
.77867 .35608 Mdot
.20253 .49711 Mdot
.3982 .58518 Mdot
.45135 .01154 Mdot
.43268 .07211 Mdot
.316 .20715 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01098 Mdot
.47411 .03488 Mdot
.41767 .10784 Mdot
.24319 .25525 Mdot
.83018 .12604 Mdot
.62625 .02089 Mdot
.59245 .55796 Mdot
.68966 .42089 Mdot
.00864 .4289 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.5237 .5861 Mdot
.57537 .51881 Mdot
.73592 .37184 Mdot
.13427 .48207 Mdot
.35427 .59906 Mdot
.38496 .07863 Mdot
.25774 .226 Mdot
.89207 .13344 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00264 Mdot
.49378 .0084 Mdot
.48018 .02673 Mdot
.43693 .08368 Mdot
.30155 .22355 Mdot
.93983 .16909 Mdot
.66624 .04151 Mdot
.59907 .57352 Mdot
.67109 .44375 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50165 .6158 Mdot
.50527 .61092 Mdot
.51677 .5954 Mdot
.5534 .54682 Mdot
.66862 .41815 Mdot
.99204 .41077 Mdot
.3274 .54121 Mdot
.45169 .58531 Mdot
.50464 .58101 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.48621 .01861 Mdot
.4561 .0588 Mdot
.36095 .17192 Mdot
.08278 .24525 Mdot
.68596 .10949 Mdot
.50881 .10133 Mdot
.34485 .22344 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .00509 Mdot
.48799 .01622 Mdot
.46174 .05135 Mdot
.37866 .15325 Mdot
.1307 .26125 Mdot
.70799 .11881 Mdot
.51575 .10423 Mdot
.3471 .22516 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.50089 .61683 Mdot
.50285 .61418 Mdot
.50908 .60577 Mdot
.52892 .57911 Mdot
.5919 .49857 Mdot
.7852 .35462 Mdot
.21142 .49785 Mdot
.40588 .5801 Mdot
.46726 .61025 Mdot
.50112 .61653 Mdot
.50356 .61323 Mdot
.51133 .60273 Mdot
.5361 .56955 Mdot
.61454 .4723 Mdot
.85034 .35312 Mdot
.27898 .49823 Mdot
.47283 .52329 Mdot
.62613 .41822 Mdot
.94944 .37213 Mdot
.34732 .49294 Mdot
.50008 .61792 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50872 .60625 Mdot
.52779 .58062 Mdot
.58833 .50288 Mdot
.77465 .3571 Mdot
.19686 .49649 Mdot
.39351 .58801 Mdot
.44209 .02249 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00517 Mdot
.48781 .01646 Mdot
.46117 .0521 Mdot
.37688 .15519 Mdot
.12577 .26003 Mdot
.70504 .11833 Mdot
.51358 .10575 Mdot
.34247 .22909 Mdot
.97179 .20307 Mdot
.64321 .08752 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.49341 .00891 Mdot
.47899 .02833 Mdot
.43316 .08849 Mdot
.28998 .2314 Mdot
.91557 .15675 Mdot
.66195 .03122 Mdot
.61143 .55418 Mdot
.71475 .41024 Mdot
.05097 .45669 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50722 .60828 Mdot
.523 .58703 Mdot
.57316 .52157 Mdot
.72924 .37528 Mdot
.12203 .47764 Mdot
.34919 .59745 Mdot
.38249 .07872 Mdot
.25511 .22619 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49486 .00695 Mdot
.48361 .02212 Mdot
.44782 .06963 Mdot
.33516 .19655 Mdot
.01713 .2124 Mdot
.67346 .0816 Mdot
.54143 .04362 Mdot
.47085 .07049 Mdot
.3568 .18605 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .00681 Mdot
.48393 .02169 Mdot
.44884 .0683 Mdot
.33832 .19371 Mdot
.02489 .21669 Mdot
.67428 .08553 Mdot
.53589 .05254 Mdot
.45087 .09737 Mdot
.29332 .23949 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00312 Mdot
.49263 .00995 Mdot
.47654 .03162 Mdot
.42537 .0983 Mdot
.26633 .24507 Mdot
.8698 .13738 Mdot
.64751 .01939 Mdot
.61614 .53906 Mdot
.74391 .39163 Mdot
.11025 .48585 Mdot
.50094 .61677 Mdot
.50298 .614 Mdot
.50951 .60519 Mdot
.53029 .57728 Mdot
.59623 .49341 Mdot
.79787 .35249 Mdot
.22753 .49857 Mdot
.42083 .56897 Mdot
.50022 .56877 Mdot
.57993 .49774 Mdot
.77457 .35195 Mdot
.50123 .61638 Mdot
.50391 .61275 Mdot
.51245 .60122 Mdot
.53965 .56485 Mdot
.62571 .46005 Mdot
.88133 .35995 Mdot
.29892 .50058 Mdot
.48895 .51082 Mdot
.66243 .38505 Mdot
.03941 .42121 Mdot
.35788 .53614 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49782 .00295 Mdot
.49304 .0094 Mdot
.47783 .02988 Mdot
.42948 .09314 Mdot
.27877 .23828 Mdot
.89322 .14655 Mdot
.65609 .02396 Mdot
.61733 .54281 Mdot
.73904 .39561 Mdot
.09893 .48153 Mdot
.50024 .61771 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50778 .60752 Mdot
.52479 .58463 Mdot
.57884 .51449 Mdot
.74638 .36699 Mdot
.15258 .48774 Mdot
.3634 .59939 Mdot
.39356 .07284 Mdot
.27569 .21847 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49082 .0124 Mdot
.47076 .03936 Mdot
.40707 .1207 Mdot
.21178 .26401 Mdot
.78461 .11994 Mdot
.59054 .04045 Mdot
.52509 .01729 Mdot
.49712 .01996 Mdot
.46483 .0523 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49242 .01024 Mdot
.47585 .03254 Mdot
.4232 .101 Mdot
.25978 .24827 Mdot
.85807 .13345 Mdot
.64214 .01851 Mdot
.61219 .54094 Mdot
.73692 .3939 Mdot
.09958 .48031 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60702 Mdot
.52598 .58305 Mdot
.58259 .50987 Mdot
.7576 .3625 Mdot
.17107 .49226 Mdot
.37457 .59688 Mdot
.4088 .05884 Mdot
.3136 .19476 Mdot
.99847 .19334 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49363 .00861 Mdot
.47969 .02739 Mdot
.43538 .08566 Mdot
.29677 .22688 Mdot
.92967 .16378 Mdot
.66466 .03694 Mdot
.60488 .56463 Mdot
.69129 .42701 Mdot
.00037 .42735 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00194 Mdot
.49541 .0062 Mdot
.48539 .01972 Mdot
.45348 .06224 Mdot
.35277 .18008 Mdot
.06139 .23559 Mdot
.68019 .10201 Mdot
.51513 .08801 Mdot
.37273 .19381 Mdot
.05914 .24738 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48709 .01742 Mdot
.4589 .0551 Mdot
.36975 .16281 Mdot
.10631 .2542 Mdot
.695 .11538 Mdot
.50831 .10768 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07804 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45944 .0544 Mdot
.37142 .16105 Mdot
.11084 .25569 Mdot
.69712 .11622 Mdot
.50907 .10782 Mdot
.33462 .23499 Mdot
.95439 .19329 Mdot
.64164 .07864 Mdot
.50089 .61683 Mdot
.50283 .6142 Mdot
.50903 .60584 Mdot
.52877 .57931 Mdot
.59142 .49914 Mdot
.7838 .35491 Mdot
.20954 .49771 Mdot
.40422 .58124 Mdot
.46376 .61455 Mdot
.4694 .02471 Mdot
.42941 .08803 Mdot
.50071 .61707 Mdot
.50226 .61497 Mdot
.50722 .60829 Mdot
.52299 .58705 Mdot
.57311 .52163 Mdot
.72909 .37536 Mdot
.12175 .47754 Mdot
.34908 .5974 Mdot
.38246 .0787 Mdot
.25513 .22616 Mdot
.88919 .13154 Mdot
.50019 .61778 Mdot
.5006 .61723 Mdot
.50191 .61546 Mdot
.50607 .60983 Mdot
.51935 .59193 Mdot
.56159 .53625 Mdot
.69391 .39778 Mdot
.05029 .44363 Mdot
.33249 .5718 Mdot
.4073 .03492 Mdot
.3508 .15385 Mdot
.50019 .61778 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50605 .60986 Mdot
.51927 .59204 Mdot
.56134 .53657 Mdot
.69315 .39833 Mdot
.04863 .44272 Mdot
.33229 .57098 Mdot
.40843 .03323 Mdot
.35466 .15001 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00225 Mdot
.49468 .00718 Mdot
.48306 .02286 Mdot
.44608 .07189 Mdot
.32976 .20129 Mdot
.00406 .20505 Mdot
.67227 .07476 Mdot
.55131 .02801 Mdot
.50598 .02247 Mdot
.46963 .05045 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50934 .60543 Mdot
.52974 .57802 Mdot
.59448 .49549 Mdot
.79277 .35324 Mdot
.22122 .49837 Mdot
.41483 .57362 Mdot
.4867 .58593 Mdot
.53864 .55046 Mdot
.64799 .4322 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48759 .01675 Mdot
.46049 .053 Mdot
.37473 .15751 Mdot
.11987 .25843 Mdot
.70173 .11761 Mdot
.51143 .10703 Mdot
.33825 .23247 Mdot
.96211 .19767 Mdot
.64227 .08266 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50203 .61529 Mdot
.50647 .6093 Mdot
.5206 .59026 Mdot
.56554 .5312 Mdot
.70604 .38925 Mdot
.07622 .45724 Mdot
.33639 .58357 Mdot
.39215 .05805 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48782 .01644 Mdot
.46122 .05203 Mdot
.37703 .15502 Mdot
.1262 .26014 Mdot
.70529 .11838 Mdot
.51376 .10564 Mdot
.34283 .22879 Mdot
.97264 .20355 Mdot
.64329 .08795 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .00271 Mdot
.49362 .00862 Mdot
.47966 .02743 Mdot
.43528 .08579 Mdot
.29646 .22709 Mdot
.92902 .16345 Mdot
.66455 .03667 Mdot
.60523 .5641 Mdot
.69249 .42609 Mdot
.00307 .42893 Mdot
.50061 .61721 Mdot
.50194 .61541 Mdot
.50619 .60967 Mdot
.51973 .59143 Mdot
.56277 .53473 Mdot
.69756 .39513 Mdot
.05823 .44791 Mdot
.33349 .57561 Mdot
.40213 .0427 Mdot
.33304 .17061 Mdot
.05699 .22232 Mdot
.49976 .00032 Mdot
.49923 .00103 Mdot
.49756 .0033 Mdot
.49223 .0105 Mdot
.47524 .03336 Mdot
.42126 .10342 Mdot
.25393 .25091 Mdot
.84794 .13044 Mdot
.63689 .01861 Mdot
.60678 .54492 Mdot
.72508 .39918 Mdot
.07919 .4696 Mdot
.50085 .61688 Mdot
.50271 .61437 Mdot
.50864 .60636 Mdot
.52753 .58097 Mdot
.58751 .50387 Mdot
.77224 .35776 Mdot
.19337 .49606 Mdot
.39073 .58959 Mdot
.43675 .02866 Mdot
.39037 .12245 Mdot
.19224 .26038 Mdot
.49992 .0001 Mdot
.49976 .00032 Mdot
.49923 .00103 Mdot
.49756 .0033 Mdot
.49223 .0105 Mdot
.47524 .03336 Mdot
.42125 .10343 Mdot
.25391 .25093 Mdot
.8479 .13043 Mdot
.63687 .01861 Mdot
.60675 .54494 Mdot
.72502 .39921 Mdot
.50071 .61708 Mdot
.50226 .61498 Mdot
.50719 .60832 Mdot
.52292 .58714 Mdot
.57291 .52189 Mdot
.72847 .37569 Mdot
.12059 .47709 Mdot
.34864 .59719 Mdot
.38236 .07856 Mdot
.25525 .22602 Mdot
.88954 .13164 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51264 .60097 Mdot
.54025 .56405 Mdot
.6276 .45803 Mdot
.88648 .3615 Mdot
.30157 .50136 Mdot
.49035 .5103 Mdot
.66466 .38347 Mdot
.0442 .42392 Mdot
.35829 .53861 Mdot
.49978 .0003 Mdot
.49929 .00097 Mdot
.49772 .00308 Mdot
.49275 .0098 Mdot
.47689 .03115 Mdot
.4265 .09689 Mdot
.26972 .2433 Mdot
.87605 .13967 Mdot
.65007 .02026 Mdot
.61728 .53914 Mdot
.74493 .39167 Mdot
.11119 .48657 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49329 .00907 Mdot
.47862 .02883 Mdot
.43196 .09 Mdot
.28634 .23372 Mdot
.90817 .15324 Mdot
.66023 .02854 Mdot
.61405 .54967 Mdot
.72467 .40399 Mdot
.07101 .46765 Mdot
.50013 .61786 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.51341 .59993 Mdot
.54271 .56081 Mdot
.6353 .44995 Mdot
.90726 .36876 Mdot
.31059 .50574 Mdot
.49229 .51289 Mdot
.66241 .38713 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49103 .01211 Mdot
.47143 .03845 Mdot
.40921 .11813 Mdot
.21807 .26272 Mdot
.79299 .12052 Mdot
.59798 .03532 Mdot
.54084 .61591 Mdot
.54428 .57538 Mdot
.61329 .479 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51257 .60106 Mdot
.54004 .56432 Mdot
.62695 .45872 Mdot
.88472 .36095 Mdot
.30068 .50108 Mdot
.48991 .51043 Mdot
.66402 .38389 Mdot
.04287 .42316 Mdot
.35819 .53791 Mdot
.50112 .61653 Mdot
.50356 .61323 Mdot
.51133 .60274 Mdot
.53608 .56958 Mdot
.61448 .47237 Mdot
.85017 .35309 Mdot
.27885 .49822 Mdot
.47271 .5234 Mdot
.62582 .41853 Mdot
.94862 .37173 Mdot
.34716 .49262 Mdot
.50008 .61793 Mdot
.50024 .61771 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50785 .60743 Mdot
.525 .58436 Mdot
.57949 .51369 Mdot
.74832 .36615 Mdot
.15587 .48864 Mdot
.36524 .59917 Mdot
.39577 .071 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49696 .00411 Mdot
.49032 .01308 Mdot
.46915 .0415 Mdot
.40201 .1267 Mdot
.197 .26614 Mdot
.76638 .11938 Mdot
.57322 .05387 Mdot
.48605 .06679 Mdot
.37799 .16914 Mdot
.10432 .25907 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.49009 .01338 Mdot
.46843 .04246 Mdot
.39974 .12938 Mdot
.19039 .2667 Mdot
.75887 .11938 Mdot
.5657 .06019 Mdot
.46832 .08936 Mdot
.32373 .22136 Mdot
.96557 .18968 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49066 .01262 Mdot
.47024 .04004 Mdot
.40546 .12262 Mdot
.20705 .26483 Mdot
.77855 .11965 Mdot
.58495 .04458 Mdot
.51282 .03271 Mdot
.45989 .0695 Mdot
.34744 .19025 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .6014 Mdot
.53924 .56539 Mdot
.62441 .46145 Mdot
.87776 .35895 Mdot
.29697 .50011 Mdot
.48777 .51144 Mdot
.66023 .38675 Mdot
.03446 .41844 Mdot
.3574 .53365 Mdot
.50018 .61778 Mdot
.50059 .61724 Mdot
.50187 .61551 Mdot
.50596 .60998 Mdot
.51899 .59242 Mdot
.56044 .53772 Mdot
.69039 .4004 Mdot
.04252 .43936 Mdot
.33163 .56792 Mdot
.41271 .02681 Mdot
.36933 .13479 Mdot
.50087 .61685 Mdot
.50278 .61428 Mdot
.50886 .60607 Mdot
.52822 .58004 Mdot
.58969 .50122 Mdot
.7787 .35607 Mdot
.20257 .49711 Mdot
.39823 .58516 Mdot
.45142 .01147 Mdot
.43286 .07189 Mdot
.31654 .20672 Mdot
.49984 .00022 Mdot
.49949 .0007 Mdot
.49836 .00221 Mdot
.49478 .00706 Mdot
.48336 .02245 Mdot
.44703 .07066 Mdot
.3327 .19873 Mdot
.01114 .20905 Mdot
.67289 .07849 Mdot
.54589 .03653 Mdot
.48677 .04878 Mdot
.40784 .12952 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51127 .60281 Mdot
.5359 .56981 Mdot
.61393 .47298 Mdot
.84864 .35287 Mdot
.27767 .49819 Mdot
.47158 .5244 Mdot
.62307 .42134 Mdot
.94132 .36817 Mdot
.34561 .48989 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49616 .00518 Mdot
.48778 .0165 Mdot
.46109 .05222 Mdot
.3766 .15549 Mdot
.125 .25983 Mdot
.7046 .11824 Mdot
.51327 .10595 Mdot
.34183 .22961 Mdot
.97032 .20225 Mdot
.64307 .08678 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50758 .60779 Mdot
.52415 .58549 Mdot
.57682 .51701 Mdot
.74028 .36974 Mdot
.14204 .48462 Mdot
.35791 .59953 Mdot
.38786 .07706 Mdot
.26317 .2241 Mdot
.90057 .13781 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48771 .0166 Mdot
.46085 .05252 Mdot
.37587 .15628 Mdot
.12301 .2593 Mdot
.70346 .11801 Mdot
.51251 .10643 Mdot
.34031 .23085 Mdot
.9668 .20029 Mdot
.64272 .08501 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49737 .00355 Mdot
.49163 .01131 Mdot
.47333 .03592 Mdot
.41522 .11085 Mdot
.23585 .25781 Mdot
.8187 .1238 Mdot
.61838 .0239 Mdot
.57971 .57109 Mdot
.65567 .44871 Mdot
.92965 .38559 Mdot
.50089 .61684 Mdot
.50283 .61421 Mdot
.50901 .60587 Mdot
.52869 .57942 Mdot
.59118 .49944 Mdot
.78306 .35507 Mdot
.20855 .49764 Mdot
.40336 .58182 Mdot
.46195 .61677 Mdot
.464 .03183 Mdot
.4125 .10892 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .6013 Mdot
.53947 .56509 Mdot
.62514 .46067 Mdot
.87976 .3595 Mdot
.29807 .50037 Mdot
.48845 .51107 Mdot
.66153 .38574 Mdot
.03739 .42008 Mdot
.35768 .53513 Mdot
.50035 .61755 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51147 .60254 Mdot
.53654 .56896 Mdot
.61595 .47073 Mdot
.8543 .35375 Mdot
.28193 .49833 Mdot
.47561 .52086 Mdot
.63284 .41151 Mdot
.967 .38114 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00286 Mdot
.49327 .0091 Mdot
.47855 .02892 Mdot
.43175 .09027 Mdot
.28569 .23412 Mdot
.90688 .15264 Mdot
.65991 .0281 Mdot
.61444 .54895 Mdot
.72622 .40305 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50982 .60477 Mdot
.53128 .57596 Mdot
.59936 .48971 Mdot
.80699 .35153 Mdot
.23821 .49867 Mdot
.43135 .56035 Mdot
.52469 .53755 Mdot
.65491 .41557 Mdot
.98251 .39938 Mdot
.50061 .61721 Mdot
.50194 .61541 Mdot
.50619 .60967 Mdot
.51973 .59142 Mdot
.56279 .53471 Mdot
.6976 .39509 Mdot
.05832 .44796 Mdot
.33351 .57566 Mdot
.40207 .04279 Mdot
.33283 .1708 Mdot
.05648 .22206 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00424 Mdot
.49 .01351 Mdot
.46814 .04285 Mdot
.3988 .13048 Mdot
.18768 .26686 Mdot
.7559 .11941 Mdot
.56268 .06279 Mdot
.46109 .09851 Mdot
.3017 .23834 Mdot
.50099 .6167 Mdot
.50314 .61379 Mdot
.51002 .6045 Mdot
.53191 .57512 Mdot
.60136 .48738 Mdot
.81276 .35116 Mdot
.24458 .49862 Mdot
.4378 .55482 Mdot
.54008 .51806 Mdot
.70183 .37722 Mdot
.09148 .45743 Mdot
.50053 .61732 Mdot
.50167 .61577 Mdot
.50534 .61083 Mdot
.517 .5951 Mdot
.55411 .54589 Mdot
.67084 .41622 Mdot
.99737 .41379 Mdot
.32785 .54403 Mdot
.44758 .59176 Mdot
.4901 .60093 Mdot
.51778 .58448 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50707 .60848 Mdot
.52253 .58766 Mdot
.57167 .52344 Mdot
.72472 .37776 Mdot
.1135 .47428 Mdot
.34609 .59574 Mdot
.38217 .07723 Mdot
.25721 .22462 Mdot
.89377 .13329 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48971 .0139 Mdot
.46723 .04406 Mdot
.39593 .13381 Mdot
.17942 .26708 Mdot
.74727 .11956 Mdot
.55382 .07061 Mdot
.43957 .1253 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.48659 .0181 Mdot
.45731 .0572 Mdot
.36476 .16802 Mdot
.09291 .24934 Mdot
.68947 .11234 Mdot
.50771 .10519 Mdot
.3375 .23099 Mdot
.96374 .19767 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.51589 .59658 Mdot
.5506 .55046 Mdot
.65994 .42591 Mdot
.9708 .39899 Mdot
.32521 .53037 Mdot
.46706 .56068 Mdot
.55986 .50648 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51124 .60285 Mdot
.53581 .56993 Mdot
.61364 .4733 Mdot
.84782 .35276 Mdot
.27704 .49818 Mdot
.47096 .52495 Mdot
.62157 .42289 Mdot
.93732 .36628 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49487 .00692 Mdot
.48367 .02204 Mdot
.44801 .06938 Mdot
.33575 .19602 Mdot
.01857 .2132 Mdot
.6736 .08234 Mdot
.54038 .0453 Mdot
.46708 .0756 Mdot
.34475 .19776 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49021 .01323 Mdot
.4688 .04196 Mdot
.4009 .12801 Mdot
.19378 .26644 Mdot
.76267 .11937 Mdot
.56953 .05694 Mdot
.47739 .07783 Mdot
.35146 .19639 Mdot
.5013 .61628 Mdot
.50413 .61246 Mdot
.51315 .60028 Mdot
.54187 .56191 Mdot
.63267 .45268 Mdot
.90023 .36612 Mdot
.30783 .50403 Mdot
.49228 .51119 Mdot
.66517 .38411 Mdot
.04366 .42408 Mdot
.35748 .53924 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60706 Mdot
.52588 .58318 Mdot
.58227 .51026 Mdot
.75666 .36284 Mdot
.16957 .49194 Mdot
.37359 .5972 Mdot
.4073 .06032 Mdot
.30971 .1976 Mdot
.98998 .18832 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49581 .00566 Mdot
.48664 .01803 Mdot
.45747 .05699 Mdot
.36525 .16751 Mdot
.09421 .24984 Mdot
.68996 .11267 Mdot
.50766 .10557 Mdot
.33685 .23169 Mdot
.96197 .19677 Mdot
.6436 .08098 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49093 .01225 Mdot
.47111 .03889 Mdot
.40819 .11936 Mdot
.21506 .26336 Mdot
.78893 .12021 Mdot
.59443 .03772 Mdot
.5334 .00698 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51191 .60195 Mdot
.53794 .5671 Mdot
.62035 .46586 Mdot
.86657 .35616 Mdot
.2903 .499 Mdot
.4829 .51482 Mdot
.64991 .3955 Mdot
.00998 .40474 Mdot
.35509 .52128 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00548 Mdot
.48709 .01743 Mdot
.45888 .05513 Mdot
.36968 .16289 Mdot
.10612 .25414 Mdot
.69492 .11534 Mdot
.50829 .10766 Mdot
.33409 .23509 Mdot
.95371 .19278 Mdot
.64179 .07804 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .60131 Mdot
.53945 .5651 Mdot
.6251 .46071 Mdot
.87965 .35947 Mdot
.29801 .50036 Mdot
.48842 .51108 Mdot
.66146 .38579 Mdot
.03725 .42 Mdot
.35767 .53505 Mdot
.49982 .00025 Mdot
.49941 .0008 Mdot
.49812 .00253 Mdot
.49402 .00807 Mdot
.48096 .02568 Mdot
.43942 .08049 Mdot
.30918 .21795 Mdot
.95653 .17815 Mdot
.66827 .04963 Mdot
.58797 .59021 Mdot
.63299 .48077 Mdot
.85508 .36424 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48945 .01424 Mdot
.46641 .04515 Mdot
.39336 .13678 Mdot
.17204 .26698 Mdot
.74006 .11972 Mdot
.54636 .07735 Mdot
.4212 .14745 Mdot
.18262 .28197 Mdot
.72638 .13605 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48815 .016 Mdot
.46225 .05067 Mdot
.38027 .15149 Mdot
.13516 .26226 Mdot
.71082 .11916 Mdot
.51801 .10251 Mdot
.35214 .2207 Mdot
.99505 .21611 Mdot
.64538 .09931 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00198 Mdot
.49533 .0063 Mdot
.48513 .02006 Mdot
.45267 .0633 Mdot
.35025 .18253 Mdot
.05491 .23243 Mdot
.67883 .09939 Mdot
.51801 .08273 Mdot
.38415 .1809 Mdot
.09145 .26109 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50959 .60508 Mdot
.53055 .57693 Mdot
.59706 .49242 Mdot
.80031 .35219 Mdot
.23046 .49862 Mdot
.42367 .5667 Mdot
.50674 .56045 Mdot
.59991 .47379 Mdot
.8333 .346 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00293 Mdot
.49309 .00934 Mdot
.47798 .02969 Mdot
.42994 .09257 Mdot
.28016 .23747 Mdot
.89593 .14772 Mdot
.65691 .0247 Mdot
.61695 .54381 Mdot
.73704 .39676 Mdot
.09508 .47975 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.49541 .0062 Mdot
.48537 .01975 Mdot
.45342 .06231 Mdot
.3526 .18024 Mdot
.06096 .23539 Mdot
.6801 .10184 Mdot
.51531 .08767 Mdot
.37345 .19301 Mdot
.06116 .24832 Mdot
.50118 .61645 Mdot
.50374 .61298 Mdot
.51193 .60193 Mdot
.53799 .56705 Mdot
.62048 .46572 Mdot
.86694 .35624 Mdot
.29053 .49903 Mdot
.48309 .51467 Mdot
.65033 .39513 Mdot
.01101 .40532 Mdot
.35518 .5218 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60045 Mdot
.54148 .56243 Mdot
.63146 .45395 Mdot
.89695 .36496 Mdot
.30644 .50332 Mdot
.49206 .51068 Mdot
.66576 .38333 Mdot
.04553 .42496 Mdot
.35793 .53985 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51223 .60152 Mdot
.53895 .56577 Mdot
.62352 .46241 Mdot
.87532 .35829 Mdot
.29559 .49983 Mdot
.48685 .512 Mdot
.65842 .38821 Mdot
.50018 .6178 Mdot
.50056 .61727 Mdot
.50179 .61562 Mdot
.5057 .61033 Mdot
.51817 .59352 Mdot
.55783 .54108 Mdot
.68235 .40666 Mdot
.02436 .42916 Mdot
.32997 .55846 Mdot
.42636 .00629 Mdot
.41618 .08045 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .00221 Mdot
.4948 .00703 Mdot
.48343 .02236 Mdot
.44724 .07038 Mdot
.33336 .19815 Mdot
.01276 .20996 Mdot
.67304 .07933 Mdot
.54467 .03846 Mdot
.50037 .61753 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51204 .60177 Mdot
.53836 .56655 Mdot
.62166 .46444 Mdot
.87018 .357 Mdot
.29255 .4993 Mdot
.48466 .5135 Mdot
.6538 .3921 Mdot
.01938 .41001 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.54169 .56215 Mdot
.63212 .45326 Mdot
.89873 .36558 Mdot
.3072 .5037 Mdot
.4922 .51093 Mdot
.66549 .3837 Mdot
.04465 .42455 Mdot
.35771 .53958 Mdot
.50115 .61647 Mdot
.50368 .61307 Mdot
.51171 .60222 Mdot
.53731 .56795 Mdot
.61835 .46806 Mdot
.86101 .35498 Mdot
.28665 .49863 Mdot
.47985 .51726 Mdot
.64291 .40188 Mdot
.99266 .39507 Mdot
.35342 .51255 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49723 .00375 Mdot
.49116 .01194 Mdot
.47184 .03791 Mdot
.4105 .11658 Mdot
.22188 .26182 Mdot
.79824 .121 Mdot
.60245 .03245 Mdot
.54994 .60494 Mdot
.57112 .54119 Mdot
.69546 .40222 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.4934 .00891 Mdot
.47898 .02835 Mdot
.43311 .08855 Mdot
.28983 .2315 Mdot
.91525 .15659 Mdot
.66187 .0311 Mdot
.61156 .55397 Mdot
.71522 .40993 Mdot
.05193 .45723 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.5134 .59995 Mdot
.54266 .56087 Mdot
.63516 .4501 Mdot
.90689 .36862 Mdot
.31045 .50565 Mdot
.4923 .51278 Mdot
.6626 .38693 Mdot
.03654 .42051 Mdot
.35615 .53644 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49014 .01332 Mdot
.46859 .04225 Mdot
.40022 .12881 Mdot
.1918 .2666 Mdot
.76043 .11937 Mdot
.56729 .05884 Mdot
.47209 .08458 Mdot
.33523 .21147 Mdot
.99307 .20505 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .00379 Mdot
.49106 .01207 Mdot
.47153 .03832 Mdot
.40952 .11775 Mdot
.21899 .26251 Mdot
.79424 .12063 Mdot
.59906 .03461 Mdot
.54307 .6132 Mdot
.5509 .56681 Mdot
.63377 .45689 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50775 .60757 Mdot
.52468 .58478 Mdot
.57849 .51493 Mdot
.74532 .36745 Mdot
.15077 .48723 Mdot
.36241 .59948 Mdot
.39243 .07375 Mdot
.2731 .21974 Mdot
.91755 .14668 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01616 Mdot
.46188 .05117 Mdot
.37909 .15278 Mdot
.13189 .26153 Mdot
.70873 .11891 Mdot
.51632 .10381 Mdot
.34836 .22406 Mdot
.98582 .21094 Mdot
.64452 .09462 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49673 .00441 Mdot
.4896 .01405 Mdot
.46686 .04455 Mdot
.39479 .13513 Mdot
.17614 .26707 Mdot
.74401 .11963 Mdot
.55044 .07365 Mdot
.43127 .1354 Mdot
.21219 .2788 Mdot
.76109 .13161 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49213 .01063 Mdot
.47492 .03379 Mdot
.42025 .10467 Mdot
.25089 .25221 Mdot
.84281 .12905 Mdot
.63401 .01899 Mdot
.60329 .54785 Mdot
.71685 .40349 Mdot
.06398 .46122 Mdot
.50003 .618 Mdot
.50008 .61792 Mdot
.50027 .61767 Mdot
.50086 .61688 Mdot
.50273 .61434 Mdot
.5087 .60628 Mdot
.52772 .58071 Mdot
.58812 .50312 Mdot
.77405 .35726 Mdot
.19599 .49639 Mdot
.39282 .58841 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51203 .60179 Mdot
.53831 .56662 Mdot
.6215 .4646 Mdot
.86976 .3569 Mdot
.29229 .49926 Mdot
.48446 .51364 Mdot
.65338 .39246 Mdot
.01836 .40944 Mdot
.35586 .52553 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .00509 Mdot
.488 .01621 Mdot
.46177 .05131 Mdot
.37874 .15316 Mdot
.13092 .2613 Mdot
.70813 .11883 Mdot
.51586 .10416 Mdot
.34733 .22496 Mdot
.98334 .20954 Mdot
.64429 .09336 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .6042 Mdot
.53264 .57415 Mdot
.60364 .48472 Mdot
.81935 .35096 Mdot
.25148 .4985 Mdot
.44489 .54857 Mdot
.55728 .49661 Mdot
.75375 .34911 Mdot
.18888 .4859 Mdot
.50041 .61748 Mdot
.5013 .61628 Mdot
.50413 .61245 Mdot
.51316 .60027 Mdot
.54191 .56186 Mdot
.6328 .45255 Mdot
.90056 .36624 Mdot
.30797 .50411 Mdot
.4923 .51125 Mdot
.66508 .38421 Mdot
.04341 .42396 Mdot
.50054 .6173 Mdot
.50172 .61571 Mdot
.50549 .61062 Mdot
.51749 .59444 Mdot
.55567 .54388 Mdot
.67565 .41214 Mdot
.00879 .42029 Mdot
.32875 .55014 Mdot
.43861 .60564 Mdot
.45866 .0255 Mdot
.4174 .09869 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50604 .60987 Mdot
.51924 .59208 Mdot
.56124 .5367 Mdot
.69285 .39856 Mdot
.04796 .44236 Mdot
.33222 .57065 Mdot
.40889 .03254 Mdot
.35624 .14842 Mdot
.1161 .24675 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51177 .60214 Mdot
.53749 .5677 Mdot
.61893 .46742 Mdot
.86263 .35531 Mdot
.28773 .49872 Mdot
.48078 .5165 Mdot
.64507 .39988 Mdot
.99805 .39807 Mdot
.35396 .51524 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50456 .61188 Mdot
.51452 .59843 Mdot
.54624 .55617 Mdot
.64634 .43883 Mdot
.93629 .38134 Mdot
.31928 .51512 Mdot
.48579 .52827 Mdot
.63103 .42007 Mdot
.95135 .37566 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49083 .01238 Mdot
.47079 .03931 Mdot
.40719 .12056 Mdot
.21212 .26394 Mdot
.78505 .11996 Mdot
.59095 .04016 Mdot
.52596 .0162 Mdot
.49975 .01643 Mdot
.47316 .0412 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49711 .0039 Mdot
.4908 .01243 Mdot
.47068 .03945 Mdot
.40684 .12097 Mdot
.21111 .26413 Mdot
.78374 .11989 Mdot
.58976 .04102 Mdot
.52338 .01942 Mdot
.49196 .02688 Mdot
.44847 .07382 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48814 .01602 Mdot
.46222 .05072 Mdot
.38016 .15161 Mdot
.13484 .26219 Mdot
.71061 .11914 Mdot
.51783 .10265 Mdot
.35175 .22105 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48732 .01711 Mdot
.45963 .05414 Mdot
.37204 .16039 Mdot
.11252 .25623 Mdot
.69793 .11651 Mdot
.50942 .10778 Mdot
.33504 .23476 Mdot
.95519 .19376 Mdot
.64167 .07909 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00374 Mdot
.49119 .0119 Mdot
.47194 .03778 Mdot
.41082 .11619 Mdot
.22282 .26159 Mdot
.79956 .12114 Mdot
.60355 .03177 Mdot
.55214 .60233 Mdot
.57754 .53326 Mdot
.71472 .38932 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49254 .01008 Mdot
.47622 .03205 Mdot
.42437 .09955 Mdot
.26329 .24658 Mdot
.86432 .13549 Mdot
.64509 .01885 Mdot
.61459 .5396 Mdot
.7415 .39227 Mdot
.1068 .48401 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00245 Mdot
.49422 .00781 Mdot
.48158 .02485 Mdot
.44137 .07798 Mdot
.31519 .21332 Mdot
.97003 .1857 Mdot
.66956 .0566 Mdot
.57797 .60521 Mdot
.59872 .51945 Mdot
.75822 .37211 Mdot
.50073 .61705 Mdot
.50232 .61491 Mdot
.50738 .60807 Mdot
.5235 .58636 Mdot
.57475 .51959 Mdot
.73403 .37279 Mdot
.13085 .48088 Mdot
.35277 .59872 Mdot
.38402 .07894 Mdot
.2563 .22637 Mdot
.89003 .13234 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00371 Mdot
.49125 .01182 Mdot
.47212 .03754 Mdot
.41138 .11551 Mdot
.22448 .26116 Mdot
.8019 .1214 Mdot
.60548 .03061 Mdot
.55595 .59784 Mdot
.58861 .51988 Mdot
.74744 .37235 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48894 .01493 Mdot
.46479 .04731 Mdot
.38824 .14261 Mdot
.1575 .26593 Mdot
.72722 .11989 Mdot
.53324 .0893 Mdot
.38875 .18424 Mdot
.09065 .2638 Mdot
.66381 .13737 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .01391 Mdot
.4672 .0441 Mdot
.39584 .13392 Mdot
.17916 .26708 Mdot
.74701 .11957 Mdot
.55355 .07086 Mdot
.4389 .12612 Mdot
.23483 .273 Mdot
.79311 .13083 Mdot
.50129 .61629 Mdot
.50411 .61249 Mdot
.51308 .60037 Mdot
.54166 .56219 Mdot
.63202 .45336 Mdot
.89846 .36549 Mdot
.30709 .50364 Mdot
.49218 .51089 Mdot
.66554 .38364 Mdot
.0448 .42463 Mdot
.35774 .53963 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48976 .01382 Mdot
.4674 .04384 Mdot
.39646 .1332 Mdot
.18095 .26707 Mdot
.74882 .11953 Mdot
.55542 .06918 Mdot
.44348 .12049 Mdot
.24852 .26803 Mdot
.81484 .13256 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60075 Mdot
.54076 .56337 Mdot
.62921 .45632 Mdot
.89086 .36289 Mdot
.30369 .50212 Mdot
.49125 .51023 Mdot
.66568 .38291 Mdot
.04611 .42507 Mdot
.35834 .53973 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51103 .60314 Mdot
.53512 .57084 Mdot
.61148 .47574 Mdot
.84171 .35202 Mdot
.27213 .49815 Mdot
.46611 .52933 Mdot
.60964 .43553 Mdot
.90494 .35255 Mdot
.3345 .47979 Mdot
.49998 3e-05 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.4935 .00878 Mdot
.4793 .02792 Mdot
.43412 .08726 Mdot
.29293 .22947 Mdot
.92163 .15972 Mdot
.6632 .03359 Mdot
.60885 .55839 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49119 .0119 Mdot
.47193 .03779 Mdot
.41078 .11624 Mdot
.22271 .26162 Mdot
.7994 .12112 Mdot
.60342 .03185 Mdot
.55188 .60264 Mdot
.57678 .53419 Mdot
.71245 .39073 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51135 .60271 Mdot
.53615 .56948 Mdot
.61472 .47209 Mdot
.85086 .3532 Mdot
.27937 .49824 Mdot
.47321 .52296 Mdot
.62705 .41729 Mdot
.95185 .37334 Mdot
.34778 .4939 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00537 Mdot
.48733 .01711 Mdot
.45965 .05412 Mdot
.37208 .16035 Mdot
.11263 .25626 Mdot
.69799 .11653 Mdot
.50945 .10777 Mdot
.33507 .23474 Mdot
.95525 .1938 Mdot
.64168 .07913 Mdot
.50086 .61688 Mdot
.50273 .61435 Mdot
.50868 .60631 Mdot
.52766 .58079 Mdot
.58791 .50338 Mdot
.77343 .35743 Mdot
.1951 .49628 Mdot
.3921 .58882 Mdot
.43937 .02564 Mdot
.39788 .11395 Mdot
.2135 .25763 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01162 Mdot
.47259 .03691 Mdot
.41286 .11372 Mdot
.22886 .25996 Mdot
.80822 .12218 Mdot
.61053 .02776 Mdot
.56561 .58668 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49744 .00345 Mdot
.49186 .011 Mdot
.47406 .03493 Mdot
.41754 .10801 Mdot
.24278 .2554 Mdot
.82954 .1259 Mdot
.62583 .02103 Mdot
.59181 .55859 Mdot
.68798 .42211 Mdot
.005 .42674 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00466 Mdot
.48901 .01484 Mdot
.46499 .04703 Mdot
.38889 .14187 Mdot
.15934 .26612 Mdot
.72875 .11989 Mdot
.53477 .08791 Mdot
.39254 .18013 Mdot
.10108 .26766 Mdot
.66799 .13928 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49067 .0126 Mdot
.47029 .03999 Mdot
.40559 .12247 Mdot
.20742 .26477 Mdot
.77902 .11967 Mdot
.58539 .04425 Mdot
.5138 .03147 Mdot
.46288 .06557 Mdot
.35679 .18113 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49487 .00693 Mdot
.48365 .02206 Mdot
.44795 .06946 Mdot
.33556 .1962 Mdot
.0181 .21294 Mdot
.67355 .08209 Mdot
.54072 .04475 Mdot
.46831 .07393 Mdot
.34869 .19401 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48761 .01673 Mdot
.46054 .05294 Mdot
.37488 .15735 Mdot
.12028 .25854 Mdot
.70195 .11767 Mdot
.51156 .10696 Mdot
.33849 .23228 Mdot
.96265 .19798 Mdot
.64232 .08293 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50363 .61313 Mdot
.51157 .60241 Mdot
.53685 .56856 Mdot
.61691 .46966 Mdot
.85697 .35421 Mdot
.28385 .49843 Mdot
.47737 .51934 Mdot
.63706 .40742 Mdot
.97784 .38694 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.46781 .04329 Mdot
.39777 .13167 Mdot
.18472 .26698 Mdot
.75273 .11946 Mdot
.55945 .06562 Mdot
.45328 .10831 Mdot
.27802 .25358 Mdot
.86772 .14459 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49022 .0132 Mdot
.46886 .04189 Mdot
.40108 .12781 Mdot
.19428 .2664 Mdot
.76324 .11937 Mdot
.5701 .05646 Mdot
.47874 .07611 Mdot
.35559 .19236 Mdot
.04434 .23293 Mdot
.50084 .6169 Mdot
.50268 .61442 Mdot
.50853 .60652 Mdot
.52716 .58146 Mdot
.58634 .50529 Mdot
.76876 .35877 Mdot
.18826 .49535 Mdot
.38677 .59169 Mdot
.4294 .03698 Mdot
.36956 .14482 Mdot
.13524 .25564 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48713 .01738 Mdot
.45901 .05496 Mdot
.37008 .16247 Mdot
.10719 .2545 Mdot
.6954 .11555 Mdot
.50844 .10773 Mdot
.33413 .23514 Mdot
.95367 .19279 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48716 .01733 Mdot
.45912 .05482 Mdot
.37043 .1621 Mdot
.10814 .25482 Mdot
.69584 .11573 Mdot
.50859 .10777 Mdot
.3342 .23515 Mdot
.95373 .19285 Mdot
.50122 .61638 Mdot
.5039 .61276 Mdot
.51243 .60125 Mdot
.53958 .56493 Mdot
.6255 .46028 Mdot
.88076 .35979 Mdot
.29861 .5005 Mdot
.48877 .5109 Mdot
.66211 .38529 Mdot
.0387 .42082 Mdot
.35781 .53578 Mdot
.5006 .61722 Mdot
.50192 .61543 Mdot
.50613 .60975 Mdot
.51953 .5917 Mdot
.56214 .53555 Mdot
.6956 .39654 Mdot
.05399 .44564 Mdot
.33294 .5736 Mdot
.40484 .03862 Mdot
.34236 .16201 Mdot
.08022 .23327 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.4928 .00972 Mdot
.47708 .0309 Mdot
.42708 .09615 Mdot
.2715 .24235 Mdot
.87937 .14092 Mdot
.65134 .02083 Mdot
.61764 .53947 Mdot
.74476 .39201 Mdot
.11048 .4864 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00494 Mdot
.48834 .01574 Mdot
.46288 .04984 Mdot
.38224 .14932 Mdot
.14064 .26338 Mdot
.71448 .11949 Mdot
.52114 .09995 Mdot
.35941 .21398 Mdot
.01318 .22619 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .60559 Mdot
.52934 .57854 Mdot
.59324 .49696 Mdot
.78914 .35386 Mdot
.21659 .49816 Mdot
.41055 .57679 Mdot
.47728 .59778 Mdot
.51004 .58848 Mdot
.55786 .53602 Mdot
.50067 .61713 Mdot
.50213 .61516 Mdot
.50678 .60887 Mdot
.5216 .58891 Mdot
.56873 .52715 Mdot
.71579 .383 Mdot
.09609 .46676 Mdot
.34085 .59091 Mdot
.38473 .07064 Mdot
.27043 .21697 Mdot
.91936 .14537 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.4985 .00202 Mdot
.49523 .00644 Mdot
.4848 .02051 Mdot
.45161 .06468 Mdot
.34696 .18569 Mdot
.04651 .22819 Mdot
.67729 .09578 Mdot
.52232 .07516 Mdot
.40071 .16135 Mdot
.13963 .27482 Mdot
.50103 .61664 Mdot
.50328 .61361 Mdot
.51044 .60394 Mdot
.53324 .57335 Mdot
.60554 .48253 Mdot
.82479 .35098 Mdot
.2569 .49838 Mdot
.4505 .54353 Mdot
.57105 .47983 Mdot
.79467 .33806 Mdot
.24768 .48559 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50457 .61186 Mdot
.51456 .59838 Mdot
.54637 .55599 Mdot
.64675 .43842 Mdot
.93737 .38185 Mdot
.31953 .51554 Mdot
.48537 .52908 Mdot
.62931 .42196 Mdot
.94655 .37334 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50888 .60604 Mdot
.5283 .57994 Mdot
.58993 .50094 Mdot
.7794 .3559 Mdot
.20353 .4972 Mdot
.39904 .58465 Mdot
.45306 .0095 Mdot
.4377 .06579 Mdot
.33125 .19452 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49445 .0075 Mdot
.48231 .02386 Mdot
.4437 .07497 Mdot
.32239 .20752 Mdot
.98662 .19513 Mdot
.6709 .06543 Mdot
.56502 .00682 Mdot
.55399 .57575 Mdot
.6224 .47314 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.4883 .0158 Mdot
.46274 .05003 Mdot
.38179 .14982 Mdot
.13937 .26313 Mdot
.71362 .11943 Mdot
.52038 .10059 Mdot
.35763 .21566 Mdot
.00868 .22371 Mdot
.64672 .10615 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49748 .00341 Mdot
.49196 .01085 Mdot
.4744 .03448 Mdot
.41861 .10668 Mdot
.246 .25418 Mdot
.83472 .12705 Mdot
.62915 .02004 Mdot
.59672 .55383 Mdot
.70061 .41333 Mdot
.03184 .44265 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51138 .60267 Mdot
.53624 .56937 Mdot
.61499 .4718 Mdot
.85159 .35331 Mdot
.27992 .49825 Mdot
.47373 .5225 Mdot
.62832 .41601 Mdot
.95519 .37502 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49748 .0034 Mdot
.49199 .01083 Mdot
.47447 .03439 Mdot
.41882 .10643 Mdot
.24662 .25394 Mdot
.83574 .12729 Mdot
.62978 .01988 Mdot
.59762 .55298 Mdot
.70287 .41186 Mdot
.03647 .44537 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51108 .60307 Mdot
.53529 .57062 Mdot
.61202 .47514 Mdot
.84323 .35219 Mdot
.27337 .49815 Mdot
.46735 .5282 Mdot
.61271 .43223 Mdot
.91335 .35581 Mdot
.33764 .48155 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51055 .60379 Mdot
.5336 .57286 Mdot
.60669 .4812 Mdot
.82809 .35106 Mdot
.26006 .49831 Mdot
.45378 .54057 Mdot
.57912 .4702 Mdot
.81832 .33604 Mdot
.2746 .48183 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60723 Mdot
.52547 .58373 Mdot
.58098 .51185 Mdot
.75279 .36433 Mdot
.1633 .49052 Mdot
.36963 .59831 Mdot
.40155 .06583 Mdot
.29504 .20751 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61025 Mdot
.51835 .59328 Mdot
.55841 .54034 Mdot
.68413 .40525 Mdot
.02843 .43146 Mdot
.33031 .56062 Mdot
.42321 .01104 Mdot
.40536 .09369 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50773 .60759 Mdot
.52464 .58484 Mdot
.57835 .5151 Mdot
.7449 .36763 Mdot
.15006 .48703 Mdot
.36203 .59951 Mdot
.392 .07408 Mdot
.27213 .2202 Mdot
.91584 .14577 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50687 .60875 Mdot
.5219 .58851 Mdot
.56967 .52597 Mdot
.71864 .38128 Mdot
.10172 .46928 Mdot
.3424 .59266 Mdot
.38346 .07326 Mdot
.26492 .22016 Mdot
.9087 .14009 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.52369 .58611 Mdot
.57535 .51884 Mdot
.73586 .37187 Mdot
.13415 .48203 Mdot
.35422 .59905 Mdot
.38493 .07864 Mdot
.25768 .22602 Mdot
.89198 .13339 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01027 Mdot
.47577 .03265 Mdot
.42295 .10132 Mdot
.259 .24863 Mdot
.85671 .13303 Mdot
.64147 .01848 Mdot
.61157 .54134 Mdot
.73566 .3944 Mdot
.09751 .47924 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49461 .00728 Mdot
.48284 .02315 Mdot
.44538 .0728 Mdot
.32759 .20315 Mdot
.99889 .20212 Mdot
.67185 .07201 Mdot
.55534 .02173 Mdot
.52018 .00308 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.5079 .60737 Mdot
.52516 .58414 Mdot
.58001 .51305 Mdot
.74987 .36551 Mdot
.15847 .48932 Mdot
.36674 .59892 Mdot
.39766 .06935 Mdot
.28545 .21325 Mdot
.9404 .15928 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49619 .00515 Mdot
.48785 .0164 Mdot
.46132 .05191 Mdot
.37733 .15469 Mdot
.12703 .26035 Mdot
.70578 .11846 Mdot
.5141 .1054 Mdot
.34356 .22818 Mdot
.97435 .20451 Mdot
.64345 .08881 Mdot
.50128 .6163 Mdot
.50409 .6125 Mdot
.51304 .60042 Mdot
.54154 .56235 Mdot
.63163 .45377 Mdot
.89742 .36512 Mdot
.30664 .50342 Mdot
.4921 .51074 Mdot
.6657 .38341 Mdot
.04533 .42487 Mdot
.35788 .5398 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00487 Mdot
.48851 .01551 Mdot
.46342 .04912 Mdot
.38394 .14743 Mdot
.14538 .26423 Mdot
.71784 .11969 Mdot
.52418 .09736 Mdot
.36664 .20703 Mdot
.03166 .23619 Mdot
.6495 .11709 Mdot
.5012 .61642 Mdot
.50381 .61289 Mdot
.51214 .60164 Mdot
.53866 .56615 Mdot
.6226 .46341 Mdot
.8728 .35764 Mdot
.29412 .49955 Mdot
.48582 .51268 Mdot
.65629 .38998 Mdot
.02529 .41333 Mdot
.35651 .52904 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00232 Mdot
.49453 .00739 Mdot
.48256 .02353 Mdot
.44449 .07395 Mdot
.32483 .20549 Mdot
.99235 .1984 Mdot
.67134 .06851 Mdot
.56049 .01377 Mdot
.53821 .59673 Mdot
.57268 .53166 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50436 .61214 Mdot
.51389 .59928 Mdot
.54423 .5588 Mdot
.64008 .44507 Mdot
.91995 .37394 Mdot
.31489 .50939 Mdot
.49068 .51803 Mdot
.6525 .39731 Mdot
.00963 .40624 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49734 .00359 Mdot
.49153 .01144 Mdot
.47303 .03632 Mdot
.41425 .11203 Mdot
.23299 .25873 Mdot
.81435 .12308 Mdot
.6152 .02537 Mdot
.57415 .57713 Mdot
.64034 .46324 Mdot
.89079 .36976 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .0025 Mdot
.49411 .00795 Mdot
.48125 .02529 Mdot
.44033 .07932 Mdot
.31198 .21582 Mdot
.96278 .18163 Mdot
.6689 .05283 Mdot
.58342 .59702 Mdot
.61743 .49776 Mdot
.81203 .36129 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49083 .01238 Mdot
.4708 .0393 Mdot
.4072 .12054 Mdot
.21217 .26393 Mdot
.78512 .11997 Mdot
.59101 .04012 Mdot
.52609 .01604 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00479 Mdot
.48872 .01524 Mdot
.46406 .04827 Mdot
.38595 .14518 Mdot
.15104 .26511 Mdot
.72208 .11983 Mdot
.52818 .09384 Mdot
.37634 .19729 Mdot
.05712 .24912 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46745 .04377 Mdot
.39662 .13301 Mdot
.1814 .26706 Mdot
.74928 .11952 Mdot
.5559 .06876 Mdot
.44464 .11905 Mdot
.252 .26659 Mdot
.82066 .13335 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49645 .00479 Mdot
.4887 .01526 Mdot
.464 .04835 Mdot
.38576 .1454 Mdot
.1505 .26504 Mdot
.72166 .11982 Mdot
.52778 .0942 Mdot
.37537 .19829 Mdot
.05453 .24786 Mdot
.65349 .12662 Mdot
.50088 .61684 Mdot
.50282 .61423 Mdot
.50898 .60591 Mdot
.5286 .57953 Mdot
.5909 .49977 Mdot
.78226 .35525 Mdot
.20746 .49755 Mdot
.4024 .58246 Mdot
.45996 .00115 Mdot
.45809 .03955 Mdot
.39409 .13065 Mdot
.49972 .00038 Mdot
.49912 .0012 Mdot
.49718 .00381 Mdot
.49102 .01213 Mdot
.47139 .03851 Mdot
.40908 .11828 Mdot
.2177 .2628 Mdot
.79248 .12048 Mdot
.59754 .03561 Mdot
.53992 .61702 Mdot
.54157 .57892 Mdot
.60486 .48859 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00333 Mdot
.49215 .0106 Mdot
.475 .03369 Mdot
.42049 .10437 Mdot
.25162 .2519 Mdot
.84404 .12937 Mdot
.63471 .01888 Mdot
.60417 .54709 Mdot
.71895 .40234 Mdot
.06795 .46344 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47324 .03604 Mdot
.41493 .1112 Mdot
.235 .25809 Mdot
.8174 .12358 Mdot
.61744 .02432 Mdot
.57809 .57283 Mdot
.65123 .4528 Mdot
.91858 .38057 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49302 .00943 Mdot
.47775 .02999 Mdot
.42923 .09346 Mdot
.278 .23873 Mdot
.89173 .14592 Mdot
.65562 .02357 Mdot
.61749 .5423 Mdot
.74003 .39505 Mdot
.10082 .48239 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50266 .61443 Mdot
.50849 .60657 Mdot
.52705 .58161 Mdot
.58597 .50573 Mdot
.76768 .3591 Mdot
.18665 .49511 Mdot
.38555 .5923 Mdot
.42719 .03943 Mdot
.3634 .15108 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.49322 .00916 Mdot
.47839 .02914 Mdot
.43124 .09092 Mdot
.28413 .23508 Mdot
.90376 .1512 Mdot
.65911 .02707 Mdot
.61531 .54731 Mdot
.72974 .40096 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49818 .00246 Mdot
.4942 .00784 Mdot
.48152 .02494 Mdot
.44117 .07824 Mdot
.31457 .21381 Mdot
.96861 .1849 Mdot
.66943 .05586 Mdot
.57905 .60359 Mdot
.60242 .51506 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46875 .04203 Mdot
.40074 .1282 Mdot
.19331 .26648 Mdot
.76213 .11937 Mdot
.56899 .0574 Mdot
.47612 .07945 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .0137 Mdot
.46769 .04344 Mdot
.3974 .1321 Mdot
.18365 .26701 Mdot
.75162 .11948 Mdot
.5583 .06663 Mdot
.45049 .11179 Mdot
.26961 .25822 Mdot
.50128 .6163 Mdot
.50408 .61252 Mdot
.51301 .60046 Mdot
.54144 .56248 Mdot
.63134 .45407 Mdot
.89663 .36484 Mdot
.3063 .50325 Mdot
.49203 .51064 Mdot
.66579 .38327 Mdot
.04565 .42501 Mdot
.35797 .53989 Mdot
.50037 .61754 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.5119 .60197 Mdot
.53789 .56717 Mdot
.62019 .46604 Mdot
.86612 .35606 Mdot
.29001 .49896 Mdot
.48267 .51499 Mdot
.64939 .39596 Mdot
.00872 .40404 Mdot
.49993 .0001 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49275 .00979 Mdot
.47692 .03111 Mdot
.42657 .09679 Mdot
.26996 .24318 Mdot
.87648 .13983 Mdot
.65024 .02033 Mdot
.61734 .53918 Mdot
.74494 .39171 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49723 .00375 Mdot
.49116 .01194 Mdot
.47185 .0379 Mdot
.41054 .11653 Mdot
.22198 .2618 Mdot
.79838 .12102 Mdot
.60257 .03238 Mdot
.55018 .60466 Mdot
.57182 .54032 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60312 Mdot
.53518 .57076 Mdot
.61167 .47553 Mdot
.84224 .35208 Mdot
.27256 .49815 Mdot
.46655 .52893 Mdot
.61073 .43436 Mdot
.90791 .35368 Mdot
.33565 .48037 Mdot
.5005 .61736 Mdot
.50158 .61589 Mdot
.50505 .61121 Mdot
.51608 .59633 Mdot
.55121 .54967 Mdot
.66182 .4242 Mdot
.97544 .40153 Mdot
.32576 .53267 Mdot
.46388 .56587 Mdot
.54829 .52178 Mdot
.70403 .38035 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49678 .00435 Mdot
.48975 .01385 Mdot
.46734 .04391 Mdot
.39628 .1334 Mdot
.18043 .26708 Mdot
.7483 .11954 Mdot
.55488 .06967 Mdot
.44215 .12212 Mdot
.24456 .26958 Mdot
.80837 .13185 Mdot
.50062 .61719 Mdot
.50198 .61535 Mdot
.50632 .6095 Mdot
.52013 .59088 Mdot
.56407 .53308 Mdot
.70153 .39232 Mdot
.06675 .4524 Mdot
.33475 .57952 Mdot
.39707 .05039 Mdot
.31554 .1856 Mdot
.01523 .1997 Mdot
.5006 .61723 Mdot
.5019 .61546 Mdot
.50606 .60985 Mdot
.51931 .59199 Mdot
.56145 .53642 Mdot
.6935 .39808 Mdot
.0494 .44314 Mdot
.33238 .57136 Mdot
.40791 .03401 Mdot
.35287 .1518 Mdot
.10726 .24387 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49748 .00341 Mdot
.49197 .01085 Mdot
.47442 .03446 Mdot
.41867 .10662 Mdot
.24615 .25412 Mdot
.83497 .12711 Mdot
.6293 .02 Mdot
.59694 .55362 Mdot
.70118 .41296 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.5041 .61249 Mdot
.51307 .60039 Mdot
.54162 .56224 Mdot
.6319 .45348 Mdot
.89815 .36538 Mdot
.30696 .50358 Mdot
.49216 .51084 Mdot
.66559 .38357 Mdot
.04497 .4247 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48856 .01545 Mdot
.46355 .04895 Mdot
.38435 .14697 Mdot
.14654 .26443 Mdot
.71869 .11973 Mdot
.52496 .09668 Mdot
.36853 .20516 Mdot
.03657 .23877 Mdot
.50028 .61766 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50901 .60586 Mdot
.5287 .5794 Mdot
.59122 .49938 Mdot
.7832 .35504 Mdot
.20874 .49765 Mdot
.40352 .58171 Mdot
.46229 .61635 Mdot
.46501 .03049 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00198 Mdot
.49533 .00631 Mdot
.48512 .02008 Mdot
.45262 .06336 Mdot
.35011 .18266 Mdot
.05455 .23225 Mdot
.67876 .09924 Mdot
.51818 .08243 Mdot
.38481 .18013 Mdot
.09336 .2618 Mdot
.50084 .61689 Mdot
.50269 .6144 Mdot
.50858 .60645 Mdot
.52732 .58125 Mdot
.58685 .50467 Mdot
.77027 .35832 Mdot
.19049 .49567 Mdot
.38848 .59081 Mdot
.43253 .03346 Mdot
.37839 .13554 Mdot
.15909 .25966 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01089 Mdot
.47431 .03461 Mdot
.41832 .10705 Mdot
.2451 .25453 Mdot
.83327 .12672 Mdot
.62823 .02029 Mdot
.5954 .55508 Mdot
.69726 .41557 Mdot
.02485 .43851 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00375 Mdot
.49115 .01195 Mdot
.47182 .03794 Mdot
.41044 .11665 Mdot
.22169 .26187 Mdot
.79798 .12098 Mdot
.60223 .03259 Mdot
.54951 .60546 Mdot
.56985 .54277 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01313 Mdot
.46903 .04166 Mdot
.40162 .12717 Mdot
.19585 .26626 Mdot
.76504 .11937 Mdot
.57189 .05497 Mdot
.48296 .07073 Mdot
.36851 .17923 Mdot
.0785 .24909 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52138 .5892 Mdot
.56803 .52804 Mdot
.71365 .38433 Mdot
.09179 .46478 Mdot
.33976 .58948 Mdot
.38596 .06835 Mdot
.27537 .21402 Mdot
.50027 .61767 Mdot
.50086 .61688 Mdot
.50272 .61435 Mdot
.50868 .60631 Mdot
.52765 .58081 Mdot
.58789 .50341 Mdot
.77335 .35745 Mdot
.19498 .49627 Mdot
.39201 .58888 Mdot
.43919 .02586 Mdot
.39735 .11456 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51281 .60074 Mdot
.54078 .56335 Mdot
.62926 .45626 Mdot
.89101 .36294 Mdot
.30376 .50215 Mdot
.49127 .51023 Mdot
.6657 .38291 Mdot
.04614 .42509 Mdot
.35834 .53975 Mdot
.50055 .6173 Mdot
.50174 .61568 Mdot
.50555 .61053 Mdot
.51769 .59417 Mdot
.5563 .54306 Mdot
.6776 .41052 Mdot
.01336 .4229 Mdot
.3291 .55259 Mdot
.43499 .61119 Mdot
.44607 .0422 Mdot
.37778 .14469 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48962 .01402 Mdot
.46694 .04445 Mdot
.39501 .13487 Mdot
.17679 .26708 Mdot
.74465 .11962 Mdot
.5511 .07305 Mdot
.4329 .13343 Mdot
.217 .27782 Mdot
.76748 .13116 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49245 .01019 Mdot
.47596 .03239 Mdot
.42355 .10057 Mdot
.26081 .24778 Mdot
.8599 .13403 Mdot
.64303 .01858 Mdot
.61296 .54047 Mdot
.73847 .39331 Mdot
.10208 .48159 Mdot
.5013 .61627 Mdot
.50416 .61242 Mdot
.51325 .60015 Mdot
.54218 .56151 Mdot
.63364 .45167 Mdot
.90282 .36707 Mdot
.30888 .50464 Mdot
.49236 .51172 Mdot
.66438 .38501 Mdot
.04142 .42298 Mdot
.35703 .5384 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48836 .01571 Mdot
.46294 .04976 Mdot
.38243 .14911 Mdot
.14116 .26348 Mdot
.71485 .11952 Mdot
.52146 .09968 Mdot
.36017 .21327 Mdot
.01509 .22724 Mdot
.64741 .1093 Mdot
.50053 .61732 Mdot
.50168 .61577 Mdot
.50535 .61081 Mdot
.51704 .59505 Mdot
.55423 .54574 Mdot
.67121 .41591 Mdot
.99825 .41429 Mdot
.32792 .5445 Mdot
.4469 .59282 Mdot
.4877 .60421 Mdot
.51007 .59487 Mdot
.50086 .61688 Mdot
.50272 .61435 Mdot
.50868 .60631 Mdot
.52765 .5808 Mdot
.5879 .50339 Mdot
.77339 .35744 Mdot
.19504 .49627 Mdot
.39205 .58885 Mdot
.43927 .02576 Mdot
.39759 .11428 Mdot
.21268 .25779 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48874 .0152 Mdot
.46415 .04815 Mdot
.38625 .14485 Mdot
.15187 .26523 Mdot
.72272 .11985 Mdot
.5288 .09329 Mdot
.37785 .19574 Mdot
.06114 .25103 Mdot
.65496 .12902 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .0139 Mdot
.46721 .04409 Mdot
.39587 .13388 Mdot
.17924 .26708 Mdot
.74709 .11956 Mdot
.55363 .07079 Mdot
.43909 .12588 Mdot
.23541 .27281 Mdot
.50021 .61775 Mdot
.50067 .61712 Mdot
.50215 .61513 Mdot
.50684 .60879 Mdot
.5218 .58864 Mdot
.56936 .52636 Mdot
.71769 .38184 Mdot
.09985 .46846 Mdot
.34187 .5921 Mdot
.38384 .07244 Mdot
.26662 .21918 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48891 .01498 Mdot
.46467 .04746 Mdot
.38788 .14302 Mdot
.15647 .26581 Mdot
.72638 .11989 Mdot
.5324 .09006 Mdot
.38668 .18646 Mdot
.08499 .26155 Mdot
.66179 .1361 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.48769 .01662 Mdot
.46081 .05259 Mdot
.37572 .15644 Mdot
.12259 .25918 Mdot
.70323 .11796 Mdot
.51236 .10652 Mdot
.34002 .23108 Mdot
.96611 .19991 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51274 .60083 Mdot
.54058 .56362 Mdot
.62862 .45694 Mdot
.88928 .36238 Mdot
.30294 .50184 Mdot
.49095 .51022 Mdot
.6654 .38303 Mdot
.04565 .42477 Mdot
.35836 .53942 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.5115 .60251 Mdot
.53662 .56886 Mdot
.6162 .47045 Mdot
.85499 .35386 Mdot
.28242 .49836 Mdot
.47607 .52046 Mdot
.63395 .41043 Mdot
.96986 .38266 Mdot
.35071 .50163 Mdot
.50059 .61724 Mdot
.50187 .61551 Mdot
.50595 .60999 Mdot
.51897 .59245 Mdot
.56036 .53782 Mdot
.69015 .40059 Mdot
.04198 .43906 Mdot
.33157 .56764 Mdot
.41311 .02622 Mdot
.37068 .13335 Mdot
.15492 .25534 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .6089 Mdot
.52154 .58899 Mdot
.56854 .52739 Mdot
.71521 .38336 Mdot
.09493 .46623 Mdot
.34055 .59054 Mdot
.38504 .07005 Mdot
.2717 .21622 Mdot
.92185 .14665 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50396 .61268 Mdot
.51261 .601 Mdot
.54017 .56416 Mdot
.62735 .4583 Mdot
.8858 .36128 Mdot
.30123 .50125 Mdot
.49018 .51035 Mdot
.66443 .38362 Mdot
.04372 .42364 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48947 .01422 Mdot
.46646 .04509 Mdot
.3935 .13661 Mdot
.17246 .26699 Mdot
.74046 .11971 Mdot
.54676 .07698 Mdot
.42221 .14626 Mdot
.18556 .28187 Mdot
.72948 .13555 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50056 .61727 Mdot
.5018 .6156 Mdot
.50573 .6103 Mdot
.51825 .59341 Mdot
.55808 .54075 Mdot
.68313 .40604 Mdot
.02613 .43016 Mdot
.33012 .5594 Mdot
.42498 .00837 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00529 Mdot
.48753 .01684 Mdot
.46028 .05328 Mdot
.37407 .15821 Mdot
.11808 .25791 Mdot
.70077 .11737 Mdot
.51087 .1073 Mdot
.33726 .23322 Mdot
.9599 .19644 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.5074 .60804 Mdot
.52357 .58627 Mdot
.57496 .51933 Mdot
.73467 .37247 Mdot
.132 .48128 Mdot
.35327 .59884 Mdot
.50008 .61793 Mdot
.50026 .61769 Mdot
.50082 .61693 Mdot
.5026 .61452 Mdot
.50828 .60685 Mdot
.52638 .58251 Mdot
.58386 .50832 Mdot
.76138 .36115 Mdot
.17702 .49346 Mdot
.3786 .5954 Mdot
.41522 .0523 Mdot
.50111 .61653 Mdot
.50354 .61324 Mdot
.51129 .60278 Mdot
.53597 .56972 Mdot
.61414 .47275 Mdot
.84922 .35296 Mdot
.27812 .4982 Mdot
.47201 .52402 Mdot
.62412 .42027 Mdot
.94412 .36952 Mdot
.34622 .49091 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49897 .00139 Mdot
.49673 .00441 Mdot
.48959 .01406 Mdot
.46684 .04457 Mdot
.39472 .13521 Mdot
.17595 .26707 Mdot
.74383 .11964 Mdot
.55025 .07382 Mdot
.43081 .13596 Mdot
.21082 .27906 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.5259 .58315 Mdot
.58235 .51016 Mdot
.7569 .36275 Mdot
.16995 .49202 Mdot
.37383 .59712 Mdot
.40768 .05995 Mdot
.31067 .1969 Mdot
.99208 .18956 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.49281 .00972 Mdot
.47709 .03088 Mdot
.42712 .09611 Mdot
.2716 .2423 Mdot
.87956 .141 Mdot
.65142 .02087 Mdot
.61765 .53949 Mdot
.74473 .39203 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61076 Mdot
.51716 .59488 Mdot
.55462 .54523 Mdot
.67242 .41487 Mdot
.00114 .41593 Mdot
.32815 .54604 Mdot
.44464 .59633 Mdot
.47975 .61505 Mdot
.48458 .01129 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00413 Mdot
.49025 .01316 Mdot
.46896 .04176 Mdot
.40139 .12744 Mdot
.19519 .26632 Mdot
.76428 .11937 Mdot
.57114 .05559 Mdot
.48118 .073 Mdot
.36307 .18485 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.50631 .6095 Mdot
.52012 .59091 Mdot
.56401 .53315 Mdot
.70135 .39245 Mdot
.06635 .45219 Mdot
.33469 .57934 Mdot
.39729 .05005 Mdot
.31632 .18497 Mdot
.01703 .20073 Mdot
.50058 .61726 Mdot
.50184 .61555 Mdot
.50585 .61013 Mdot
.51863 .5929 Mdot
.55931 .53918 Mdot
.6869 .40308 Mdot
.0347 .435 Mdot
.33086 .5639 Mdot
.41845 .0182 Mdot
.389 .11297 Mdot
.20621 .25496 Mdot
.501 .61668 Mdot
.50319 .61373 Mdot
.51016 .60432 Mdot
.53236 .57453 Mdot
.60275 .48575 Mdot
.81679 .35101 Mdot
.24885 .49855 Mdot
.44218 .55098 Mdot
.55067 .50479 Mdot
.7339 .358 Mdot
.15463 .47984 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00223 Mdot
.49474 .0071 Mdot
.48325 .0226 Mdot
.44668 .07111 Mdot
.33162 .19968 Mdot
.00854 .20759 Mdot
.67265 .07712 Mdot
.54787 .03342 Mdot
.4938 .03916 Mdot
.43043 .10163 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48755 .01681 Mdot
.46034 .0532 Mdot
.37427 .158 Mdot
.11861 .25806 Mdot
.70106 .11744 Mdot
.51103 .10722 Mdot
.33754 .23301 Mdot
.96052 .19679 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00414 Mdot
.49025 .01317 Mdot
.46894 .04179 Mdot
.40132 .12751 Mdot
.195 .26634 Mdot
.76406 .11937 Mdot
.57092 .05578 Mdot
.48067 .07365 Mdot
.3615 .18645 Mdot
.05982 .24061 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.5078 .6075 Mdot
.52484 .58457 Mdot
.57899 .51431 Mdot
.74681 .3668 Mdot
.15331 .48795 Mdot
.3638 .59935 Mdot
.39403 .07246 Mdot
.27679 .21792 Mdot
.9242 .15027 Mdot
.50119 .61643 Mdot
.50379 .61292 Mdot
.51206 .60175 Mdot
.5384 .56649 Mdot
.6218 .46428 Mdot
.87058 .35709 Mdot
.29279 .49934 Mdot
.48484 .51337 Mdot
.6542 .39176 Mdot
.02032 .41055 Mdot
.35605 .52653 Mdot
.4999 .00013 Mdot
.49969 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48981 .01376 Mdot
.46755 .04363 Mdot
.39696 .13262 Mdot
.18238 .26704 Mdot
.7503 .1195 Mdot
.55694 .06783 Mdot
.44719 .11589 Mdot
.25967 .26317 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01053 Mdot
.47516 .03347 Mdot
.42101 .10373 Mdot
.25317 .25124 Mdot
.84665 .13008 Mdot
.63618 .01868 Mdot
.60594 .5456 Mdot
.72315 .40015 Mdot
.0757 .46771 Mdot
.49964 .00049 Mdot
.49886 .00155 Mdot
.49636 .00492 Mdot
.48839 .01568 Mdot
.46302 .04965 Mdot
.38269 .14881 Mdot
.14191 .26362 Mdot
.71536 .11955 Mdot
.52192 .09929 Mdot
.36126 .21223 Mdot
.01787 .22876 Mdot
.64773 .11064 Mdot
.49975 .00034 Mdot
.4992 .00109 Mdot
.49744 .00346 Mdot
.49184 .01102 Mdot
.47402 .035 Mdot
.41738 .1082 Mdot
.24232 .25557 Mdot
.82879 .12574 Mdot
.62534 .02119 Mdot
.59106 .55934 Mdot
.68603 .42355 Mdot
.00072 .42421 Mdot
.50062 .6172 Mdot
.50198 .61536 Mdot
.5063 .60953 Mdot
.52006 .59098 Mdot
.56384 .53337 Mdot
.70083 .39281 Mdot
.06526 .45162 Mdot
.33452 .57885 Mdot
.39791 .0491 Mdot
.31847 .1832 Mdot
.02205 .20358 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00455 Mdot
.48928 .01448 Mdot
.46586 .04589 Mdot
.39161 .13878 Mdot
.16706 .26674 Mdot
.73547 .11981 Mdot
.54161 .08167 Mdot
.40946 .16115 Mdot
.14872 .27981 Mdot
.69597 .14069 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50408 .61253 Mdot
.51299 .6005 Mdot
.54136 .56259 Mdot
.63108 .45435 Mdot
.89592 .3646 Mdot
.30599 .5031 Mdot
.49195 .51056 Mdot
.66585 .38316 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .60559 Mdot
.52934 .57855 Mdot
.59323 .49698 Mdot
.78911 .35386 Mdot
.21654 .49816 Mdot
.4105 .57682 Mdot
.47718 .5979 Mdot
.50976 .58887 Mdot
.55695 .53719 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49261 .00998 Mdot
.47647 .03171 Mdot
.42517 .09855 Mdot
.26572 .24537 Mdot
.86869 .13699 Mdot
.64703 .01926 Mdot
.61586 .53913 Mdot
.74354 .3917 Mdot
.10975 .48557 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50611 .60978 Mdot
.51947 .59177 Mdot
.56196 .53577 Mdot
.69506 .39693 Mdot
.05281 .44499 Mdot
.33279 .57302 Mdot
.40562 .03745 Mdot
.34503 .15946 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50344 .61339 Mdot
.51096 .60324 Mdot
.5349 .57114 Mdot
.61078 .47653 Mdot
.83974 .35183 Mdot
.27047 .49815 Mdot
.46445 .53084 Mdot
.60553 .44002 Mdot
.89357 .34854 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46846 .04242 Mdot
.39982 .12928 Mdot
.19063 .26668 Mdot
.75913 .11938 Mdot
.56597 .05996 Mdot
.46895 .08856 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00279 Mdot
.49343 .00888 Mdot
.47907 .02823 Mdot
.43339 .08819 Mdot
.29071 .23093 Mdot
.91705 .15747 Mdot
.66226 .03178 Mdot
.61084 .55517 Mdot
.71256 .41168 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49072 .01253 Mdot
.47045 .03977 Mdot
.40609 .12187 Mdot
.20891 .26452 Mdot
.78091 .11975 Mdot
.58715 .04293 Mdot
.51768 .02657 Mdot
.47468 .04994 Mdot
.39387 .1412 Mdot
.50113 .6165 Mdot
.50361 .61315 Mdot
.51151 .6025 Mdot
.53665 .56882 Mdot
.61628 .47036 Mdot
.85522 .3539 Mdot
.28259 .49836 Mdot
.47622 .52032 Mdot
.63432 .41007 Mdot
.97081 .38316 Mdot
.35084 .50207 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04864 Mdot
.38509 .14614 Mdot
.14863 .26476 Mdot
.72024 .11978 Mdot
.52642 .0954 Mdot
.37206 .20164 Mdot
.04581 .24352 Mdot
.65178 .12319 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61117 Mdot
.51618 .5962 Mdot
.5515 .54929 Mdot
.66273 .42338 Mdot
.97769 .40276 Mdot
.32601 .5338 Mdot
.4623 .56842 Mdot
.54257 .52943 Mdot
.68594 .39367 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49947 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48301 .02292 Mdot
.44592 .0721 Mdot
.32926 .20172 Mdot
.00286 .20438 Mdot
.67217 .07412 Mdot
.55224 .02656 Mdot
.50926 .01798 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01634 Mdot
.46145 .05173 Mdot
.37774 .15425 Mdot
.12817 .26063 Mdot
.70645 .11858 Mdot
.51459 .10507 Mdot
.34459 .22731 Mdot
.97679 .20587 Mdot
.64368 .09004 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57438 .52005 Mdot
.73293 .37335 Mdot
.12884 .48016 Mdot
.35192 .59848 Mdot
.38356 .07901 Mdot
.25571 .22646 Mdot
.88929 .13191 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49553 .00604 Mdot
.48577 .01922 Mdot
.45467 .06067 Mdot
.35651 .17639 Mdot
.07111 .24014 Mdot
.68256 .10564 Mdot
.51162 .09488 Mdot
.35811 .20967 Mdot
.01885 .22711 Mdot
.49983 .00022 Mdot
.49947 .00072 Mdot
.49831 .00228 Mdot
.49462 .00726 Mdot
.48288 .02311 Mdot
.44549 .07266 Mdot
.32793 .20287 Mdot
.99968 .20257 Mdot
.67191 .07243 Mdot
.55471 .0227 Mdot
.51798 .00607 Mdot
.50816 .61654 Mdot
.4998 .00027 Mdot
.49936 .00086 Mdot
.49798 .00273 Mdot
.49355 .00871 Mdot
.47946 .0277 Mdot
.43463 .08661 Mdot
.2945 .22842 Mdot
.9249 .16136 Mdot
.66382 .03492 Mdot
.60731 .56084 Mdot
.69986 .42056 Mdot
.01938 .43848 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60624 Mdot
.52783 .58057 Mdot
.58844 .50274 Mdot
.77499 .35701 Mdot
.19734 .49655 Mdot
.39391 .58778 Mdot
.44286 .02159 Mdot
.40792 .10227 Mdot
.24245 .24965 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51218 .60158 Mdot
.5388 .56597 Mdot
.62304 .46294 Mdot
.87399 .35795 Mdot
.29482 .49968 Mdot
.48632 .51234 Mdot
.65733 .38911 Mdot
.02774 .4147 Mdot
.35675 .53028 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00468 Mdot
.48897 .0149 Mdot
.46487 .0472 Mdot
.38849 .14232 Mdot
.15821 .266 Mdot
.72781 .11989 Mdot
.53383 .08876 Mdot
.39021 .18267 Mdot
.09465 .26533 Mdot
.66534 .13817 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00352 Mdot
.49171 .0112 Mdot
.47359 .03557 Mdot
.41603 .10986 Mdot
.23827 .25701 Mdot
.82242 .12447 Mdot
.62102 .02279 Mdot
.58415 .56639 Mdot
.66771 .43814 Mdot
.95878 .40035 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50344 .61339 Mdot
.51096 .60324 Mdot
.53489 .57115 Mdot
.61075 .47656 Mdot
.83966 .35182 Mdot
.27041 .49815 Mdot
.46438 .5309 Mdot
.60537 .4402 Mdot
.89311 .34839 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49243 .01022 Mdot
.47589 .03249 Mdot
.42332 .10085 Mdot
.26014 .2481 Mdot
.85871 .13366 Mdot
.64245 .01853 Mdot
.61247 .54077 Mdot
.73749 .39368 Mdot
.1005 .48078 Mdot
.50129 .61628 Mdot
.50413 .61246 Mdot
.51314 .60029 Mdot
.54185 .56194 Mdot
.63262 .45274 Mdot
.90008 .36607 Mdot
.30777 .504 Mdot
.49228 .51116 Mdot
.6652 .38407 Mdot
.04377 .42413 Mdot
.35751 .53928 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.53939 .56518 Mdot
.62491 .46092 Mdot
.87913 .35933 Mdot
.29772 .50029 Mdot
.48824 .51118 Mdot
.66114 .38604 Mdot
.03651 .41959 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50768 .60766 Mdot
.52447 .58506 Mdot
.57782 .51576 Mdot
.7433 .36835 Mdot
.1473 .48622 Mdot
.36057 .59957 Mdot
.39044 .07527 Mdot
.26865 .2218 Mdot
.90976 .14256 Mdot
.50131 .61627 Mdot
.50417 .61241 Mdot
.51327 .60012 Mdot
.54226 .5614 Mdot
.63389 .45141 Mdot
.9035 .36733 Mdot
.30915 .5048 Mdot
.49237 .51187 Mdot
.66413 .38529 Mdot
.04073 .42263 Mdot
.35689 .53813 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47738 .0305 Mdot
.42803 .09496 Mdot
.27438 .24078 Mdot
.88479 .14306 Mdot
.65331 .02191 Mdot
.61785 .54041 Mdot
.74346 .39299 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00552 Mdot
.48699 .01757 Mdot
.45857 .05554 Mdot
.3687 .16392 Mdot
.10347 .25323 Mdot
.69374 .11481 Mdot
.50798 .10741 Mdot
.3342 .23478 Mdot
.95431 .19301 Mdot
.64202 .07813 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00203 Mdot
.4952 .00648 Mdot
.48472 .02063 Mdot
.45134 .06504 Mdot
.34611 .18649 Mdot
.04436 .22709 Mdot
.67693 .09482 Mdot
.52351 .0731 Mdot
.40523 .15585 Mdot
.15306 .27686 Mdot
.50019 .61778 Mdot
.50059 .61724 Mdot
.50188 .61549 Mdot
.50599 .60994 Mdot
.51908 .5923 Mdot
.56071 .53738 Mdot
.69122 .39978 Mdot
.04436 .44037 Mdot
.33182 .56885 Mdot
.41141 .02877 Mdot
.36486 .13953 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00272 Mdot
.4936 .00865 Mdot
.4796 .02751 Mdot
.43508 .08605 Mdot
.29585 .22751 Mdot
.92773 .16279 Mdot
.66433 .03611 Mdot
.60589 .56306 Mdot
.69484 .42429 Mdot
.00832 .432 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48894 .01494 Mdot
.46476 .04734 Mdot
.38816 .1427 Mdot
.15727 .2659 Mdot
.72703 .11989 Mdot
.53305 .08947 Mdot
.38828 .18475 Mdot
.08935 .2633 Mdot
.66333 .13709 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49784 .00292 Mdot
.49312 .00929 Mdot
.47808 .02955 Mdot
.43027 .09215 Mdot
.28117 .23687 Mdot
.8979 .14858 Mdot
.65749 .02527 Mdot
.61661 .54461 Mdot
.73541 .39769 Mdot
.09193 .47825 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51026 .60418 Mdot
.53267 .57411 Mdot
.60373 .48462 Mdot
.8196 .35096 Mdot
.25174 .49849 Mdot
.44516 .54833 Mdot
.55794 .4958 Mdot
.75573 .34835 Mdot
.19209 .48623 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50872 .60625 Mdot
.52779 .58062 Mdot
.58832 .50289 Mdot
.77463 .3571 Mdot
.19683 .49649 Mdot
.39349 .58803 Mdot
.44204 .02254 Mdot
.40557 .10504 Mdot
.23561 .25198 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00526 Mdot
.48759 .01676 Mdot
.46047 .05303 Mdot
.37466 .15758 Mdot
.11969 .25837 Mdot
.70163 .11759 Mdot
.51137 .10706 Mdot
.33814 .23255 Mdot
.96187 .19754 Mdot
.64225 .08254 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49756 .0033 Mdot
.49221 .01052 Mdot
.47519 .03343 Mdot
.4211 .10362 Mdot
.25344 .25113 Mdot
.8471 .1302 Mdot
.63643 .01866 Mdot
.60624 .54536 Mdot
.50013 .61786 Mdot
.5004 .6175 Mdot
.50127 .61632 Mdot
.50405 .61257 Mdot
.51289 .60063 Mdot
.54105 .563 Mdot
.6301 .45538 Mdot
.89327 .36369 Mdot
.30481 .50257 Mdot
.49163 .51033 Mdot
.6659 .38291 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61716 Mdot
.50205 .61526 Mdot
.50654 .6092 Mdot
.52083 .58994 Mdot
.56629 .53025 Mdot
.70833 .38773 Mdot
.08096 .45959 Mdot
.33732 .58548 Mdot
.38999 .0615 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50749 .60792 Mdot
.52386 .58589 Mdot
.57587 .51818 Mdot
.73744 .37109 Mdot
.137 .48299 Mdot
.35551 .59928 Mdot
.38586 .07822 Mdot
.2593 .22551 Mdot
.89441 .13465 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51259 .60104 Mdot
.54009 .56426 Mdot
.6271 .45857 Mdot
.88512 .36108 Mdot
.30088 .50114 Mdot
.49001 .51039 Mdot
.66418 .38379 Mdot
.0432 .42334 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.50809 .6071 Mdot
.52578 .5833 Mdot
.58198 .51062 Mdot
.75579 .36317 Mdot
.16817 .49164 Mdot
.37268 .59747 Mdot
.40595 .06165 Mdot
.3062 .20009 Mdot
.49995 7e-05 Mdot
.49982 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49433 .00766 Mdot
.48195 .02436 Mdot
.44253 .07648 Mdot
.31878 .21046 Mdot
.97825 .19036 Mdot
.67024 .06096 Mdot
.57161 .61482 Mdot
.5768 .54636 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50741 .60802 Mdot
.52362 .58621 Mdot
.57511 .51913 Mdot
.73515 .37223 Mdot
.13287 .48159 Mdot
.35365 .59893 Mdot
.38456 .07878 Mdot
.25708 .22618 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49594 .00549 Mdot
.48706 .01747 Mdot
.45879 .05525 Mdot
.36939 .16319 Mdot
.10535 .25388 Mdot
.69457 .11519 Mdot
.50819 .1076 Mdot
.33409 .23503 Mdot
.95381 .1928 Mdot
.64185 .07803 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48934 .01439 Mdot
.46605 .04563 Mdot
.39223 .13807 Mdot
.16882 .26684 Mdot
.73707 .11978 Mdot
.54326 .08017 Mdot
.41355 .15642 Mdot
.16045 .28122 Mdot
.49995 6e-05 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00198 Mdot
.49532 .00632 Mdot
.4851 .02011 Mdot
.45256 .06344 Mdot
.34991 .18286 Mdot
.05404 .232 Mdot
.67866 .09903 Mdot
.51843 .08198 Mdot
.38578 .17901 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.5119 .60197 Mdot
.53789 .56717 Mdot
.62019 .46604 Mdot
.86611 .35605 Mdot
.29001 .49896 Mdot
.48267 .515 Mdot
.64938 .39597 Mdot
.00869 .40402 Mdot
.35497 .52062 Mdot
.49978 .0003 Mdot
.49929 .00095 Mdot
.49775 .00304 Mdot
.49283 .00968 Mdot
.47716 .03078 Mdot
.42736 .09581 Mdot
.27233 .24191 Mdot
.88091 .14153 Mdot
.65192 .02112 Mdot
.61775 .53969 Mdot
.74451 .39223 Mdot
.10987 .48619 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48992 .01361 Mdot
.46791 .04316 Mdot
.39808 .13131 Mdot
.18561 .26695 Mdot
.75368 .11944 Mdot
.56042 .06476 Mdot
.45563 .10537 Mdot
.28515 .24933 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48731 .01714 Mdot
.45958 .05421 Mdot
.37187 .16056 Mdot
.11207 .25609 Mdot
.69772 .11643 Mdot
.50933 .10779 Mdot
.33491 .23483 Mdot
.95495 .19362 Mdot
.64166 .07896 Mdot
.50113 .61651 Mdot
.5036 .61318 Mdot
.51146 .60257 Mdot
.53648 .56904 Mdot
.61576 .47094 Mdot
.85375 .35366 Mdot
.28153 .49831 Mdot
.47524 .52118 Mdot
.63195 .41239 Mdot
.96469 .37992 Mdot
.34996 .49931 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51108 .60307 Mdot
.5353 .57062 Mdot
.61202 .47513 Mdot
.84324 .35219 Mdot
.27338 .49815 Mdot
.46736 .52819 Mdot
.61274 .4322 Mdot
.91342 .35584 Mdot
.33766 .48156 Mdot
.50083 .61691 Mdot
.50264 .61447 Mdot
.50841 .60667 Mdot
.5268 .58195 Mdot
.58519 .50669 Mdot
.76534 .35983 Mdot
.18312 .49454 Mdot
.38294 .59354 Mdot
.42257 .04448 Mdot
.3506 .16353 Mdot
.08601 .23943 Mdot
.50071 .61708 Mdot
.50225 .615 Mdot
.50717 .60835 Mdot
.52283 .58727 Mdot
.57261 .52226 Mdot
.72758 .37618 Mdot
.11891 .47644 Mdot
.34801 .59688 Mdot
.38224 .07832 Mdot
.25552 .22577 Mdot
.89021 .13188 Mdot
.50089 .61683 Mdot
.50285 .61419 Mdot
.50907 .60579 Mdot
.52888 .57917 Mdot
.59177 .49873 Mdot
.78481 .3547 Mdot
.2109 .49781 Mdot
.40542 .58042 Mdot
.46628 .61145 Mdot
.47692 .01474 Mdot
.45308 .05761 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51437 .59864 Mdot
.54574 .55682 Mdot
.64478 .44036 Mdot
.93226 .37944 Mdot
.31831 .51361 Mdot
.48727 .52539 Mdot
.63717 .41339 Mdot
.96829 .38419 Mdot
.50114 .61649 Mdot
.50364 .61311 Mdot
.51161 .60236 Mdot
.53698 .56839 Mdot
.61731 .46922 Mdot
.8581 .35442 Mdot
.28464 .49848 Mdot
.47808 .51874 Mdot
.63875 .40579 Mdot
.98217 .38929 Mdot
.35228 .50741 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.5119 .60197 Mdot
.53789 .56718 Mdot
.62017 .46606 Mdot
.86606 .35604 Mdot
.28997 .49896 Mdot
.48264 .51502 Mdot
.64932 .39602 Mdot
.00855 .40394 Mdot
.35496 .52055 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52556 .5836 Mdot
.58129 .51147 Mdot
.7537 .36397 Mdot
.16479 .49087 Mdot
.37055 .59807 Mdot
.40285 .06462 Mdot
.2983 .20542 Mdot
.96592 .17407 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49743 .00347 Mdot
.49182 .01105 Mdot
.47395 .03509 Mdot
.41718 .10845 Mdot
.2417 .2558 Mdot
.82781 .12554 Mdot
.62469 .02141 Mdot
.59005 .56035 Mdot
.68339 .42554 Mdot
.99486 .42077 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .00421 Mdot
.49008 .0134 Mdot
.46841 .04249 Mdot
.39965 .12948 Mdot
.19015 .26671 Mdot
.7586 .11938 Mdot
.56543 .06042 Mdot
.46767 .09018 Mdot
.32175 .22299 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00297 Mdot
.49298 .00948 Mdot
.47765 .03013 Mdot
.42891 .09386 Mdot
.27704 .23928 Mdot
.88987 .14514 Mdot
.65503 .0231 Mdot
.61766 .54172 Mdot
.74113 .39441 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00548 Mdot
.48708 .01744 Mdot
.45887 .05515 Mdot
.36963 .16294 Mdot
.10599 .2541 Mdot
.69486 .11532 Mdot
.50827 .10765 Mdot
.33409 .23508 Mdot
.95372 .19278 Mdot
.6418 .07804 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50132 .61624 Mdot
.50422 .61233 Mdot
.51345 .59988 Mdot
.54282 .56066 Mdot
.63566 .44958 Mdot
.90822 .36913 Mdot
.31095 .50599 Mdot
.49224 .51319 Mdot
.66188 .38769 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.5078 .6075 Mdot
.52485 .58456 Mdot
.57902 .51428 Mdot
.7469 .36676 Mdot
.15347 .48799 Mdot
.36389 .59934 Mdot
.39413 .07237 Mdot
.27704 .21779 Mdot
.92464 .15051 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60044 Mdot
.54149 .56241 Mdot
.6315 .45391 Mdot
.89706 .36499 Mdot
.30649 .50334 Mdot
.49207 .51069 Mdot
.66575 .38334 Mdot
.04548 .42494 Mdot
.35792 .53984 Mdot
.49994 7e-05 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.4943 .00771 Mdot
.48183 .02452 Mdot
.44216 .07696 Mdot
.31763 .21139 Mdot
.9756 .18885 Mdot
.67003 .05955 Mdot
.57368 .61169 Mdot
.58393 .53744 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50824 .6069 Mdot
.52626 .58267 Mdot
.58349 .50877 Mdot
.76028 .36153 Mdot
.17531 .49313 Mdot
.37742 .59586 Mdot
.41329 .05429 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.49769 .00312 Mdot
.49265 .00993 Mdot
.47657 .03158 Mdot
.42548 .09817 Mdot
.26664 .24491 Mdot
.87037 .13759 Mdot
.64775 .01946 Mdot
.61627 .53904 Mdot
.74408 .3916 Mdot
.5001 .61789 Mdot
.50033 .61759 Mdot
.50104 .61662 Mdot
.50333 .61354 Mdot
.51061 .60371 Mdot
.53378 .57263 Mdot
.60724 .48056 Mdot
.82967 .35112 Mdot
.26154 .49828 Mdot
.4553 .53917 Mdot
.5829 .46575 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01025 Mdot
.47583 .03257 Mdot
.42314 .10109 Mdot
.25957 .24836 Mdot
.85771 .13334 Mdot
.64196 .0185 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00232 Mdot
.49453 .00739 Mdot
.48256 .02353 Mdot
.4445 .07394 Mdot
.32485 .20547 Mdot
.99239 .19842 Mdot
.67134 .06853 Mdot
.56045 .01383 Mdot
.53808 .5969 Mdot
.57227 .53218 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49605 .00534 Mdot
.4874 .01701 Mdot
.45988 .05382 Mdot
.3728 .15958 Mdot
.1146 .25687 Mdot
.69897 .11684 Mdot
.50991 .10766 Mdot
.33571 .23432 Mdot
.95657 .19456 Mdot
.64177 .07984 Mdot
.50003 .618 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.5009 .61681 Mdot
.50288 .61414 Mdot
.50917 .60564 Mdot
.52922 .57871 Mdot
.59286 .49743 Mdot
.788 .35407 Mdot
.21511 .49808 Mdot
.4092 .57777 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50176 .61565 Mdot
.50562 .61044 Mdot
.51791 .59388 Mdot
.557 .54216 Mdot
.67977 .40875 Mdot
.01839 .42576 Mdot
.32949 .55528 Mdot
.43103 .61724 Mdot
.4323 .06009 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49903 .00132 Mdot
.4969 .00419 Mdot
.49012 .01335 Mdot
.46853 .04233 Mdot
.40003 .12904 Mdot
.19124 .26664 Mdot
.7598 .11938 Mdot
.56665 .05938 Mdot
.47057 .0865 Mdot
.33061 .21552 Mdot
.49977 .00032 Mdot
.49926 .00101 Mdot
.49763 .00321 Mdot
.49244 .01021 Mdot
.47592 .03245 Mdot
.42342 .10073 Mdot
.26044 .24796 Mdot
.85923 .13382 Mdot
.64271 .01855 Mdot
.61269 .54063 Mdot
.73793 .39351 Mdot
.10121 .48114 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50657 .60916 Mdot
.52094 .5898 Mdot
.56662 .52983 Mdot
.70933 .38708 Mdot
.08301 .4606 Mdot
.33775 .58628 Mdot
.38913 .06291 Mdot
.28734 .20641 Mdot
.95336 .16379 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60972 Mdot
.5196 .5916 Mdot
.56237 .53524 Mdot
.69633 .39601 Mdot
.05557 .44649 Mdot
.33314 .57435 Mdot
.40382 .04016 Mdot
.33884 .16531 Mdot
.07137 .22927 Mdot
.50058 .61726 Mdot
.50183 .61556 Mdot
.50584 .61014 Mdot
.51862 .59292 Mdot
.55925 .53925 Mdot
.68673 .40321 Mdot
.03431 .43478 Mdot
.33083 .5637 Mdot
.41874 .01777 Mdot
.39 .11182 Mdot
.20907 .25451 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.49428 .00772 Mdot
.48179 .02456 Mdot
.44205 .07711 Mdot
.31729 .21166 Mdot
.97481 .18841 Mdot
.66996 .05913 Mdot
.57429 .61077 Mdot
.58604 .53484 Mdot
.72066 .38979 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.5259 .58315 Mdot
.58234 .51018 Mdot
.75685 .36277 Mdot
.16987 .49201 Mdot
.37378 .59713 Mdot
.4076 .06003 Mdot
.31048 .19705 Mdot
.99165 .18931 Mdot
.50114 .61649 Mdot
.50363 .61312 Mdot
.51158 .6024 Mdot
.53688 .56851 Mdot
.61701 .46955 Mdot
.85727 .35427 Mdot
.28406 .49844 Mdot
.47756 .51918 Mdot
.63751 .40698 Mdot
.97901 .38757 Mdot
.3519 .50589 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61025 Mdot
.51836 .59327 Mdot
.55842 .54032 Mdot
.68417 .40522 Mdot
.02851 .43151 Mdot
.33032 .56066 Mdot
.42315 .01113 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51085 .60338 Mdot
.53456 .57159 Mdot
.60971 .47775 Mdot
.8367 .35156 Mdot
.26787 .49817 Mdot
.4618 .53325 Mdot
.59899 .44728 Mdot
.87529 .34313 Mdot
.32008 .4766 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49005 .01344 Mdot
.46831 .04262 Mdot
.39935 .12983 Mdot
.18927 .26677 Mdot
.75764 .11939 Mdot
.56445 .06126 Mdot
.46533 .09314 Mdot
.31462 .22869 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51104 .60312 Mdot
.53517 .57078 Mdot
.61164 .47556 Mdot
.84217 .35207 Mdot
.2725 .49815 Mdot
.46648 .52899 Mdot
.61057 .43453 Mdot
.90748 .35351 Mdot
.33549 .48028 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.5127 .60089 Mdot
.54043 .56381 Mdot
.62817 .45743 Mdot
.88803 .36198 Mdot
.30234 .50162 Mdot
.4907 .51024 Mdot
.66511 .38319 Mdot
.0451 .42444 Mdot
.35834 .5391 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .00441 Mdot
.4896 .01405 Mdot
.46687 .04454 Mdot
.3948 .13512 Mdot
.17618 .26707 Mdot
.74405 .11963 Mdot
.55048 .07361 Mdot
.43137 .13528 Mdot
.21248 .27875 Mdot
.76146 .13158 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.4973 .00365 Mdot
.4914 .01162 Mdot
.4726 .03689 Mdot
.41291 .11366 Mdot
.229 .25992 Mdot
.80844 .12221 Mdot
.61069 .02767 Mdot
.56592 .58633 Mdot
.61723 .48721 Mdot
.49998 3e-05 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00267 Mdot
.49371 .00849 Mdot
.47997 .02701 Mdot
.43627 .08453 Mdot
.2995 .22499 Mdot
.93546 .16678 Mdot
.6656 .03951 Mdot
.60167 .56957 Mdot
.49995 7e-05 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00212 Mdot
.495 .00675 Mdot
.48407 .0215 Mdot
.44929 .06772 Mdot
.33972 .19244 Mdot
.02835 .21858 Mdot
.67468 .08725 Mdot
.53351 .05641 Mdot
.44224 .10879 Mdot
.50053 .61732 Mdot
.50168 .61576 Mdot
.50536 .61079 Mdot
.51708 .59499 Mdot
.55436 .54557 Mdot
.67161 .41556 Mdot
.99921 .41484 Mdot
.328 .54501 Mdot
.44615 .59399 Mdot
.48505 .60783 Mdot
.50156 .60639 Mdot
.50096 .61674 Mdot
.50305 .61392 Mdot
.50971 .60492 Mdot
.53093 .57643 Mdot
.59824 .49103 Mdot
.80374 .35182 Mdot
.23449 .49866 Mdot
.42764 .56345 Mdot
.51595 .54869 Mdot
.62815 .44232 Mdot
.91247 .3652 Mdot
.50129 .61629 Mdot
.5041 .61249 Mdot
.51307 .60039 Mdot
.54162 .56225 Mdot
.63188 .45351 Mdot
.89809 .36536 Mdot
.30693 .50356 Mdot
.49215 .51084 Mdot
.6656 .38355 Mdot
.045 .42472 Mdot
.35779 .5397 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00405 Mdot
.49045 .0129 Mdot
.46958 .04093 Mdot
.40336 .12511 Mdot
.20093 .2657 Mdot
.77102 .11944 Mdot
.57777 .05018 Mdot
.49657 .05336 Mdot
.41024 .13223 Mdot
.19629 .27145 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.50451 .61195 Mdot
.51436 .59865 Mdot
.54572 .55685 Mdot
.64471 .44044 Mdot
.93206 .37935 Mdot
.31826 .51353 Mdot
.48734 .52526 Mdot
.63746 .41309 Mdot
.96907 .3846 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48717 .01733 Mdot
.45913 .0548 Mdot
.37047 .16206 Mdot
.10825 .25485 Mdot
.69589 .11575 Mdot
.5086 .10778 Mdot
.33421 .23515 Mdot
.95374 .19286 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49785 .0029 Mdot
.49315 .00925 Mdot
.47819 .0294 Mdot
.43061 .09171 Mdot
.28222 .23625 Mdot
.89996 .14949 Mdot
.65808 .02588 Mdot
.6162 .54551 Mdot
.73355 .39875 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50701 .60857 Mdot
.52232 .58795 Mdot
.57099 .5243 Mdot
.72267 .37892 Mdot
.10956 .47265 Mdot
.34479 .5948 Mdot
.38239 .07614 Mdot
.25919 .22344 Mdot
.89766 .13497 Mdot
.49996 6e-05 Mdot
.49986 .00018 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00598 Mdot
.4859 .01903 Mdot
.4551 .06011 Mdot
.35785 .17505 Mdot
.07461 .24171 Mdot
.68351 .10686 Mdot
.51061 .09703 Mdot
.35362 .21439 Mdot
.50028 .61765 Mdot
.5009 .61682 Mdot
.50285 .61418 Mdot
.50909 .60575 Mdot
.52896 .57905 Mdot
.59204 .4984 Mdot
.78562 .35453 Mdot
.21197 .49789 Mdot
.40637 .57976 Mdot
.4683 .60895 Mdot
.483 .00665 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50515 .61107 Mdot
.51642 .59588 Mdot
.55226 .5483 Mdot
.6651 .42125 Mdot
.9835 .40598 Mdot
.32661 .53676 Mdot
.45811 .57515 Mdot
.52749 .54979 Mdot
.6379 .43736 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48771 .0166 Mdot
.46085 .05252 Mdot
.37587 .15628 Mdot
.12301 .2593 Mdot
.70346 .11801 Mdot
.51251 .10642 Mdot
.34031 .23084 Mdot
.9668 .20029 Mdot
.64273 .08501 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49714 .00387 Mdot
.49087 .01233 Mdot
.47092 .03913 Mdot
.40761 .12006 Mdot
.21335 .26371 Mdot
.78667 .12006 Mdot
.59241 .03913 Mdot
.5291 .0123 Mdot
.5092 .00378 Mdot
.50308 .00093 Mdot
.50081 .61695 Mdot
.50257 .61457 Mdot
.50818 .60699 Mdot
.52605 .58294 Mdot
.58283 .50958 Mdot
.75832 .36223 Mdot
.17221 .4925 Mdot
.37533 .59662 Mdot
.40998 .05766 Mdot
.31668 .19244 Mdot
.0053 .19736 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50703 .60854 Mdot
.52238 .58786 Mdot
.5712 .52403 Mdot
.7233 .37856 Mdot
.11077 .47316 Mdot
.34518 .5951 Mdot
.3823 .0765 Mdot
.25852 .22383 Mdot
.89635 .13439 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.50059 .61723 Mdot
.50189 .61548 Mdot
.50603 .60989 Mdot
.51922 .59211 Mdot
.56116 .5368 Mdot
.69259 .39876 Mdot
.04739 .44204 Mdot
.33215 .57036 Mdot
.40929 .03194 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49347 .00882 Mdot
.47921 .02803 Mdot
.43385 .08761 Mdot
.29209 .23003 Mdot
.9199 .15887 Mdot
.66285 .03289 Mdot
.60963 .55714 Mdot
.70815 .41467 Mdot
.03721 .44885 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00091 Mdot
.49785 .00291 Mdot
.49314 .00927 Mdot
.47815 .02946 Mdot
.43048 .09188 Mdot
.28182 .23648 Mdot
.89918 .14914 Mdot
.65786 .02564 Mdot
.61636 .54516 Mdot
.73428 .39833 Mdot
.50093 .61678 Mdot
.50296 .61403 Mdot
.50944 .60529 Mdot
.53005 .57759 Mdot
.59549 .49429 Mdot
.79571 .35279 Mdot
.22489 .4985 Mdot
.4183 .57096 Mdot
.49447 .57609 Mdot
.56234 .51976 Mdot
.72135 .3746 Mdot
.50013 .61785 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.50431 .61222 Mdot
.51372 .59952 Mdot
.54368 .55953 Mdot
.63835 .44682 Mdot
.91537 .37201 Mdot
.31344 .50799 Mdot
.49149 .51588 Mdot
.65679 .39292 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46949 .04104 Mdot
.40308 .12544 Mdot
.20011 .2658 Mdot
.77004 .11942 Mdot
.57681 .05094 Mdot
.49438 .05615 Mdot
.40353 .1402 Mdot
.17668 .27237 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48709 .01743 Mdot
.4589 .05511 Mdot
.36973 .16283 Mdot
.10627 .25419 Mdot
.69498 .11537 Mdot
.50831 .10767 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07804 Mdot
.49989 .00014 Mdot
.49967 .00045 Mdot
.49893 .00144 Mdot
.4966 .00459 Mdot
.48917 .01462 Mdot
.46551 .04635 Mdot
.39051 .14004 Mdot
.16392 .26652 Mdot
.73267 .11985 Mdot
.53875 .08428 Mdot
.40238 .16922 Mdot
.12858 .27586 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48947 .01422 Mdot
.46645 .0451 Mdot
.39348 .13663 Mdot
.17241 .26699 Mdot
.74041 .11971 Mdot
.54672 .07702 Mdot
.42209 .14639 Mdot
.18522 .28189 Mdot
.72912 .13561 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49852 .00201 Mdot
.49527 .00639 Mdot
.48493 .02034 Mdot
.45203 .06414 Mdot
.34825 .18445 Mdot
.04981 .22988 Mdot
.67787 .09723 Mdot
.52055 .07823 Mdot
.39397 .16942 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49084 .01238 Mdot
.47081 .03928 Mdot
.40726 .12048 Mdot
.21232 .26391 Mdot
.78531 .11998 Mdot
.59119 .03999 Mdot
.52648 .01556 Mdot
.5013 .01436 Mdot
.47807 .03462 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46941 .04116 Mdot
.40281 .12576 Mdot
.19933 .26589 Mdot
.76911 .11941 Mdot
.57591 .05168 Mdot
.4923 .05881 Mdot
.39713 .14768 Mdot
.50123 .61637 Mdot
.50391 .61275 Mdot
.51247 .6012 Mdot
.53971 .56476 Mdot
.62591 .45984 Mdot
.88187 .36011 Mdot
.2992 .50066 Mdot
.48912 .51074 Mdot
.66272 .38483 Mdot
.04005 .42157 Mdot
.35794 .53646 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50746 .60795 Mdot
.52378 .58599 Mdot
.57562 .5185 Mdot
.73666 .37147 Mdot
.13561 .48252 Mdot
.35487 .59918 Mdot
.38539 .07845 Mdot
.25846 .22578 Mdot
.89313 .13399 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50832 .6068 Mdot
.5265 .58234 Mdot
.58425 .50784 Mdot
.76255 .36075 Mdot
.17884 .49379 Mdot
.37987 .59488 Mdot
.41732 .0501 Mdot
.33627 .17649 Mdot
.0507 .2227 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51259 .60104 Mdot
.54009 .56427 Mdot
.62708 .45858 Mdot
.88508 .36107 Mdot
.30087 .50114 Mdot
.49001 .5104 Mdot
.66417 .3838 Mdot
.04317 .42333 Mdot
.35821 .53806 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47455 .03428 Mdot
.41908 .10611 Mdot
.2474 .25363 Mdot
.83702 .12759 Mdot
.63056 .01968 Mdot
.59872 .55196 Mdot
.70563 .41011 Mdot
.04207 .44865 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.4954 .00622 Mdot
.48534 .01979 Mdot
.45332 .06245 Mdot
.35228 .18056 Mdot
.06014 .23499 Mdot
.67992 .10152 Mdot
.51566 .08703 Mdot
.37485 .19146 Mdot
.06507 .25011 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47455 .03428 Mdot
.41908 .10611 Mdot
.2474 .25363 Mdot
.83701 .12759 Mdot
.63056 .01968 Mdot
.59871 .55196 Mdot
.70562 .41011 Mdot
.04204 .44864 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00813 Mdot
.48083 .02586 Mdot
.43898 .08106 Mdot
.30783 .21897 Mdot
.95353 .1765 Mdot
.66795 .04813 Mdot
.59008 .58704 Mdot
.64022 .47323 Mdot
.87452 .36859 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49085 .01236 Mdot
.47085 .03923 Mdot
.40738 .12033 Mdot
.21269 .26384 Mdot
.78579 .12001 Mdot
.59162 .03968 Mdot
.52741 .0144 Mdot
.50411 .01058 Mdot
.48699 .02263 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00379 Mdot
.49107 .01206 Mdot
.47156 .03828 Mdot
.40962 .11763 Mdot
.21929 .26244 Mdot
.79465 .12066 Mdot
.59941 .03438 Mdot
.54378 .61233 Mdot
.553 .5641 Mdot
.64027 .45025 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00367 Mdot
.49136 .01168 Mdot
.47246 .03708 Mdot
.41247 .11419 Mdot
.2277 .26029 Mdot
.80654 .12196 Mdot
.60921 .02848 Mdot
.56313 .58951 Mdot
.60927 .49598 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50041 .61748 Mdot
.5013 .61627 Mdot
.50416 .61242 Mdot
.51324 .60015 Mdot
.54217 .56151 Mdot
.63363 .45168 Mdot
.9028 .36707 Mdot
.30887 .50463 Mdot
.49236 .51171 Mdot
.50037 .61754 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60208 Mdot
.53764 .56751 Mdot
.61939 .46692 Mdot
.8639 .35557 Mdot
.28857 .49881 Mdot
.48149 .51593 Mdot
.64669 .39839 Mdot
.00208 .40032 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60311 Mdot
.5352 .57074 Mdot
.61172 .47547 Mdot
.84239 .3521 Mdot
.27269 .49815 Mdot
.46667 .52882 Mdot
.61103 .43403 Mdot
.90875 .354 Mdot
.33597 .48054 Mdot
.50127 .61632 Mdot
.50405 .61257 Mdot
.51289 .60063 Mdot
.54106 .56298 Mdot
.63013 .45535 Mdot
.89336 .36372 Mdot
.30485 .50259 Mdot
.49164 .51034 Mdot
.6659 .38292 Mdot
.04633 .42526 Mdot
.35824 .53998 Mdot
.50044 .61744 Mdot
.50139 .61616 Mdot
.50443 .61205 Mdot
.51411 .59899 Mdot
.54492 .5579 Mdot
.64222 .44291 Mdot
.92558 .37641 Mdot
.31654 .51124 Mdot
.48934 .52112 Mdot
.64615 .40388 Mdot
.99265 .39708 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .00471 Mdot
.4889 .01498 Mdot
.46466 .04748 Mdot
.38784 .14306 Mdot
.15637 .2658 Mdot
.7263 .11989 Mdot
.53232 .09013 Mdot
.38649 .18666 Mdot
.08446 .26134 Mdot
.66161 .13597 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50718 .60834 Mdot
.52286 .58722 Mdot
.57272 .52212 Mdot
.72791 .376 Mdot
.11953 .47668 Mdot
.34824 .597 Mdot
.38228 .07841 Mdot
.25541 .22587 Mdot
.88994 .13178 Mdot
.50122 .61639 Mdot
.50388 .6128 Mdot
.51235 .60136 Mdot
.53932 .56528 Mdot
.62467 .46117 Mdot
.87849 .35915 Mdot
.29737 .50021 Mdot
.48802 .5113 Mdot
.66072 .38637 Mdot
.03557 .41907 Mdot
.35751 .53421 Mdot
.49983 .00024 Mdot
.49945 .00075 Mdot
.49823 .00239 Mdot
.49437 .0076 Mdot
.48207 .02418 Mdot
.44294 .07595 Mdot
.32004 .20944 Mdot
.98116 .19202 Mdot
.67047 .06251 Mdot
.56932 .00026 Mdot
.5689 .5564 Mdot
.66862 .42773 Mdot
.50127 .61632 Mdot
.50405 .61257 Mdot
.51289 .60063 Mdot
.54105 .56299 Mdot
.63011 .45537 Mdot
.8933 .3637 Mdot
.30482 .50258 Mdot
.49163 .51033 Mdot
.6659 .38291 Mdot
.04633 .42526 Mdot
.35825 .53997 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00648 Mdot
.48473 .02061 Mdot
.45138 .06499 Mdot
.34623 .18637 Mdot
.04467 .22724 Mdot
.67698 .09496 Mdot
.52334 .07339 Mdot
.40459 .15665 Mdot
.15113 .27662 Mdot
.50079 .61696 Mdot
.50253 .61462 Mdot
.50806 .60715 Mdot
.52566 .58347 Mdot
.58159 .5111 Mdot
.75462 .36361 Mdot
.16629 .49121 Mdot
.37149 .59782 Mdot
.40419 .06334 Mdot
.30171 .20316 Mdot
.97298 .17824 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51084 .60339 Mdot
.53453 .57163 Mdot
.60961 .47787 Mdot
.8364 .35154 Mdot
.26761 .49818 Mdot
.46154 .53349 Mdot
.59834 .44801 Mdot
.87344 .34266 Mdot
.31899 .47656 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00553 Mdot
.48697 .0176 Mdot
.4585 .05564 Mdot
.36848 .16415 Mdot
.10287 .25302 Mdot
.69348 .11468 Mdot
.50793 .10733 Mdot
.33426 .23468 Mdot
.95455 .19311 Mdot
.64209 .0782 Mdot
.50012 .61787 Mdot
.50038 .61753 Mdot
.5012 .61642 Mdot
.50382 .61288 Mdot
.51216 .60162 Mdot
.53871 .56609 Mdot
.62276 .46324 Mdot
.87323 .35775 Mdot
.29438 .4996 Mdot
.48601 .51255 Mdot
.65668 .38966 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51319 .60023 Mdot
.542 .56174 Mdot
.63309 .45224 Mdot
.90135 .36653 Mdot
.30829 .50429 Mdot
.49233 .5114 Mdot
.66486 .38447 Mdot
.04278 .42365 Mdot
.3573 .53892 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.51171 .60223 Mdot
.53728 .56798 Mdot
.61828 .46815 Mdot
.8608 .35494 Mdot
.2865 .49862 Mdot
.47972 .51736 Mdot
.64262 .40215 Mdot
.99193 .39467 Mdot
.35334 .51219 Mdot
.50083 .61691 Mdot
.50264 .61447 Mdot
.50841 .60668 Mdot
.52679 .58196 Mdot
.58516 .50673 Mdot
.76525 .35986 Mdot
.18299 .49452 Mdot
.38284 .59358 Mdot
.4224 .04467 Mdot
.35012 .16397 Mdot
.0848 .23892 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00325 Mdot
.49235 .01034 Mdot
.47561 .03286 Mdot
.42245 .10194 Mdot
.25751 .24932 Mdot
.8541 .13223 Mdot
.64015 .01845 Mdot
.61029 .54223 Mdot
.73295 .39553 Mdot
.09297 .4769 Mdot
.50076 .61701 Mdot
.50242 .61476 Mdot
.50773 .6076 Mdot
.52461 .58488 Mdot
.57826 .51521 Mdot
.74463 .36775 Mdot
.1496 .4869 Mdot
.36178 .59952 Mdot
.39173 .07429 Mdot
.27152 .22049 Mdot
.91476 .1452 Mdot
.50042 .61747 Mdot
.50134 .61622 Mdot
.50427 .61226 Mdot
.51361 .59966 Mdot
.54334 .55998 Mdot
.63728 .44792 Mdot
.91253 .37085 Mdot
.31248 .50717 Mdot
.49186 .51471 Mdot
.65905 .39061 Mdot
.02703 .41555 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.50411 .61249 Mdot
.51308 .60037 Mdot
.54166 .5622 Mdot
.63201 .45338 Mdot
.89843 .36548 Mdot
.30707 .50364 Mdot
.49218 .51089 Mdot
.66555 .38363 Mdot
.04482 .42463 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00517 Mdot
.48782 .01645 Mdot
.46121 .05205 Mdot
.37698 .15508 Mdot
.12606 .2601 Mdot
.70521 .11836 Mdot
.5137 .10568 Mdot
.34271 .22888 Mdot
.97237 .2034 Mdot
.64326 .08781 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00407 Mdot
.49039 .01297 Mdot
.4694 .04117 Mdot
.40279 .12579 Mdot
.19926 .2659 Mdot
.76903 .11941 Mdot
.57582 .05174 Mdot
.4921 .05906 Mdot
.39653 .14837 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00407 Mdot
.49041 .01295 Mdot
.46945 .0411 Mdot
.40294 .1256 Mdot
.19971 .26585 Mdot
.76956 .11941 Mdot
.57635 .05132 Mdot
.49332 .05751 Mdot
.40026 .14404 Mdot
.16719 .27206 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00554 Mdot
.48694 .01763 Mdot
.45842 .05574 Mdot
.36824 .16441 Mdot
.10222 .25279 Mdot
.6932 .11454 Mdot
.50787 .10724 Mdot
.33435 .23455 Mdot
.95484 .19324 Mdot
.64217 .07829 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49022 .01321 Mdot
.46885 .0419 Mdot
.40105 .12783 Mdot
.19421 .26641 Mdot
.76316 .11937 Mdot
.57002 .05653 Mdot
.47855 .07636 Mdot
.355 .19294 Mdot
.04281 .23215 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00332 Mdot
.49218 .01057 Mdot
.47508 .03357 Mdot
.42077 .10403 Mdot
.25245 .25155 Mdot
.84543 .12975 Mdot
.6355 .01877 Mdot
.60513 .54627 Mdot
.72124 .40113 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49943 .00076 Mdot
.4982 .00243 Mdot
.49426 .00776 Mdot
.48171 .02468 Mdot
.44178 .07745 Mdot
.31646 .21232 Mdot
.97292 .18734 Mdot
.6698 .05813 Mdot
.57575 .60856 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.51149 .60252 Mdot
.5366 .56888 Mdot
.61613 .47053 Mdot
.8548 .35383 Mdot
.28229 .49835 Mdot
.47594 .52057 Mdot
.63365 .41072 Mdot
.96908 .38224 Mdot
.3506 .50128 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.4965 .00473 Mdot
.48884 .01507 Mdot
.46446 .04774 Mdot
.38722 .14376 Mdot
.1546 .26559 Mdot
.72488 .11988 Mdot
.53091 .0914 Mdot
.38302 .19034 Mdot
.07504 .25736 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.49571 .0058 Mdot
.48632 .01847 Mdot
.45643 .05836 Mdot
.36201 .17084 Mdot
.08558 .24641 Mdot
.68688 .11032 Mdot
.50837 .10256 Mdot
.34242 .22592 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49737 .00356 Mdot
.49161 .01134 Mdot
.47327 .036 Mdot
.41501 .1111 Mdot
.23524 .25801 Mdot
.81777 .12364 Mdot
.61771 .0242 Mdot
.57855 .57233 Mdot
.6525 .45162 Mdot
.92177 .38198 Mdot
.50119 .61643 Mdot
.50378 .61292 Mdot
.51205 .60176 Mdot
.53839 .56651 Mdot
.62176 .46433 Mdot
.87046 .35706 Mdot
.29272 .49933 Mdot
.48479 .51341 Mdot
.65408 .39186 Mdot
.02004 .41039 Mdot
.35602 .52639 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48784 .01642 Mdot
.46127 .05198 Mdot
.37717 .15488 Mdot
.12657 .26023 Mdot
.70551 .11841 Mdot
.51391 .10554 Mdot
.34315 .22852 Mdot
.97339 .20397 Mdot
.64336 .08832 Mdot
.5004 .61749 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.5129 .60061 Mdot
.54109 .56294 Mdot
.63024 .45523 Mdot
.89367 .36383 Mdot
.30499 .50265 Mdot
.49168 .51036 Mdot
.66591 .38293 Mdot
.04631 .42526 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00245 Mdot
.49422 .00781 Mdot
.48158 .02484 Mdot
.44139 .07796 Mdot
.31525 .21328 Mdot
.97015 .18577 Mdot
.66957 .05667 Mdot
.57787 .60536 Mdot
.59839 .51985 Mdot
.75726 .37246 Mdot
.50115 .61649 Mdot
.50365 .6131 Mdot
.51163 .60232 Mdot
.53705 .56828 Mdot
.61755 .46895 Mdot
.85877 .35454 Mdot
.28511 .49851 Mdot
.4785 .51838 Mdot
.63974 .40486 Mdot
.98467 .39066 Mdot
.35256 .50862 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50965 .605 Mdot
.53073 .57669 Mdot
.59763 .49176 Mdot
.80195 .352 Mdot
.2324 .49864 Mdot
.50042 .61746 Mdot
.50135 .6162 Mdot
.50431 .61221 Mdot
.51374 .59948 Mdot
.54376 .55942 Mdot
.6386 .44656 Mdot
.91605 .37229 Mdot
.31366 .50819 Mdot
.49139 .51617 Mdot
.6562 .39352 Mdot
.01948 .41153 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48715 .01735 Mdot
.45907 .05488 Mdot
.37028 .16225 Mdot
.10776 .25469 Mdot
.69566 .11566 Mdot
.50852 .10776 Mdot
.33417 .23515 Mdot
.95369 .19282 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48977 .01381 Mdot
.46742 .04381 Mdot
.39654 .1331 Mdot
.18118 .26707 Mdot
.74905 .11952 Mdot
.55566 .06897 Mdot
.44406 .11976 Mdot
.25028 .26731 Mdot
.81776 .13294 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.49429 .00771 Mdot
.48182 .02452 Mdot
.44215 .07698 Mdot
.31759 .21142 Mdot
.9755 .1888 Mdot
.67002 .0595 Mdot
.57375 .61158 Mdot
.58419 .53712 Mdot
.71512 .3931 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51004 .60447 Mdot
.53199 .57502 Mdot
.60158 .48711 Mdot
.81342 .35113 Mdot
.24529 .49861 Mdot
.43853 .55419 Mdot
.54183 .51586 Mdot
.70715 .37363 Mdot
.10261 .4623 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50515 .61108 Mdot
.5164 .5959 Mdot
.55222 .54836 Mdot
.66495 .42138 Mdot
.98315 .40579 Mdot
.32657 .53658 Mdot
.45837 .57474 Mdot
.52842 .54854 Mdot
.64087 .43434 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .00379 Mdot
.49106 .01207 Mdot
.47152 .03833 Mdot
.4095 .11778 Mdot
.21893 .26252 Mdot
.79416 .12062 Mdot
.59899 .03465 Mdot
.54292 .61338 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49302 .00943 Mdot
.47777 .02997 Mdot
.42928 .09339 Mdot
.27817 .23863 Mdot
.89206 .14606 Mdot
.65573 .02365 Mdot
.61746 .54241 Mdot
.73982 .39517 Mdot
.10042 .48221 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00544 Mdot
.48718 .01731 Mdot
.45917 .05475 Mdot
.37057 .16195 Mdot
.10854 .25495 Mdot
.69603 .1158 Mdot
.50865 .10779 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60041 Mdot
.54157 .56231 Mdot
.63173 .45367 Mdot
.89768 .36521 Mdot
.30676 .50347 Mdot
.49212 .51078 Mdot
.66567 .38347 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45872 .05535 Mdot
.36916 .16343 Mdot
.10472 .25366 Mdot
.69429 .11506 Mdot
.50812 .10754 Mdot
.33411 .23496 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01438 Mdot
.46607 .0456 Mdot
.39229 .138 Mdot
.169 .26685 Mdot
.73723 .11978 Mdot
.54343 .08001 Mdot
.41396 .15595 Mdot
.16164 .28133 Mdot
.70644 .13928 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00483 Mdot
.4886 .01539 Mdot
.46371 .04874 Mdot
.38484 .14642 Mdot
.14792 .26465 Mdot
.71971 .11977 Mdot
.52593 .09584 Mdot
.37086 .20285 Mdot
.04264 .24191 Mdot
.65123 .12188 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.4884 .01567 Mdot
.46305 .04961 Mdot
.38277 .14873 Mdot
.14212 .26366 Mdot
.71552 .11956 Mdot
.52206 .09918 Mdot
.36158 .21192 Mdot
.01869 .22921 Mdot
.64782 .11104 Mdot
.50007 .61794 Mdot
.50021 .61774 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50695 .60865 Mdot
.52213 .5882 Mdot
.57041 .52504 Mdot
.72088 .37996 Mdot
.10609 .47119 Mdot
.3437 .59389 Mdot
.38276 .07498 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.5063 .60952 Mdot
.52008 .59095 Mdot
.5639 .53329 Mdot
.70103 .39267 Mdot
.06567 .45184 Mdot
.33458 .57904 Mdot
.39768 .04946 Mdot
.31765 .18388 Mdot
.02013 .20249 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51085 .60338 Mdot
.53457 .57159 Mdot
.60972 .47774 Mdot
.83672 .35156 Mdot
.26789 .49817 Mdot
.46182 .53323 Mdot
.59904 .44723 Mdot
.87541 .34317 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51024 .6042 Mdot
.53263 .57416 Mdot
.60361 .48475 Mdot
.81927 .35096 Mdot
.2514 .4985 Mdot
.44481 .54864 Mdot
.55709 .49685 Mdot
.75317 .34933 Mdot
.18793 .4858 Mdot
.50021 .61776 Mdot
.50065 .61715 Mdot
.50208 .61522 Mdot
.50664 .60907 Mdot
.52114 .58952 Mdot
.56727 .529 Mdot
.71134 .38578 Mdot
.08713 .46258 Mdot
.33865 .58782 Mdot
.38754 .06558 Mdot
.28143 .21026 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.50501 .61126 Mdot
.51597 .59648 Mdot
.55084 .55015 Mdot
.66069 .42523 Mdot
.97266 .4 Mdot
.32544 .53128 Mdot
.4658 .56274 Mdot
.55527 .51252 Mdot
.72599 .36665 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51281 .60074 Mdot
.54079 .56334 Mdot
.62929 .45623 Mdot
.8911 .36297 Mdot
.3038 .50216 Mdot
.49129 .51023 Mdot
.66571 .3829 Mdot
.04616 .4251 Mdot
.35834 .53976 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60697 Mdot
.52609 .58289 Mdot
.58295 .50942 Mdot
.75869 .3621 Mdot
.1728 .49262 Mdot
.37572 .59648 Mdot
.41059 .05705 Mdot
.31828 .19122 Mdot
.50038 .61751 Mdot
.50122 .61638 Mdot
.5039 .61276 Mdot
.51243 .60125 Mdot
.5396 .56492 Mdot
.62554 .46023 Mdot
.88088 .35982 Mdot
.29867 .50052 Mdot
.48881 .51089 Mdot
.66218 .38524 Mdot
.03885 .4209 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49732 .00362 Mdot
.49147 .01153 Mdot
.47281 .03661 Mdot
.41358 .11285 Mdot
.23099 .25934 Mdot
.81137 .12263 Mdot
.61295 .02649 Mdot
.57009 .58162 Mdot
.629 .4747 Mdot
.86092 .36156 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .0021 Mdot
.49504 .0067 Mdot
.4842 .02132 Mdot
.44971 .06716 Mdot
.34104 .19122 Mdot
.03164 .22036 Mdot
.67509 .08886 Mdot
.53132 .06001 Mdot
.43422 .11927 Mdot
.24124 .26659 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49785 .0029 Mdot
.49315 .00925 Mdot
.47818 .02942 Mdot
.43058 .09175 Mdot
.28212 .2363 Mdot
.89978 .14941 Mdot
.65803 .02583 Mdot
.61624 .54543 Mdot
.73372 .39865 Mdot
.08869 .47668 Mdot
.50007 .61794 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50688 .60875 Mdot
.52191 .5885 Mdot
.56969 .52594 Mdot
.71871 .38124 Mdot
.10185 .46934 Mdot
.34244 .5927 Mdot
.38344 .07332 Mdot
.50105 .61662 Mdot
.50333 .61353 Mdot
.51062 .60369 Mdot
.53384 .57255 Mdot
.60743 .48035 Mdot
.8302 .35115 Mdot
.26203 .49827 Mdot
.45581 .53871 Mdot
.58416 .46427 Mdot
.83295 .33632 Mdot
.28877 .47951 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00666 Mdot
.48431 .02118 Mdot
.45003 .06674 Mdot
.34204 .1903 Mdot
.03413 .2217 Mdot
.67542 .09006 Mdot
.5297 .06269 Mdot
.42827 .12696 Mdot
.50014 .61784 Mdot
.50046 .61742 Mdot
.50146 .61607 Mdot
.50464 .61177 Mdot
.51478 .59808 Mdot
.54706 .55508 Mdot
.64892 .43631 Mdot
.94296 .38455 Mdot
.32074 .51776 Mdot
.48298 .53351 Mdot
.61975 .43267 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.4881 .01606 Mdot
.46212 .05085 Mdot
.37984 .15196 Mdot
.13395 .26199 Mdot
.71004 .11908 Mdot
.51737 .10301 Mdot
.35069 .222 Mdot
.99149 .21411 Mdot
.64505 .0975 Mdot
.50041 .61748 Mdot
.5013 .61627 Mdot
.50415 .61243 Mdot
.51322 .60019 Mdot
.54209 .56162 Mdot
.63337 .45195 Mdot
.90209 .36681 Mdot
.30859 .50446 Mdot
.49235 .51156 Mdot
.66463 .38473 Mdot
.04212 .42333 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.5123 .60142 Mdot
.53918 .56546 Mdot
.62425 .46163 Mdot
.87732 .35883 Mdot
.29672 .50006 Mdot
.48761 .51154 Mdot
.65992 .387 Mdot
.03375 .41805 Mdot
.35733 .5333 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49583 .00563 Mdot
.48672 .01793 Mdot
.4577 .05669 Mdot
.36598 .16676 Mdot
.09616 .25058 Mdot
.69072 .11315 Mdot
.50763 .10608 Mdot
.336 .2326 Mdot
.95964 .19559 Mdot
.64318 .08005 Mdot
.50028 .61766 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50903 .60583 Mdot
.52877 .5793 Mdot
.59144 .49912 Mdot
.78384 .3549 Mdot
.2096 .49772 Mdot
.40428 .5812 Mdot
.46387 .61442 Mdot
.46972 .02428 Mdot
.50013 .61785 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.50429 .61224 Mdot
.51367 .59957 Mdot
.54354 .55971 Mdot
.63792 .44726 Mdot
.91424 .37155 Mdot
.31306 .50766 Mdot
.49165 .51539 Mdot
.65773 .39196 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .6042 Mdot
.53263 .57416 Mdot
.60363 .48473 Mdot
.81932 .35096 Mdot
.25145 .4985 Mdot
.44486 .5486 Mdot
.55721 .4967 Mdot
.75354 .34919 Mdot
.18854 .48587 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51177 .60214 Mdot
.53749 .5677 Mdot
.61893 .46742 Mdot
.86263 .35531 Mdot
.28773 .49872 Mdot
.48078 .5165 Mdot
.64506 .39988 Mdot
.99805 .39807 Mdot
.35396 .51524 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49645 .00479 Mdot
.4887 .01526 Mdot
.464 .04835 Mdot
.38577 .14539 Mdot
.15052 .26504 Mdot
.72168 .11982 Mdot
.5278 .09418 Mdot
.37541 .19825 Mdot
.05463 .24791 Mdot
.65351 .12666 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.5085 .60656 Mdot
.52707 .58158 Mdot
.58604 .50565 Mdot
.76789 .35903 Mdot
.18696 .49515 Mdot
.38578 .59218 Mdot
.42761 .03897 Mdot
.36456 .14991 Mdot
.122 .25226 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49792 .0028 Mdot
.49339 .00893 Mdot
.47893 .02841 Mdot
.43296 .08874 Mdot
.28937 .2318 Mdot
.91431 .15614 Mdot
.66167 .03074 Mdot
.61192 .55336 Mdot
.71656 .40906 Mdot
.05469 .45877 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00506 Mdot
.48807 .0161 Mdot
.46202 .05098 Mdot
.37954 .15229 Mdot
.13313 .26181 Mdot
.70951 .11901 Mdot
.51695 .10333 Mdot
.34975 .22284 Mdot
.98919 .21282 Mdot
.64483 .09633 Mdot
.50001 .61802 Mdot
.50002 .61801 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50697 .60862 Mdot
.52221 .58809 Mdot
.57065 .52473 Mdot
.72163 .37952 Mdot
.10755 .47181 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01346 Mdot
.46825 .04271 Mdot
.39915 .13007 Mdot
.18869 .2668 Mdot
.757 .1194 Mdot
.56381 .06182 Mdot
.46378 .09511 Mdot
.30989 .23233 Mdot
.93396 .17285 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00807 Mdot
.48098 .02566 Mdot
.43947 .08043 Mdot
.30933 .21784 Mdot
.95686 .17833 Mdot
.66831 .0498 Mdot
.58773 .59056 Mdot
.63218 .48164 Mdot
.85287 .36385 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.4663 .04529 Mdot
.39302 .13717 Mdot
.17108 .26694 Mdot
.73916 .11974 Mdot
.54542 .0782 Mdot
.4189 .15017 Mdot
.50095 .61675 Mdot
.50302 .61396 Mdot
.50962 .60504 Mdot
.53064 .57681 Mdot
.59733 .4921 Mdot
.80109 .3521 Mdot
.23139 .49863 Mdot
.42458 .56596 Mdot
.50884 .55777 Mdot
.60635 .46635 Mdot
.85178 .34796 Mdot
.50118 .61643 Mdot
.50377 .61294 Mdot
.51202 .60181 Mdot
.53828 .56666 Mdot
.6214 .46472 Mdot
.86947 .35683 Mdot
.29211 .49924 Mdot
.48433 .51374 Mdot
.65308 .39272 Mdot
.01765 .40905 Mdot
.3558 .52517 Mdot
.50123 .61638 Mdot
.5039 .61276 Mdot
.51244 .60124 Mdot
.53962 .56488 Mdot
.62562 .46015 Mdot
.88108 .35988 Mdot
.29878 .50055 Mdot
.48887 .51086 Mdot
.66229 .38515 Mdot
.0391 .42104 Mdot
.35785 .53599 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49235 .01033 Mdot
.47564 .03282 Mdot
.42253 .10184 Mdot
.25776 .24921 Mdot
.85453 .13236 Mdot
.64037 .01845 Mdot
.61052 .54207 Mdot
.73343 .39532 Mdot
.09378 .47732 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00191 Mdot
.49549 .0061 Mdot
.48562 .01941 Mdot
.45423 .06126 Mdot
.35511 .17778 Mdot
.06745 .23846 Mdot
.68162 .10432 Mdot
.51283 .09244 Mdot
.36325 .20419 Mdot
.03287 .23444 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49622 .00511 Mdot
.48794 .01628 Mdot
.4616 .05154 Mdot
.3782 .15375 Mdot
.12943 .26094 Mdot
.70722 .1187 Mdot
.51516 .10466 Mdot
.34581 .22627 Mdot
.9797 .2075 Mdot
.64396 .09151 Mdot
.50005 .61796 Mdot
.50017 .61781 Mdot
.50053 .61731 Mdot
.5017 .61574 Mdot
.50542 .61071 Mdot
.51726 .59475 Mdot
.55494 .54482 Mdot
.67341 .41403 Mdot
.0035 .41727 Mdot
.32834 .5473 Mdot
.44279 .5992 Mdot
.50043 .61745 Mdot
.50137 .61619 Mdot
.50435 .61216 Mdot
.51386 .59932 Mdot
.54414 .55892 Mdot
.63979 .44536 Mdot
.91918 .37361 Mdot
.31466 .50915 Mdot
.49083 .51764 Mdot
.65327 .39652 Mdot
.01169 .40735 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00257 Mdot
.49393 .0082 Mdot
.48066 .02608 Mdot
.43846 .08173 Mdot
.30622 .22016 Mdot
.94998 .17456 Mdot
.66755 .04637 Mdot
.59251 .58339 Mdot
.64857 .46481 Mdot
.89649 .37547 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01185 Mdot
.47205 .03763 Mdot
.41117 .11577 Mdot
.22385 .26133 Mdot
.80101 .1213 Mdot
.60475 .03105 Mdot
.55452 .59952 Mdot
.58447 .52485 Mdot
.50017 .61781 Mdot
.50053 .61732 Mdot
.50168 .61576 Mdot
.50536 .61079 Mdot
.51709 .59498 Mdot
.55439 .54553 Mdot
.6717 .41548 Mdot
.99944 .41496 Mdot
.32802 .54513 Mdot
.44597 .59426 Mdot
.48444 .60867 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61239 Mdot
.51332 .60005 Mdot
.54242 .56119 Mdot
.63439 .45089 Mdot
.90482 .36783 Mdot
.30967 .50512 Mdot
.49236 .51221 Mdot
.66359 .38588 Mdot
.03923 .42188 Mdot
.50045 .61743 Mdot
.50143 .61611 Mdot
.50455 .61189 Mdot
.51449 .59847 Mdot
.54614 .55629 Mdot
.64604 .43912 Mdot
.93552 .38097 Mdot
.3191 .51483 Mdot
.48609 .52771 Mdot
.63225 .41873 Mdot
.95472 .37732 Mdot
.50092 .61679 Mdot
.50294 .61407 Mdot
.50935 .6054 Mdot
.52979 .57794 Mdot
.59466 .49528 Mdot
.79328 .35315 Mdot
.22187 .4984 Mdot
.41544 .57315 Mdot
.48806 .58421 Mdot
.54279 .54502 Mdot
.66092 .41999 Mdot
.50048 .61738 Mdot
.50154 .61596 Mdot
.50489 .61143 Mdot
.51558 .597 Mdot
.54961 .55175 Mdot
.65687 .42875 Mdot
.96313 .39488 Mdot
.3242 .52667 Mdot
.47203 .55247 Mdot
.57812 .48292 Mdot
.79673 .34169 Mdot
.50058 .61725 Mdot
.50184 .61555 Mdot
.50586 .61011 Mdot
.51868 .59284 Mdot
.55944 .53901 Mdot
.6873 .40277 Mdot
.0356 .4355 Mdot
.33095 .56437 Mdot
.41778 .01922 Mdot
.38668 .11561 Mdot
.19962 .25583 Mdot
.50024 .61771 Mdot
.50075 .61702 Mdot
.5024 .61479 Mdot
.50764 .60771 Mdot
.52434 .58524 Mdot
.57739 .51629 Mdot
.74202 .36893 Mdot
.14508 .48556 Mdot
.35943 .59958 Mdot
.38929 .0761 Mdot
.26616 .22288 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49605 .00534 Mdot
.4874 .01701 Mdot
.45988 .05381 Mdot
.37282 .15956 Mdot
.11465 .25689 Mdot
.699 .11685 Mdot
.50993 .10766 Mdot
.33573 .23431 Mdot
.95661 .19458 Mdot
.64177 .07986 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00263 Mdot
.49379 .00839 Mdot
.48022 .02667 Mdot
.43707 .0835 Mdot
.30196 .22326 Mdot
.94072 .16956 Mdot
.66636 .04193 Mdot
.59852 .57435 Mdot
.6692 .44541 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50433 .61218 Mdot
.51381 .5994 Mdot
.54396 .55916 Mdot
.63923 .44593 Mdot
.91771 .37299 Mdot
.31419 .50869 Mdot
.49111 .51693 Mdot
.6547 .39506 Mdot
.01548 .40938 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48888 .01502 Mdot
.46457 .04759 Mdot
.38756 .14337 Mdot
.15558 .26571 Mdot
.72566 .11988 Mdot
.53169 .0907 Mdot
.38493 .18833 Mdot
.08021 .25958 Mdot
.66021 .1349 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51082 .60342 Mdot
.53448 .5717 Mdot
.60944 .47805 Mdot
.83593 .3515 Mdot
.26719 .49818 Mdot
.46112 .53387 Mdot
.59729 .44919 Mdot
.87049 .34195 Mdot
.31721 .47653 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49704 .004 Mdot
.49057 .01274 Mdot
.46996 .04042 Mdot
.40455 .1237 Mdot
.20439 .26523 Mdot
.77524 .11954 Mdot
.58182 .04698 Mdot
.5058 .0416 Mdot
.43849 .09722 Mdot
.28118 .24194 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.49192 .01091 Mdot
.47427 .03466 Mdot
.41818 .10722 Mdot
.2447 .25468 Mdot
.83261 .12657 Mdot
.62782 .02041 Mdot
.59479 .55567 Mdot
.69569 .41663 Mdot
.02156 .43656 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49271 .00985 Mdot
.47678 .0313 Mdot
.42614 .09733 Mdot
.26865 .24387 Mdot
.87407 .13893 Mdot
.64928 .01996 Mdot
.61699 .53904 Mdot
.7448 .39158 Mdot
.11122 .48649 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51226 .60148 Mdot
.53904 .56565 Mdot
.6238 .46211 Mdot
.87609 .3585 Mdot
.29603 .49991 Mdot
.48715 .51181 Mdot
.65902 .38773 Mdot
.03167 .41689 Mdot
.35713 .53225 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49158 .01137 Mdot
.47318 .03612 Mdot
.41474 .11143 Mdot
.23444 .25827 Mdot
.81654 .12344 Mdot
.61682 .02461 Mdot
.577 .57401 Mdot
.64824 .4556 Mdot
.91106 .37738 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51302 .60045 Mdot
.54147 .56244 Mdot
.63141 .454 Mdot
.89683 .36491 Mdot
.30639 .50329 Mdot
.49205 .51066 Mdot
.66577 .3833 Mdot
.04557 .42498 Mdot
.35795 .53987 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51068 .60362 Mdot
.53401 .57233 Mdot
.60796 .47975 Mdot
.83171 .35122 Mdot
.26342 .49824 Mdot
.45724 .53741 Mdot
.5877 .46015 Mdot
.84316 .33717 Mdot
.2976 .47817 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60336 Mdot
.5346 .57154 Mdot
.60984 .4776 Mdot
.83706 .35159 Mdot
.26818 .49817 Mdot
.46212 .53296 Mdot
.59978 .4464 Mdot
.8775 .34372 Mdot
.32135 .47668 Mdot
.50044 .61743 Mdot
.50141 .61613 Mdot
.5045 .61195 Mdot
.51434 .59868 Mdot
.54566 .55693 Mdot
.64453 .44062 Mdot
.93159 .37913 Mdot
.31814 .51336 Mdot
.4875 .52493 Mdot
.63814 .41235 Mdot
.97094 .38556 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48476 .02057 Mdot
.45149 .06485 Mdot
.34656 .18606 Mdot
.04551 .22768 Mdot
.67712 .09533 Mdot
.52287 .0742 Mdot
.40281 .15881 Mdot
.14584 .27587 Mdot
.50032 .6176 Mdot
.50103 .61664 Mdot
.50329 .61358 Mdot
.51049 .60386 Mdot
.53342 .5731 Mdot
.60612 .48185 Mdot
.82646 .35101 Mdot
.25851 .49835 Mdot
.45217 .54202 Mdot
.57516 .4749 Mdot
.80675 .33664 Mdot
.50002 .61801 Mdot
.50005 .61796 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61084 Mdot
.51696 .59515 Mdot
.55399 .54605 Mdot
.67045 .41656 Mdot
.99645 .41327 Mdot
.32777 .54354 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48936 .01436 Mdot
.46612 .04553 Mdot
.39245 .13782 Mdot
.16945 .26687 Mdot
.73765 .11977 Mdot
.54386 .07962 Mdot
.41503 .15471 Mdot
.1647 .28157 Mdot
.70912 .13886 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50449 .61197 Mdot
.51431 .59872 Mdot
.54555 .55707 Mdot
.6442 .44094 Mdot
.93074 .37874 Mdot
.31792 .51305 Mdot
.48779 .52436 Mdot
.63935 .41106 Mdot
.97423 .38728 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.5122 .60156 Mdot
.53885 .5659 Mdot
.6232 .46276 Mdot
.87443 .35806 Mdot
.29507 .49973 Mdot
.4865 .51223 Mdot
.6577 .38881 Mdot
.0286 .41517 Mdot
.35683 .53071 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50427 .61227 Mdot
.51359 .59969 Mdot
.54328 .56006 Mdot
.63708 .44812 Mdot
.912 .37063 Mdot
.3123 .50702 Mdot
.49192 .5145 Mdot
.65944 .39021 Mdot
.02807 .41609 Mdot
.49994 9e-05 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.49339 .00893 Mdot
.47895 .02839 Mdot
.43302 .08866 Mdot
.28956 .23167 Mdot
.91471 .15633 Mdot
.66176 .03089 Mdot
.61177 .55362 Mdot
.716 .40943 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51208 .60172 Mdot
.53848 .5664 Mdot
.62203 .46403 Mdot
.87121 .35725 Mdot
.29317 .4994 Mdot
.48513 .51316 Mdot
.65481 .39123 Mdot
.02179 .41137 Mdot
.35618 .52728 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48836 .01571 Mdot
.46294 .04976 Mdot
.38242 .14912 Mdot
.14114 .26348 Mdot
.71483 .11952 Mdot
.52145 .09969 Mdot
.36014 .2133 Mdot
.01502 .2272 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60336 Mdot
.5346 .57154 Mdot
.60984 .47761 Mdot
.83705 .35159 Mdot
.26817 .49817 Mdot
.46211 .53296 Mdot
.59976 .44642 Mdot
.87744 .3437 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54244 .56116 Mdot
.63446 .45082 Mdot
.90503 .3679 Mdot
.30974 .50517 Mdot
.49236 .51226 Mdot
.6635 .38597 Mdot
.03899 .42175 Mdot
.35657 .53744 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.49429 .00771 Mdot
.48182 .02452 Mdot
.44215 .07698 Mdot
.3176 .21141 Mdot
.97552 .18881 Mdot
.67002 .05951 Mdot
.57374 .6116 Mdot
.58414 .53718 Mdot
.71496 .3932 Mdot
.49982 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49402 .00808 Mdot
.48094 .02571 Mdot
.43934 .08059 Mdot
.30895 .21813 Mdot
.956 .17786 Mdot
.66822 .04937 Mdot
.58834 .58965 Mdot
.63426 .47943 Mdot
.85853 .36488 Mdot
.50059 .61723 Mdot
.5019 .61547 Mdot
.50604 .60988 Mdot
.51924 .59208 Mdot
.56123 .53672 Mdot
.6928 .3986 Mdot
.04786 .4423 Mdot
.3322 .5706 Mdot
.40896 .03243 Mdot
.35648 .14817 Mdot
.11674 .24695 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.50931 .60547 Mdot
.52964 .57814 Mdot
.59419 .49584 Mdot
.79191 .35338 Mdot
.22013 .49833 Mdot
.41382 .57438 Mdot
.48446 .58877 Mdot
.53181 .55947 Mdot
.62657 .45411 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49652 .0047 Mdot
.48892 .01496 Mdot
.46471 .04741 Mdot
.388 .14289 Mdot
.1568 .26585 Mdot
.72665 .11989 Mdot
.53267 .08981 Mdot
.38735 .18574 Mdot
.08681 .26229 Mdot
.66242 .13653 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49619 .00515 Mdot
.48785 .0164 Mdot
.46131 .05191 Mdot
.37732 .15471 Mdot
.12699 .26034 Mdot
.70576 .11846 Mdot
.51409 .10542 Mdot
.34352 .22821 Mdot
.97426 .20446 Mdot
.64344 .08876 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50723 .60826 Mdot
.52304 .58698 Mdot
.57329 .52141 Mdot
.72964 .37507 Mdot
.12277 .47793 Mdot
.34947 .59758 Mdot
.38257 .0788 Mdot
.25507 .22627 Mdot
.88897 .13148 Mdot
.50042 .61747 Mdot
.50134 .61622 Mdot
.50427 .61226 Mdot
.51361 .59966 Mdot
.54334 .55998 Mdot
.63728 .44792 Mdot
.91253 .37085 Mdot
.31248 .50717 Mdot
.49186 .51471 Mdot
.65905 .39061 Mdot
.02703 .41555 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01438 Mdot
.46608 .04559 Mdot
.39232 .13797 Mdot
.16909 .26685 Mdot
.73731 .11978 Mdot
.54351 .07994 Mdot
.41418 .1557 Mdot
.16225 .28138 Mdot
.70697 .1392 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49063 .01266 Mdot
.47015 .04017 Mdot
.40516 .12297 Mdot
.20619 .26496 Mdot
.77747 .11961 Mdot
.58394 .04536 Mdot
.51055 .03558 Mdot
.45297 .07855 Mdot
.32588 .20964 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50982 .60477 Mdot
.53129 .57595 Mdot
.59938 .4897 Mdot
.80703 .35152 Mdot
.23826 .49867 Mdot
.4314 .56031 Mdot
.52479 .53742 Mdot
.65522 .41527 Mdot
.9833 .39982 Mdot
.5013 .61627 Mdot
.50415 .61243 Mdot
.51322 .60018 Mdot
.54211 .56159 Mdot
.63344 .45188 Mdot
.90227 .36687 Mdot
.30866 .50451 Mdot
.49235 .5116 Mdot
.66457 .3848 Mdot
.04195 .42324 Mdot
.35713 .5386 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50759 .60779 Mdot
.52417 .58546 Mdot
.57687 .51694 Mdot
.74044 .36966 Mdot
.14232 .48471 Mdot
.35805 .59953 Mdot
.38799 .07698 Mdot
.26343 .224 Mdot
.90099 .13802 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.50252 .61464 Mdot
.50801 .60721 Mdot
.52553 .58365 Mdot
.58116 .51162 Mdot
.75334 .36411 Mdot
.16419 .49073 Mdot
.37018 .59817 Mdot
.40232 .06511 Mdot
.49988 .00016 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.48791 .01633 Mdot
.46148 .05169 Mdot
.37784 .15414 Mdot
.12844 .2607 Mdot
.70662 .1186 Mdot
.51471 .10498 Mdot
.34485 .22709 Mdot
.97741 .20622 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51041 .60398 Mdot
.53315 .57347 Mdot
.60526 .48285 Mdot
.82399 .35096 Mdot
.25611 .4984 Mdot
.44969 .54427 Mdot
.56904 .48226 Mdot
.78873 .33906 Mdot
.24012 .48632 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39526 .13459 Mdot
.17748 .26708 Mdot
.74533 .1196 Mdot
.55181 .07242 Mdot
.43464 .13132 Mdot
.22216 .27661 Mdot
.77459 .13083 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50204 .61527 Mdot
.50651 .60924 Mdot
.52075 .59005 Mdot
.56602 .53059 Mdot
.70751 .38827 Mdot
.07927 .45876 Mdot
.33698 .58481 Mdot
.39074 .0603 Mdot
.29317 .20245 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61075 Mdot
.51718 .59485 Mdot
.55468 .54515 Mdot
.67261 .41471 Mdot
.0016 .41619 Mdot
.32819 .54629 Mdot
.44428 .5969 Mdot
.47848 .61679 Mdot
.48049 .0168 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49013 .01333 Mdot
.46857 .04228 Mdot
.40016 .12889 Mdot
.19162 .26661 Mdot
.76023 .11937 Mdot
.56708 .05902 Mdot
.47159 .08522 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00381 Mdot
.49101 .01214 Mdot
.47138 .03853 Mdot
.40904 .11833 Mdot
.21758 .26283 Mdot
.79232 .12047 Mdot
.5974 .0357 Mdot
.53963 .61737 Mdot
.54071 .58005 Mdot
.60217 .4917 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00329 Mdot
.49224 .01048 Mdot
.47529 .03329 Mdot
.42142 .10322 Mdot
.2544 .25071 Mdot
.84875 .13066 Mdot
.63733 .01857 Mdot
.60728 .54452 Mdot
.72623 .39861 Mdot
.08126 .47072 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48853 .01549 Mdot
.46347 .04906 Mdot
.38408 .14727 Mdot
.14579 .2643 Mdot
.71814 .1197 Mdot
.52445 .09713 Mdot
.3673 .20638 Mdot
.03337 .23709 Mdot
.64975 .11786 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.4973 .00364 Mdot
.49141 .01161 Mdot
.47263 .03685 Mdot
.413 .11355 Mdot
.22926 .25985 Mdot
.80882 .12227 Mdot
.61099 .02751 Mdot
.56648 .58569 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51017 .60429 Mdot
.5324 .57446 Mdot
.60291 .48557 Mdot
.81724 .351 Mdot
.24931 .49854 Mdot
.44266 .55056 Mdot
.55183 .50335 Mdot
.73739 .35627 Mdot
.16092 .48131 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51168 .60226 Mdot
.5372 .56809 Mdot
.618 .46845 Mdot
.86002 .35478 Mdot
.28597 .49857 Mdot
.47926 .51775 Mdot
.64153 .40316 Mdot
.9892 .39316 Mdot
.35306 .51084 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49594 .00548 Mdot
.48708 .01745 Mdot
.45884 .05518 Mdot
.36956 .16301 Mdot
.10581 .25403 Mdot
.69478 .11528 Mdot
.50825 .10764 Mdot
.33409 .23507 Mdot
.95374 .19278 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.5033 .61357 Mdot
.51052 .60383 Mdot
.5335 .573 Mdot
.60636 .48158 Mdot
.82716 .35103 Mdot
.25918 .49833 Mdot
.45286 .5414 Mdot
.57686 .47289 Mdot
.81171 .33629 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.5078 .6075 Mdot
.52485 .58455 Mdot
.57902 .51427 Mdot
.74692 .36675 Mdot
.1535 .488 Mdot
.36391 .59934 Mdot
.39415 .07236 Mdot
.27708 .21777 Mdot
.92472 .15055 Mdot
.50102 .61665 Mdot
.50326 .61364 Mdot
.51037 .60403 Mdot
.53304 .57362 Mdot
.60491 .48325 Mdot
.82298 .35095 Mdot
.25513 .49842 Mdot
.44867 .54519 Mdot
.56653 .48529 Mdot
.78131 .34059 Mdot
.23022 .487 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61511 Mdot
.5069 .60872 Mdot
.52197 .58842 Mdot
.56989 .52569 Mdot
.71931 .38088 Mdot
.10303 .46986 Mdot
.34278 .59304 Mdot
.38322 .07381 Mdot
.2638 .2208 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60118 Mdot
.53975 .56471 Mdot
.62603 .4597 Mdot
.88222 .36021 Mdot
.29938 .50071 Mdot
.48922 .5107 Mdot
.6629 .3847 Mdot
.04043 .42178 Mdot
.35797 .53666 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.505 .61128 Mdot
.51592 .59655 Mdot
.55067 .55037 Mdot
.66016 .42571 Mdot
.97135 .3993 Mdot
.32528 .53064 Mdot
.46669 .5613 Mdot
.55849 .50829 Mdot
.73607 .36131 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50629 .60954 Mdot
.52004 .59101 Mdot
.56377 .53346 Mdot
.7006 .39297 Mdot
.06477 .45137 Mdot
.33444 .57863 Mdot
.3982 .04866 Mdot
.31946 .18238 Mdot
.02436 .20488 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.5058 .6102 Mdot
.51847 .59312 Mdot
.55877 .53987 Mdot
.68524 .40437 Mdot
.03095 .43288 Mdot
.33053 .56194 Mdot
.42129 .01394 Mdot
.39873 .10161 Mdot
.23432 .24844 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51271 .60087 Mdot
.54048 .56375 Mdot
.62832 .45727 Mdot
.88845 .36211 Mdot
.30254 .50169 Mdot
.49078 .51023 Mdot
.66522 .38313 Mdot
.0453 .42456 Mdot
.35835 .53922 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60337 Mdot
.5346 .57155 Mdot
.60982 .47763 Mdot
.837 .35158 Mdot
.26813 .49817 Mdot
.46207 .53301 Mdot
.59964 .44655 Mdot
.87712 .34361 Mdot
.32114 .47666 Mdot
.49975 .00033 Mdot
.49922 .00106 Mdot
.4975 .00337 Mdot
.49205 .01074 Mdot
.47466 .03413 Mdot
.41944 .10567 Mdot
.24847 .2532 Mdot
.83878 .12802 Mdot
.63163 .01944 Mdot
.60018 .55062 Mdot
.70926 .40788 Mdot
.0493 .45285 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.4877 .01661 Mdot
.46082 .05257 Mdot
.37575 .15641 Mdot
.12268 .25921 Mdot
.70328 .11797 Mdot
.51239 .1065 Mdot
.34008 .23104 Mdot
.96625 .19998 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01506 Mdot
.46449 .0477 Mdot
.38731 .14366 Mdot
.15485 .26562 Mdot
.72507 .11988 Mdot
.53111 .09122 Mdot
.3835 .18984 Mdot
.07634 .25793 Mdot
.65901 .13384 Mdot
.50076 .617 Mdot
.50244 .61474 Mdot
.50777 .60754 Mdot
.52474 .5847 Mdot
.57867 .51471 Mdot
.74585 .36722 Mdot
.15168 .48749 Mdot
.3629 .59944 Mdot
.39299 .07331 Mdot
.27437 .21913 Mdot
.91982 .1479 Mdot
.50034 .61757 Mdot
.50108 .61657 Mdot
.50346 .61336 Mdot
.51101 .60316 Mdot
.53507 .57091 Mdot
.61132 .47592 Mdot
.84127 .35198 Mdot
.27176 .49815 Mdot
.46574 .52966 Mdot
.60872 .43653 Mdot
.90241 .35162 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51338 .59997 Mdot
.54261 .56094 Mdot
.63499 .45027 Mdot
.90644 .36844 Mdot
.31028 .50553 Mdot
.49232 .51265 Mdot
.66283 .38668 Mdot
.03717 .42083 Mdot
.50032 .6176 Mdot
.50103 .61664 Mdot
.50328 .61361 Mdot
.51044 .60394 Mdot
.53325 .57334 Mdot
.60557 .48249 Mdot
.82488 .35098 Mdot
.25699 .49838 Mdot
.45059 .54345 Mdot
.57127 .47956 Mdot
.79533 .33796 Mdot
.50032 .6176 Mdot
.50103 .61664 Mdot
.5033 .61358 Mdot
.5105 .60385 Mdot
.53345 .57306 Mdot
.60622 .48174 Mdot
.82674 .35102 Mdot
.25878 .49834 Mdot
.45244 .54178 Mdot
.57583 .4741 Mdot
.80872 .33649 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49776 .00303 Mdot
.49286 .00964 Mdot
.47726 .03065 Mdot
.42767 .09542 Mdot
.27327 .24139 Mdot
.88269 .14222 Mdot
.65257 .02147 Mdot
.61782 .53999 Mdot
.74411 .39254 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60849 Mdot
.52251 .58769 Mdot
.5716 .52354 Mdot
.7245 .37788 Mdot
.11308 .47411 Mdot
.34595 .59564 Mdot
.38218 .07712 Mdot
.25739 .22451 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49067 .0126 Mdot
.47028 .04 Mdot
.40556 .1225 Mdot
.20736 .26478 Mdot
.77894 .11967 Mdot
.58532 .04431 Mdot
.51363 .03169 Mdot
.46236 .06626 Mdot
.35515 .18275 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50658 .60915 Mdot
.52095 .58978 Mdot
.56666 .52977 Mdot
.70947 .38699 Mdot
.08331 .46074 Mdot
.33782 .58639 Mdot
.38901 .06311 Mdot
.28689 .20671 Mdot
.95243 .16326 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49852 .002 Mdot
.49527 .00639 Mdot
.48494 .02033 Mdot
.45204 .06412 Mdot
.34829 .18441 Mdot
.04991 .22992 Mdot
.67788 .09727 Mdot
.5205 .07832 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49775 .00304 Mdot
.49282 .0097 Mdot
.47713 .03083 Mdot
.42724 .09596 Mdot
.27198 .2421 Mdot
.88026 .14127 Mdot
.65168 .021 Mdot
.61771 .53959 Mdot
.74463 .39213 Mdot
.11015 .48628 Mdot
.50008 .61792 Mdot
.50026 .61769 Mdot
.50082 .61692 Mdot
.50262 .6145 Mdot
.50834 .60677 Mdot
.52657 .58225 Mdot
.58446 .50758 Mdot
.76318 .36054 Mdot
.17982 .49397 Mdot
.38056 .59459 Mdot
.41849 .04886 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51223 .60152 Mdot
.53895 .56578 Mdot
.6235 .46243 Mdot
.87527 .35828 Mdot
.29556 .49982 Mdot
.48684 .51201 Mdot
.65839 .38824 Mdot
.0302 .41607 Mdot
.35698 .53151 Mdot
.50026 .61769 Mdot
.50082 .61692 Mdot
.50262 .6145 Mdot
.50833 .60678 Mdot
.52654 .58229 Mdot
.58438 .50767 Mdot
.76295 .36062 Mdot
.17945 .4939 Mdot
.3803 .5947 Mdot
.41805 .04933 Mdot
.33824 .17477 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.54169 .56215 Mdot
.63212 .45325 Mdot
.89874 .36559 Mdot
.30721 .5037 Mdot
.4922 .51093 Mdot
.66549 .38371 Mdot
.04464 .42455 Mdot
.50018 .6178 Mdot
.50056 .61727 Mdot
.50179 .61561 Mdot
.50571 .61032 Mdot
.51819 .59349 Mdot
.5579 .54099 Mdot
.68257 .40649 Mdot
.02485 .42943 Mdot
.33001 .55872 Mdot
.42598 .00687 Mdot
.41486 .08208 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00264 Mdot
.49378 .0084 Mdot
.48018 .02673 Mdot
.43694 .08367 Mdot
.30156 .22354 Mdot
.93987 .16911 Mdot
.66624 .04153 Mdot
.59904 .57356 Mdot
.671 .44382 Mdot
.95288 .40078 Mdot
.50096 .61673 Mdot
.50307 .61389 Mdot
.50978 .60483 Mdot
.53115 .57614 Mdot
.59894 .49021 Mdot
.80577 .35163 Mdot
.23683 .49867 Mdot
.42996 .56152 Mdot
.52141 .54173 Mdot
.64487 .42522 Mdot
.95684 .3857 Mdot
.50116 .61647 Mdot
.50369 .61304 Mdot
.51177 .60215 Mdot
.53748 .56772 Mdot
.61888 .46748 Mdot
.86248 .35528 Mdot
.28763 .49871 Mdot
.4807 .51657 Mdot
.64487 .40006 Mdot
.99757 .3978 Mdot
.35391 .515 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50253 .61461 Mdot
.50807 .60713 Mdot
.52572 .58339 Mdot
.58178 .51087 Mdot
.75518 .3634 Mdot
.16718 .49142 Mdot
.37205 .59766 Mdot
.40502 .06254 Mdot
.30382 .20173 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .01561 Mdot
.46318 .04944 Mdot
.38318 .14827 Mdot
.14327 .26387 Mdot
.71632 .11961 Mdot
.52279 .09856 Mdot
.36331 .21026 Mdot
.0231 .2316 Mdot
.50042 .61746 Mdot
.50134 .61622 Mdot
.50428 .61225 Mdot
.51363 .59963 Mdot
.54341 .55989 Mdot
.63749 .4477 Mdot
.91309 .37108 Mdot
.31267 .50733 Mdot
.4918 .51493 Mdot
.65863 .39104 Mdot
.02592 .41496 Mdot
.50021 .61774 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50693 .60867 Mdot
.52208 .58827 Mdot
.57024 .52524 Mdot
.72039 .38024 Mdot
.10514 .47078 Mdot
.34341 .59363 Mdot
.38289 .07463 Mdot
.26213 .22175 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50023 .61772 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.52369 .58611 Mdot
.57534 .51885 Mdot
.73581 .37189 Mdot
.13408 .482 Mdot
.35418 .59905 Mdot
.5002 .61776 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50656 .60917 Mdot
.52091 .58984 Mdot
.56652 .52995 Mdot
.70904 .38726 Mdot
.08244 .46032 Mdot
.33763 .58606 Mdot
.38937 .06252 Mdot
.28821 .20583 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00536 Mdot
.48737 .01705 Mdot
.45977 .05395 Mdot
.37248 .15992 Mdot
.11373 .2566 Mdot
.69854 .11671 Mdot
.5097 .10772 Mdot
.33541 .23452 Mdot
.95594 .1942 Mdot
.64172 .0795 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.5364 .56915 Mdot
.6155 .47123 Mdot
.85303 .35354 Mdot
.281 .49829 Mdot
.47474 .52161 Mdot
.63075 .41358 Mdot
.96157 .3783 Mdot
.34947 .49795 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51041 .60398 Mdot
.53315 .57347 Mdot
.60525 .48286 Mdot
.82397 .35096 Mdot
.2561 .4984 Mdot
.44968 .54428 Mdot
.56901 .48229 Mdot
.78865 .33907 Mdot
.24002 .48633 Mdot
.5012 .61641 Mdot
.50383 .61285 Mdot
.51222 .60154 Mdot
.53891 .56583 Mdot
.62338 .46257 Mdot
.87492 .35819 Mdot
.29536 .49978 Mdot
.4867 .5121 Mdot
.6581 .38847 Mdot
.02954 .4157 Mdot
.35692 .53119 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50976 .60486 Mdot
.53108 .57623 Mdot
.59872 .49047 Mdot
.80513 .35168 Mdot
.23609 .49867 Mdot
.42923 .56213 Mdot
.51969 .54393 Mdot
.6396 .43048 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .0018 Mdot
.49576 .00573 Mdot
.48649 .01824 Mdot
.45696 .05766 Mdot
.36367 .16914 Mdot
.09 .2482 Mdot
.68841 .11157 Mdot
.50789 .10425 Mdot
.3392 .22923 Mdot
.96831 .20004 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50628 .60954 Mdot
.52002 .59103 Mdot
.56371 .53353 Mdot
.70044 .39309 Mdot
.06441 .45118 Mdot
.33438 .57847 Mdot
.39841 .04835 Mdot
.32018 .18178 Mdot
.02605 .20582 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.49219 .01055 Mdot
.47511 .03353 Mdot
.42085 .10392 Mdot
.2527 .25145 Mdot
.84585 .12986 Mdot
.63573 .01874 Mdot
.60541 .54604 Mdot
.7219 .40079 Mdot
.07342 .46646 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49007 .0134 Mdot
.46838 .04252 Mdot
.39958 .12956 Mdot
.18996 .26673 Mdot
.75838 .11939 Mdot
.56521 .06061 Mdot
.46715 .09084 Mdot
.32016 .22428 Mdot
.95726 .18514 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .0142 Mdot
.46651 .04502 Mdot
.39366 .13643 Mdot
.17291 .267 Mdot
.74089 .1197 Mdot
.54721 .07657 Mdot
.42331 .14495 Mdot
.18879 .28171 Mdot
.73297 .13501 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47454 .03429 Mdot
.41906 .10613 Mdot
.24733 .25366 Mdot
.83691 .12757 Mdot
.6305 .0197 Mdot
.59862 .55204 Mdot
.7054 .41025 Mdot
.04159 .44838 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .00279 Mdot
.49341 .0089 Mdot
.47901 .02831 Mdot
.43321 .08842 Mdot
.29014 .2313 Mdot
.91588 .1569 Mdot
.66201 .03133 Mdot
.61131 .55438 Mdot
.7143 .41054 Mdot
.05004 .45616 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50927 .60552 Mdot
.52952 .57831 Mdot
.5938 .4963 Mdot
.79077 .35357 Mdot
.21868 .49827 Mdot
.41247 .57538 Mdot
.48148 .59252 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48811 .01606 Mdot
.46213 .05083 Mdot
.37988 .15191 Mdot
.13408 .26202 Mdot
.71012 .11909 Mdot
.51743 .10296 Mdot
.35084 .22186 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60224 Mdot
.53725 .56803 Mdot
.61816 .46827 Mdot
.86048 .35487 Mdot
.28628 .4986 Mdot
.47953 .51752 Mdot
.64216 .40257 Mdot
.99079 .39404 Mdot
.50129 .61629 Mdot
.50411 .61249 Mdot
.51308 .60037 Mdot
.54167 .56218 Mdot
.63203 .45334 Mdot
.89851 .3655 Mdot
.30711 .50365 Mdot
.49218 .5109 Mdot
.66553 .38365 Mdot
.04478 .42461 Mdot
.35774 .53962 Mdot
.50045 .61742 Mdot
.50144 .61609 Mdot
.50459 .61184 Mdot
.51462 .5983 Mdot
.54654 .55577 Mdot
.64728 .43791 Mdot
.93873 .3825 Mdot
.31983 .51607 Mdot
.48482 .53012 Mdot
.62706 .42445 Mdot
.94029 .37038 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51666 .59556 Mdot
.55303 .5473 Mdot
.66748 .41915 Mdot
.98928 .40922 Mdot
.32715 .53977 Mdot
.45379 .58201 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49613 .00522 Mdot
.48768 .01663 Mdot
.46077 .05263 Mdot
.37562 .15655 Mdot
.12232 .25911 Mdot
.70308 .11793 Mdot
.51226 .10657 Mdot
.33983 .23123 Mdot
.96568 .19967 Mdot
.64262 .08445 Mdot
.50032 .6176 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51038 .60401 Mdot
.53308 .57357 Mdot
.60503 .48312 Mdot
.82333 .35096 Mdot
.25547 .49841 Mdot
.44902 .54487 Mdot
.5674 .48424 Mdot
.78388 .34003 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49587 .00557 Mdot
.48686 .01775 Mdot
.45814 .0561 Mdot
.36737 .16532 Mdot
.09988 .25195 Mdot
.69222 .11402 Mdot
.50772 .10687 Mdot
.33481 .23396 Mdot
.95626 .19391 Mdot
.6425 .07877 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.51179 .60211 Mdot
.53756 .56761 Mdot
.61914 .46719 Mdot
.86321 .35543 Mdot
.28811 .49876 Mdot
.4811 .51624 Mdot
.64582 .39919 Mdot
.99991 .39911 Mdot
.35414 .51618 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.5092 .6056 Mdot
.52932 .57857 Mdot
.59317 .49705 Mdot
.78892 .3539 Mdot
.2163 .49815 Mdot
.41029 .57698 Mdot
.47671 .5985 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49615 .0052 Mdot
.48775 .01655 Mdot
.46098 .05236 Mdot
.37625 .15587 Mdot
.12405 .25958 Mdot
.70405 .11814 Mdot
.5129 .10619 Mdot
.34109 .23022 Mdot
.96859 .20129 Mdot
.6429 .08591 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51294 .60056 Mdot
.54121 .56279 Mdot
.6306 .45485 Mdot
.89464 .36416 Mdot
.30543 .50284 Mdot
.49181 .51043 Mdot
.66591 .38301 Mdot
.04619 .42523 Mdot
.35815 .54 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.48691 .01767 Mdot
.45832 .05587 Mdot
.36791 .16474 Mdot
.10135 .25248 Mdot
.69283 .11435 Mdot
.50781 .10712 Mdot
.33449 .23435 Mdot
.9553 .19346 Mdot
.64228 .07844 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50395 .61269 Mdot
.5126 .60103 Mdot
.54011 .56424 Mdot
.62716 .4585 Mdot
.88528 .36113 Mdot
.30097 .50117 Mdot
.49006 .51038 Mdot
.66424 .38374 Mdot
.04333 .42342 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.46491 .04714 Mdot
.38863 .14217 Mdot
.1586 .26604 Mdot
.72813 .11989 Mdot
.53415 .08847 Mdot
.39099 .18181 Mdot
.09682 .26613 Mdot
.66621 .13857 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00483 Mdot
.48861 .01538 Mdot
.46372 .04872 Mdot
.38489 .14638 Mdot
.14805 .26467 Mdot
.7198 .11977 Mdot
.52601 .09576 Mdot
.37106 .20264 Mdot
.04318 .24218 Mdot
.50045 .61742 Mdot
.50145 .61608 Mdot
.50461 .61181 Mdot
.51467 .59823 Mdot
.54672 .55553 Mdot
.64786 .43734 Mdot
.94022 .38322 Mdot
.32016 .51666 Mdot
.48419 .53129 Mdot
.62454 .42726 Mdot
.93322 .36716 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51112 .60301 Mdot
.53542 .57045 Mdot
.61242 .47468 Mdot
.84438 .35232 Mdot
.27431 .49815 Mdot
.46828 .52736 Mdot
.615 .42978 Mdot
.9196 .35838 Mdot
.33973 .48309 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .60419 Mdot
.53265 .57414 Mdot
.60367 .48468 Mdot
.81944 .35096 Mdot
.25157 .4985 Mdot
.44499 .54849 Mdot
.55751 .49632 Mdot
.75445 .34883 Mdot
.19002 .48603 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00301 Mdot
.4929 .0096 Mdot
.47737 .0305 Mdot
.42802 .09498 Mdot
.27433 .24081 Mdot
.8847 .14302 Mdot
.65328 .02189 Mdot
.61785 .54039 Mdot
.74349 .39297 Mdot
.10765 .48533 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50531 .61085 Mdot
.51693 .59519 Mdot
.55389 .54618 Mdot
.67016 .41681 Mdot
.99575 .41287 Mdot
.32771 .54317 Mdot
.44884 .58978 Mdot
.49456 .59483 Mdot
.50056 .61728 Mdot
.50178 .61563 Mdot
.50566 .61039 Mdot
.51803 .59371 Mdot
.55739 .54165 Mdot
.68098 .40776 Mdot
.02121 .42736 Mdot
.32972 .55679 Mdot
.42882 .00256 Mdot
.42467 .06982 Mdot
.3117 .20641 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61346 Mdot
.51079 .60347 Mdot
.53435 .57187 Mdot
.60906 .47849 Mdot
.83484 .35142 Mdot
.26623 .4982 Mdot
.46013 .53477 Mdot
.59484 .45196 Mdot
.86356 .34041 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61069 Mdot
.51732 .59466 Mdot
.55514 .54455 Mdot
.67404 .4135 Mdot
.00498 .41812 Mdot
.32846 .54809 Mdot
.44162 .60101 Mdot
.46917 .01138 Mdot
.45075 .05631 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49667 .0045 Mdot
.48939 .01433 Mdot
.46619 .04544 Mdot
.39267 .13757 Mdot
.17008 .2669 Mdot
.73823 .11976 Mdot
.54446 .07908 Mdot
.4165 .15298 Mdot
.16898 .28182 Mdot
.71299 .13824 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48854 .01548 Mdot
.46349 .04903 Mdot
.38415 .1472 Mdot
.14597 .26433 Mdot
.71827 .11971 Mdot
.52457 .09702 Mdot
.36759 .20609 Mdot
.03414 .23749 Mdot
.64987 .1182 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50375 .61296 Mdot
.51196 .60188 Mdot
.5381 .5669 Mdot
.62084 .46533 Mdot
.86791 .35646 Mdot
.29115 .4991 Mdot
.48358 .5143 Mdot
.65142 .39416 Mdot
.01365 .4068 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00534 Mdot
.4874 .01702 Mdot
.45986 .05383 Mdot
.37276 .15962 Mdot
.11449 .25684 Mdot
.69892 .11683 Mdot
.50989 .10767 Mdot
.33567 .23435 Mdot
.95649 .19451 Mdot
.64176 .07979 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50232 .61489 Mdot
.50741 .60803 Mdot
.52359 .58624 Mdot
.57503 .51923 Mdot
.73489 .37235 Mdot
.13241 .48143 Mdot
.35345 .59889 Mdot
.38443 .07882 Mdot
.25689 .22623 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00534 Mdot
.4874 .01701 Mdot
.45987 .05382 Mdot
.37278 .1596 Mdot
.11455 .25686 Mdot
.69895 .11684 Mdot
.5099 .10766 Mdot
.3357 .23433 Mdot
.95654 .19454 Mdot
.64177 .07982 Mdot
.4996 .00054 Mdot
.49872 .00172 Mdot
.49593 .00549 Mdot
.48704 .01749 Mdot
.45874 .05532 Mdot
.36922 .16337 Mdot
.10488 .25372 Mdot
.69436 .1151 Mdot
.50813 .10756 Mdot
.3341 .23498 Mdot
.9539 .19284 Mdot
.64189 .07805 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00548 Mdot
.48709 .01743 Mdot
.45888 .05513 Mdot
.36967 .16289 Mdot
.10611 .25413 Mdot
.69491 .11534 Mdot
.50829 .10766 Mdot
.33409 .23509 Mdot
.95371 .19278 Mdot
.64179 .07804 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50398 .61265 Mdot
.51269 .60089 Mdot
.54043 .56382 Mdot
.62815 .45744 Mdot
.88799 .36197 Mdot
.30232 .50161 Mdot
.49069 .51024 Mdot
.6651 .38319 Mdot
.04508 .42443 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49438 .0076 Mdot
.48208 .02417 Mdot
.44298 .07591 Mdot
.32015 .20935 Mdot
.98141 .19216 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60082 Mdot
.5406 .56359 Mdot
.62869 .45687 Mdot
.88947 .36244 Mdot
.30303 .50187 Mdot
.49099 .51022 Mdot
.66544 .38301 Mdot
.04572 .42481 Mdot
.35836 .53946 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.4876 .01674 Mdot
.46051 .05298 Mdot
.37479 .15744 Mdot
.12005 .25848 Mdot
.70183 .11764 Mdot
.51148 .107 Mdot
.33836 .23239 Mdot
.96235 .1978 Mdot
.64229 .08278 Mdot
.50036 .61755 Mdot
.50114 .6165 Mdot
.50362 .61314 Mdot
.51154 .60246 Mdot
.53674 .5687 Mdot
.61656 .47005 Mdot
.856 .35404 Mdot
.28315 .49839 Mdot
.47674 .51988 Mdot
.63555 .40887 Mdot
.97398 .38486 Mdot
.50093 .61678 Mdot
.50296 .61403 Mdot
.50945 .60528 Mdot
.53009 .57755 Mdot
.59559 .49416 Mdot
.79602 .35274 Mdot
.22527 .49851 Mdot
.41866 .57067 Mdot
.4953 .57503 Mdot
.56487 .51654 Mdot
.72909 .37027 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51031 .60411 Mdot
.53285 .57387 Mdot
.60431 .48395 Mdot
.82126 .35095 Mdot
.25342 .49846 Mdot
.44689 .54678 Mdot
.56218 .4906 Mdot
.76837 .34403 Mdot
.21171 .48733 Mdot
.50046 .61742 Mdot
.50145 .61607 Mdot
.50463 .61178 Mdot
.51475 .59813 Mdot
.54696 .55523 Mdot
.64858 .43664 Mdot
.94208 .38412 Mdot
.32056 .51741 Mdot
.48338 .53279 Mdot
.62131 .4309 Mdot
.92409 .36317 Mdot
.50123 .61637 Mdot
.50391 .61275 Mdot
.51247 .6012 Mdot
.53971 .56477 Mdot
.62589 .45986 Mdot
.88181 .36009 Mdot
.29917 .50065 Mdot
.4891 .51075 Mdot
.66269 .38486 Mdot
.03998 .42153 Mdot
.35793 .53643 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51178 .60213 Mdot
.53751 .56768 Mdot
.61898 .46737 Mdot
.86276 .35533 Mdot
.28782 .49873 Mdot
.48085 .51644 Mdot
.64523 .39972 Mdot
.99847 .3983 Mdot
.354 .51545 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00568 Mdot
.48661 .01808 Mdot
.45736 .05713 Mdot
.36492 .16786 Mdot
.09331 .24949 Mdot
.68962 .11244 Mdot
.50769 .10531 Mdot
.33729 .23122 Mdot
.96318 .19738 Mdot
.64381 .08148 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00233 Mdot
.49451 .00741 Mdot
.48252 .02358 Mdot
.44437 .07411 Mdot
.32446 .2058 Mdot
.99147 .19789 Mdot
.67127 .06804 Mdot
.56119 .0127 Mdot
.54064 .59347 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49735 .00358 Mdot
.49155 .01142 Mdot
.47307 .03627 Mdot
.41439 .11186 Mdot
.2334 .2586 Mdot
.81498 .12318 Mdot
.61567 .02515 Mdot
.57498 .57621 Mdot
.64264 .46098 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.4977 .00311 Mdot
.49266 .00991 Mdot
.47663 .0315 Mdot
.42567 .09793 Mdot
.26721 .24461 Mdot
.87142 .13796 Mdot
.64819 .01959 Mdot
.61649 .53902 Mdot
.74435 .39156 Mdot
.11078 .48617 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.46629 .04532 Mdot
.39297 .13723 Mdot
.17092 .26693 Mdot
.73901 .11974 Mdot
.54527 .07834 Mdot
.41852 .15062 Mdot
.17482 .282 Mdot
.50062 .6172 Mdot
.50198 .61536 Mdot
.50629 .60953 Mdot
.52005 .59099 Mdot
.56381 .53341 Mdot
.70074 .39287 Mdot
.06506 .45152 Mdot
.33449 .57876 Mdot
.39803 .04893 Mdot
.31886 .18287 Mdot
.02296 .20409 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00233 Mdot
.49451 .00742 Mdot
.4825 .02361 Mdot
.4443 .0742 Mdot
.32424 .20598 Mdot
.99096 .1976 Mdot
.67123 .06776 Mdot
.56159 .01208 Mdot
.54204 .5916 Mdot
.58481 .51664 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00395 Mdot
.49068 .01259 Mdot
.4703 .03997 Mdot
.40562 .12242 Mdot
.20754 .26475 Mdot
.77917 .11967 Mdot
.58553 .04414 Mdot
.5141 .03109 Mdot
.4638 .06435 Mdot
.35968 .17823 Mdot
.50063 .61719 Mdot
.502 .61533 Mdot
.50638 .60942 Mdot
.52032 .59064 Mdot
.56464 .53234 Mdot
.7033 .39111 Mdot
.07047 .45432 Mdot
.33536 .58115 Mdot
.39504 .05352 Mdot
.30844 .19123 Mdot
.99903 .19033 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61068 Mdot
.51735 .59463 Mdot
.55521 .54446 Mdot
.67425 .41332 Mdot
.00549 .41841 Mdot
.32849 .54837 Mdot
.44122 .60163 Mdot
.46775 .01329 Mdot
.44625 .06217 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50564 .61042 Mdot
.51796 .5938 Mdot
.55716 .54194 Mdot
.68028 .40833 Mdot
.01958 .42644 Mdot
.32959 .55592 Mdot
.43009 .00063 Mdot
.42907 .06423 Mdot
.32514 .19564 Mdot
.49969 .00043 Mdot
.499 .00135 Mdot
.49681 .00432 Mdot
.48982 .01374 Mdot
.46758 .04359 Mdot
.39706 .1325 Mdot
.18267 .26704 Mdot
.75059 .11949 Mdot
.55724 .06756 Mdot
.44793 .11498 Mdot
.26188 .26212 Mdot
.83777 .13644 Mdot
.50058 .61725 Mdot
.50185 .61554 Mdot
.50588 .61009 Mdot
.51874 .59276 Mdot
.55964 .53876 Mdot
.68791 .4023 Mdot
.03698 .43627 Mdot
.33108 .56508 Mdot
.41676 .02075 Mdot
.38319 .11957 Mdot
.18971 .25666 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.5049 .61141 Mdot
.51562 .59695 Mdot
.54974 .55158 Mdot
.65726 .42839 Mdot
.96411 .3954 Mdot
.32434 .52714 Mdot
.47141 .5535 Mdot
.57584 .48583 Mdot
.78975 .34286 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.4882 .01593 Mdot
.46242 .05045 Mdot
.38078 .15093 Mdot
.13658 .26256 Mdot
.71174 .11926 Mdot
.51878 .10189 Mdot
.35391 .2191 Mdot
.9994 .21854 Mdot
.64579 .10151 Mdot
.50033 .61759 Mdot
.50105 .61662 Mdot
.50333 .61353 Mdot
.51061 .6037 Mdot
.53381 .5726 Mdot
.60733 .48047 Mdot
.82991 .35114 Mdot
.26176 .49828 Mdot
.45553 .53897 Mdot
.58346 .4651 Mdot
.83092 .33621 Mdot
.50065 .61716 Mdot
.50207 .61524 Mdot
.50659 .60914 Mdot
.52098 .58974 Mdot
.56676 .52966 Mdot
.70976 .3868 Mdot
.0839 .46103 Mdot
.33794 .58662 Mdot
.38878 .0635 Mdot
.28603 .20728 Mdot
.95064 .16225 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51227 .60147 Mdot
.53907 .56562 Mdot
.62388 .46203 Mdot
.87631 .35855 Mdot
.29615 .49994 Mdot
.48723 .51176 Mdot
.65918 .38759 Mdot
.03204 .4171 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49803 .00266 Mdot
.49373 .00847 Mdot
.48003 .02694 Mdot
.43644 .08431 Mdot
.30002 .22463 Mdot
.93657 .16737 Mdot
.66576 .04001 Mdot
.60103 .57055 Mdot
.67786 .43791 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57436 .52007 Mdot
.73288 .37337 Mdot
.12875 .48013 Mdot
.35188 .59847 Mdot
.38354 .07902 Mdot
.25569 .22647 Mdot
.88926 .13189 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .6049 Mdot
.53098 .57636 Mdot
.59841 .49083 Mdot
.80424 .35177 Mdot
.23507 .49866 Mdot
.42821 .56298 Mdot
.51729 .54698 Mdot
.63225 .43801 Mdot
.92354 .36982 Mdot
.50125 .61635 Mdot
.50398 .61266 Mdot
.51267 .60092 Mdot
.54036 .5639 Mdot
.62795 .45765 Mdot
.88745 .3618 Mdot
.30205 .50152 Mdot
.49057 .51026 Mdot
.66496 .38328 Mdot
.04479 .42426 Mdot
.35832 .53893 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01347 Mdot
.46824 .04272 Mdot
.39912 .1301 Mdot
.18861 .26681 Mdot
.75691 .1194 Mdot
.56372 .0619 Mdot
.46357 .09537 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50902 .60586 Mdot
.52872 .57938 Mdot
.59126 .49933 Mdot
.78333 .35501 Mdot
.20891 .49766 Mdot
.40367 .58162 Mdot
.46259 .61598 Mdot
.46592 .0293 Mdot
.41851 .10159 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60498 Mdot
.53078 .57663 Mdot
.59778 .49158 Mdot
.80239 .35195 Mdot
.23292 .49865 Mdot
.42609 .56473 Mdot
.51233 .55332 Mdot
.61704 .45434 Mdot
.88191 .35463 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50957 .6051 Mdot
.5305 .577 Mdot
.59689 .49263 Mdot
.79979 .35225 Mdot
.22984 .49861 Mdot
.42307 .56718 Mdot
.50535 .56222 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48822 .01591 Mdot
.46248 .05038 Mdot
.38097 .15072 Mdot
.13709 .26267 Mdot
.71208 .11929 Mdot
.51906 .10166 Mdot
.35457 .21849 Mdot
.00104 .21946 Mdot
.64595 .10234 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50923 .60556 Mdot
.52941 .57845 Mdot
.59345 .49671 Mdot
.78975 .35375 Mdot
.21738 .4982 Mdot
.41127 .57627 Mdot
.47885 .59581 Mdot
.51481 .5821 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00202 Mdot
.49525 .00642 Mdot
.48485 .02044 Mdot
.45178 .06447 Mdot
.34747 .1852 Mdot
.04782 .22886 Mdot
.67751 .09636 Mdot
.52161 .07639 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.5081 .60709 Mdot
.52581 .58327 Mdot
.58207 .51051 Mdot
.75604 .36308 Mdot
.16857 .49172 Mdot
.37294 .5974 Mdot
.40633 .06127 Mdot
.30719 .19939 Mdot
.98457 .18511 Mdot
.50071 .61708 Mdot
.50225 .615 Mdot
.50716 .60836 Mdot
.52282 .58727 Mdot
.57259 .52229 Mdot
.72752 .37621 Mdot
.1188 .4764 Mdot
.34797 .59686 Mdot
.38224 .0783 Mdot
.25554 .22576 Mdot
.89026 .1319 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.4875 .01687 Mdot
.4602 .05338 Mdot
.37383 .15848 Mdot
.1174 .25771 Mdot
.70042 .11727 Mdot
.51067 .10739 Mdot
.33692 .23347 Mdot
.50065 .61715 Mdot
.50207 .61523 Mdot
.50661 .60911 Mdot
.52105 .58965 Mdot
.56699 .52936 Mdot
.71046 .38635 Mdot
.08534 .46172 Mdot
.33825 .58716 Mdot
.38821 .06444 Mdot
.28394 .20865 Mdot
.94634 .15984 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.4892 .01458 Mdot
.46562 .04621 Mdot
.39085 .13965 Mdot
.1649 .2666 Mdot
.73354 .11984 Mdot
.53963 .08348 Mdot
.40456 .16675 Mdot
.13475 .27727 Mdot
.68611 .14146 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00506 Mdot
.48807 .0161 Mdot
.46202 .05098 Mdot
.37952 .15231 Mdot
.13308 .2618 Mdot
.70948 .11901 Mdot
.51692 .10336 Mdot
.34969 .22289 Mdot
.98904 .21274 Mdot
.64482 .09626 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.49549 .00609 Mdot
.48564 .01939 Mdot
.45427 .0612 Mdot
.35525 .17764 Mdot
.06782 .23863 Mdot
.68171 .10446 Mdot
.5127 .0927 Mdot
.36271 .20476 Mdot
.0314 .23368 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .0054 Mdot
.48727 .01718 Mdot
.45947 .05435 Mdot
.37153 .16093 Mdot
.11115 .25579 Mdot
.69727 .11627 Mdot
.50913 .10781 Mdot
.33469 .23496 Mdot
.95452 .19337 Mdot
.64165 .07871 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49775 .00303 Mdot
.49284 .00967 Mdot
.4772 .03073 Mdot
.42749 .09564 Mdot
.27273 .24169 Mdot
.88168 .14182 Mdot
.6522 .02127 Mdot
.61778 .53981 Mdot
.74436 .39236 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54244 .56116 Mdot
.63446 .45082 Mdot
.90502 .3679 Mdot
.30974 .50517 Mdot
.49236 .51226 Mdot
.66351 .38597 Mdot
.03899 .42176 Mdot
.35657 .53744 Mdot
.50055 .61729 Mdot
.50176 .61565 Mdot
.50561 .61045 Mdot
.51789 .5939 Mdot
.55694 .54224 Mdot
.67958 .4089 Mdot
.01796 .42552 Mdot
.32946 .55505 Mdot
.43137 .61673 Mdot
.43348 .05858 Mdot
.3387 .1838 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49414 .00791 Mdot
.48133 .02518 Mdot
.44059 .07898 Mdot
.3128 .21519 Mdot
.96462 .18266 Mdot
.66907 .05378 Mdot
.58205 .59907 Mdot
.61274 .50308 Mdot
.79873 .3624 Mdot
.50072 .61705 Mdot
.50231 .61491 Mdot
.50736 .6081 Mdot
.52344 .58644 Mdot
.57455 .51983 Mdot
.73345 .37308 Mdot
.12979 .48051 Mdot
.35232 .5986 Mdot
.38377 .07899 Mdot
.25597 .22643 Mdot
.8896 .13209 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50184 .61555 Mdot
.50587 .61011 Mdot
.5187 .59281 Mdot
.5595 .53893 Mdot
.6875 .40262 Mdot
.03605 .43575 Mdot
.33099 .5646 Mdot
.41744 .01971 Mdot
.38555 .11691 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .6022 Mdot
.53735 .56788 Mdot
.6185 .4679 Mdot
.86142 .35506 Mdot
.28692 .49865 Mdot
.48009 .51706 Mdot
.64346 .40136 Mdot
.99404 .39584 Mdot
.35356 .51324 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.49321 .00917 Mdot
.47837 .02917 Mdot
.43117 .09101 Mdot
.28392 .23522 Mdot
.90333 .15101 Mdot
.659 .02693 Mdot
.61542 .5471 Mdot
.73019 .4007 Mdot
.5008 .61695 Mdot
.50255 .61458 Mdot
.50814 .60704 Mdot
.52592 .58312 Mdot
.58241 .51009 Mdot
.75706 .3627 Mdot
.1702 .49208 Mdot
.374 .59706 Mdot
.40793 .0597 Mdot
.31134 .19642 Mdot
.99352 .19042 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49666 .00451 Mdot
.48937 .01435 Mdot
.46614 .0455 Mdot
.39252 .13774 Mdot
.16964 .26688 Mdot
.73783 .11976 Mdot
.54404 .07945 Mdot
.41548 .15417 Mdot
.16603 .28165 Mdot
.7103 .13867 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00455 Mdot
.48926 .0145 Mdot
.46579 .04597 Mdot
.39141 .13901 Mdot
.16649 .2667 Mdot
.73495 .11982 Mdot
.54108 .08215 Mdot
.40815 .16265 Mdot
.14498 .27922 Mdot
.69319 .14098 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50529 .61089 Mdot
.51684 .59531 Mdot
.55361 .54655 Mdot
.66928 .41757 Mdot
.99363 .41167 Mdot
.32753 .54205 Mdot
.45048 .58723 Mdot
.50033 .58692 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49803 .00265 Mdot
.49374 .00846 Mdot
.48005 .0269 Mdot
.43653 .08419 Mdot
.30031 .22443 Mdot
.93718 .16769 Mdot
.66585 .04029 Mdot
.60067 .5711 Mdot
.67661 .43897 Mdot
.96634 .408 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.4877 .01661 Mdot
.46083 .05256 Mdot
.37579 .15637 Mdot
.12278 .25923 Mdot
.70333 .11798 Mdot
.51243 .10648 Mdot
.34014 .23098 Mdot
.96641 .20007 Mdot
.64269 .08481 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00805 Mdot
.48102 .0256 Mdot
.43961 .08025 Mdot
.30975 .21752 Mdot
.9578 .17886 Mdot
.66841 .05028 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .0048 Mdot
.48867 .01529 Mdot
.46393 .04845 Mdot
.38553 .14565 Mdot
.14986 .26494 Mdot
.72118 .11981 Mdot
.52732 .09461 Mdot
.37423 .19945 Mdot
.05151 .24637 Mdot
.65287 .12546 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.4971 .00391 Mdot
.49077 .01247 Mdot
.4706 .03957 Mdot
.40657 .12129 Mdot
.21032 .26427 Mdot
.78271 .11984 Mdot
.58882 .04171 Mdot
.52133 .02199 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49399 .00812 Mdot
.48085 .02583 Mdot
.43906 .08095 Mdot
.30807 .21878 Mdot
.95407 .1768 Mdot
.66801 .0484 Mdot
.5897 .58761 Mdot
.63892 .47457 Mdot
.87105 .36768 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48759 .01675 Mdot
.46049 .053 Mdot
.37473 .15751 Mdot
.11987 .25842 Mdot
.70173 .11761 Mdot
.51143 .10703 Mdot
.33825 .23247 Mdot
.9621 .19767 Mdot
.64227 .08265 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .0019 Mdot
.49552 .00605 Mdot
.48572 .01927 Mdot
.45454 .06085 Mdot
.35609 .17681 Mdot
.07 .23963 Mdot
.68227 .10525 Mdot
.51197 .09416 Mdot
.35961 .20807 Mdot
.02294 .22927 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.4638 .04862 Mdot
.38514 .14609 Mdot
.14876 .26478 Mdot
.72034 .11979 Mdot
.52652 .09532 Mdot
.37229 .20141 Mdot
.04639 .24382 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49246 .01018 Mdot
.47599 .03236 Mdot
.42364 .10046 Mdot
.26109 .24765 Mdot
.86038 .13419 Mdot
.64326 .0186 Mdot
.61316 .54035 Mdot
.73885 .39317 Mdot
.10268 .4819 Mdot
.50055 .61729 Mdot
.50174 .61568 Mdot
.50555 .61053 Mdot
.5177 .59416 Mdot
.55633 .54302 Mdot
.6777 .41044 Mdot
.0136 .42303 Mdot
.32912 .55272 Mdot
.43481 .61147 Mdot
.44542 .04305 Mdot
.37576 .14688 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .00221 Mdot
.49479 .00704 Mdot
.48341 .02239 Mdot
.44718 .07047 Mdot
.33316 .19833 Mdot
.01225 .20968 Mdot
.67299 .07907 Mdot
.54505 .03786 Mdot
.48379 .05286 Mdot
.39827 .14088 Mdot
.5012 .61642 Mdot
.50381 .61289 Mdot
.51213 .60165 Mdot
.53864 .56619 Mdot
.62253 .46349 Mdot
.87259 .35759 Mdot
.294 .49953 Mdot
.48574 .51274 Mdot
.65611 .39013 Mdot
.02486 .41308 Mdot
.35647 .52882 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00314 Mdot
.49259 .01001 Mdot
.47639 .03182 Mdot
.42491 .09888 Mdot
.26492 .24577 Mdot
.86725 .13649 Mdot
.64641 .01911 Mdot
.61548 .53924 Mdot
.74297 .39184 Mdot
.10896 .48514 Mdot
.50132 .61625 Mdot
.5042 .61235 Mdot
.51339 .59995 Mdot
.54265 .56089 Mdot
.63512 .45014 Mdot
.90678 .36857 Mdot
.31041 .50562 Mdot
.49231 .51275 Mdot
.66266 .38687 Mdot
.0367 .42059 Mdot
.35617 .5365 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.4872 .01729 Mdot
.45923 .05467 Mdot
.37077 .16174 Mdot
.10907 .25512 Mdot
.69628 .1159 Mdot
.50874 .1078 Mdot
.33431 .23512 Mdot
.95387 .19296 Mdot
.64166 .0783 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49728 .00368 Mdot
.49132 .01172 Mdot
.47235 .03722 Mdot
.41212 .11461 Mdot
.22667 .26058 Mdot
.80505 .12177 Mdot
.60802 .02914 Mdot
.56087 .59212 Mdot
.6028 .5033 Mdot
.78844 .36004 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51338 .59997 Mdot
.54262 .56092 Mdot
.63503 .45023 Mdot
.90653 .36848 Mdot
.31032 .50555 Mdot
.49232 .51268 Mdot
.66279 .38673 Mdot
.03704 .42076 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48821 .01592 Mdot
.46245 .0504 Mdot
.3809 .15079 Mdot
.13691 .26263 Mdot
.71196 .11928 Mdot
.51896 .10175 Mdot
.35433 .21871 Mdot
.00046 .21913 Mdot
.6459 .10204 Mdot
.50027 .61766 Mdot
.50087 .61685 Mdot
.50278 .61428 Mdot
.50886 .60606 Mdot
.52823 .58003 Mdot
.58973 .50118 Mdot
.7788 .35604 Mdot
.20271 .49712 Mdot
.39835 .58508 Mdot
.45166 .01118 Mdot
.43358 .07098 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48929 .01446 Mdot
.46588 .04585 Mdot
.3917 .13868 Mdot
.16731 .26675 Mdot
.73569 .11981 Mdot
.54184 .08146 Mdot
.41004 .16048 Mdot
.15037 .28005 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .61211 Mdot
.51398 .59917 Mdot
.5445 .55845 Mdot
.64091 .44423 Mdot
.92214 .37489 Mdot
.31555 .51009 Mdot
.4902 .51917 Mdot
.65017 .39971 Mdot
.50122 .61638 Mdot
.50389 .61277 Mdot
.5124 .60129 Mdot
.5395 .56504 Mdot
.62525 .46055 Mdot
.88007 .35959 Mdot
.29824 .50041 Mdot
.48855 .51101 Mdot
.66172 .38559 Mdot
.03781 .42032 Mdot
.35772 .53534 Mdot
.49962 .00052 Mdot
.49879 .00164 Mdot
.49613 .00523 Mdot
.48767 .01665 Mdot
.46073 .05268 Mdot
.37548 .1567 Mdot
.12194 .259 Mdot
.70287 .11788 Mdot
.51213 .10665 Mdot
.33957 .23144 Mdot
.96509 .19933 Mdot
.64256 .08415 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00448 Mdot
.48944 .01425 Mdot
.46638 .04519 Mdot
.39327 .13688 Mdot
.17178 .26697 Mdot
.73982 .11972 Mdot
.5461 .07758 Mdot
.42058 .14819 Mdot
.18081 .28201 Mdot
.72452 .13635 Mdot
.50002 .618 Mdot
.50007 .61794 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50723 .60826 Mdot
.52305 .58697 Mdot
.5733 .52139 Mdot
.72967 .37505 Mdot
.12282 .47794 Mdot
.34949 .59759 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00372 Mdot
.49122 .01186 Mdot
.47203 .03766 Mdot
.41109 .11586 Mdot
.22362 .26139 Mdot
.80069 .12126 Mdot
.60449 .03121 Mdot
.55399 .60014 Mdot
.50123 .61638 Mdot
.50391 .61275 Mdot
.51245 .60123 Mdot
.53965 .56485 Mdot
.6257 .46007 Mdot
.88129 .35994 Mdot
.29889 .50058 Mdot
.48894 .51082 Mdot
.66241 .38506 Mdot
.03936 .42119 Mdot
.35787 .53612 Mdot
.50038 .61753 Mdot
.5012 .61642 Mdot
.50381 .61289 Mdot
.51213 .60165 Mdot
.53864 .56618 Mdot
.62254 .46348 Mdot
.87261 .35759 Mdot
.29401 .49954 Mdot
.48574 .51273 Mdot
.65612 .39012 Mdot
.02489 .4131 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00306 Mdot
.49278 .00975 Mdot
.477 .031 Mdot
.42684 .09646 Mdot
.27077 .24275 Mdot
.878 .1404 Mdot
.65082 .02059 Mdot
.61751 .53931 Mdot
.74489 .39184 Mdot
.11087 .48651 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49391 .00823 Mdot
.48059 .02618 Mdot
.43824 .08201 Mdot
.30555 .22066 Mdot
.94852 .17376 Mdot
.66737 .04566 Mdot
.5935 .58191 Mdot
.65195 .46149 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50348 .61334 Mdot
.51108 .60308 Mdot
.53528 .57064 Mdot
.61197 .47519 Mdot
.8431 .35218 Mdot
.27327 .49815 Mdot
.46726 .52829 Mdot
.61247 .43249 Mdot
.91268 .35554 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49392 .00821 Mdot
.48063 .02612 Mdot
.43837 .08183 Mdot
.30596 .22035 Mdot
.94942 .17425 Mdot
.66748 .0461 Mdot
.59289 .58282 Mdot
.64987 .46353 Mdot
.89987 .3767 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00557 Mdot
.48686 .01773 Mdot
.45817 .05607 Mdot
.36745 .16523 Mdot
.1001 .25203 Mdot
.69231 .11407 Mdot
.50773 .10691 Mdot
.33475 .23402 Mdot
.9561 .19384 Mdot
.64246 .07871 Mdot
.50059 .61724 Mdot
.50188 .6155 Mdot
.50599 .60995 Mdot
.51907 .59231 Mdot
.5607 .53738 Mdot
.6912 .3998 Mdot
.04431 .44035 Mdot
.33182 .56882 Mdot
.41144 .02872 Mdot
.36497 .13941 Mdot
.13939 .25274 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.4985 .00202 Mdot
.49523 .00644 Mdot
.48481 .02051 Mdot
.45163 .06466 Mdot
.347 .18564 Mdot
.04663 .22825 Mdot
.67731 .09583 Mdot
.52225 .07527 Mdot
.40045 .16166 Mdot
.13889 .27468 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00202 Mdot
.49524 .00643 Mdot
.48484 .02046 Mdot
.45175 .06451 Mdot
.34737 .18529 Mdot
.04756 .22873 Mdot
.67747 .09624 Mdot
.52174 .07615 Mdot
.39853 .16398 Mdot
.13321 .27355 Mdot
.50076 .61701 Mdot
.50243 .61476 Mdot
.50773 .60759 Mdot
.52462 .58486 Mdot
.57829 .51517 Mdot
.74473 .36771 Mdot
.14977 .48695 Mdot
.36187 .59952 Mdot
.39183 .07422 Mdot
.27175 .22039 Mdot
.91515 .1454 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50605 .60986 Mdot
.51927 .59205 Mdot
.56131 .53661 Mdot
.69306 .3984 Mdot
.04843 .44261 Mdot
.33227 .57088 Mdot
.40856 .03303 Mdot
.35513 .14954 Mdot
.11317 .24583 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49458 .00732 Mdot
.48274 .02329 Mdot
.44504 .07324 Mdot
.32655 .20404 Mdot
.9964 .20071 Mdot
.67165 .07068 Mdot
.55729 .01871 Mdot
.52702 .61181 Mdot
.5371 .57773 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49047 .01287 Mdot
.46964 .04085 Mdot
.40355 .12489 Mdot
.20147 .26563 Mdot
.77167 .11945 Mdot
.57839 .04968 Mdot
.49801 .05152 Mdot
.41465 .12691 Mdot
.20931 .26966 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49007 .01341 Mdot
.46838 .04252 Mdot
.39958 .12956 Mdot
.18995 .26673 Mdot
.75837 .11939 Mdot
.5652 .06062 Mdot
.46712 .09088 Mdot
.32007 .22435 Mdot
.95706 .18503 Mdot
.50043 .61745 Mdot
.50138 .61618 Mdot
.50438 .61211 Mdot
.51396 .59918 Mdot
.54446 .5585 Mdot
.64079 .44435 Mdot
.92181 .37475 Mdot
.31546 .50999 Mdot
.49028 .519 Mdot
.65052 .39935 Mdot
.00437 .40339 Mdot
.50052 .61733 Mdot
.50165 .61581 Mdot
.50525 .61094 Mdot
.51674 .59545 Mdot
.55328 .54698 Mdot
.66825 .41848 Mdot
.99114 .41026 Mdot
.32732 .54074 Mdot
.45238 .58423 Mdot
.50709 .57766 Mdot
.57241 .51282 Mdot
.50072 .61706 Mdot
.50229 .61495 Mdot
.50728 .60819 Mdot
.5232 .58676 Mdot
.57381 .52076 Mdot
.7312 .37424 Mdot
.12566 .47901 Mdot
.35061 .59804 Mdot
.38297 .07898 Mdot
.25517 .22645 Mdot
.88877 .13152 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50685 .60878 Mdot
.52183 .5886 Mdot
.56946 .52623 Mdot
.718 .38166 Mdot
.10046 .46873 Mdot
.34204 .59228 Mdot
.38371 .07271 Mdot
.26606 .21951 Mdot
.50054 .61731 Mdot
.5017 .61573 Mdot
.50543 .6107 Mdot
.51731 .59468 Mdot
.55509 .54463 Mdot
.67386 .41365 Mdot
.00455 .41787 Mdot
.32842 .54786 Mdot
.44196 .60049 Mdot
.47035 .00978 Mdot
.45452 .05137 Mdot
.50041 .61748 Mdot
.5013 .61628 Mdot
.50413 .61245 Mdot
.51316 .60027 Mdot
.5419 .56187 Mdot
.63278 .45256 Mdot
.90052 .36623 Mdot
.30795 .5041 Mdot
.4923 .51124 Mdot
.66509 .3842 Mdot
.04345 .42398 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .61211 Mdot
.51397 .59917 Mdot
.54449 .55846 Mdot
.64087 .44427 Mdot
.92204 .37485 Mdot
.31552 .51006 Mdot
.49023 .51912 Mdot
.65028 .3996 Mdot
.00371 .40304 Mdot
.49964 .00048 Mdot
.49886 .00153 Mdot
.49638 .00489 Mdot
.48847 .01556 Mdot
.46329 .04929 Mdot
.38353 .14789 Mdot
.14425 .26404 Mdot
.71702 .11965 Mdot
.52342 .09801 Mdot
.36483 .20879 Mdot
.027 .2337 Mdot
.64886 .11496 Mdot
.49978 .0003 Mdot
.49929 .00095 Mdot
.49775 .00303 Mdot
.49284 .00967 Mdot
.4772 .03073 Mdot
.42747 .09566 Mdot
.27269 .24171 Mdot
.88159 .14179 Mdot
.65217 .02125 Mdot
.61778 .5398 Mdot
.74437 .39234 Mdot
.10955 .48607 Mdot
.50051 .61735 Mdot
.50161 .61586 Mdot
.50513 .6111 Mdot
.51636 .59596 Mdot
.55208 .54854 Mdot
.66453 .42176 Mdot
.98211 .40521 Mdot
.32647 .53605 Mdot
.45912 .57353 Mdot
.53113 .54485 Mdot
.64954 .42574 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48712 .01738 Mdot
.459 .05498 Mdot
.37004 .16251 Mdot
.10709 .25447 Mdot
.69536 .11553 Mdot
.50842 .10773 Mdot
.33412 .23514 Mdot
.95366 .19278 Mdot
.64173 .07808 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50915 .60568 Mdot
.52914 .57882 Mdot
.59259 .49775 Mdot
.78721 .35422 Mdot
.21407 .49802 Mdot
.40826 .57844 Mdot
.47233 .60396 Mdot
.49511 .60849 Mdot
.51056 .59871 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60695 Mdot
.52615 .58281 Mdot
.58314 .5092 Mdot
.75924 .3619 Mdot
.17367 .4928 Mdot
.3763 .59627 Mdot
.41151 .05611 Mdot
.32072 .18933 Mdot
.01437 .20264 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.4882 .01593 Mdot
.46243 .05043 Mdot
.38084 .15087 Mdot
.13673 .26259 Mdot
.71184 .11927 Mdot
.51886 .10183 Mdot
.3541 .21892 Mdot
.99988 .21881 Mdot
.64584 .10175 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60904 Mdot
.5212 .58944 Mdot
.56746 .52876 Mdot
.71191 .38542 Mdot
.08829 .46314 Mdot
.33892 .58825 Mdot
.38712 .0663 Mdot
.27985 .21126 Mdot
.93802 .15524 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50883 .60611 Mdot
.52813 .58017 Mdot
.58939 .50159 Mdot
.7778 .35629 Mdot
.20131 .49698 Mdot
.39717 .58582 Mdot
.4493 .014 Mdot
.42665 .07961 Mdot
.29784 .22054 Mdot
.49965 .00047 Mdot
.49889 .00149 Mdot
.49647 .00476 Mdot
.48877 .01517 Mdot
.46423 .04805 Mdot
.38648 .14459 Mdot
.15252 .26532 Mdot
.72323 .11986 Mdot
.5293 .09285 Mdot
.37907 .19448 Mdot
.06439 .25256 Mdot
.65574 .13014 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52047 .59042 Mdot
.56515 .5317 Mdot
.70484 .39006 Mdot
.07371 .45597 Mdot
.33593 .58253 Mdot
.39337 .05612 Mdot
.30258 .19568 Mdot
.98596 .18268 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.4935 .00878 Mdot
.47928 .02794 Mdot
.43408 .08731 Mdot
.2928 .22955 Mdot
.92138 .1596 Mdot
.66315 .03348 Mdot
.60897 .5582 Mdot
.70578 .41632 Mdot
.49962 .00052 Mdot
.49878 .00164 Mdot
.49612 .00524 Mdot
.48765 .01668 Mdot
.46066 .05278 Mdot
.37527 .15693 Mdot
.12134 .25884 Mdot
.70253 .11781 Mdot
.51192 .10677 Mdot
.33916 .23176 Mdot
.96417 .19882 Mdot
.64247 .08369 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00517 Mdot
.48781 .01646 Mdot
.46119 .05208 Mdot
.37691 .15515 Mdot
.12587 .26005 Mdot
.7051 .11834 Mdot
.51362 .10573 Mdot
.34255 .22902 Mdot
.97198 .20318 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02203 Mdot
.44803 .06935 Mdot
.33582 .19597 Mdot
.01874 .2133 Mdot
.67362 .08242 Mdot
.54026 .04549 Mdot
.46666 .07618 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00806 Mdot
.481 .02563 Mdot
.43954 .08034 Mdot
.30955 .21768 Mdot
.95734 .1786 Mdot
.66836 .05004 Mdot
.58739 .59108 Mdot
.631 .48289 Mdot
.84968 .36334 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51103 .60314 Mdot
.53512 .57085 Mdot
.61147 .47576 Mdot
.84167 .35202 Mdot
.27209 .49815 Mdot
.46608 .52936 Mdot
.60956 .43562 Mdot
.90471 .35247 Mdot
.33441 .47974 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61095 Mdot
.51671 .59548 Mdot
.5532 .54707 Mdot
.66802 .41867 Mdot
.99059 .40996 Mdot
.32727 .54045 Mdot
.4528 .58357 Mdot
.50856 .57564 Mdot
.57715 .50689 Mdot
.50065 .61716 Mdot
.50207 .61524 Mdot
.50659 .60913 Mdot
.521 .58971 Mdot
.56683 .52957 Mdot
.70997 .38667 Mdot
.08433 .46124 Mdot
.33803 .58678 Mdot
.3886 .06379 Mdot
.28539 .2077 Mdot
.94933 .16152 Mdot
.50002 .61801 Mdot
.50006 .61795 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52128 .58934 Mdot
.5677 .52846 Mdot
.71264 .38496 Mdot
.08976 .46383 Mdot
.33927 .58877 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00194 Mdot
.49542 .00618 Mdot
.48541 .01969 Mdot
.45356 .06213 Mdot
.35303 .17982 Mdot
.06207 .23592 Mdot
.68035 .10228 Mdot
.51486 .08853 Mdot
.37161 .19505 Mdot
.05601 .24591 Mdot
.50131 .61627 Mdot
.50416 .61241 Mdot
.51327 .60012 Mdot
.54225 .56141 Mdot
.63386 .45144 Mdot
.90342 .3673 Mdot
.30912 .50478 Mdot
.49236 .51186 Mdot
.66416 .38525 Mdot
.04081 .42267 Mdot
.35691 .53816 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49655 .00466 Mdot
.48901 .01484 Mdot
.46499 .04703 Mdot
.38889 .14187 Mdot
.15934 .26612 Mdot
.72875 .11989 Mdot
.53477 .08791 Mdot
.39252 .18014 Mdot
.10105 .26765 Mdot
.66798 .13927 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50928 .60551 Mdot
.52954 .57828 Mdot
.59387 .49621 Mdot
.79099 .35353 Mdot
.21897 .49828 Mdot
.41273 .57519 Mdot
.48206 .59178 Mdot
.52454 .56913 Mdot
.60367 .47967 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47928 .02795 Mdot
.43406 .08734 Mdot
.29273 .2296 Mdot
.92123 .15952 Mdot
.66312 .03342 Mdot
.60904 .5581 Mdot
.70601 .41615 Mdot
.03266 .44622 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50697 .60862 Mdot
.52221 .5881 Mdot
.57065 .52473 Mdot
.72161 .37953 Mdot
.10752 .47179 Mdot
.34414 .59427 Mdot
.38259 .07548 Mdot
.26046 .2227 Mdot
.90012 .13607 Mdot
.49992 .00011 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49149 .0115 Mdot
.47288 .03652 Mdot
.41378 .1126 Mdot
.2316 .25916 Mdot
.81228 .12276 Mdot
.61364 .02614 Mdot
.57135 .58022 Mdot
.63253 .47108 Mdot
.50086 .61688 Mdot
.50273 .61435 Mdot
.5087 .60629 Mdot
.52771 .58073 Mdot
.58806 .50319 Mdot
.77388 .35731 Mdot
.19574 .49636 Mdot
.39261 .58853 Mdot
.44035 .02451 Mdot
.4007 .1107 Mdot
.22158 .2559 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00297 Mdot
.493 .00946 Mdot
.47769 .03008 Mdot
.42902 .09372 Mdot
.27737 .23909 Mdot
.89051 .14541 Mdot
.65524 .02326 Mdot
.61761 .54192 Mdot
.74077 .39462 Mdot
.5012 .61641 Mdot
.50383 .61285 Mdot
.51222 .60154 Mdot
.5389 .56583 Mdot
.62336 .46258 Mdot
.87489 .35818 Mdot
.29534 .49978 Mdot
.48669 .51211 Mdot
.65808 .38849 Mdot
.02948 .41567 Mdot
.35691 .53116 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.4862 .01862 Mdot
.45607 .05884 Mdot
.36087 .17201 Mdot
.08256 .24515 Mdot
.68589 .10942 Mdot
.50884 .10123 Mdot
.34506 .22323 Mdot
.98387 .2083 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48859 .01541 Mdot
.46366 .04881 Mdot
.38468 .14661 Mdot
.14746 .26458 Mdot
.71937 .11975 Mdot
.5256 .09612 Mdot
.37007 .20363 Mdot
.04059 .24085 Mdot
.65088 .12101 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50243 .61476 Mdot
.50773 .60759 Mdot
.52462 .58486 Mdot
.57831 .51515 Mdot
.74477 .36769 Mdot
.14984 .48697 Mdot
.36191 .59952 Mdot
.39187 .07419 Mdot
.27183 .22035 Mdot
.50098 .6167 Mdot
.50314 .6138 Mdot
.50999 .60454 Mdot
.53183 .57522 Mdot
.6011 .48767 Mdot
.81203 .35119 Mdot
.24379 .49863 Mdot
.43699 .55552 Mdot
.53814 .5205 Mdot
.69595 .38138 Mdot
.07886 .45154 Mdot
.50027 .61768 Mdot
.50085 .61689 Mdot
.5027 .61439 Mdot
.50859 .60643 Mdot
.52737 .58118 Mdot
.587 .50448 Mdot
.77074 .35819 Mdot
.19118 .49577 Mdot
.38901 .59052 Mdot
.43352 .03234 Mdot
.3812 .13253 Mdot
.5004 .61749 Mdot
.50128 .6163 Mdot
.50408 .61252 Mdot
.51301 .60047 Mdot
.54143 .5625 Mdot
.63128 .45414 Mdot
.89648 .36479 Mdot
.30624 .50322 Mdot
.49201 .51062 Mdot
.66581 .38324 Mdot
.04571 .42504 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56064 Mdot
.63571 .44953 Mdot
.90836 .36919 Mdot
.311 .50603 Mdot
.49223 .51323 Mdot
.6618 .38777 Mdot
.50004 .61799 Mdot
.50011 .61788 Mdot
.50037 .61754 Mdot
.50117 .61646 Mdot
.50371 .61302 Mdot
.51183 .60206 Mdot
.53767 .56746 Mdot
.61949 .46681 Mdot
.86418 .35563 Mdot
.28876 .49882 Mdot
.48164 .5158 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49085 .01236 Mdot
.47086 .03922 Mdot
.4074 .12031 Mdot
.21273 .26383 Mdot
.78585 .12001 Mdot
.59167 .03965 Mdot
.52752 .01426 Mdot
.50446 .01013 Mdot
.48807 .02117 Mdot
.49989 .00014 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49659 .0046 Mdot
.48914 .01466 Mdot
.46542 .04647 Mdot
.39024 .14035 Mdot
.16315 .26646 Mdot
.73201 .11986 Mdot
.53807 .08491 Mdot
.40069 .17111 Mdot
.12382 .27467 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50375 .61296 Mdot
.51195 .60189 Mdot
.53807 .56693 Mdot
.62076 .46542 Mdot
.86769 .35641 Mdot
.291 .49909 Mdot
.48347 .51438 Mdot
.65118 .39438 Mdot
.01305 .40647 Mdot
.50084 .61689 Mdot
.50269 .6144 Mdot
.50857 .60645 Mdot
.52731 .58126 Mdot
.58681 .50471 Mdot
.77018 .35835 Mdot
.19036 .49565 Mdot
.38837 .59086 Mdot
.43234 .03368 Mdot
.37784 .13613 Mdot
.15757 .25949 Mdot
.49993 .0001 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49271 .00985 Mdot
.47678 .0313 Mdot
.42614 .09733 Mdot
.26865 .24387 Mdot
.87406 .13893 Mdot
.64928 .01996 Mdot
.61699 .53904 Mdot
.7448 .39158 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50984 .60475 Mdot
.53134 .57588 Mdot
.59955 .48949 Mdot
.80754 .35148 Mdot
.23883 .49866 Mdot
.43197 .55983 Mdot
.52615 .53569 Mdot
.65939 .41142 Mdot
.9937 .40558 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02203 Mdot
.44803 .06935 Mdot
.33582 .19597 Mdot
.01874 .2133 Mdot
.67362 .08242 Mdot
.54026 .04549 Mdot
.46665 .07618 Mdot
.3434 .19904 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50876 .6062 Mdot
.5279 .58047 Mdot
.58869 .50244 Mdot
.77573 .35682 Mdot
.19838 .49667 Mdot
.39475 .58728 Mdot
.44451 .01965 Mdot
.41272 .09657 Mdot
.25646 .24399 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49525 .00642 Mdot
.48487 .02043 Mdot
.45182 .06442 Mdot
.34759 .18508 Mdot
.04811 .22901 Mdot
.67756 .09649 Mdot
.52145 .07667 Mdot
.3974 .16533 Mdot
.12989 .27282 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48711 .0174 Mdot
.45896 .05503 Mdot
.36991 .16264 Mdot
.10676 .25435 Mdot
.6952 .11547 Mdot
.50838 .1077 Mdot
.33411 .23512 Mdot
.95367 .19278 Mdot
.64175 .07806 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48793 .0163 Mdot
.46155 .0516 Mdot
.37807 .15389 Mdot
.12906 .26085 Mdot
.70699 .11866 Mdot
.51499 .10478 Mdot
.34545 .22658 Mdot
.97883 .20702 Mdot
.64387 .09107 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00495 Mdot
.48834 .01575 Mdot
.46285 .04988 Mdot
.38214 .14942 Mdot
.14038 .26333 Mdot
.7143 .11948 Mdot
.52098 .10009 Mdot
.35903 .21434 Mdot
.01222 .22566 Mdot
.6471 .1079 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51138 .60267 Mdot
.53623 .56937 Mdot
.61496 .47183 Mdot
.85153 .3533 Mdot
.27988 .49825 Mdot
.47369 .52254 Mdot
.62821 .41613 Mdot
.9549 .37487 Mdot
.34834 .49514 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01099 Mdot
.47409 .0349 Mdot
.41763 .1079 Mdot
.24304 .2553 Mdot
.82996 .12599 Mdot
.6261 .02094 Mdot
.59223 .55818 Mdot
.68908 .42131 Mdot
.00738 .42815 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.51141 .60263 Mdot
.53632 .56925 Mdot
.61526 .4715 Mdot
.85236 .35343 Mdot
.2805 .49827 Mdot
.47427 .52202 Mdot
.62963 .4147 Mdot
.95863 .37678 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48957 .01408 Mdot
.46679 .04465 Mdot
.39455 .13541 Mdot
.17546 .26706 Mdot
.74334 .11965 Mdot
.54975 .07427 Mdot
.42958 .13744 Mdot
.20719 .27968 Mdot
.75465 .1322 Mdot
.50022 .61773 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50718 .60834 Mdot
.52286 .58722 Mdot
.57272 .52212 Mdot
.72791 .37599 Mdot
.11954 .47669 Mdot
.34825 .597 Mdot
.38228 .07841 Mdot
.2554 .22587 Mdot
.49969 .00043 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48982 .01374 Mdot
.46759 .04358 Mdot
.39708 .13248 Mdot
.18273 .26704 Mdot
.75065 .11949 Mdot
.55731 .06751 Mdot
.44808 .11479 Mdot
.26234 .26189 Mdot
.83859 .13662 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.4877 .01661 Mdot
.46083 .05256 Mdot
.37579 .15636 Mdot
.12279 .25924 Mdot
.70334 .11799 Mdot
.51243 .10647 Mdot
.34016 .23097 Mdot
.96644 .20009 Mdot
.64269 .08483 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49303 .00941 Mdot
.4778 .02992 Mdot
.42939 .09325 Mdot
.2785 .23844 Mdot
.8927 .14633 Mdot
.65593 .02382 Mdot
.61739 .54263 Mdot
.7394 .39541 Mdot
.09961 .48184 Mdot
.50128 .6163 Mdot
.50408 .61252 Mdot
.51301 .60047 Mdot
.54143 .5625 Mdot
.63129 .45413 Mdot
.89649 .36479 Mdot
.30624 .50322 Mdot
.49201 .51062 Mdot
.66581 .38325 Mdot
.0457 .42503 Mdot
.35798 .5399 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00109 Mdot
.49744 .00346 Mdot
.49184 .01103 Mdot
.474 .03503 Mdot
.41732 .10828 Mdot
.24213 .25564 Mdot
.82849 .12568 Mdot
.62514 .02125 Mdot
.59075 .55964 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49445 .0075 Mdot
.48231 .02386 Mdot
.44371 .07497 Mdot
.32241 .2075 Mdot
.98667 .19516 Mdot
.6709 .06546 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50612 .60977 Mdot
.5195 .59173 Mdot
.56206 .53565 Mdot
.69535 .39672 Mdot
.05345 .44534 Mdot
.33287 .57333 Mdot
.4052 .03808 Mdot
.34358 .16085 Mdot
.08331 .23461 Mdot
.50086 .61688 Mdot
.50273 .61434 Mdot
.5087 .60628 Mdot
.52773 .5807 Mdot
.58813 .50311 Mdot
.77408 .35725 Mdot
.19603 .4964 Mdot
.39285 .5884 Mdot
.4408 .02399 Mdot
.40199 .10922 Mdot
.22527 .25498 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.49659 .0046 Mdot
.48915 .01465 Mdot
.46544 .04644 Mdot
.3903 .14027 Mdot
.16334 .26648 Mdot
.73217 .11986 Mdot
.53824 .08475 Mdot
.40111 .17064 Mdot
.125 .27497 Mdot
.68008 .14144 Mdot
.50094 .61677 Mdot
.50299 .61399 Mdot
.50953 .60516 Mdot
.53036 .57719 Mdot
.59644 .49316 Mdot
.79849 .35241 Mdot
.22828 .49858 Mdot
.42155 .5684 Mdot
.50186 .56667 Mdot
.58497 .49159 Mdot
.78957 .34858 Mdot
.50108 .61657 Mdot
.50345 .61337 Mdot
.511 .60318 Mdot
.53504 .57096 Mdot
.6112 .47605 Mdot
.84093 .35194 Mdot
.27148 .49815 Mdot
.46546 .52992 Mdot
.60804 .43728 Mdot
.90051 .35093 Mdot
.33269 .47901 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00333 Mdot
.49216 .01059 Mdot
.47501 .03366 Mdot
.42055 .1043 Mdot
.2518 .25183 Mdot
.84433 .12945 Mdot
.63487 .01885 Mdot
.60437 .54692 Mdot
.71944 .40208 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49276 .00977 Mdot
.47695 .03107 Mdot
.42667 .09667 Mdot
.27026 .24302 Mdot
.87705 .14004 Mdot
.65046 .02042 Mdot
.61741 .53922 Mdot
.74493 .39175 Mdot
.11106 .48656 Mdot
.50012 .61787 Mdot
.50038 .61753 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51218 .60159 Mdot
.53879 .56598 Mdot
.62302 .46296 Mdot
.87394 .35793 Mdot
.29479 .49967 Mdot
.4863 .51236 Mdot
.65729 .38915 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00475 Mdot
.48879 .01514 Mdot
.46429 .04797 Mdot
.38667 .14437 Mdot
.15307 .26539 Mdot
.72366 .11986 Mdot
.52972 .09247 Mdot
.38009 .19341 Mdot
.06715 .25383 Mdot
.65644 .13105 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.4965 .00473 Mdot
.48883 .01508 Mdot
.46444 .04777 Mdot
.38715 .14384 Mdot
.15441 .26556 Mdot
.72472 .11988 Mdot
.53076 .09154 Mdot
.38264 .19074 Mdot
.07402 .25691 Mdot
.65832 .13317 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01054 Mdot
.47515 .03348 Mdot
.42098 .10377 Mdot
.25307 .25129 Mdot
.84649 .13003 Mdot
.63609 .01869 Mdot
.60584 .54569 Mdot
.7229 .40027 Mdot
.07524 .46746 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49816 .00249 Mdot
.49413 .00793 Mdot
.4813 .02523 Mdot
.44048 .07913 Mdot
.31244 .21547 Mdot
.96381 .1822 Mdot
.669 .05336 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.487 .01755 Mdot
.4586 .0555 Mdot
.36879 .16382 Mdot
.10372 .25332 Mdot
.69385 .11486 Mdot
.50801 .10744 Mdot
.33417 .23482 Mdot
.95422 .19297 Mdot
.642 .07811 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49715 .00385 Mdot
.49091 .01227 Mdot
.47105 .03896 Mdot
.40801 .11957 Mdot
.21455 .26347 Mdot
.78825 .12016 Mdot
.59382 .03814 Mdot
.53211 .00857 Mdot
.51825 .60972 Mdot
.53171 .58051 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00556 Mdot
.48688 .01771 Mdot
.45822 .05601 Mdot
.36759 .16508 Mdot
.10049 .25217 Mdot
.69247 .11416 Mdot
.50775 .10697 Mdot
.33467 .23413 Mdot
.95584 .19371 Mdot
.6424 .07862 Mdot
.50095 .61674 Mdot
.50304 .61392 Mdot
.50969 .60494 Mdot
.53087 .5765 Mdot
.59807 .49123 Mdot
.80325 .35187 Mdot
.23392 .49866 Mdot
.42707 .56392 Mdot
.51462 .55038 Mdot
.62408 .44666 Mdot
.90138 .36097 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51088 .60334 Mdot
.53465 .57147 Mdot
.60999 .47744 Mdot
.83748 .35162 Mdot
.26854 .49817 Mdot
.46249 .53262 Mdot
.60069 .44538 Mdot
.88006 .34441 Mdot
.32278 .4768 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61518 Mdot
.50674 .60894 Mdot
.52146 .5891 Mdot
.56827 .52774 Mdot
.71436 .38388 Mdot
.09323 .46545 Mdot
.34012 .58997 Mdot
.38552 .06915 Mdot
.27364 .21507 Mdot
.50104 .61664 Mdot
.5033 .61358 Mdot
.51051 .60384 Mdot
.53347 .57305 Mdot
.60625 .4817 Mdot
.82684 .35102 Mdot
.25887 .49834 Mdot
.45254 .54168 Mdot
.57608 .47381 Mdot
.80944 .33644 Mdot
.26508 .48332 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50854 .6065 Mdot
.5272 .58141 Mdot
.58646 .50514 Mdot
.76914 .35866 Mdot
.18882 .49543 Mdot
.38719 .59147 Mdot
.43017 .03612 Mdot
.37172 .14258 Mdot
.14102 .25687 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .6121 Mdot
.514 .59914 Mdot
.54456 .55837 Mdot
.64111 .44403 Mdot
.92266 .37512 Mdot
.31571 .51027 Mdot
.49008 .51946 Mdot
.64958 .40032 Mdot
.00186 .40204 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60702 Mdot
.52597 .58306 Mdot
.58256 .50991 Mdot
.7575 .36253 Mdot
.17091 .49223 Mdot
.37447 .59691 Mdot
.40865 .05899 Mdot
.31319 .19506 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49786 .00289 Mdot
.49317 .00922 Mdot
.47825 .02932 Mdot
.43081 .09146 Mdot
.28283 .23588 Mdot
.90117 .15003 Mdot
.65841 .02625 Mdot
.61594 .54606 Mdot
.7324 .39942 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49526 .00641 Mdot
.48489 .0204 Mdot
.45189 .06433 Mdot
.3478 .18488 Mdot
.04867 .22929 Mdot
.67766 .09673 Mdot
.52115 .07718 Mdot
.39627 .16668 Mdot
.12659 .27204 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .6022 Mdot
.53734 .5679 Mdot
.61846 .46794 Mdot
.86132 .35504 Mdot
.28686 .49865 Mdot
.48003 .51711 Mdot
.64333 .40149 Mdot
.99371 .39566 Mdot
.35353 .51307 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50731 .60816 Mdot
.52328 .58666 Mdot
.57405 .52046 Mdot
.73192 .37387 Mdot
.12699 .47949 Mdot
.35115 .59823 Mdot
.38319 .07902 Mdot
.25534 .22648 Mdot
.88889 .13164 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49851 .00201 Mdot
.49525 .00641 Mdot
.48488 .02041 Mdot
.45186 .06436 Mdot
.34772 .18496 Mdot
.04845 .22918 Mdot
.67762 .09663 Mdot
.52127 .07697 Mdot
.39672 .16614 Mdot
.1279 .27235 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49168 .01124 Mdot
.4735 .03569 Mdot
.41575 .11019 Mdot
.23746 .25728 Mdot
.82117 .12424 Mdot
.62014 .02315 Mdot
.58269 .56792 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.496 .0054 Mdot
.48727 .01719 Mdot
.45947 .05436 Mdot
.37151 .16095 Mdot
.11109 .25578 Mdot
.69724 .11626 Mdot
.50912 .10781 Mdot
.33468 .23496 Mdot
.9545 .19335 Mdot
.64165 .0787 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49632 .00498 Mdot
.48826 .01585 Mdot
.46261 .05019 Mdot
.3814 .15024 Mdot
.1383 .26292 Mdot
.71289 .11937 Mdot
.51975 .1011 Mdot
.35617 .21702 Mdot
.00503 .22168 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48904 .0148 Mdot
.46508 .04692 Mdot
.38917 .14156 Mdot
.16013 .2662 Mdot
.72941 .11988 Mdot
.53544 .0873 Mdot
.39418 .17833 Mdot
.10563 .26922 Mdot
.67001 .13992 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .60259 Mdot
.53642 .56913 Mdot
.61555 .47117 Mdot
.85317 .35356 Mdot
.2811 .4983 Mdot
.47484 .52153 Mdot
.63099 .41335 Mdot
.96218 .37862 Mdot
.34957 .49822 Mdot
.50118 .61645 Mdot
.50375 .61297 Mdot
.51194 .60192 Mdot
.53802 .56701 Mdot
.62058 .46561 Mdot
.86721 .3563 Mdot
.2907 .49905 Mdot
.48323 .51457 Mdot
.65064 .39485 Mdot
.01175 .40574 Mdot
.35525 .52218 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00807 Mdot
.48097 .02567 Mdot
.43944 .08047 Mdot
.30924 .21791 Mdot
.95666 .17823 Mdot
.66829 .0497 Mdot
.58787 .59035 Mdot
.63265 .48113 Mdot
.85417 .36408 Mdot
.50101 .61666 Mdot
.50323 .61367 Mdot
.51029 .60414 Mdot
.53278 .57396 Mdot
.60409 .4842 Mdot
.82063 .35095 Mdot
.25278 .49847 Mdot
.44624 .54737 Mdot
.56057 .49256 Mdot
.76359 .34556 Mdot
.20447 .4871 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49414 .00791 Mdot
.48134 .02517 Mdot
.44062 .07894 Mdot
.31289 .21512 Mdot
.96483 .18277 Mdot
.66909 .05389 Mdot
.5819 .5993 Mdot
.61221 .50368 Mdot
.50113 .61651 Mdot
.5036 .61316 Mdot
.51149 .60253 Mdot
.53658 .56891 Mdot
.61606 .47061 Mdot
.8546 .3538 Mdot
.28214 .49834 Mdot
.47581 .52068 Mdot
.63333 .41104 Mdot
.96826 .38181 Mdot
.35048 .50091 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00438 Mdot
.48966 .01396 Mdot
.46707 .04427 Mdot
.39543 .13439 Mdot
.17798 .26709 Mdot
.74583 .11959 Mdot
.55233 .07195 Mdot
.4359 .12978 Mdot
.22592 .27564 Mdot
.77993 .13069 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60458 Mdot
.53172 .57537 Mdot
.60075 .48808 Mdot
.81102 .35125 Mdot
.24268 .49864 Mdot
.43587 .55649 Mdot
.53544 .52391 Mdot
.68774 .38751 Mdot
.06074 .44246 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50613 .60976 Mdot
.51952 .5917 Mdot
.56213 .53556 Mdot
.69558 .39656 Mdot
.05394 .44561 Mdot
.33293 .57357 Mdot
.40488 .03856 Mdot
.34248 .16189 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48715 .01735 Mdot
.45909 .05486 Mdot
.37033 .16221 Mdot
.10787 .25473 Mdot
.69572 .11568 Mdot
.50854 .10776 Mdot
.33418 .23515 Mdot
.9537 .19283 Mdot
.6417 .07815 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.501 .61668 Mdot
.50319 .61373 Mdot
.51016 .60432 Mdot
.53235 .57453 Mdot
.60274 .48577 Mdot
.81675 .35101 Mdot
.2488 .49855 Mdot
.44213 .55103 Mdot
.55055 .50495 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.51291 .60061 Mdot
.5411 .56293 Mdot
.63025 .45522 Mdot
.8937 .36383 Mdot
.305 .50266 Mdot
.49169 .51036 Mdot
.66591 .38293 Mdot
.04631 .42526 Mdot
.35822 .53999 Mdot
.50067 .61712 Mdot
.50215 .61513 Mdot
.50684 .6088 Mdot
.52178 .58866 Mdot
.56931 .52642 Mdot
.71753 .38194 Mdot
.09954 .46832 Mdot
.34178 .592 Mdot
.3839 .0723 Mdot
.26692 .21901 Mdot
.91255 .14196 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48794 .01629 Mdot
.46158 .05157 Mdot
.37814 .15381 Mdot
.12926 .2609 Mdot
.70712 .11868 Mdot
.51508 .10472 Mdot
.34565 .22641 Mdot
.9793 .20728 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.5119 .60197 Mdot
.53789 .56718 Mdot
.62017 .46607 Mdot
.86605 .35604 Mdot
.28997 .49896 Mdot
.48264 .51502 Mdot
.64931 .39603 Mdot
.00853 .40393 Mdot
.35495 .52054 Mdot
.50016 .61782 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61117 Mdot
.51619 .59619 Mdot
.55154 .54924 Mdot
.66284 .42328 Mdot
.97797 .40291 Mdot
.32604 .53394 Mdot
.46211 .56874 Mdot
.54187 .53037 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00806 Mdot
.48099 .02564 Mdot
.43952 .08037 Mdot
.30948 .21773 Mdot
.95718 .17851 Mdot
.66834 .04997 Mdot
.5875 .59091 Mdot
.63138 .48248 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49344 .00886 Mdot
.4791 .02818 Mdot
.43351 .08804 Mdot
.29106 .2307 Mdot
.91778 .15782 Mdot
.66242 .03206 Mdot
.61054 .55566 Mdot
.71146 .41242 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00376 Mdot
.49113 .01197 Mdot
.47176 .03802 Mdot
.41025 .11688 Mdot
.22113 .26201 Mdot
.7972 .1209 Mdot
.60158 .033 Mdot
.54818 .60704 Mdot
.56597 .54763 Mdot
.67989 .41417 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00302 Mdot
.49289 .00961 Mdot
.47734 .03054 Mdot
.42792 .09511 Mdot
.27403 .24097 Mdot
.88413 .1428 Mdot
.65308 .02177 Mdot
.61785 .54027 Mdot
.74368 .39284 Mdot
.10805 .48549 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.5124 .60129 Mdot
.53949 .56505 Mdot
.62521 .46059 Mdot
.87997 .35956 Mdot
.29818 .5004 Mdot
.48852 .51103 Mdot
.66166 .38564 Mdot
.03768 .42025 Mdot
.35771 .53527 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00376 Mdot
.49113 .01198 Mdot
.47175 .03803 Mdot
.41021 .11693 Mdot
.22102 .26203 Mdot
.79704 .12089 Mdot
.60145 .03308 Mdot
.54792 .60736 Mdot
.5652 .54859 Mdot
.50081 .61693 Mdot
.5026 .61453 Mdot
.50827 .60686 Mdot
.52635 .58254 Mdot
.58378 .50841 Mdot
.76116 .36123 Mdot
.17668 .49339 Mdot
.37836 .59549 Mdot
.41483 .0527 Mdot
.32956 .18219 Mdot
.03476 .21416 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46941 .04115 Mdot
.40282 .12575 Mdot
.19936 .26589 Mdot
.76915 .11941 Mdot
.57595 .05164 Mdot
.49238 .0587 Mdot
.3974 .14737 Mdot
.15896 .27142 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.48751 .01686 Mdot
.46023 .05334 Mdot
.37392 .15837 Mdot
.11767 .25779 Mdot
.70056 .11731 Mdot
.51075 .10735 Mdot
.33705 .23337 Mdot
.95944 .19618 Mdot
.64202 .08131 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48713 .01737 Mdot
.45903 .05494 Mdot
.37014 .16241 Mdot
.10736 .25456 Mdot
.69548 .11558 Mdot
.50846 .10774 Mdot
.33414 .23514 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50079 .61696 Mdot
.50252 .61462 Mdot
.50804 .60717 Mdot
.52561 .58353 Mdot
.58143 .51129 Mdot
.75415 .3638 Mdot
.16551 .49104 Mdot
.371 .59795 Mdot
.40349 .06401 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49356 .0087 Mdot
.47948 .02767 Mdot
.43471 .08651 Mdot
.29473 .22827 Mdot
.92538 .1616 Mdot
.66391 .03512 Mdot
.60708 .56121 Mdot
.69903 .42116 Mdot
.01757 .43742 Mdot
.50028 .61766 Mdot
.50088 .61684 Mdot
.5028 .61424 Mdot
.50894 .60597 Mdot
.52846 .57972 Mdot
.59046 .5003 Mdot
.78095 .35554 Mdot
.20567 .4974 Mdot
.40086 .58348 Mdot
.45678 .00502 Mdot
.44866 .05179 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50712 .60842 Mdot
.52267 .58748 Mdot
.57212 .52288 Mdot
.72607 .377 Mdot
.11606 .47532 Mdot
.34699 .5963 Mdot
.38215 .07781 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00314 Mdot
.4926 .01 Mdot
.47643 .03177 Mdot
.42502 .09873 Mdot
.26527 .2456 Mdot
.86788 .13671 Mdot
.64668 .01918 Mdot
.61565 .53919 Mdot
.74323 .39177 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49705 .00398 Mdot
.49061 .01268 Mdot
.4701 .04023 Mdot
.405 .12317 Mdot
.20571 .26504 Mdot
.77688 .11959 Mdot
.58338 .04578 Mdot
.5093 .03716 Mdot
.44918 .08348 Mdot
.49961 .00053 Mdot
.49876 .00167 Mdot
.49605 .00533 Mdot
.48743 .01697 Mdot
.45996 .0537 Mdot
.37307 .15929 Mdot
.11534 .2571 Mdot
.69935 .11696 Mdot
.5101 .1076 Mdot
.336 .23412 Mdot
.95718 .1949 Mdot
.64182 .08015 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50096 .61673 Mdot
.50307 .61388 Mdot
.50979 .60482 Mdot
.53117 .5761 Mdot
.59903 .49011 Mdot
.80602 .35161 Mdot
.23711 .49867 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51013 .60435 Mdot
.53227 .57464 Mdot
.60248 .48607 Mdot
.81599 .35103 Mdot
.24801 .49856 Mdot
.44132 .55174 Mdot
.54859 .50739 Mdot
.72761 .36131 Mdot
.14301 .47675 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49236 .01032 Mdot
.47566 .0328 Mdot
.42259 .10177 Mdot
.25792 .24913 Mdot
.85481 .13244 Mdot
.64051 .01845 Mdot
.61066 .54197 Mdot
.73373 .3952 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00805 Mdot
.48102 .0256 Mdot
.4396 .08026 Mdot
.30974 .21753 Mdot
.95776 .17883 Mdot
.6684 .05026 Mdot
.58708 .59153 Mdot
.62996 .484 Mdot
.84683 .36293 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00406 Mdot
.49043 .01293 Mdot
.46951 .04102 Mdot
.40314 .12537 Mdot
.20028 .26578 Mdot
.77024 .11942 Mdot
.57701 .05079 Mdot
.49484 .05557 Mdot
.40492 .13857 Mdot
.1807 .27235 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60225 Mdot
.53723 .56806 Mdot
.61809 .46835 Mdot
.86029 .35483 Mdot
.28615 .49859 Mdot
.47942 .51762 Mdot
.6419 .40282 Mdot
.99012 .39367 Mdot
.35316 .51129 Mdot
.50093 .61677 Mdot
.50297 .61402 Mdot
.50946 .60526 Mdot
.53014 .57749 Mdot
.59574 .49399 Mdot
.79646 .35268 Mdot
.2258 .49853 Mdot
.41917 .57028 Mdot
.49645 .57357 Mdot
.5684 .51209 Mdot
.73981 .36485 Mdot
.50092 .61679 Mdot
.50294 .61406 Mdot
.50937 .60538 Mdot
.52984 .57788 Mdot
.59482 .49508 Mdot
.79376 .35308 Mdot
.22247 .49842 Mdot
.416 .57273 Mdot
.48931 .58263 Mdot
.5466 .54004 Mdot
.67279 .40952 Mdot
.50059 .61724 Mdot
.50186 .61551 Mdot
.50594 .61001 Mdot
.51893 .59251 Mdot
.56023 .53799 Mdot
.68974 .40089 Mdot
.04108 .43856 Mdot
.33148 .56719 Mdot
.41375 .02525 Mdot
.37289 .13096 Mdot
.16099 .25603 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.5071 .60844 Mdot
.52262 .58754 Mdot
.57195 .52309 Mdot
.72558 .37728 Mdot
.11513 .47494 Mdot
.34666 .5961 Mdot
.38215 .07761 Mdot
.25657 .22503 Mdot
.89247 .13276 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50994 .60461 Mdot
.53166 .57545 Mdot
.60057 .4883 Mdot
.81048 .35128 Mdot
.2421 .49864 Mdot
.43528 .55701 Mdot
.53402 .52571 Mdot
.68341 .39089 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51042 .60396 Mdot
.53319 .57341 Mdot
.6054 .48269 Mdot
.82439 .35097 Mdot
.25651 .49839 Mdot
.4501 .5439 Mdot
.57006 .48103 Mdot
.79173 .33853 Mdot
.24398 .48597 Mdot
.49985 .0002 Mdot
.49953 .00063 Mdot
.49852 .00201 Mdot
.49527 .00639 Mdot
.48493 .02034 Mdot
.45202 .06415 Mdot
.34823 .18447 Mdot
.04976 .22985 Mdot
.67786 .0972 Mdot
.52058 .07818 Mdot
.39407 .16929 Mdot
.12016 .2704 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51228 .60145 Mdot
.53911 .56556 Mdot
.62402 .46187 Mdot
.87669 .35866 Mdot
.29637 .49998 Mdot
.48738 .51168 Mdot
.65947 .38736 Mdot
.0327 .41747 Mdot
.35723 .53277 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00314 Mdot
.49258 .01002 Mdot
.47638 .03183 Mdot
.42487 .09893 Mdot
.2648 .24584 Mdot
.86703 .13641 Mdot
.64631 .01909 Mdot
.61542 .53926 Mdot
.50093 .61678 Mdot
.50297 .61402 Mdot
.50946 .60526 Mdot
.53012 .57751 Mdot
.59569 .49405 Mdot
.7963 .3527 Mdot
.22561 .49852 Mdot
.41899 .57042 Mdot
.49603 .57411 Mdot
.5671 .51373 Mdot
.73588 .36676 Mdot
.50098 .6167 Mdot
.50314 .6138 Mdot
.50999 .60454 Mdot
.53182 .57523 Mdot
.60108 .4877 Mdot
.81196 .3512 Mdot
.24371 .49863 Mdot
.43691 .55559 Mdot
.53795 .52075 Mdot
.69536 .38181 Mdot
.07757 .45091 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49374 .00846 Mdot
.48006 .02689 Mdot
.43654 .08417 Mdot
.30035 .2244 Mdot
.93727 .16773 Mdot
.66587 .04033 Mdot
.60061 .57118 Mdot
.67642 .43912 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00328 Mdot
.49226 .01046 Mdot
.47533 .03324 Mdot
.42156 .10305 Mdot
.25482 .25053 Mdot
.84946 .13086 Mdot
.63771 .01854 Mdot
.60771 .54418 Mdot
.72721 .39814 Mdot
.08301 .47165 Mdot
.49979 .00028 Mdot
.49933 .00091 Mdot
.49786 .00288 Mdot
.4932 .00919 Mdot
.47833 .02922 Mdot
.43105 .09116 Mdot
.28355 .23544 Mdot
.90261 .15068 Mdot
.6588 .0267 Mdot
.6156 .54675 Mdot
.73094 .40026 Mdot
.08331 .47401 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49584 .00562 Mdot
.48674 .01791 Mdot
.45776 .05661 Mdot
.36617 .16656 Mdot
.09667 .25077 Mdot
.69092 .11327 Mdot
.50764 .1062 Mdot
.3358 .23282 Mdot
.9591 .19531 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.4869 .01768 Mdot
.4583 .0559 Mdot
.36785 .16481 Mdot
.10119 .25242 Mdot
.69276 .11431 Mdot
.5078 .10709 Mdot
.33452 .23431 Mdot
.9554 .1935 Mdot
.6423 .07847 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50866 .60634 Mdot
.52757 .58091 Mdot
.58765 .5037 Mdot
.77265 .35764 Mdot
.19397 .49614 Mdot
.3912 .58933 Mdot
.43764 .02764 Mdot
.39292 .11958 Mdot
.19943 .25974 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01038 Mdot
.47552 .03298 Mdot
.42215 .10231 Mdot
.25662 .24972 Mdot
.85256 .13177 Mdot
.63936 .01846 Mdot
.60948 .54282 Mdot
.73118 .3963 Mdot
.08995 .47532 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.5092 .60561 Mdot
.52929 .57861 Mdot
.59308 .49716 Mdot
.78865 .35395 Mdot
.21595 .49813 Mdot
.40996 .57722 Mdot
.47601 .59937 Mdot
.5062 .59363 Mdot
.54569 .55186 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00414 Mdot
.49023 .0132 Mdot
.46887 .04187 Mdot
.40112 .12776 Mdot
.19441 .26639 Mdot
.76338 .11937 Mdot
.57024 .05634 Mdot
.47907 .07569 Mdot
.35661 .19135 Mdot
.047 .23429 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49236 .01032 Mdot
.47565 .03281 Mdot
.42256 .1018 Mdot
.25785 .24916 Mdot
.85469 .13241 Mdot
.64045 .01845 Mdot
.6106 .54201 Mdot
.7336 .39525 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .6022 Mdot
.53735 .56789 Mdot
.61847 .46793 Mdot
.86135 .35505 Mdot
.28688 .49865 Mdot
.48005 .5171 Mdot
.64337 .40145 Mdot
.99381 .39571 Mdot
.35354 .51312 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50531 .61086 Mdot
.51693 .59519 Mdot
.55389 .54618 Mdot
.67016 .41681 Mdot
.99574 .41286 Mdot
.32771 .54317 Mdot
.44885 .58977 Mdot
.49458 .5948 Mdot
.53217 .56519 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49749 .0034 Mdot
.49199 .01082 Mdot
.47449 .03436 Mdot
.41889 .10634 Mdot
.24682 .25386 Mdot
.83607 .12737 Mdot
.62998 .01982 Mdot
.59791 .55271 Mdot
.70361 .41139 Mdot
.03796 .44625 Mdot
.50016 .61782 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61117 Mdot
.51618 .5962 Mdot
.55151 .54927 Mdot
.66277 .42334 Mdot
.97779 .40282 Mdot
.32602 .53385 Mdot
.46223 .56854 Mdot
.54232 .52977 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .00471 Mdot
.4889 .01498 Mdot
.46466 .04748 Mdot
.38784 .14306 Mdot
.15637 .2658 Mdot
.7263 .11989 Mdot
.53232 .09013 Mdot
.38648 .18667 Mdot
.08445 .26133 Mdot
.6616 .13597 Mdot
.50126 .61633 Mdot
.50403 .61259 Mdot
.51283 .60072 Mdot
.54085 .56326 Mdot
.62947 .45605 Mdot
.89157 .36312 Mdot
.30403 .50225 Mdot
.49137 .51025 Mdot
.66577 .38289 Mdot
.04624 .42516 Mdot
.35832 .53982 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00224 Mdot
.49473 .00712 Mdot
.48321 .02266 Mdot
.44655 .07128 Mdot
.33121 .20004 Mdot
.00754 .20702 Mdot
.67257 .0766 Mdot
.54863 .03222 Mdot
.49649 .03547 Mdot
.50118 .61645 Mdot
.50374 .61298 Mdot
.51193 .60193 Mdot
.53799 .56705 Mdot
.62048 .46572 Mdot
.86694 .35624 Mdot
.29053 .49903 Mdot
.48309 .51467 Mdot
.65033 .39513 Mdot
.01101 .40532 Mdot
.35518 .5218 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01089 Mdot
.47431 .0346 Mdot
.41832 .10704 Mdot
.24512 .25452 Mdot
.8333 .12673 Mdot
.62825 .02029 Mdot
.59543 .55506 Mdot
.69733 .41552 Mdot
.02501 .43861 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.5041 .61249 Mdot
.51307 .60038 Mdot
.54163 .56223 Mdot
.63192 .45346 Mdot
.8982 .3654 Mdot
.30698 .50359 Mdot
.49216 .51085 Mdot
.66559 .38358 Mdot
.04494 .42469 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49511 .00661 Mdot
.48442 .02102 Mdot
.45041 .06626 Mdot
.34319 .18922 Mdot
.03702 .22324 Mdot
.67582 .09143 Mdot
.52788 .06572 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00107 Mdot
.49747 .00342 Mdot
.49192 .01091 Mdot
.47427 .03465 Mdot
.4182 .10719 Mdot
.24476 .25466 Mdot
.83272 .1266 Mdot
.62788 .02039 Mdot
.59489 .55558 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00172 Mdot
.49593 .00549 Mdot
.48705 .01749 Mdot
.45875 .0553 Mdot
.36927 .16332 Mdot
.10502 .25376 Mdot
.69442 .11512 Mdot
.50815 .10757 Mdot
.3341 .23499 Mdot
.95387 .19283 Mdot
.50075 .61703 Mdot
.50237 .61483 Mdot
.50757 .60781 Mdot
.5241 .58556 Mdot
.57665 .51722 Mdot
.73977 .36998 Mdot
.14114 .48433 Mdot
.35747 .5995 Mdot
.38747 .07731 Mdot
.26239 .2244 Mdot
.89929 .13715 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01616 Mdot
.46188 .05117 Mdot
.37908 .15279 Mdot
.13187 .26152 Mdot
.70872 .11891 Mdot
.51631 .10381 Mdot
.34834 .22408 Mdot
.98577 .21091 Mdot
.64452 .0946 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47927 .02795 Mdot
.43405 .08735 Mdot
.29271 .22961 Mdot
.92119 .1595 Mdot
.66311 .03341 Mdot
.60906 .55807 Mdot
.70608 .4161 Mdot
.03281 .44631 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48928 .01447 Mdot
.46587 .04587 Mdot
.39165 .13874 Mdot
.16716 .26675 Mdot
.73556 .11981 Mdot
.54171 .08159 Mdot
.4097 .16088 Mdot
.14939 .27991 Mdot
.69648 .14063 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49827 .00233 Mdot
.4945 .00743 Mdot
.48249 .02363 Mdot
.44426 .07426 Mdot
.32411 .20609 Mdot
.99064 .19742 Mdot
.67121 .06759 Mdot
.56184 .01169 Mdot
.54292 .59042 Mdot
.49962 .00052 Mdot
.49879 .00164 Mdot
.49613 .00523 Mdot
.48767 .01665 Mdot
.46074 .05268 Mdot
.37551 .15667 Mdot
.122 .25902 Mdot
.7029 .11789 Mdot
.51215 .10664 Mdot
.33961 .23141 Mdot
.96518 .19938 Mdot
.64257 .0842 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00072 Mdot
.49829 .00231 Mdot
.49456 .00735 Mdot
.48266 .0234 Mdot
.44479 .07356 Mdot
.32577 .2047 Mdot
.99457 .19966 Mdot
.67151 .0697 Mdot
.55873 .01648 Mdot
.53207 .60498 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51042 .60396 Mdot
.53319 .57341 Mdot
.60539 .48269 Mdot
.82438 .35097 Mdot
.2565 .49839 Mdot
.45008 .54391 Mdot
.57002 .48107 Mdot
.79162 .33855 Mdot
.24384 .48598 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50253 .61461 Mdot
.50807 .60713 Mdot
.52571 .5834 Mdot
.58174 .51091 Mdot
.75507 .36344 Mdot
.167 .49138 Mdot
.37194 .59769 Mdot
.40485 .06271 Mdot
.30339 .20203 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.5109 .60332 Mdot
.53471 .5714 Mdot
.61017 .47722 Mdot
.83801 .35167 Mdot
.269 .49816 Mdot
.46295 .5322 Mdot
.60184 .4441 Mdot
.88327 .34533 Mdot
.32451 .477 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.49599 .00541 Mdot
.48724 .01723 Mdot
.45936 .0545 Mdot
.37117 .16131 Mdot
.11016 .25547 Mdot
.69679 .1161 Mdot
.50894 .10782 Mdot
.33449 .23506 Mdot
.95416 .19314 Mdot
.64164 .07849 Mdot
.5012 .61642 Mdot
.50381 .61288 Mdot
.51215 .60163 Mdot
.53869 .56612 Mdot
.62269 .46331 Mdot
.87303 .3577 Mdot
.29426 .49958 Mdot
.48592 .51261 Mdot
.6565 .3898 Mdot
.02579 .4136 Mdot
.35656 .52929 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51067 .60362 Mdot
.53399 .57235 Mdot
.60792 .4798 Mdot
.83159 .35122 Mdot
.26331 .49825 Mdot
.45713 .53751 Mdot
.58741 .46049 Mdot
.84233 .33708 Mdot
.29692 .47826 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50545 .61067 Mdot
.51737 .5946 Mdot
.55529 .54437 Mdot
.67448 .41313 Mdot
.00603 .41871 Mdot
.32854 .54865 Mdot
.4408 .60228 Mdot
.46628 .01527 Mdot
.44157 .06823 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49083 .01239 Mdot
.47078 .03932 Mdot
.40716 .12059 Mdot
.21204 .26396 Mdot
.78494 .11996 Mdot
.59085 .04024 Mdot
.52574 .01647 Mdot
.50096 .61673 Mdot
.50307 .61388 Mdot
.50979 .60481 Mdot
.53118 .57609 Mdot
.59906 .49007 Mdot
.80611 .3516 Mdot
.23721 .49867 Mdot
.43034 .5612 Mdot
.5223 .54059 Mdot
.64761 .42254 Mdot
.96392 .38938 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.5113 .60278 Mdot
.53599 .5697 Mdot
.6142 .47269 Mdot
.84937 .35298 Mdot
.27824 .49821 Mdot
.47213 .52392 Mdot
.62441 .41997 Mdot
.94488 .36989 Mdot
.34639 .49119 Mdot
.4998 .00027 Mdot
.49937 .00084 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47978 .02727 Mdot
.43565 .08532 Mdot
.2976 .22631 Mdot
.93142 .16468 Mdot
.66495 .03771 Mdot
.60394 .56609 Mdot
.68799 .4296 Mdot
.99289 .42301 Mdot
.50006 .61795 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50198 .61535 Mdot
.50632 .6095 Mdot
.52013 .59089 Mdot
.56406 .53309 Mdot
.7015 .39235 Mdot
.06666 .45236 Mdot
.33474 .57948 Mdot
.39712 .05032 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.5044 .61209 Mdot
.51402 .59911 Mdot
.54465 .55826 Mdot
.64136 .44377 Mdot
.92332 .37541 Mdot
.3159 .51048 Mdot
.48992 .51982 Mdot
.64883 .40109 Mdot
.99985 .40096 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49374 .00845 Mdot
.48006 .02689 Mdot
.43656 .08415 Mdot
.3004 .22436 Mdot
.93738 .1678 Mdot
.66588 .04038 Mdot
.60054 .57128 Mdot
.67619 .43932 Mdot
.96535 .40745 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50759 .60778 Mdot
.52417 .58546 Mdot
.57687 .51694 Mdot
.74045 .36966 Mdot
.14233 .48471 Mdot
.35805 .59953 Mdot
.38799 .07698 Mdot
.26344 .224 Mdot
.901 .13803 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .0051 Mdot
.48796 .01625 Mdot
.46167 .05144 Mdot
.37844 .1535 Mdot
.13007 .2611 Mdot
.70761 .11876 Mdot
.51546 .10445 Mdot
.34645 .22572 Mdot
.98123 .20836 Mdot
.6441 .09229 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49843 .00212 Mdot
.49501 .00674 Mdot
.48411 .02144 Mdot
.44941 .06756 Mdot
.3401 .19208 Mdot
.02931 .2191 Mdot
.6748 .08772 Mdot
.53286 .05747 Mdot
.43987 .11189 Mdot
.25883 .25921 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00506 Mdot
.48806 .01612 Mdot
.46199 .05102 Mdot
.37944 .1524 Mdot
.13285 .26175 Mdot
.70933 .11899 Mdot
.5168 .10345 Mdot
.5006 .61722 Mdot
.50192 .61545 Mdot
.5061 .60979 Mdot
.51945 .5918 Mdot
.56189 .53586 Mdot
.69485 .39708 Mdot
.05236 .44475 Mdot
.33273 .5728 Mdot
.40592 .037 Mdot
.34605 .15848 Mdot
.08962 .23724 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50792 .60733 Mdot
.52524 .58403 Mdot
.58026 .51273 Mdot
.75064 .36519 Mdot
.15975 .48964 Mdot
.36749 .59878 Mdot
.39865 .06847 Mdot
.28786 .21186 Mdot
.94506 .16194 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00328 Mdot
.49228 .01043 Mdot
.47539 .03316 Mdot
.42174 .10282 Mdot
.25538 .25028 Mdot
.85043 .13114 Mdot
.63823 .01851 Mdot
.60828 .54373 Mdot
.72851 .39752 Mdot
.0853 .47287 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01633 Mdot
.46147 .0517 Mdot
.37782 .15417 Mdot
.12837 .26068 Mdot
.70657 .1186 Mdot
.51468 .105 Mdot
.34478 .22715 Mdot
.97724 .20613 Mdot
.64373 .09027 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51587 .59662 Mdot
.55051 .55058 Mdot
.65965 .42618 Mdot
.97008 .39861 Mdot
.32513 .53002 Mdot
.46754 .5599 Mdot
.56161 .5042 Mdot
.7458 .35671 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48782 .01644 Mdot
.46123 .05203 Mdot
.37704 .15501 Mdot
.12622 .26014 Mdot
.7053 .11838 Mdot
.51376 .10563 Mdot
.34285 .22878 Mdot
.97268 .20357 Mdot
.49985 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49531 .00634 Mdot
.48505 .02018 Mdot
.4524 .06365 Mdot
.34941 .18334 Mdot
.05277 .23136 Mdot
.67841 .09849 Mdot
.51905 .08088 Mdot
.38818 .17622 Mdot
.10306 .26522 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48805 .01613 Mdot
.46196 .05106 Mdot
.37934 .15251 Mdot
.13258 .26168 Mdot
.70916 .11897 Mdot
.51667 .10355 Mdot
.34912 .22339 Mdot
.50074 .61703 Mdot
.50237 .61484 Mdot
.50754 .60785 Mdot
.52401 .58568 Mdot
.57635 .51759 Mdot
.73887 .3704 Mdot
.13954 .48382 Mdot
.35671 .59943 Mdot
.38681 .0777 Mdot
.26109 .22489 Mdot
.89722 .13609 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00191 Mdot
.49549 .0061 Mdot
.48563 .0194 Mdot
.45423 .06125 Mdot
.35512 .17777 Mdot
.06748 .23847 Mdot
.68163 .10433 Mdot
.51281 .09247 Mdot
.3632 .20424 Mdot
.03273 .23437 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.48921 .01457 Mdot
.46563 .04619 Mdot
.3909 .13959 Mdot
.16504 .26661 Mdot
.73366 .11984 Mdot
.53975 .08337 Mdot
.40487 .1664 Mdot
.13562 .27746 Mdot
.50016 .61782 Mdot
.5005 .61735 Mdot
.5016 .61587 Mdot
.50511 .61113 Mdot
.51628 .59606 Mdot
.55184 .54884 Mdot
.66379 .42242 Mdot
.98031 .40421 Mdot
.32628 .53513 Mdot
.46043 .57143 Mdot
.53583 .5385 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04863 Mdot
.3851 .14614 Mdot
.14864 .26476 Mdot
.72025 .11979 Mdot
.52644 .09539 Mdot
.37209 .20161 Mdot
.04588 .24356 Mdot
.6518 .12322 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50985 .60474 Mdot
.53136 .57585 Mdot
.59961 .48942 Mdot
.80771 .35147 Mdot
.23902 .49866 Mdot
.43216 .55967 Mdot
.52661 .53511 Mdot
.66077 .41016 Mdot
.99713 .40749 Mdot
.50003 .618 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50894 .60596 Mdot
.52848 .57969 Mdot
.59052 .50022 Mdot
.78115 .35549 Mdot
.20595 .49742 Mdot
.4011 .58332 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50376 .61296 Mdot
.51198 .60186 Mdot
.53814 .56685 Mdot
.62096 .4652 Mdot
.86826 .35654 Mdot
.29136 .49913 Mdot
.48375 .51417 Mdot
.6518 .39383 Mdot
.01456 .40732 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60665 Mdot
.52686 .58186 Mdot
.58539 .50645 Mdot
.76593 .35964 Mdot
.18402 .49469 Mdot
.38359 .59324 Mdot
.42372 .04324 Mdot
.35375 .16053 Mdot
.094 .2427 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .00179 Mdot
.49577 .00572 Mdot
.48652 .0182 Mdot
.45708 .05751 Mdot
.36403 .16878 Mdot
.09094 .24857 Mdot
.68875 .11182 Mdot
.50782 .10457 Mdot
.33861 .22983 Mdot
.96674 .19922 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50933 .60543 Mdot
.52972 .57804 Mdot
.59442 .49555 Mdot
.7926 .35326 Mdot
.22101 .49837 Mdot
.41463 .57377 Mdot
.48626 .58649 Mdot
.53729 .55223 Mdot
.64376 .43635 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00464 Mdot
.48905 .01479 Mdot
.46512 .04687 Mdot
.38928 .14144 Mdot
.16043 .26622 Mdot
.72967 .11988 Mdot
.5357 .08707 Mdot
.39482 .17763 Mdot
.1074 .26981 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00535 Mdot
.48739 .01702 Mdot
.45985 .05386 Mdot
.3727 .15968 Mdot
.11434 .25679 Mdot
.69884 .1168 Mdot
.50985 .10768 Mdot
.33562 .23438 Mdot
.95638 .19445 Mdot
.64175 .07973 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .0024 Mdot
.49435 .00763 Mdot
.482 .02428 Mdot
.44272 .07624 Mdot
.31936 .21 Mdot
.97957 .19111 Mdot
.67035 .06166 Mdot
.57057 .6164 Mdot
.57322 .55089 Mdot
.68186 .41666 Mdot
.50009 .61792 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50876 .6062 Mdot
.52791 .58045 Mdot
.58872 .5024 Mdot
.77582 .35679 Mdot
.19852 .49669 Mdot
.39487 .58721 Mdot
.44473 .01939 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51039 .60401 Mdot
.53308 .57357 Mdot
.60503 .48311 Mdot
.82334 .35096 Mdot
.25548 .49841 Mdot
.44903 .54486 Mdot
.56742 .48422 Mdot
.78394 .34001 Mdot
.23378 .48679 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00223 Mdot
.49474 .00711 Mdot
.48324 .02261 Mdot
.44665 .07115 Mdot
.33152 .19976 Mdot
.00831 .20746 Mdot
.67263 .077 Mdot
.54804 .03314 Mdot
.49442 .03832 Mdot
.43242 .0991 Mdot
.5 0 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48776 .01653 Mdot
.46101 .05231 Mdot
.37637 .15574 Mdot
.12437 .25966 Mdot
.70423 .11817 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49513 .00657 Mdot
.4845 .02092 Mdot
.45064 .06595 Mdot
.34394 .18853 Mdot
.03889 .22423 Mdot
.67609 .09231 Mdot
.52673 .06765 Mdot
.41727 .14094 Mdot
.18923 .27786 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50903 .60584 Mdot
.52876 .57932 Mdot
.5914 .49917 Mdot
.78372 .35493 Mdot
.20944 .49771 Mdot
.40413 .5813 Mdot
.46357 .61478 Mdot
.46882 .02547 Mdot
.42761 .09029 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50321 .61369 Mdot
.51024 .60421 Mdot
.53261 .57418 Mdot
.60357 .4848 Mdot
.81914 .35096 Mdot
.25127 .4985 Mdot
.44467 .54877 Mdot
.55674 .49727 Mdot
.75214 .34974 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00414 Mdot
.49025 .01317 Mdot
.46894 .04178 Mdot
.40134 .1275 Mdot
.19504 .26633 Mdot
.7641 .11937 Mdot
.57096 .05574 Mdot
.48077 .07352 Mdot
.36181 .18613 Mdot
.06065 .241 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51328 .60011 Mdot
.54229 .56136 Mdot
.63399 .45131 Mdot
.90375 .36742 Mdot
.30925 .50486 Mdot
.49237 .51194 Mdot
.66404 .3854 Mdot
.04045 .42249 Mdot
.35684 .53802 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48965 .01398 Mdot
.46704 .04432 Mdot
.39533 .1345 Mdot
.1777 .26708 Mdot
.74555 .1196 Mdot
.55204 .07221 Mdot
.43519 .13065 Mdot
.2238 .2762 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50913 .6057 Mdot
.52909 .57888 Mdot
.59243 .49793 Mdot
.78677 .3543 Mdot
.21349 .49798 Mdot
.40773 .57881 Mdot
.4712 .60536 Mdot
.49171 .61304 Mdot
.49979 .61324 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60694 Mdot
.52617 .58279 Mdot
.58319 .50913 Mdot
.75941 .36184 Mdot
.17393 .49285 Mdot
.37648 .59621 Mdot
.41179 .05582 Mdot
.32147 .18874 Mdot
.01608 .20362 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50321 .61369 Mdot
.51024 .60421 Mdot
.53261 .57419 Mdot
.60356 .48482 Mdot
.81911 .35096 Mdot
.25123 .4985 Mdot
.44464 .5488 Mdot
.55666 .49737 Mdot
.7519 .34984 Mdot
.50085 .61689 Mdot
.5027 .61439 Mdot
.5086 .60642 Mdot
.5274 .58114 Mdot
.58709 .50437 Mdot
.771 .35811 Mdot
.19157 .49582 Mdot
.38931 .59036 Mdot
.43409 .0317 Mdot
.3828 .13079 Mdot
.17117 .26061 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50705 .60851 Mdot
.52245 .58777 Mdot
.57142 .52375 Mdot
.72397 .37818 Mdot
.11207 .4737 Mdot
.34561 .59541 Mdot
.38222 .07686 Mdot
.25786 .22423 Mdot
.89505 .13383 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60207 Mdot
.53765 .56749 Mdot
.61943 .46687 Mdot
.86402 .3556 Mdot
.28865 .49881 Mdot
.48155 .51588 Mdot
.64685 .39825 Mdot
.00247 .40054 Mdot
.35438 .51747 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .0142 Mdot
.4665 .04503 Mdot
.39365 .13644 Mdot
.17288 .267 Mdot
.74086 .1197 Mdot
.54718 .0766 Mdot
.42323 .14504 Mdot
.18855 .28172 Mdot
.73271 .13505 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01163 Mdot
.47257 .03693 Mdot
.41281 .11378 Mdot
.22871 .26001 Mdot
.80801 .12215 Mdot
.61036 .02785 Mdot
.56529 .58704 Mdot
.61545 .48916 Mdot
.82398 .35726 Mdot
.50119 .61643 Mdot
.50379 .61292 Mdot
.51207 .60174 Mdot
.53844 .56645 Mdot
.6219 .46417 Mdot
.87087 .35716 Mdot
.29296 .49936 Mdot
.48498 .51327 Mdot
.65448 .39151 Mdot
.021 .41093 Mdot
.35611 .52688 Mdot
.50026 .61769 Mdot
.50082 .61693 Mdot
.5026 .61452 Mdot
.50828 .60685 Mdot
.52639 .5825 Mdot
.58388 .50828 Mdot
.76146 .36112 Mdot
.17716 .49348 Mdot
.37869 .59536 Mdot
.41537 .05214 Mdot
.331 .18098 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00271 Mdot
.49361 .00864 Mdot
.47963 .02746 Mdot
.4352 .08589 Mdot
.29622 .22726 Mdot
.9285 .16319 Mdot
.66446 .03644 Mdot
.6055 .56368 Mdot
.69344 .42535 Mdot
.00521 .43018 Mdot
.50082 .61693 Mdot
.5026 .61452 Mdot
.50828 .60685 Mdot
.52638 .58251 Mdot
.58386 .50831 Mdot
.76139 .36115 Mdot
.17704 .49346 Mdot
.37861 .5954 Mdot
.41524 .05228 Mdot
.33064 .18129 Mdot
.03731 .21556 Mdot
.50111 .61654 Mdot
.50352 .61327 Mdot
.51123 .60288 Mdot
.53575 .57001 Mdot
.61346 .47352 Mdot
.84729 .35269 Mdot
.27662 .49818 Mdot
.47056 .52531 Mdot
.62058 .42392 Mdot
.93467 .36504 Mdot
.34402 .48758 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .00221 Mdot
.49479 .00703 Mdot
.48342 .02238 Mdot
.44721 .07043 Mdot
.33325 .19825 Mdot
.01248 .2098 Mdot
.67301 .07919 Mdot
.54488 .03813 Mdot
.48318 .0537 Mdot
.3963 .14317 Mdot
.50061 .61721 Mdot
.50195 .61541 Mdot
.5062 .60966 Mdot
.51975 .5914 Mdot
.56284 .53465 Mdot
.69775 .39499 Mdot
.05865 .44813 Mdot
.33355 .57581 Mdot
.40187 .04309 Mdot
.33214 .17142 Mdot
.05477 .2212 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51135 .60271 Mdot
.53614 .56949 Mdot
.61469 .47213 Mdot
.85077 .35319 Mdot
.27931 .49824 Mdot
.47315 .52301 Mdot
.62689 .41745 Mdot
.95144 .37313 Mdot
.3477 .49373 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60499 Mdot
.53077 .57664 Mdot
.59775 .49161 Mdot
.8023 .35196 Mdot
.23282 .49865 Mdot
.42599 .56482 Mdot
.51209 .55362 Mdot
.61632 .45513 Mdot
.50082 .61692 Mdot
.50263 .61449 Mdot
.50837 .60673 Mdot
.52665 .58214 Mdot
.58473 .50724 Mdot
.76399 .36027 Mdot
.18107 .49419 Mdot
.38145 .59421 Mdot
.42 .04725 Mdot
.34354 .17004 Mdot
.06841 .23153 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49238 .01029 Mdot
.47574 .03269 Mdot
.42285 .10144 Mdot
.25872 .24876 Mdot
.85621 .13287 Mdot
.64122 .01847 Mdot
.61134 .5415 Mdot
.73517 .3946 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48887 .01503 Mdot
.46454 .04764 Mdot
.38746 .14348 Mdot
.1553 .26567 Mdot
.72544 .11988 Mdot
.53146 .0909 Mdot
.38438 .18891 Mdot
.07872 .25895 Mdot
.65974 .1345 Mdot
.50131 .61627 Mdot
.50417 .61241 Mdot
.51327 .60012 Mdot
.54226 .5614 Mdot
.6339 .4514 Mdot
.90353 .36734 Mdot
.30916 .50481 Mdot
.49237 .51188 Mdot
.66412 .3853 Mdot
.04069 .42261 Mdot
.35689 .53812 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61173 Mdot
.51486 .59797 Mdot
.54732 .55475 Mdot
.64971 .43554 Mdot
.94499 .38555 Mdot
.32115 .5186 Mdot
.48204 .53521 Mdot
.61604 .43692 Mdot
.90909 .35715 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .00299 Mdot
.49294 .00954 Mdot
.4775 .03033 Mdot
.42843 .09446 Mdot
.27558 .24011 Mdot
.88708 .14399 Mdot
.6541 .02243 Mdot
.61781 .54095 Mdot
.74254 .39357 Mdot
.50055 .61729 Mdot
.50175 .61567 Mdot
.50557 .61051 Mdot
.51774 .5941 Mdot
.55647 .54284 Mdot
.67813 .41009 Mdot
.01459 .4236 Mdot
.3292 .55325 Mdot
.43402 .61267 Mdot
.4427 .04662 Mdot
.36727 .15589 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49069 .01258 Mdot
.47033 .03992 Mdot
.40574 .12229 Mdot
.20787 .26469 Mdot
.77959 .11969 Mdot
.58592 .04385 Mdot
.51497 .03 Mdot
.46643 .06088 Mdot
.36792 .16975 Mdot
.50098 .61672 Mdot
.50311 .61383 Mdot
.5099 .60466 Mdot
.53155 .57561 Mdot
.6002 .48873 Mdot
.80941 .35135 Mdot
.24092 .49865 Mdot
.43408 .55803 Mdot
.53116 .52933 Mdot
.67469 .398 Mdot
.03072 .4263 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52556 .5836 Mdot
.58127 .51149 Mdot
.75366 .36399 Mdot
.16472 .49085 Mdot
.37051 .59809 Mdot
.40278 .06467 Mdot
.29814 .20552 Mdot
.9656 .17388 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51042 .60396 Mdot
.53319 .57341 Mdot
.60539 .4827 Mdot
.82436 .35097 Mdot
.25648 .49839 Mdot
.45007 .54393 Mdot
.56997 .48113 Mdot
.79149 .33857 Mdot
.24367 .486 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49074 .01251 Mdot
.47049 .03971 Mdot
.40623 .1217 Mdot
.20932 .26445 Mdot
.78143 .11977 Mdot
.58763 .04258 Mdot
.51874 .02524 Mdot
.4779 .04566 Mdot
.50114 .6165 Mdot
.50362 .61314 Mdot
.51153 .60246 Mdot
.53674 .5687 Mdot
.61656 .47005 Mdot
.85599 .35404 Mdot
.28315 .49839 Mdot
.47673 .51988 Mdot
.63554 .40888 Mdot
.97396 .38485 Mdot
.35127 .50352 Mdot
.5005 .61736 Mdot
.5016 .61588 Mdot
.50509 .61116 Mdot
.51621 .59616 Mdot
.55159 .54917 Mdot
.66302 .42311 Mdot
.97841 .40316 Mdot
.32608 .53417 Mdot
.46179 .56925 Mdot
.54072 .53191 Mdot
.68007 .39838 Mdot
.50055 .61729 Mdot
.50175 .61567 Mdot
.50558 .6105 Mdot
.51777 .59406 Mdot
.55656 .54272 Mdot
.67843 .40984 Mdot
.0153 .424 Mdot
.32925 .55363 Mdot
.43347 .61352 Mdot
.44077 .04914 Mdot
.36125 .16208 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49848 .00206 Mdot
.49514 .00656 Mdot
.48453 .02088 Mdot
.45075 .0658 Mdot
.34428 .18821 Mdot
.03975 .22468 Mdot
.67621 .09271 Mdot
.52621 .06853 Mdot
.41533 .14337 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49548 .0061 Mdot
.4856 .01943 Mdot
.45416 .06134 Mdot
.35491 .17797 Mdot
.06694 .23822 Mdot
.68149 .10413 Mdot
.513 .09209 Mdot
.364 .20338 Mdot
.03492 .23549 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00267 Mdot
.49371 .0085 Mdot
.47996 .02703 Mdot
.43623 .08458 Mdot
.29937 .22508 Mdot
.93518 .16664 Mdot
.66555 .03938 Mdot
.60183 .56933 Mdot
.68064 .43557 Mdot
.50106 .6166 Mdot
.50337 .61347 Mdot
.51075 .60352 Mdot
.53424 .57201 Mdot
.6087 .4789 Mdot
.83383 .35135 Mdot
.26534 .49821 Mdot
.45921 .53561 Mdot
.59258 .45454 Mdot
.85712 .33917 Mdot
.30833 .47692 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61708 Mdot
.50224 .615 Mdot
.50715 .60837 Mdot
.52279 .58732 Mdot
.57248 .52243 Mdot
.72718 .3764 Mdot
.11816 .47614 Mdot
.34774 .59673 Mdot
.38221 .0782 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.49599 .00541 Mdot
.48723 .01724 Mdot
.45934 .05452 Mdot
.37113 .16135 Mdot
.11006 .25544 Mdot
.69675 .11608 Mdot
.50892 .10782 Mdot
.33447 .23506 Mdot
.95413 .19312 Mdot
.64165 .07847 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50528 .6109 Mdot
.51683 .59533 Mdot
.55356 .54661 Mdot
.66914 .4177 Mdot
.99329 .41148 Mdot
.3275 .54187 Mdot
.45074 .58681 Mdot
.50125 .58565 Mdot
.55364 .53686 Mdot
.50127 .61632 Mdot
.50404 .61258 Mdot
.51286 .60068 Mdot
.54094 .56314 Mdot
.62976 .45574 Mdot
.89235 .36338 Mdot
.30439 .5024 Mdot
.49149 .51028 Mdot
.66584 .38289 Mdot
.04632 .42522 Mdot
.35829 .53991 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51113 .60301 Mdot
.53544 .57043 Mdot
.61246 .47463 Mdot
.84449 .35234 Mdot
.2744 .49815 Mdot
.46837 .52728 Mdot
.61522 .42955 Mdot
.92019 .35862 Mdot
.33992 .48324 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01037 Mdot
.47553 .03297 Mdot
.42219 .10226 Mdot
.25674 .24967 Mdot
.85276 .13183 Mdot
.63946 .01846 Mdot
.60959 .54274 Mdot
.73142 .3962 Mdot
.09035 .47553 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00245 Mdot
.49422 .00781 Mdot
.48158 .02485 Mdot
.44137 .07799 Mdot
.31518 .21333 Mdot
.97001 .18569 Mdot
.66956 .0566 Mdot
.57798 .60519 Mdot
.59876 .5194 Mdot
.75835 .37206 Mdot
.50104 .61663 Mdot
.50331 .61357 Mdot
.51054 .60381 Mdot
.53356 .57293 Mdot
.60654 .48137 Mdot
.82767 .35105 Mdot
.25966 .49832 Mdot
.45336 .54094 Mdot
.5781 .47141 Mdot
.81534 .33613 Mdot
.27148 .48233 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.51131 .60276 Mdot
.53601 .56966 Mdot
.61428 .47259 Mdot
.84962 .35302 Mdot
.27843 .49821 Mdot
.47231 .52375 Mdot
.62485 .41952 Mdot
.94606 .37046 Mdot
.34663 .49164 Mdot
.50011 .61789 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50353 .61326 Mdot
.51126 .60283 Mdot
.53585 .56988 Mdot
.61377 .47316 Mdot
.84819 .35281 Mdot
.27732 .49819 Mdot
.47124 .52471 Mdot
.62225 .4222 Mdot
.50097 .61672 Mdot
.5031 .61384 Mdot
.50989 .60468 Mdot
.5315 .57567 Mdot
.60004 .48892 Mdot
.80895 .35138 Mdot
.2404 .49866 Mdot
.43356 .55848 Mdot
.52992 .5309 Mdot
.6709 .40121 Mdot
.02174 .4213 Mdot
.49974 .00035 Mdot
.49916 .00113 Mdot
.49734 .0036 Mdot
.49151 .01146 Mdot
.47297 .0364 Mdot
.41407 .11225 Mdot
.23244 .2589 Mdot
.81354 .12296 Mdot
.61459 .02567 Mdot
.57306 .57832 Mdot
.63731 .46625 Mdot
.88291 .36723 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50717 .60835 Mdot
.52284 .58725 Mdot
.57264 .52223 Mdot
.72765 .37614 Mdot
.11905 .47649 Mdot
.34807 .59691 Mdot
.38225 .07834 Mdot
.25549 .2258 Mdot
.89014 .13185 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51484 .598 Mdot
.54726 .55483 Mdot
.64953 .43572 Mdot
.94451 .38532 Mdot
.32105 .5184 Mdot
.48226 .53481 Mdot
.61692 .43591 Mdot
.91161 .35811 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00491 Mdot
.48841 .01565 Mdot
.46309 .04956 Mdot
.3829 .14859 Mdot
.14248 .26372 Mdot
.71577 .11958 Mdot
.52228 .09899 Mdot
.36212 .21141 Mdot
.02005 .22995 Mdot
.64799 .11169 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00231 Mdot
.49455 .00737 Mdot
.48263 .02344 Mdot
.4447 .07368 Mdot
.32548 .20494 Mdot
.99388 .19927 Mdot
.67146 .06933 Mdot
.55928 .01563 Mdot
.53398 .6024 Mdot
.55928 .54871 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01453 Mdot
.46572 .04607 Mdot
.39118 .13927 Mdot
.16584 .26666 Mdot
.73437 .11983 Mdot
.54049 .0827 Mdot
.40668 .16434 Mdot
.14078 .27848 Mdot
.50065 .61716 Mdot
.50206 .61524 Mdot
.50658 .60915 Mdot
.52095 .58978 Mdot
.56667 .52976 Mdot
.7095 .38697 Mdot
.08337 .46077 Mdot
.33783 .58641 Mdot
.38899 .06315 Mdot
.28681 .20677 Mdot
.95226 .16317 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48973 .01387 Mdot
.4673 .04397 Mdot
.39615 .13356 Mdot
.18005 .26708 Mdot
.74791 .11955 Mdot
.55448 .07002 Mdot
.44118 .12332 Mdot
.24164 .27066 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50242 .61476 Mdot
.50772 .60761 Mdot
.52459 .5849 Mdot
.5782 .51529 Mdot
.74445 .36783 Mdot
.14929 .48681 Mdot
.36162 .59953 Mdot
.39155 .07443 Mdot
.27112 .22068 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.5116 .60237 Mdot
.53694 .56843 Mdot
.6172 .46934 Mdot
.8578 .35436 Mdot
.28443 .49847 Mdot
.47789 .5189 Mdot
.6383 .40622 Mdot
.98102 .38867 Mdot
.35214 .50686 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49249 .01015 Mdot
.47607 .03225 Mdot
.42389 .10015 Mdot
.26183 .24729 Mdot
.86171 .13462 Mdot
.64389 .01867 Mdot
.61367 .54006 Mdot
.73983 .39282 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.51221 .60155 Mdot
.53887 .56588 Mdot
.62326 .46269 Mdot
.87461 .35811 Mdot
.29518 .49975 Mdot
.48657 .51218 Mdot
.65785 .38868 Mdot
.02895 .41537 Mdot
.35686 .53089 Mdot
.5005 .61735 Mdot
.50161 .61586 Mdot
.50513 .61111 Mdot
.51633 .596 Mdot
.55198 .54866 Mdot
.66423 .42203 Mdot
.98138 .4048 Mdot
.32639 .53567 Mdot
.45966 .57267 Mdot
.53305 .54226 Mdot
.65566 .41988 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.4992 .00109 Mdot
.49744 .00346 Mdot
.49185 .01101 Mdot
.47403 .03498 Mdot
.41743 .10814 Mdot
.24245 .25552 Mdot
.82901 .12579 Mdot
.62548 .02114 Mdot
.59128 .55912 Mdot
.6866 .42313 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49696 .00411 Mdot
.4903 .0131 Mdot
.4691 .04157 Mdot
.40184 .12691 Mdot
.1965 .26619 Mdot
.76579 .11937 Mdot
.57263 .05435 Mdot
.48469 .06852 Mdot
.37382 .17362 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49347 .00882 Mdot
.4792 .02805 Mdot
.43381 .08766 Mdot
.29198 .2301 Mdot
.91968 .15875 Mdot
.66281 .0328 Mdot
.60973 .55698 Mdot
.70851 .41442 Mdot
.03796 .44928 Mdot
.50056 .61727 Mdot
.5018 .61561 Mdot
.50572 .6103 Mdot
.51823 .59344 Mdot
.55803 .54082 Mdot
.68296 .40618 Mdot
.02575 .42995 Mdot
.33009 .5592 Mdot
.42527 .00793 Mdot
.41245 .08506 Mdot
.27482 .23081 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00317 Mdot
.49251 .01011 Mdot
.47616 .03213 Mdot
.42416 .09981 Mdot
.26267 .24689 Mdot
.8632 .13511 Mdot
.64458 .01877 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49118 .01191 Mdot
.47191 .03782 Mdot
.41072 .11631 Mdot
.22253 .26166 Mdot
.79915 .1211 Mdot
.60321 .03198 Mdot
.55147 .60313 Mdot
.57558 .53567 Mdot
.70886 .39302 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.51271 .60088 Mdot
.54046 .56377 Mdot
.62827 .45732 Mdot
.8883 .36207 Mdot
.30247 .50167 Mdot
.49075 .51023 Mdot
.66518 .38315 Mdot
.04523 .42452 Mdot
.35835 .53918 Mdot
.50085 .61688 Mdot
.50271 .61437 Mdot
.50864 .60636 Mdot
.52752 .58097 Mdot
.58749 .50389 Mdot
.77218 .35778 Mdot
.19328 .49605 Mdot
.39066 .58963 Mdot
.43662 .02882 Mdot
.38999 .12287 Mdot
.19118 .26045 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50191 .61545 Mdot
.5061 .60979 Mdot
.51943 .59183 Mdot
.56183 .53594 Mdot
.69467 .39722 Mdot
.05196 .44454 Mdot
.33269 .57261 Mdot
.40618 .03661 Mdot
.34695 .15762 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51124 .60286 Mdot
.53578 .56997 Mdot
.61356 .4734 Mdot
.84758 .35273 Mdot
.27685 .49818 Mdot
.47078 .52511 Mdot
.62113 .42335 Mdot
.93614 .36572 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48936 .01436 Mdot
.46613 .04553 Mdot
.39246 .13781 Mdot
.16948 .26687 Mdot
.73768 .11977 Mdot
.54389 .07959 Mdot
.41511 .15461 Mdot
.16493 .28158 Mdot
.70933 .13883 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60223 Mdot
.53727 .568 Mdot
.61823 .46819 Mdot
.86068 .35491 Mdot
.28642 .49861 Mdot
.47965 .51742 Mdot
.64245 .40231 Mdot
.9915 .39443 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.5082 .60696 Mdot
.52612 .58285 Mdot
.58305 .50931 Mdot
.75897 .362 Mdot
.17325 .49271 Mdot
.37602 .59638 Mdot
.41106 .05657 Mdot
.31953 .19026 Mdot
.01169 .20108 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .6014 Mdot
.53924 .56539 Mdot
.62442 .46144 Mdot
.8778 .35896 Mdot
.29699 .50012 Mdot
.48778 .51144 Mdot
.66026 .38673 Mdot
.03451 .41847 Mdot
.3574 .53368 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.4875 .01688 Mdot
.46019 .05339 Mdot
.3738 .15851 Mdot
.11733 .25769 Mdot
.70038 .11726 Mdot
.51065 .10739 Mdot
.33688 .23349 Mdot
.95908 .19598 Mdot
.64198 .08113 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.48621 .01861 Mdot
.45609 .0588 Mdot
.36095 .17192 Mdot
.08277 .24524 Mdot
.68596 .10949 Mdot
.50881 .10132 Mdot
.34486 .22343 Mdot
.98334 .20802 Mdot
.49994 8e-05 Mdot
.49982 .00025 Mdot
.49941 .0008 Mdot
.49812 .00253 Mdot
.49402 .00807 Mdot
.48096 .02568 Mdot
.4394 .08051 Mdot
.30913 .21799 Mdot
.9564 .17808 Mdot
.66826 .04957 Mdot
.58805 .59008 Mdot
.63329 .48046 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.49229 .01041 Mdot
.47544 .03309 Mdot
.4219 .10263 Mdot
.25584 .25007 Mdot
.85121 .13137 Mdot
.63865 .01849 Mdot
.60873 .54338 Mdot
.72953 .39705 Mdot
.08708 .47381 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61239 Mdot
.51331 .60007 Mdot
.54238 .56125 Mdot
.63426 .45102 Mdot
.90449 .3677 Mdot
.30954 .50504 Mdot
.49236 .51212 Mdot
.66374 .38572 Mdot
.03962 .42208 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60898 Mdot
.52135 .58924 Mdot
.56794 .52815 Mdot
.71338 .38449 Mdot
.09125 .46453 Mdot
.33963 .58929 Mdot
.38613 .06804 Mdot
.27603 .21362 Mdot
.93039 .15113 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47739 .03047 Mdot
.42809 .09489 Mdot
.27455 .24069 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.5081 .60709 Mdot
.52581 .58327 Mdot
.58206 .51052 Mdot
.75602 .36308 Mdot
.16854 .49172 Mdot
.37292 .5974 Mdot
.4063 .0613 Mdot
.30712 .19944 Mdot
.98442 .18502 Mdot
.50053 .61731 Mdot
.5017 .61573 Mdot
.50543 .61071 Mdot
.51728 .59471 Mdot
.55502 .54472 Mdot
.67364 .41383 Mdot
.00404 .41758 Mdot
.32838 .54759 Mdot
.44236 .59987 Mdot
.47175 .00789 Mdot
.45898 .0455 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01603 Mdot
.46218 .05077 Mdot
.38004 .15175 Mdot
.13451 .26212 Mdot
.71039 .11912 Mdot
.51766 .10278 Mdot
.35135 .22141 Mdot
.9931 .21502 Mdot
.6452 .09832 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48908 .01474 Mdot
.46523 .04672 Mdot
.38964 .14102 Mdot
.16146 .26632 Mdot
.73055 .11988 Mdot
.53658 .08626 Mdot
.39701 .17521 Mdot
.11352 .27175 Mdot
.67382 .14078 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.49769 .00312 Mdot
.49265 .00993 Mdot
.47658 .03156 Mdot
.42552 .09811 Mdot
.26677 .24484 Mdot
.87061 .13767 Mdot
.64785 .01949 Mdot
.61632 .53903 Mdot
.74415 .39159 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00645 Mdot
.48478 .02054 Mdot
.45155 .06477 Mdot
.34675 .18588 Mdot
.04598 .22792 Mdot
.6772 .09554 Mdot
.52261 .07466 Mdot
.40181 .16002 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .0056 Mdot
.48679 .01783 Mdot
.45795 .05636 Mdot
.36675 .16596 Mdot
.09823 .25135 Mdot
.69154 .11364 Mdot
.50766 .10655 Mdot
.33527 .23342 Mdot
.95759 .19456 Mdot
.50027 .61767 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50882 .60612 Mdot
.5281 .58021 Mdot
.58931 .50169 Mdot
.77756 .35635 Mdot
.20097 .49695 Mdot
.39689 .58599 Mdot
.44873 .01467 Mdot
.42499 .08166 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00294 Mdot
.49306 .00938 Mdot
.47788 .02982 Mdot
.42964 .09294 Mdot
.27926 .238 Mdot
.89418 .14696 Mdot
.65639 .02422 Mdot
.6172 .54315 Mdot
.73837 .396 Mdot
.09762 .48093 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49237 .01031 Mdot
.47568 .03277 Mdot
.42266 .10168 Mdot
.25814 .24903 Mdot
.8552 .13256 Mdot
.64071 .01846 Mdot
.61085 .54184 Mdot
.50007 .61795 Mdot
.50021 .61775 Mdot
.50067 .61713 Mdot
.50213 .61516 Mdot
.50678 .60887 Mdot
.52161 .5889 Mdot
.56875 .52713 Mdot
.71585 .38296 Mdot
.0962 .46681 Mdot
.34088 .59095 Mdot
.3847 .0707 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49605 .00534 Mdot
.4874 .01701 Mdot
.45988 .05381 Mdot
.37281 .15957 Mdot
.11461 .25688 Mdot
.69898 .11685 Mdot
.50992 .10766 Mdot
.33572 .23432 Mdot
.95659 .19457 Mdot
.64177 .07984 Mdot
.50029 .61764 Mdot
.50094 .61677 Mdot
.50298 .614 Mdot
.50951 .60519 Mdot
.53029 .57728 Mdot
.59624 .4934 Mdot
.79791 .35249 Mdot
.22757 .49857 Mdot
.42087 .56894 Mdot
.50031 .56865 Mdot
.58022 .49739 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48862 .01536 Mdot
.46377 .04866 Mdot
.38503 .14621 Mdot
.14846 .26473 Mdot
.72012 .11978 Mdot
.52631 .0955 Mdot
.37178 .20192 Mdot
.04506 .24314 Mdot
.50103 .61664 Mdot
.50328 .6136 Mdot
.51045 .60392 Mdot
.53328 .57329 Mdot
.60567 .48237 Mdot
.82517 .35098 Mdot
.25727 .49837 Mdot
.45088 .54319 Mdot
.57199 .4787 Mdot
.79743 .33766 Mdot
.25108 .4852 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.49769 .00311 Mdot
.49265 .00992 Mdot
.4766 .03154 Mdot
.42557 .09805 Mdot
.26692 .24476 Mdot
.87089 .13777 Mdot
.64797 .01952 Mdot
.61638 .53903 Mdot
.74422 .39158 Mdot
.11063 .48608 Mdot
.50041 .61749 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54177 .56204 Mdot
.63237 .453 Mdot
.8994 .36582 Mdot
.30748 .50385 Mdot
.49224 .51104 Mdot
.66536 .38387 Mdot
.04424 .42436 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49548 .00611 Mdot
.48558 .01946 Mdot
.4541 .06143 Mdot
.35471 .17817 Mdot
.06642 .23797 Mdot
.68137 .10394 Mdot
.51319 .09172 Mdot
.36478 .20253 Mdot
.03708 .23659 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50132 .61625 Mdot
.50422 .61234 Mdot
.51343 .5999 Mdot
.54276 .56073 Mdot
.63548 .44977 Mdot
.90774 .36895 Mdot
.31077 .50587 Mdot
.49226 .51304 Mdot
.66215 .3874 Mdot
.50079 .61697 Mdot
.50251 .61465 Mdot
.50798 .60725 Mdot
.52543 .58377 Mdot
.58087 .51198 Mdot
.75247 .36446 Mdot
.16276 .49039 Mdot
.3693 .59838 Mdot
.4011 .06625 Mdot
.2939 .20822 Mdot
.957 .16883 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.49482 .007 Mdot
.48349 .02229 Mdot
.44743 .07014 Mdot
.33393 .19764 Mdot
.01414 .21073 Mdot
.67317 .08005 Mdot
.54364 .0401 Mdot
.47876 .05973 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50475 .61161 Mdot
.51514 .5976 Mdot
.5482 .55359 Mdot
.65248 .43289 Mdot
.95204 .3891 Mdot
.32246 .52162 Mdot
.47847 .54152 Mdot
.60228 .45309 Mdot
.86916 .345 Mdot
.5008 .61696 Mdot
.50253 .61461 Mdot
.50807 .60713 Mdot
.52572 .58339 Mdot
.58177 .51087 Mdot
.75516 .36341 Mdot
.16716 .49141 Mdot
.37204 .59766 Mdot
.405 .06257 Mdot
.30376 .20177 Mdot
.97728 .18079 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49829 .00231 Mdot
.49455 .00736 Mdot
.48264 .02342 Mdot
.44475 .07362 Mdot
.32564 .20481 Mdot
.99425 .19948 Mdot
.67148 .06953 Mdot
.55899 .01608 Mdot
.53297 .60377 Mdot
.55604 .55289 Mdot
.50037 .61754 Mdot
.50117 .61645 Mdot
.50373 .613 Mdot
.51187 .60201 Mdot
.5378 .5673 Mdot
.61989 .46637 Mdot
.86528 .35587 Mdot
.28947 .4989 Mdot
.48223 .51534 Mdot
.6484 .39685 Mdot
.00628 .40267 Mdot
.50126 .61633 Mdot
.50401 .61261 Mdot
.51278 .60078 Mdot
.5407 .56346 Mdot
.62901 .45653 Mdot
.89032 .36271 Mdot
.30344 .50202 Mdot
.49115 .51022 Mdot
.6656 .38294 Mdot
.04598 .42498 Mdot
.35835 .53963 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.5065 .60926 Mdot
.52069 .59013 Mdot
.56584 .53082 Mdot
.70696 .38863 Mdot
.07814 .4582 Mdot
.33676 .58436 Mdot
.39125 .05948 Mdot
.295 .20117 Mdot
.96951 .17307 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47456 .03427 Mdot
.41912 .10606 Mdot
.2475 .25359 Mdot
.83718 .12763 Mdot
.63067 .01966 Mdot
.59886 .55183 Mdot
.70599 .40989 Mdot
.04277 .44906 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49258 .01003 Mdot
.47636 .03186 Mdot
.4248 .09901 Mdot
.2646 .24594 Mdot
.86666 .13629 Mdot
.64615 .01906 Mdot
.61531 .5393 Mdot
.74271 .39191 Mdot
.10859 .48494 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50839 .6067 Mdot
.52672 .58205 Mdot
.58495 .50698 Mdot
.76465 .36006 Mdot
.18206 .49436 Mdot
.38217 .59389 Mdot
.42123 .04593 Mdot
.49991 .00012 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49104 .01211 Mdot
.47145 .03844 Mdot
.40926 .11808 Mdot
.2182 .26269 Mdot
.79317 .12054 Mdot
.59814 .03521 Mdot
.54116 .61552 Mdot
.54523 .57415 Mdot
.50027 .61767 Mdot
.50085 .61689 Mdot
.5027 .61439 Mdot
.5086 .60642 Mdot
.5274 .58114 Mdot
.5871 .50436 Mdot
.77103 .3581 Mdot
.19161 .49583 Mdot
.38935 .59034 Mdot
.43415 .03163 Mdot
.38297 .1306 Mdot
.50128 .61631 Mdot
.50407 .61253 Mdot
.51297 .60052 Mdot
.54132 .56265 Mdot
.63094 .4545 Mdot
.89555 .36447 Mdot
.30583 .50303 Mdot
.49191 .51052 Mdot
.66588 .38311 Mdot
.046 .42516 Mdot
.35808 .53997 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01603 Mdot
.46218 .05077 Mdot
.38004 .15174 Mdot
.13452 .26212 Mdot
.7104 .11912 Mdot
.51766 .10278 Mdot
.35136 .2214 Mdot
.99313 .21503 Mdot
.6452 .09833 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60457 Mdot
.53176 .57532 Mdot
.60088 .48793 Mdot
.81139 .35123 Mdot
.24309 .49863 Mdot
.43629 .55613 Mdot
.53644 .52264 Mdot
.69079 .38519 Mdot
.06753 .44594 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50185 .61554 Mdot
.50588 .61009 Mdot
.51873 .59276 Mdot
.55962 .53878 Mdot
.68786 .40234 Mdot
.03687 .43621 Mdot
.33107 .56502 Mdot
.41684 .02063 Mdot
.38346 .11926 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00468 Mdot
.48896 .0149 Mdot
.46485 .04723 Mdot
.38843 .1424 Mdot
.15802 .26598 Mdot
.72766 .11989 Mdot
.53367 .08891 Mdot
.38982 .18309 Mdot
.09358 .26492 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50515 .61108 Mdot
.5164 .5959 Mdot
.55222 .54835 Mdot
.66498 .42136 Mdot
.9832 .40581 Mdot
.32658 .53661 Mdot
.45833 .5748 Mdot
.52828 .54873 Mdot
.64042 .43479 Mdot
.50128 .61631 Mdot
.50407 .61253 Mdot
.51298 .60051 Mdot
.54132 .56263 Mdot
.63096 .45447 Mdot
.89561 .36449 Mdot
.30586 .50304 Mdot
.49192 .51053 Mdot
.66587 .38312 Mdot
.04598 .42515 Mdot
.35807 .53997 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49574 .00576 Mdot
.48642 .01833 Mdot
.45675 .05794 Mdot
.36301 .16982 Mdot
.08823 .24749 Mdot
.68778 .11108 Mdot
.50805 .10362 Mdot
.3404 .22799 Mdot
.9715 .20171 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50587 .6101 Mdot
.51871 .5928 Mdot
.55954 .53888 Mdot
.68763 .40252 Mdot
.03634 .43591 Mdot
.33102 .56475 Mdot
.41723 .02004 Mdot
.38481 .11774 Mdot
.1943 .25634 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48796 .01626 Mdot
.46164 .05148 Mdot
.37836 .15358 Mdot
.12985 .26105 Mdot
.70747 .11874 Mdot
.51535 .10452 Mdot
.34623 .22591 Mdot
.9807 .20806 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49427 .00775 Mdot
.48173 .02465 Mdot
.44185 .07736 Mdot
.31668 .21215 Mdot
.97342 .18762 Mdot
.66985 .05839 Mdot
.57536 .60914 Mdot
.58975 .53028 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51225 .60149 Mdot
.53902 .56568 Mdot
.62372 .4622 Mdot
.87587 .35844 Mdot
.2959 .49989 Mdot
.48707 .51187 Mdot
.65885 .38786 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49405 .00804 Mdot
.48103 .02559 Mdot
.43963 .08022 Mdot
.30982 .21747 Mdot
.95795 .17894 Mdot
.66842 .05035 Mdot
.58695 .59173 Mdot
.62951 .48449 Mdot
.84558 .36276 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.50492 .61138 Mdot
.51568 .59687 Mdot
.54992 .55135 Mdot
.65782 .42787 Mdot
.96552 .39615 Mdot
.32454 .52781 Mdot
.47052 .55498 Mdot
.57255 .49003 Mdot
.77966 .34504 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.51141 .60263 Mdot
.53633 .56924 Mdot
.61528 .47147 Mdot
.85243 .35344 Mdot
.28055 .49828 Mdot
.47432 .52198 Mdot
.62974 .41459 Mdot
.95892 .37693 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.4932 .00918 Mdot
.47834 .0292 Mdot
.43109 .09111 Mdot
.28368 .23536 Mdot
.90285 .15079 Mdot
.65887 .02678 Mdot
.61554 .54687 Mdot
.73069 .40041 Mdot
.08282 .47377 Mdot
.50037 .61753 Mdot
.50118 .61643 Mdot
.50377 .61293 Mdot
.51203 .6018 Mdot
.5383 .56663 Mdot
.62147 .46465 Mdot
.86965 .35687 Mdot
.29222 .49925 Mdot
.48442 .51368 Mdot
.65327 .39255 Mdot
.0181 .4093 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50559 .61048 Mdot
.51782 .59399 Mdot
.55673 .5425 Mdot
.67895 .40942 Mdot
.0165 .42468 Mdot
.32935 .55427 Mdot
.43252 .61497 Mdot
.43748 .05341 Mdot
.35107 .17219 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51054 .6038 Mdot
.53357 .57291 Mdot
.60657 .48134 Mdot
.82775 .35105 Mdot
.25974 .49832 Mdot
.45344 .54087 Mdot
.57829 .47118 Mdot
.81591 .33611 Mdot
.27208 .48223 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49615 .0052 Mdot
.48773 .01656 Mdot
.46093 .05242 Mdot
.37612 .15601 Mdot
.12369 .25948 Mdot
.70385 .11809 Mdot
.51277 .10627 Mdot
.34081 .23044 Mdot
.96795 .20093 Mdot
.64284 .08559 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.49281 .00972 Mdot
.47709 .03088 Mdot
.42711 .09612 Mdot
.27159 .24231 Mdot
.87953 .14099 Mdot
.65141 .02086 Mdot
.61765 .53949 Mdot
.74474 .39203 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00368 Mdot
.49131 .01173 Mdot
.47233 .03725 Mdot
.41206 .11469 Mdot
.22648 .26063 Mdot
.80477 .12174 Mdot
.6078 .02927 Mdot
.56044 .59261 Mdot
.60158 .5047 Mdot
.78496 .3607 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00444 Mdot
.48954 .01413 Mdot
.46667 .0448 Mdot
.39418 .13583 Mdot
.17439 .26704 Mdot
.74231 .11967 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49849 .00205 Mdot
.49518 .00652 Mdot
.48464 .02074 Mdot
.45108 .06538 Mdot
.3453 .18725 Mdot
.04233 .22603 Mdot
.67661 .0939 Mdot
.52468 .07111 Mdot
.40963 .15046 Mdot
.49995 7e-05 Mdot
.49982 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49433 .00765 Mdot
.48195 .02435 Mdot
.44255 .07646 Mdot
.31884 .21041 Mdot
.97838 .19044 Mdot
.67025 .06103 Mdot
.5715 .61498 Mdot
.57644 .54681 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48974 .01386 Mdot
.46731 .04396 Mdot
.39619 .13352 Mdot
.18015 .26708 Mdot
.74801 .11955 Mdot
.55458 .06993 Mdot
.44143 .12301 Mdot
.2424 .27039 Mdot
.80491 .13153 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51077 .60349 Mdot
.5343 .57194 Mdot
.60889 .47869 Mdot
.83435 .35139 Mdot
.2658 .4982 Mdot
.45969 .53518 Mdot
.59376 .4532 Mdot
.86046 .33979 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.51009 .6044 Mdot
.53215 .5748 Mdot
.60211 .48649 Mdot
.81495 .35107 Mdot
.24691 .49858 Mdot
.44019 .55273 Mdot
.54585 .51082 Mdot
.71933 .366 Mdot
.12712 .47171 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.49631 .00499 Mdot
.48823 .01589 Mdot
.46252 .05031 Mdot
.38112 .15056 Mdot
.13751 .26276 Mdot
.71236 .11932 Mdot
.5193 .10147 Mdot
.35512 .21799 Mdot
.00241 .22022 Mdot
.64609 .10302 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00265 Mdot
.49376 .00843 Mdot
.48011 .02682 Mdot
.43672 .08396 Mdot
.30087 .22403 Mdot
.93839 .16833 Mdot
.66603 .04085 Mdot
.59994 .5722 Mdot
.67411 .44111 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.51229 .60144 Mdot
.53914 .56553 Mdot
.62409 .46179 Mdot
.8769 .35871 Mdot
.29649 .50001 Mdot
.48745 .51163 Mdot
.65962 .38724 Mdot
.03305 .41766 Mdot
.50009 .61791 Mdot
.50028 .61765 Mdot
.5009 .61681 Mdot
.50288 .61414 Mdot
.50917 .60564 Mdot
.52922 .5787 Mdot
.59286 .49742 Mdot
.78801 .35407 Mdot
.21512 .49808 Mdot
.40921 .57776 Mdot
.47438 .6014 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01801 Mdot
.45753 .05691 Mdot
.36544 .16732 Mdot
.09471 .25003 Mdot
.69015 .11279 Mdot
.50765 .1057 Mdot
.33662 .23193 Mdot
.96134 .19644 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48837 .01571 Mdot
.46295 .04974 Mdot
.38246 .14907 Mdot
.14127 .2635 Mdot
.71492 .11952 Mdot
.52153 .09963 Mdot
.36032 .21312 Mdot
.01548 .22745 Mdot
.64745 .10949 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01053 Mdot
.47516 .03346 Mdot
.42102 .10372 Mdot
.2532 .25123 Mdot
.84669 .13009 Mdot
.6362 .01868 Mdot
.60597 .54557 Mdot
.72321 .40011 Mdot
.07582 .46777 Mdot
.5013 .61628 Mdot
.50413 .61246 Mdot
.51315 .60028 Mdot
.54188 .56191 Mdot
.63269 .45266 Mdot
.90028 .36614 Mdot
.30785 .50405 Mdot
.49229 .5112 Mdot
.66515 .38413 Mdot
.04362 .42406 Mdot
.35747 .53922 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46278 .04997 Mdot
.38194 .14965 Mdot
.1398 .26322 Mdot
.71391 .11945 Mdot
.52063 .10038 Mdot
.35822 .21511 Mdot
.01017 .22453 Mdot
.64688 .10689 Mdot
.4999 .00013 Mdot
.49969 .00041 Mdot
.49903 .00131 Mdot
.4969 .00419 Mdot
.49012 .01334 Mdot
.46853 .04233 Mdot
.40005 .12901 Mdot
.1913 .26664 Mdot
.75987 .11938 Mdot
.56672 .05932 Mdot
.47074 .08629 Mdot
.33112 .21508 Mdot
.5002 .61776 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50662 .6091 Mdot
.52108 .58962 Mdot
.56706 .52928 Mdot
.71067 .38621 Mdot
.08577 .46193 Mdot
.33835 .58732 Mdot
.38805 .06472 Mdot
.28333 .20904 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.5065 .60926 Mdot
.52069 .59013 Mdot
.56585 .53081 Mdot
.70697 .38863 Mdot
.07816 .45821 Mdot
.33676 .58437 Mdot
.39124 .0595 Mdot
.29497 .20119 Mdot
.96944 .17303 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00271 Mdot
.49361 .00864 Mdot
.47964 .02746 Mdot
.4352 .08589 Mdot
.29623 .22726 Mdot
.92852 .16319 Mdot
.66447 .03645 Mdot
.60549 .5637 Mdot
.69341 .42538 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50476 .61161 Mdot
.51516 .59757 Mdot
.54827 .55351 Mdot
.65268 .4327 Mdot
.95256 .38937 Mdot
.32255 .52184 Mdot
.47819 .542 Mdot
.60122 .45436 Mdot
.86605 .34433 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .61129 Mdot
.5159 .59657 Mdot
.55063 .55043 Mdot
.66002 .42584 Mdot
.97099 .3991 Mdot
.32524 .53046 Mdot
.46693 .56089 Mdot
.55939 .50711 Mdot
.73887 .35992 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50531 .61086 Mdot
.51692 .59521 Mdot
.55385 .54624 Mdot
.67002 .41693 Mdot
.9954 .41267 Mdot
.32768 .54299 Mdot
.44911 .58937 Mdot
.49549 .59355 Mdot
.5351 .56128 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01782 Mdot
.45796 .05635 Mdot
.36679 .16592 Mdot
.09833 .25138 Mdot
.69158 .11367 Mdot
.50766 .10657 Mdot
.33524 .23345 Mdot
.9575 .19452 Mdot
.64276 .07922 Mdot
.5 0 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01346 Mdot
.46825 .0427 Mdot
.39915 .13006 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00355 Mdot
.49164 .01129 Mdot
.47337 .03587 Mdot
.41533 .11071 Mdot
.23619 .2577 Mdot
.81922 .12389 Mdot
.61876 .02374 Mdot
.58035 .5704 Mdot
.65742 .44712 Mdot
.93396 .38764 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49337 .00896 Mdot
.47888 .02848 Mdot
.43279 .08895 Mdot
.28886 .23212 Mdot
.91327 .15564 Mdot
.66144 .03036 Mdot
.61231 .5527 Mdot
.71802 .40813 Mdot
.05766 .46042 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50203 .61529 Mdot
.50647 .6093 Mdot
.5206 .59026 Mdot
.56554 .5312 Mdot
.70604 .38925 Mdot
.07623 .45724 Mdot
.33639 .58358 Mdot
.39214 .05805 Mdot
.29821 .19888 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48981 .01377 Mdot
.46753 .04366 Mdot
.3969 .13269 Mdot
.1822 .26705 Mdot
.75011 .1195 Mdot
.55675 .068 Mdot
.44671 .11649 Mdot
.25823 .26384 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50546 .61066 Mdot
.51739 .59458 Mdot
.55534 .5443 Mdot
.67464 .41299 Mdot
.00642 .41893 Mdot
.32857 .54886 Mdot
.44049 .60276 Mdot
.4652 .01673 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48958 .01408 Mdot
.4668 .04463 Mdot
.39458 .13537 Mdot
.17555 .26706 Mdot
.74343 .11964 Mdot
.54984 .07419 Mdot
.42979 .13719 Mdot
.20782 .27958 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.5111 .60305 Mdot
.53535 .57055 Mdot
.61218 .47495 Mdot
.8437 .35224 Mdot
.27375 .49815 Mdot
.46773 .52786 Mdot
.5012 .61641 Mdot
.50383 .61285 Mdot
.51221 .60154 Mdot
.5389 .56584 Mdot
.62334 .4626 Mdot
.87483 .35817 Mdot
.29531 .49977 Mdot
.48666 .51212 Mdot
.65803 .38853 Mdot
.02938 .41561 Mdot
.3569 .5311 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.51131 .60276 Mdot
.53602 .56966 Mdot
.6143 .47257 Mdot
.84966 .35302 Mdot
.27846 .49821 Mdot
.47234 .52373 Mdot
.62492 .41945 Mdot
.94624 .37055 Mdot
.34667 .49171 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50928 .6055 Mdot
.52955 .57826 Mdot
.59391 .49617 Mdot
.79109 .35351 Mdot
.21909 .49829 Mdot
.41285 .5751 Mdot
.48232 .59145 Mdot
.52533 .56807 Mdot
.60617 .47678 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00378 Mdot
.49108 .01205 Mdot
.47157 .03827 Mdot
.40965 .1176 Mdot
.21938 .26242 Mdot
.79478 .12067 Mdot
.59952 .03431 Mdot
.54401 .61207 Mdot
.55366 .56326 Mdot
.64229 .44823 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51039 .604 Mdot
.5331 .57353 Mdot
.60511 .48302 Mdot
.82356 .35096 Mdot
.2557 .49841 Mdot
.44926 .54466 Mdot
.56798 .48354 Mdot
.7856 .33967 Mdot
.236 .48664 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50565 .6104 Mdot
.51801 .59374 Mdot
.55732 .54174 Mdot
.68077 .40794 Mdot
.02072 .42709 Mdot
.32968 .55652 Mdot
.4292 .00198 Mdot
.426 .06814 Mdot
.31575 .20327 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50958 .60509 Mdot
.53052 .57697 Mdot
.59696 .49255 Mdot
.8 .35222 Mdot
.23009 .49862 Mdot
.42331 .56699 Mdot
.50591 .56152 Mdot
.59736 .47679 Mdot
.8259 .3457 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00453 Mdot
.48931 .01444 Mdot
.46594 .04577 Mdot
.39189 .13846 Mdot
.16785 .26679 Mdot
.73618 .1198 Mdot
.54234 .081 Mdot
.41128 .15906 Mdot
.15391 .28052 Mdot
.70001 .14019 Mdot
.5 .61803 Mdot
.50001 .61802 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50041 .61749 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54175 .56207 Mdot
.6323 .45306 Mdot
.89923 .36576 Mdot
.49969 .00041 Mdot
.49903 .00131 Mdot
.4969 .00419 Mdot
.49012 .01334 Mdot
.46854 .04232 Mdot
.40007 .12899 Mdot
.19136 .26663 Mdot
.75994 .11937 Mdot
.56679 .05926 Mdot
.47091 .08608 Mdot
.33163 .21464 Mdot
.98434 .20014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .0044 Mdot
.48963 .014 Mdot
.46698 .0444 Mdot
.39514 .13472 Mdot
.17716 .26708 Mdot
.74501 .11961 Mdot
.55148 .07272 Mdot
.43382 .13232 Mdot
.21973 .2772 Mdot
.77121 .13096 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50477 .61159 Mdot
.51519 .59753 Mdot
.54836 .55339 Mdot
.65296 .43243 Mdot
.95328 .38973 Mdot
.32268 .52216 Mdot
.4778 .54267 Mdot
.59974 .45615 Mdot
.86168 .34346 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60624 Mdot
.52783 .58057 Mdot
.58844 .50274 Mdot
.77499 .35701 Mdot
.19734 .49655 Mdot
.39391 .58778 Mdot
.44285 .02159 Mdot
.40791 .10228 Mdot
.24243 .24966 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.49549 .00609 Mdot
.48564 .01939 Mdot
.45427 .0612 Mdot
.35524 .17765 Mdot
.06779 .23862 Mdot
.68171 .10445 Mdot
.51271 .09268 Mdot
.36275 .20473 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49291 .00957 Mdot
.47743 .03042 Mdot
.4282 .09475 Mdot
.27489 .2405 Mdot
.88576 .14345 Mdot
.65365 .02213 Mdot
.61784 .54063 Mdot
.74309 .39322 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50452 .61193 Mdot
.51439 .59861 Mdot
.54582 .55672 Mdot
.64502 .44013 Mdot
.93288 .37973 Mdot
.31846 .51384 Mdot
.48706 .52582 Mdot
.63626 .41437 Mdot
.96579 .3829 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00636 Mdot
.485 .02025 Mdot
.45223 .06387 Mdot
.34888 .18384 Mdot
.05142 .23069 Mdot
.67816 .09792 Mdot
.51972 .07968 Mdot
.3908 .17316 Mdot
.11063 .26765 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47927 .02796 Mdot
.43403 .08738 Mdot
.29266 .22965 Mdot
.92107 .15944 Mdot
.66308 .03336 Mdot
.60911 .55798 Mdot
.70628 .41597 Mdot
.03323 .44655 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49716 .00384 Mdot
.49095 .01222 Mdot
.47118 .03879 Mdot
.40842 .11908 Mdot
.21575 .26322 Mdot
.78986 .12028 Mdot
.59524 .03716 Mdot
.53512 .00486 Mdot
.52726 .59774 Mdot
.5601 .54334 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46507 .04693 Mdot
.38914 .14159 Mdot
.16003 .26619 Mdot
.72933 .11988 Mdot
.53536 .08737 Mdot
.39398 .17855 Mdot
.10508 .26904 Mdot
.66977 .13985 Mdot
.50118 .61644 Mdot
.50375 .61297 Mdot
.51194 .60191 Mdot
.53804 .56698 Mdot
.62065 .46554 Mdot
.86738 .35634 Mdot
.29081 .49906 Mdot
.48332 .5145 Mdot
.65084 .39468 Mdot
.01223 .40601 Mdot
.3553 .52242 Mdot
.50052 .61734 Mdot
.50164 .61581 Mdot
.50523 .61096 Mdot
.51667 .59554 Mdot
.55308 .54724 Mdot
.66763 .41902 Mdot
.98964 .40942 Mdot
.32718 .53995 Mdot
.45352 .58244 Mdot
.51112 .57214 Mdot
.58538 .49672 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50768 .60766 Mdot
.52446 .58507 Mdot
.57779 .51579 Mdot
.74322 .36838 Mdot
.14716 .48618 Mdot
.3605 .59957 Mdot
.39037 .07533 Mdot
.26849 .22188 Mdot
.90948 .14241 Mdot
.50021 .61775 Mdot
.50067 .61712 Mdot
.50214 .61514 Mdot
.50683 .60881 Mdot
.52176 .5887 Mdot
.56923 .52652 Mdot
.7173 .38208 Mdot
.09908 .46811 Mdot
.34166 .59186 Mdot
.38401 .07209 Mdot
.26736 .21876 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51318 .60024 Mdot
.54198 .56177 Mdot
.63303 .45231 Mdot
.90117 .36647 Mdot
.30822 .50425 Mdot
.49232 .51137 Mdot
.66491 .38441 Mdot
.04292 .42372 Mdot
.35733 .53897 Mdot
.50073 .61705 Mdot
.50232 .61491 Mdot
.50738 .60807 Mdot
.5235 .58636 Mdot
.57475 .51958 Mdot
.73405 .37278 Mdot
.13089 .48089 Mdot
.35279 .59872 Mdot
.38403 .07893 Mdot
.25631 .22636 Mdot
.89005 .13235 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51185 .60203 Mdot
.53775 .56736 Mdot
.61975 .46653 Mdot
.86489 .35579 Mdot
.28922 .49887 Mdot
.48202 .5155 Mdot
.64793 .39728 Mdot
.00512 .40202 Mdot
.35464 .51881 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00322 Mdot
.4924 .01027 Mdot
.47579 .03263 Mdot
.423 .10126 Mdot
.25915 .24856 Mdot
.85697 .13311 Mdot
.6416 .01848 Mdot
.61169 .54126 Mdot
.73591 .3943 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48934 .0144 Mdot
.46604 .04564 Mdot
.39218 .13812 Mdot
.1687 .26683 Mdot
.73695 .11978 Mdot
.54314 .08027 Mdot
.41326 .15677 Mdot
.1596 .28115 Mdot
.7047 .13954 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49632 .00497 Mdot
.48827 .01584 Mdot
.46265 .05015 Mdot
.3815 .15013 Mdot
.13859 .26298 Mdot
.71308 .11938 Mdot
.51992 .10097 Mdot
.35655 .21666 Mdot
.00599 .22221 Mdot
.64644 .10481 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00474 Mdot
.48882 .0151 Mdot
.46439 .04784 Mdot
.38699 .14402 Mdot
.15396 .26551 Mdot
.72436 .11987 Mdot
.5304 .09186 Mdot
.38178 .19165 Mdot
.07168 .25588 Mdot
.65766 .13248 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00218 Mdot
.49485 .00695 Mdot
.4836 .02213 Mdot
.4478 .06966 Mdot
.33509 .19661 Mdot
.01697 .21231 Mdot
.67344 .08151 Mdot
.54155 .04343 Mdot
.47128 .06991 Mdot
.35817 .18466 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50877 .6062 Mdot
.52792 .58044 Mdot
.58874 .50237 Mdot
.77589 .35677 Mdot
.19862 .4967 Mdot
.39495 .58717 Mdot
.44489 .01921 Mdot
.41381 .09526 Mdot
.50114 .61649 Mdot
.50364 .61311 Mdot
.5116 .60237 Mdot
.53695 .56842 Mdot
.61723 .46931 Mdot
.85787 .35438 Mdot
.28448 .49847 Mdot
.47794 .51886 Mdot
.63841 .40612 Mdot
.9813 .38882 Mdot
.35217 .50699 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51264 .60097 Mdot
.54025 .56405 Mdot
.62761 .45802 Mdot
.88651 .3615 Mdot
.30158 .50137 Mdot
.49036 .5103 Mdot
.66467 .38346 Mdot
.04422 .42393 Mdot
.35829 .53862 Mdot
.50035 .61756 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51128 .60281 Mdot
.53592 .56979 Mdot
.61398 .47293 Mdot
.84876 .35289 Mdot
.27777 .4982 Mdot
.47167 .52432 Mdot
.62329 .42112 Mdot
.94191 .36845 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50747 .60794 Mdot
.5238 .58597 Mdot
.57568 .51842 Mdot
.73686 .37138 Mdot
.13596 .48264 Mdot
.35503 .5992 Mdot
.3855 .07839 Mdot
.25866 .22572 Mdot
.89345 .13415 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00599 Mdot
.48588 .01907 Mdot
.45503 .0602 Mdot
.35761 .17529 Mdot
.074 .24144 Mdot
.68334 .10665 Mdot
.51078 .09666 Mdot
.50014 .61785 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50449 .61196 Mdot
.51432 .59871 Mdot
.54559 .55702 Mdot
.64432 .44082 Mdot
.93106 .37889 Mdot
.31801 .51317 Mdot
.48768 .52458 Mdot
.6389 .41155 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.51248 .60119 Mdot
.53973 .56473 Mdot
.62597 .45977 Mdot
.88205 .36016 Mdot
.2993 .50069 Mdot
.48917 .51072 Mdot
.66281 .38477 Mdot
.04025 .42168 Mdot
.35795 .53656 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00172 Mdot
.49594 .00549 Mdot
.48706 .01747 Mdot
.45878 .05526 Mdot
.36937 .16321 Mdot
.1053 .25386 Mdot
.69455 .11518 Mdot
.50818 .1076 Mdot
.33409 .23502 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49262 .00997 Mdot
.47648 .0317 Mdot
.4252 .09852 Mdot
.26579 .24534 Mdot
.86882 .13704 Mdot
.64709 .01928 Mdot
.6159 .53912 Mdot
.74359 .39169 Mdot
.10982 .48561 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.497 .00405 Mdot
.49045 .01289 Mdot
.46959 .04091 Mdot
.40339 .12508 Mdot
.20101 .26569 Mdot
.77111 .11944 Mdot
.57786 .05011 Mdot
.49678 .05309 Mdot
.41088 .13145 Mdot
.50098 .6167 Mdot
.50314 .6138 Mdot
.50999 .60454 Mdot
.53182 .57524 Mdot
.60106 .48772 Mdot
.81191 .3512 Mdot
.24366 .49863 Mdot
.43686 .55564 Mdot
.53783 .5209 Mdot
.69499 .38208 Mdot
.07678 .45053 Mdot
.50002 .618 Mdot
.50007 .61793 Mdot
.50023 .61772 Mdot
.50075 .61702 Mdot
.50238 .61481 Mdot
.5076 .60777 Mdot
.5242 .58543 Mdot
.57696 .51683 Mdot
.74071 .36954 Mdot
.14279 .48485 Mdot
.35828 .59955 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.5085 .60655 Mdot
.52709 .58155 Mdot
.58612 .50555 Mdot
.76811 .35896 Mdot
.1873 .49521 Mdot
.38604 .59206 Mdot
.42807 .03846 Mdot
.50027 .61766 Mdot
.50087 .61686 Mdot
.50278 .61428 Mdot
.50885 .60608 Mdot
.5282 .58007 Mdot
.58963 .5013 Mdot
.7785 .35612 Mdot
.20229 .49708 Mdot
.39799 .58531 Mdot
.45094 .01204 Mdot
.43146 .07363 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49439 .00758 Mdot
.48213 .0241 Mdot
.44314 .07571 Mdot
.32064 .20895 Mdot
.98255 .19281 Mdot
.67058 .06325 Mdot
.56823 .00192 Mdot
.56513 .56125 Mdot
.657 .43818 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.5005 .61735 Mdot
.50161 .61586 Mdot
.50512 .61111 Mdot
.51632 .59601 Mdot
.55196 .54868 Mdot
.66417 .42208 Mdot
.98124 .40473 Mdot
.32638 .5356 Mdot
.45976 .57251 Mdot
.50068 .61711 Mdot
.50217 .6151 Mdot
.50691 .60869 Mdot
.52203 .58834 Mdot
.57007 .52546 Mdot
.71986 .38055 Mdot
.10412 .47034 Mdot
.3431 .59335 Mdot
.38304 .07424 Mdot
.26292 .2213 Mdot
.90485 .13825 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50438 .61212 Mdot
.51395 .5992 Mdot
.54442 .55856 Mdot
.64065 .44449 Mdot
.92145 .37459 Mdot
.31535 .50987 Mdot
.49036 .5188 Mdot
.65092 .39894 Mdot
.00541 .40396 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51023 .60422 Mdot
.53259 .57422 Mdot
.60349 .4849 Mdot
.81891 .35097 Mdot
.25104 .49851 Mdot
.44443 .54898 Mdot
.55616 .49799 Mdot
.7504 .35044 Mdot
.18337 .48525 Mdot
.49993 .0001 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49272 .00984 Mdot
.47679 .03128 Mdot
.42619 .09728 Mdot
.26879 .2438 Mdot
.87432 .13902 Mdot
.64938 .01999 Mdot
.61703 .53905 Mdot
.74483 .39158 Mdot
.50051 .61734 Mdot
.50163 .61583 Mdot
.50519 .61102 Mdot
.51653 .59572 Mdot
.55263 .54782 Mdot
.66624 .42024 Mdot
.98628 .40754 Mdot
.32687 .5382 Mdot
.45604 .57844 Mdot
.52011 .55984 Mdot
.61427 .46278 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61519 Mdot
.50671 .60897 Mdot
.52137 .58922 Mdot
.568 .52808 Mdot
.71356 .38438 Mdot
.09161 .4647 Mdot
.33971 .58942 Mdot
.38602 .06825 Mdot
.27559 .21389 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61543 Mdot
.50613 .60975 Mdot
.51954 .59168 Mdot
.56217 .5355 Mdot
.69571 .39646 Mdot
.05422 .44576 Mdot
.33297 .57371 Mdot
.40469 .03884 Mdot
.34184 .1625 Mdot
.50083 .61691 Mdot
.50264 .61446 Mdot
.50842 .60667 Mdot
.52681 .58193 Mdot
.58523 .50664 Mdot
.76547 .35979 Mdot
.18332 .49457 Mdot
.38308 .59347 Mdot
.42282 .04422 Mdot
.35126 .1629 Mdot
.08769 .24014 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50704 .60852 Mdot
.52243 .5878 Mdot
.57135 .52384 Mdot
.72376 .3783 Mdot
.11165 .47352 Mdot
.34547 .59531 Mdot
.38224 .07675 Mdot
.25806 .2241 Mdot
.89546 .13401 Mdot
.50029 .61765 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60547 Mdot
.52962 .57817 Mdot
.59412 .49591 Mdot
.79172 .35341 Mdot
.2199 .49832 Mdot
.4136 .57454 Mdot
.48397 .58938 Mdot
.53033 .56143 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51184 .60205 Mdot
.5377 .56742 Mdot
.6196 .46669 Mdot
.86447 .35569 Mdot
.28894 .49884 Mdot
.4818 .51568 Mdot
.64741 .39774 Mdot
.00384 .40131 Mdot
.35452 .51817 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49607 .0053 Mdot
.48749 .01689 Mdot
.46017 .05343 Mdot
.37373 .15859 Mdot
.11713 .25763 Mdot
.70027 .11723 Mdot
.51059 .10742 Mdot
.33678 .23357 Mdot
.95887 .19586 Mdot
.64196 .08102 Mdot
.49982 .00025 Mdot
.49941 .0008 Mdot
.49812 .00253 Mdot
.49402 .00807 Mdot
.48096 .02568 Mdot
.43941 .08051 Mdot
.30914 .21798 Mdot
.95643 .1781 Mdot
.66826 .04959 Mdot
.58803 .59011 Mdot
.63321 .48054 Mdot
.85568 .36435 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48805 .01613 Mdot
.46196 .05106 Mdot
.37934 .15251 Mdot
.13257 .26168 Mdot
.70916 .11897 Mdot
.51666 .10355 Mdot
.34912 .2234 Mdot
.98765 .21196 Mdot
.64469 .09555 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51282 .60073 Mdot
.54081 .56331 Mdot
.62935 .45617 Mdot
.89126 .36302 Mdot
.30388 .50219 Mdot
.49132 .51024 Mdot
.66573 .3829 Mdot
.04619 .42512 Mdot
.35833 .53978 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50708 .60847 Mdot
.52255 .58764 Mdot
.57174 .52336 Mdot
.72492 .37765 Mdot
.11387 .47443 Mdot
.34622 .59582 Mdot
.38216 .07732 Mdot
.25705 .22472 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01627 Mdot
.46163 .05149 Mdot
.37832 .15362 Mdot
.12975 .26102 Mdot
.70741 .11873 Mdot
.51531 .10456 Mdot
.34613 .226 Mdot
.98046 .20793 Mdot
.64403 .0919 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.5045 .61195 Mdot
.51435 .59866 Mdot
.5457 .55687 Mdot
.64466 .44049 Mdot
.93193 .37929 Mdot
.31823 .51349 Mdot
.48739 .52517 Mdot
.63765 .41288 Mdot
.96959 .38486 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49666 .00451 Mdot
.48937 .01435 Mdot
.46615 .0455 Mdot
.39253 .13773 Mdot
.16969 .26688 Mdot
.73787 .11976 Mdot
.54408 .07942 Mdot
.41558 .15406 Mdot
.16631 .28167 Mdot
.71056 .13863 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48853 .01548 Mdot
.46348 .04904 Mdot
.38413 .14722 Mdot
.14592 .26432 Mdot
.71823 .11971 Mdot
.52454 .09705 Mdot
.36751 .20618 Mdot
.03391 .23737 Mdot
.64983 .1181 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61024 Mdot
.51839 .59322 Mdot
.55853 .54018 Mdot
.68451 .40495 Mdot
.02929 .43195 Mdot
.33038 .56107 Mdot
.42255 .01204 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49632 .00497 Mdot
.48827 .01584 Mdot
.46265 .05014 Mdot
.38152 .15011 Mdot
.13863 .26298 Mdot
.71311 .11939 Mdot
.51994 .10095 Mdot
.35661 .21661 Mdot
.00612 .22228 Mdot
.64646 .10488 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60664 Mdot
.52686 .58186 Mdot
.5854 .50643 Mdot
.76597 .35963 Mdot
.18408 .4947 Mdot
.38364 .59321 Mdot
.4238 .04316 Mdot
.35397 .16032 Mdot
.09456 .24292 Mdot
.50015 .61784 Mdot
.50047 .61741 Mdot
.50148 .61603 Mdot
.50472 .61165 Mdot
.51505 .59773 Mdot
.5479 .55398 Mdot
.65154 .43379 Mdot
.94966 .38789 Mdot
.32204 .52058 Mdot
.47973 .53932 Mdot
.60709 .44737 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60843 Mdot
.52265 .58751 Mdot
.57204 .52299 Mdot
.72583 .37714 Mdot
.1156 .47513 Mdot
.34682 .5962 Mdot
.38215 .07771 Mdot
.25641 .22514 Mdot
.89213 .13262 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49155 .01141 Mdot
.47308 .03625 Mdot
.41443 .11181 Mdot
.23353 .25856 Mdot
.81517 .12321 Mdot
.61581 .02508 Mdot
.57522 .57595 Mdot
.64332 .46032 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51166 .6023 Mdot
.53712 .5682 Mdot
.61776 .46872 Mdot
.85936 .35465 Mdot
.28551 .49854 Mdot
.47886 .51808 Mdot
.64058 .40406 Mdot
.98681 .39184 Mdot
.3528 .50966 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49696 .00411 Mdot
.49031 .01308 Mdot
.46915 .0415 Mdot
.402 .12672 Mdot
.19696 .26615 Mdot
.76633 .11938 Mdot
.57317 .05391 Mdot
.48594 .06692 Mdot
.37766 .16949 Mdot
.10341 .25876 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48847 .01557 Mdot
.46326 .04933 Mdot
.38345 .14798 Mdot
.14402 .264 Mdot
.71686 .11964 Mdot
.52327 .09814 Mdot
.36448 .20914 Mdot
.02608 .23321 Mdot
.64874 .11453 Mdot
.50086 .61688 Mdot
.50273 .61435 Mdot
.5087 .60629 Mdot
.5277 .58074 Mdot
.58805 .50321 Mdot
.77383 .35732 Mdot
.19567 .49635 Mdot
.39256 .58856 Mdot
.44024 .02463 Mdot
.40038 .11107 Mdot
.22066 .25612 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48814 .01602 Mdot
.46222 .05071 Mdot
.38017 .1516 Mdot
.13488 .2622 Mdot
.71063 .11914 Mdot
.51785 .10263 Mdot
.3518 .22101 Mdot
.9942 .21563 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00197 Mdot
.49535 .00628 Mdot
.48519 .01999 Mdot
.45285 .06306 Mdot
.35082 .18198 Mdot
.05636 .23315 Mdot
.67912 .09999 Mdot
.51733 .08396 Mdot
.38148 .18396 Mdot
.08382 .25813 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02202 Mdot
.44805 .06933 Mdot
.33588 .19591 Mdot
.0189 .21339 Mdot
.67363 .0825 Mdot
.54014 .04568 Mdot
.46623 .07675 Mdot
.34204 .2003 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01037 Mdot
.47555 .03295 Mdot
.42223 .10221 Mdot
.25685 .24962 Mdot
.85295 .13188 Mdot
.63956 .01846 Mdot
.60969 .54266 Mdot
.73164 .3961 Mdot
.09074 .47574 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00907 Mdot
.4786 .02885 Mdot
.43192 .09006 Mdot
.2862 .23381 Mdot
.90789 .1531 Mdot
.66016 .02845 Mdot
.61414 .54951 Mdot
.72502 .40378 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49824 .00237 Mdot
.49441 .00756 Mdot
.48218 .02405 Mdot
.44327 .07554 Mdot
.32105 .20862 Mdot
.98349 .19334 Mdot
.67065 .06376 Mdot
.56749 .00305 Mdot
.56256 .56457 Mdot
.64906 .44572 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49605 .00534 Mdot
.4874 .01701 Mdot
.45988 .05381 Mdot
.37281 .15957 Mdot
.11462 .25688 Mdot
.69898 .11685 Mdot
.50992 .10766 Mdot
.33572 .23432 Mdot
.95659 .19457 Mdot
.64177 .07985 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49082 .01241 Mdot
.47074 .03938 Mdot
.40703 .12074 Mdot
.21167 .26403 Mdot
.78446 .11993 Mdot
.59041 .04055 Mdot
.5248 .01765 Mdot
.49625 .02112 Mdot
.46208 .05594 Mdot
.49995 6e-05 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49532 .00633 Mdot
.48508 .02014 Mdot
.45249 .06354 Mdot
.34968 .18308 Mdot
.05346 .23171 Mdot
.67855 .09878 Mdot
.51871 .08148 Mdot
.38687 .17774 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50564 .61042 Mdot
.51796 .5938 Mdot
.55717 .54194 Mdot
.68029 .40832 Mdot
.01961 .42646 Mdot
.32959 .55593 Mdot
.43007 .00066 Mdot
.429 .06432 Mdot
.32494 .19581 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.5129 .60062 Mdot
.54109 .56295 Mdot
.63022 .45526 Mdot
.89359 .3638 Mdot
.30495 .50264 Mdot
.49167 .51035 Mdot
.66591 .38293 Mdot
.04631 .42526 Mdot
.35823 .53999 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.49761 .00324 Mdot
.49237 .01031 Mdot
.4757 .03275 Mdot
.42271 .10162 Mdot
.25829 .24896 Mdot
.85546 .13264 Mdot
.64084 .01846 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.4957 .0058 Mdot
.48631 .01848 Mdot
.45642 .05837 Mdot
.36197 .17089 Mdot
.08546 .24636 Mdot
.68684 .11029 Mdot
.50839 .10251 Mdot
.34252 .22583 Mdot
.97712 .20469 Mdot
.50036 .61755 Mdot
.50115 .61649 Mdot
.50365 .6131 Mdot
.51163 .60233 Mdot
.53704 .5683 Mdot
.61752 .46899 Mdot
.85868 .35453 Mdot
.28504 .49851 Mdot
.47844 .51843 Mdot
.6396 .40498 Mdot
.98433 .39048 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01536 Mdot
.46378 .04865 Mdot
.38506 .14618 Mdot
.14853 .26474 Mdot
.72017 .11978 Mdot
.52636 .09546 Mdot
.3719 .2018 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49375 .00845 Mdot
.48008 .02686 Mdot
.43662 .08407 Mdot
.30059 .22423 Mdot
.93779 .16801 Mdot
.66594 .04057 Mdot
.6003 .57165 Mdot
.67536 .44003 Mdot
.50007 .61794 Mdot
.50023 .61773 Mdot
.50072 .61705 Mdot
.50231 .61491 Mdot
.50736 .60809 Mdot
.52344 .58644 Mdot
.57456 .51982 Mdot
.73348 .37307 Mdot
.12984 .48052 Mdot
.35234 .5986 Mdot
.38378 .07898 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00479 Mdot
.48871 .01524 Mdot
.46406 .04828 Mdot
.38594 .14519 Mdot
.15102 .26511 Mdot
.72206 .11983 Mdot
.52817 .09386 Mdot
.3763 .19733 Mdot
.05701 .24906 Mdot
.65402 .12754 Mdot
.50051 .61734 Mdot
.50164 .61582 Mdot
.50523 .61098 Mdot
.51665 .59557 Mdot
.55299 .54735 Mdot
.66737 .41925 Mdot
.98901 .40907 Mdot
.32713 .53962 Mdot
.454 .58168 Mdot
.51282 .56981 Mdot
.59084 .4901 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.49599 .00541 Mdot
.48724 .01723 Mdot
.45935 .0545 Mdot
.37116 .16132 Mdot
.11014 .25547 Mdot
.69678 .1161 Mdot
.50894 .10782 Mdot
.33448 .23506 Mdot
.95415 .19314 Mdot
.64164 .07849 Mdot
.50025 .6177 Mdot
.50079 .61696 Mdot
.50252 .61462 Mdot
.50804 .60717 Mdot
.52561 .58353 Mdot
.58143 .51129 Mdot
.75414 .3638 Mdot
.16551 .49103 Mdot
.371 .59796 Mdot
.40348 .06401 Mdot
.29991 .20436 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51185 .60203 Mdot
.53775 .56736 Mdot
.61974 .46653 Mdot
.86488 .35578 Mdot
.28921 .49887 Mdot
.48202 .51551 Mdot
.64791 .39729 Mdot
.00508 .402 Mdot
.35463 .51879 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50331 .61357 Mdot
.51053 .60381 Mdot
.53355 .57294 Mdot
.60651 .48141 Mdot
.82758 .35105 Mdot
.25958 .49832 Mdot
.45327 .54102 Mdot
.57788 .47167 Mdot
.81469 .33615 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49749 .0034 Mdot
.49199 .01081 Mdot
.4745 .03436 Mdot
.41891 .10632 Mdot
.24687 .25384 Mdot
.83615 .12739 Mdot
.63003 .01981 Mdot
.59798 .55264 Mdot
.70378 .41128 Mdot
.03832 .44646 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00306 Mdot
.49279 .00974 Mdot
.47704 .03095 Mdot
.42697 .0963 Mdot
.27115 .24255 Mdot
.8787 .14067 Mdot
.65109 .02071 Mdot
.61758 .53939 Mdot
.74483 .39192 Mdot
.11069 .48646 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61392 Mdot
.50971 .60492 Mdot
.53093 .57643 Mdot
.59826 .49101 Mdot
.80378 .35181 Mdot
.23453 .49866 Mdot
.42768 .56342 Mdot
.51605 .54857 Mdot
.62845 .442 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00213 Mdot
.49497 .00679 Mdot
.48399 .02161 Mdot
.44902 .06807 Mdot
.33888 .1932 Mdot
.02628 .21745 Mdot
.67444 .08622 Mdot
.53493 .0541 Mdot
.44738 .102 Mdot
.28235 .24651 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54179 .56202 Mdot
.63243 .45293 Mdot
.89958 .36589 Mdot
.30756 .50389 Mdot
.49225 .51107 Mdot
.66532 .38392 Mdot
.04412 .4243 Mdot
.35758 .5394 Mdot
.50082 .61692 Mdot
.50262 .61449 Mdot
.50835 .60675 Mdot
.52661 .58219 Mdot
.58461 .5074 Mdot
.76362 .36039 Mdot
.18049 .49409 Mdot
.38104 .59439 Mdot
.4193 .04801 Mdot
.34162 .17177 Mdot
.06369 .22925 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.49849 .00204 Mdot
.49519 .0065 Mdot
.48467 .02069 Mdot
.4512 .06523 Mdot
.34566 .18692 Mdot
.04322 .22649 Mdot
.67675 .0943 Mdot
.52417 .07199 Mdot
.40769 .15284 Mdot
.16039 .27761 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .00249 Mdot
.49412 .00794 Mdot
.48126 .02527 Mdot
.44037 .07927 Mdot
.31211 .21572 Mdot
.96306 .18178 Mdot
.66893 .05297 Mdot
.58322 .59733 Mdot
.61672 .49857 Mdot
.81002 .36139 Mdot
.50087 .61686 Mdot
.50278 .61428 Mdot
.50886 .60607 Mdot
.52821 .58006 Mdot
.58965 .50127 Mdot
.77857 .3561 Mdot
.20239 .49709 Mdot
.39808 .58525 Mdot
.45111 .01183 Mdot
.43197 .073 Mdot
.31386 .20882 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .0049 Mdot
.48844 .01561 Mdot
.46318 .04945 Mdot
.38317 .14829 Mdot
.14323 .26386 Mdot
.7163 .11961 Mdot
.52276 .09858 Mdot
.36326 .21031 Mdot
.02297 .23153 Mdot
.5003 .61763 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50957 .6051 Mdot
.5305 .577 Mdot
.59689 .49263 Mdot
.79979 .35225 Mdot
.22984 .49861 Mdot
.42307 .56718 Mdot
.50536 .56221 Mdot
.59568 .47876 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48302 .02291 Mdot
.44595 .07206 Mdot
.32936 .20164 Mdot
.00311 .20452 Mdot
.67219 .07425 Mdot
.55205 .02686 Mdot
.50859 .0189 Mdot
.478 .03924 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49564 .00589 Mdot
.4861 .01876 Mdot
.45574 .05927 Mdot
.35985 .17304 Mdot
.07987 .24401 Mdot
.68505 .10858 Mdot
.50936 .09991 Mdot
.3477 .22052 Mdot
.99088 .21208 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48721 .01726 Mdot
.45928 .0546 Mdot
.37093 .16157 Mdot
.10951 .25527 Mdot
.69648 .11598 Mdot
.50882 .10781 Mdot
.33438 .2351 Mdot
.95397 .19303 Mdot
.64165 .07837 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51281 .60074 Mdot
.54079 .56334 Mdot
.62928 .45624 Mdot
.89106 .36296 Mdot
.30379 .50216 Mdot
.49128 .51023 Mdot
.66571 .3829 Mdot
.04615 .42509 Mdot
.35834 .53976 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60555 Mdot
.52945 .5784 Mdot
.59357 .49657 Mdot
.7901 .35368 Mdot
.21783 .49823 Mdot
.41168 .57596 Mdot
.47976 .59467 Mdot
.51756 .57843 Mdot
.58164 .50602 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60311 Mdot
.5352 .57074 Mdot
.61173 .47546 Mdot
.84242 .3521 Mdot
.27271 .49815 Mdot
.4667 .52879 Mdot
.61109 .43397 Mdot
.90892 .35406 Mdot
.33603 .48057 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00255 Mdot
.49399 .00811 Mdot
.48087 .0258 Mdot
.43912 .08088 Mdot
.30825 .21865 Mdot
.95446 .17701 Mdot
.50105 .61662 Mdot
.50334 .61352 Mdot
.51064 .60367 Mdot
.53389 .57249 Mdot
.60759 .48017 Mdot
.83065 .35117 Mdot
.26245 .49826 Mdot
.45624 .53832 Mdot
.58521 .46305 Mdot
.83599 .33652 Mdot
.29149 .47908 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49704 .004 Mdot
.49057 .01274 Mdot
.46995 .04043 Mdot
.40453 .12373 Mdot
.20433 .26524 Mdot
.77517 .11954 Mdot
.58175 .04703 Mdot
.50565 .0418 Mdot
.43802 .09782 Mdot
.27975 .24279 Mdot
.50102 .61665 Mdot
.50325 .61364 Mdot
.51036 .60404 Mdot
.53301 .57366 Mdot
.60481 .48336 Mdot
.82271 .35095 Mdot
.25486 .49843 Mdot
.44839 .54544 Mdot
.56584 .48613 Mdot
.77927 .34107 Mdot
.22741 .48713 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51087 .60335 Mdot
.53463 .5715 Mdot
.60991 .47752 Mdot
.83728 .35161 Mdot
.26837 .49817 Mdot
.46231 .53278 Mdot
.60025 .44587 Mdot
.87882 .34407 Mdot
.3221 .47674 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51224 .60151 Mdot
.53898 .56573 Mdot
.62361 .46232 Mdot
.87556 .35836 Mdot
.29573 .49985 Mdot
.48695 .51194 Mdot
.65861 .38806 Mdot
.03072 .41636 Mdot
.35703 .53178 Mdot
.50007 .61794 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.52309 .58691 Mdot
.57346 .5212 Mdot
.73014 .3748 Mdot
.1237 .47828 Mdot
.34983 .59773 Mdot
.38268 .07887 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.50492 .61139 Mdot
.51566 .5969 Mdot
.54986 .55143 Mdot
.65763 .42804 Mdot
.96505 .3959 Mdot
.32447 .52758 Mdot
.47082 .55448 Mdot
.57365 .48861 Mdot
.78306 .34424 Mdot
.50046 .61742 Mdot
.50145 .61607 Mdot
.50463 .61178 Mdot
.51474 .59814 Mdot
.54692 .55527 Mdot
.64848 .43673 Mdot
.94183 .384 Mdot
.3205 .5173 Mdot
.48349 .53258 Mdot
.62175 .4304 Mdot
.92534 .3637 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49574 .00576 Mdot
.48642 .01833 Mdot
.45677 .05792 Mdot
.36305 .16978 Mdot
.08834 .24754 Mdot
.68782 .11111 Mdot
.50804 .10366 Mdot
.34032 .22808 Mdot
.97128 .2016 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.49229 .01042 Mdot
.47543 .03311 Mdot
.42186 .10267 Mdot
.25573 .25012 Mdot
.85103 .13132 Mdot
.63855 .01849 Mdot
.60863 .54346 Mdot
.72929 .39716 Mdot
.08666 .47359 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61095 Mdot
.51671 .59548 Mdot
.5532 .54708 Mdot
.668 .41869 Mdot
.99054 .40993 Mdot
.32726 .54042 Mdot
.45284 .58351 Mdot
.5087 .57544 Mdot
.57762 .5063 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50972 .6049 Mdot
.53098 .57637 Mdot
.5984 .49085 Mdot
.80419 .35177 Mdot
.23501 .49866 Mdot
.42816 .56303 Mdot
.51716 .54715 Mdot
.63185 .43843 Mdot
.92245 .36935 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.4871 .01742 Mdot
.45891 .05509 Mdot
.36977 .1628 Mdot
.10635 .25422 Mdot
.69502 .11539 Mdot
.50832 .10768 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07805 Mdot
.50114 .61649 Mdot
.50365 .61311 Mdot
.51162 .60234 Mdot
.53701 .56834 Mdot
.61742 .46909 Mdot
.85841 .35448 Mdot
.28486 .4985 Mdot
.47828 .51857 Mdot
.63921 .40536 Mdot
.98333 .38993 Mdot
.35241 .50797 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50984 .60474 Mdot
.53135 .57586 Mdot
.59959 .48945 Mdot
.80765 .35147 Mdot
.23895 .49866 Mdot
.4321 .55972 Mdot
.52645 .53532 Mdot
.66028 .4106 Mdot
.99591 .40681 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .0139 Mdot
.46721 .04409 Mdot
.39586 .13389 Mdot
.17923 .26708 Mdot
.74707 .11956 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00332 Mdot
.49218 .01057 Mdot
.47508 .03357 Mdot
.42076 .10404 Mdot
.25242 .25157 Mdot
.84538 .12973 Mdot
.63547 .01877 Mdot
.60509 .5463 Mdot
.72116 .40118 Mdot
.50034 .61757 Mdot
.5011 .61655 Mdot
.5035 .61331 Mdot
.51114 .60299 Mdot
.53549 .57036 Mdot
.61262 .47446 Mdot
.84493 .35239 Mdot
.27475 .49815 Mdot
.46872 .52697 Mdot
.61607 .42865 Mdot
.9225 .35961 Mdot
.50007 .61793 Mdot
.50024 .61772 Mdot
.50075 .61702 Mdot
.5024 .6148 Mdot
.50764 .60772 Mdot
.52432 .58526 Mdot
.57735 .51634 Mdot
.7419 .36899 Mdot
.14487 .48549 Mdot
.35932 .59958 Mdot
.38919 .07617 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49756 .0033 Mdot
.49222 .01051 Mdot
.47521 .0334 Mdot
.42117 .10352 Mdot
.25367 .25103 Mdot
.84749 .13031 Mdot
.63664 .01864 Mdot
.60649 .54515 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49819 .00245 Mdot
.49423 .00779 Mdot
.48163 .02478 Mdot
.44153 .07777 Mdot
.31569 .21293 Mdot
.97117 .18634 Mdot
.66966 .0572 Mdot
.5771 .60653 Mdot
.59572 .52304 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.50771 .60763 Mdot
.52455 .58496 Mdot
.57806 .51546 Mdot
.74404 .36801 Mdot
.14858 .4866 Mdot
.36124 .59955 Mdot
.39115 .07474 Mdot
.27021 .2211 Mdot
.91247 .14398 Mdot
.50031 .61761 Mdot
.50099 .6167 Mdot
.50315 .61377 Mdot
.51004 .60447 Mdot
.53199 .57501 Mdot
.60161 .48708 Mdot
.81349 .35112 Mdot
.24536 .49861 Mdot
.4386 .55412 Mdot
.54201 .51563 Mdot
.7077 .37327 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60083 Mdot
.54059 .56361 Mdot
.62865 .45691 Mdot
.88936 .3624 Mdot
.30298 .50185 Mdot
.49097 .51022 Mdot
.66542 .38302 Mdot
.04568 .42479 Mdot
.35836 .53944 Mdot
.5001 .6179 Mdot
.50032 .61761 Mdot
.501 .61668 Mdot
.5032 .61371 Mdot
.51019 .60427 Mdot
.53247 .57438 Mdot
.6031 .48535 Mdot
.81779 .35099 Mdot
.24988 .49853 Mdot
.44324 .55004 Mdot
.55326 .50159 Mdot
.50036 .61754 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51174 .60218 Mdot
.5374 .56782 Mdot
.61864 .46774 Mdot
.86182 .35514 Mdot
.28719 .49867 Mdot
.48032 .51687 Mdot
.644 .40086 Mdot
.99539 .39659 Mdot
.50062 .6172 Mdot
.50196 .61539 Mdot
.50624 .6096 Mdot
.51989 .59121 Mdot
.56329 .53407 Mdot
.69915 .39399 Mdot
.06165 .44973 Mdot
.33397 .57721 Mdot
.40003 .04587 Mdot
.32581 .177 Mdot
.03942 .21317 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49637 .00491 Mdot
.48842 .01564 Mdot
.46312 .04952 Mdot
.38299 .14848 Mdot
.14274 .26377 Mdot
.71595 .11959 Mdot
.52245 .09885 Mdot
.3625 .21104 Mdot
.02103 .23048 Mdot
.6481 .11216 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60849 Mdot
.52251 .58769 Mdot
.57161 .52352 Mdot
.72453 .37786 Mdot
.11313 .47413 Mdot
.34597 .59565 Mdot
.38218 .07714 Mdot
.25737 .22452 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.49671 .00444 Mdot
.48952 .01416 Mdot
.46661 .04488 Mdot
.394 .13604 Mdot
.17388 .26703 Mdot
.74181 .11968 Mdot
.54817 .07571 Mdot
.42567 .14213 Mdot
.1957 .28117 Mdot
.74075 .13388 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.49619 .00514 Mdot
.48787 .01637 Mdot
.46138 .05182 Mdot
.37753 .15448 Mdot
.12757 .26048 Mdot
.7061 .11852 Mdot
.51433 .10525 Mdot
.34404 .22778 Mdot
.97549 .20514 Mdot
.64356 .08938 Mdot
.49991 .00011 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01184 Mdot
.47207 .03761 Mdot
.41122 .11571 Mdot
.22399 .26129 Mdot
.80121 .12132 Mdot
.60491 .03095 Mdot
.55483 .59915 Mdot
.58538 .52374 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49303 .00942 Mdot
.47778 .02995 Mdot
.42932 .09335 Mdot
.27828 .23857 Mdot
.89226 .14615 Mdot
.65579 .0237 Mdot
.61744 .54248 Mdot
.73968 .39525 Mdot
.10016 .48209 Mdot
.50105 .61661 Mdot
.50335 .6135 Mdot
.51069 .6036 Mdot
.53403 .5723 Mdot
.60804 .47966 Mdot
.83194 .35124 Mdot
.26363 .49824 Mdot
.45746 .53721 Mdot
.58823 .45955 Mdot
.84466 .33734 Mdot
.29883 .47799 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46025 .05332 Mdot
.37397 .15832 Mdot
.1178 .25783 Mdot
.70062 .11733 Mdot
.51079 .10734 Mdot
.33711 .23333 Mdot
.95959 .19626 Mdot
.5001 .6179 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50991 .60464 Mdot
.53158 .57556 Mdot
.6003 .48861 Mdot
.80971 .35133 Mdot
.24125 .49865 Mdot
.43441 .55775 Mdot
.53196 .52832 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49248 .01016 Mdot
.47603 .0323 Mdot
.42377 .1003 Mdot
.26147 .24747 Mdot
.86106 .13441 Mdot
.64358 .01864 Mdot
.61343 .5402 Mdot
.73936 .39298 Mdot
.1035 .48231 Mdot
.50123 .61637 Mdot
.50393 .61273 Mdot
.51252 .60113 Mdot
.53986 .56457 Mdot
.62638 .45934 Mdot
.88315 .36049 Mdot
.29987 .50085 Mdot
.48949 .51058 Mdot
.66335 .38437 Mdot
.04142 .42234 Mdot
.35806 .53716 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49006 .01343 Mdot
.46833 .04259 Mdot
.39941 .12976 Mdot
.18945 .26676 Mdot
.75783 .11939 Mdot
.56465 .06109 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49612 .00525 Mdot
.48762 .01671 Mdot
.46058 .05288 Mdot
.37502 .15719 Mdot
.12068 .25865 Mdot
.70217 .11772 Mdot
.51169 .10689 Mdot
.33874 .23209 Mdot
.96321 .19829 Mdot
.64238 .08321 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50838 .60671 Mdot
.52671 .58206 Mdot
.58491 .50703 Mdot
.76451 .3601 Mdot
.18186 .49433 Mdot
.38202 .59395 Mdot
.42098 .0462 Mdot
.34623 .16758 Mdot
.07508 .23463 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00599 Mdot
.48588 .01907 Mdot
.45502 .06021 Mdot
.3576 .1753 Mdot
.07397 .24143 Mdot
.68333 .10664 Mdot
.51079 .09665 Mdot
.35441 .21357 Mdot
.00885 .22177 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .6013 Mdot
.53947 .56508 Mdot
.62515 .46066 Mdot
.87979 .35951 Mdot
.29808 .50037 Mdot
.48846 .51106 Mdot
.66155 .38572 Mdot
.03743 .42011 Mdot
.35769 .53515 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50587 .6101 Mdot
.51871 .5928 Mdot
.55954 .53888 Mdot
.68762 .40252 Mdot
.03633 .43591 Mdot
.33102 .56475 Mdot
.41724 .02002 Mdot
.38484 .11771 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48961 .01402 Mdot
.46692 .04447 Mdot
.39497 .13492 Mdot
.17666 .26708 Mdot
.74452 .11962 Mdot
.55097 .07317 Mdot
.43258 .13382 Mdot
.21606 .27802 Mdot
.50013 .61786 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50419 .61238 Mdot
.51334 .60002 Mdot
.54249 .56109 Mdot
.63463 .45064 Mdot
.90548 .36808 Mdot
.30992 .50529 Mdot
.49235 .51238 Mdot
.6633 .38619 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45727 .05726 Mdot
.36462 .16817 Mdot
.09252 .24919 Mdot
.68933 .11223 Mdot
.50773 .10508 Mdot
.33771 .23078 Mdot
.9643 .19796 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60705 Mdot
.52589 .58315 Mdot
.58233 .51019 Mdot
.75683 .36278 Mdot
.16984 .492 Mdot
.37377 .59714 Mdot
.40758 .06005 Mdot
.31041 .19709 Mdot
.50091 .61681 Mdot
.50288 .61414 Mdot
.50919 .60562 Mdot
.52927 .57864 Mdot
.59302 .49723 Mdot
.78849 .35398 Mdot
.21574 .49812 Mdot
.40978 .57735 Mdot
.4756 .59988 Mdot
.50497 .59527 Mdot
.5418 .55697 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51108 .60307 Mdot
.5353 .57061 Mdot
.61202 .47513 Mdot
.84325 .35219 Mdot
.27339 .49815 Mdot
.46737 .52818 Mdot
.61276 .43218 Mdot
.91348 .35586 Mdot
.33768 .48157 Mdot
.5003 .61763 Mdot
.50094 .61676 Mdot
.503 .61398 Mdot
.50955 .60513 Mdot
.53043 .57709 Mdot
.59668 .49287 Mdot
.7992 .35232 Mdot
.22914 .4986 Mdot
.42239 .56773 Mdot
.50378 .56423 Mdot
.59083 .48452 Mdot
.50007 .61794 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50688 .60874 Mdot
.52193 .58848 Mdot
.56975 .52586 Mdot
.71889 .38113 Mdot
.10222 .4695 Mdot
.34254 .5928 Mdot
.38337 .07347 Mdot
.4998 .00027 Mdot
.49936 .00086 Mdot
.49797 .00275 Mdot
.49352 .00876 Mdot
.47935 .02784 Mdot
.4343 .08704 Mdot
.29347 .22911 Mdot
.92277 .16029 Mdot
.66342 .03404 Mdot
.60833 .55923 Mdot
.70349 .41794 Mdot
.02725 .44308 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50811 .60708 Mdot
.52584 .58323 Mdot
.58215 .51041 Mdot
.75629 .36298 Mdot
.16897 .49181 Mdot
.3732 .59732 Mdot
.40672 .06089 Mdot
.30819 .19869 Mdot
.98671 .18638 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50533 .61084 Mdot
.51697 .59514 Mdot
.55401 .54603 Mdot
.67052 .4165 Mdot
.9966 .41335 Mdot
.32778 .54362 Mdot
.44818 .59082 Mdot
.49221 .59804 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49685 .00425 Mdot
.48998 .01354 Mdot
.46807 .04294 Mdot
.3986 .13071 Mdot
.18712 .26688 Mdot
.75529 .11942 Mdot
.56207 .06333 Mdot
.4596 .10038 Mdot
.29718 .24149 Mdot
.90645 .15967 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45873 .05533 Mdot
.3692 .16339 Mdot
.10483 .2537 Mdot
.69434 .11508 Mdot
.50813 .10755 Mdot
.3341 .23497 Mdot
.95391 .19284 Mdot
.64189 .07805 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51088 .60334 Mdot
.53465 .57147 Mdot
.60999 .47743 Mdot
.83749 .35162 Mdot
.26855 .49817 Mdot
.4625 .53261 Mdot
.60071 .44536 Mdot
.8801 .34443 Mdot
.32281 .4768 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00334 Mdot
.49214 .01062 Mdot
.47495 .03375 Mdot
.42033 .10456 Mdot
.25115 .2521 Mdot
.84324 .12916 Mdot
.63425 .01895 Mdot
.60359 .54758 Mdot
.71759 .40309 Mdot
.06538 .46201 Mdot
.50024 .61771 Mdot
.50077 .61699 Mdot
.50245 .61472 Mdot
.50782 .60747 Mdot
.5249 .58448 Mdot
.57919 .51406 Mdot
.74743 .36653 Mdot
.15438 .48824 Mdot
.36439 .59928 Mdot
.39474 .07187 Mdot
.27845 .21706 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50802 .6072 Mdot
.52554 .58363 Mdot
.58121 .51157 Mdot
.75348 .36406 Mdot
.16442 .49078 Mdot
.37032 .59813 Mdot
.40252 .06492 Mdot
.29748 .20595 Mdot
.96425 .17308 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60208 Mdot
.53763 .56752 Mdot
.61937 .46695 Mdot
.86383 .35556 Mdot
.28853 .4988 Mdot
.48145 .51596 Mdot
.64661 .39847 Mdot
.00188 .40021 Mdot
.35433 .51717 Mdot
.50058 .61725 Mdot
.50185 .61553 Mdot
.5059 .61007 Mdot
.51879 .59269 Mdot
.55979 .53856 Mdot
.68838 .40194 Mdot
.03803 .43686 Mdot
.33118 .56562 Mdot
.41598 .02191 Mdot
.38053 .12256 Mdot
.18222 .25692 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .61211 Mdot
.51398 .59916 Mdot
.54451 .55843 Mdot
.64095 .44419 Mdot
.92224 .37494 Mdot
.31559 .51013 Mdot
.49018 .51923 Mdot
.65005 .39984 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60037 Mdot
.54167 .56217 Mdot
.63206 .45332 Mdot
.89857 .36553 Mdot
.30714 .50367 Mdot
.49219 .51091 Mdot
.66552 .38366 Mdot
.04474 .4246 Mdot
.35773 .53961 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61426 Mdot
.50891 .606 Mdot
.52837 .57984 Mdot
.59017 .50065 Mdot
.7801 .35574 Mdot
.20451 .49729 Mdot
.39987 .58412 Mdot
.45475 .00747 Mdot
.44266 .05949 Mdot
.50069 .61711 Mdot
.50218 .61508 Mdot
.50696 .60864 Mdot
.52216 .58816 Mdot
.5705 .52492 Mdot
.72116 .37979 Mdot
.10664 .47142 Mdot
.34387 .59404 Mdot
.38269 .07517 Mdot
.26105 .22236 Mdot
.90126 .13659 Mdot
.50128 .61631 Mdot
.50408 .61253 Mdot
.51299 .6005 Mdot
.54136 .56259 Mdot
.63107 .45436 Mdot
.89591 .36459 Mdot
.30599 .5031 Mdot
.49195 .51056 Mdot
.66585 .38316 Mdot
.04589 .42512 Mdot
.35804 .53995 Mdot
.50028 .61765 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50922 .60559 Mdot
.52936 .57853 Mdot
.59328 .49691 Mdot
.78926 .35384 Mdot
.21674 .49817 Mdot
.41069 .57669 Mdot
.47758 .59741 Mdot
.51096 .58726 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01617 Mdot
.46187 .05118 Mdot
.37906 .15281 Mdot
.13181 .26151 Mdot
.70868 .11891 Mdot
.51629 .10383 Mdot
.34828 .22413 Mdot
.98563 .21083 Mdot
.64451 .09453 Mdot
.49993 .0001 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.49272 .00984 Mdot
.4768 .03127 Mdot
.42621 .09725 Mdot
.26886 .24376 Mdot
.87445 .13907 Mdot
.64943 .02001 Mdot
.61705 .53906 Mdot
.74484 .39159 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49039 .01298 Mdot
.46938 .0412 Mdot
.40272 .12587 Mdot
.19907 .26592 Mdot
.7688 .1194 Mdot
.5756 .05192 Mdot
.49159 .05971 Mdot
.39498 .15016 Mdot
.5007 .61708 Mdot
.50225 .615 Mdot
.50716 .60837 Mdot
.5228 .58731 Mdot
.57252 .52238 Mdot
.72729 .37633 Mdot
.11837 .47623 Mdot
.34782 .59677 Mdot
.38222 .07823 Mdot
.25564 .22568 Mdot
.89047 .13197 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49699 .00407 Mdot
.4904 .01297 Mdot
.46942 .04115 Mdot
.40284 .12573 Mdot
.19941 .26588 Mdot
.76921 .11941 Mdot
.576 .0516 Mdot
.49252 .05853 Mdot
.39781 .14689 Mdot
.16014 .27154 Mdot
.5008 .61695 Mdot
.50256 .61457 Mdot
.50817 .607 Mdot
.52602 .58298 Mdot
.58274 .50968 Mdot
.75805 .36233 Mdot
.17179 .49242 Mdot
.37505 .59671 Mdot
.40954 .0581 Mdot
.31554 .19331 Mdot
.00276 .19587 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50976 .60485 Mdot
.53108 .57622 Mdot
.59874 .49045 Mdot
.80517 .35168 Mdot
.23614 .49867 Mdot
.42928 .56209 Mdot
.5198 .54378 Mdot
.63996 .43012 Mdot
.94401 .37928 Mdot
.50002 .61801 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50059 .61724 Mdot
.50186 .61551 Mdot
.50594 .61001 Mdot
.51893 .5925 Mdot
.56024 .53798 Mdot
.68977 .40088 Mdot
.04113 .43859 Mdot
.33148 .56721 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49574 .00575 Mdot
.48643 .01832 Mdot
.45679 .05788 Mdot
.36314 .16969 Mdot
.08859 .24763 Mdot
.68791 .11118 Mdot
.50802 .10375 Mdot
.34015 .22825 Mdot
.97083 .20136 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49782 .00295 Mdot
.49304 .0094 Mdot
.47784 .02987 Mdot
.42951 .09311 Mdot
.27886 .23823 Mdot
.89339 .14662 Mdot
.65614 .024 Mdot
.61731 .54287 Mdot
.73893 .39568 Mdot
.0987 .48143 Mdot
.50062 .61719 Mdot
.50199 .61535 Mdot
.50633 .60949 Mdot
.52016 .59085 Mdot
.56415 .53297 Mdot
.70179 .39214 Mdot
.06729 .45268 Mdot
.33484 .57976 Mdot
.39677 .05085 Mdot
.31448 .18645 Mdot
.01279 .1983 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00425 Mdot
.48999 .01352 Mdot
.46811 .04289 Mdot
.3987 .13059 Mdot
.1874 .26687 Mdot
.7556 .11942 Mdot
.56238 .06305 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00228 Mdot
.49463 .00725 Mdot
.4829 .02307 Mdot
.44558 .07255 Mdot
.32819 .20264 Mdot
.00032 .20293 Mdot
.67197 .07277 Mdot
.55422 .02348 Mdot
.51623 .00845 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48746 .01694 Mdot
.46005 .05358 Mdot
.37335 .15899 Mdot
.1161 .25732 Mdot
.69974 .11708 Mdot
.5103 .10753 Mdot
.33632 .2339 Mdot
.95785 .19529 Mdot
.64187 .0805 Mdot
.4997 .0004 Mdot
.49906 .00127 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46949 .04105 Mdot
.40307 .12546 Mdot
.20007 .2658 Mdot
.76999 .11942 Mdot
.57677 .05098 Mdot
.49428 .05629 Mdot
.4032 .14059 Mdot
.17571 .27236 Mdot
.50051 .61735 Mdot
.50161 .61586 Mdot
.50513 .61111 Mdot
.51633 .59599 Mdot
.552 .54864 Mdot
.66427 .42199 Mdot
.98147 .40486 Mdot
.3264 .53572 Mdot
.45959 .57279 Mdot
.5328 .5426 Mdot
.65485 .42065 Mdot
.5 0 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00647 Mdot
.48475 .02058 Mdot
.45145 .0649 Mdot
.34643 .18618 Mdot
.04519 .22751 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49843 .00212 Mdot
.49501 .00674 Mdot
.48411 .02145 Mdot
.44941 .06756 Mdot
.3401 .19209 Mdot
.02929 .21909 Mdot
.6748 .08771 Mdot
.53288 .05745 Mdot
.43992 .11184 Mdot
.25895 .25915 Mdot
.50025 .6177 Mdot
.50078 .61697 Mdot
.5025 .61466 Mdot
.50796 .60729 Mdot
.52535 .58389 Mdot
.5806 .51232 Mdot
.75165 .36478 Mdot
.16142 .49006 Mdot
.36849 .59857 Mdot
.39998 .06727 Mdot
.29114 .20992 Mdot
.50054 .6173 Mdot
.50172 .6157 Mdot
.50549 .61061 Mdot
.5175 .59442 Mdot
.55571 .54382 Mdot
.67578 .41203 Mdot
.0091 .42046 Mdot
.32877 .5503 Mdot
.43837 .60602 Mdot
.45781 .02664 Mdot
.4147 .10199 Mdot
.50105 .61662 Mdot
.50333 .61353 Mdot
.51061 .6037 Mdot
.5338 .57261 Mdot
.6073 .4805 Mdot
.82984 .35113 Mdot
.2617 .49828 Mdot
.45547 .53902 Mdot
.58331 .46527 Mdot
.83048 .33619 Mdot
.28651 .47987 Mdot
.50015 .61783 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50481 .61153 Mdot
.51533 .59735 Mdot
.5488 .55281 Mdot
.65433 .43113 Mdot
.95675 .39153 Mdot
.32325 .52372 Mdot
.47585 .54602 Mdot
.59237 .46511 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50296 .61403 Mdot
.50944 .60528 Mdot
.53007 .57757 Mdot
.59555 .49421 Mdot
.7959 .35276 Mdot
.22512 .49851 Mdot
.41852 .57079 Mdot
.49496 .57546 Mdot
.56384 .51786 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.49659 .0046 Mdot
.48915 .01466 Mdot
.46543 .04645 Mdot
.39028 .1403 Mdot
.16327 .26647 Mdot
.7321 .11986 Mdot
.53817 .08481 Mdot
.40094 .17084 Mdot
.12452 .27485 Mdot
.6798 .14142 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50913 .6057 Mdot
.52908 .57889 Mdot
.59242 .49794 Mdot
.78674 .35431 Mdot
.21345 .49798 Mdot
.4077 .57883 Mdot
.47113 .60545 Mdot
.49149 .61333 Mdot
.4991 .61416 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49697 .0041 Mdot
.49034 .01304 Mdot
.46924 .04139 Mdot
.40227 .1264 Mdot
.19776 .26606 Mdot
.76725 .11939 Mdot
.57408 .05316 Mdot
.48807 .06421 Mdot
.38417 .16236 Mdot
.12146 .26435 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49765 .00317 Mdot
.49253 .01009 Mdot
.47619 .03208 Mdot
.42428 .09966 Mdot
.26303 .24671 Mdot
.86385 .13533 Mdot
.64488 .01882 Mdot
.61443 .53967 Mdot
.74122 .39235 Mdot
.10638 .48379 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49857 .00193 Mdot
.49544 .00615 Mdot
.48549 .01959 Mdot
.45379 .06183 Mdot
.35374 .17913 Mdot
.0639 .23679 Mdot
.68077 .10299 Mdot
.51413 .0899 Mdot
.36866 .19831 Mdot
.04779 .24195 Mdot
.50052 .61733 Mdot
.50166 .6158 Mdot
.50528 .6109 Mdot
.51682 .59534 Mdot
.55354 .54664 Mdot
.66905 .41777 Mdot
.99309 .41136 Mdot
.32749 .54176 Mdot
.45089 .58657 Mdot
.5018 .5849 Mdot
.55542 .53455 Mdot
.49986 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49563 .00591 Mdot
.48606 .01881 Mdot
.45563 .05942 Mdot
.35949 .17341 Mdot
.07891 .2436 Mdot
.68476 .10828 Mdot
.50956 .09942 Mdot
.3487 .21949 Mdot
.99356 .21352 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .0051 Mdot
.48796 .01625 Mdot
.46167 .05145 Mdot
.37842 .15351 Mdot
.13004 .26109 Mdot
.70759 .11875 Mdot
.51544 .10446 Mdot
.34641 .22575 Mdot
.98114 .20831 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50871 .60626 Mdot
.52776 .58066 Mdot
.58823 .50299 Mdot
.77438 .35717 Mdot
.19647 .49645 Mdot
.3932 .58819 Mdot
.44148 .0232 Mdot
.40394 .10694 Mdot
.23091 .25343 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46026 .05331 Mdot
.37401 .15828 Mdot
.11791 .25786 Mdot
.70068 .11734 Mdot
.51082 .10732 Mdot
.33717 .23328 Mdot
.95971 .19633 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49659 .00461 Mdot
.48913 .01468 Mdot
.46537 .04653 Mdot
.39009 .14052 Mdot
.16273 .26643 Mdot
.73164 .11986 Mdot
.53769 .08525 Mdot
.39975 .17216 Mdot
.12119 .27396 Mdot
.67791 .1413 Mdot
.50033 .61759 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51067 .60363 Mdot
.53397 .57238 Mdot
.60785 .47988 Mdot
.83139 .35121 Mdot
.26312 .49825 Mdot
.45694 .53769 Mdot
.58694 .46103 Mdot
.84097 .33694 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.49861 .00188 Mdot
.49557 .00598 Mdot
.48589 .01905 Mdot
.45506 .06016 Mdot
.35772 .17518 Mdot
.07428 .24157 Mdot
.68342 .10675 Mdot
.5107 .09683 Mdot
.35402 .21397 Mdot
.0078 .2212 Mdot
.50111 .61654 Mdot
.50352 .61328 Mdot
.51122 .60288 Mdot
.53574 .57003 Mdot
.61342 .47356 Mdot
.84718 .35268 Mdot
.27654 .49817 Mdot
.47048 .52539 Mdot
.62038 .42413 Mdot
.93413 .36479 Mdot
.34388 .4874 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48822 .01591 Mdot
.46248 .05037 Mdot
.38098 .1507 Mdot
.13714 .26268 Mdot
.71212 .1193 Mdot
.51909 .10164 Mdot
.35463 .21843 Mdot
.0012 .21955 Mdot
.64597 .10242 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49465 .00723 Mdot
.48296 .023 Mdot
.44574 .07233 Mdot
.32871 .2022 Mdot
.00155 .20363 Mdot
.67206 .07343 Mdot
.55326 .02497 Mdot
.50038 .61752 Mdot
.50122 .61638 Mdot
.5039 .61277 Mdot
.51242 .60127 Mdot
.53955 .56498 Mdot
.62539 .46039 Mdot
.88046 .3597 Mdot
.29845 .50046 Mdot
.48868 .51095 Mdot
.66194 .38542 Mdot
.03832 .4206 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49304 .00941 Mdot
.47781 .02991 Mdot
.42942 .09321 Mdot
.2786 .23838 Mdot
.89289 .14641 Mdot
.65599 .02387 Mdot
.61737 .5427 Mdot
.73927 .39549 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60904 Mdot
.52122 .58942 Mdot
.56751 .5287 Mdot
.71206 .38533 Mdot
.08859 .46328 Mdot
.33899 .58835 Mdot
.38702 .06648 Mdot
.27945 .21151 Mdot
.93723 .15481 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51043 .60395 Mdot
.53322 .57338 Mdot
.60547 .4826 Mdot
.82461 .35097 Mdot
.25672 .49839 Mdot
.45032 .5437 Mdot
.57059 .48039 Mdot
.79331 .33827 Mdot
.24597 .48577 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51186 .60202 Mdot
.53776 .56734 Mdot
.61979 .46648 Mdot
.86501 .35581 Mdot
.28929 .49888 Mdot
.48209 .51545 Mdot
.64806 .39715 Mdot
.00546 .40221 Mdot
.35467 .51898 Mdot
.50006 .61795 Mdot
.50021 .61776 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60903 Mdot
.52122 .58942 Mdot
.56752 .52868 Mdot
.7121 .3853 Mdot
.08867 .46332 Mdot
.33901 .58838 Mdot
.38699 .06653 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00352 Mdot
.4917 .01122 Mdot
.47355 .03562 Mdot
.41591 .11 Mdot
.23793 .25712 Mdot
.82189 .12438 Mdot
.62065 .02294 Mdot
.58354 .56704 Mdot
.66605 .43954 Mdot
.95486 .39825 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48092 .02573 Mdot
.43929 .08066 Mdot
.30878 .21825 Mdot
.95564 .17766 Mdot
.66818 .04919 Mdot
.58859 .58927 Mdot
.63514 .4785 Mdot
.86091 .36536 Mdot
.50091 .6168 Mdot
.50291 .61411 Mdot
.50926 .60553 Mdot
.52949 .57835 Mdot
.5937 .49642 Mdot
.79047 .35362 Mdot
.21831 .49825 Mdot
.41212 .57564 Mdot
.48072 .59347 Mdot
.52047 .57454 Mdot
.59084 .49483 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51586 .59663 Mdot
.5505 .55059 Mdot
.65963 .42619 Mdot
.97004 .39858 Mdot
.32512 .52999 Mdot
.46757 .55985 Mdot
.56172 .50405 Mdot
.74615 .35655 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01634 Mdot
.46147 .05171 Mdot
.37781 .15418 Mdot
.12833 .26067 Mdot
.70655 .11859 Mdot
.51467 .10501 Mdot
.34475 .22718 Mdot
.97717 .20608 Mdot
.64372 .09023 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48803 .01616 Mdot
.46188 .05116 Mdot
.37911 .15276 Mdot
.13194 .26154 Mdot
.70876 .11892 Mdot
.51635 .10379 Mdot
.34842 .22401 Mdot
.98596 .21101 Mdot
.64454 .09469 Mdot
.50004 .61799 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50365 .61311 Mdot
.51162 .60235 Mdot
.537 .56836 Mdot
.61738 .46914 Mdot
.85829 .35445 Mdot
.28478 .49849 Mdot
.4782 .51863 Mdot
.5013 .61628 Mdot
.50413 .61246 Mdot
.51315 .60028 Mdot
.54189 .56189 Mdot
.63273 .45262 Mdot
.90038 .36618 Mdot
.30789 .50407 Mdot
.49229 .51121 Mdot
.66513 .38416 Mdot
.04355 .42403 Mdot
.35746 .5392 Mdot
.50056 .61727 Mdot
.5018 .6156 Mdot
.50573 .61029 Mdot
.51825 .59341 Mdot
.55809 .54074 Mdot
.68315 .40602 Mdot
.02619 .43019 Mdot
.33012 .55943 Mdot
.42494 .00844 Mdot
.41129 .08649 Mdot
.27135 .23271 Mdot
.50052 .61733 Mdot
.50165 .6158 Mdot
.50526 .61092 Mdot
.51677 .59541 Mdot
.55338 .54684 Mdot
.66857 .41819 Mdot
.99192 .41071 Mdot
.32739 .54115 Mdot
.45178 .58517 Mdot
.50496 .58058 Mdot
.56557 .5215 Mdot
.5005 .61736 Mdot
.5016 .61587 Mdot
.5051 .61115 Mdot
.51624 .59611 Mdot
.55171 .54901 Mdot
.66339 .42279 Mdot
.9793 .40365 Mdot
.32618 .53462 Mdot
.46115 .57028 Mdot
.53843 .535 Mdot
.67278 .40448 Mdot
.50036 .61755 Mdot
.50114 .6165 Mdot
.50362 .61315 Mdot
.51152 .60247 Mdot
.5367 .56875 Mdot
.61644 .47018 Mdot
.85568 .35398 Mdot
.28293 .49838 Mdot
.47653 .52006 Mdot
.63506 .40935 Mdot
.97271 .38418 Mdot
.50031 .61762 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51003 .60449 Mdot
.53194 .57508 Mdot
.60144 .48728 Mdot
.81301 .35115 Mdot
.24484 .49861 Mdot
.43807 .55459 Mdot
.54072 .51725 Mdot
.70379 .37588 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01558 Mdot
.46325 .04934 Mdot
.38342 .14801 Mdot
.14392 .26398 Mdot
.71679 .11964 Mdot
.52321 .0982 Mdot
.36433 .20928 Mdot
.0257 .23301 Mdot
.64869 .11436 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49607 .0053 Mdot
.48749 .01689 Mdot
.46017 .05343 Mdot
.37371 .1586 Mdot
.11709 .25762 Mdot
.70025 .11722 Mdot
.51058 .10742 Mdot
.33677 .23358 Mdot
.95883 .19584 Mdot
.50058 .61726 Mdot
.50184 .61555 Mdot
.50585 .61013 Mdot
.51863 .5929 Mdot
.55931 .53918 Mdot
.6869 .40308 Mdot
.0347 .43499 Mdot
.33086 .5639 Mdot
.41845 .0182 Mdot
.389 .11296 Mdot
.20623 .25496 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50147 .61604 Mdot
.5047 .61169 Mdot
.51497 .59783 Mdot
.54765 .55431 Mdot
.65076 .43453 Mdot
.94767 .38689 Mdot
.32167 .51973 Mdot
.48073 .53755 Mdot
.61097 .44281 Mdot
.50024 .61771 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50778 .60752 Mdot
.52479 .58463 Mdot
.57885 .51449 Mdot
.74639 .36698 Mdot
.1526 .48775 Mdot
.36341 .59939 Mdot
.39357 .07284 Mdot
.27571 .21846 Mdot
.50055 .61728 Mdot
.50177 .61565 Mdot
.50563 .61043 Mdot
.51794 .59383 Mdot
.55709 .54203 Mdot
.68006 .40851 Mdot
.01909 .42616 Mdot
.32955 .55565 Mdot
.43048 4e-05 Mdot
.43042 .0625 Mdot
.32929 .19211 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49458 .00732 Mdot
.48274 .02329 Mdot
.44504 .07324 Mdot
.32655 .20404 Mdot
.9964 .20071 Mdot
.67165 .07068 Mdot
.55729 .01871 Mdot
.52702 .61181 Mdot
.53709 .57773 Mdot
.50081 .61693 Mdot
.50259 .61453 Mdot
.50827 .60687 Mdot
.52634 .58256 Mdot
.58373 .50847 Mdot
.76101 .36128 Mdot
.17645 .49335 Mdot
.3782 .59556 Mdot
.41456 .05298 Mdot
.32884 .18279 Mdot
.03308 .21323 Mdot
.50054 .61731 Mdot
.50172 .61572 Mdot
.50547 .61065 Mdot
.51742 .59453 Mdot
.55544 .54417 Mdot
.67497 .41272 Mdot
.00718 .41937 Mdot
.32863 .54927 Mdot
.43989 .60368 Mdot
.46311 .01954 Mdot
.43149 .08111 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50723 .60827 Mdot
.52302 .58701 Mdot
.57322 .5215 Mdot
.72942 .37519 Mdot
.12236 .47777 Mdot
.34931 .59751 Mdot
.38252 .07876 Mdot
.25509 .22623 Mdot
.88905 .1315 Mdot
.50073 .61705 Mdot
.50232 .61491 Mdot
.50738 .60807 Mdot
.52351 .58636 Mdot
.57476 .51957 Mdot
.73408 .37276 Mdot
.13095 .48091 Mdot
.35281 .59873 Mdot
.38405 .07893 Mdot
.25633 .22636 Mdot
.89008 .13236 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50993 .60462 Mdot
.53163 .57549 Mdot
.60048 .4884 Mdot
.81022 .3513 Mdot
.24181 .49865 Mdot
.43498 .55726 Mdot
.53332 .52659 Mdot
.68128 .39259 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49363 .0086 Mdot
.47971 .02736 Mdot
.43544 .08558 Mdot
.29697 .22675 Mdot
.93009 .164 Mdot
.66473 .03713 Mdot
.60466 .56498 Mdot
.6905 .42763 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51142 .60261 Mdot
.53638 .56918 Mdot
.61542 .47131 Mdot
.85283 .3535 Mdot
.28084 .49829 Mdot
.4746 .52174 Mdot
.63041 .41392 Mdot
.96067 .37783 Mdot
.34933 .49756 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48895 .01493 Mdot
.46479 .0473 Mdot
.38826 .14259 Mdot
.15755 .26593 Mdot
.72726 .11989 Mdot
.53328 .08926 Mdot
.38885 .18413 Mdot
.09093 .26391 Mdot
.66391 .13743 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50176 .61565 Mdot
.50561 .61045 Mdot
.51789 .5939 Mdot
.55693 .54224 Mdot
.67957 .40891 Mdot
.01795 .42551 Mdot
.32946 .55505 Mdot
.43137 .61671 Mdot
.43351 .05854 Mdot
.49989 .00015 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .00471 Mdot
.4889 .01499 Mdot
.46464 .0475 Mdot
.38779 .14311 Mdot
.15623 .26578 Mdot
.72619 .11989 Mdot
.53221 .09023 Mdot
.38621 .18696 Mdot
.0837 .26103 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49238 .01029 Mdot
.47573 .0327 Mdot
.42282 .10147 Mdot
.25863 .2488 Mdot
.85606 .13283 Mdot
.64115 .01847 Mdot
.61127 .54155 Mdot
.73502 .39466 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48925 .01452 Mdot
.46575 .04603 Mdot
.39126 .13918 Mdot
.16607 .26668 Mdot
.73458 .11982 Mdot
.5407 .08251 Mdot
.4072 .16375 Mdot
.14225 .27875 Mdot
.69123 .14115 Mdot
.50093 .61677 Mdot
.50298 .61401 Mdot
.50949 .60522 Mdot
.53022 .57738 Mdot
.59601 .49367 Mdot
.79723 .35258 Mdot
.22674 .49855 Mdot
.42008 .56957 Mdot
.4985 .57096 Mdot
.57466 .50426 Mdot
.75875 .35694 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61168 Mdot
.51499 .5978 Mdot
.54774 .5542 Mdot
.65103 .43427 Mdot
.94836 .38724 Mdot
.3218 .52002 Mdot
.48039 .53815 Mdot
.60964 .44437 Mdot
.89064 .35077 Mdot
.50059 .61724 Mdot
.50187 .6155 Mdot
.50596 .60998 Mdot
.519 .5924 Mdot
.56048 .53768 Mdot
.69049 .40033 Mdot
.04275 .43949 Mdot
.33165 .56804 Mdot
.41255 .02706 Mdot
.36877 .13539 Mdot
.14971 .2546 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49068 .01258 Mdot
.47032 .03994 Mdot
.40569 .12234 Mdot
.20775 .26471 Mdot
.77943 .11968 Mdot
.58577 .04396 Mdot
.51464 .03041 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00302 Mdot
.49289 .00961 Mdot
.47734 .03055 Mdot
.42791 .09512 Mdot
.274 .24099 Mdot
.88407 .14277 Mdot
.65306 .02176 Mdot
.61785 .54025 Mdot
.7437 .39283 Mdot
.1081 .48551 Mdot
.50027 .61766 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.50889 .60603 Mdot
.52832 .57991 Mdot
.59001 .50084 Mdot
.77963 .35585 Mdot
.20386 .49723 Mdot
.39931 .58447 Mdot
.45362 .00883 Mdot
.43933 .06373 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48865 .01533 Mdot
.46384 .04856 Mdot
.38526 .14595 Mdot
.14911 .26483 Mdot
.7206 .1198 Mdot
.52677 .0951 Mdot
.3729 .2008 Mdot
.048 .24462 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50669 .609 Mdot
.5213 .58931 Mdot
.56778 .52836 Mdot
.71287 .38481 Mdot
.09023 .46405 Mdot
.33938 .58894 Mdot
.38646 .06745 Mdot
.27732 .21283 Mdot
.93295 .15249 Mdot
.50048 .61739 Mdot
.50153 .61597 Mdot
.50487 .61146 Mdot
.5155 .59711 Mdot
.54935 .55209 Mdot
.65604 .42952 Mdot
.96106 .39378 Mdot
.32391 .5257 Mdot
.4733 .55034 Mdot
.58283 .47697 Mdot
.81108 .34016 Mdot
.49959 .00055 Mdot
.49871 .00174 Mdot
.49589 .00556 Mdot
.48689 .01769 Mdot
.45827 .05594 Mdot
.36775 .16491 Mdot
.10091 .25232 Mdot
.69265 .11425 Mdot
.50778 .10704 Mdot
.33458 .23424 Mdot
.95557 .19358 Mdot
.64234 .07853 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50426 .61228 Mdot
.51357 .59971 Mdot
.54322 .56013 Mdot
.63691 .44829 Mdot
.91155 .37046 Mdot
.31214 .5069 Mdot
.49197 .51434 Mdot
.65975 .38988 Mdot
.02891 .41654 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.49571 .0058 Mdot
.48632 .01847 Mdot
.45643 .05836 Mdot
.36199 .17086 Mdot
.08554 .24639 Mdot
.68686 .11031 Mdot
.50838 .10254 Mdot
.34246 .22589 Mdot
.50099 .6167 Mdot
.50315 .61377 Mdot
.51005 .60446 Mdot
.53201 .57498 Mdot
.60168 .487 Mdot
.81369 .35112 Mdot
.24557 .4986 Mdot
.43882 .55394 Mdot
.54253 .51498 Mdot
.70928 .37223 Mdot
.107 .46412 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48369 .02201 Mdot
.44807 .0693 Mdot
.33595 .19585 Mdot
.01906 .21347 Mdot
.67365 .08258 Mdot
.54003 .04586 Mdot
.46582 .07731 Mdot
.34073 .20153 Mdot
.50103 .61664 Mdot
.50329 .61359 Mdot
.51049 .60387 Mdot
.53341 .57313 Mdot
.60606 .48192 Mdot
.8263 .35101 Mdot
.25836 .49835 Mdot
.45201 .54217 Mdot
.57476 .47538 Mdot
.80559 .33674 Mdot
.26073 .48395 Mdot
.50047 .6174 Mdot
.50148 .61603 Mdot
.50473 .61165 Mdot
.51506 .59771 Mdot
.54795 .55392 Mdot
.65169 .43364 Mdot
.95005 .38809 Mdot
.32211 .52075 Mdot
.47952 .53967 Mdot
.60631 .44829 Mdot
.88097 .34794 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00276 Mdot
.49348 .00881 Mdot
.47923 .02801 Mdot
.43391 .08753 Mdot
.29229 .2299 Mdot
.9203 .15906 Mdot
.66293 .03305 Mdot
.60945 .55743 Mdot
.70751 .41511 Mdot
.03585 .44806 Mdot
.50102 .61666 Mdot
.50324 .61365 Mdot
.51033 .60408 Mdot
.53291 .57379 Mdot
.60451 .48372 Mdot
.82183 .35095 Mdot
.25399 .49845 Mdot
.44748 .54625 Mdot
.56363 .48882 Mdot
.7727 .34278 Mdot
.21807 .48736 Mdot
.50123 .61637 Mdot
.50393 .61272 Mdot
.51252 .60113 Mdot
.53987 .56455 Mdot
.6264 .45931 Mdot
.88323 .36051 Mdot
.29991 .50086 Mdot
.48951 .51058 Mdot
.66338 .38435 Mdot
.04149 .42238 Mdot
.35807 .5372 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60802 Mdot
.52363 .58619 Mdot
.57515 .51909 Mdot
.73525 .37217 Mdot
.13306 .48165 Mdot
.35373 .59895 Mdot
.38461 .07876 Mdot
.25717 .22616 Mdot
.50051 .61735 Mdot
.50162 .61584 Mdot
.50517 .61105 Mdot
.51648 .5958 Mdot
.55246 .54805 Mdot
.6657 .42072 Mdot
.98496 .4068 Mdot
.32675 .53752 Mdot
.45703 .57687 Mdot
.52363 .55505 Mdot
.62554 .45037 Mdot
.50004 .61799 Mdot
.50011 .61788 Mdot
.50036 .61754 Mdot
.50116 .61647 Mdot
.50369 .61305 Mdot
.51175 .60217 Mdot
.53742 .5678 Mdot
.6187 .46768 Mdot
.86198 .35517 Mdot
.2873 .49868 Mdot
.48041 .5168 Mdot
.50014 .61784 Mdot
.50046 .61742 Mdot
.50146 .61607 Mdot
.50464 .61176 Mdot
.51479 .59807 Mdot
.54709 .55505 Mdot
.64901 .43622 Mdot
.94319 .38467 Mdot
.32079 .51786 Mdot
.48287 .53371 Mdot
.61932 .43316 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .00509 Mdot
.48799 .01621 Mdot
.46177 .05131 Mdot
.37874 .15316 Mdot
.13092 .2613 Mdot
.70813 .11883 Mdot
.51585 .10416 Mdot
.5009 .61682 Mdot
.50287 .61416 Mdot
.50914 .60569 Mdot
.52911 .57885 Mdot
.5925 .49785 Mdot
.78697 .35427 Mdot
.21376 .498 Mdot
.40797 .57864 Mdot
.47172 .60472 Mdot
.49326 .61096 Mdot
.50471 .6066 Mdot
.5009 .61682 Mdot
.50286 .61417 Mdot
.50911 .60573 Mdot
.52902 .57897 Mdot
.59222 .49818 Mdot
.78614 .35443 Mdot
.21266 .49793 Mdot
.40699 .57933 Mdot
.46962 .60732 Mdot
.48696 .00136 Mdot
.48476 .01547 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50895 .60595 Mdot
.5285 .57967 Mdot
.59057 .50017 Mdot
.78127 .35547 Mdot
.20612 .49744 Mdot
.40124 .58323 Mdot
.45757 .00407 Mdot
.45099 .04879 Mdot
.37204 .15504 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48709 .01743 Mdot
.4589 .05511 Mdot
.36973 .16283 Mdot
.10627 .25419 Mdot
.69498 .11537 Mdot
.50831 .10767 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07804 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50892 .60599 Mdot
.52841 .57979 Mdot
.59028 .50051 Mdot
.78044 .35566 Mdot
.20497 .49734 Mdot
.40026 .58386 Mdot
.45555 .0065 Mdot
.44504 .05644 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49776 .00303 Mdot
.49287 .00964 Mdot
.47727 .03063 Mdot
.42771 .09537 Mdot
.2734 .24132 Mdot
.88294 .14232 Mdot
.65266 .02152 Mdot
.61783 .54003 Mdot
.74404 .39259 Mdot
.10881 .48579 Mdot
.49997 4e-05 Mdot
.49991 .00013 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46947 .04107 Mdot
.40302 .12552 Mdot
.19993 .26582 Mdot
.76982 .11942 Mdot
.5766 .05112 Mdot
.49389 .05678 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49807 .0026 Mdot
.49386 .00829 Mdot
.48044 .02638 Mdot
.43775 .08263 Mdot
.30405 .22175 Mdot
.94524 .17199 Mdot
.66696 .04407 Mdot
.59566 .57867 Mdot
.65936 .45441 Mdot
.9241 .38669 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51139 .60266 Mdot
.53627 .56933 Mdot
.61508 .4717 Mdot
.85186 .35335 Mdot
.28012 .49826 Mdot
.47392 .52233 Mdot
.62877 .41556 Mdot
.95639 .37563 Mdot
.34861 .49575 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00317 Mdot
.49252 .01011 Mdot
.47617 .03212 Mdot
.4242 .09976 Mdot
.26278 .24683 Mdot
.86341 .13518 Mdot
.64468 .01878 Mdot
.61428 .53975 Mdot
.74095 .39244 Mdot
.10597 .48358 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50825 .60689 Mdot
.52628 .58264 Mdot
.58355 .5087 Mdot
.76046 .36147 Mdot
.17559 .49318 Mdot
.3776 .59579 Mdot
.4136 .05398 Mdot
.32627 .1849 Mdot
.02709 .20989 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50866 .60634 Mdot
.52759 .58088 Mdot
.5877 .50363 Mdot
.7728 .3576 Mdot
.19419 .49617 Mdot
.39137 .58923 Mdot
.43798 .02725 Mdot
.39388 .1185 Mdot
.20215 .25942 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00514 Mdot
.48788 .01636 Mdot
.46141 .05179 Mdot
.37762 .15438 Mdot
.12782 .26055 Mdot
.70625 .11854 Mdot
.51444 .10517 Mdot
.34427 .22758 Mdot
.97603 .20545 Mdot
.64361 .08966 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51109 .60306 Mdot
.53533 .57057 Mdot
.61212 .47502 Mdot
.84352 .35222 Mdot
.27361 .49815 Mdot
.46759 .52798 Mdot
.6133 .4316 Mdot
.91495 .35646 Mdot
.33819 .48192 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .60289 Mdot
.53572 .57005 Mdot
.61335 .47363 Mdot
.84699 .35265 Mdot
.27639 .49817 Mdot
.47033 .52552 Mdot
.62003 .4245 Mdot
.93318 .36435 Mdot
.34364 .48709 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01286 Mdot
.46968 .0408 Mdot
.40367 .12475 Mdot
.20182 .26558 Mdot
.7721 .11946 Mdot
.57881 .04935 Mdot
.49896 .05031 Mdot
.41756 .12336 Mdot
.21796 .26793 Mdot
.50077 .61699 Mdot
.50247 .6147 Mdot
.50786 .60742 Mdot
.52503 .58432 Mdot
.57958 .51358 Mdot
.74859 .36604 Mdot
.15633 .48876 Mdot
.3655 .59913 Mdot
.39609 .07072 Mdot
.28167 .21535 Mdot
.93322 .15524 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48731 .01714 Mdot
.45957 .05421 Mdot
.37185 .16059 Mdot
.11202 .25607 Mdot
.69769 .11642 Mdot
.50931 .10779 Mdot
.3349 .23484 Mdot
.95492 .19361 Mdot
.64166 .07895 Mdot
.5012 .61642 Mdot
.50381 .61288 Mdot
.51215 .60163 Mdot
.53869 .56612 Mdot
.62269 .46331 Mdot
.87304 .3577 Mdot
.29427 .49958 Mdot
.48593 .51261 Mdot
.65651 .38979 Mdot
.02581 .41362 Mdot
.35656 .52931 Mdot
.50016 .61782 Mdot
.5005 .61735 Mdot
.50161 .61586 Mdot
.50512 .61112 Mdot
.51631 .59603 Mdot
.55192 .54875 Mdot
.66402 .42221 Mdot
.98087 .40452 Mdot
.32634 .53541 Mdot
.46002 .57208 Mdot
.53437 .54047 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00457 Mdot
.48923 .01454 Mdot
.4657 .0461 Mdot
.39111 .13935 Mdot
.16565 .26665 Mdot
.7342 .11983 Mdot
.54031 .08286 Mdot
.40624 .16484 Mdot
.13953 .27824 Mdot
.68932 .14129 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.5004 .6175 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.5128 .60075 Mdot
.54077 .56336 Mdot
.62924 .45629 Mdot
.89095 .36292 Mdot
.30373 .50213 Mdot
.49126 .51023 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00373 Mdot
.4912 .01189 Mdot
.47197 .03774 Mdot
.4109 .11609 Mdot
.22306 .26153 Mdot
.7999 .12118 Mdot
.60383 .0316 Mdot
.5527 .60167 Mdot
.57917 .53127 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48852 .0155 Mdot
.46345 .04908 Mdot
.38403 .14732 Mdot
.14566 .26428 Mdot
.71804 .1197 Mdot
.52436 .0972 Mdot
.36709 .20659 Mdot
.03282 .2368 Mdot
.64967 .11761 Mdot
.4998 .00027 Mdot
.49936 .00086 Mdot
.49797 .00274 Mdot
.49355 .00872 Mdot
.47944 .02773 Mdot
.43457 .08669 Mdot
.2943 .22856 Mdot
.92449 .16115 Mdot
.66374 .03475 Mdot
.60751 .56052 Mdot
.70057 .42004 Mdot
.02093 .43939 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50474 .61163 Mdot
.5151 .59766 Mdot
.54807 .55377 Mdot
.65206 .43329 Mdot
.95098 .38856 Mdot
.32228 .52115 Mdot
.47903 .54053 Mdot
.60443 .45052 Mdot
.87548 .3465 Mdot
.50017 .6178 Mdot
.50055 .61729 Mdot
.50175 .61568 Mdot
.50556 .61052 Mdot
.51772 .59413 Mdot
.55639 .54294 Mdot
.6779 .41028 Mdot
.01405 .42329 Mdot
.32916 .55296 Mdot
.43445 .61202 Mdot
.44419 .04467 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .0051 Mdot
.48798 .01623 Mdot
.46171 .05139 Mdot
.37857 .15335 Mdot
.13043 .26118 Mdot
.70783 .11879 Mdot
.51562 .10433 Mdot
.34682 .2254 Mdot
.98211 .20885 Mdot
.64418 .09274 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51338 .59997 Mdot
.54261 .56093 Mdot
.635 .45026 Mdot
.90647 .36846 Mdot
.3103 .50554 Mdot
.49232 .51266 Mdot
.66282 .3867 Mdot
.03712 .42081 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00214 Mdot
.49496 .00681 Mdot
.48395 .02166 Mdot
.4489 .06823 Mdot
.33851 .19354 Mdot
.02535 .21694 Mdot
.67433 .08576 Mdot
.53556 .05307 Mdot
.4497 .09893 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01454 Mdot
.46572 .04607 Mdot
.39117 .13929 Mdot
.1658 .26666 Mdot
.73433 .11983 Mdot
.54045 .08273 Mdot
.40658 .16445 Mdot
.14049 .27843 Mdot
.68999 .14125 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50757 .60781 Mdot
.52412 .58553 Mdot
.57671 .51714 Mdot
.73995 .36989 Mdot
.14145 .48443 Mdot
.35762 .59951 Mdot
.3876 .07722 Mdot
.26265 .2243 Mdot
.89973 .13737 Mdot
.50062 .6172 Mdot
.50197 .61538 Mdot
.50627 .60957 Mdot
.51996 .59111 Mdot
.56353 .53377 Mdot
.69987 .39348 Mdot
.0632 .45055 Mdot
.3342 .57792 Mdot
.39911 .04728 Mdot
.32262 .17973 Mdot
.03181 .20902 Mdot
.49977 .00032 Mdot
.49926 .00101 Mdot
.49763 .0032 Mdot
.49245 .0102 Mdot
.47594 .03243 Mdot
.42347 .10067 Mdot
.26058 .24789 Mdot
.85948 .1339 Mdot
.64283 .01856 Mdot
.61279 .54057 Mdot
.73813 .39343 Mdot
.10154 .48131 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00236 Mdot
.49444 .00751 Mdot
.48229 .0239 Mdot
.44362 .07508 Mdot
.32213 .20773 Mdot
.98602 .19478 Mdot
.67085 .06511 Mdot
.5655 .00609 Mdot
.55564 .57359 Mdot
.62755 .4676 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51236 .60134 Mdot
.53937 .56521 Mdot
.62484 .46099 Mdot
.87894 .35927 Mdot
.29762 .50026 Mdot
.48818 .51121 Mdot
.66102 .38613 Mdot
.03624 .41944 Mdot
.35757 .53455 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50493 .61137 Mdot
.51571 .59684 Mdot
.55001 .55124 Mdot
.65808 .42762 Mdot
.96617 .3965 Mdot
.32462 .52812 Mdot
.4701 .55568 Mdot
.571 .49201 Mdot
.77491 .34627 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.49481 .00701 Mdot
.48346 .02232 Mdot
.44734 .07025 Mdot
.33367 .19788 Mdot
.0135 .21037 Mdot
.67311 .07972 Mdot
.54412 .03934 Mdot
.48047 .05739 Mdot
.38761 .15313 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.4663 .0453 Mdot
.393 .13719 Mdot
.17102 .26694 Mdot
.73911 .11974 Mdot
.54536 .07825 Mdot
.41875 .15034 Mdot
.17549 .28201 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60665 Mdot
.52685 .58188 Mdot
.58536 .50649 Mdot
.76584 .35967 Mdot
.18388 .49467 Mdot
.3835 .59328 Mdot
.42354 .04343 Mdot
.35327 .16099 Mdot
.09279 .24222 Mdot
.50104 .61663 Mdot
.5033 .61357 Mdot
.51053 .60382 Mdot
.53353 .57296 Mdot
.60646 .48147 Mdot
.82743 .35104 Mdot
.25943 .49833 Mdot
.45313 .54116 Mdot
.57752 .4721 Mdot
.81364 .3362 Mdot
.26966 .48262 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00252 Mdot
.49405 .00804 Mdot
.48104 .02557 Mdot
.43966 .08018 Mdot
.30992 .21739 Mdot
.95817 .17906 Mdot
.66844 .05047 Mdot
.58679 .59197 Mdot
.62896 .48508 Mdot
.84409 .36257 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49798 .00272 Mdot
.49358 .00868 Mdot
.47954 .0276 Mdot
.43488 .08629 Mdot
.29526 .22791 Mdot
.92649 .16216 Mdot
.66411 .03559 Mdot
.60653 .56208 Mdot
.69707 .42262 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49337 .00896 Mdot
.47887 .02849 Mdot
.43278 .08896 Mdot
.28884 .23214 Mdot
.91323 .15562 Mdot
.66143 .03034 Mdot
.61233 .55268 Mdot
.71808 .40809 Mdot
.05777 .46048 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50784 .60744 Mdot
.52499 .58437 Mdot
.57945 .51374 Mdot
.74821 .3662 Mdot
.15569 .48859 Mdot
.36513 .59918 Mdot
.39564 .07111 Mdot
.28058 .21594 Mdot
.93118 .15411 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60843 Mdot
.52264 .58752 Mdot
.57202 .52301 Mdot
.72577 .37717 Mdot
.1155 .47509 Mdot
.34679 .59618 Mdot
.38215 .07769 Mdot
.25644 .22511 Mdot
.8922 .13265 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.48729 .01716 Mdot
.45953 .05427 Mdot
.37172 .16072 Mdot
.11167 .25596 Mdot
.69752 .11636 Mdot
.50924 .1078 Mdot
.33481 .23489 Mdot
.95475 .1935 Mdot
.64165 .07885 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01163 Mdot
.47258 .03693 Mdot
.41283 .11376 Mdot
.22877 .25999 Mdot
.80809 .12217 Mdot
.61042 .02782 Mdot
.56542 .5869 Mdot
.6158 .48877 Mdot
.82496 .35729 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50084 .61689 Mdot
.50269 .6144 Mdot
.50857 .60646 Mdot
.5273 .58128 Mdot
.58677 .50476 Mdot
.77005 .35839 Mdot
.19017 .49563 Mdot
.38823 .59093 Mdot
.43208 .03397 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48891 .01497 Mdot
.46469 .04743 Mdot
.38794 .14295 Mdot
.15665 .26583 Mdot
.72653 .11989 Mdot
.53255 .08993 Mdot
.38704 .18607 Mdot
.08598 .26196 Mdot
.66213 .13633 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .0137 Mdot
.46769 .04345 Mdot
.39739 .13212 Mdot
.18362 .26701 Mdot
.75158 .11948 Mdot
.55826 .06666 Mdot
.45039 .11191 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46802 .04301 Mdot
.39844 .1309 Mdot
.18663 .2669 Mdot
.75477 .11943 Mdot
.56154 .06379 Mdot
.45833 .10198 Mdot
.29331 .2441 Mdot
.89835 .15614 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.5101 .6044 Mdot
.53216 .57478 Mdot
.60214 .48646 Mdot
.81504 .35106 Mdot
.24701 .49858 Mdot
.44029 .55265 Mdot
.54608 .51052 Mdot
.72004 .36559 Mdot
.12851 .47219 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54007 .56429 Mdot
.62702 .45864 Mdot
.88492 .36102 Mdot
.30078 .50111 Mdot
.48996 .51041 Mdot
.6641 .38384 Mdot
.04304 .42325 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49631 .00498 Mdot
.48825 .01587 Mdot
.46257 .05025 Mdot
.38127 .15039 Mdot
.13793 .26284 Mdot
.71264 .11934 Mdot
.51954 .10128 Mdot
.35566 .21748 Mdot
.00377 .22098 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00562 Mdot
.48675 .01788 Mdot
.45782 .05653 Mdot
.36635 .16637 Mdot
.09716 .25095 Mdot
.69111 .11339 Mdot
.50764 .10631 Mdot
.33562 .23302 Mdot
.9586 .19506 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49038 .013 Mdot
.46935 .04123 Mdot
.40263 .12597 Mdot
.19881 .26595 Mdot
.76849 .1194 Mdot
.5753 .05217 Mdot
.49089 .06061 Mdot
.39283 .15262 Mdot
.14589 .26971 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00264 Mdot
.49378 .0084 Mdot
.4802 .02671 Mdot
.43698 .08361 Mdot
.30169 .22345 Mdot
.94015 .16926 Mdot
.66628 .04166 Mdot
.59887 .57382 Mdot
.67042 .44433 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00491 Mdot
.48842 .01564 Mdot
.46311 .04953 Mdot
.38297 .14851 Mdot
.14268 .26376 Mdot
.71591 .11959 Mdot
.52241 .09888 Mdot
.36242 .21113 Mdot
.02081 .23036 Mdot
.64808 .11205 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00414 Mdot
.49023 .0132 Mdot
.46888 .04187 Mdot
.40113 .12774 Mdot
.19444 .26639 Mdot
.76342 .11937 Mdot
.57028 .05631 Mdot
.47917 .07556 Mdot
.35691 .19105 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01506 Mdot
.46449 .04771 Mdot
.38729 .14368 Mdot
.15482 .26561 Mdot
.72505 .11988 Mdot
.53108 .09125 Mdot
.38344 .1899 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48979 .01379 Mdot
.46747 .04374 Mdot
.3967 .13292 Mdot
.18164 .26706 Mdot
.74953 .11951 Mdot
.55615 .06853 Mdot
.44526 .11829 Mdot
.25386 .26579 Mdot
.82381 .13383 Mdot
.50051 .61734 Mdot
.50163 .61583 Mdot
.50519 .61102 Mdot
.51654 .59571 Mdot
.55266 .54778 Mdot
.66634 .42015 Mdot
.98653 .40767 Mdot
.3269 .53833 Mdot
.45586 .57873 Mdot
.51946 .56073 Mdot
.61218 .46513 Mdot
.50019 .61777 Mdot
.50061 .6172 Mdot
.50196 .61539 Mdot
.50624 .60961 Mdot
.51987 .59123 Mdot
.56324 .53413 Mdot
.699 .3941 Mdot
.06134 .44957 Mdot
.33393 .57707 Mdot
.40022 .04559 Mdot
.32645 .17644 Mdot
.50018 .61779 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50582 .61017 Mdot
.51855 .59301 Mdot
.55905 .53951 Mdot
.6861 .4037 Mdot
.0329 .43398 Mdot
.3307 .56296 Mdot
.41981 .01616 Mdot
.39366 .10758 Mdot
.50091 .61681 Mdot
.50289 .61414 Mdot
.50919 .60562 Mdot
.52928 .57863 Mdot
.59304 .4972 Mdot
.78855 .35396 Mdot
.21583 .49812 Mdot
.40985 .5773 Mdot
.47576 .59968 Mdot
.50547 .59461 Mdot
.54337 .5549 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49375 .00844 Mdot
.4801 .02683 Mdot
.43669 .08399 Mdot
.30078 .22409 Mdot
.9382 .16822 Mdot
.666 .04076 Mdot
.60006 .57202 Mdot
.67451 .44076 Mdot
.96135 .40528 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49514 .00657 Mdot
.4845 .02092 Mdot
.45066 .06593 Mdot
.34398 .18849 Mdot
.039 .22428 Mdot
.6761 .09236 Mdot
.52666 .06776 Mdot
.41703 .14124 Mdot
.1885 .2779 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.5237 .5861 Mdot
.57536 .51882 Mdot
.7359 .37185 Mdot
.13423 .48205 Mdot
.35425 .59906 Mdot
.38495 .07863 Mdot
.25772 .226 Mdot
.89204 .13342 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04863 Mdot
.38512 .14612 Mdot
.14869 .26477 Mdot
.72029 .11979 Mdot
.52647 .09536 Mdot
.37218 .20152 Mdot
.0461 .24367 Mdot
.65184 .12331 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00296 Mdot
.49301 .00944 Mdot
.47773 .03002 Mdot
.42915 .09356 Mdot
.27776 .23887 Mdot
.89127 .14573 Mdot
.65548 .02345 Mdot
.61754 .54216 Mdot
.74031 .39488 Mdot
.10138 .48264 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49029 .01311 Mdot
.46907 .0416 Mdot
.40176 .127 Mdot
.19627 .26622 Mdot
.76552 .11937 Mdot
.57237 .05457 Mdot
.48407 .06931 Mdot
.37193 .17563 Mdot
.08775 .25292 Mdot
.49979 .00029 Mdot
.49932 .00091 Mdot
.49785 .00291 Mdot
.49314 .00927 Mdot
.47815 .02946 Mdot
.43048 .09189 Mdot
.2818 .23649 Mdot
.89915 .14913 Mdot
.65785 .02563 Mdot
.61637 .54515 Mdot
.7343 .39832 Mdot
.08981 .47723 Mdot
.5013 .61628 Mdot
.50413 .61245 Mdot
.51317 .60025 Mdot
.54194 .56182 Mdot
.6329 .45244 Mdot
.90085 .36635 Mdot
.30808 .50418 Mdot
.49231 .5113 Mdot
.665 .3843 Mdot
.04319 .42385 Mdot
.35738 .53907 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50746 .60795 Mdot
.52377 .586 Mdot
.5756 .51852 Mdot
.73662 .3715 Mdot
.13553 .48249 Mdot
.35484 .59917 Mdot
.38536 .07846 Mdot
.25841 .2258 Mdot
.89307 .13396 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00556 Mdot
.48688 .01772 Mdot
.45821 .05601 Mdot
.36758 .16509 Mdot
.10046 .25216 Mdot
.69246 .11415 Mdot
.50775 .10697 Mdot
.33467 .23412 Mdot
.95585 .19372 Mdot
.64241 .07862 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.4965 .00473 Mdot
.48884 .01507 Mdot
.46444 .04776 Mdot
.38716 .14382 Mdot
.15445 .26557 Mdot
.72475 .11988 Mdot
.53079 .09151 Mdot
.38273 .19065 Mdot
.07425 .25701 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .00179 Mdot
.49577 .00572 Mdot
.48652 .0182 Mdot
.45707 .05751 Mdot
.36402 .16879 Mdot
.09091 .24856 Mdot
.68873 .11181 Mdot
.50782 .10456 Mdot
.33863 .22981 Mdot
.96679 .19925 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.4977 .00311 Mdot
.49266 .00991 Mdot
.47662 .03151 Mdot
.42564 .09796 Mdot
.26713 .24465 Mdot
.87127 .13791 Mdot
.64813 .01957 Mdot
.61646 .53902 Mdot
.74431 .39157 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50449 .61197 Mdot
.5143 .59873 Mdot
.54553 .55709 Mdot
.64414 .441 Mdot
.93058 .37867 Mdot
.31788 .513 Mdot
.48784 .52426 Mdot
.63957 .41083 Mdot
.97484 .3876 Mdot
.49977 .00031 Mdot
.49928 .00098 Mdot
.4977 .00311 Mdot
.49266 .00991 Mdot
.47663 .03149 Mdot
.42567 .09792 Mdot
.26723 .2446 Mdot
.87146 .13798 Mdot
.64821 .0196 Mdot
.6165 .53902 Mdot
.74436 .39156 Mdot
.1108 .48618 Mdot
.5011 .61655 Mdot
.50351 .6133 Mdot
.51117 .60295 Mdot
.53559 .57023 Mdot
.61294 .4741 Mdot
.84583 .3525 Mdot
.27547 .49816 Mdot
.46943 .52633 Mdot
.61781 .42682 Mdot
.92721 .36166 Mdot
.34203 .48522 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.4867 .01796 Mdot
.45765 .05676 Mdot
.36581 .16694 Mdot
.0957 .25041 Mdot
.69054 .11304 Mdot
.50764 .10596 Mdot
.33618 .2324 Mdot
.96016 .19585 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49815 .0025 Mdot
.4941 .00797 Mdot
.48121 .02535 Mdot
.44019 .0795 Mdot
.31156 .21614 Mdot
.96184 .1811 Mdot
.66881 .05234 Mdot
.58412 .59598 Mdot
.61981 .49511 Mdot
.81871 .3611 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50722 .60829 Mdot
.52299 .58705 Mdot
.57313 .52161 Mdot
.72915 .37533 Mdot
.12185 .47757 Mdot
.34912 .59742 Mdot
.38247 .07871 Mdot
.25512 .22617 Mdot
.88917 .13153 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50793 .60732 Mdot
.52527 .58399 Mdot
.58035 .51263 Mdot
.7509 .36508 Mdot
.16019 .48975 Mdot
.36775 .59872 Mdot
.39899 .06817 Mdot
.28869 .21138 Mdot
.94668 .16286 Mdot
.5004 .61749 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51302 .60045 Mdot
.54146 .56245 Mdot
.6314 .45401 Mdot
.8968 .3649 Mdot
.30638 .50329 Mdot
.49204 .51066 Mdot
.66578 .3833 Mdot
.04559 .42498 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.5056 .61047 Mdot
.51783 .59397 Mdot
.55676 .54246 Mdot
.67904 .40934 Mdot
.01671 .4248 Mdot
.32936 .55438 Mdot
.43235 .61522 Mdot
.43691 .05416 Mdot
.34928 .17391 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01089 Mdot
.47431 .03461 Mdot
.41832 .10705 Mdot
.2451 .25453 Mdot
.83327 .12672 Mdot
.62824 .02029 Mdot
.59541 .55508 Mdot
.69726 .41556 Mdot
.02487 .43852 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.51219 .60157 Mdot
.53883 .56593 Mdot
.62314 .46282 Mdot
.87429 .35802 Mdot
.29499 .49971 Mdot
.48644 .51226 Mdot
.65758 .3889 Mdot
.02832 .41502 Mdot
.3568 .53057 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49005 .01343 Mdot
.46832 .04261 Mdot
.39938 .1298 Mdot
.18936 .26676 Mdot
.75773 .11939 Mdot
.56455 .06118 Mdot
.46556 .09286 Mdot
.31532 .22815 Mdot
.49991 .00012 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49047 .01287 Mdot
.46964 .04085 Mdot
.40353 .12491 Mdot
.20143 .26563 Mdot
.77162 .11945 Mdot
.57835 .04971 Mdot
.49791 .05165 Mdot
.41433 .12729 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00277 Mdot
.49347 .00882 Mdot
.4792 .02804 Mdot
.43382 .08764 Mdot
.29202 .23007 Mdot
.91975 .15879 Mdot
.66282 .03283 Mdot
.6097 .55704 Mdot
.70839 .41451 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.51011 .60438 Mdot
.5322 .57474 Mdot
.60225 .48634 Mdot
.81534 .35105 Mdot
.24732 .49858 Mdot
.44061 .55236 Mdot
.54687 .50954 Mdot
.72242 .36421 Mdot
.13312 .47372 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46947 .04107 Mdot
.40302 .12552 Mdot
.19992 .26582 Mdot
.76982 .11942 Mdot
.5766 .05112 Mdot
.49389 .05679 Mdot
.402 .142 Mdot
.17224 .27228 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00286 Mdot
.49326 .0091 Mdot
.47854 .02894 Mdot
.43172 .09031 Mdot
.28559 .23418 Mdot
.90668 .15254 Mdot
.65986 .02803 Mdot
.6145 .54884 Mdot
.72646 .40291 Mdot
.07454 .46951 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00367 Mdot
.49136 .01167 Mdot
.47247 .03707 Mdot
.41249 .11417 Mdot
.22776 .26028 Mdot
.80662 .12197 Mdot
.60927 .02845 Mdot
.56324 .58939 Mdot
.60959 .49563 Mdot
.80765 .35766 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51039 .604 Mdot
.53309 .57354 Mdot
.60508 .48305 Mdot
.82348 .35096 Mdot
.25562 .49841 Mdot
.44917 .54473 Mdot
.56778 .48378 Mdot
.78501 .33979 Mdot
.23522 .4867 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48855 .01545 Mdot
.46355 .04895 Mdot
.38434 .14698 Mdot
.14653 .26442 Mdot
.71868 .11973 Mdot
.52496 .09669 Mdot
.36851 .20518 Mdot
.03652 .23874 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47748 .03035 Mdot
.42838 .09453 Mdot
.27542 .2402 Mdot
.88678 .14387 Mdot
.654 .02236 Mdot
.61782 .54087 Mdot
.74267 .39348 Mdot
.106 .48465 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50831 .6068 Mdot
.52649 .58236 Mdot
.5842 .50789 Mdot
.76242 .3608 Mdot
.17864 .49376 Mdot
.37972 .59494 Mdot
.41709 .05034 Mdot
.33563 .17705 Mdot
.04916 .2219 Mdot
.50012 .61788 Mdot
.50037 .61754 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51185 .60203 Mdot
.53774 .56737 Mdot
.61972 .46655 Mdot
.86483 .35577 Mdot
.28918 .49887 Mdot
.48199 .51553 Mdot
.64784 .39735 Mdot
.5012 .61641 Mdot
.50382 .61288 Mdot
.51216 .60161 Mdot
.53874 .56605 Mdot
.62286 .46313 Mdot
.87349 .35782 Mdot
.29453 .49963 Mdot
.48612 .51248 Mdot
.6569 .38947 Mdot
.02673 .41413 Mdot
.35665 .52977 Mdot
.50019 .61778 Mdot
.5006 .61723 Mdot
.5019 .61547 Mdot
.50605 .60987 Mdot
.51926 .59205 Mdot
.5613 .53661 Mdot
.69305 .39841 Mdot
.0484 .44259 Mdot
.33227 .57086 Mdot
.40859 .03299 Mdot
.35521 .14945 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61507 Mdot
.507 .60858 Mdot
.52229 .58798 Mdot
.57092 .52439 Mdot
.72243 .37906 Mdot
.1091 .47246 Mdot
.34464 .59468 Mdot
.38243 .07599 Mdot
.25947 .22328 Mdot
.50034 .61758 Mdot
.50108 .61657 Mdot
.50345 .61338 Mdot
.51098 .6032 Mdot
.53499 .57103 Mdot
.61104 .47624 Mdot
.84047 .3519 Mdot
.27109 .49815 Mdot
.46507 .53027 Mdot
.60708 .43832 Mdot
.89786 .35 Mdot
.50028 .61765 Mdot
.50091 .61681 Mdot
.50289 .61414 Mdot
.50919 .60562 Mdot
.52929 .57862 Mdot
.59306 .49718 Mdot
.78861 .35395 Mdot
.2159 .49813 Mdot
.40992 .57725 Mdot
.47591 .5995 Mdot
.50591 .59402 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49434 .00764 Mdot
.48198 .02432 Mdot
.44263 .07636 Mdot
.31908 .21022 Mdot
.97894 .19075 Mdot
.6703 .06133 Mdot
.57107 .61564 Mdot
.57494 .54871 Mdot
.68711 .41253 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60664 Mdot
.52686 .58186 Mdot
.5854 .50643 Mdot
.76597 .35963 Mdot
.18407 .4947 Mdot
.38364 .59322 Mdot
.42379 .04316 Mdot
.35395 .16034 Mdot
.09452 .2429 Mdot
.50088 .61684 Mdot
.50282 .61423 Mdot
.50897 .60592 Mdot
.52857 .57958 Mdot
.59079 .4999 Mdot
.78194 .35531 Mdot
.20703 .49751 Mdot
.40204 .58271 Mdot
.4592 .00208 Mdot
.45582 .04251 Mdot
.38703 .13866 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51225 .60149 Mdot
.53902 .56568 Mdot
.62373 .46218 Mdot
.87591 .35845 Mdot
.29592 .49989 Mdot
.48708 .51186 Mdot
.65888 .38784 Mdot
.03134 .41671 Mdot
.35709 .53209 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50701 .60857 Mdot
.52232 .58795 Mdot
.571 .52429 Mdot
.72269 .37891 Mdot
.1096 .47267 Mdot
.3448 .59481 Mdot
.38238 .07615 Mdot
.25917 .22345 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50304 .61392 Mdot
.5097 .60494 Mdot
.53089 .57648 Mdot
.59813 .49116 Mdot
.80342 .35185 Mdot
.23412 .49866 Mdot
.42728 .56376 Mdot
.5151 .54978 Mdot
.62554 .4451 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51023 .60422 Mdot
.53258 .57423 Mdot
.60346 .48493 Mdot
.81883 .35097 Mdot
.25095 .49851 Mdot
.44435 .54906 Mdot
.55596 .49825 Mdot
.74978 .3507 Mdot
.18233 .48511 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50612 .60977 Mdot
.5195 .59174 Mdot
.56204 .53567 Mdot
.69531 .39675 Mdot
.05336 .44529 Mdot
.33286 .57329 Mdot
.40526 .03799 Mdot
.34378 .16065 Mdot
.49974 .00035 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49174 .01116 Mdot
.47368 .03545 Mdot
.41632 .1095 Mdot
.23914 .2567 Mdot
.82378 .12473 Mdot
.62196 .02241 Mdot
.58569 .56479 Mdot
.67184 .43468 Mdot
.96851 .40568 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00355 Mdot
.49164 .01129 Mdot
.47337 .03587 Mdot
.41533 .11071 Mdot
.2362 .2577 Mdot
.81923 .1239 Mdot
.61876 .02373 Mdot
.58036 .5704 Mdot
.65744 .44711 Mdot
.93401 .38767 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00565 Mdot
.48667 .018 Mdot
.45754 .05689 Mdot
.36549 .16727 Mdot
.09484 .25008 Mdot
.6902 .11283 Mdot
.50765 .10574 Mdot
.33656 .232 Mdot
.96118 .19636 Mdot
.64346 .08066 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00263 Mdot
.49379 .00839 Mdot
.48022 .02668 Mdot
.43705 .08353 Mdot
.30189 .22331 Mdot
.94057 .16948 Mdot
.66634 .04186 Mdot
.59862 .57421 Mdot
.66953 .44512 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51193 .60193 Mdot
.53799 .56705 Mdot
.62048 .46572 Mdot
.86693 .35624 Mdot
.29053 .49902 Mdot
.48309 .51468 Mdot
.65032 .39513 Mdot
.01098 .40531 Mdot
.35518 .52179 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00559 Mdot
.48683 .01778 Mdot
.45806 .05622 Mdot
.3671 .1656 Mdot
.09916 .25169 Mdot
.69192 .11386 Mdot
.50769 .10673 Mdot
.335 .23373 Mdot
.95681 .19418 Mdot
.64262 .07897 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48973 .01387 Mdot
.46729 .04398 Mdot
.39613 .13358 Mdot
.18 .26708 Mdot
.74785 .11955 Mdot
.55442 .07008 Mdot
.44104 .1235 Mdot
.24122 .27082 Mdot
.80303 .13138 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48819 .01595 Mdot
.46239 .05049 Mdot
.38069 .15103 Mdot
.13632 .26251 Mdot
.71157 .11924 Mdot
.51863 .10201 Mdot
.35358 .2194 Mdot
.99858 .21808 Mdot
.64572 .1011 Mdot
.50055 .6173 Mdot
.50174 .61568 Mdot
.50554 .61055 Mdot
.51765 .59421 Mdot
.55619 .5432 Mdot
.67729 .41078 Mdot
.01262 .42247 Mdot
.32905 .55219 Mdot
.43558 .61029 Mdot
.4481 .03952 Mdot
.38416 .13768 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49748 .00341 Mdot
.49197 .01085 Mdot
.47441 .03447 Mdot
.41864 .10665 Mdot
.24607 .25415 Mdot
.83485 .12708 Mdot
.62922 .02002 Mdot
.59683 .55372 Mdot
.70089 .41315 Mdot
.03241 .44298 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52047 .59043 Mdot
.56514 .53171 Mdot
.70482 .39007 Mdot
.07367 .45595 Mdot
.33592 .58251 Mdot
.39339 .05608 Mdot
.30265 .19563 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .01421 Mdot
.46649 .04505 Mdot
.3936 .1365 Mdot
.17274 .267 Mdot
.74072 .1197 Mdot
.54704 .07673 Mdot
.42289 .14545 Mdot
.18755 .28178 Mdot
.73162 .13522 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46875 .04203 Mdot
.40074 .1282 Mdot
.19332 .26648 Mdot
.76214 .11937 Mdot
.569 .05738 Mdot
.47615 .07941 Mdot
.34766 .20004 Mdot
.02399 .2222 Mdot
.50032 .6176 Mdot
.50101 .61667 Mdot
.50323 .61368 Mdot
.51028 .60416 Mdot
.53273 .57403 Mdot
.60393 .48439 Mdot
.82017 .35095 Mdot
.25232 .49848 Mdot
.44576 .5478 Mdot
.5594 .494 Mdot
.76009 .34675 Mdot
.50118 .61643 Mdot
.50377 .61294 Mdot
.51202 .6018 Mdot
.53829 .56665 Mdot
.62144 .46468 Mdot
.86957 .35685 Mdot
.29218 .49925 Mdot
.48438 .5137 Mdot
.65319 .39263 Mdot
.0179 .40919 Mdot
.35582 .5253 Mdot
.5 .61803 Mdot
.50001 .61801 Mdot
.50005 .61797 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50477 .61159 Mdot
.51521 .59751 Mdot
.54841 .55332 Mdot
.65313 .43227 Mdot
.9537 .38995 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60547 Mdot
.52963 .57816 Mdot
.59414 .4959 Mdot
.79176 .3534 Mdot
.21995 .49832 Mdot
.41364 .57451 Mdot
.48407 .58925 Mdot
.53063 .56103 Mdot
.62287 .45811 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50825 .6069 Mdot
.52627 .58266 Mdot
.58351 .50874 Mdot
.76035 .36151 Mdot
.17541 .49315 Mdot
.37748 .59583 Mdot
.4134 .05418 Mdot
.32574 .18533 Mdot
.02588 .20921 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .00441 Mdot
.4896 .01404 Mdot
.46688 .04453 Mdot
.39482 .13509 Mdot
.17624 .26707 Mdot
.74411 .11963 Mdot
.55055 .07355 Mdot
.43153 .13509 Mdot
.21296 .27865 Mdot
.76209 .13153 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50125 .61635 Mdot
.50397 .61266 Mdot
.51266 .60094 Mdot
.54032 .56395 Mdot
.62783 .45779 Mdot
.88712 .36169 Mdot
.30189 .50147 Mdot
.4905 .51027 Mdot
.66486 .38334 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47977 .02729 Mdot
.43561 .08536 Mdot
.29749 .22639 Mdot
.93118 .16456 Mdot
.66492 .0376 Mdot
.60407 .56589 Mdot
.68845 .42924 Mdot
.99392 .42361 Mdot
.49974 .00034 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49175 .01115 Mdot
.47371 .03541 Mdot
.41643 .10937 Mdot
.23946 .25659 Mdot
.82429 .12483 Mdot
.62231 .02228 Mdot
.58626 .5642 Mdot
.67336 .43344 Mdot
.97204 .40765 Mdot
.49978 .0003 Mdot
.49929 .00095 Mdot
.49775 .00304 Mdot
.49283 .00969 Mdot
.47714 .03081 Mdot
.42729 .09589 Mdot
.27214 .24201 Mdot
.88056 .14139 Mdot
.65179 .02105 Mdot
.61772 .53963 Mdot
.74458 .39217 Mdot
.11003 .48624 Mdot
.50126 .61633 Mdot
.50401 .61261 Mdot
.51278 .60078 Mdot
.5407 .56346 Mdot
.629 .45654 Mdot
.89031 .36271 Mdot
.30343 .50202 Mdot
.49115 .51022 Mdot
.66559 .38294 Mdot
.04598 .42498 Mdot
.35835 .53963 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01559 Mdot
.46324 .04936 Mdot
.38337 .14806 Mdot
.1438 .26396 Mdot
.7167 .11963 Mdot
.52313 .09826 Mdot
.36414 .20947 Mdot
.02521 .23274 Mdot
.64863 .11413 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01802 Mdot
.45751 .05694 Mdot
.36537 .16739 Mdot
.09452 .24996 Mdot
.69008 .11275 Mdot
.50765 .10565 Mdot
.3367 .23184 Mdot
.96158 .19657 Mdot
.64353 .08082 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.4927 .00985 Mdot
.47676 .03132 Mdot
.42607 .09742 Mdot
.26845 .24397 Mdot
.87369 .13879 Mdot
.64913 .0199 Mdot
.61693 .53903 Mdot
.74476 .39157 Mdot
.11119 .48646 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50406 .61254 Mdot
.51295 .60055 Mdot
.54124 .56275 Mdot
.6307 .45475 Mdot
.8949 .36424 Mdot
.30554 .5029 Mdot
.49184 .51046 Mdot
.6659 .38303 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00425 Mdot
.48998 .01353 Mdot
.4681 .0429 Mdot
.39868 .13062 Mdot
.18733 .26687 Mdot
.75552 .11942 Mdot
.5623 .06312 Mdot
.46016 .09967 Mdot
.29889 .24031 Mdot
.91007 .1613 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51328 .60011 Mdot
.54229 .56136 Mdot
.63399 .45131 Mdot
.90375 .36742 Mdot
.30925 .50486 Mdot
.49237 .51194 Mdot
.66404 .3854 Mdot
.04045 .42249 Mdot
.35684 .53802 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48952 .01415 Mdot
.46662 .04487 Mdot
.39402 .13602 Mdot
.17394 .26703 Mdot
.74187 .11968 Mdot
.54823 .07565 Mdot
.42582 .14195 Mdot
.19614 .28113 Mdot
.74126 .13381 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01605 Mdot
.46215 .05081 Mdot
.37994 .15185 Mdot
.13425 .26206 Mdot
.71023 .1191 Mdot
.51752 .10289 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.4933 .00905 Mdot
.47865 .02879 Mdot
.43206 .08988 Mdot
.28664 .23353 Mdot
.90878 .15352 Mdot
.66038 .02875 Mdot
.61386 .55001 Mdot
.72392 .40444 Mdot
.50077 .61699 Mdot
.50247 .6147 Mdot
.50786 .60742 Mdot
.52504 .5843 Mdot
.57961 .51354 Mdot
.74869 .366 Mdot
.15648 .4888 Mdot
.36559 .59911 Mdot
.3962 .07063 Mdot
.28193 .21521 Mdot
.93371 .15552 Mdot
.50009 .61791 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50971 .60491 Mdot
.53094 .57641 Mdot
.5983 .49097 Mdot
.8039 .3518 Mdot
.23467 .49866 Mdot
.42782 .56331 Mdot
.51637 .54815 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48949 .0142 Mdot
.46652 .04501 Mdot
.39369 .1364 Mdot
.173 .26701 Mdot
.74097 .1197 Mdot
.5473 .07649 Mdot
.42353 .14469 Mdot
.18941 .28167 Mdot
.49982 .00024 Mdot
.49943 .00076 Mdot
.4982 .00244 Mdot
.49425 .00776 Mdot
.48169 .0247 Mdot
.44172 .07753 Mdot
.31628 .21246 Mdot
.9725 .1871 Mdot
.66977 .05791 Mdot
.57607 .60808 Mdot
.59218 .52732 Mdot
.73896 .38013 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49118 .01191 Mdot
.47191 .03782 Mdot
.41071 .11633 Mdot
.22249 .26167 Mdot
.7991 .12109 Mdot
.60317 .03201 Mdot
.55138 .60324 Mdot
.57531 .536 Mdot
.70806 .39354 Mdot
.50024 .61772 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.50761 .60776 Mdot
.52424 .58538 Mdot
.57708 .51668 Mdot
.74106 .36937 Mdot
.14341 .48504 Mdot
.35859 .59956 Mdot
.38848 .07665 Mdot
.26445 .22359 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.51011 .60438 Mdot
.5322 .57474 Mdot
.60225 .48634 Mdot
.81533 .35105 Mdot
.24732 .49858 Mdot
.44061 .55237 Mdot
.54686 .50955 Mdot
.72238 .36423 Mdot
.13305 .4737 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49841 .00215 Mdot
.49492 .00686 Mdot
.48381 .02184 Mdot
.44847 .06879 Mdot
.33717 .19475 Mdot
.02206 .21513 Mdot
.67397 .08411 Mdot
.53788 .04933 Mdot
.45806 .08776 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00488 Mdot
.48849 .01554 Mdot
.46335 .04921 Mdot
.38373 .14767 Mdot
.14479 .26413 Mdot
.71742 .11967 Mdot
.52378 .0977 Mdot
.3657 .20795 Mdot
.02922 .23489 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49324 .00914 Mdot
.47845 .02905 Mdot
.43144 .09066 Mdot
.28475 .2347 Mdot
.905 .15177 Mdot
.65943 .02747 Mdot
.61498 .54795 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.49541 .00621 Mdot
.48537 .01975 Mdot
.45341 .06233 Mdot
.35255 .1803 Mdot
.06082 .23532 Mdot
.68007 .10179 Mdot
.51537 .08756 Mdot
.37369 .19274 Mdot
.06183 .24863 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00369 Mdot
.4913 .01175 Mdot
.4723 .0373 Mdot
.41195 .11483 Mdot
.22615 .26072 Mdot
.80429 .12168 Mdot
.60742 .02949 Mdot
.5597 .59346 Mdot
.59946 .50714 Mdot
.77889 .36202 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49119 .0119 Mdot
.47193 .03779 Mdot
.41077 .11625 Mdot
.22268 .26162 Mdot
.79937 .12112 Mdot
.60339 .03187 Mdot
.55182 .60271 Mdot
.57662 .53439 Mdot
.71195 .39104 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00295 Mdot
.49305 .00938 Mdot
.47787 .02983 Mdot
.42961 .09297 Mdot
.27918 .23805 Mdot
.89401 .14689 Mdot
.65633 .02417 Mdot
.61723 .54309 Mdot
.73849 .39593 Mdot
.09786 .48104 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.48751 .01686 Mdot
.46023 .05335 Mdot
.3739 .1584 Mdot
.11761 .25777 Mdot
.70052 .1173 Mdot
.51073 .10736 Mdot
.33702 .2334 Mdot
.95938 .19614 Mdot
.49967 .00044 Mdot
.49895 .00141 Mdot
.49667 .0045 Mdot
.48939 .01433 Mdot
.46621 .04541 Mdot
.39273 .1375 Mdot
.17026 .26691 Mdot
.7384 .11975 Mdot
.54463 .07892 Mdot
.41694 .15248 Mdot
.17022 .28187 Mdot
.71415 .13805 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00378 Mdot
.49108 .01205 Mdot
.47158 .03826 Mdot
.40968 .11757 Mdot
.21945 .2624 Mdot
.79488 .12068 Mdot
.59961 .03425 Mdot
.54418 .61185 Mdot
.55418 .56259 Mdot
.6439 .44663 Mdot
.49959 .00055 Mdot
.49871 .00174 Mdot
.49589 .00556 Mdot
.4869 .01769 Mdot
.45827 .05593 Mdot
.36778 .16489 Mdot
.10098 .25235 Mdot
.69268 .11427 Mdot
.50778 .10706 Mdot
.33456 .23426 Mdot
.95552 .19356 Mdot
.64233 .07851 Mdot
.50081 .61693 Mdot
.50259 .61453 Mdot
.50826 .60688 Mdot
.52631 .5826 Mdot
.58363 .50859 Mdot
.76072 .36138 Mdot
.17599 .49326 Mdot
.37789 .59568 Mdot
.41405 .05351 Mdot
.32748 .18391 Mdot
.02991 .21147 Mdot
.50127 .61632 Mdot
.50404 .61258 Mdot
.51286 .60067 Mdot
.54096 .56312 Mdot
.62981 .45568 Mdot
.8925 .36343 Mdot
.30446 .50243 Mdot
.49152 .51029 Mdot
.66585 .38289 Mdot
.04633 .42523 Mdot
.35829 .53992 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49725 .00371 Mdot
.49125 .01182 Mdot
.47213 .03752 Mdot
.41143 .11546 Mdot
.22461 .26113 Mdot
.80209 .12142 Mdot
.60563 .03052 Mdot
.55625 .59749 Mdot
.58949 .51883 Mdot
.75 .37129 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60341 Mdot
.53449 .57168 Mdot
.60949 .47799 Mdot
.83608 .35151 Mdot
.26733 .49818 Mdot
.46125 .53375 Mdot
.59763 .44881 Mdot
.87144 .34217 Mdot
.31779 .47653 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49848 .00205 Mdot
.49517 .00652 Mdot
.48462 .02076 Mdot
.45102 .06545 Mdot
.34512 .18742 Mdot
.04187 .22579 Mdot
.67654 .09369 Mdot
.52495 .07066 Mdot
.41062 .14922 Mdot
.16917 .27815 Mdot
.50015 .61783 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50482 .61153 Mdot
.51534 .59732 Mdot
.54885 .55274 Mdot
.6545 .43097 Mdot
.95717 .39175 Mdot
.32331 .52391 Mdot
.47561 .54644 Mdot
.59146 .46624 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48995 .01357 Mdot
.46799 .04304 Mdot
.39835 .131 Mdot
.18639 .26692 Mdot
.75451 .11943 Mdot
.56127 .06402 Mdot
.45769 .10279 Mdot
.29138 .24537 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48859 .0154 Mdot
.46367 .04879 Mdot
.38472 .14656 Mdot
.14757 .26459 Mdot
.71945 .11976 Mdot
.52568 .09606 Mdot
.37025 .20345 Mdot
.04106 .2411 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51192 .60193 Mdot
.53798 .56706 Mdot
.62046 .46575 Mdot
.86686 .35622 Mdot
.29048 .49902 Mdot
.48305 .5147 Mdot
.65025 .3952 Mdot
.0108 .4052 Mdot
.35516 .52169 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49806 .00263 Mdot
.4938 .00837 Mdot
.48026 .02662 Mdot
.4372 .08334 Mdot
.30235 .22298 Mdot
.94156 .17001 Mdot
.66648 .04232 Mdot
.598 .57514 Mdot
.66741 .44701 Mdot
.94413 .39628 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49756 .0033 Mdot
.49221 .01052 Mdot
.47519 .03343 Mdot
.42111 .1036 Mdot
.25347 .25111 Mdot
.84716 .13022 Mdot
.63646 .01865 Mdot
.60628 .54532 Mdot
.72392 .39976 Mdot
.0771 .46847 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50749 .60792 Mdot
.52385 .5859 Mdot
.57584 .51822 Mdot
.73734 .37114 Mdot
.13683 .48293 Mdot
.35543 .59927 Mdot
.3858 .07825 Mdot
.25919 .22555 Mdot
.89425 .13457 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48836 .01571 Mdot
.46294 .04976 Mdot
.38243 .14911 Mdot
.14116 .26348 Mdot
.71485 .11952 Mdot
.52146 .09968 Mdot
.36017 .21327 Mdot
.01509 .22724 Mdot
.64741 .1093 Mdot
.50087 .61686 Mdot
.50278 .61428 Mdot
.50885 .60608 Mdot
.5282 .58007 Mdot
.58963 .5013 Mdot
.77852 .35611 Mdot
.20231 .49709 Mdot
.39801 .5853 Mdot
.45098 .01199 Mdot
.43158 .07348 Mdot
.31268 .20973 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50928 .6055 Mdot
.52955 .57827 Mdot
.5939 .49618 Mdot
.79106 .35352 Mdot
.21906 .49828 Mdot
.41282 .57512 Mdot
.48225 .59154 Mdot
.52512 .56835 Mdot
.6055 .47756 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49834 .00225 Mdot
.4947 .00716 Mdot
.48311 .02279 Mdot
.44623 .0717 Mdot
.33022 .2009 Mdot
.00516 .20568 Mdot
.67236 .07534 Mdot
.55046 .02935 Mdot
.50297 .02659 Mdot
.45995 .06332 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50641 .60937 Mdot
.52042 .59049 Mdot
.56498 .53191 Mdot
.70433 .3904 Mdot
.07265 .45543 Mdot
.33574 .58208 Mdot
.39391 .05528 Mdot
.30447 .19426 Mdot
.99015 .18513 Mdot
.5004 .61749 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60041 Mdot
.54156 .56232 Mdot
.63171 .45368 Mdot
.89764 .3652 Mdot
.30674 .50347 Mdot
.49212 .51077 Mdot
.66567 .38346 Mdot
.04522 .42482 Mdot
.50046 .61742 Mdot
.50146 .61607 Mdot
.50464 .61177 Mdot
.51477 .59809 Mdot
.54704 .55512 Mdot
.64884 .43639 Mdot
.94274 .38445 Mdot
.32069 .51767 Mdot
.48308 .53333 Mdot
.62013 .43224 Mdot
.92075 .36177 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48819 .01595 Mdot
.46239 .05049 Mdot
.38069 .15103 Mdot
.13632 .26251 Mdot
.71157 .11924 Mdot
.51863 .10201 Mdot
.35358 .2194 Mdot
.99859 .21809 Mdot
.64572 .1011 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49005 .01344 Mdot
.4683 .04263 Mdot
.39932 .12987 Mdot
.18919 .26677 Mdot
.75754 .11939 Mdot
.56436 .06134 Mdot
.46511 .09343 Mdot
.31393 .22923 Mdot
.50012 .61787 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.5127 .60089 Mdot
.54044 .5638 Mdot
.6282 .45739 Mdot
.88812 .36201 Mdot
.30238 .50164 Mdot
.49072 .51024 Mdot
.66514 .38317 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50033 .61758 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60341 Mdot
.53449 .57169 Mdot
.60948 .478 Mdot
.83606 .35151 Mdot
.2673 .49818 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48784 .01642 Mdot
.46127 .05197 Mdot
.37719 .15486 Mdot
.12662 .26024 Mdot
.70554 .11842 Mdot
.51393 .10552 Mdot
.34319 .22849 Mdot
.9735 .20403 Mdot
.64337 .08838 Mdot
.5002 .61776 Mdot
.50065 .61716 Mdot
.50207 .61523 Mdot
.5066 .60912 Mdot
.52103 .58967 Mdot
.56692 .52945 Mdot
.71026 .38648 Mdot
.08492 .46152 Mdot
.33816 .587 Mdot
.38837 .06418 Mdot
.28453 .20826 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50184 .61554 Mdot
.50587 .6101 Mdot
.51871 .5928 Mdot
.55954 .53887 Mdot
.68763 .40252 Mdot
.03634 .43591 Mdot
.33102 .56475 Mdot
.41723 .02004 Mdot
.3848 .11775 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.4954 .00621 Mdot
.48534 .01978 Mdot
.45333 .06243 Mdot
.35232 .18051 Mdot
.06024 .23504 Mdot
.67994 .10156 Mdot
.51561 .08711 Mdot
.37466 .19166 Mdot
.06454 .24987 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49046 .01288 Mdot
.46962 .04087 Mdot
.40349 .12496 Mdot
.2013 .26565 Mdot
.77146 .11945 Mdot
.5782 .04984 Mdot
.49756 .0521 Mdot
.41327 .12858 Mdot
.20522 .27032 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49345 .00885 Mdot
.47912 .02815 Mdot
.43357 .08796 Mdot
.29124 .23058 Mdot
.91816 .15801 Mdot
.66249 .03221 Mdot
.61038 .55592 Mdot
.71088 .41281 Mdot
.04294 .45214 Mdot
.49959 .00055 Mdot
.49871 .00175 Mdot
.49588 .00556 Mdot
.48688 .01772 Mdot
.45821 .05601 Mdot
.36759 .16508 Mdot
.10048 .25217 Mdot
.69247 .11416 Mdot
.50775 .10697 Mdot
.33467 .23413 Mdot
.95584 .19372 Mdot
.64241 .07862 Mdot
.50118 .61644 Mdot
.50377 .61294 Mdot
.51201 .60182 Mdot
.53824 .56671 Mdot
.62128 .46485 Mdot
.86914 .35675 Mdot
.29191 .49921 Mdot
.48417 .51386 Mdot
.65274 .39302 Mdot
.01682 .40858 Mdot
.35572 .52476 Mdot
.50074 .61704 Mdot
.50235 .61485 Mdot
.5075 .60791 Mdot
.52388 .58585 Mdot
.57596 .51808 Mdot
.73769 .37097 Mdot
.13745 .48313 Mdot
.35572 .59931 Mdot
.38602 .07814 Mdot
.25959 .22541 Mdot
.89487 .13488 Mdot
.49984 .00021 Mdot
.49951 .00067 Mdot
.49842 .00213 Mdot
.49498 .00679 Mdot
.48399 .0216 Mdot
.44904 .06805 Mdot
.33893 .19315 Mdot
.02641 .21752 Mdot
.67445 .08629 Mdot
.53484 .05425 Mdot
.44706 .10243 Mdot
.28133 .24712 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50653 .60922 Mdot
.52079 .59 Mdot
.56616 .53042 Mdot
.70792 .388 Mdot
.08012 .45918 Mdot
.33715 .58515 Mdot
.39036 .06091 Mdot
.29181 .20339 Mdot
.96272 .16914 Mdot
.50062 .61719 Mdot
.50199 .61534 Mdot
.50634 .60947 Mdot
.5202 .59079 Mdot
.56429 .5328 Mdot
.7022 .39186 Mdot
.06816 .45313 Mdot
.33498 .58014 Mdot
.39629 .05159 Mdot
.31281 .18779 Mdot
.00896 .19609 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48656 .01815 Mdot
.4572 .05735 Mdot
.3644 .16839 Mdot
.09193 .24896 Mdot
.68911 .11208 Mdot
.50776 .10489 Mdot
.33803 .23044 Mdot
.96518 .19841 Mdot
.64414 .08232 Mdot
.49979 .00029 Mdot
.49933 .00091 Mdot
.49785 .0029 Mdot
.49316 .00924 Mdot
.4782 .02939 Mdot
.43066 .09165 Mdot
.28236 .23616 Mdot
.90024 .14962 Mdot
.65816 .02597 Mdot
.61614 .54563 Mdot
.73329 .3989 Mdot
.08785 .47627 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51113 .60301 Mdot
.53544 .57043 Mdot
.61247 .47463 Mdot
.8445 .35234 Mdot
.2744 .49815 Mdot
.46838 .52727 Mdot
.61523 .42954 Mdot
.92022 .35864 Mdot
.33993 .48325 Mdot
.50104 .61663 Mdot
.5033 .61357 Mdot
.51052 .60383 Mdot
.5335 .573 Mdot
.60636 .48158 Mdot
.82715 .35103 Mdot
.25917 .49833 Mdot
.45285 .54141 Mdot
.57683 .47292 Mdot
.81164 .3363 Mdot
.26749 .48295 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50531 .61086 Mdot
.51693 .59519 Mdot
.55389 .54618 Mdot
.67014 .41683 Mdot
.9957 .41284 Mdot
.32771 .54315 Mdot
.44888 .58973 Mdot
.49467 .59468 Mdot
.53246 .56479 Mdot
.50002 .61801 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50653 .60922 Mdot
.52079 .59 Mdot
.56615 .53043 Mdot
.70789 .38802 Mdot
.08007 .45915 Mdot
.33714 .58513 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49798 .00272 Mdot
.49358 .00868 Mdot
.47954 .0276 Mdot
.43488 .0863 Mdot
.29525 .22792 Mdot
.92648 .16215 Mdot
.6641 .03558 Mdot
.60653 .56207 Mdot
.69709 .4226 Mdot
.01331 .43493 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00321 Mdot
.49243 .01023 Mdot
.47588 .03251 Mdot
.42328 .10091 Mdot
.25999 .24817 Mdot
.85845 .13357 Mdot
.64233 .01852 Mdot
.61235 .54084 Mdot
.73726 .39377 Mdot
.10013 .48059 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60224 Mdot
.53724 .56803 Mdot
.61814 .46829 Mdot
.86043 .35486 Mdot
.28625 .4986 Mdot
.4795 .51755 Mdot
.64209 .40263 Mdot
.99062 .39394 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48987 .01368 Mdot
.46774 .04338 Mdot
.39755 .13193 Mdot
.18407 .267 Mdot
.75206 .11947 Mdot
.55875 .06623 Mdot
.45159 .11042 Mdot
.27292 .25644 Mdot
.858 .14158 Mdot
.50057 .61726 Mdot
.50181 .61558 Mdot
.50578 .61023 Mdot
.51841 .5932 Mdot
.5586 .54009 Mdot
.68471 .40479 Mdot
.02975 .43221 Mdot
.33042 .56131 Mdot
.4222 .01256 Mdot
.40187 .09788 Mdot
.2435 .2453 Mdot
.50057 .61727 Mdot
.50181 .61558 Mdot
.50578 .61023 Mdot
.5184 .59321 Mdot
.55857 .54013 Mdot
.68461 .40487 Mdot
.02952 .43208 Mdot
.3304 .56119 Mdot
.42238 .0123 Mdot
.40248 .09716 Mdot
.24527 .24464 Mdot
.50023 .61772 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50757 .6078 Mdot
.52413 .58552 Mdot
.57674 .51711 Mdot
.74004 .36985 Mdot
.14161 .48448 Mdot
.3577 .59951 Mdot
.38767 .07718 Mdot
.26279 .22425 Mdot
.50012 .61787 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51272 .60086 Mdot
.54051 .56371 Mdot
.62842 .45716 Mdot
.88871 .3622 Mdot
.30267 .50174 Mdot
.49084 .51022 Mdot
.66528 .38309 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01285 Mdot
.46968 .04079 Mdot
.40368 .12473 Mdot
.20187 .26558 Mdot
.77215 .11946 Mdot
.57886 .04931 Mdot
.49908 .05016 Mdot
.41792 .12293 Mdot
.21901 .26769 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01324 Mdot
.46876 .04201 Mdot
.40078 .12815 Mdot
.19343 .26647 Mdot
.76227 .11937 Mdot
.56913 .05728 Mdot
.47645 .07903 Mdot
.34857 .19917 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49846 .00208 Mdot
.4951 .00663 Mdot
.48437 .02109 Mdot
.45025 .06646 Mdot
.34272 .18966 Mdot
.03584 .22261 Mdot
.67565 .09087 Mdot
.52861 .06449 Mdot
.42426 .13209 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .00239 Mdot
.49435 .00763 Mdot
.48201 .02427 Mdot
.44274 .07622 Mdot
.31941 .20996 Mdot
.97969 .19118 Mdot
.67035 .06172 Mdot
.57048 .61653 Mdot
.57291 .55128 Mdot
.68093 .41741 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .0133 Mdot
.46863 .0422 Mdot
.40035 .12866 Mdot
.19218 .26657 Mdot
.76085 .11937 Mdot
.56771 .05848 Mdot
.47309 .08331 Mdot
.33828 .20873 Mdot
.00055 .20924 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.4948 .00702 Mdot
.48344 .02235 Mdot
.44728 .07033 Mdot
.33349 .19804 Mdot
.01305 .21013 Mdot
.67306 .07949 Mdot
.54445 .03881 Mdot
.48165 .05578 Mdot
.50044 .61745 Mdot
.50139 .61616 Mdot
.50442 .61207 Mdot
.51407 .59904 Mdot
.54482 .55804 Mdot
.64189 .44324 Mdot
.92472 .37602 Mdot
.3163 .51095 Mdot
.48957 .52061 Mdot
.6472 .40279 Mdot
.99546 .39859 Mdot
.50126 .61633 Mdot
.50403 .61259 Mdot
.51283 .60071 Mdot
.54086 .56325 Mdot
.62951 .456 Mdot
.89168 .36316 Mdot
.30408 .50227 Mdot
.49139 .51025 Mdot
.66578 .38289 Mdot
.04625 .42517 Mdot
.35832 .53984 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49069 .01257 Mdot
.47034 .03991 Mdot
.40577 .12225 Mdot
.20798 .26468 Mdot
.77972 .1197 Mdot
.58605 .04376 Mdot
.51525 .02964 Mdot
.46728 .05976 Mdot
.50054 .6173 Mdot
.50172 .61571 Mdot
.50548 .61063 Mdot
.51746 .59447 Mdot
.55558 .54399 Mdot
.67539 .41236 Mdot
.00818 .41994 Mdot
.3287 .54981 Mdot
.43909 .60491 Mdot
.46033 .02327 Mdot
.42267 .09217 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50441 .61208 Mdot
.51404 .59908 Mdot
.5447 .55819 Mdot
.64153 .4436 Mdot
.92377 .3756 Mdot
.31603 .51063 Mdot
.48981 .52007 Mdot
.64832 .40163 Mdot
.99848 .40021 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50622 .60963 Mdot
.51981 .59131 Mdot
.56305 .53438 Mdot
.69841 .39452 Mdot
.06007 .44889 Mdot
.33375 .57648 Mdot
.40099 .04442 Mdot
.32911 .17411 Mdot
.04739 .2174 Mdot
.49998 2e-05 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.4981 .00256 Mdot
.49396 .00816 Mdot
.48076 .02595 Mdot
.43877 .08132 Mdot
.30719 .21944 Mdot
.95213 .17573 Mdot
.66779 .04743 Mdot
.59105 .58559 Mdot
.50083 .61691 Mdot
.50264 .61446 Mdot
.50842 .60667 Mdot
.52681 .58193 Mdot
.58524 .50663 Mdot
.76549 .35979 Mdot
.18334 .49458 Mdot
.3831 .59347 Mdot
.42285 .04419 Mdot
.35135 .16281 Mdot
.08791 .24023 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51255 .60109 Mdot
.53995 .56444 Mdot
.62667 .45903 Mdot
.88395 .36072 Mdot
.30028 .50096 Mdot
.48971 .5105 Mdot
.6637 .38412 Mdot
.04219 .42277 Mdot
.35813 .53755 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49256 .01004 Mdot
.47631 .03193 Mdot
.42465 .09919 Mdot
.26416 .24616 Mdot
.86587 .13601 Mdot
.64579 .01898 Mdot
.61508 .53939 Mdot
.74233 .39202 Mdot
.10804 .48465 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49237 .0103 Mdot
.47571 .03273 Mdot
.42275 .10156 Mdot
.25842 .2489 Mdot
.85568 .13271 Mdot
.64095 .01846 Mdot
.61108 .54167 Mdot
.73464 .39482 Mdot
.09581 .47837 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50808 .60712 Mdot
.52574 .58336 Mdot
.58184 .51079 Mdot
.75537 .36333 Mdot
.1675 .49149 Mdot
.37225 .5976 Mdot
.40531 .06226 Mdot
.30458 .20121 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00194 Mdot
.49542 .00618 Mdot
.48542 .01969 Mdot
.45356 .06213 Mdot
.35304 .17981 Mdot
.0621 .23593 Mdot
.68035 .10229 Mdot
.51484 .08855 Mdot
.37157 .19511 Mdot
.05588 .24585 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01453 Mdot
.46572 .04606 Mdot
.39119 .13926 Mdot
.16587 .26666 Mdot
.7344 .11983 Mdot
.54052 .08267 Mdot
.40676 .16425 Mdot
.141 .27852 Mdot
.69034 .14122 Mdot
.5 .61803 Mdot
.50002 .61801 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50051 .61735 Mdot
.50161 .61585 Mdot
.50514 .61108 Mdot
.51639 .59592 Mdot
.55217 .54842 Mdot
.66482 .4215 Mdot
.98281 .4056 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51021 .60424 Mdot
.53253 .57429 Mdot
.60331 .4851 Mdot
.81841 .35097 Mdot
.25052 .49852 Mdot
.4439 .54946 Mdot
.55486 .4996 Mdot
.74649 .35209 Mdot
.17679 .4843 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.5065 .60925 Mdot
.5207 .59011 Mdot
.56588 .53077 Mdot
.70708 .38856 Mdot
.07837 .45831 Mdot
.33681 .58445 Mdot
.39114 .05965 Mdot
.29463 .20143 Mdot
.9687 .1726 Mdot
.50014 .61784 Mdot
.50045 .61742 Mdot
.50144 .61609 Mdot
.50459 .61184 Mdot
.51461 .59832 Mdot
.54651 .55581 Mdot
.64719 .43799 Mdot
.93851 .38239 Mdot
.31978 .51598 Mdot
.48491 .52995 Mdot
.62743 .42404 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48762 .01672 Mdot
.46057 .0529 Mdot
.37498 .15724 Mdot
.12057 .25862 Mdot
.70211 .11771 Mdot
.51166 .10691 Mdot
.33867 .23214 Mdot
.96306 .1982 Mdot
.49999 1e-05 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49836 .00222 Mdot
.49477 .00707 Mdot
.48333 .02249 Mdot
.44693 .07078 Mdot
.33241 .19899 Mdot
.01044 .20866 Mdot
.67282 .07812 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49458 .00732 Mdot
.48275 .02328 Mdot
.44508 .07319 Mdot
.32666 .20395 Mdot
.99666 .20085 Mdot
.67167 .07082 Mdot
.55709 .01903 Mdot
.5263 .61279 Mdot
.53479 .5808 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49363 .0086 Mdot
.47971 .02736 Mdot
.43545 .08557 Mdot
.29699 .22673 Mdot
.93013 .16402 Mdot
.66474 .03715 Mdot
.60464 .56501 Mdot
.69043 .42769 Mdot
.99842 .42622 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.49251 .01012 Mdot
.47614 .03216 Mdot
.42411 .09987 Mdot
.26251 .24696 Mdot
.86292 .13502 Mdot
.64445 .01875 Mdot
.61411 .53983 Mdot
.74065 .39254 Mdot
.1055 .48334 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49624 .00508 Mdot
.48802 .01618 Mdot
.46183 .05122 Mdot
.37895 .15293 Mdot
.1315 .26144 Mdot
.70849 .11888 Mdot
.51614 .10395 Mdot
.34794 .22443 Mdot
.98482 .21037 Mdot
.64443 .09411 Mdot
.50036 .61755 Mdot
.50114 .6165 Mdot
.50362 .61314 Mdot
.51154 .60246 Mdot
.53674 .5687 Mdot
.61657 .47004 Mdot
.85603 .35404 Mdot
.28318 .49839 Mdot
.47676 .51986 Mdot
.6356 .40882 Mdot
.97411 .38493 Mdot
.49982 .00024 Mdot
.49943 .00076 Mdot
.4982 .00244 Mdot
.49425 .00776 Mdot
.4817 .02469 Mdot
.44174 .0775 Mdot
.31635 .21241 Mdot
.97266 .18719 Mdot
.66978 .05799 Mdot
.57595 .60826 Mdot
.59177 .52782 Mdot
.73774 .38071 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.5283 .57993 Mdot
.58995 .50091 Mdot
.77947 .35589 Mdot
.20363 .49721 Mdot
.39912 .58459 Mdot
.45323 .00929 Mdot
.4382 .06516 Mdot
.33277 .1932 Mdot
.49988 .00017 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48722 .01725 Mdot
.4593 .05457 Mdot
.371 .1615 Mdot
.10969 .25532 Mdot
.69657 .11602 Mdot
.50885 .10781 Mdot
.33441 .23509 Mdot
.95402 .19306 Mdot
.50125 .61635 Mdot
.50398 .61266 Mdot
.51267 .60093 Mdot
.54034 .56393 Mdot
.62789 .45773 Mdot
.88727 .36174 Mdot
.30196 .50149 Mdot
.49053 .51027 Mdot
.6649 .38331 Mdot
.04469 .4242 Mdot
.35832 .53887 Mdot
.50015 .61784 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50475 .61162 Mdot
.51512 .59763 Mdot
.54814 .55368 Mdot
.65226 .43309 Mdot
.95151 .38883 Mdot
.32237 .52138 Mdot
.47876 .54102 Mdot
.60337 .45178 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00168 Mdot
.49603 .00537 Mdot
.48734 .01709 Mdot
.45969 .05407 Mdot
.3722 .16021 Mdot
.11297 .25637 Mdot
.69816 .11658 Mdot
.50952 .10776 Mdot
.33517 .23468 Mdot
.95545 .19392 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51041 .60397 Mdot
.53316 .57346 Mdot
.60529 .48282 Mdot
.82407 .35096 Mdot
.2562 .4984 Mdot
.44977 .54419 Mdot
.56926 .48199 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00565 Mdot
.48667 .018 Mdot
.45755 .05689 Mdot
.3655 .16725 Mdot
.09488 .25009 Mdot
.69022 .11284 Mdot
.50765 .10575 Mdot
.33654 .23201 Mdot
.96113 .19634 Mdot
.64345 .08064 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49547 .00612 Mdot
.48557 .01947 Mdot
.45406 .06147 Mdot
.3546 .17828 Mdot
.06614 .23785 Mdot
.6813 .10384 Mdot
.51329 .09153 Mdot
.36519 .20209 Mdot
.03821 .23717 Mdot
.4997 .00041 Mdot
.49903 .0013 Mdot
.49692 .00416 Mdot
.4902 .01324 Mdot
.46878 .042 Mdot
.40082 .1281 Mdot
.19355 .26646 Mdot
.7624 .11937 Mdot
.56926 .05716 Mdot
.47677 .07862 Mdot
.34957 .19822 Mdot
.02884 .22481 Mdot
.50118 .61644 Mdot
.50375 .61297 Mdot
.51194 .60191 Mdot
.53804 .56698 Mdot
.62064 .46555 Mdot
.86736 .35634 Mdot
.2908 .49906 Mdot
.4833 .51451 Mdot
.65081 .3947 Mdot
.01217 .40598 Mdot
.35529 .52239 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.5047 .61168 Mdot
.51497 .59782 Mdot
.54767 .55429 Mdot
.65082 .43448 Mdot
.94782 .38696 Mdot
.3217 .51979 Mdot
.48066 .53767 Mdot
.61069 .44313 Mdot
.89369 .35174 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00306 Mdot
.49278 .00975 Mdot
.477 .031 Mdot
.42683 .09647 Mdot
.27075 .24276 Mdot
.87795 .14038 Mdot
.65081 .02058 Mdot
.61751 .53931 Mdot
.74489 .39184 Mdot
.11088 .48652 Mdot
.50035 .61755 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51148 .60254 Mdot
.53655 .56896 Mdot
.61596 .47072 Mdot
.85432 .35375 Mdot
.28194 .49833 Mdot
.47562 .52085 Mdot
.63288 .41148 Mdot
.96708 .38118 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49632 .00497 Mdot
.48828 .01583 Mdot
.46266 .05013 Mdot
.38155 .15008 Mdot
.13871 .263 Mdot
.71316 .11939 Mdot
.51999 .10091 Mdot
.35671 .21651 Mdot
.00639 .22243 Mdot
.64648 .10501 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51165 .6023 Mdot
.53712 .5682 Mdot
.61775 .46873 Mdot
.85933 .35465 Mdot
.28549 .49854 Mdot
.47884 .5181 Mdot
.64054 .40409 Mdot
.9867 .39178 Mdot
.35279 .50961 Mdot
.50047 .6174 Mdot
.5015 .616 Mdot
.50479 .61156 Mdot
.51527 .59742 Mdot
.54863 .55303 Mdot
.65381 .43162 Mdot
.95543 .39084 Mdot
.32303 .52312 Mdot
.47661 .54473 Mdot
.59521 .46164 Mdot
.84827 .34133 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49403 .00806 Mdot
.48099 .02564 Mdot
.43951 .08038 Mdot
.30945 .21775 Mdot
.95713 .17848 Mdot
.66834 .04994 Mdot
.58753 .59085 Mdot
.63151 .48234 Mdot
.85107 .36356 Mdot
.50019 .61778 Mdot
.50059 .61723 Mdot
.50189 .61548 Mdot
.50602 .6099 Mdot
.51919 .59215 Mdot
.56108 .5369 Mdot
.69235 .39893 Mdot
.04687 .44175 Mdot
.33209 .5701 Mdot
.40965 .0314 Mdot
.35883 .14578 Mdot
.50036 .61755 Mdot
.50113 .6165 Mdot
.50362 .61315 Mdot
.51152 .60248 Mdot
.53669 .56876 Mdot
.61642 .47021 Mdot
.8556 .35397 Mdot
.28287 .49838 Mdot
.47648 .52011 Mdot
.63493 .40947 Mdot
.97238 .384 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.49771 .0031 Mdot
.4927 .00986 Mdot
.47674 .03135 Mdot
.42601 .0975 Mdot
.26825 .24408 Mdot
.87333 .13866 Mdot
.64898 .01985 Mdot
.61686 .53902 Mdot
.74471 .39156 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49626 .00506 Mdot
.48807 .01611 Mdot
.46201 .051 Mdot
.3795 .15234 Mdot
.13301 .26178 Mdot
.70944 .119 Mdot
.51688 .10338 Mdot
.34961 .22296 Mdot
.98884 .21263 Mdot
.6448 .09616 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50042 .61746 Mdot
.50134 .61622 Mdot
.50428 .61226 Mdot
.51362 .59965 Mdot
.54337 .55993 Mdot
.63738 .44781 Mdot
.9128 .37096 Mdot
.31258 .50725 Mdot
.49183 .51481 Mdot
.50132 .61624 Mdot
.50422 .61233 Mdot
.51345 .59988 Mdot
.54283 .56065 Mdot
.63567 .44957 Mdot
.90824 .36914 Mdot
.31096 .506 Mdot
.49223 .5132 Mdot
.66187 .3877 Mdot
.03455 .41948 Mdot
.35582 .5356 Mdot
.49969 .00042 Mdot
.49901 .00133 Mdot
.49686 .00424 Mdot
.49 .01351 Mdot
.46815 .04284 Mdot
.39883 .13044 Mdot
.18778 .26685 Mdot
.75601 .11941 Mdot
.5628 .06269 Mdot
.46137 .09815 Mdot
.30255 .23773 Mdot
.9179 .16495 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00312 Mdot
.49264 .00994 Mdot
.47655 .03161 Mdot
.42541 .09825 Mdot
.26644 .24501 Mdot
.87 .13745 Mdot
.64759 .01941 Mdot
.61618 .53906 Mdot
.74397 .39162 Mdot
.11032 .4859 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00383 Mdot
.49098 .01218 Mdot
.47126 .03868 Mdot
.40868 .11877 Mdot
.2165 .26306 Mdot
.79086 .12035 Mdot
.59613 .03655 Mdot
.53699 .00257 Mdot
.53283 .59039 Mdot
.57756 .5213 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00537 Mdot
.48733 .01711 Mdot
.45964 .05412 Mdot
.37207 .16036 Mdot
.1126 .25625 Mdot
.69798 .11652 Mdot
.50944 .10777 Mdot
.33506 .23474 Mdot
.95524 .19379 Mdot
.64168 .07912 Mdot
.50019 .61777 Mdot
.50062 .6172 Mdot
.50196 .61538 Mdot
.50626 .60958 Mdot
.51993 .59115 Mdot
.56344 .53389 Mdot
.69959 .39368 Mdot
.0626 .45023 Mdot
.33411 .57764 Mdot
.39947 .04673 Mdot
.32385 .17868 Mdot
.50099 .61669 Mdot
.50316 .61377 Mdot
.51007 .60444 Mdot
.53206 .57492 Mdot
.60182 .48683 Mdot
.81411 .3511 Mdot
.24602 .4986 Mdot
.43927 .55354 Mdot
.54363 .5136 Mdot
.71261 .3701 Mdot
.11377 .46682 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51085 .60338 Mdot
.53457 .57158 Mdot
.60974 .47771 Mdot
.83678 .35157 Mdot
.26794 .49817 Mdot
.46188 .53318 Mdot
.59917 .44708 Mdot
.87578 .34326 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.4872 .01727 Mdot
.45925 .05464 Mdot
.37085 .16165 Mdot
.10929 .25519 Mdot
.69638 .11594 Mdot
.50878 .10781 Mdot
.33434 .23511 Mdot
.95392 .19299 Mdot
.64166 .07833 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49304 .0094 Mdot
.47782 .0299 Mdot
.42945 .09318 Mdot
.27867 .23834 Mdot
.89303 .14647 Mdot
.65603 .02391 Mdot
.61735 .54274 Mdot
.73918 .39554 Mdot
.09918 .48165 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50641 .60937 Mdot
.52043 .59048 Mdot
.56502 .53186 Mdot
.70445 .39032 Mdot
.0729 .45556 Mdot
.33578 .58219 Mdot
.39378 .05547 Mdot
.30403 .1946 Mdot
.98916 .18456 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.50492 .61139 Mdot
.51567 .59689 Mdot
.54988 .5514 Mdot
.65769 .42799 Mdot
.96519 .39598 Mdot
.32449 .52765 Mdot
.47073 .55464 Mdot
.57331 .48905 Mdot
.78201 .34448 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49596 .00546 Mdot
.48712 .01738 Mdot
.459 .05497 Mdot
.37005 .1625 Mdot
.10712 .25447 Mdot
.69537 .11554 Mdot
.50843 .10773 Mdot
.33412 .23514 Mdot
.95366 .19279 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.48681 .01781 Mdot
.45798 .05632 Mdot
.36686 .16584 Mdot
.09852 .25146 Mdot
.69166 .11371 Mdot
.50767 .10661 Mdot
.33518 .23352 Mdot
.95733 .19444 Mdot
.64273 .07916 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48936 .01437 Mdot
.46611 .04555 Mdot
.3924 .13788 Mdot
.16931 .26686 Mdot
.73752 .11977 Mdot
.54372 .07974 Mdot
.4147 .15509 Mdot
.16375 .2815 Mdot
.70828 .13899 Mdot
.50031 .61761 Mdot
.501 .61668 Mdot
.50319 .61373 Mdot
.51016 .60431 Mdot
.53236 .57452 Mdot
.60276 .48574 Mdot
.81681 .35101 Mdot
.24887 .49855 Mdot
.4422 .55097 Mdot
.55071 .50474 Mdot
.73402 .35794 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49776 .00303 Mdot
.49286 .00965 Mdot
.47725 .03067 Mdot
.42762 .09548 Mdot
.27314 .24147 Mdot
.88243 .14212 Mdot
.65248 .02142 Mdot
.61781 .53994 Mdot
.74417 .39249 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49546 .00613 Mdot
.48555 .01951 Mdot
.45399 .06157 Mdot
.35436 .17852 Mdot
.06552 .23755 Mdot
.68115 .1036 Mdot
.51352 .09108 Mdot
.36615 .20105 Mdot
.04084 .2385 Mdot
.50086 .61687 Mdot
.50276 .61431 Mdot
.50878 .60618 Mdot
.52796 .58039 Mdot
.58888 .50221 Mdot
.77629 .35667 Mdot
.19918 .49676 Mdot
.39541 .58689 Mdot
.4458 .01813 Mdot
.41647 .09206 Mdot
.2675 .23872 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00515 Mdot
.48784 .01641 Mdot
.46129 .05195 Mdot
.37723 .1548 Mdot
.12675 .26028 Mdot
.70562 .11843 Mdot
.51399 .10548 Mdot
.34331 .22839 Mdot
.97377 .20418 Mdot
.6434 .08852 Mdot
.50075 .61702 Mdot
.50238 .61481 Mdot
.5076 .60777 Mdot
.5242 .58543 Mdot
.57696 .51683 Mdot
.74071 .36954 Mdot
.14279 .48485 Mdot
.35828 .59955 Mdot
.3882 .07684 Mdot
.26386 .22383 Mdot
.9017 .13838 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .6029 Mdot
.5357 .57008 Mdot
.6133 .47369 Mdot
.84685 .35263 Mdot
.27628 .49817 Mdot
.47022 .52562 Mdot
.61976 .42478 Mdot
.93245 .36402 Mdot
.34345 .48685 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60823 Mdot
.52311 .58688 Mdot
.57351 .52113 Mdot
.7303 .37472 Mdot
.124 .47839 Mdot
.34995 .59778 Mdot
.38272 .07889 Mdot
.25507 .22636 Mdot
.88881 .13146 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60602 Mdot
.52835 .57988 Mdot
.59009 .50075 Mdot
.77986 .35579 Mdot
.20417 .49726 Mdot
.39958 .5843 Mdot
.45417 .00817 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.5076 .60777 Mdot
.52421 .58541 Mdot
.57701 .51677 Mdot
.74086 .36947 Mdot
.14304 .48493 Mdot
.35841 .59955 Mdot
.38831 .07677 Mdot
.26411 .22373 Mdot
.9021 .13859 Mdot
.50076 .617 Mdot
.50243 .61474 Mdot
.50776 .60756 Mdot
.52471 .58474 Mdot
.57858 .51482 Mdot
.74558 .36733 Mdot
.15122 .48736 Mdot
.36265 .59946 Mdot
.3927 .07353 Mdot
.27373 .21944 Mdot
.91866 .14728 Mdot
.50011 .61788 Mdot
.50036 .61754 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.5118 .6021 Mdot
.53758 .56759 Mdot
.61921 .46712 Mdot
.86339 .35546 Mdot
.28823 .49877 Mdot
.4812 .51616 Mdot
.64605 .39898 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .0048 Mdot
.48867 .0153 Mdot
.46392 .04846 Mdot
.3855 .14568 Mdot
.14978 .26493 Mdot
.72111 .11981 Mdot
.52726 .09467 Mdot
.37408 .19959 Mdot
.05113 .24619 Mdot
.50067 .61713 Mdot
.50214 .61514 Mdot
.50682 .60882 Mdot
.52173 .58874 Mdot
.56913 .52665 Mdot
.71699 .38227 Mdot
.09846 .46784 Mdot
.34149 .59167 Mdot
.38415 .0718 Mdot
.26797 .2184 Mdot
.91459 .14297 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00325 Mdot
.49234 .01035 Mdot
.47559 .03289 Mdot
.42239 .10202 Mdot
.25731 .24941 Mdot
.85376 .13213 Mdot
.63998 .01845 Mdot
.61012 .54235 Mdot
.73258 .39569 Mdot
.09234 .47657 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50455 .61189 Mdot
.5145 .59846 Mdot
.54616 .55627 Mdot
.6461 .43906 Mdot
.93569 .38105 Mdot
.31914 .51489 Mdot
.48603 .52783 Mdot
.63198 .41903 Mdot
.95397 .37695 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.50649 .60927 Mdot
.52068 .59015 Mdot
.5658 .53087 Mdot
.70683 .38872 Mdot
.07786 .45806 Mdot
.33671 .58425 Mdot
.39138 .05927 Mdot
.29547 .20084 Mdot
.9705 .17365 Mdot
.50061 .61721 Mdot
.50193 .61542 Mdot
.50616 .60971 Mdot
.51963 .59156 Mdot
.56247 .53512 Mdot
.69663 .39579 Mdot
.05623 .44684 Mdot
.33323 .57467 Mdot
.40339 .04079 Mdot
.33739 .16665 Mdot
.06774 .22757 Mdot
.50126 .61634 Mdot
.504 .61263 Mdot
.51275 .60081 Mdot
.54062 .56357 Mdot
.62874 .45681 Mdot
.8896 .36248 Mdot
.30309 .50189 Mdot
.49102 .51022 Mdot
.66547 .383 Mdot
.04576 .42484 Mdot
.35836 .53949 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51159 .60238 Mdot
.53691 .56847 Mdot
.61711 .46944 Mdot
.85754 .35431 Mdot
.28425 .49846 Mdot
.47773 .51904 Mdot
.63791 .4066 Mdot
.98003 .38813 Mdot
.35202 .50638 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46217 .05079 Mdot
.37999 .15179 Mdot
.13438 .26209 Mdot
.71031 .11911 Mdot
.51759 .10283 Mdot
.3512 .22154 Mdot
.99274 .21481 Mdot
.64516 .09814 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39525 .1346 Mdot
.17747 .26708 Mdot
.74532 .1196 Mdot
.5518 .07243 Mdot
.43461 .13135 Mdot
.22208 .27663 Mdot
.50123 .61637 Mdot
.50392 .61274 Mdot
.5125 .60116 Mdot
.53979 .56466 Mdot
.62616 .45957 Mdot
.88256 .36031 Mdot
.29957 .50076 Mdot
.48932 .51065 Mdot
.66307 .38458 Mdot
.04081 .422 Mdot
.35801 .53685 Mdot
.50086 .61687 Mdot
.50276 .61431 Mdot
.50878 .60618 Mdot
.52796 .58039 Mdot
.58887 .50222 Mdot
.77626 .35668 Mdot
.19915 .49675 Mdot
.39538 .58691 Mdot
.44574 .0182 Mdot
.41629 .09228 Mdot
.26697 .23899 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.49949 .00068 Mdot
.49839 .00218 Mdot
.49485 .00695 Mdot
.48361 .02212 Mdot
.44781 .06964 Mdot
.33514 .19657 Mdot
.01708 .21238 Mdot
.67345 .08157 Mdot
.54147 .04356 Mdot
.47098 .07032 Mdot
.50123 .61638 Mdot
.50391 .61276 Mdot
.51244 .60123 Mdot
.53963 .56487 Mdot
.62565 .46011 Mdot
.88117 .35991 Mdot
.29883 .50056 Mdot
.4889 .51084 Mdot
.66234 .38511 Mdot
.03922 .4211 Mdot
.35786 .53604 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.5114 .60264 Mdot
.5363 .56928 Mdot
.6152 .47157 Mdot
.85219 .3534 Mdot
.28037 .49827 Mdot
.47415 .52213 Mdot
.62933 .415 Mdot
.95785 .37638 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56064 Mdot
.63571 .44953 Mdot
.90835 .36918 Mdot
.31099 .50603 Mdot
.49223 .51323 Mdot
.66181 .38776 Mdot
.03439 .4194 Mdot
.35579 .53553 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00124 Mdot
.49709 .00394 Mdot
.49072 .01253 Mdot
.47044 .03978 Mdot
.40608 .12188 Mdot
.20886 .26453 Mdot
.78085 .11975 Mdot
.58709 .04298 Mdot
.51756 .02673 Mdot
.47431 .05045 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01162 Mdot
.47259 .03691 Mdot
.41287 .11371 Mdot
.22889 .25996 Mdot
.80827 .12219 Mdot
.61056 .02774 Mdot
.56567 .58661 Mdot
.61652 .48798 Mdot
.82695 .35735 Mdot
.50057 .61726 Mdot
.50183 .61557 Mdot
.50582 .61017 Mdot
.51855 .59301 Mdot
.55903 .53953 Mdot
.68605 .40374 Mdot
.03278 .43391 Mdot
.33069 .5629 Mdot
.4199 .01603 Mdot
.39397 .10721 Mdot
.22049 .25223 Mdot
.49978 .0003 Mdot
.49929 .00097 Mdot
.49772 .00308 Mdot
.49274 .0098 Mdot
.47689 .03115 Mdot
.42648 .09691 Mdot
.26967 .24333 Mdot
.87595 .13963 Mdot
.65003 .02025 Mdot
.61727 .53914 Mdot
.74493 .39167 Mdot
.1112 .48657 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60498 Mdot
.53078 .57662 Mdot
.59779 .49156 Mdot
.80243 .35195 Mdot
.23296 .49865 Mdot
.42613 .5647 Mdot
.51243 .55319 Mdot
.61735 .45399 Mdot
.88278 .35488 Mdot
.49991 .00011 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01184 Mdot
.47207 .03761 Mdot
.41122 .11571 Mdot
.224 .26129 Mdot
.80122 .12132 Mdot
.60492 .03094 Mdot
.55485 .59913 Mdot
.58545 .52367 Mdot
.50113 .6165 Mdot
.50362 .61315 Mdot
.51152 .60248 Mdot
.53669 .56877 Mdot
.6164 .47023 Mdot
.85554 .35396 Mdot
.28283 .49838 Mdot
.47644 .52014 Mdot
.63484 .40956 Mdot
.97215 .38388 Mdot
.35103 .50268 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50504 .61123 Mdot
.51604 .59638 Mdot
.55108 .54984 Mdot
.66142 .42456 Mdot
.97446 .40099 Mdot
.32565 .53218 Mdot
.46456 .56476 Mdot
.55077 .51849 Mdot
.71183 .37517 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49245 .0102 Mdot
.47595 .0324 Mdot
.42352 .1006 Mdot
.26075 .24781 Mdot
.85978 .134 Mdot
.64297 .01858 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60134 Mdot
.53938 .5652 Mdot
.62486 .46096 Mdot
.87901 .35929 Mdot
.29766 .50027 Mdot
.4882 .5112 Mdot
.66106 .3861 Mdot
.03634 .4195 Mdot
.50056 .61727 Mdot
.5018 .61561 Mdot
.50573 .6103 Mdot
.51824 .59342 Mdot
.55807 .54078 Mdot
.68307 .40609 Mdot
.026 .43009 Mdot
.33011 .55934 Mdot
.42508 .00822 Mdot
.41178 .08588 Mdot
.27283 .23191 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48703 .01751 Mdot
.4587 .05536 Mdot
.36912 .16348 Mdot
.10461 .25362 Mdot
.69424 .11504 Mdot
.5081 .10753 Mdot
.33411 .23495 Mdot
.95396 .19286 Mdot
.64191 .07806 Mdot
.50066 .61714 Mdot
.50211 .61518 Mdot
.50673 .60894 Mdot
.52144 .58913 Mdot
.56821 .52782 Mdot
.71418 .38399 Mdot
.09287 .46528 Mdot
.34002 .58985 Mdot
.38563 .06895 Mdot
.27407 .21481 Mdot
.92651 .14907 Mdot
.5011 .61655 Mdot
.50351 .6133 Mdot
.51117 .60295 Mdot
.53558 .57023 Mdot
.61293 .47411 Mdot
.84581 .3525 Mdot
.27545 .49816 Mdot
.46941 .52634 Mdot
.61777 .42685 Mdot
.92711 .36162 Mdot
.342 .48519 Mdot
.50063 .61718 Mdot
.50202 .61531 Mdot
.50643 .60935 Mdot
.52047 .59043 Mdot
.56514 .53171 Mdot
.70481 .39008 Mdot
.07366 .45595 Mdot
.33592 .58251 Mdot
.3934 .05607 Mdot
.30267 .19561 Mdot
.98617 .18281 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49651 .00471 Mdot
.4889 .015 Mdot
.46463 .04751 Mdot
.38775 .14316 Mdot
.15612 .26577 Mdot
.72609 .11989 Mdot
.53211 .09032 Mdot
.38598 .18721 Mdot
.08307 .26077 Mdot
.66114 .13563 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50516 .61107 Mdot
.51643 .59587 Mdot
.55229 .54826 Mdot
.66519 .42117 Mdot
.98372 .40611 Mdot
.32663 .53688 Mdot
.45794 .57541 Mdot
.5269 .55059 Mdot
.63602 .43929 Mdot
.5001 .6179 Mdot
.5003 .61762 Mdot
.50097 .61672 Mdot
.50309 .61386 Mdot
.50985 .60474 Mdot
.53136 .57585 Mdot
.59961 .48942 Mdot
.8077 .35147 Mdot
.23901 .49866 Mdot
.43215 .55967 Mdot
.52659 .53514 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50738 .60806 Mdot
.52352 .58633 Mdot
.57482 .5195 Mdot
.73424 .37268 Mdot
.13124 .48102 Mdot
.35294 .59876 Mdot
.38412 .07891 Mdot
.25643 .22634 Mdot
.89021 .13244 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49357 .00868 Mdot
.47952 .02762 Mdot
.43483 .08636 Mdot
.29509 .22802 Mdot
.92614 .16198 Mdot
.66404 .03544 Mdot
.6067 .5618 Mdot
.69769 .42216 Mdot
.01462 .43569 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00283 Mdot
.49332 .00903 Mdot
.47871 .02871 Mdot
.43226 .08963 Mdot
.28724 .23315 Mdot
.91 .15409 Mdot
.66067 .02918 Mdot
.61346 .55071 Mdot
.72239 .40538 Mdot
.06647 .46523 Mdot
.50019 .61777 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.5063 .60952 Mdot
.52009 .59095 Mdot
.56392 .53327 Mdot
.70106 .39265 Mdot
.06575 .45188 Mdot
.33459 .57907 Mdot
.39764 .04952 Mdot
.3175 .184 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49697 .00409 Mdot
.49035 .01303 Mdot
.46927 .04134 Mdot
.40238 .12627 Mdot
.19806 .26603 Mdot
.76761 .11939 Mdot
.57444 .05287 Mdot
.48889 .06316 Mdot
.3867 .15955 Mdot
.12855 .26617 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49357 .00868 Mdot
.47952 .02762 Mdot
.43484 .08635 Mdot
.29512 .22801 Mdot
.9262 .16201 Mdot
.66405 .03546 Mdot
.60667 .56185 Mdot
.69758 .42223 Mdot
.01439 .43556 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53084 .57654 Mdot
.59798 .49134 Mdot
.80297 .35189 Mdot
.2336 .49866 Mdot
.42676 .56418 Mdot
.51389 .55132 Mdot
.62184 .44909 Mdot
.8952 .3588 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00388 Mdot
.49086 .01235 Mdot
.47087 .0392 Mdot
.40745 .12025 Mdot
.21288 .2638 Mdot
.78605 .12002 Mdot
.59185 .03952 Mdot
.52791 .01378 Mdot
.50561 .00858 Mdot
.49994 8e-05 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49798 .00272 Mdot
.49358 .00868 Mdot
.47954 .02759 Mdot
.43489 .08628 Mdot
.29529 .22789 Mdot
.92656 .1622 Mdot
.66412 .03562 Mdot
.60649 .56213 Mdot
.69694 .42271 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00535 Mdot
.48737 .01705 Mdot
.45979 .05393 Mdot
.37254 .15986 Mdot
.11388 .25665 Mdot
.69861 .11673 Mdot
.50974 .10771 Mdot
.33546 .23449 Mdot
.95605 .19426 Mdot
.64173 .07956 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48657 .01814 Mdot
.45722 .05732 Mdot
.36447 .16832 Mdot
.09212 .24903 Mdot
.68918 .11213 Mdot
.50775 .10495 Mdot
.33793 .23055 Mdot
.96489 .19826 Mdot
.64409 .0822 Mdot
.50131 .61626 Mdot
.50419 .61238 Mdot
.51334 .60003 Mdot
.54247 .56113 Mdot
.63454 .45073 Mdot
.90524 .36799 Mdot
.30983 .50523 Mdot
.49235 .51232 Mdot
.66341 .38608 Mdot
.03872 .42162 Mdot
.35653 .53733 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00354 Mdot
.49165 .01127 Mdot
.47341 .03581 Mdot
.41547 .11054 Mdot
.23662 .25756 Mdot
.81988 .12401 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00569 Mdot
.48659 .0181 Mdot
.4573 .05721 Mdot
.36474 .16804 Mdot
.09284 .24931 Mdot
.68944 .11232 Mdot
.50771 .10517 Mdot
.33754 .23096 Mdot
.96384 .19772 Mdot
.50002 .618 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50815 .60702 Mdot
.52596 .58306 Mdot
.58255 .50992 Mdot
.75749 .36254 Mdot
.17089 .49223 Mdot
.37445 .59692 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45943 .05441 Mdot
.3714 .16107 Mdot
.11078 .25567 Mdot
.69709 .11621 Mdot
.50906 .10782 Mdot
.33461 .235 Mdot
.95437 .19328 Mdot
.50075 .61702 Mdot
.5024 .61479 Mdot
.50765 .60771 Mdot
.52436 .58521 Mdot
.57747 .5162 Mdot
.74224 .36883 Mdot
.14546 .48567 Mdot
.35962 .59958 Mdot
.38948 .07597 Mdot
.26656 .22271 Mdot
.9062 .14071 Mdot
.49985 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49531 .00634 Mdot
.48505 .02018 Mdot
.45239 .06367 Mdot
.34937 .18337 Mdot
.05267 .23131 Mdot
.67839 .09845 Mdot
.5191 .08079 Mdot
.38838 .17599 Mdot
.10363 .26541 Mdot
.50069 .61711 Mdot
.50219 .61508 Mdot
.50698 .60861 Mdot
.52223 .58807 Mdot
.5707 .52466 Mdot
.72178 .37943 Mdot
.10785 .47193 Mdot
.34424 .59436 Mdot
.38255 .07559 Mdot
.26024 .22283 Mdot
.8997 .13588 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00232 Mdot
.49453 .00739 Mdot
.48256 .02353 Mdot
.44449 .07395 Mdot
.32484 .20548 Mdot
.99237 .19841 Mdot
.67134 .06852 Mdot
.56047 .0138 Mdot
.53815 .5968 Mdot
.49962 .00051 Mdot
.49879 .00163 Mdot
.49616 .00519 Mdot
.48777 .01652 Mdot
.46104 .05227 Mdot
.37646 .15564 Mdot
.12463 .25973 Mdot
.70438 .1182 Mdot
.51313 .10605 Mdot
.34154 .22985 Mdot
.96963 .20187 Mdot
.643 .08643 Mdot
.49978 .00029 Mdot
.49931 .00094 Mdot
.49779 .00299 Mdot
.49296 .00951 Mdot
.47756 .03024 Mdot
.42863 .09421 Mdot
.27619 .23976 Mdot
.88825 .14447 Mdot
.65449 .0227 Mdot
.61776 .54126 Mdot
.74199 .3939 Mdot
.10464 .48407 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48837 .01571 Mdot
.46295 .04974 Mdot
.38246 .14907 Mdot
.14127 .2635 Mdot
.71492 .11952 Mdot
.52152 .09963 Mdot
.36032 .21313 Mdot
.01547 .22745 Mdot
.64745 .10948 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51077 .6035 Mdot
.53429 .57195 Mdot
.60885 .47873 Mdot
.83425 .35138 Mdot
.26571 .49821 Mdot
.4596 .53526 Mdot
.59353 .45346 Mdot
.85983 .33967 Mdot
.31023 .47677 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49384 .00833 Mdot
.48037 .02648 Mdot
.43752 .08293 Mdot
.30333 .22227 Mdot
.94369 .17115 Mdot
.66676 .04333 Mdot
.59666 .57716 Mdot
.6628 .45121 Mdot
.93272 .39068 Mdot
.50126 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.54089 .56321 Mdot
.6296 .45591 Mdot
.89193 .36324 Mdot
.30419 .50232 Mdot
.49142 .51026 Mdot
.6658 .38289 Mdot
.04628 .42519 Mdot
.35831 .53987 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.5085 .60655 Mdot
.52709 .58156 Mdot
.58611 .50557 Mdot
.76809 .35897 Mdot
.18726 .4952 Mdot
.38601 .59207 Mdot
.42802 .03852 Mdot
.3657 .14876 Mdot
.125 .25309 Mdot
.49986 .00019 Mdot
.49954 .00062 Mdot
.49854 .00198 Mdot
.49533 .0063 Mdot
.48513 .02007 Mdot
.45266 .06331 Mdot
.35023 .18255 Mdot
.05485 .2324 Mdot
.67882 .09937 Mdot
.51804 .08269 Mdot
.38425 .18078 Mdot
.09174 .2612 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49003 .01346 Mdot
.46825 .04271 Mdot
.39915 .13007 Mdot
.18869 .2668 Mdot
.757 .1194 Mdot
.56381 .06182 Mdot
.46378 .09511 Mdot
.30989 .23233 Mdot
.93398 .17286 Mdot
.50057 .61726 Mdot
.50183 .61557 Mdot
.50581 .61018 Mdot
.51852 .59304 Mdot
.55896 .53963 Mdot
.68582 .40392 Mdot
.03227 .43363 Mdot
.33064 .56263 Mdot
.42029 .01545 Mdot
.39529 .10566 Mdot
.22433 .25129 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51227 .60146 Mdot
.53909 .56559 Mdot
.62395 .46195 Mdot
.8765 .35861 Mdot
.29626 .49996 Mdot
.48731 .51172 Mdot
.65933 .38747 Mdot
.03238 .41729 Mdot
.3572 .53261 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51166 .60229 Mdot
.53712 .56819 Mdot
.61778 .4687 Mdot
.85941 .35466 Mdot
.28555 .49854 Mdot
.47889 .51806 Mdot
.64065 .40399 Mdot
.98698 .39194 Mdot
.35282 .50975 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.5055 .6106 Mdot
.51752 .59439 Mdot
.55578 .54373 Mdot
.676 .41185 Mdot
.00961 .42076 Mdot
.32881 .55058 Mdot
.43796 .60664 Mdot
.45639 .02853 Mdot
.41023 .10741 Mdot
.50049 .61737 Mdot
.50157 .61592 Mdot
.50499 .6113 Mdot
.51589 .59659 Mdot
.55058 .55048 Mdot
.65988 .42597 Mdot
.97065 .39891 Mdot
.3252 .5303 Mdot
.46716 .56052 Mdot
.56021 .50602 Mdot
.74145 .35869 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51226 .60149 Mdot
.53903 .56567 Mdot
.62376 .46215 Mdot
.87599 .35847 Mdot
.29597 .4999 Mdot
.48711 .51184 Mdot
.65895 .38779 Mdot
.03149 .41679 Mdot
.35711 .53217 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51177 .60214 Mdot
.5375 .56769 Mdot
.61895 .4674 Mdot
.86268 .35532 Mdot
.28777 .49873 Mdot
.48081 .51647 Mdot
.64514 .39981 Mdot
.99823 .39817 Mdot
.35398 .51533 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49213 .01063 Mdot
.47492 .03379 Mdot
.42025 .10466 Mdot
.25091 .2522 Mdot
.84284 .12906 Mdot
.63402 .01898 Mdot
.60331 .54783 Mdot
.71689 .40347 Mdot
.06407 .46127 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49574 .00575 Mdot
.48643 .01832 Mdot
.4568 .05788 Mdot
.36315 .16968 Mdot
.0886 .24764 Mdot
.68791 .11118 Mdot
.50802 .10375 Mdot
.34014 .22826 Mdot
.97081 .20135 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49954 .00061 Mdot
.49855 .00196 Mdot
.49538 .00624 Mdot
.48528 .01987 Mdot
.45314 .06269 Mdot
.35171 .18112 Mdot
.05866 .23427 Mdot
.6796 .10093 Mdot
.5163 .08585 Mdot
.37739 .18859 Mdot
.50023 .61773 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50739 .60805 Mdot
.52354 .5863 Mdot
.57488 .51942 Mdot
.73445 .37257 Mdot
.13161 .48115 Mdot
.3531 .5988 Mdot
.38421 .07889 Mdot
.25657 .22631 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49935 .00088 Mdot
.49793 .00279 Mdot
.49342 .00889 Mdot
.47904 .02826 Mdot
.43331 .0883 Mdot
.29043 .23111 Mdot
.91649 .1572 Mdot
.66214 .03157 Mdot
.61107 .55479 Mdot
.71339 .41113 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00552 Mdot
.48698 .01758 Mdot
.45854 .05557 Mdot
.36862 .164 Mdot
.10326 .25315 Mdot
.69365 .11476 Mdot
.50796 .10738 Mdot
.33422 .23475 Mdot
.95439 .19304 Mdot
.64204 .07816 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50503 .61124 Mdot
.51602 .59642 Mdot
.55099 .54995 Mdot
.66115 .42481 Mdot
.9738 .40063 Mdot
.32557 .53185 Mdot
.46502 .56402 Mdot
.55241 .5163 Mdot
.71702 .37192 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .00399 Mdot
.49058 .01272 Mdot
.47001 .04036 Mdot
.4047 .12352 Mdot
.20485 .26516 Mdot
.7758 .11955 Mdot
.58236 .04656 Mdot
.50702 .04006 Mdot
.4422 .09248 Mdot
.29257 .23477 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48953 .01414 Mdot
.46666 .04482 Mdot
.39413 .13589 Mdot
.17426 .26704 Mdot
.74218 .11967 Mdot
.54855 .07536 Mdot
.42662 .141 Mdot
.19848 .28088 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50748 .60793 Mdot
.52382 .58593 Mdot
.57576 .51832 Mdot
.7371 .37126 Mdot
.1364 .48278 Mdot
.35523 .59924 Mdot
.38565 .07832 Mdot
.25892 .22563 Mdot
.89384 .13436 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51022 .60424 Mdot
.53254 .57428 Mdot
.60334 .48507 Mdot
.81848 .35097 Mdot
.2506 .49852 Mdot
.44398 .54938 Mdot
.55506 .49935 Mdot
.74709 .35183 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00285 Mdot
.49327 .00909 Mdot
.47856 .0289 Mdot
.4318 .09021 Mdot
.28584 .23403 Mdot
.90718 .15277 Mdot
.65999 .0282 Mdot
.61435 .54911 Mdot
.72587 .40326 Mdot
.07338 .4689 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48942 .01428 Mdot
.46631 .04528 Mdot
.39305 .13713 Mdot
.17117 .26694 Mdot
.73925 .11974 Mdot
.54551 .07812 Mdot
.41912 .14991 Mdot
.17656 .28202 Mdot
.72024 .13705 Mdot
.5008 .61696 Mdot
.50254 .6146 Mdot
.50809 .60711 Mdot
.52577 .58332 Mdot
.58195 .51066 Mdot
.75569 .3632 Mdot
.16802 .4916 Mdot
.37259 .5975 Mdot
.4058 .06178 Mdot
.30583 .20034 Mdot
.98167 .18339 Mdot
.5008 .61695 Mdot
.50256 .61458 Mdot
.50816 .60702 Mdot
.52598 .58304 Mdot
.58261 .50984 Mdot
.75766 .36247 Mdot
.17117 .49229 Mdot
.37464 .59685 Mdot
.40891 .05873 Mdot
.31388 .19455 Mdot
.9991 .19371 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.51139 .60265 Mdot
.53628 .56931 Mdot
.61512 .47165 Mdot
.85197 .35337 Mdot
.28021 .49826 Mdot
.474 .52226 Mdot
.62897 .41536 Mdot
.95691 .3759 Mdot
.3487 .49597 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51285 .60069 Mdot
.54091 .56318 Mdot
.62966 .45584 Mdot
.8921 .3633 Mdot
.30427 .50235 Mdot
.49145 .51027 Mdot
.66582 .38289 Mdot
.0463 .4252 Mdot
.3583 .53988 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00474 Mdot
.48882 .01509 Mdot
.4644 .04782 Mdot
.38703 .14397 Mdot
.15407 .26552 Mdot
.72445 .11987 Mdot
.53049 .09178 Mdot
.382 .19142 Mdot
.07227 .25614 Mdot
.65783 .13266 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50934 .60543 Mdot
.52974 .57802 Mdot
.59449 .49548 Mdot
.79278 .35323 Mdot
.22124 .49838 Mdot
.41485 .5736 Mdot
.48675 .58587 Mdot
.53879 .55027 Mdot
.64843 .43177 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51319 .60023 Mdot
.542 .56175 Mdot
.63307 .45226 Mdot
.9013 .36651 Mdot
.30827 .50428 Mdot
.49233 .51139 Mdot
.66488 .38445 Mdot
.04282 .42367 Mdot
.35731 .53893 Mdot
.49981 .00026 Mdot
.4994 .00081 Mdot
.49808 .00259 Mdot
.49389 .00825 Mdot
.48054 .02624 Mdot
.43808 .08221 Mdot
.30506 .22101 Mdot
.94746 .17318 Mdot
.66724 .04514 Mdot
.5942 .58085 Mdot
.65436 .45915 Mdot
.91144 .38122 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00366 Mdot
.49136 .01166 Mdot
.47249 .03704 Mdot
.41256 .11408 Mdot
.22797 .26022 Mdot
.80693 .12201 Mdot
.60951 .02831 Mdot
.56371 .58885 Mdot
.61093 .49414 Mdot
.50104 .61663 Mdot
.50331 .61357 Mdot
.51053 .60381 Mdot
.53355 .57294 Mdot
.60652 .48139 Mdot
.82761 .35105 Mdot
.2596 .49832 Mdot
.4533 .541 Mdot
.57795 .47159 Mdot
.8149 .33614 Mdot
.27101 .4824 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48796 .01626 Mdot
.46166 .05146 Mdot
.37839 .15354 Mdot
.12996 .26107 Mdot
.70754 .11875 Mdot
.5154 .10449 Mdot
.34634 .22582 Mdot
.98095 .2082 Mdot
.64407 .09215 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46277 .04998 Mdot
.38191 .14968 Mdot
.13971 .2632 Mdot
.71385 .11945 Mdot
.52058 .10042 Mdot
.3581 .21522 Mdot
.00987 .22436 Mdot
.64684 .10674 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49626 .00505 Mdot
.48809 .01608 Mdot
.46208 .05089 Mdot
.37974 .15207 Mdot
.13368 .26193 Mdot
.70986 .11906 Mdot
.51722 .10312 Mdot
.35037 .22228 Mdot
.99071 .21367 Mdot
.64497 .0971 Mdot
.49995 6e-05 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49532 .00633 Mdot
.48508 .02014 Mdot
.45249 .06354 Mdot
.34968 .18307 Mdot
.05347 .23171 Mdot
.67855 .09879 Mdot
.51871 .08149 Mdot
.38686 .17776 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49909 .00122 Mdot
.49711 .0039 Mdot
.4908 .01242 Mdot
.47071 .03942 Mdot
.40693 .12086 Mdot
.21137 .26408 Mdot
.78407 .11991 Mdot
.59006 .0408 Mdot
.52403 .01861 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.5122 .60156 Mdot
.53886 .56589 Mdot
.62324 .46271 Mdot
.87456 .35809 Mdot
.29515 .49974 Mdot
.48655 .51219 Mdot
.6578 .38872 Mdot
.02884 .41531 Mdot
.49962 .00052 Mdot
.49878 .00164 Mdot
.49613 .00523 Mdot
.48766 .01666 Mdot
.4607 .05273 Mdot
.37539 .1568 Mdot
.12167 .25893 Mdot
.70272 .11785 Mdot
.51203 .1067 Mdot
.33938 .23158 Mdot
.96467 .1991 Mdot
.64252 .08394 Mdot
.50069 .61711 Mdot
.50218 .61508 Mdot
.50696 .60864 Mdot
.52216 .58816 Mdot
.5705 .52492 Mdot
.72116 .37979 Mdot
.10665 .47143 Mdot
.34387 .59404 Mdot
.38269 .07518 Mdot
.26104 .22237 Mdot
.90124 .13658 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .0021 Mdot
.49506 .00668 Mdot
.48425 .02125 Mdot
.44986 .06697 Mdot
.3415 .1908 Mdot
.03277 .22097 Mdot
.67524 .08941 Mdot
.53058 .06123 Mdot
.4315 .1228 Mdot
.23281 .26948 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49801 .00269 Mdot
.49366 .00856 Mdot
.47981 .02723 Mdot
.43575 .08519 Mdot
.29791 .2261 Mdot
.93208 .16502 Mdot
.66506 .038 Mdot
.60358 .56664 Mdot
.68674 .4306 Mdot
.99001 .42135 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49364 .0086 Mdot
.47972 .02734 Mdot
.43548 .08553 Mdot
.29708 .22667 Mdot
.93032 .16412 Mdot
.66477 .03723 Mdot
.60454 .56517 Mdot
.69008 .42796 Mdot
.99762 .42576 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.4903 .01311 Mdot
.46909 .04158 Mdot
.40181 .12694 Mdot
.19642 .2662 Mdot
.76569 .11937 Mdot
.57254 .05443 Mdot
.48447 .06881 Mdot
.37314 .17435 Mdot
.09104 .25422 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00495 Mdot
.48833 .01576 Mdot
.46284 .04989 Mdot
.38211 .14946 Mdot
.14028 .26331 Mdot
.71423 .11947 Mdot
.52092 .10014 Mdot
.35889 .21447 Mdot
.01187 .22546 Mdot
.64706 .10772 Mdot
.49972 .00038 Mdot
.49909 .00123 Mdot
.49711 .00391 Mdot
.49078 .01245 Mdot
.47065 .03951 Mdot
.40673 .12111 Mdot
.21077 .26419 Mdot
.78329 .11987 Mdot
.58935 .04132 Mdot
.52249 .02054 Mdot
.48925 .0305 Mdot
.4399 .0849 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48983 .01374 Mdot
.4676 .04357 Mdot
.3971 .13245 Mdot
.1828 .26704 Mdot
.75072 .11949 Mdot
.55738 .06744 Mdot
.44826 .11457 Mdot
.49986 .00018 Mdot
.49957 .00059 Mdot
.49862 .00187 Mdot
.49559 .00595 Mdot
.48596 .01895 Mdot
.45529 .05986 Mdot
.35844 .17446 Mdot
.07617 .2424 Mdot
.68395 .10738 Mdot
.51021 .09793 Mdot
.35176 .21633 Mdot
.00173 .21793 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00407 Mdot
.49039 .01297 Mdot
.4694 .04117 Mdot
.40279 .12578 Mdot
.19927 .2659 Mdot
.76904 .11941 Mdot
.57584 .05173 Mdot
.49213 .05902 Mdot
.39663 .14826 Mdot
.15675 .27119 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.4973 .00365 Mdot
.49139 .01163 Mdot
.47258 .03692 Mdot
.41284 .11375 Mdot
.22879 .25998 Mdot
.80812 .12217 Mdot
.61045 .0278 Mdot
.56546 .58685 Mdot
.61593 .48863 Mdot
.82531 .3573 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00443 Mdot
.48955 .01411 Mdot
.46673 .04473 Mdot
.39436 .13563 Mdot
.1749 .26705 Mdot
.7428 .11966 Mdot
.54919 .07478 Mdot
.4282 .13911 Mdot
.20312 .2803 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49065 .01262 Mdot
.47023 .04006 Mdot
.40541 .12267 Mdot
.20692 .26485 Mdot
.77839 .11964 Mdot
.5848 .04469 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49066 .01262 Mdot
.47025 .04004 Mdot
.40546 .12262 Mdot
.20706 .26483 Mdot
.77856 .11965 Mdot
.58496 .04457 Mdot
.51284 .03268 Mdot
.45995 .06942 Mdot
.34763 .19006 Mdot
.50108 .61658 Mdot
.50344 .61339 Mdot
.51095 .60324 Mdot
.53488 .57116 Mdot
.61072 .4766 Mdot
.83957 .35181 Mdot
.27033 .49815 Mdot
.4643 .53097 Mdot
.60518 .44041 Mdot
.89258 .34821 Mdot
.32915 .47788 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51289 .60064 Mdot
.54103 .56302 Mdot
.63005 .45543 Mdot
.89315 .36365 Mdot
.30475 .50255 Mdot
.49161 .51032 Mdot
.66589 .38291 Mdot
.04633 .42526 Mdot
.35825 .53997 Mdot
.50026 .61768 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50838 .60671 Mdot
.5267 .58207 Mdot
.58489 .50705 Mdot
.76446 .36012 Mdot
.18178 .49431 Mdot
.38196 .59398 Mdot
.42088 .04631 Mdot
.34596 .16784 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00456 Mdot
.48924 .01452 Mdot
.46575 .04603 Mdot
.39126 .13918 Mdot
.16606 .26668 Mdot
.73457 .11982 Mdot
.54069 .08251 Mdot
.40718 .16377 Mdot
.1422 .27874 Mdot
.69119 .14116 Mdot
.50091 .61681 Mdot
.50288 .61414 Mdot
.50919 .60563 Mdot
.52927 .57865 Mdot
.59299 .49726 Mdot
.78841 .35399 Mdot
.21564 .49811 Mdot
.40968 .57742 Mdot
.4754 .60013 Mdot
.50437 .59608 Mdot
.53989 .55949 Mdot
.50112 .61652 Mdot
.50356 .61323 Mdot
.51134 .60272 Mdot
.53611 .56954 Mdot
.61458 .47226 Mdot
.85045 .35314 Mdot
.27906 .49823 Mdot
.47291 .52322 Mdot
.62632 .41803 Mdot
.94993 .37237 Mdot
.34741 .49313 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49706 .00397 Mdot
.49065 .01263 Mdot
.47021 .04009 Mdot
.40534 .12276 Mdot
.20672 .26488 Mdot
.77813 .11963 Mdot
.58456 .04488 Mdot
.51195 .03381 Mdot
.45724 .07297 Mdot
.33917 .19796 Mdot
.50036 .61755 Mdot
.50113 .61651 Mdot
.5036 .61316 Mdot
.51148 .60253 Mdot
.53658 .56892 Mdot
.61605 .47062 Mdot
.85458 .35379 Mdot
.28213 .49834 Mdot
.47579 .52069 Mdot
.63329 .41107 Mdot
.96816 .38176 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49746 .00343 Mdot
.4919 .01094 Mdot
.47421 .03474 Mdot
.418 .10744 Mdot
.24415 .25489 Mdot
.83173 .12637 Mdot
.62725 .02058 Mdot
.59395 .55649 Mdot
.69354 .41813 Mdot
.01699 .43385 Mdot
.50101 .61667 Mdot
.50321 .6137 Mdot
.51022 .60423 Mdot
.53257 .57425 Mdot
.60342 .48498 Mdot
.81871 .35097 Mdot
.25082 .49851 Mdot
.44421 .54918 Mdot
.55563 .49865 Mdot
.7488 .35111 Mdot
.1807 .48488 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49714 .00386 Mdot
.4909 .01229 Mdot
.47102 .039 Mdot
.40791 .11969 Mdot
.21425 .26353 Mdot
.78786 .12014 Mdot
.59347 .03838 Mdot
.53137 .00949 Mdot
.51602 .61269 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49846 .00208 Mdot
.49509 .00663 Mdot
.48437 .02109 Mdot
.45024 .06648 Mdot
.34267 .18971 Mdot
.03571 .22254 Mdot
.67563 .09081 Mdot
.5287 .06435 Mdot
.42457 .13169 Mdot
.21149 .27494 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60224 Mdot
.53725 .56803 Mdot
.61816 .46828 Mdot
.86047 .35487 Mdot
.28628 .4986 Mdot
.47953 .51752 Mdot
.64216 .40258 Mdot
.99078 .39403 Mdot
.35322 .51161 Mdot
.50031 .61762 Mdot
.50098 .6167 Mdot
.50314 .6138 Mdot
.50999 .60454 Mdot
.53182 .57524 Mdot
.60106 .48772 Mdot
.81191 .3512 Mdot
.24366 .49863 Mdot
.43686 .55564 Mdot
.53783 .5209 Mdot
.695 .38207 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.49339 .00892 Mdot
.47896 .02837 Mdot
.43305 .08862 Mdot
.28965 .23161 Mdot
.91489 .15642 Mdot
.6618 .03096 Mdot
.6117 .55374 Mdot
.71573 .4096 Mdot
.05299 .45782 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00284 Mdot
.49331 .00904 Mdot
.47868 .02874 Mdot
.43218 .08973 Mdot
.28699 .23331 Mdot
.90949 .15385 Mdot
.66055 .029 Mdot
.61363 .55042 Mdot
.72303 .40499 Mdot
.06775 .46591 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50746 .60796 Mdot
.52376 .58602 Mdot
.57555 .51858 Mdot
.73647 .37157 Mdot
.13526 .4824 Mdot
.35472 .59915 Mdot
.38527 .0785 Mdot
.25827 .22584 Mdot
.89285 .13384 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49068 .01258 Mdot
.47033 .03993 Mdot
.40571 .12232 Mdot
.20779 .26471 Mdot
.77949 .11969 Mdot
.58583 .04392 Mdot
.51477 .03025 Mdot
.46583 .06168 Mdot
.36602 .17173 Mdot
.50111 .61654 Mdot
.50353 .61326 Mdot
.51126 .60284 Mdot
.53585 .56988 Mdot
.61376 .47318 Mdot
.84814 .35281 Mdot
.27729 .49819 Mdot
.47121 .52474 Mdot
.62217 .42228 Mdot
.9389 .36702 Mdot
.34505 .48902 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48946 .01423 Mdot
.46643 .04512 Mdot
.39343 .13669 Mdot
.17226 .26698 Mdot
.74027 .11971 Mdot
.54657 .07716 Mdot
.42172 .14683 Mdot
.18415 .28193 Mdot
.72798 .13579 Mdot
.50026 .61769 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50832 .6068 Mdot
.52651 .58234 Mdot
.58426 .50782 Mdot
.7626 .36074 Mdot
.17892 .49381 Mdot
.37992 .59486 Mdot
.41741 .05 Mdot
.33651 .17628 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60802 Mdot
.52363 .58619 Mdot
.57514 .51909 Mdot
.73523 .37218 Mdot
.13303 .48164 Mdot
.35372 .59895 Mdot
.3846 .07877 Mdot
.25715 .22616 Mdot
.89121 .13298 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49392 .00822 Mdot
.48062 .02614 Mdot
.43833 .08189 Mdot
.30582 .22045 Mdot
.94912 .17408 Mdot
.66744 .04595 Mdot
.5931 .58251 Mdot
.65057 .46284 Mdot
.50121 .6164 Mdot
.50385 .61284 Mdot
.51226 .60149 Mdot
.53903 .56566 Mdot
.62377 .46214 Mdot
.87601 .35848 Mdot
.29598 .4999 Mdot
.48712 .51183 Mdot
.65896 .38778 Mdot
.03153 .41681 Mdot
.35711 .53218 Mdot
.5005 .61735 Mdot
.5016 .61587 Mdot
.50511 .61113 Mdot
.51629 .59605 Mdot
.55185 .54883 Mdot
.66383 .42238 Mdot
.9804 .40426 Mdot
.32629 .53518 Mdot
.46036 .57154 Mdot
.53558 .53883 Mdot
.66374 .41243 Mdot
.50079 .61697 Mdot
.50251 .61465 Mdot
.50798 .60725 Mdot
.52544 .58377 Mdot
.58088 .51198 Mdot
.75248 .36445 Mdot
.16278 .49039 Mdot
.36931 .59838 Mdot
.40111 .06623 Mdot
.29394 .20819 Mdot
.95708 .16888 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50891 .606 Mdot
.52839 .57981 Mdot
.59024 .50057 Mdot
.7803 .35569 Mdot
.20478 .49732 Mdot
.4001 .58397 Mdot
.45522 .0069 Mdot
.44406 .0577 Mdot
.35069 .17669 Mdot
.50094 .61676 Mdot
.503 .61398 Mdot
.50956 .60513 Mdot
.53044 .57707 Mdot
.59672 .49283 Mdot
.7993 .35231 Mdot
.22926 .4986 Mdot
.4225 .56764 Mdot
.50404 .56389 Mdot
.59165 .48355 Mdot
.80924 .34611 Mdot
.50092 .61679 Mdot
.50294 .61406 Mdot
.50938 .60537 Mdot
.52987 .57783 Mdot
.59492 .49497 Mdot
.79405 .35304 Mdot
.22282 .49843 Mdot
.41634 .57247 Mdot
.49007 .58167 Mdot
.5489 .53705 Mdot
.67994 .40357 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.5101 .60439 Mdot
.53217 .57477 Mdot
.60218 .48642 Mdot
.81513 .35106 Mdot
.2471 .49858 Mdot
.44038 .55256 Mdot
.54632 .51023 Mdot
.72075 .36517 Mdot
.1299 .47266 Mdot
.50047 .61739 Mdot
.50151 .61599 Mdot
.50481 .61153 Mdot
.51533 .59734 Mdot
.54882 .55279 Mdot
.65438 .43108 Mdot
.95687 .39159 Mdot
.32327 .52378 Mdot
.47578 .54614 Mdot
.5921 .46544 Mdot
.839 .34037 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.47611 .0322 Mdot
.42401 .1 Mdot
.2622 .24711 Mdot
.86236 .13484 Mdot
.64419 .01871 Mdot
.61391 .53993 Mdot
.74028 .39267 Mdot
.10493 .48305 Mdot
.5004 .6175 Mdot
.50126 .61633 Mdot
.50402 .6126 Mdot
.51281 .60074 Mdot
.5408 .56332 Mdot
.62932 .4562 Mdot
.89118 .36299 Mdot
.30384 .50218 Mdot
.4913 .51024 Mdot
.66572 .3829 Mdot
.04618 .42511 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54245 .56115 Mdot
.63448 .4508 Mdot
.90508 .36793 Mdot
.30977 .50519 Mdot
.49235 .51227 Mdot
.66348 .386 Mdot
.03892 .42172 Mdot
.35656 .53741 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49818 .00245 Mdot
.49421 .00782 Mdot
.48157 .02487 Mdot
.44133 .07803 Mdot
.31507 .21342 Mdot
.96976 .18555 Mdot
.66953 .05646 Mdot
.57818 .6049 Mdot
.59943 .5186 Mdot
.76031 .37137 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60337 Mdot
.53459 .57156 Mdot
.60979 .47766 Mdot
.83691 .35158 Mdot
.26805 .49817 Mdot
.46199 .53308 Mdot
.59945 .44677 Mdot
.87656 .34347 Mdot
.32082 .47664 Mdot
.50057 .61726 Mdot
.50181 .61558 Mdot
.50578 .61023 Mdot
.51841 .59319 Mdot
.55861 .54008 Mdot
.68474 .40477 Mdot
.02981 .43224 Mdot
.33043 .56135 Mdot
.42215 .01264 Mdot
.4017 .09808 Mdot
.243 .24549 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49674 .0044 Mdot
.48962 .01402 Mdot
.46693 .04446 Mdot
.39498 .13491 Mdot
.1767 .26708 Mdot
.74456 .11962 Mdot
.55101 .07314 Mdot
.43267 .13371 Mdot
.21632 .27796 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49603 .00536 Mdot
.48737 .01706 Mdot
.45976 .05396 Mdot
.37245 .15995 Mdot
.11365 .25658 Mdot
.6985 .11669 Mdot
.50968 .10772 Mdot
.33538 .23454 Mdot
.95589 .19417 Mdot
.64172 .07947 Mdot
.5004 .61749 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60041 Mdot
.54156 .56232 Mdot
.63172 .45368 Mdot
.89765 .3652 Mdot
.30674 .50347 Mdot
.49212 .51077 Mdot
.66567 .38346 Mdot
.04522 .42482 Mdot
.50116 .61647 Mdot
.5037 .61304 Mdot
.51178 .60213 Mdot
.53751 .56768 Mdot
.61897 .46738 Mdot
.86274 .35533 Mdot
.28781 .49873 Mdot
.48084 .51645 Mdot
.64522 .39974 Mdot
.99842 .39828 Mdot
.35399 .51543 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00314 Mdot
.4926 .00999 Mdot
.47644 .03176 Mdot
.42505 .09869 Mdot
.26536 .24555 Mdot
.86805 .13677 Mdot
.64676 .01919 Mdot
.6157 .53917 Mdot
.7433 .39176 Mdot
.10942 .48539 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00443 Mdot
.48956 .01409 Mdot
.46676 .04469 Mdot
.39445 .13552 Mdot
.17518 .26706 Mdot
.74308 .11965 Mdot
.54947 .07452 Mdot
.42889 .13827 Mdot
.20517 .28 Mdot
.75212 .13247 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50376 .61295 Mdot
.51199 .60184 Mdot
.5382 .56677 Mdot
.62114 .465 Mdot
.86876 .35666 Mdot
.29167 .49917 Mdot
.48399 .51399 Mdot
.65233 .39337 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.49571 .00579 Mdot
.48634 .01845 Mdot
.45649 .05828 Mdot
.36219 .17066 Mdot
.08606 .24661 Mdot
.68704 .11046 Mdot
.50831 .10276 Mdot
.34203 .22632 Mdot
.97584 .20401 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.4862 .01862 Mdot
.45607 .05884 Mdot
.36087 .17201 Mdot
.08256 .24515 Mdot
.68589 .10942 Mdot
.50884 .10122 Mdot
.34506 .22323 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50493 .61138 Mdot
.5157 .59685 Mdot
.54997 .55128 Mdot
.65797 .42773 Mdot
.9659 .39635 Mdot
.32459 .52799 Mdot
.47028 .55538 Mdot
.57166 .49117 Mdot
.77693 .34573 Mdot
.50023 .61772 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50758 .6078 Mdot
.52414 .5855 Mdot
.57679 .51705 Mdot
.74019 .36978 Mdot
.14187 .48456 Mdot
.35783 .59952 Mdot
.38779 .07711 Mdot
.26303 .22416 Mdot
.5004 .61749 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.51291 .6006 Mdot
.54112 .56291 Mdot
.63032 .45515 Mdot
.89387 .36389 Mdot
.30508 .50269 Mdot
.49171 .51037 Mdot
.66591 .38295 Mdot
.04629 .42526 Mdot
.5004 .61749 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.5131 .60035 Mdot
.5417 .56214 Mdot
.63214 .45323 Mdot
.8988 .36561 Mdot
.30723 .50372 Mdot
.4922 .51094 Mdot
.66548 .38372 Mdot
.04461 .42453 Mdot
.50093 .61677 Mdot
.50297 .61402 Mdot
.50947 .60525 Mdot
.53015 .57746 Mdot
.5958 .49392 Mdot
.79663 .35266 Mdot
.22602 .49853 Mdot
.41938 .57012 Mdot
.49691 .57299 Mdot
.5698 .51034 Mdot
.74405 .36289 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50627 .60956 Mdot
.51999 .59107 Mdot
.56361 .53366 Mdot
.70013 .3933 Mdot
.06376 .45084 Mdot
.33429 .57817 Mdot
.39878 .04778 Mdot
.32148 .18069 Mdot
.02912 .20753 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50813 .60706 Mdot
.52589 .58316 Mdot
.58232 .5102 Mdot
.7568 .36279 Mdot
.16979 .49199 Mdot
.37373 .59715 Mdot
.40752 .06011 Mdot
.31026 .1972 Mdot
.99119 .18903 Mdot
.50074 .61704 Mdot
.50234 .61487 Mdot
.50746 .60795 Mdot
.52377 .58599 Mdot
.57562 .5185 Mdot
.73666 .37148 Mdot
.1356 .48252 Mdot
.35487 .59917 Mdot
.38538 .07845 Mdot
.25845 .22578 Mdot
.89313 .13399 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00373 Mdot
.4912 .01189 Mdot
.47197 .03774 Mdot
.41091 .11608 Mdot
.22309 .26152 Mdot
.79993 .12118 Mdot
.60386 .03158 Mdot
.55276 .6016 Mdot
.57934 .53106 Mdot
.72007 .38611 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50102 .61665 Mdot
.50326 .61362 Mdot
.5104 .60399 Mdot
.53312 .57351 Mdot
.60516 .48296 Mdot
.82372 .35096 Mdot
.25585 .49841 Mdot
.44941 .54452 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49065 .01262 Mdot
.47023 .04007 Mdot
.4054 .12269 Mdot
.20687 .26486 Mdot
.77833 .11964 Mdot
.58475 .04474 Mdot
.51236 .03329 Mdot
.45849 .07134 Mdot
.34306 .19437 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50759 .60779 Mdot
.52417 .58547 Mdot
.57686 .51695 Mdot
.74042 .36967 Mdot
.14228 .48469 Mdot
.35803 .59953 Mdot
.38797 .07699 Mdot
.26339 .22401 Mdot
.90093 .13799 Mdot
.50103 .61664 Mdot
.50328 .61361 Mdot
.51044 .60394 Mdot
.53325 .57333 Mdot
.60558 .48248 Mdot
.82492 .35098 Mdot
.25702 .49838 Mdot
.45063 .54342 Mdot
.57135 .47947 Mdot
.79556 .33793 Mdot
.24878 .48547 Mdot
.50029 .61765 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.50929 .60549 Mdot
.52959 .57821 Mdot
.59403 .49602 Mdot
.79146 .35345 Mdot
.21956 .49831 Mdot
.41329 .57478 Mdot
.48328 .59025 Mdot
.52824 .5642 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49947 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48301 .02292 Mdot
.44592 .0721 Mdot
.32927 .20172 Mdot
.00289 .20439 Mdot
.67217 .07414 Mdot
.55222 .02659 Mdot
.50919 .01808 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00352 Mdot
.49169 .01122 Mdot
.47353 .03565 Mdot
.41585 .11008 Mdot
.23773 .25719 Mdot
.8216 .12432 Mdot
.62044 .02302 Mdot
.58319 .5674 Mdot
.66512 .44034 Mdot
.50095 .61675 Mdot
.50302 .61395 Mdot
.50962 .60504 Mdot
.53065 .57681 Mdot
.59735 .49208 Mdot
.80115 .35209 Mdot
.23146 .49863 Mdot
.42466 .5659 Mdot
.509 .55756 Mdot
.60686 .46578 Mdot
.85322 .34819 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51227 .60146 Mdot
.53908 .56559 Mdot
.62394 .46196 Mdot
.87647 .3586 Mdot
.29624 .49996 Mdot
.48729 .51173 Mdot
.6593 .3875 Mdot
.03232 .41725 Mdot
.35719 .53258 Mdot
.5 .61803 Mdot
.5 .61803 Mdot
.5 .61803 Mdot
.50001 .61802 Mdot
.50004 .61799 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50113 .6165 Mdot
.50362 .61315 Mdot
.51152 .60248 Mdot
.53668 .56877 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49133 .0117 Mdot
.4724 .03716 Mdot
.41226 .11444 Mdot
.22709 .26046 Mdot
.80566 .12185 Mdot
.6085 .02887 Mdot
.56179 .59105 Mdot
.60545 .50029 Mdot
.79597 .35886 Mdot
.50065 .61716 Mdot
.50207 .61523 Mdot
.5066 .60911 Mdot
.52104 .58967 Mdot
.56694 .52942 Mdot
.71031 .38644 Mdot
.08503 .46158 Mdot
.33819 .58704 Mdot
.38833 .06425 Mdot
.28438 .20836 Mdot
.94724 .16034 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49247 .01017 Mdot
.47602 .03231 Mdot
.42375 .10032 Mdot
.26142 .24749 Mdot
.86097 .13438 Mdot
.64354 .01863 Mdot
.61339 .54022 Mdot
.7393 .39301 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00389 Mdot
.49084 .01237 Mdot
.47082 .03928 Mdot
.40726 .12046 Mdot
.21235 .2639 Mdot
.78535 .11998 Mdot
.59122 .03997 Mdot
.52655 .01547 Mdot
.50151 .01407 Mdot
.47874 .03372 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60973 Mdot
.51959 .59162 Mdot
.56233 .5353 Mdot
.69619 .39611 Mdot
.05527 .44633 Mdot
.3331 .57421 Mdot
.40401 .03987 Mdot
.3395 .16469 Mdot
.07303 .23004 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .00499 Mdot
.48822 .0159 Mdot
.4625 .05035 Mdot
.38103 .15065 Mdot
.13727 .26271 Mdot
.7122 .1193 Mdot
.51916 .10158 Mdot
.3548 .21828 Mdot
.00161 .21978 Mdot
.64601 .10262 Mdot
.50086 .61687 Mdot
.50273 .61434 Mdot
.50871 .60627 Mdot
.52775 .58067 Mdot
.58822 .50301 Mdot
.77433 .35718 Mdot
.19639 .49644 Mdot
.39314 .58823 Mdot
.44136 .02333 Mdot
.40361 .10732 Mdot
.22996 .2537 Mdot
.50002 .618 Mdot
.50008 .61793 Mdot
.50024 .61771 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50774 .60758 Mdot
.52466 .58481 Mdot
.57841 .51503 Mdot
.74508 .36755 Mdot
.15037 .48712 Mdot
.36219 .5995 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48858 .01542 Mdot
.46364 .04883 Mdot
.38463 .14666 Mdot
.14734 .26456 Mdot
.71928 .11975 Mdot
.52552 .0962 Mdot
.36987 .20384 Mdot
.04005 .24058 Mdot
.65079 .12078 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49756 .0033 Mdot
.49221 .01052 Mdot
.47519 .03343 Mdot
.42109 .10362 Mdot
.25343 .25113 Mdot
.84709 .1302 Mdot
.63642 .01866 Mdot
.60623 .54536 Mdot
.72382 .39981 Mdot
.07692 .46837 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.46492 .04714 Mdot
.38865 .14215 Mdot
.15865 .26605 Mdot
.72817 .11989 Mdot
.53419 .08844 Mdot
.3911 .1817 Mdot
.0971 .26624 Mdot
.66632 .13862 Mdot
.50055 .61729 Mdot
.50175 .61567 Mdot
.50557 .61052 Mdot
.51773 .59411 Mdot
.55644 .54288 Mdot
.67804 .41016 Mdot
.01438 .42347 Mdot
.32918 .55313 Mdot
.43419 .61242 Mdot
.44328 .04586 Mdot
.36909 .15399 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49457 .00733 Mdot
.48271 .02332 Mdot
.44498 .07332 Mdot
.32635 .20421 Mdot
.99592 .20043 Mdot
.67162 .07042 Mdot
.55767 .01813 Mdot
.52834 .61002 Mdot
.5413 .57216 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48756 .0168 Mdot
.46037 .05316 Mdot
.37436 .1579 Mdot
.11887 .25814 Mdot
.70119 .11748 Mdot
.51111 .10719 Mdot
.33768 .2329 Mdot
.96083 .19696 Mdot
.64215 .08202 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50212 .61517 Mdot
.50674 .60892 Mdot
.52148 .58907 Mdot
.56835 .52763 Mdot
.71463 .38371 Mdot
.09378 .4657 Mdot
.34025 .59015 Mdot
.38536 .06944 Mdot
.27301 .21544 Mdot
.50014 .61784 Mdot
.50046 .61742 Mdot
.50146 .61606 Mdot
.50465 .61175 Mdot
.51481 .59804 Mdot
.54716 .55496 Mdot
.64921 .43603 Mdot
.9437 .38492 Mdot
.32089 .51807 Mdot
.48264 .53413 Mdot
.61841 .4342 Mdot
.50004 .61798 Mdot
.50014 .61785 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50448 .61198 Mdot
.51429 .59875 Mdot
.54549 .55715 Mdot
.644 .44113 Mdot
.93023 .37851 Mdot
.31779 .51287 Mdot
.48795 .52403 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49704 .004 Mdot
.49057 .01274 Mdot
.46996 .04041 Mdot
.40457 .12368 Mdot
.20446 .26522 Mdot
.77532 .11954 Mdot
.5819 .04692 Mdot
.50598 .04137 Mdot
.43904 .09651 Mdot
.28288 .24092 Mdot
.50125 .61635 Mdot
.50397 .61267 Mdot
.51265 .60095 Mdot
.5403 .56399 Mdot
.62774 .45788 Mdot
.88689 .36162 Mdot
.30177 .50143 Mdot
.49044 .51028 Mdot
.66479 .38338 Mdot
.04446 .42407 Mdot
.3583 .53875 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00438 Mdot
.48968 .01394 Mdot
.46713 .0442 Mdot
.39561 .13418 Mdot
.17851 .26709 Mdot
.74635 .11958 Mdot
.55287 .07147 Mdot
.43723 .12816 Mdot
.22986 .27453 Mdot
.78567 .13067 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49673 .00441 Mdot
.4896 .01405 Mdot
.46686 .04455 Mdot
.39478 .13514 Mdot
.17612 .26707 Mdot
.74399 .11963 Mdot
.55042 .07367 Mdot
.43122 .13546 Mdot
.21205 .27883 Mdot
.76089 .13163 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49824 .00237 Mdot
.4944 .00756 Mdot
.48217 .02406 Mdot
.44325 .07556 Mdot
.32098 .20868 Mdot
.98334 .19326 Mdot
.67064 .06368 Mdot
.56761 .00287 Mdot
.56297 .56403 Mdot
.65035 .44448 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00554 Mdot
.48693 .01765 Mdot
.45837 .0558 Mdot
.36809 .16456 Mdot
.10182 .25264 Mdot
.69303 .11445 Mdot
.50784 .10719 Mdot
.33441 .23446 Mdot
.95505 .19334 Mdot
.64222 .07835 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60457 Mdot
.53176 .57533 Mdot
.60086 .48796 Mdot
.81133 .35123 Mdot
.24302 .49863 Mdot
.43622 .5562 Mdot
.53627 .52286 Mdot
.69026 .38559 Mdot
.50115 .61647 Mdot
.50368 .61307 Mdot
.51171 .60222 Mdot
.53731 .56794 Mdot
.61836 .46806 Mdot
.86102 .35498 Mdot
.28665 .49863 Mdot
.47985 .51726 Mdot
.64291 .40187 Mdot
.99268 .39508 Mdot
.35342 .51256 Mdot
.50012 .61787 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51272 .60086 Mdot
.54051 .5637 Mdot
.62842 .45716 Mdot
.88872 .3622 Mdot
.30267 .50174 Mdot
.49084 .51022 Mdot
.66528 .38309 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50874 .60623 Mdot
.52784 .58055 Mdot
.5885 .50267 Mdot
.77517 .35696 Mdot
.19759 .49658 Mdot
.39411 .58766 Mdot
.44325 .02113 Mdot
.40906 .10092 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.4882 .01594 Mdot
.46241 .05047 Mdot
.38075 .15096 Mdot
.13648 .26254 Mdot
.71168 .11925 Mdot
.51872 .10194 Mdot
.35379 .2192 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00334 Mdot
.49211 .01065 Mdot
.47488 .03385 Mdot
.42011 .10484 Mdot
.25048 .25238 Mdot
.84212 .12887 Mdot
.63361 .01905 Mdot
.60278 .54829 Mdot
.71563 .40417 Mdot
.06166 .45992 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00183 Mdot
.49569 .00582 Mdot
.48628 .01852 Mdot
.45631 .05851 Mdot
.36164 .17123 Mdot
.08459 .246 Mdot
.68655 .11003 Mdot
.50851 .10214 Mdot
.50074 .61704 Mdot
.50235 .61486 Mdot
.50748 .60792 Mdot
.52384 .5859 Mdot
.57583 .51823 Mdot
.73731 .37116 Mdot
.13676 .48291 Mdot
.3554 .59926 Mdot
.38578 .07826 Mdot
.25915 .22556 Mdot
.89418 .13453 Mdot
.50119 .61643 Mdot
.50378 .61292 Mdot
.51205 .60176 Mdot
.53838 .56653 Mdot
.62172 .46437 Mdot
.87036 .35704 Mdot
.29266 .49932 Mdot
.48475 .51344 Mdot
.65399 .39194 Mdot
.01982 .41027 Mdot
.356 .52628 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .00421 Mdot
.49008 .0134 Mdot
.46839 .04251 Mdot
.3996 .12954 Mdot
.19 .26672 Mdot
.75843 .11939 Mdot
.56526 .06056 Mdot
.46727 .09069 Mdot
.32053 .22398 Mdot
.95811 .1856 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49809 .00258 Mdot
.49391 .00823 Mdot
.4806 .02616 Mdot
.43827 .08197 Mdot
.30564 .22059 Mdot
.94872 .17387 Mdot
.6674 .04575 Mdot
.59336 .58212 Mdot
.65148 .46195 Mdot
.90403 .37828 Mdot
.5005 .61736 Mdot
.50158 .61589 Mdot
.50505 .61122 Mdot
.51608 .59634 Mdot
.55118 .5497 Mdot
.66174 .42427 Mdot
.97526 .40143 Mdot
.32574 .53258 Mdot
.46401 .56566 Mdot
.54875 .52118 Mdot
.70546 .37937 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49303 .00941 Mdot
.4778 .02992 Mdot
.42939 .09326 Mdot
.27849 .23844 Mdot
.89268 .14633 Mdot
.65592 .02381 Mdot
.61739 .54262 Mdot
.73941 .39541 Mdot
.09963 .48185 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50896 .60594 Mdot
.52853 .57964 Mdot
.59065 .50007 Mdot
.78153 .35541 Mdot
.20647 .49747 Mdot
.40155 .58303 Mdot
.45819 .0033 Mdot
.45285 .04638 Mdot
.3778 .14886 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47738 .03049 Mdot
.42806 .09493 Mdot
.27445 .24074 Mdot
.88493 .14312 Mdot
.65336 .02195 Mdot
.61785 .54044 Mdot
.7434 .39302 Mdot
.10748 .48526 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .01421 Mdot
.46648 .04506 Mdot
.39357 .13653 Mdot
.17266 .267 Mdot
.74066 .11971 Mdot
.54697 .07679 Mdot
.42271 .14566 Mdot
.18703 .28181 Mdot
.73106 .1353 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50503 .61124 Mdot
.51602 .59642 Mdot
.55099 .54995 Mdot
.66115 .42481 Mdot
.97379 .40062 Mdot
.32557 .53184 Mdot
.46503 .56401 Mdot
.55245 .51626 Mdot
.71712 .37185 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .0021 Mdot
.49506 .00667 Mdot
.48426 .02124 Mdot
.44989 .06694 Mdot
.34159 .19072 Mdot
.033 .22109 Mdot
.67527 .08951 Mdot
.53043 .06147 Mdot
.43097 .12348 Mdot
.23116 .27 Mdot
.49966 .00046 Mdot
.4989 .00148 Mdot
.49651 .00472 Mdot
.48888 .01502 Mdot
.46457 .04759 Mdot
.38757 .14337 Mdot
.15559 .26571 Mdot
.72567 .11988 Mdot
.53169 .0907 Mdot
.38494 .18831 Mdot
.08025 .25959 Mdot
.66022 .13491 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01313 Mdot
.46902 .04167 Mdot
.4016 .12719 Mdot
.19581 .26626 Mdot
.76499 .11937 Mdot
.57184 .05501 Mdot
.48283 .07089 Mdot
.36812 .17963 Mdot
.07747 .24865 Mdot
.50019 .61778 Mdot
.50059 .61723 Mdot
.50189 .61547 Mdot
.50604 .60988 Mdot
.51923 .59209 Mdot
.5612 .53674 Mdot
.69273 .39865 Mdot
.04771 .44222 Mdot
.33219 .57052 Mdot
.40906 .03228 Mdot
.35683 .14781 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47455 .03429 Mdot
.41907 .10613 Mdot
.24735 .25365 Mdot
.83694 .12758 Mdot
.63051 .01969 Mdot
.59865 .55202 Mdot
.70546 .41021 Mdot
.04172 .44845 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50793 .60733 Mdot
.52525 .58401 Mdot
.5803 .51269 Mdot
.75074 .36515 Mdot
.15991 .48968 Mdot
.36759 .59876 Mdot
.39878 .06836 Mdot
.28817 .21168 Mdot
.94566 .16228 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.46781 .04329 Mdot
.39777 .13168 Mdot
.18472 .26698 Mdot
.75273 .11946 Mdot
.55945 .06562 Mdot
.45327 .10832 Mdot
.27801 .25358 Mdot
.86771 .14458 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51222 .60154 Mdot
.53891 .56582 Mdot
.6234 .46254 Mdot
.87499 .35821 Mdot
.2954 .49979 Mdot
.48672 .51208 Mdot
.65816 .38843 Mdot
.02966 .41577 Mdot
.35693 .53125 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49804 .00265 Mdot
.49375 .00844 Mdot
.48008 .02686 Mdot
.43662 .08407 Mdot
.30059 .22422 Mdot
.93779 .16801 Mdot
.66594 .04057 Mdot
.6003 .57165 Mdot
.67535 .44004 Mdot
.96335 .40636 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.49322 .00916 Mdot
.4784 .02912 Mdot
.43128 .09086 Mdot
.28426 .235 Mdot
.90401 .15132 Mdot
.65918 .02715 Mdot
.61524 .54744 Mdot
.72946 .40113 Mdot
.08043 .47255 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61543 Mdot
.50613 .60975 Mdot
.51954 .59169 Mdot
.56217 .53551 Mdot
.6957 .39647 Mdot
.05421 .44575 Mdot
.33296 .5737 Mdot
.4047 .03883 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49768 .00313 Mdot
.49261 .00998 Mdot
.47647 .03171 Mdot
.42515 .09857 Mdot
.26566 .2454 Mdot
.86859 .13696 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48818 .01596 Mdot
.46236 .05053 Mdot
.38061 .15112 Mdot
.13609 .26246 Mdot
.71142 .11923 Mdot
.51851 .10211 Mdot
.3533 .21965 Mdot
.99789 .2177 Mdot
.64565 .10074 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.5071 .60845 Mdot
.52261 .58755 Mdot
.57193 .52312 Mdot
.72551 .37732 Mdot
.115 .47489 Mdot
.34661 .59607 Mdot
.38215 .07758 Mdot
.25662 .225 Mdot
.89257 .1328 Mdot
.50065 .61716 Mdot
.50206 .61525 Mdot
.50657 .60915 Mdot
.52094 .5898 Mdot
.56663 .52981 Mdot
.70938 .38705 Mdot
.08312 .46065 Mdot
.33777 .58632 Mdot
.38909 .06298 Mdot
.28719 .20652 Mdot
.95304 .16361 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .61231 Mdot
.51351 .5998 Mdot
.54301 .56041 Mdot
.63624 .44899 Mdot
.90976 .36974 Mdot
.31151 .5064 Mdot
.49213 .5137 Mdot
.66095 .38865 Mdot
.50114 .6165 Mdot
.50363 .61313 Mdot
.51156 .60243 Mdot
.53681 .5686 Mdot
.6168 .46978 Mdot
.85667 .35416 Mdot
.28363 .49842 Mdot
.47718 .51951 Mdot
.6366 .40786 Mdot
.97667 .38631 Mdot
.35161 .50479 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00366 Mdot
.49136 .01166 Mdot
.47249 .03704 Mdot
.41256 .11409 Mdot
.22796 .26022 Mdot
.80692 .12201 Mdot
.6095 .02832 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00506 Mdot
.48807 .0161 Mdot
.46202 .05098 Mdot
.37953 .1523 Mdot
.1331 .2618 Mdot
.70949 .11901 Mdot
.51693 .10335 Mdot
.34971 .22287 Mdot
.9891 .21277 Mdot
.64483 .09629 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00697 Mdot
.48357 .02217 Mdot
.44771 .06978 Mdot
.33481 .19686 Mdot
.01627 .21193 Mdot
.67337 .08115 Mdot
.54206 .04261 Mdot
.47311 .06742 Mdot
.36402 .1787 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.49659 .0046 Mdot
.48915 .01465 Mdot
.46544 .04643 Mdot
.39031 .14026 Mdot
.16337 .26648 Mdot
.73219 .11986 Mdot
.53826 .08473 Mdot
.40116 .17058 Mdot
.12515 .27501 Mdot
.68017 .14144 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49338 .00894 Mdot
.47891 .02844 Mdot
.43288 .08884 Mdot
.28914 .23194 Mdot
.91385 .15592 Mdot
.66157 .03057 Mdot
.6121 .55307 Mdot
.71721 .40864 Mdot
.05601 .4595 Mdot
.50119 .61643 Mdot
.50378 .61292 Mdot
.51205 .60176 Mdot
.53838 .56653 Mdot
.62172 .46437 Mdot
.87036 .35704 Mdot
.29266 .49932 Mdot
.48475 .51344 Mdot
.65399 .39194 Mdot
.01982 .41027 Mdot
.356 .52628 Mdot
.50032 .6176 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51042 .60396 Mdot
.53319 .57341 Mdot
.60539 .4827 Mdot
.82437 .35097 Mdot
.25649 .49839 Mdot
.45008 .54392 Mdot
.57 .48109 Mdot
.79158 .33855 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50754 .60784 Mdot
.52403 .58565 Mdot
.57644 .51748 Mdot
.73915 .37027 Mdot
.14003 .48398 Mdot
.35694 .59945 Mdot
.38701 .07758 Mdot
.26148 .22475 Mdot
.89783 .1364 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49105 .01209 Mdot
.47149 .03838 Mdot
.40938 .11793 Mdot
.21857 .2626 Mdot
.79366 .12058 Mdot
.59856 .03493 Mdot
.54204 .61445 Mdot
.54784 .57076 Mdot
.62433 .46687 Mdot
.50082 .61693 Mdot
.50261 .6145 Mdot
.50832 .60679 Mdot
.52651 .58233 Mdot
.58429 .50779 Mdot
.76266 .36071 Mdot
.17902 .49382 Mdot
.37999 .59483 Mdot
.41753 .04988 Mdot
.33683 .176 Mdot
.05205 .2234 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48792 .01631 Mdot
.46154 .05162 Mdot
.37802 .15395 Mdot
.12892 .26082 Mdot
.70691 .11865 Mdot
.51493 .10483 Mdot
.34531 .2267 Mdot
.97849 .20683 Mdot
.64384 .0909 Mdot
.50021 .61776 Mdot
.50065 .61715 Mdot
.50208 .61522 Mdot
.50663 .60908 Mdot
.52112 .58955 Mdot
.56721 .52908 Mdot
.71115 .38591 Mdot
.08674 .46239 Mdot
.33857 .58768 Mdot
.38768 .06534 Mdot
.28197 .20991 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48909 .01474 Mdot
.46524 .0467 Mdot
.38968 .14098 Mdot
.16157 .26633 Mdot
.73064 .11987 Mdot
.53668 .08617 Mdot
.39724 .17495 Mdot
.11416 .27194 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51585 .59664 Mdot
.55046 .55064 Mdot
.65951 .42631 Mdot
.96974 .39842 Mdot
.32508 .52985 Mdot
.46777 .55952 Mdot
.56245 .5031 Mdot
.74842 .35556 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.4966 .0046 Mdot
.48916 .01464 Mdot
.46547 .04641 Mdot
.39038 .14019 Mdot
.16355 .26649 Mdot
.73235 .11986 Mdot
.53842 .08458 Mdot
.40156 .17013 Mdot
.12628 .2753 Mdot
.68084 .14147 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49839 .00217 Mdot
.49488 .00692 Mdot
.48368 .02202 Mdot
.44806 .06932 Mdot
.33589 .19589 Mdot
.01893 .2134 Mdot
.67364 .08252 Mdot
.54012 .04571 Mdot
.46615 .07686 Mdot
.3418 .20053 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.4899 .01364 Mdot
.46783 .04326 Mdot
.39784 .13159 Mdot
.18493 .26697 Mdot
.75296 .11945 Mdot
.55968 .06542 Mdot
.45383 .10762 Mdot
.2797 .2526 Mdot
.87099 .14567 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49092 .01227 Mdot
.47107 .03894 Mdot
.40806 .11951 Mdot
.21469 .26344 Mdot
.78844 .12018 Mdot
.59399 .03802 Mdot
.53248 .00812 Mdot
.51934 .60827 Mdot
.53514 .57596 Mdot
.50026 .61768 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50855 .60649 Mdot
.52722 .58138 Mdot
.58654 .50504 Mdot
.76936 .35859 Mdot
.18915 .49548 Mdot
.38744 .59134 Mdot
.43063 .0356 Mdot
.37302 .14123 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49324 .00913 Mdot
.47848 .02902 Mdot
.43152 .09056 Mdot
.28498 .23456 Mdot
.90546 .15198 Mdot
.65955 .02763 Mdot
.61485 .54819 Mdot
.72786 .40207 Mdot
.0773 .47095 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00506 Mdot
.48807 .0161 Mdot
.46202 .05098 Mdot
.37953 .1523 Mdot
.13311 .26181 Mdot
.7095 .11901 Mdot
.51693 .10334 Mdot
.34972 .22286 Mdot
.98912 .21278 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00298 Mdot
.49298 .00948 Mdot
.47765 .03013 Mdot
.42889 .09388 Mdot
.27698 .23931 Mdot
.88977 .1451 Mdot
.65499 .02307 Mdot
.61767 .54169 Mdot
.74119 .39437 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.4879 .01634 Mdot
.46146 .05172 Mdot
.37777 .15422 Mdot
.12825 .26065 Mdot
.7065 .11858 Mdot
.51463 .10504 Mdot
.34467 .22725 Mdot
.97698 .20598 Mdot
.6437 .09014 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49514 .00657 Mdot
.48451 .02091 Mdot
.45068 .0659 Mdot
.34406 .18842 Mdot
.03919 .22438 Mdot
.67613 .09245 Mdot
.52654 .06795 Mdot
.41659 .14179 Mdot
.18717 .27799 Mdot
.50098 .61671 Mdot
.50313 .6138 Mdot
.50998 .60456 Mdot
.53178 .57529 Mdot
.60094 .48787 Mdot
.81155 .35122 Mdot
.24327 .49863 Mdot
.43647 .55598 Mdot
.53687 .5221 Mdot
.69209 .38422 Mdot
.07041 .44738 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46216 .0508 Mdot
.37996 .15182 Mdot
.13431 .26207 Mdot
.71026 .1191 Mdot
.51755 .10287 Mdot
.35111 .22162 Mdot
.99251 .21469 Mdot
.50064 .61717 Mdot
.50204 .61527 Mdot
.50651 .60924 Mdot
.52073 .59008 Mdot
.56597 .53066 Mdot
.70734 .38838 Mdot
.07893 .45859 Mdot
.33691 .58467 Mdot
.39089 .06005 Mdot
.29373 .20206 Mdot
.96678 .17149 Mdot
.49977 .00031 Mdot
.49926 .00099 Mdot
.49766 .00317 Mdot
.49253 .01009 Mdot
.47622 .03205 Mdot
.42435 .09957 Mdot
.26324 .24661 Mdot
.86422 .13546 Mdot
.64505 .01885 Mdot
.61456 .53961 Mdot
.74144 .39228 Mdot
.10672 .48397 Mdot
.50031 .61762 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51002 .6045 Mdot
.53192 .57511 Mdot
.60138 .48735 Mdot
.81283 .35115 Mdot
.24465 .49862 Mdot
.43788 .55476 Mdot
.54026 .51783 Mdot
.7024 .37683 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00314 Mdot
.49258 .01002 Mdot
.47638 .03184 Mdot
.42486 .09893 Mdot
.26479 .24584 Mdot
.86701 .13641 Mdot
.6463 .01909 Mdot
.61541 .53926 Mdot
.74286 .39187 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46746 .04376 Mdot
.39666 .13297 Mdot
.18152 .26706 Mdot
.7494 .11952 Mdot
.55602 .06865 Mdot
.44494 .11868 Mdot
.25291 .2662 Mdot
.82219 .13358 Mdot
.49995 7e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .0021 Mdot
.49504 .0067 Mdot
.48419 .02133 Mdot
.44967 .06721 Mdot
.34092 .19133 Mdot
.03134 .2202 Mdot
.67505 .08871 Mdot
.53151 .05969 Mdot
.43493 .11834 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00183 Mdot
.49568 .00584 Mdot
.48623 .01859 Mdot
.45615 .05873 Mdot
.36113 .17175 Mdot
.08324 .24544 Mdot
.68611 .10963 Mdot
.50873 .10154 Mdot
.34444 .22386 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50893 .60597 Mdot
.52845 .57973 Mdot
.59043 .50034 Mdot
.78086 .35556 Mdot
.20555 .49739 Mdot
.40076 .58354 Mdot
.45657 .00527 Mdot
.44804 .05259 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.48841 .01565 Mdot
.46308 .04958 Mdot
.38286 .14862 Mdot
.14238 .26371 Mdot
.7157 .11957 Mdot
.52222 .09904 Mdot
.36197 .21155 Mdot
.01968 .22975 Mdot
.64794 .11151 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50982 .60478 Mdot
.53126 .57598 Mdot
.59931 .48978 Mdot
.80683 .35154 Mdot
.23803 .49867 Mdot
.43117 .5605 Mdot
.52425 .53811 Mdot
.65358 .41682 Mdot
.97915 .39755 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49643 .00483 Mdot
.48861 .01537 Mdot
.46374 .0487 Mdot
.38494 .14631 Mdot
.14821 .26469 Mdot
.71993 .11977 Mdot
.52613 .09566 Mdot
.37134 .20236 Mdot
.04392 .24256 Mdot
.65145 .12241 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51128 .6028 Mdot
.53593 .56977 Mdot
.61402 .47288 Mdot
.84889 .35291 Mdot
.27787 .4982 Mdot
.47176 .52424 Mdot
.62353 .42088 Mdot
.94253 .36875 Mdot
.34588 .49032 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.5127 .60088 Mdot
.54046 .56378 Mdot
.62824 .45735 Mdot
.88823 .36204 Mdot
.30243 .50165 Mdot
.49074 .51023 Mdot
.66516 .38316 Mdot
.0452 .4245 Mdot
.35834 .53916 Mdot
.50015 .61784 Mdot
.50047 .61741 Mdot
.50148 .61603 Mdot
.50472 .61165 Mdot
.51505 .59772 Mdot
.54793 .55396 Mdot
.65161 .43372 Mdot
.94983 .38798 Mdot
.32207 .52065 Mdot
.47964 .53948 Mdot
.60674 .44778 Mdot
.5012 .61641 Mdot
.50382 .61287 Mdot
.51217 .60161 Mdot
.53875 .56604 Mdot
.62288 .46311 Mdot
.87356 .35784 Mdot
.29457 .49963 Mdot
.48614 .51246 Mdot
.65696 .38942 Mdot
.02687 .41421 Mdot
.35666 .52984 Mdot
.50068 .61711 Mdot
.50217 .6151 Mdot
.50691 .6087 Mdot
.52202 .58835 Mdot
.57004 .5255 Mdot
.71976 .38061 Mdot
.10393 .47025 Mdot
.34304 .59329 Mdot
.38308 .07416 Mdot
.26308 .22121 Mdot
.90515 .13839 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48906 .01477 Mdot
.46517 .0468 Mdot
.38945 .14124 Mdot
.16092 .26627 Mdot
.73008 .11988 Mdot
.53611 .08669 Mdot
.39585 .17649 Mdot
.11029 .27074 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49836 .00221 Mdot
.49479 .00704 Mdot
.48339 .02242 Mdot
.44711 .07055 Mdot
.33296 .1985 Mdot
.01179 .20942 Mdot
.67295 .07883 Mdot
.5454 .03731 Mdot
.48504 .05115 Mdot
.40227 .13616 Mdot
.50024 .61771 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50783 .60746 Mdot
.52494 .58444 Mdot
.57929 .51393 Mdot
.74773 .3664 Mdot
.15488 .48837 Mdot
.36468 .59924 Mdot
.39508 .07158 Mdot
.27926 .21664 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49566 .00586 Mdot
.48617 .01867 Mdot
.45596 .05898 Mdot
.36054 .17234 Mdot
.08168 .24479 Mdot
.68561 .10915 Mdot
.509 .10081 Mdot
.34589 .22238 Mdot
.98607 .20948 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48476 .02057 Mdot
.45147 .06487 Mdot
.34651 .1861 Mdot
.04539 .22762 Mdot
.6771 .09528 Mdot
.52294 .07409 Mdot
.40305 .15851 Mdot
.14658 .27598 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.5131 .60035 Mdot
.54172 .56211 Mdot
.6322 .45317 Mdot
.89896 .36567 Mdot
.3073 .50375 Mdot
.49221 .51097 Mdot
.66545 .38376 Mdot
.04451 .42449 Mdot
.35768 .53954 Mdot
.50058 .61724 Mdot
.50186 .61552 Mdot
.50593 .61002 Mdot
.5189 .59254 Mdot
.56016 .53809 Mdot
.68951 .40107 Mdot
.04056 .43827 Mdot
.33143 .56692 Mdot
.41413 .02469 Mdot
.37418 .12955 Mdot
.16457 .25634 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.5409 .5632 Mdot
.62962 .45588 Mdot
.89199 .36326 Mdot
.30422 .50233 Mdot
.49144 .51026 Mdot
.66581 .38289 Mdot
.04629 .42519 Mdot
.35831 .53987 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61511 Mdot
.50689 .60873 Mdot
.52194 .58845 Mdot
.56981 .52579 Mdot
.71907 .38102 Mdot
.10257 .46966 Mdot
.34265 .59291 Mdot
.3833 .07362 Mdot
.26419 .22058 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60842 Mdot
.52266 .58749 Mdot
.57209 .52292 Mdot
.72599 .37705 Mdot
.11591 .47526 Mdot
.34693 .59627 Mdot
.38215 .07778 Mdot
.25631 .2252 Mdot
.89192 .13253 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48933 .0144 Mdot
.46603 .04566 Mdot
.39215 .13816 Mdot
.1686 .26683 Mdot
.73686 .11978 Mdot
.54305 .08036 Mdot
.41302 .15704 Mdot
.15893 .28108 Mdot
.70414 .13962 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50172 .61572 Mdot
.50547 .61065 Mdot
.51742 .59453 Mdot
.55546 .54415 Mdot
.675 .41269 Mdot
.00726 .41941 Mdot
.32863 .54931 Mdot
.43982 .60378 Mdot
.46289 .01984 Mdot
.49997 4e-05 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48909 .01474 Mdot
.46524 .0467 Mdot
.38968 .14098 Mdot
.16158 .26633 Mdot
.73065 .11987 Mdot
.53668 .08617 Mdot
.39726 .17493 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48476 .02057 Mdot
.45148 .06485 Mdot
.34656 .18606 Mdot
.0455 .22767 Mdot
.67712 .09533 Mdot
.52288 .07419 Mdot
.40283 .15879 Mdot
.14591 .27588 Mdot
.50041 .61748 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.5132 .60021 Mdot
.54204 .56168 Mdot
.63322 .4521 Mdot
.9017 .36666 Mdot
.30843 .50437 Mdot
.49234 .51147 Mdot
.66475 .38459 Mdot
.04247 .4235 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60134 Mdot
.53938 .5652 Mdot
.62487 .46095 Mdot
.87903 .3593 Mdot
.29767 .50028 Mdot
.48821 .5112 Mdot
.66108 .38609 Mdot
.03637 .41951 Mdot
.35758 .53461 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49706 .00397 Mdot
.49065 .01263 Mdot
.47021 .04009 Mdot
.40534 .12277 Mdot
.20669 .26488 Mdot
.7781 .11963 Mdot
.58453 .0449 Mdot
.51188 .0339 Mdot
.45703 .07325 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49886 .00155 Mdot
.49635 .00493 Mdot
.48838 .01569 Mdot
.463 .04968 Mdot
.38262 .1489 Mdot
.1417 .26358 Mdot
.71522 .11954 Mdot
.52179 .0994 Mdot
.36095 .21252 Mdot
.5002 .61776 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50661 .6091 Mdot
.52107 .58963 Mdot
.56703 .52931 Mdot
.7106 .38626 Mdot
.08561 .46186 Mdot
.33832 .58726 Mdot
.3881 .06462 Mdot
.28354 .2089 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49612 .00525 Mdot
.48763 .0167 Mdot
.46061 .05285 Mdot
.3751 .15711 Mdot
.1209 .25871 Mdot
.70229 .11775 Mdot
.51177 .10685 Mdot
.33888 .23198 Mdot
.96352 .19846 Mdot
.64241 .08337 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.49781 .00295 Mdot
.49304 .00941 Mdot
.47781 .02991 Mdot
.42942 .09322 Mdot
.27859 .23839 Mdot
.89287 .14641 Mdot
.65598 .02386 Mdot
.61737 .54269 Mdot
.73928 .39548 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51083 .60341 Mdot
.53448 .5717 Mdot
.60946 .47804 Mdot
.83598 .3515 Mdot
.26723 .49818 Mdot
.46116 .53384 Mdot
.59739 .44908 Mdot
.87077 .34201 Mdot
.31738 .47653 Mdot
.50033 .61759 Mdot
.50106 .61661 Mdot
.50336 .61349 Mdot
.51071 .60357 Mdot
.53412 .57218 Mdot
.6083 .47935 Mdot
.8327 .35128 Mdot
.26431 .49823 Mdot
.45816 .53657 Mdot
.58998 .45753 Mdot
.84968 .33799 Mdot
.49982 .00024 Mdot
.49943 .00078 Mdot
.49817 .00247 Mdot
.49417 .00787 Mdot
.48144 .02504 Mdot
.44092 .07856 Mdot
.31381 .2144 Mdot
.96691 .18394 Mdot
.66928 .05497 Mdot
.58034 .60165 Mdot
.60686 .50986 Mdot
.78188 .36527 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00518 Mdot
.48779 .01648 Mdot
.46112 .05216 Mdot
.37672 .15536 Mdot
.12534 .25991 Mdot
.70479 .11828 Mdot
.51341 .10587 Mdot
.34211 .22938 Mdot
.97096 .20261 Mdot
.64313 .0871 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50824 .6069 Mdot
.52626 .58267 Mdot
.58348 .50877 Mdot
.76027 .36154 Mdot
.1753 .49312 Mdot
.37741 .59586 Mdot
.41328 .05431 Mdot
.32541 .1856 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48745 .01694 Mdot
.46004 .0536 Mdot
.37331 .15903 Mdot
.11599 .25729 Mdot
.69968 .11706 Mdot
.51028 .10754 Mdot
.33627 .23393 Mdot
.95776 .19523 Mdot
.64187 .08045 Mdot
.50118 .61644 Mdot
.50376 .61296 Mdot
.51197 .60187 Mdot
.53812 .56688 Mdot
.62089 .46528 Mdot
.86806 .3565 Mdot
.29124 .49912 Mdot
.48365 .51425 Mdot
.65158 .39403 Mdot
.01403 .40702 Mdot
.35546 .52334 Mdot
.50059 .61723 Mdot
.50189 .61548 Mdot
.50603 .60989 Mdot
.51921 .59212 Mdot
.56114 .53682 Mdot
.69255 .39878 Mdot
.0473 .44199 Mdot
.33214 .57032 Mdot
.40934 .03186 Mdot
.3578 .14683 Mdot
.12022 .24798 Mdot
.50029 .61764 Mdot
.50092 .61679 Mdot
.50294 .61406 Mdot
.50937 .60538 Mdot
.52983 .57789 Mdot
.59479 .49511 Mdot
.79368 .35309 Mdot
.22237 .49842 Mdot
.41591 .5728 Mdot
.48911 .58288 Mdot
.54599 .54084 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49842 .00213 Mdot
.49497 .00679 Mdot
.48398 .02162 Mdot
.449 .06809 Mdot
.33883 .19324 Mdot
.02616 .21739 Mdot
.67442 .08617 Mdot
.535 .05398 Mdot
.44767 .10162 Mdot
.28324 .24596 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54006 .5643 Mdot
.627 .45867 Mdot
.88485 .36099 Mdot
.30075 .5011 Mdot
.48995 .51042 Mdot
.66407 .38386 Mdot
.04298 .42322 Mdot
.3582 .53796 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49041 .01295 Mdot
.46947 .04108 Mdot
.40301 .12553 Mdot
.1999 .26582 Mdot
.76978 .11942 Mdot
.57656 .05114 Mdot
.49381 .05688 Mdot
.40177 .14227 Mdot
.17157 .27226 Mdot
.50091 .6168 Mdot
.50291 .6141 Mdot
.50928 .6055 Mdot
.52956 .57826 Mdot
.59392 .49615 Mdot
.79113 .35351 Mdot
.21915 .49829 Mdot
.4129 .57506 Mdot
.48243 .59132 Mdot
.52565 .56765 Mdot
.60718 .47563 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.49218 .01056 Mdot
.4751 .03354 Mdot
.42083 .10395 Mdot
.25264 .25147 Mdot
.84575 .12983 Mdot
.63568 .01874 Mdot
.60535 .54609 Mdot
.72175 .40087 Mdot
.07314 .46631 Mdot
.49992 .00011 Mdot
.49974 .00034 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49175 .01115 Mdot
.47371 .03541 Mdot
.41641 .1094 Mdot
.2394 .25661 Mdot
.82419 .12481 Mdot
.62224 .02231 Mdot
.58615 .56432 Mdot
.67307 .43368 Mdot
.50049 .61738 Mdot
.50155 .61594 Mdot
.50494 .61136 Mdot
.51575 .59678 Mdot
.55014 .55106 Mdot
.65851 .42722 Mdot
.96725 .39708 Mdot
.32477 .52864 Mdot
.46941 .55683 Mdot
.56844 .49531 Mdot
.76701 .34861 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.50061 .61721 Mdot
.50194 .61541 Mdot
.50618 .60969 Mdot
.51969 .59148 Mdot
.56266 .53488 Mdot
.6972 .39539 Mdot
.05745 .44749 Mdot
.33339 .57525 Mdot
.40262 .04196 Mdot
.50015 .61784 Mdot
.50047 .6174 Mdot
.50149 .61601 Mdot
.50476 .6116 Mdot
.51517 .59756 Mdot
.5483 .55347 Mdot
.65276 .43262 Mdot
.95277 .38948 Mdot
.32259 .52194 Mdot
.47808 .5422 Mdot
.60078 .45489 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00647 Mdot
.48474 .0206 Mdot
.45141 .06495 Mdot
.34633 .18628 Mdot
.04491 .22737 Mdot
.67702 .09507 Mdot
.5232 .07363 Mdot
.40406 .15728 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49825 .00236 Mdot
.49443 .00753 Mdot
.48224 .02396 Mdot
.44347 .07527 Mdot
.32168 .2081 Mdot
.98496 .19418 Mdot
.67077 .06455 Mdot
.56633 .00482 Mdot
.55853 .56981 Mdot
.63656 .45818 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.4883 .0158 Mdot
.46274 .05003 Mdot
.38179 .14982 Mdot
.13938 .26313 Mdot
.71362 .11943 Mdot
.52038 .10058 Mdot
.35764 .21565 Mdot
.00871 .22372 Mdot
.64672 .10616 Mdot
.50127 .61632 Mdot
.50404 .61258 Mdot
.51287 .60066 Mdot
.54099 .56307 Mdot
.62992 .45557 Mdot
.8928 .36353 Mdot
.30459 .50248 Mdot
.49156 .5103 Mdot
.66587 .3829 Mdot
.04633 .42525 Mdot
.35827 .53994 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49741 .0035 Mdot
.49175 .01114 Mdot
.47373 .03538 Mdot
.41649 .10929 Mdot
.23966 .25652 Mdot
.8246 .12489 Mdot
.62252 .0222 Mdot
.5866 .56385 Mdot
.67427 .43269 Mdot
.50099 .61669 Mdot
.50316 .61377 Mdot
.51007 .60444 Mdot
.53206 .57492 Mdot
.60182 .48684 Mdot
.81409 .3511 Mdot
.246 .4986 Mdot
.43926 .55355 Mdot
.54359 .51364 Mdot
.7125 .37017 Mdot
.11355 .46673 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49093 .01225 Mdot
.4711 .0389 Mdot
.40816 .1194 Mdot
.21497 .26338 Mdot
.7888 .1202 Mdot
.59431 .0378 Mdot
.53316 .00728 Mdot
.52139 .60554 Mdot
.54161 .56741 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00533 Mdot
.48744 .01696 Mdot
.45999 .05366 Mdot
.37316 .15919 Mdot
.11559 .25717 Mdot
.69948 .117 Mdot
.51017 .10758 Mdot
.3361 .23405 Mdot
.9574 .19503 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46746 .04375 Mdot
.39667 .13295 Mdot
.18156 .26706 Mdot
.74944 .11952 Mdot
.55606 .06861 Mdot
.44505 .11855 Mdot
.25323 .26606 Mdot
.82273 .13366 Mdot
.50087 .61686 Mdot
.50277 .61429 Mdot
.50882 .60612 Mdot
.52809 .58022 Mdot
.58928 .50172 Mdot
.77748 .35637 Mdot
.20086 .49694 Mdot
.3968 .58605 Mdot
.44856 .01488 Mdot
.42449 .08228 Mdot
.29135 .22488 Mdot
.50018 .6178 Mdot
.50056 .61727 Mdot
.50179 .61561 Mdot
.50571 .61032 Mdot
.5182 .59348 Mdot
.55794 .54095 Mdot
.68267 .40641 Mdot
.02508 .42957 Mdot
.33003 .55885 Mdot
.42579 .00714 Mdot
.41424 .08286 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49848 .00206 Mdot
.49515 .00655 Mdot
.48455 .02085 Mdot
.45082 .06572 Mdot
.34449 .18801 Mdot
.04028 .22496 Mdot
.67629 .09295 Mdot
.52589 .06906 Mdot
.41415 .14485 Mdot
.17978 .27826 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49726 .0037 Mdot
.49127 .01179 Mdot
.47219 .03744 Mdot
.41161 .11523 Mdot
.22516 .26098 Mdot
.80288 .12151 Mdot
.60628 .03015 Mdot
.5575 .59603 Mdot
.5931 .51456 Mdot
.76052 .36734 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49665 .00452 Mdot
.48933 .0144 Mdot
.46603 .04566 Mdot
.39216 .13816 Mdot
.16861 .26683 Mdot
.73688 .11978 Mdot
.54307 .08035 Mdot
.41306 .15699 Mdot
.15905 .28109 Mdot
.70423 .13961 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.51231 .60142 Mdot
.53919 .56545 Mdot
.62428 .46159 Mdot
.8774 .35885 Mdot
.29677 .50007 Mdot
.48764 .51152 Mdot
.65998 .38695 Mdot
.03388 .41813 Mdot
.35734 .53337 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49583 .00563 Mdot
.48673 .01792 Mdot
.45773 .05665 Mdot
.36607 .16666 Mdot
.09641 .25067 Mdot
.69082 .11321 Mdot
.50763 .10614 Mdot
.3359 .23271 Mdot
.95937 .19545 Mdot
.64313 .07994 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01061 Mdot
.47498 .03371 Mdot
.42042 .10445 Mdot
.25142 .25199 Mdot
.84369 .12928 Mdot
.63451 .01891 Mdot
.60392 .5473 Mdot
.71838 .40266 Mdot
.06687 .46284 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.5394 .56517 Mdot
.62494 .46088 Mdot
.87921 .35935 Mdot
.29777 .5003 Mdot
.48827 .51116 Mdot
.66119 .386 Mdot
.03663 .41966 Mdot
.35761 .53475 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48957 .01408 Mdot
.46679 .04464 Mdot
.39456 .1354 Mdot
.17548 .26706 Mdot
.74336 .11965 Mdot
.54977 .07425 Mdot
.42963 .13738 Mdot
.20734 .27966 Mdot
.75484 .13218 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60724 Mdot
.52547 .58373 Mdot
.58098 .51185 Mdot
.75279 .36433 Mdot
.1633 .49051 Mdot
.36963 .59831 Mdot
.40155 .06583 Mdot
.29503 .20751 Mdot
.95927 .17016 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60697 Mdot
.52609 .5829 Mdot
.58294 .50944 Mdot
.75864 .36212 Mdot
.17272 .49261 Mdot
.37566 .5965 Mdot
.4105 .05713 Mdot
.31807 .19139 Mdot
.0084 .19917 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00814 Mdot
.48081 .02589 Mdot
.43892 .08113 Mdot
.30765 .2191 Mdot
.95314 .17628 Mdot
.66791 .04793 Mdot
.59035 .58664 Mdot
.64115 .47228 Mdot
.87699 .36926 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.50771 .60762 Mdot
.52455 .58496 Mdot
.57807 .51545 Mdot
.74406 .36801 Mdot
.14861 .48661 Mdot
.36126 .59955 Mdot
.39117 .07473 Mdot
.27026 .22108 Mdot
.49979 .00029 Mdot
.49932 .00093 Mdot
.49782 .00295 Mdot
.49305 .00939 Mdot
.47785 .02986 Mdot
.42953 .09308 Mdot
.27893 .23819 Mdot
.89353 .14669 Mdot
.65619 .02404 Mdot
.61729 .54292 Mdot
.73883 .39574 Mdot
.09851 .48134 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49624 .00508 Mdot
.48802 .01618 Mdot
.46183 .05123 Mdot
.37895 .15294 Mdot
.13149 .26143 Mdot
.70848 .11888 Mdot
.51613 .10395 Mdot
.34793 .22444 Mdot
.98478 .21035 Mdot
.50128 .6163 Mdot
.50408 .61252 Mdot
.513 .60048 Mdot
.54141 .56252 Mdot
.63123 .45419 Mdot
.89635 .36474 Mdot
.30618 .50319 Mdot
.492 .51061 Mdot
.66582 .38322 Mdot
.04575 .42506 Mdot
.358 .53992 Mdot
.50007 .61795 Mdot
.50021 .61775 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .60891 Mdot
.52152 .58901 Mdot
.56848 .52747 Mdot
.71501 .38348 Mdot
.09453 .46605 Mdot
.34044 .5904 Mdot
.38515 .06984 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.498 .0027 Mdot
.49363 .00861 Mdot
.4797 .02738 Mdot
.4354 .08563 Mdot
.29685 .22683 Mdot
.92984 .16387 Mdot
.66469 .03702 Mdot
.60479 .56477 Mdot
.69097 .42726 Mdot
.99965 .42693 Mdot
.50121 .6164 Mdot
.50385 .61283 Mdot
.51228 .60145 Mdot
.53911 .56556 Mdot
.62401 .46189 Mdot
.87666 .35865 Mdot
.29635 .49998 Mdot
.48737 .51168 Mdot
.65945 .38738 Mdot
.03265 .41744 Mdot
.35722 .53275 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48949 .0142 Mdot
.46651 .04502 Mdot
.39367 .13642 Mdot
.17294 .267 Mdot
.74091 .1197 Mdot
.54724 .07655 Mdot
.42337 .14487 Mdot
.18896 .2817 Mdot
.73316 .13498 Mdot
.49989 .00016 Mdot
.49963 .00049 Mdot
.49883 .00158 Mdot
.49628 .00502 Mdot
.48816 .01598 Mdot
.4623 .0506 Mdot
.38043 .15131 Mdot
.1356 .26236 Mdot
.7111 .1192 Mdot
.51824 .10232 Mdot
.35268 .22021 Mdot
.99638 .21685 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60315 Mdot
.53511 .57086 Mdot
.61145 .47578 Mdot
.84162 .35201 Mdot
.27205 .49815 Mdot
.46603 .5294 Mdot
.60944 .43575 Mdot
.90439 .35235 Mdot
.33428 .47968 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50904 .60582 Mdot
.5288 .57927 Mdot
.59153 .49902 Mdot
.7841 .35485 Mdot
.20995 .49774 Mdot
.40459 .58099 Mdot
.46452 .61361 Mdot
.47167 .0217 Mdot
.43656 .07896 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .00249 Mdot
.49412 .00794 Mdot
.48127 .02527 Mdot
.44038 .07925 Mdot
.31215 .21569 Mdot
.96315 .18183 Mdot
.66894 .05302 Mdot
.58315 .59743 Mdot
.61649 .49882 Mdot
.80939 .36143 Mdot
.50078 .61698 Mdot
.50249 .61466 Mdot
.50795 .6073 Mdot
.52531 .58394 Mdot
.58048 .51246 Mdot
.7513 .36492 Mdot
.16084 .48992 Mdot
.36814 .59864 Mdot
.39952 .0677 Mdot
.28998 .21061 Mdot
.94921 .16432 Mdot
.50024 .61771 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.50771 .60762 Mdot
.52456 .58495 Mdot
.57809 .51542 Mdot
.74412 .36798 Mdot
.14872 .48664 Mdot
.36131 .59955 Mdot
.39123 .07468 Mdot
.27038 .22102 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50432 .6122 Mdot
.51376 .59946 Mdot
.54381 .55936 Mdot
.63874 .44642 Mdot
.91642 .37245 Mdot
.31378 .5083 Mdot
.49133 .51634 Mdot
.65588 .39385 Mdot
.01861 .41107 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00368 Mdot
.49133 .01171 Mdot
.47239 .03718 Mdot
.41224 .11448 Mdot
.22701 .26048 Mdot
.80554 .12183 Mdot
.60841 .02892 Mdot
.56161 .59125 Mdot
.60495 .50086 Mdot
.79454 .35906 Mdot
.5009 .61682 Mdot
.50285 .61418 Mdot
.50909 .60575 Mdot
.52896 .57905 Mdot
.59203 .49841 Mdot
.78559 .35454 Mdot
.21193 .49788 Mdot
.40634 .57978 Mdot
.46823 .60904 Mdot
.48279 .00693 Mdot
.47158 .03313 Mdot
.50022 .61774 Mdot
.5007 .61708 Mdot
.50224 .61501 Mdot
.50714 .60839 Mdot
.52273 .58739 Mdot
.57232 .52263 Mdot
.72668 .37667 Mdot
.11722 .47578 Mdot
.3474 .59654 Mdot
.38217 .07803 Mdot
.25592 .22547 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.487 .01754 Mdot
.45862 .05548 Mdot
.36885 .16376 Mdot
.10389 .25337 Mdot
.69392 .11489 Mdot
.50803 .10745 Mdot
.33416 .23485 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01025 Mdot
.47583 .03257 Mdot
.42313 .10109 Mdot
.25956 .24837 Mdot
.85768 .13333 Mdot
.64195 .0185 Mdot
.61202 .54105 Mdot
.73657 .39403 Mdot
.09901 .48002 Mdot
.5006 .61723 Mdot
.5019 .61546 Mdot
.50606 .60984 Mdot
.51932 .59197 Mdot
.56149 .53638 Mdot
.69361 .398 Mdot
.04963 .44327 Mdot
.33241 .57147 Mdot
.40775 .03425 Mdot
.35233 .15233 Mdot
.10586 .24339 Mdot
.50076 .61701 Mdot
.50242 .61477 Mdot
.5077 .60763 Mdot
.52453 .58499 Mdot
.57799 .51554 Mdot
.74383 .36811 Mdot
.14821 .48649 Mdot
.36105 .59956 Mdot
.39094 .0749 Mdot
.26975 .22131 Mdot
.91167 .14356 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50398 .61265 Mdot
.5127 .60089 Mdot
.54043 .56381 Mdot
.62816 .45743 Mdot
.88802 .36198 Mdot
.30233 .50162 Mdot
.49069 .51024 Mdot
.66511 .38319 Mdot
.04509 .42444 Mdot
.50117 .61645 Mdot
.50373 .61299 Mdot
.51189 .60198 Mdot
.53787 .5672 Mdot
.62011 .46613 Mdot
.8659 .35601 Mdot
.28987 .49895 Mdot
.48256 .51508 Mdot
.64914 .39619 Mdot
.00809 .40369 Mdot
.35491 .52032 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46876 .04202 Mdot
.40077 .12817 Mdot
.19338 .26648 Mdot
.76222 .11937 Mdot
.56908 .05732 Mdot
.47633 .07919 Mdot
.3482 .19953 Mdot
.02536 .22294 Mdot
.50012 .61787 Mdot
.50038 .61753 Mdot
.5012 .61642 Mdot
.50382 .61288 Mdot
.51216 .60161 Mdot
.53874 .56605 Mdot
.62284 .46315 Mdot
.87345 .35781 Mdot
.2945 .49962 Mdot
.4861 .51249 Mdot
.65687 .3895 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49821 .00242 Mdot
.49429 .00771 Mdot
.48182 .02453 Mdot
.44212 .07701 Mdot
.31752 .21148 Mdot
.97534 .18871 Mdot
.67001 .05941 Mdot
.57387 .6114 Mdot
.58461 .5366 Mdot
.71637 .39234 Mdot
.50122 .61639 Mdot
.50387 .6128 Mdot
.51234 .60137 Mdot
.5393 .56531 Mdot
.62461 .46124 Mdot
.87831 .3591 Mdot
.29727 .50018 Mdot
.48796 .51133 Mdot
.6606 .38646 Mdot
.0353 .41892 Mdot
.35748 .53408 Mdot
.50029 .61764 Mdot
.50094 .61677 Mdot
.50298 .61401 Mdot
.5095 .60521 Mdot
.53025 .57734 Mdot
.59609 .49357 Mdot
.79748 .35254 Mdot
.22705 .49856 Mdot
.42037 .56933 Mdot
.49917 .5701 Mdot
.57673 .50169 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49815 .0025 Mdot
.49412 .00795 Mdot
.48126 .02529 Mdot
.44034 .0793 Mdot
.31203 .21578 Mdot
.96288 .18168 Mdot
.66891 .05288 Mdot
.58335 .59713 Mdot
.61717 .49806 Mdot
.8113 .36132 Mdot
.49986 .00019 Mdot
.49955 .0006 Mdot
.49858 .00192 Mdot
.49547 .00613 Mdot
.48555 .0195 Mdot
.454 .06155 Mdot
.35442 .17846 Mdot
.06566 .23762 Mdot
.68118 .10366 Mdot
.51347 .09119 Mdot
.36592 .2013 Mdot
.04022 .23818 Mdot
.50093 .61678 Mdot
.50295 .61405 Mdot
.5094 .60534 Mdot
.52995 .57774 Mdot
.59514 .4947 Mdot
.79471 .35293 Mdot
.22365 .49846 Mdot
.41712 .57187 Mdot
.49182 .57945 Mdot
.55424 .53014 Mdot
.69646 .39087 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49324 .00913 Mdot
.47847 .02903 Mdot
.4315 .09059 Mdot
.28492 .2346 Mdot
.90533 .15192 Mdot
.65952 .02758 Mdot
.61489 .54812 Mdot
.72801 .40198 Mdot
.07759 .4711 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00147 Mdot
.49655 .00467 Mdot
.48899 .01486 Mdot
.46494 .0471 Mdot
.38873 .14205 Mdot
.15889 .26607 Mdot
.72838 .11989 Mdot
.53439 .08825 Mdot
.3916 .18115 Mdot
.0985 .26674 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49961 .00053 Mdot
.49876 .00167 Mdot
.49605 .00534 Mdot
.48742 .01699 Mdot
.45993 .05375 Mdot
.37296 .15941 Mdot
.11504 .257 Mdot
.6992 .11691 Mdot
.50018 .61779 Mdot
.50057 .61726 Mdot
.50183 .61557 Mdot
.50582 .61017 Mdot
.51855 .59301 Mdot
.55903 .53953 Mdot
.68605 .40374 Mdot
.03278 .43392 Mdot
.33069 .5629 Mdot
.41989 .01603 Mdot
.39395 .10723 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49602 .00538 Mdot
.48731 .01714 Mdot
.45958 .05421 Mdot
.37187 .16057 Mdot
.11206 .25608 Mdot
.69771 .11643 Mdot
.50932 .10779 Mdot
.33491 .23483 Mdot
.50075 .61703 Mdot
.50238 .61482 Mdot
.50758 .6078 Mdot
.52415 .5855 Mdot
.57679 .51704 Mdot
.74021 .36977 Mdot
.14191 .48458 Mdot
.35785 .59952 Mdot
.38781 .07709 Mdot
.26306 .22414 Mdot
.90039 .13771 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50901 .60586 Mdot
.52871 .57939 Mdot
.59124 .49936 Mdot
.78327 .35502 Mdot
.20883 .49766 Mdot
.4036 .58166 Mdot
.46244 .61616 Mdot
.46548 .02987 Mdot
.41714 .10327 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49704 .004 Mdot
.49057 .01273 Mdot
.46997 .0404 Mdot
.4046 .12364 Mdot
.20454 .26521 Mdot
.77542 .11954 Mdot
.582 .04684 Mdot
.5062 .0411 Mdot
.43971 .09566 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50991 .60465 Mdot
.53157 .57557 Mdot
.60029 .48863 Mdot
.80968 .35133 Mdot
.24121 .49865 Mdot
.43437 .55778 Mdot
.53187 .52844 Mdot
.67684 .39621 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49189 .01096 Mdot
.47415 .03482 Mdot
.41782 .10766 Mdot
.24362 .25509 Mdot
.83089 .12619 Mdot
.62671 .02075 Mdot
.59314 .55728 Mdot
.69144 .41961 Mdot
.0125 .43118 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48993 .0136 Mdot
.46793 .04313 Mdot
.39815 .13123 Mdot
.18582 .26694 Mdot
.7539 .11944 Mdot
.56064 .06457 Mdot
.45617 .10469 Mdot
.28677 .24832 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49117 .01192 Mdot
.47189 .03785 Mdot
.41065 .11639 Mdot
.22233 .26171 Mdot
.79887 .12107 Mdot
.60298 .03213 Mdot
.551 .60369 Mdot
.57422 .53735 Mdot
.70476 .39572 Mdot
.50103 .61664 Mdot
.5033 .61358 Mdot
.5105 .60385 Mdot
.53344 .57308 Mdot
.60619 .48178 Mdot
.82665 .35102 Mdot
.25869 .49834 Mdot
.45236 .54185 Mdot
.57562 .47435 Mdot
.80811 .33653 Mdot
.26359 .48354 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00319 Mdot
.49248 .01015 Mdot
.47606 .03226 Mdot
.42386 .10019 Mdot
.26175 .24733 Mdot
.86156 .13457 Mdot
.64382 .01867 Mdot
.61361 .54009 Mdot
.73972 .39286 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.50631 .60951 Mdot
.5201 .59093 Mdot
.56396 .53322 Mdot
.70119 .39256 Mdot
.06602 .45202 Mdot
.33463 .57919 Mdot
.39748 .04976 Mdot
.31696 .18444 Mdot
.01853 .20158 Mdot
.49978 .0003 Mdot
.49928 .00097 Mdot
.49772 .00308 Mdot
.49274 .00981 Mdot
.47687 .03118 Mdot
.42641 .09699 Mdot
.26948 .24343 Mdot
.87559 .13949 Mdot
.64989 .02019 Mdot
.61722 .53911 Mdot
.74492 .39164 Mdot
.11122 .48656 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50685 .60877 Mdot
.52184 .58859 Mdot
.56947 .52621 Mdot
.71804 .38163 Mdot
.10054 .46877 Mdot
.34206 .59231 Mdot
.38369 .07275 Mdot
.26598 .21955 Mdot
.91074 .14107 Mdot
.50097 .61672 Mdot
.50311 .61384 Mdot
.5099 .60467 Mdot
.53152 .57564 Mdot
.60013 .48882 Mdot
.8092 .35136 Mdot
.24069 .49866 Mdot
.43385 .55823 Mdot
.53061 .53003 Mdot
.673 .39942 Mdot
.02673 .42408 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00194 Mdot
.49542 .00619 Mdot
.48541 .01969 Mdot
.45355 .06215 Mdot
.35299 .17987 Mdot
.06195 .23586 Mdot
.68032 .10223 Mdot
.5149 .08844 Mdot
.37181 .19484 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49385 .00831 Mdot
.48041 .02642 Mdot
.43767 .08274 Mdot
.30379 .22194 Mdot
.94469 .17169 Mdot
.66689 .0438 Mdot
.59602 .57813 Mdot
.66059 .45326 Mdot
.92721 .3881 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46949 .04105 Mdot
.40306 .12546 Mdot
.20006 .2658 Mdot
.76999 .11942 Mdot
.57676 .05099 Mdot
.49426 .05631 Mdot
.40316 .14065 Mdot
.17559 .27236 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50741 .60802 Mdot
.52362 .58621 Mdot
.57511 .51913 Mdot
.73513 .37223 Mdot
.13285 .48158 Mdot
.35364 .59893 Mdot
.38455 .07878 Mdot
.25707 .22618 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.46701 .04435 Mdot
.39525 .1346 Mdot
.17747 .26708 Mdot
.74532 .1196 Mdot
.5518 .07242 Mdot
.43462 .13135 Mdot
.22209 .27663 Mdot
.77449 .13083 Mdot
.49994 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00283 Mdot
.49332 .00902 Mdot
.47873 .02868 Mdot
.43232 .08956 Mdot
.28741 .23304 Mdot
.91034 .15425 Mdot
.66076 .0293 Mdot
.61335 .55091 Mdot
.72195 .40565 Mdot
.50105 .61662 Mdot
.50334 .61353 Mdot
.51063 .60368 Mdot
.53387 .57252 Mdot
.60752 .48025 Mdot
.83045 .35116 Mdot
.26226 .49827 Mdot
.45605 .5385 Mdot
.58474 .4636 Mdot
.83462 .33642 Mdot
.29028 .47927 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00325 Mdot
.49233 .01036 Mdot
.47556 .03293 Mdot
.42227 .10216 Mdot
.25697 .24956 Mdot
.85317 .13195 Mdot
.63967 .01846 Mdot
.60981 .54258 Mdot
.73189 .39599 Mdot
.09117 .47596 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51026 .60418 Mdot
.53267 .57411 Mdot
.60373 .48462 Mdot
.8196 .35096 Mdot
.25174 .49849 Mdot
.44516 .54833 Mdot
.55794 .49579 Mdot
.75573 .34834 Mdot
.50094 .61677 Mdot
.50299 .61399 Mdot
.50953 .60516 Mdot
.53036 .57719 Mdot
.59645 .49315 Mdot
.79851 .35241 Mdot
.2283 .49858 Mdot
.42158 .56838 Mdot
.50192 .5666 Mdot
.58514 .49138 Mdot
.79007 .34849 Mdot
.49995 7e-05 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00212 Mdot
.495 .00676 Mdot
.48406 .02151 Mdot
.44925 .06777 Mdot
.33959 .19255 Mdot
.02805 .21841 Mdot
.67465 .0871 Mdot
.53372 .05608 Mdot
.44299 .10781 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49427 .00774 Mdot
.48174 .02463 Mdot
.44189 .07731 Mdot
.31681 .21204 Mdot
.97372 .18779 Mdot
.66987 .05855 Mdot
.57513 .60949 Mdot
.58896 .53125 Mdot
.50075 .61701 Mdot
.5024 .61479 Mdot
.50766 .60769 Mdot
.5244 .58516 Mdot
.57759 .51604 Mdot
.74262 .36866 Mdot
.14612 .48587 Mdot
.35996 .59958 Mdot
.38982 .07572 Mdot
.2673 .2224 Mdot
.90745 .14135 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00415 Mdot
.49021 .01322 Mdot
.46882 .04195 Mdot
.40094 .12796 Mdot
.1939 .26643 Mdot
.7628 .11937 Mdot
.56966 .05683 Mdot
.4777 .07743 Mdot
.50086 .61687 Mdot
.50275 .61431 Mdot
.50877 .60619 Mdot
.52794 .58041 Mdot
.58881 .50229 Mdot
.77609 .35672 Mdot
.1989 .49673 Mdot
.39518 .58703 Mdot
.44535 .01867 Mdot
.41515 .09365 Mdot
.26361 .24066 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49776 .00303 Mdot
.49286 .00964 Mdot
.47726 .03065 Mdot
.42766 .09543 Mdot
.27325 .2414 Mdot
.88265 .14221 Mdot
.65255 .02147 Mdot
.61782 .53998 Mdot
.74412 .39254 Mdot
.10898 .48585 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49737 .00356 Mdot
.49161 .01134 Mdot
.47326 .03601 Mdot
.41499 .11113 Mdot
.23518 .25803 Mdot
.81768 .12363 Mdot
.61764 .02423 Mdot
.57844 .57246 Mdot
.65218 .45191 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49824 .00237 Mdot
.49441 .00756 Mdot
.48218 .02404 Mdot
.44328 .07552 Mdot
.3211 .20858 Mdot
.9836 .19341 Mdot
.67066 .06382 Mdot
.5674 .00319 Mdot
.56224 .56498 Mdot
.64809 .44666 Mdot
.50116 .61647 Mdot
.50368 .61306 Mdot
.51173 .6022 Mdot
.53734 .5679 Mdot
.61846 .46795 Mdot
.86131 .35504 Mdot
.28685 .49865 Mdot
.48002 .51712 Mdot
.64331 .4015 Mdot
.99366 .39563 Mdot
.35352 .51305 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50867 .60632 Mdot
.52763 .58083 Mdot
.58782 .50348 Mdot
.77317 .3575 Mdot
.19472 .49624 Mdot
.3918 .58899 Mdot
.43879 .02631 Mdot
.39621 .11585 Mdot
.20876 .25847 Mdot
.50044 .61743 Mdot
.50142 .61612 Mdot
.50451 .61194 Mdot
.51437 .59864 Mdot
.54575 .5568 Mdot
.64482 .44032 Mdot
.93237 .37949 Mdot
.31833 .51365 Mdot
.48724 .52546 Mdot
.63702 .41356 Mdot
.96786 .38397 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48822 .01591 Mdot
.46247 .05038 Mdot
.38094 .15075 Mdot
.13703 .26266 Mdot
.71204 .11929 Mdot
.51903 .10169 Mdot
.35449 .21856 Mdot
.00084 .21935 Mdot
.64593 .10223 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.49731 .00364 Mdot
.49142 .01159 Mdot
.47266 .03682 Mdot
.41309 .11344 Mdot
.22954 .25977 Mdot
.80923 .12232 Mdot
.61131 .02734 Mdot
.56707 .58503 Mdot
.62047 .48371 Mdot
.83782 .35806 Mdot
.5012 .61641 Mdot
.50384 .61285 Mdot
.51223 .60152 Mdot
.53895 .56577 Mdot
.62352 .46242 Mdot
.87531 .35829 Mdot
.29558 .49982 Mdot
.48685 .512 Mdot
.65841 .38822 Mdot
.03026 .4161 Mdot
.35699 .53155 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49764 .00318 Mdot
.49249 .01014 Mdot
.47609 .03222 Mdot
.42395 .10008 Mdot
.26202 .2472 Mdot
.86204 .13473 Mdot
.64404 .01869 Mdot
.61379 .54 Mdot
.74006 .39274 Mdot
.10459 .48287 Mdot
.50077 .61699 Mdot
.50245 .61472 Mdot
.50782 .60747 Mdot
.5249 .58448 Mdot
.57919 .51406 Mdot
.74742 .36654 Mdot
.15435 .48823 Mdot
.36438 .59928 Mdot
.39472 .07189 Mdot
.2784 .21709 Mdot
.92714 .15188 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48754 .01682 Mdot
.46033 .05322 Mdot
.37422 .15806 Mdot
.11848 .25803 Mdot
.70098 .11742 Mdot
.51099 .10724 Mdot
.33747 .23306 Mdot
.96037 .1967 Mdot
.6421 .08178 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .00151 Mdot
.49645 .0048 Mdot
.48869 .01527 Mdot
.46398 .04838 Mdot
.38571 .14546 Mdot
.15035 .26502 Mdot
.72155 .11982 Mdot
.52767 .0943 Mdot
.3751 .19856 Mdot
.05382 .24751 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49667 .0045 Mdot
.4894 .01432 Mdot
.46623 .04539 Mdot
.39278 .13744 Mdot
.1704 .26691 Mdot
.73853 .11975 Mdot
.54477 .07879 Mdot
.41728 .15208 Mdot
.17121 .28191 Mdot
.71508 .1379 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48872 .01523 Mdot
.46407 .04826 Mdot
.38599 .14515 Mdot
.15114 .26513 Mdot
.72215 .11984 Mdot
.52825 .09378 Mdot
.37651 .19712 Mdot
.05757 .24933 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00409 Mdot
.49036 .01301 Mdot
.4693 .04129 Mdot
.40249 .12614 Mdot
.19839 .266 Mdot
.76799 .11939 Mdot
.57481 .05257 Mdot
.48976 .06205 Mdot
.38936 .15656 Mdot
.13603 .26787 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49067 .0126 Mdot
.47028 .04 Mdot
.40557 .12249 Mdot
.20737 .26478 Mdot
.77895 .11967 Mdot
.58533 .0443 Mdot
.51365 .03166 Mdot
.46242 .06618 Mdot
.35534 .18256 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00505 Mdot
.48809 .01608 Mdot
.46207 .05092 Mdot
.37968 .15213 Mdot
.13353 .2619 Mdot
.70977 .11904 Mdot
.51715 .10318 Mdot
.50004 .61798 Mdot
.50012 .61787 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60134 Mdot
.53938 .5652 Mdot
.62488 .46095 Mdot
.87905 .3593 Mdot
.29768 .50028 Mdot
.48821 .51119 Mdot
.50053 .61732 Mdot
.50169 .61575 Mdot
.50539 .61076 Mdot
.51716 .59487 Mdot
.55464 .54521 Mdot
.67247 .41483 Mdot
.00125 .41599 Mdot
.32816 .5461 Mdot
.44455 .59647 Mdot
.47944 .61548 Mdot
.48357 .01265 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50592 .61003 Mdot
.51887 .59259 Mdot
.56004 .53824 Mdot
.68916 .40134 Mdot
.03977 .43783 Mdot
.33135 .56652 Mdot
.4147 .02382 Mdot
.37616 .12739 Mdot
.17003 .2567 Mdot
.50053 .61731 Mdot
.5017 .61573 Mdot
.50543 .6107 Mdot
.51729 .59471 Mdot
.55503 .5447 Mdot
.67369 .41379 Mdot
.00416 .41765 Mdot
.32839 .54765 Mdot
.44227 .60001 Mdot
.47143 .00831 Mdot
.45798 .04682 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00513 Mdot
.48789 .01635 Mdot
.46144 .05174 Mdot
.37772 .15427 Mdot
.12811 .26062 Mdot
.70642 .11857 Mdot
.51457 .10508 Mdot
.34454 .22736 Mdot
.97666 .2058 Mdot
.64367 .08998 Mdot
.50099 .61669 Mdot
.50316 .61376 Mdot
.51007 .60444 Mdot
.53207 .5749 Mdot
.60186 .48679 Mdot
.81421 .35109 Mdot
.24613 .49859 Mdot
.43939 .55344 Mdot
.54391 .51325 Mdot
.71345 .36958 Mdot
.11546 .46747 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .01719 Mdot
.45944 .05439 Mdot
.37144 .16102 Mdot
.11091 .25572 Mdot
.69715 .11623 Mdot
.50908 .10781 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.49831 .00229 Mdot
.49461 .00729 Mdot
.48282 .02318 Mdot
.44531 .07289 Mdot
.32738 .20334 Mdot
.99837 .20183 Mdot
.67181 .07173 Mdot
.55574 .02111 Mdot
.52159 .00115 Mdot
.51973 .60094 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50694 .60866 Mdot
.52211 .58823 Mdot
.57033 .52513 Mdot
.72066 .38008 Mdot
.10567 .471 Mdot
.34357 .59378 Mdot
.38282 .07483 Mdot
.26175 .22197 Mdot
.90259 .1372 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.5118 .6021 Mdot
.53757 .5676 Mdot
.61918 .46715 Mdot
.86332 .35545 Mdot
.28819 .49877 Mdot
.48117 .51618 Mdot
.64597 .39905 Mdot
.00029 .39932 Mdot
.35418 .51637 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50439 .61211 Mdot
.51397 .59917 Mdot
.5445 .55846 Mdot
.6409 .44424 Mdot
.9221 .37487 Mdot
.31554 .51008 Mdot
.49021 .51915 Mdot
.65021 .39967 Mdot
.00354 .40295 Mdot
.50035 .61756 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.51131 .60276 Mdot
.53604 .56963 Mdot
.61435 .47251 Mdot
.84981 .35304 Mdot
.27857 .49822 Mdot
.47244 .52364 Mdot
.62518 .41919 Mdot
.94693 .37089 Mdot
.50052 .61733 Mdot
.50165 .6158 Mdot
.50527 .61091 Mdot
.51679 .59537 Mdot
.55346 .54674 Mdot
.66881 .41798 Mdot
.99251 .41104 Mdot
.32744 .54146 Mdot
.45134 .58587 Mdot
.50338 .58274 Mdot
.56048 .52802 Mdot
.50068 .61711 Mdot
.50217 .6151 Mdot
.50693 .60868 Mdot
.52207 .58828 Mdot
.5702 .52529 Mdot
.72027 .38031 Mdot
.1049 .47068 Mdot
.34334 .59357 Mdot
.38292 .07454 Mdot
.26231 .22164 Mdot
.90369 .13771 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50561 .61046 Mdot
.51787 .59393 Mdot
.55688 .54231 Mdot
.6794 .40905 Mdot
.01754 .42528 Mdot
.32943 .55483 Mdot
.4317 .61622 Mdot
.43463 .05709 Mdot
.34226 .18054 Mdot
.49993 .0001 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49237 .01031 Mdot
.47568 .03277 Mdot
.42266 .10168 Mdot
.25813 .24903 Mdot
.85519 .13256 Mdot
.6407 .01846 Mdot
.61084 .54184 Mdot
.73412 .39503 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.51091 .6033 Mdot
.53474 .57135 Mdot
.61027 .47711 Mdot
.83829 .35169 Mdot
.26924 .49816 Mdot
.4632 .53198 Mdot
.60244 .44343 Mdot
.88496 .34583 Mdot
.3254 .47712 Mdot
.50058 .61724 Mdot
.50186 .61552 Mdot
.50593 .61002 Mdot
.51889 .59255 Mdot
.56013 .53812 Mdot
.68945 .40112 Mdot
.04042 .43819 Mdot
.33141 .56685 Mdot
.41423 .02453 Mdot
.37454 .12916 Mdot
.16555 .25642 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.4957 .0058 Mdot
.48631 .01848 Mdot
.45642 .05837 Mdot
.36197 .17088 Mdot
.08548 .24637 Mdot
.68684 .11029 Mdot
.50839 .10252 Mdot
.3425 .22584 Mdot
.97709 .20467 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00222 Mdot
.49475 .00709 Mdot
.48328 .02256 Mdot
.44679 .07097 Mdot
.33195 .19938 Mdot
.00934 .20804 Mdot
.67273 .07755 Mdot
.54725 .03438 Mdot
.49162 .04215 Mdot
.42342 .11044 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.5101 .6044 Mdot
.53216 .57479 Mdot
.60214 .48647 Mdot
.81501 .35106 Mdot
.24698 .49858 Mdot
.44026 .55267 Mdot
.54601 .51061 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.50211 .61518 Mdot
.50674 .60894 Mdot
.52146 .58911 Mdot
.56826 .52774 Mdot
.71435 .38389 Mdot
.09321 .46544 Mdot
.34011 .58996 Mdot
.38553 .06914 Mdot
.27366 .21505 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00357 Mdot
.49158 .01137 Mdot
.47318 .03611 Mdot
.41475 .11142 Mdot
.23447 .25826 Mdot
.81659 .12344 Mdot
.61685 .02459 Mdot
.57706 .57395 Mdot
.6484 .45546 Mdot
.91145 .37754 Mdot
.50084 .61689 Mdot
.50269 .6144 Mdot
.50858 .60645 Mdot
.52732 .58125 Mdot
.58683 .50469 Mdot
.77023 .35833 Mdot
.19043 .49566 Mdot
.38843 .59083 Mdot
.43244 .03356 Mdot
.37814 .13581 Mdot
.15839 .25958 Mdot
.4996 .00054 Mdot
.49873 .00171 Mdot
.49597 .00545 Mdot
.48716 .01734 Mdot
.45911 .05483 Mdot
.37039 .16214 Mdot
.10804 .25478 Mdot
.6958 .11571 Mdot
.50857 .10777 Mdot
.33419 .23515 Mdot
.95371 .19284 Mdot
.64169 .07816 Mdot
.501 .61668 Mdot
.5032 .61372 Mdot
.51018 .60429 Mdot
.53242 .57443 Mdot
.60297 .4855 Mdot
.81742 .35099 Mdot
.2495 .49854 Mdot
.44285 .55039 Mdot
.55231 .50276 Mdot
.73882 .35558 Mdot
.16347 .48185 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00382 Mdot
.491 .01215 Mdot
.47134 .03858 Mdot
.40892 .11848 Mdot
.21722 .2629 Mdot
.79183 .12043 Mdot
.59698 .03598 Mdot
.53876 .00041 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49677 .00437 Mdot
.4897 .01392 Mdot
.46718 .04413 Mdot
.39578 .13399 Mdot
.17897 .26709 Mdot
.74682 .11957 Mdot
.55335 .07103 Mdot
.43842 .1267 Mdot
.23341 .27345 Mdot
.79096 .13076 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51272 .60086 Mdot
.5405 .56372 Mdot
.62839 .45719 Mdot
.88865 .36218 Mdot
.30263 .50173 Mdot
.49083 .51023 Mdot
.66526 .3831 Mdot
.04539 .42461 Mdot
.35835 .53927 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01801 Mdot
.45751 .05693 Mdot
.36539 .16737 Mdot
.09458 .24998 Mdot
.6901 .11276 Mdot
.50765 .10567 Mdot
.33668 .23187 Mdot
.9615 .19653 Mdot
.64351 .08079 Mdot
.50128 .61631 Mdot
.50407 .61254 Mdot
.51296 .60054 Mdot
.54127 .5627 Mdot
.63081 .45463 Mdot
.89519 .36434 Mdot
.30567 .50295 Mdot
.49187 .51048 Mdot
.66589 .38307 Mdot
.04608 .42519 Mdot
.35811 .53999 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50854 .6065 Mdot
.52721 .5814 Mdot
.58649 .50511 Mdot
.76921 .35863 Mdot
.18893 .49545 Mdot
.38727 .59143 Mdot
.43032 .03595 Mdot
.37215 .14213 Mdot
.14218 .25709 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00325 Mdot
.49233 .01037 Mdot
.47555 .03294 Mdot
.42225 .10219 Mdot
.25691 .24959 Mdot
.85307 .13192 Mdot
.63962 .01846 Mdot
.60975 .54262 Mdot
.73178 .39604 Mdot
.09097 .47586 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46278 .04997 Mdot
.38193 .14966 Mdot
.13976 .26321 Mdot
.71388 .11945 Mdot
.52061 .10039 Mdot
.35817 .21515 Mdot
.01005 .22446 Mdot
.64686 .10683 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49512 .00659 Mdot
.48446 .02098 Mdot
.45052 .06612 Mdot
.34354 .18891 Mdot
.03788 .22369 Mdot
.67594 .09184 Mdot
.52734 .06661 Mdot
.41957 .13804 Mdot
.19621 .27724 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49734 .00359 Mdot
.49154 .01143 Mdot
.47304 .03631 Mdot
.41429 .11197 Mdot
.23312 .25869 Mdot
.81455 .12311 Mdot
.61534 .0253 Mdot
.57441 .57684 Mdot
.64106 .46254 Mdot
.89266 .3704 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50051 .61735 Mdot
.50162 .61585 Mdot
.50516 .61106 Mdot
.51644 .59585 Mdot
.55234 .5482 Mdot
.66533 .42105 Mdot
.98406 .4063 Mdot
.32666 .53705 Mdot
.45769 .57581 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00697 Mdot
.48356 .02219 Mdot
.44766 .06983 Mdot
.33467 .19699 Mdot
.01594 .21174 Mdot
.67334 .08098 Mdot
.54231 .04222 Mdot
.47399 .06622 Mdot
.36685 .17576 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50297 .61403 Mdot
.50945 .60527 Mdot
.53011 .57753 Mdot
.59565 .4941 Mdot
.79618 .35272 Mdot
.22547 .49852 Mdot
.41885 .57053 Mdot
.49572 .57449 Mdot
.56617 .5149 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50739 .60806 Mdot
.52353 .58632 Mdot
.57484 .51947 Mdot
.73432 .37264 Mdot
.13137 .48106 Mdot
.35299 .59878 Mdot
.38415 .0789 Mdot
.25648 .22633 Mdot
.89028 .13248 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .60489 Mdot
.531 .57634 Mdot
.59847 .49076 Mdot
.8044 .35175 Mdot
.23525 .49866 Mdot
.42839 .56283 Mdot
.51771 .54645 Mdot
.63354 .43667 Mdot
.50023 .61772 Mdot
.50074 .61703 Mdot
.50236 .61484 Mdot
.50753 .60787 Mdot
.52398 .58572 Mdot
.57627 .51769 Mdot
.73864 .37052 Mdot
.13913 .48369 Mdot
.35651 .59941 Mdot
.38665 .07779 Mdot
.26078 .225 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49806 .00263 Mdot
.49381 .00836 Mdot
.48027 .02661 Mdot
.43723 .0833 Mdot
.30244 .22291 Mdot
.94176 .17012 Mdot
.66651 .04241 Mdot
.59788 .57532 Mdot
.66698 .4474 Mdot
.94307 .39574 Mdot
.49997 3e-05 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00353 Mdot
.49167 .01126 Mdot
.47345 .03575 Mdot
.41561 .11037 Mdot
.23702 .25743 Mdot
.8205 .12412 Mdot
.61967 .02335 Mdot
.58189 .56877 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00483 Mdot
.48861 .01539 Mdot
.46371 .04874 Mdot
.38486 .14641 Mdot
.14796 .26465 Mdot
.71974 .11977 Mdot
.52595 .09581 Mdot
.37092 .20278 Mdot
.04282 .242 Mdot
.65126 .12195 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49586 .0056 Mdot
.4868 .01783 Mdot
.45795 .05636 Mdot
.36677 .16594 Mdot
.09827 .25136 Mdot
.69156 .11365 Mdot
.50766 .10655 Mdot
.33526 .23343 Mdot
.95756 .19455 Mdot
.64277 .07924 Mdot
.49965 .00047 Mdot
.49889 .00149 Mdot
.49648 .00476 Mdot
.48877 .01516 Mdot
.46424 .04803 Mdot
.38653 .14454 Mdot
.15266 .26534 Mdot
.72334 .11986 Mdot
.5294 .09275 Mdot
.37933 .19421 Mdot
.06509 .25288 Mdot
.65592 .13038 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51293 .60058 Mdot
.54117 .56284 Mdot
.63047 .45499 Mdot
.89429 .36403 Mdot
.30527 .50277 Mdot
.49176 .5104 Mdot
.66591 .38298 Mdot
.04625 .42525 Mdot
.49963 .0005 Mdot
.49882 .0016 Mdot
.49623 .00509 Mdot
.48799 .01621 Mdot
.46176 .05132 Mdot
.37873 .15317 Mdot
.13089 .26129 Mdot
.70811 .11883 Mdot
.51584 .10417 Mdot
.3473 .22499 Mdot
.98325 .20949 Mdot
.64429 .09332 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49007 .01341 Mdot
.46837 .04254 Mdot
.39953 .12962 Mdot
.1898 .26674 Mdot
.75821 .11939 Mdot
.56504 .06076 Mdot
.46673 .09138 Mdot
.31886 .22533 Mdot
.95427 .18352 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50992 .60464 Mdot
.53159 .57554 Mdot
.60034 .48856 Mdot
.80983 .35132 Mdot
.24138 .49865 Mdot
.43454 .55763 Mdot
.53227 .52792 Mdot
.67808 .39518 Mdot
.50009 .61791 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50922 .60558 Mdot
.52938 .57849 Mdot
.59336 .49682 Mdot
.78949 .35379 Mdot
.21704 .49819 Mdot
.41096 .57649 Mdot
.47817 .59667 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48873 .01522 Mdot
.4641 .04822 Mdot
.38608 .14504 Mdot
.15141 .26517 Mdot
.72236 .11984 Mdot
.52845 .0936 Mdot
.377 .19661 Mdot
.05888 .24996 Mdot
.65444 .12822 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46801 .04301 Mdot
.39842 .13092 Mdot
.18658 .26691 Mdot
.75471 .11943 Mdot
.56148 .06384 Mdot
.45817 .10217 Mdot
.29286 .2444 Mdot
.89741 .15574 Mdot
.50036 .61755 Mdot
.50113 .61651 Mdot
.50361 .61316 Mdot
.51149 .60252 Mdot
.53659 .5689 Mdot
.61608 .47058 Mdot
.85466 .35381 Mdot
.28219 .49834 Mdot
.47585 .52064 Mdot
.63343 .41094 Mdot
.96853 .38195 Mdot
.50057 .61726 Mdot
.50183 .61557 Mdot
.50582 .61017 Mdot
.51855 .59302 Mdot
.55902 .53954 Mdot
.68602 .40376 Mdot
.03273 .43389 Mdot
.33068 .56287 Mdot
.41994 .01597 Mdot
.3941 .10706 Mdot
.22087 .25214 Mdot
.50097 .61672 Mdot
.50309 .61385 Mdot
.50986 .60472 Mdot
.53139 .57581 Mdot
.59972 .48929 Mdot
.80803 .35145 Mdot
.23938 .49866 Mdot
.43252 .55936 Mdot
.52746 .53402 Mdot
.66339 .40779 Mdot
.00357 .4111 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48819 .01594 Mdot
.46239 .05049 Mdot
.3807 .15101 Mdot
.13636 .26252 Mdot
.7116 .11925 Mdot
.51866 .10199 Mdot
.35363 .21935 Mdot
.99872 .21816 Mdot
.64573 .10117 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .00211 Mdot
.49503 .00671 Mdot
.48417 .02137 Mdot
.44959 .06732 Mdot
.34066 .19157 Mdot
.0307 .21985 Mdot
.67497 .0884 Mdot
.53194 .05899 Mdot
.4365 .11631 Mdot
.24831 .26384 Mdot
.50008 .61792 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50265 .61446 Mdot
.50843 .60664 Mdot
.52687 .58185 Mdot
.58541 .50641 Mdot
.76602 .35962 Mdot
.18415 .49471 Mdot
.38369 .59319 Mdot
.42389 .04306 Mdot
.49987 .00017 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.48692 .01766 Mdot
.45835 .05584 Mdot
.368 .16465 Mdot
.10158 .25256 Mdot
.69293 .1144 Mdot
.50782 .10715 Mdot
.33445 .23441 Mdot
.95517 .1934 Mdot
.50067 .61713 Mdot
.50214 .61515 Mdot
.50681 .60884 Mdot
.52168 .58881 Mdot
.56897 .52685 Mdot
.71651 .38256 Mdot
.09752 .46741 Mdot
.34123 .59137 Mdot
.38437 .07135 Mdot
.26893 .21785 Mdot
.91644 .14389 Mdot
.50054 .6173 Mdot
.50173 .61569 Mdot
.50552 .61058 Mdot
.51758 .59432 Mdot
.55595 .54351 Mdot
.67654 .4114 Mdot
.01088 .42148 Mdot
.32891 .55126 Mdot
.43696 .60818 Mdot
.45289 .03318 Mdot
.3992 .12051 Mdot
.50068 .61712 Mdot
.50217 .61511 Mdot
.5069 .60872 Mdot
.52198 .58841 Mdot
.56991 .52566 Mdot
.71938 .38083 Mdot
.10318 .46993 Mdot
.34282 .59308 Mdot
.3832 .07387 Mdot
.26368 .22087 Mdot
.9063 .13894 Mdot
.50062 .6172 Mdot
.50198 .61537 Mdot
.50629 .60953 Mdot
.52005 .59099 Mdot
.5638 .53341 Mdot
.70072 .39289 Mdot
.06502 .4515 Mdot
.33448 .57874 Mdot
.39805 .04888 Mdot
.31896 .1828 Mdot
.02319 .20421 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00382 Mdot
.49099 .01217 Mdot
.47129 .03864 Mdot
.40878 .11865 Mdot
.21679 .263 Mdot
.79126 .12038 Mdot
.59647 .03632 Mdot
.5377 .00169 Mdot
.53496 .58758 Mdot
.58424 .51308 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00236 Mdot
.49444 .00751 Mdot
.48229 .02389 Mdot
.44364 .07505 Mdot
.3222 .20767 Mdot
.98619 .19488 Mdot
.67086 .0652 Mdot
.56536 .0063 Mdot
.55517 .57421 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49427 .00775 Mdot
.48173 .02465 Mdot
.44185 .07736 Mdot
.31668 .21215 Mdot
.97342 .18762 Mdot
.66985 .05839 Mdot
.57536 .60914 Mdot
.58975 .53028 Mdot
.73173 .38371 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50423 .61231 Mdot
.51349 .59982 Mdot
.54296 .56048 Mdot
.63607 .44915 Mdot
.90933 .36957 Mdot
.31135 .50629 Mdot
.49216 .51355 Mdot
.66122 .38837 Mdot
.03282 .41858 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.49709 .00393 Mdot
.49074 .01251 Mdot
.4705 .0397 Mdot
.40627 .12165 Mdot
.20944 .26443 Mdot
.78158 .11978 Mdot
.58777 .04247 Mdot
.51905 .02486 Mdot
.47883 .04442 Mdot
.40695 .12585 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .00168 Mdot
.49603 .00537 Mdot
.48735 .01708 Mdot
.45971 .05404 Mdot
.37228 .16013 Mdot
.11318 .25643 Mdot
.69826 .11662 Mdot
.50957 .10775 Mdot
.33523 .23464 Mdot
.95558 .19399 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50366 .61309 Mdot
.51167 .60228 Mdot
.53716 .56815 Mdot
.61788 .46859 Mdot
.85969 .35472 Mdot
.28574 .49856 Mdot
.47906 .51792 Mdot
.64105 .40361 Mdot
.98799 .39249 Mdot
.50027 .61766 Mdot
.50087 .61685 Mdot
.50279 .61427 Mdot
.50888 .60604 Mdot
.52828 .57996 Mdot
.58988 .501 Mdot
.77924 .35594 Mdot
.20331 .49718 Mdot
.39885 .58476 Mdot
.45268 .00995 Mdot
.43658 .0672 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49599 .00542 Mdot
.48722 .01726 Mdot
.45929 .05459 Mdot
.37097 .16152 Mdot
.10962 .2553 Mdot
.69654 .116 Mdot
.50884 .10781 Mdot
.33439 .2351 Mdot
.954 .19304 Mdot
.64165 .07839 Mdot
.50063 .61719 Mdot
.502 .61533 Mdot
.50637 .60943 Mdot
.52029 .59067 Mdot
.56457 .53243 Mdot
.70308 .39125 Mdot
.07002 .45409 Mdot
.33528 .58095 Mdot
.39528 .05314 Mdot
.3093 .19057 Mdot
.00095 .19145 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46592 .0458 Mdot
.39181 .13856 Mdot
.16762 .26677 Mdot
.73597 .1198 Mdot
.54213 .0812 Mdot
.41074 .15967 Mdot
.15239 .28033 Mdot
.69881 .14035 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50193 .61543 Mdot
.50613 .60975 Mdot
.51954 .59167 Mdot
.56219 .53547 Mdot
.69578 .39641 Mdot
.05438 .44584 Mdot
.33299 .57378 Mdot
.40459 .039 Mdot
.50106 .61661 Mdot
.50336 .61349 Mdot
.51071 .60357 Mdot
.53412 .57218 Mdot
.60832 .47934 Mdot
.83273 .35128 Mdot
.26434 .49823 Mdot
.4582 .53654 Mdot
.59006 .45744 Mdot
.84991 .33802 Mdot
.30298 .47747 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00453 Mdot
.48931 .01444 Mdot
.46595 .04576 Mdot
.39192 .13843 Mdot
.16794 .26679 Mdot
.73626 .1198 Mdot
.54243 .08093 Mdot
.41148 .15882 Mdot
.15451 .28059 Mdot
.7005 .14013 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49693 .00414 Mdot
.49023 .0132 Mdot
.46887 .04188 Mdot
.4011 .12778 Mdot
.19436 .26639 Mdot
.76332 .11937 Mdot
.57018 .05639 Mdot
.47894 .07586 Mdot
.35619 .19176 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51339 .59996 Mdot
.54263 .56091 Mdot
.63505 .45021 Mdot
.90659 .3685 Mdot
.31034 .50557 Mdot
.49231 .51269 Mdot
.66276 .38677 Mdot
.03696 .42072 Mdot
.50089 .61683 Mdot
.50285 .61419 Mdot
.50907 .60579 Mdot
.52888 .57916 Mdot
.59179 .4987 Mdot
.78488 .35468 Mdot
.21098 .49782 Mdot
.4055 .58037 Mdot
.46644 .61125 Mdot
.47742 .01408 Mdot
.45465 .05555 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50773 .60759 Mdot
.52464 .58484 Mdot
.57835 .5151 Mdot
.7449 .36763 Mdot
.15006 .48703 Mdot
.36203 .59951 Mdot
.392 .07408 Mdot
.27213 .2202 Mdot
.91583 .14576 Mdot
.50094 .61676 Mdot
.503 .61398 Mdot
.50956 .60513 Mdot
.53044 .57709 Mdot
.59669 .49286 Mdot
.79922 .35232 Mdot
.22916 .4986 Mdot
.42241 .56771 Mdot
.50383 .56417 Mdot
.59099 .48433 Mdot
.80732 .34626 Mdot
.49984 .00021 Mdot
.49949 .00069 Mdot
.49838 .00218 Mdot
.49485 .00695 Mdot
.4836 .02213 Mdot
.4478 .06965 Mdot
.3351 .19661 Mdot
.01698 .21232 Mdot
.67344 .08152 Mdot
.54154 .04344 Mdot
.47125 .06995 Mdot
.35806 .18478 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00475 Mdot
.48881 .01511 Mdot
.46436 .04788 Mdot
.38689 .14413 Mdot
.15369 .26547 Mdot
.72415 .11987 Mdot
.53019 .09205 Mdot
.38126 .19219 Mdot
.07029 .25526 Mdot
.65728 .13205 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48876 .01517 Mdot
.46421 .04807 Mdot
.38643 .14465 Mdot
.15238 .2653 Mdot
.72312 .11985 Mdot
.52919 .09295 Mdot
.3788 .19476 Mdot
.06367 .25222 Mdot
.65557 .1299 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.4892 .01458 Mdot
.46561 .04621 Mdot
.39084 .13966 Mdot
.16486 .26659 Mdot
.7335 .11984 Mdot
.53959 .08351 Mdot
.40447 .16685 Mdot
.1345 .27722 Mdot
.68595 .14146 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50201 .61531 Mdot
.50642 .60937 Mdot
.52044 .59047 Mdot
.56503 .53185 Mdot
.70448 .3903 Mdot
.07297 .4556 Mdot
.3358 .58222 Mdot
.39375 .05553 Mdot
.30389 .1947 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51127 .60281 Mdot
.53591 .5698 Mdot
.61395 .47296 Mdot
.84868 .35288 Mdot
.2777 .4982 Mdot
.47161 .52438 Mdot
.62314 .42127 Mdot
.94151 .36826 Mdot
.34565 .48995 Mdot
.50039 .61751 Mdot
.50124 .61635 Mdot
.50396 .61268 Mdot
.51262 .601 Mdot
.54019 .56413 Mdot
.6274 .45824 Mdot
.88595 .36133 Mdot
.3013 .50128 Mdot
.49022 .51034 Mdot
.66448 .38358 Mdot
.04383 .4237 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50839 .6067 Mdot
.52673 .58204 Mdot
.58497 .50695 Mdot
.76471 .36004 Mdot
.18216 .49438 Mdot
.38224 .59386 Mdot
.42135 .0458 Mdot
.34725 .16665 Mdot
.0776 .23577 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51123 .60287 Mdot
.53578 .56998 Mdot
.61353 .47343 Mdot
.84751 .35272 Mdot
.2768 .49818 Mdot
.47073 .52516 Mdot
.621 .42349 Mdot
.93579 .36556 Mdot
.3443 .48795 Mdot
.5007 .61709 Mdot
.50222 .61503 Mdot
.50708 .60847 Mdot
.52256 .58763 Mdot
.57176 .52333 Mdot
.725 .3776 Mdot
.11402 .47449 Mdot
.34628 .59586 Mdot
.38216 .07736 Mdot
.25699 .22476 Mdot
.89333 .13311 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49827 .00234 Mdot
.49448 .00746 Mdot
.48241 .02374 Mdot
.444 .07458 Mdot
.32332 .20675 Mdot
.9888 .19637 Mdot
.67106 .06661 Mdot
.56329 .00946 Mdot
.54798 .58369 Mdot
.60356 .49432 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49726 .0037 Mdot
.49128 .01178 Mdot
.47221 .03742 Mdot
.41167 .11517 Mdot
.22532 .26094 Mdot
.80311 .12154 Mdot
.60646 .03004 Mdot
.55786 .59561 Mdot
.59414 .51334 Mdot
.76354 .36633 Mdot
.49985 .00021 Mdot
.49951 .00067 Mdot
.49843 .00212 Mdot
.49499 .00676 Mdot
.48405 .02153 Mdot
.44922 .06781 Mdot
.3395 .19264 Mdot
.0278 .21828 Mdot
.67462 .08698 Mdot
.53388 .0558 Mdot
.44359 .10701 Mdot
.27045 .25334 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50641 .60937 Mdot
.52042 .59049 Mdot
.56499 .53191 Mdot
.70434 .39039 Mdot
.07267 .45545 Mdot
.33574 .58209 Mdot
.3939 .05529 Mdot
.30443 .19429 Mdot
.99006 .18508 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50498 .61131 Mdot
.51586 .59664 Mdot
.55048 .55062 Mdot
.65956 .42626 Mdot
.96985 .39848 Mdot
.3251 .5299 Mdot
.4677 .55964 Mdot
.56218 .50346 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48852 .0155 Mdot
.46345 .04909 Mdot
.38402 .14734 Mdot
.14561 .26427 Mdot
.71801 .1197 Mdot
.52433 .09723 Mdot
.36701 .20666 Mdot
.03262 .2367 Mdot
.64964 .11752 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50784 .60744 Mdot
.52498 .58437 Mdot
.57945 .51374 Mdot
.74819 .36621 Mdot
.15565 .48858 Mdot
.36511 .59918 Mdot
.39561 .07113 Mdot
.28052 .21597 Mdot
.93107 .15405 Mdot
.5009 .61682 Mdot
.50287 .61415 Mdot
.50915 .60567 Mdot
.52915 .5788 Mdot
.59263 .49769 Mdot
.78735 .35419 Mdot
.21426 .49803 Mdot
.40843 .57832 Mdot
.47269 .60351 Mdot
.49619 .60705 Mdot
.51396 .59412 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49617 .00518 Mdot
.48779 .01648 Mdot
.46113 .05216 Mdot
.37673 .15535 Mdot
.12538 .25992 Mdot
.70481 .11829 Mdot
.51342 .10586 Mdot
.34214 .22936 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50504 .61122 Mdot
.51607 .59635 Mdot
.55116 .54973 Mdot
.66167 .42433 Mdot
.97509 .40133 Mdot
.32572 .53249 Mdot
.46413 .56546 Mdot
.54919 .52058 Mdot
.70688 .37842 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49692 .00416 Mdot
.49019 .01325 Mdot
.46874 .04204 Mdot
.40072 .12823 Mdot
.19325 .26649 Mdot
.76206 .11937 Mdot
.56892 .05745 Mdot
.47596 .07966 Mdot
.34707 .2006 Mdot
.02248 .22138 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45743 .05705 Mdot
.36512 .16765 Mdot
.09385 .2497 Mdot
.68983 .11258 Mdot
.50767 .10547 Mdot
.33702 .2315 Mdot
.96244 .197 Mdot
.64368 .08118 Mdot
.50045 .61743 Mdot
.50142 .61612 Mdot
.50452 .61193 Mdot
.51439 .59861 Mdot
.54583 .55671 Mdot
.64505 .4401 Mdot
.93296 .37977 Mdot
.31848 .51387 Mdot
.48703 .52588 Mdot
.63615 .4145 Mdot
.96547 .38274 Mdot
.50088 .61684 Mdot
.50281 .61424 Mdot
.50894 .60596 Mdot
.52849 .57969 Mdot
.59053 .50022 Mdot
.78116 .35549 Mdot
.20596 .49742 Mdot
.40112 .58331 Mdot
.4573 .00439 Mdot
.4502 .04981 Mdot
.3696 .15762 Mdot
.50087 .61686 Mdot
.50276 .61431 Mdot
.50879 .60616 Mdot
.52799 .58035 Mdot
.58897 .5021 Mdot
.77656 .3566 Mdot
.19956 .4968 Mdot
.39572 .5867 Mdot
.44642 .01741 Mdot
.41825 .08991 Mdot
.27278 .23594 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51127 .60281 Mdot
.53591 .5698 Mdot
.61395 .47297 Mdot
.84867 .35288 Mdot
.2777 .4982 Mdot
.4716 .52438 Mdot
.62314 .42128 Mdot
.9415 .36826 Mdot
.34565 .48995 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50733 .60813 Mdot
.52335 .58656 Mdot
.57428 .52018 Mdot
.73261 .37351 Mdot
.12826 .47996 Mdot
.35168 .5984 Mdot
.38344 .07902 Mdot
.25558 .22648 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50629 .60954 Mdot
.52003 .59103 Mdot
.56373 .53351 Mdot
.70048 .39305 Mdot
.06451 .45123 Mdot
.3344 .57851 Mdot
.39835 .04844 Mdot
.31998 .18195 Mdot
.02558 .20556 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.4979 .00283 Mdot
.49332 .00902 Mdot
.47872 .02869 Mdot
.4323 .08958 Mdot
.28735 .23308 Mdot
.91022 .15419 Mdot
.66073 .02926 Mdot
.61339 .55084 Mdot
.72211 .40556 Mdot
.0659 .46492 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56063 Mdot
.63571 .44952 Mdot
.90837 .36919 Mdot
.311 .50603 Mdot
.49223 .51324 Mdot
.66179 .38778 Mdot
.03436 .41938 Mdot
.35579 .53552 Mdot
.50116 .61646 Mdot
.5037 .61303 Mdot
.51179 .60211 Mdot
.53756 .56761 Mdot
.61914 .46719 Mdot
.86321 .35543 Mdot
.28812 .49876 Mdot
.48111 .51623 Mdot
.64582 .39919 Mdot
.99993 .39912 Mdot
.35414 .51619 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51135 .60271 Mdot
.53614 .56949 Mdot
.61469 .47213 Mdot
.85076 .35318 Mdot
.2793 .49824 Mdot
.47314 .52302 Mdot
.62688 .41746 Mdot
.95141 .37311 Mdot
.3477 .49372 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49554 .00602 Mdot
.48579 .01918 Mdot
.45476 .06055 Mdot
.35679 .17611 Mdot
.07183 .24046 Mdot
.68275 .1059 Mdot
.5114 .09533 Mdot
.35715 .21069 Mdot
.01625 .22573 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49292 .00957 Mdot
.47744 .03041 Mdot
.42824 .09471 Mdot
.275 .24043 Mdot
.88597 .14354 Mdot
.65372 .02218 Mdot
.61784 .54068 Mdot
.74301 .39327 Mdot
.10668 .48493 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.5123 .60142 Mdot
.53918 .56546 Mdot
.62425 .46163 Mdot
.87732 .35883 Mdot
.29672 .50006 Mdot
.48761 .51154 Mdot
.65992 .387 Mdot
.03374 .41805 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50662 .60909 Mdot
.52109 .5896 Mdot
.5671 .52922 Mdot
.7108 .38613 Mdot
.08602 .46205 Mdot
.33841 .58741 Mdot
.38795 .06488 Mdot
.28296 .20928 Mdot
.94435 .15873 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00547 Mdot
.48709 .01742 Mdot
.4589 .0551 Mdot
.36974 .16282 Mdot
.10629 .2542 Mdot
.69499 .11538 Mdot
.50831 .10767 Mdot
.33409 .2351 Mdot
.95369 .19277 Mdot
.64178 .07804 Mdot
.5 0 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48745 .01694 Mdot
.46004 .05359 Mdot
.37332 .15902 Mdot
.11603 .2573 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01506 Mdot
.46448 .04772 Mdot
.38726 .14371 Mdot
.15473 .2656 Mdot
.72497 .11988 Mdot
.53101 .09131 Mdot
.38326 .19009 Mdot
.07568 .25764 Mdot
.65881 .13366 Mdot
.50046 .61742 Mdot
.50146 .61606 Mdot
.50464 .61176 Mdot
.51479 .59807 Mdot
.5471 .55503 Mdot
.64904 .43619 Mdot
.94328 .38471 Mdot
.3208 .51789 Mdot
.48284 .53377 Mdot
.61917 .43334 Mdot
.91802 .36065 Mdot
.49977 .0003 Mdot
.49928 .00097 Mdot
.49771 .00309 Mdot
.4927 .00985 Mdot
.47676 .03132 Mdot
.42608 .09741 Mdot
.26846 .24397 Mdot
.87372 .1388 Mdot
.64914 .0199 Mdot
.61693 .53903 Mdot
.74476 .39157 Mdot
.11119 .48646 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50426 .61227 Mdot
.51359 .59969 Mdot
.54326 .56008 Mdot
.63703 .44818 Mdot
.91186 .37058 Mdot
.31225 .50698 Mdot
.49194 .51445 Mdot
.65953 .39011 Mdot
.02833 .41623 Mdot
.50035 .61757 Mdot
.5011 .61655 Mdot
.5035 .6133 Mdot
.51116 .60297 Mdot
.53554 .57029 Mdot
.61278 .47427 Mdot
.84539 .35245 Mdot
.27512 .49816 Mdot
.46909 .52663 Mdot
.61698 .42769 Mdot
.92495 .36067 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51305 .60041 Mdot
.54157 .56231 Mdot
.63173 .45367 Mdot
.89767 .36521 Mdot
.30675 .50347 Mdot
.49212 .51078 Mdot
.66567 .38346 Mdot
.04521 .42481 Mdot
.35785 .53976 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48906 .01477 Mdot
.46517 .0468 Mdot
.38944 .14125 Mdot
.1609 .26627 Mdot
.73007 .11988 Mdot
.5361 .0867 Mdot
.39582 .17652 Mdot
.1102 .27072 Mdot
.67217 .14046 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61239 Mdot
.51332 .60005 Mdot
.54241 .5612 Mdot
.63437 .45091 Mdot
.90478 .36781 Mdot
.30965 .50511 Mdot
.49236 .51219 Mdot
.66361 .38586 Mdot
.03928 .42191 Mdot
.50123 .61638 Mdot
.5039 .61276 Mdot
.51244 .60124 Mdot
.53961 .5649 Mdot
.62559 .46018 Mdot
.881 .35986 Mdot
.29874 .50054 Mdot
.48885 .51087 Mdot
.66225 .38518 Mdot
.03901 .42099 Mdot
.35784 .53594 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49066 .01262 Mdot
.47024 .04005 Mdot
.40544 .12264 Mdot
.20701 .26483 Mdot
.7785 .11965 Mdot
.5849 .04462 Mdot
.51271 .03285 Mdot
.45955 .06995 Mdot
.34636 .19127 Mdot
.49981 .00026 Mdot
.49938 .00083 Mdot
.49803 .00266 Mdot
.49373 .00847 Mdot
.48002 .02694 Mdot
.43644 .08431 Mdot
.30001 .22463 Mdot
.93655 .16736 Mdot
.66576 .04 Mdot
.60104 .57054 Mdot
.67789 .43788 Mdot
.96938 .40967 Mdot
.50063 .61719 Mdot
.502 .61534 Mdot
.50636 .60944 Mdot
.52026 .59071 Mdot
.56447 .53257 Mdot
.70276 .39147 Mdot
.06934 .45374 Mdot
.33517 .58066 Mdot
.39565 .05258 Mdot
.31056 .18957 Mdot
.00383 .19312 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00448 Mdot
.48944 .01427 Mdot
.46635 .04523 Mdot
.39317 .137 Mdot
.17151 .26696 Mdot
.73956 .11973 Mdot
.54584 .07782 Mdot
.41992 .14897 Mdot
.17888 .28203 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00294 Mdot
.49307 .00936 Mdot
.47792 .02976 Mdot
.42976 .09279 Mdot
.27963 .23778 Mdot
.8949 .14727 Mdot
.6566 .02441 Mdot
.6171 .54342 Mdot
.73784 .3963 Mdot
.4996 .00054 Mdot
.49871 .00174 Mdot
.49591 .00553 Mdot
.48696 .01761 Mdot
.45846 .05568 Mdot
.36837 .16427 Mdot
.10258 .25291 Mdot
.69335 .11462 Mdot
.5079 .10729 Mdot
.3343 .23462 Mdot
.95468 .19317 Mdot
.64212 .07824 Mdot
.50063 .61719 Mdot
.502 .61534 Mdot
.50636 .60944 Mdot
.52026 .59071 Mdot
.56447 .53257 Mdot
.70276 .39147 Mdot
.06935 .45375 Mdot
.33517 .58066 Mdot
.39564 .05259 Mdot
.31055 .18958 Mdot
.0038 .19311 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49834 .00224 Mdot
.49472 .00713 Mdot
.48319 .02268 Mdot
.4465 .07135 Mdot
.33106 .20016 Mdot
.00719 .20682 Mdot
.67254 .07641 Mdot
.5489 .03179 Mdot
.49746 .03415 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49277 .00977 Mdot
.47697 .03104 Mdot
.42674 .09659 Mdot
.27046 .24291 Mdot
.87742 .14018 Mdot
.50048 .61739 Mdot
.50153 .61597 Mdot
.50487 .61146 Mdot
.51551 .5971 Mdot
.54939 .55205 Mdot
.65616 .42942 Mdot
.96135 .39393 Mdot
.32395 .52584 Mdot
.47313 .55063 Mdot
.58219 .47778 Mdot
.80913 .3403 Mdot
.5 0 Mdot
.5 0 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00567 Mdot
.48663 .01805 Mdot
.45742 .05705 Mdot
.36511 .16766 Mdot
.50078 .61698 Mdot
.50249 .61467 Mdot
.50794 .60731 Mdot
.52528 .58397 Mdot
.58039 .51258 Mdot
.75102 .36504 Mdot
.16038 .4898 Mdot
.36787 .5987 Mdot
.39915 .06803 Mdot
.28907 .21115 Mdot
.94743 .16329 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .6089 Mdot
.52155 .58898 Mdot
.56856 .52737 Mdot
.71525 .38333 Mdot
.09501 .46627 Mdot
.34057 .59056 Mdot
.38502 .07009 Mdot
.27161 .21628 Mdot
.92166 .14655 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50432 .6122 Mdot
.51377 .59945 Mdot
.54384 .55932 Mdot
.63884 .44632 Mdot
.91668 .37256 Mdot
.31387 .50838 Mdot
.49129 .51646 Mdot
.65564 .39409 Mdot
.01799 .41073 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48657 .01813 Mdot
.45724 .05729 Mdot
.36454 .16825 Mdot
.0923 .2491 Mdot
.68925 .11218 Mdot
.50774 .10501 Mdot
.33783 .23065 Mdot
.96462 .19812 Mdot
.64405 .08208 Mdot
.50056 .61728 Mdot
.50177 .61564 Mdot
.50564 .61042 Mdot
.51796 .59381 Mdot
.55716 .54195 Mdot
.68026 .40834 Mdot
.01955 .42642 Mdot
.32958 .5559 Mdot
.43012 .00059 Mdot
.42916 .06412 Mdot
.3254 .19542 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48867 .0153 Mdot
.46391 .04848 Mdot
.38547 .14573 Mdot
.14967 .26492 Mdot
.72103 .11981 Mdot
.52718 .09474 Mdot
.37389 .19979 Mdot
.05062 .24593 Mdot
.65269 .12512 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49415 .00791 Mdot
.48135 .02516 Mdot
.44064 .07893 Mdot
.31293 .21509 Mdot
.96491 .18282 Mdot
.6691 .05393 Mdot
.58184 .5994 Mdot
.61199 .50394 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .0018 Mdot
.49576 .00573 Mdot
.4865 .01823 Mdot
.457 .05761 Mdot
.36378 .16903 Mdot
.09028 .24831 Mdot
.68851 .11164 Mdot
.50787 .10435 Mdot
.33902 .22941 Mdot
.96782 .19978 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49645 .0048 Mdot
.48868 .01528 Mdot
.46395 .04842 Mdot
.3856 .14557 Mdot
.15006 .26497 Mdot
.72133 .11982 Mdot
.52746 .09448 Mdot
.37459 .19908 Mdot
.05246 .24684 Mdot
.65306 .12583 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49657 .00464 Mdot
.48907 .01476 Mdot
.46518 .04679 Mdot
.38948 .14121 Mdot
.161 .26628 Mdot
.73015 .11988 Mdot
.53618 .08662 Mdot
.39602 .1763 Mdot
.11076 .27089 Mdot
.67244 .14052 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49564 .00588 Mdot
.48612 .01873 Mdot
.45582 .05917 Mdot
.36008 .1728 Mdot
.08048 .24427 Mdot
.68524 .10878 Mdot
.50923 .10022 Mdot
.34707 .22117 Mdot
.98922 .21118 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50504 .61123 Mdot
.51604 .59639 Mdot
.55107 .54985 Mdot
.66139 .42459 Mdot
.9744 .40096 Mdot
.32564 .53215 Mdot
.46461 .56469 Mdot
.55091 .51829 Mdot
.7123 .37487 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49677 .00437 Mdot
.4897 .01392 Mdot
.46718 .04413 Mdot
.39578 .13398 Mdot
.179 .26709 Mdot
.74684 .11957 Mdot
.55337 .07101 Mdot
.43848 .12664 Mdot
.23357 .2734 Mdot
.79121 .13077 Mdot
.50117 .61645 Mdot
.50372 .613 Mdot
.51186 .60202 Mdot
.53778 .56732 Mdot
.61985 .46642 Mdot
.86516 .35584 Mdot
.28939 .49889 Mdot
.48217 .51539 Mdot
.64825 .39698 Mdot
.00593 .40247 Mdot
.35471 .51922 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01558 Mdot
.46325 .04935 Mdot
.38341 .14802 Mdot
.1439 .26398 Mdot
.71677 .11964 Mdot
.5232 .09821 Mdot
.36429 .20932 Mdot
.0256 .23295 Mdot
.64868 .11431 Mdot
.50119 .61642 Mdot
.50381 .61289 Mdot
.51213 .60166 Mdot
.53863 .5662 Mdot
.6225 .46352 Mdot
.87251 .35757 Mdot
.29395 .49952 Mdot
.4857 .51276 Mdot
.65603 .3902 Mdot
.02468 .41298 Mdot
.35646 .52874 Mdot
.50064 .61717 Mdot
.50203 .61529 Mdot
.50647 .6093 Mdot
.5206 .59026 Mdot
.56554 .5312 Mdot
.70604 .38925 Mdot
.07621 .45724 Mdot
.33639 .58357 Mdot
.39215 .05804 Mdot
.29823 .19886 Mdot
.97646 .17712 Mdot
.50006 .61796 Mdot
.50018 .61779 Mdot
.50059 .61724 Mdot
.50186 .61551 Mdot
.50594 .61001 Mdot
.51893 .5925 Mdot
.56024 .53798 Mdot
.68977 .40087 Mdot
.04114 .43859 Mdot
.33149 .56722 Mdot
.41371 .02532 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49625 .00507 Mdot
.48805 .01613 Mdot
.46195 .05107 Mdot
.37931 .15254 Mdot
.13249 .26166 Mdot
.70911 .11896 Mdot
.51662 .10358 Mdot
.34902 .22348 Mdot
.98743 .21184 Mdot
.64467 .09544 Mdot
.49976 .00032 Mdot
.49924 .00102 Mdot
.49759 .00326 Mdot
.49232 .01038 Mdot
.47552 .03298 Mdot
.42215 .10231 Mdot
.25662 .24972 Mdot
.85256 .13177 Mdot
.63936 .01846 Mdot
.60948 .54282 Mdot
.73118 .39631 Mdot
.08994 .47532 Mdot
.49984 .00022 Mdot
.49947 .00071 Mdot
.49833 .00226 Mdot
.49467 .0072 Mdot
.48301 .02292 Mdot
.44592 .0721 Mdot
.32925 .20173 Mdot
.00285 .20437 Mdot
.67217 .07412 Mdot
.55225 .02654 Mdot
.5093 .01793 Mdot
.48029 .03616 Mdot
.4996 .00053 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.4872 .01728 Mdot
.45924 .05465 Mdot
.37082 .16168 Mdot
.10921 .25517 Mdot
.69634 .11593 Mdot
.50877 .10781 Mdot
.33433 .23512 Mdot
.9539 .19298 Mdot
.64166 .07832 Mdot
.4999 .00014 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48928 .01447 Mdot
.46587 .04587 Mdot
.39165 .13874 Mdot
.16716 .26675 Mdot
.73556 .11981 Mdot
.54171 .08159 Mdot
.4097 .16088 Mdot
.14938 .27991 Mdot
.50057 .61726 Mdot
.50181 .61558 Mdot
.50578 .61022 Mdot
.51842 .59318 Mdot
.55863 .54005 Mdot
.68482 .4047 Mdot
.03 .43235 Mdot
.33044 .56144 Mdot
.42201 .01285 Mdot
.40121 .09867 Mdot
.24157 .246 Mdot
.50002 .61801 Mdot
.50006 .61796 Mdot
.50018 .61778 Mdot
.50059 .61724 Mdot
.50187 .6155 Mdot
.50597 .60996 Mdot
.51903 .59236 Mdot
.56057 .53756 Mdot
.69077 .40011 Mdot
.04337 .43983 Mdot
.33172 .56835 Mdot
.49981 .00026 Mdot
.4994 .00081 Mdot
.49808 .00259 Mdot
.49389 .00825 Mdot
.48054 .02625 Mdot
.43807 .08223 Mdot
.30502 .22104 Mdot
.94737 .17314 Mdot
.66723 .0451 Mdot
.59426 .58076 Mdot
.65457 .45896 Mdot
.91196 .38144 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50577 .61024 Mdot
.51838 .59324 Mdot
.5585 .54022 Mdot
.6844 .40503 Mdot
.02905 .43181 Mdot
.33036 .56094 Mdot
.42274 .01176 Mdot
.40371 .09567 Mdot
.24891 .24321 Mdot
.50057 .61727 Mdot
.50181 .61559 Mdot
.50576 .61026 Mdot
.51834 .59329 Mdot
.55838 .54038 Mdot
.68403 .40533 Mdot
.02819 .43133 Mdot
.33029 .56049 Mdot
.42339 .01077 Mdot
.40597 .09295 Mdot
.25558 .2404 Mdot
.50079 .61697 Mdot
.50251 .61464 Mdot
.508 .60723 Mdot
.52549 .5837 Mdot
.58105 .51176 Mdot
.753 .36424 Mdot
.16364 .4906 Mdot
.36984 .59825 Mdot
.40184 .06556 Mdot
.29577 .20704 Mdot
.96077 .17104 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49742 .00349 Mdot
.49177 .01112 Mdot
.47379 .03531 Mdot
.41666 .10909 Mdot
.24015 .25635 Mdot
.82537 .12504 Mdot
.62305 .022 Mdot
.58745 .56298 Mdot
.67652 .43089 Mdot
.97933 .41178 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49415 .0079 Mdot
.48137 .02513 Mdot
.44071 .07883 Mdot
.31316 .21491 Mdot
.96544 .18312 Mdot
.66915 .0542 Mdot
.58145 .59998 Mdot
.61065 .50547 Mdot
.79278 .36323 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01488 Mdot
.46491 .04715 Mdot
.38862 .14218 Mdot
.15857 .26604 Mdot
.72811 .11989 Mdot
.53412 .0885 Mdot
.39094 .18187 Mdot
.09666 .26607 Mdot
.50058 .61725 Mdot
.50184 .61555 Mdot
.50587 .61011 Mdot
.51869 .59282 Mdot
.55949 .53894 Mdot
.68747 .40264 Mdot
.03598 .43571 Mdot
.33098 .56457 Mdot
.41749 .01964 Mdot
.38571 .11672 Mdot
.19687 .25611 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00456 Mdot
.48925 .01452 Mdot
.46576 .04601 Mdot
.39131 .13912 Mdot
.1662 .26669 Mdot
.73469 .11982 Mdot
.54082 .0824 Mdot
.4075 .1634 Mdot
.14311 .2789 Mdot
.69184 .1411 Mdot
.50118 .61644 Mdot
.50375 .61296 Mdot
.51196 .60188 Mdot
.53809 .5669 Mdot
.62082 .46535 Mdot
.86788 .35645 Mdot
.29112 .4991 Mdot
.48356 .51431 Mdot
.65138 .3942 Mdot
.01356 .40675 Mdot
.35542 .5231 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50496 .61133 Mdot
.5158 .59671 Mdot
.55031 .55083 Mdot
.65905 .42673 Mdot
.96858 .39779 Mdot
.32494 .52928 Mdot
.46854 .55826 Mdot
.56526 .49943 Mdot
.75716 .35204 Mdot
.50027 .61767 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50866 .60634 Mdot
.52758 .5809 Mdot
.58768 .50366 Mdot
.77273 .35762 Mdot
.19408 .49615 Mdot
.39129 .58928 Mdot
.43782 .02744 Mdot
.39343 .11902 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49712 .00388 Mdot
.49084 .01237 Mdot
.47082 .03927 Mdot
.40728 .12045 Mdot
.2124 .26389 Mdot
.78541 .11998 Mdot
.59127 .03993 Mdot
.52667 .01532 Mdot
.50187 .01359 Mdot
.47988 .03219 Mdot
.50099 .6167 Mdot
.50315 .61377 Mdot
.51005 .60447 Mdot
.532 .575 Mdot
.60163 .48705 Mdot
.81356 .35112 Mdot
.24544 .4986 Mdot
.43868 .55406 Mdot
.54219 .5154 Mdot
.70826 .3729 Mdot
.10489 .46325 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50629 .60954 Mdot
.52002 .59103 Mdot
.56372 .53353 Mdot
.70045 .39308 Mdot
.06443 .45119 Mdot
.33439 .57848 Mdot
.39839 .04837 Mdot
.32012 .18183 Mdot
.02592 .20575 Mdot
.50096 .61674 Mdot
.50305 .61392 Mdot
.50971 .60493 Mdot
.53092 .57644 Mdot
.59821 .49107 Mdot
.80364 .35183 Mdot
.23438 .49866 Mdot
.42753 .56355 Mdot
.51569 .54902 Mdot
.62735 .44317 Mdot
.91029 .36434 Mdot
.50037 .61754 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60208 Mdot
.53763 .56752 Mdot
.61936 .46695 Mdot
.86381 .35555 Mdot
.28851 .4988 Mdot
.48144 .51597 Mdot
.64659 .39849 Mdot
.00182 .40017 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50854 .6065 Mdot
.52721 .5814 Mdot
.58649 .5051 Mdot
.76921 .35863 Mdot
.18893 .49545 Mdot
.38728 .59143 Mdot
.43033 .03594 Mdot
.37217 .14211 Mdot
.14224 .2571 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51666 .59555 Mdot
.55304 .54728 Mdot
.66753 .41911 Mdot
.9894 .40928 Mdot
.32716 .53983 Mdot
.45371 .58214 Mdot
.50016 .61782 Mdot
.5005 .61736 Mdot
.50159 .61589 Mdot
.50505 .61121 Mdot
.51609 .59632 Mdot
.55122 .54965 Mdot
.66187 .42415 Mdot
.97558 .4016 Mdot
.32577 .53274 Mdot
.46379 .56602 Mdot
.54795 .52224 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .6049 Mdot
.53098 .57636 Mdot
.59842 .49082 Mdot
.80425 .35177 Mdot
.23508 .49866 Mdot
.42823 .56297 Mdot
.51732 .54694 Mdot
.63236 .4379 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00667 Mdot
.48428 .02122 Mdot
.44995 .06686 Mdot
.34177 .19055 Mdot
.03345 .22133 Mdot
.67533 .08973 Mdot
.53014 .06196 Mdot
.42988 .12488 Mdot
.50081 .61694 Mdot
.50257 .61456 Mdot
.50819 .60698 Mdot
.52608 .58291 Mdot
.58291 .50947 Mdot
.75856 .36214 Mdot
.1726 .49258 Mdot
.37559 .59653 Mdot
.41038 .05725 Mdot
.31775 .19163 Mdot
.00769 .19875 Mdot
.49963 .0005 Mdot
.49881 .0016 Mdot
.49622 .00511 Mdot
.48795 .01627 Mdot
.46161 .05152 Mdot
.37826 .15369 Mdot
.12959 .26098 Mdot
.70731 .11871 Mdot
.51523 .10461 Mdot
.34596 .22614 Mdot
.98006 .2077 Mdot
.64399 .0917 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49865 .00182 Mdot
.49571 .0058 Mdot
.48632 .01846 Mdot
.45645 .05833 Mdot
.36208 .17078 Mdot
.08575 .24648 Mdot
.68693 .11037 Mdot
.50835 .10264 Mdot
.34228 .22607 Mdot
.9765 .20436 Mdot
.5006 .61722 Mdot
.50193 .61543 Mdot
.50614 .60974 Mdot
.51955 .59167 Mdot
.56221 .53546 Mdot
.69582 .39638 Mdot
.05447 .44589 Mdot
.333 .57383 Mdot
.40453 .03909 Mdot
.34128 .16302 Mdot
.07751 .23207 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49654 .00467 Mdot
.48898 .01489 Mdot
.46489 .04717 Mdot
.38856 .14225 Mdot
.1584 .26602 Mdot
.72797 .11989 Mdot
.53398 .08862 Mdot
.39059 .18225 Mdot
.09569 .26572 Mdot
.66575 .13836 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.4934 .00892 Mdot
.47897 .02836 Mdot
.43309 .08858 Mdot
.28976 .23154 Mdot
.91512 .15653 Mdot
.66185 .03104 Mdot
.61161 .55388 Mdot
.71541 .40981 Mdot
.05233 .45745 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01285 Mdot
.46969 .04079 Mdot
.40369 .12472 Mdot
.2019 .26557 Mdot
.77219 .11946 Mdot
.5789 .04928 Mdot
.49917 .05005 Mdot
.41819 .12259 Mdot
.21984 .26749 Mdot
.49995 6e-05 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49531 .00633 Mdot
.48507 .02015 Mdot
.45247 .06357 Mdot
.34961 .18314 Mdot
.05328 .23162 Mdot
.67851 .09871 Mdot
.5188 .08133 Mdot
.38721 .17736 Mdot
.50058 .61725 Mdot
.50185 .61554 Mdot
.50589 .61008 Mdot
.51876 .59273 Mdot
.5597 .53868 Mdot
.6881 .40215 Mdot
.0374 .43651 Mdot
.33112 .5653 Mdot
.41644 .02122 Mdot
.38211 .12079 Mdot
.18667 .2568 Mdot
.5001 .6179 Mdot
.50031 .61762 Mdot
.50098 .6167 Mdot
.50314 .61379 Mdot
.51 .60453 Mdot
.53185 .5752 Mdot
.60115 .48762 Mdot
.81216 .35119 Mdot
.24393 .49862 Mdot
.43714 .5554 Mdot
.53849 .52006 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49616 .00518 Mdot
.48778 .0165 Mdot
.46108 .05222 Mdot
.37659 .1555 Mdot
.12498 .25982 Mdot
.70458 .11824 Mdot
.51326 .10596 Mdot
.34182 .22962 Mdot
.97028 .20223 Mdot
.64306 .08676 Mdot
.5 .61803 Mdot
.50001 .61802 Mdot
.50002 .61801 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.50219 .61507 Mdot
.50699 .60859 Mdot
.52227 .58801 Mdot
.57084 .52448 Mdot
.72221 .37918 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00531 Mdot
.48747 .01691 Mdot
.46011 .05351 Mdot
.37353 .1588 Mdot
.11659 .25747 Mdot
.69999 .11715 Mdot
.51044 .10748 Mdot
.33654 .23375 Mdot
.95833 .19555 Mdot
.64192 .08074 Mdot
.50115 .61647 Mdot
.50368 .61306 Mdot
.51172 .60221 Mdot
.53733 .56792 Mdot
.61842 .46799 Mdot
.86119 .35501 Mdot
.28676 .49864 Mdot
.47995 .51718 Mdot
.64314 .40166 Mdot
.99325 .3954 Mdot
.35348 .51284 Mdot
.50102 .61665 Mdot
.50326 .61363 Mdot
.51039 .604 Mdot
.5331 .57353 Mdot
.60511 .48302 Mdot
.82358 .35096 Mdot
.25572 .49841 Mdot
.44927 .54464 Mdot
.56802 .48348 Mdot
.78573 .33964 Mdot
.23618 .48663 Mdot
.50034 .61758 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51092 .60328 Mdot
.53479 .57129 Mdot
.61042 .47694 Mdot
.83872 .35173 Mdot
.26961 .49816 Mdot
.46357 .53163 Mdot
.60337 .4424 Mdot
.88754 .34661 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49464 .00724 Mdot
.48293 .02303 Mdot
.44566 .07243 Mdot
.32847 .20241 Mdot
.00097 .2033 Mdot
.67202 .07312 Mdot
.55371 .02426 Mdot
.51446 .01088 Mdot
.49685 .0138 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48856 .01545 Mdot
.46357 .04893 Mdot
.38441 .14691 Mdot
.1467 .26445 Mdot
.71881 .11973 Mdot
.52507 .09658 Mdot
.3688 .2049 Mdot
.03726 .23913 Mdot
.65034 .11958 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00287 Mdot
.49323 .00914 Mdot
.47844 .02907 Mdot
.4314 .09072 Mdot
.28461 .23479 Mdot
.90472 .15164 Mdot
.65936 .02738 Mdot
.61506 .5478 Mdot
.72869 .40158 Mdot
.07893 .47179 Mdot
.50082 .61692 Mdot
.50262 .6145 Mdot
.50834 .60677 Mdot
.52657 .58225 Mdot
.58446 .50757 Mdot
.76319 .36054 Mdot
.17983 .49397 Mdot
.38057 .59459 Mdot
.41851 .04884 Mdot
.33948 .17368 Mdot
.05845 .22666 Mdot
.50075 .61702 Mdot
.50238 .61482 Mdot
.50758 .60779 Mdot
.52415 .58549 Mdot
.5768 .51702 Mdot
.74024 .36975 Mdot
.14197 .48459 Mdot
.35788 .59952 Mdot
.38783 .07708 Mdot
.26311 .22412 Mdot
.90047 .13775 Mdot
.50004 .61798 Mdot
.50013 .61785 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50436 .61214 Mdot
.5139 .59927 Mdot
.54426 .55876 Mdot
.64016 .44498 Mdot
.92017 .37404 Mdot
.31496 .50946 Mdot
.49063 .51814 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50363 .61313 Mdot
.51157 .60241 Mdot
.53686 .56854 Mdot
.61694 .46963 Mdot
.85706 .35423 Mdot
.28391 .49844 Mdot
.47742 .51929 Mdot
.63719 .40729 Mdot
.97819 .38713 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00482 Mdot
.48864 .01534 Mdot
.46383 .04858 Mdot
.38523 .14599 Mdot
.149 .26482 Mdot
.72052 .11979 Mdot
.52669 .09516 Mdot
.37272 .20098 Mdot
.04753 .24439 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51285 .60069 Mdot
.54091 .56318 Mdot
.62968 .45582 Mdot
.89214 .36331 Mdot
.30429 .50236 Mdot
.49146 .51027 Mdot
.66582 .38289 Mdot
.0463 .42521 Mdot
.3583 .53989 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .01331 Mdot
.46862 .04221 Mdot
.40032 .1287 Mdot
.19207 .26658 Mdot
.76074 .11937 Mdot
.56759 .05858 Mdot
.47281 .08366 Mdot
.49983 .00023 Mdot
.49946 .00074 Mdot
.49826 .00234 Mdot
.49447 .00747 Mdot
.48238 .02377 Mdot
.44393 .07468 Mdot
.3231 .20693 Mdot
.98827 .19607 Mdot
.67102 .06632 Mdot
.56371 .00882 Mdot
.54945 .58175 Mdot
.60816 .48902 Mdot
.50037 .61753 Mdot
.50118 .61644 Mdot
.50375 .61296 Mdot
.51196 .60189 Mdot
.53809 .56692 Mdot
.6208 .46538 Mdot
.8678 .35644 Mdot
.29107 .49909 Mdot
.48352 .51434 Mdot
.6513 .39428 Mdot
.01335 .40663 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51042 .60396 Mdot
.53318 .57342 Mdot
.60537 .48272 Mdot
.8243 .35097 Mdot
.25642 .49839 Mdot
.45001 .54398 Mdot
.56983 .4813 Mdot
.79107 .33864 Mdot
.24313 .48605 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00332 Mdot
.49218 .01057 Mdot
.47508 .03358 Mdot
.42075 .10404 Mdot
.25241 .25157 Mdot
.84536 .12973 Mdot
.63546 .01877 Mdot
.60509 .54631 Mdot
.72113 .40119 Mdot
.072 .46568 Mdot
.49971 .0004 Mdot
.49907 .00126 Mdot
.49703 .00401 Mdot
.49053 .01278 Mdot
.46985 .04057 Mdot
.4042 .12411 Mdot
.20338 .26537 Mdot
.774 .1195 Mdot
.58064 .04791 Mdot
.50313 .04501 Mdot
.4303 .10757 Mdot
.25624 .25501 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49742 .00349 Mdot
.49177 .01112 Mdot
.47378 .03531 Mdot
.41665 .10909 Mdot
.24014 .25635 Mdot
.82535 .12504 Mdot
.62303 .02201 Mdot
.58743 .563 Mdot
.67647 .43093 Mdot
.97921 .41171 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00378 Mdot
.49108 .01205 Mdot
.47158 .03826 Mdot
.40967 .11758 Mdot
.21943 .26241 Mdot
.79485 .12068 Mdot
.59958 .03427 Mdot
.54413 .61192 Mdot
.55402 .5628 Mdot
.6434 .44713 Mdot
.50046 .61742 Mdot
.50146 .61606 Mdot
.50465 .61176 Mdot
.5148 .59805 Mdot
.54713 .555 Mdot
.64912 .43611 Mdot
.94348 .38481 Mdot
.32084 .51797 Mdot
.48275 .53394 Mdot
.61881 .43374 Mdot
.91701 .36024 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46592 .0458 Mdot
.39182 .13855 Mdot
.16765 .26677 Mdot
.736 .1198 Mdot
.54216 .08117 Mdot
.41081 .1596 Mdot
.15258 .28035 Mdot
.69896 .14033 Mdot
.50051 .61734 Mdot
.50163 .61583 Mdot
.5052 .61101 Mdot
.51658 .59567 Mdot
.55277 .54764 Mdot
.66667 .41986 Mdot
.98733 .40812 Mdot
.32697 .53874 Mdot
.45526 .57967 Mdot
.51733 .56364 Mdot
.60535 .47295 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .0133 Mdot
.46863 .0422 Mdot
.40035 .12866 Mdot
.19216 .26657 Mdot
.76084 .11937 Mdot
.56769 .05849 Mdot
.47305 .08335 Mdot
.33819 .20882 Mdot
.00032 .20911 Mdot
.50063 .61718 Mdot
.502 .61533 Mdot
.50638 .60942 Mdot
.52032 .59063 Mdot
.56466 .53232 Mdot
.70335 .39106 Mdot
.0706 .45439 Mdot
.33538 .5812 Mdot
.39497 .05362 Mdot
.30821 .19141 Mdot
.99851 .19003 Mdot
.49976 .00032 Mdot
.49925 .00102 Mdot
.4976 .00324 Mdot
.49236 .01032 Mdot
.47566 .03279 Mdot
.42261 .10175 Mdot
.25798 .24911 Mdot
.85492 .13247 Mdot
.64057 .01845 Mdot
.61071 .54194 Mdot
.73384 .39515 Mdot
.09447 .47768 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49633 .00495 Mdot
.48832 .01577 Mdot
.4628 .04994 Mdot
.382 .14958 Mdot
.13998 .26325 Mdot
.71403 .11946 Mdot
.52074 .10029 Mdot
.35847 .21487 Mdot
.01081 .22488 Mdot
.64694 .1072 Mdot
.50088 .61684 Mdot
.50281 .61423 Mdot
.50896 .60593 Mdot
.52855 .57961 Mdot
.59072 .49999 Mdot
.78173 .35536 Mdot
.20674 .49749 Mdot
.40178 .58287 Mdot
.45868 .00272 Mdot
.45428 .04453 Mdot
.38223 .14401 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50436 .61214 Mdot
.5139 .59927 Mdot
.54427 .55875 Mdot
.6402 .44495 Mdot
.92025 .37408 Mdot
.31499 .50949 Mdot
.49062 .51818 Mdot
.65218 .39764 Mdot
.00878 .40578 Mdot
.50124 .61636 Mdot
.50395 .6127 Mdot
.51258 .60105 Mdot
.54007 .56429 Mdot
.62703 .45864 Mdot
.88494 .36102 Mdot
.30079 .50112 Mdot
.48997 .51041 Mdot
.66411 .38383 Mdot
.04306 .42326 Mdot
.3582 .538 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49343 .00887 Mdot
.47908 .02821 Mdot
.43345 .08812 Mdot
.29086 .23083 Mdot
.91737 .15762 Mdot
.66233 .0319 Mdot
.61071 .55538 Mdot
.71208 .412 Mdot
.04545 .45357 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48793 .0163 Mdot
.46155 .0516 Mdot
.37806 .1539 Mdot
.12905 .26085 Mdot
.70699 .11866 Mdot
.51499 .10479 Mdot
.34543 .22659 Mdot
.9788 .207 Mdot
.64387 .09106 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01286 Mdot
.46968 .0408 Mdot
.40367 .12475 Mdot
.20182 .26558 Mdot
.77209 .11946 Mdot
.5788 .04935 Mdot
.49895 .05033 Mdot
.41751 .12342 Mdot
.21781 .26796 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.4955 .00608 Mdot
.48565 .01937 Mdot
.45432 .06114 Mdot
.35539 .1775 Mdot
.0682 .2388 Mdot
.68181 .1046 Mdot
.51257 .09296 Mdot
.36216 .20536 Mdot
.02989 .2329 Mdot
.50103 .61664 Mdot
.50328 .6136 Mdot
.51045 .60392 Mdot
.53329 .57328 Mdot
.6057 .48233 Mdot
.82527 .35099 Mdot
.25737 .49837 Mdot
.45098 .5431 Mdot
.57223 .47841 Mdot
.79814 .33757 Mdot
.25195 .4851 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00486 Mdot
.48853 .01548 Mdot
.46348 .04904 Mdot
.38412 .14722 Mdot
.14591 .26432 Mdot
.71823 .11971 Mdot
.52453 .09706 Mdot
.36749 .20619 Mdot
.03388 .23736 Mdot
.64983 .11808 Mdot
.50048 .61738 Mdot
.50154 .61595 Mdot
.5049 .61141 Mdot
.51563 .59694 Mdot
.54975 .55157 Mdot
.65729 .42836 Mdot
.96419 .39544 Mdot
.32435 .52718 Mdot
.47137 .55358 Mdot
.57566 .48605 Mdot
.78921 .34296 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00527 Mdot
.48757 .01678 Mdot
.46042 .05309 Mdot
.37452 .15774 Mdot
.11929 .25826 Mdot
.70142 .11754 Mdot
.51124 .10712 Mdot
.33792 .23272 Mdot
.96136 .19725 Mdot
.6422 .08228 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49788 .00286 Mdot
.49325 .00912 Mdot
.47848 .02901 Mdot
.43154 .09054 Mdot
.28503 .23453 Mdot
.90556 .15203 Mdot
.65958 .02766 Mdot
.61482 .54824 Mdot
.72775 .40214 Mdot
.07708 .47083 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49157 .01139 Mdot
.47314 .03617 Mdot
.41461 .11159 Mdot
.23406 .25839 Mdot
.81597 .12334 Mdot
.6164 .0248 Mdot
.57627 .57481 Mdot
.64621 .45754 Mdot
.90591 .3753 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00313 Mdot
.49263 .00996 Mdot
.47652 .03165 Mdot
.42531 .09838 Mdot
.26613 .24517 Mdot
.86945 .13726 Mdot
.64736 .01935 Mdot
.61605 .53908 Mdot
.50103 .61664 Mdot
.50329 .61358 Mdot
.51049 .60386 Mdot
.53342 .57311 Mdot
.6061 .48187 Mdot
.82642 .35101 Mdot
.25847 .49835 Mdot
.45212 .54207 Mdot
.57504 .47505 Mdot
.8064 .33667 Mdot
.26166 .48382 Mdot
.49963 .0005 Mdot
.49882 .00159 Mdot
.49624 .00508 Mdot
.48802 .01617 Mdot
.46185 .0512 Mdot
.379 .15288 Mdot
.13165 .26147 Mdot
.70858 .11889 Mdot
.51621 .1039 Mdot
.3481 .22429 Mdot
.98519 .21058 Mdot
.64446 .0943 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48704 .0175 Mdot
.45872 .05534 Mdot
.36917 .16342 Mdot
.10476 .25367 Mdot
.69431 .11507 Mdot
.50812 .10755 Mdot
.33411 .23496 Mdot
.95393 .19285 Mdot
.6419 .07805 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50808 .60712 Mdot
.52574 .58336 Mdot
.58186 .51077 Mdot
.75541 .36331 Mdot
.16756 .4915 Mdot
.37229 .59759 Mdot
.40537 .06221 Mdot
.30472 .20112 Mdot
.97931 .18199 Mdot
.50076 .617 Mdot
.50243 .61475 Mdot
.50774 .60758 Mdot
.52465 .58482 Mdot
.57839 .51505 Mdot
.74502 .36758 Mdot
.15026 .48709 Mdot
.36213 .5995 Mdot
.39212 .07399 Mdot
.2724 .22008 Mdot
.91631 .14602 Mdot
.49988 .00016 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48812 .01604 Mdot
.46217 .05078 Mdot
.38001 .15177 Mdot
.13445 .2621 Mdot
.71035 .11911 Mdot
.51762 .10281 Mdot
.35128 .22148 Mdot
.99292 .21491 Mdot
.50102 .61666 Mdot
.50325 .61365 Mdot
.51034 .60407 Mdot
.53294 .57375 Mdot
.60458 .48363 Mdot
.82205 .35095 Mdot
.2542 .49844 Mdot
.44771 .54605 Mdot
.56418 .48816 Mdot
.77432 .34233 Mdot
.22042 .48733 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49631 .00498 Mdot
.48825 .01587 Mdot
.46258 .05024 Mdot
.38128 .15037 Mdot
.13798 .26285 Mdot
.71267 .11935 Mdot
.51957 .10125 Mdot
.35573 .21742 Mdot
.00394 .22107 Mdot
.64624 .10379 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50613 .60975 Mdot
.51952 .5917 Mdot
.56213 .53555 Mdot
.6956 .39654 Mdot
.05398 .44563 Mdot
.33294 .57359 Mdot
.40485 .03861 Mdot
.34238 .16199 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49827 .00233 Mdot
.4945 .00743 Mdot
.48247 .02365 Mdot
.4442 .07433 Mdot
.32393 .20624 Mdot
.99022 .19718 Mdot
.67117 .06737 Mdot
.56217 .01118 Mdot
.54408 .58887 Mdot
.59126 .50883 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49621 .00512 Mdot
.48793 .0163 Mdot
.46155 .05161 Mdot
.37804 .15392 Mdot
.12899 .26084 Mdot
.70695 .11866 Mdot
.51496 .10481 Mdot
.34538 .22664 Mdot
.97866 .20692 Mdot
.64386 .09099 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49916 .00113 Mdot
.49734 .0036 Mdot
.49152 .01145 Mdot
.47299 .03637 Mdot
.41415 .11216 Mdot
.23267 .25883 Mdot
.81388 .12301 Mdot
.61485 .02554 Mdot
.57352 .57781 Mdot
.6386 .46496 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.50279 .61426 Mdot
.5089 .60601 Mdot
.52836 .57986 Mdot
.59013 .5007 Mdot
.77999 .35576 Mdot
.20435 .49728 Mdot
.39974 .5842 Mdot
.45448 .0078 Mdot
.44186 .0605 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48761 .01673 Mdot
.46054 .05294 Mdot
.37489 .15734 Mdot
.12031 .25855 Mdot
.70197 .11767 Mdot
.51157 .10695 Mdot
.33851 .23226 Mdot
.9627 .198 Mdot
.64233 .08296 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54283 .56064 Mdot
.63569 .44955 Mdot
.90831 .36917 Mdot
.31098 .50602 Mdot
.49223 .51322 Mdot
.66183 .38774 Mdot
.03445 .41943 Mdot
.3558 .53555 Mdot
.4998 .00028 Mdot
.49935 .00088 Mdot
.49793 .0028 Mdot
.4934 .00891 Mdot
.47899 .02833 Mdot
.43315 .0885 Mdot
.28996 .23142 Mdot
.91551 .15672 Mdot
.66193 .03119 Mdot
.61146 .55414 Mdot
.71484 .41018 Mdot
.05114 .45679 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49384 .00832 Mdot
.48039 .02645 Mdot
.43759 .08284 Mdot
.30354 .22212 Mdot
.94415 .1714 Mdot
.66682 .04355 Mdot
.59636 .57761 Mdot
.66177 .45216 Mdot
.93016 .38947 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49705 .00398 Mdot
.49061 .01268 Mdot
.47009 .04024 Mdot
.40498 .12319 Mdot
.20565 .26505 Mdot
.77679 .11959 Mdot
.5833 .04584 Mdot
.50913 .03739 Mdot
.44863 .08419 Mdot
.31242 .22053 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51146 .60255 Mdot
.53651 .569 Mdot
.61585 .47083 Mdot
.85403 .3537 Mdot
.28173 .49832 Mdot
.47542 .52102 Mdot
.6324 .41195 Mdot
.96586 .38054 Mdot
.35013 .49983 Mdot
.50019 .61777 Mdot
.50061 .61721 Mdot
.50195 .61539 Mdot
.50623 .60962 Mdot
.51983 .59129 Mdot
.56311 .5343 Mdot
.6986 .39438 Mdot
.06048 .44911 Mdot
.33381 .57666 Mdot
.40074 .0448 Mdot
.32826 .17486 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49775 .00305 Mdot
.49282 .0097 Mdot
.47712 .03084 Mdot
.42722 .09599 Mdot
.27191 .24213 Mdot
.88013 .14122 Mdot
.65163 .02097 Mdot
.6177 .53957 Mdot
.74465 .39211 Mdot
.1102 .4863 Mdot
.50107 .61659 Mdot
.5034 .61345 Mdot
.51082 .60342 Mdot
.53446 .57173 Mdot
.60939 .47812 Mdot
.83577 .35149 Mdot
.26706 .49819 Mdot
.46098 .534 Mdot
.59694 .44958 Mdot
.8695 .34171 Mdot
.3166 .47653 Mdot
.50063 .61718 Mdot
.50202 .6153 Mdot
.50644 .60933 Mdot
.52053 .59035 Mdot
.56532 .53149 Mdot
.70535 .38971 Mdot
.07478 .45652 Mdot
.33612 .58298 Mdot
.39284 .05695 Mdot
.30069 .19708 Mdot
.98182 .18026 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49662 .00457 Mdot
.48923 .01455 Mdot
.46569 .04611 Mdot
.39107 .13939 Mdot
.16553 .26664 Mdot
.73409 .11983 Mdot
.5402 .08296 Mdot
.40597 .16514 Mdot
.13876 .27809 Mdot
.68879 .14133 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48655 .01815 Mdot
.45718 .05737 Mdot
.36434 .16845 Mdot
.09178 .2489 Mdot
.68905 .11204 Mdot
.50776 .10485 Mdot
.33812 .23035 Mdot
.9654 .19853 Mdot
.50092 .61679 Mdot
.50293 .61407 Mdot
.50934 .60541 Mdot
.52977 .57798 Mdot
.59457 .49537 Mdot
.79304 .35319 Mdot
.22156 .49839 Mdot
.41515 .57337 Mdot
.48742 .58502 Mdot
.54083 .54759 Mdot
.65481 .42566 Mdot
.50059 .61724 Mdot
.50187 .61551 Mdot
.50595 .60999 Mdot
.51896 .59245 Mdot
.56036 .53783 Mdot
.69012 .40061 Mdot
.04193 .43903 Mdot
.33157 .56762 Mdot
.41314 .02617 Mdot
.3708 .13322 Mdot
.15524 .25538 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .00229 Mdot
.4946 .0073 Mdot
.48279 .02322 Mdot
.44522 .07301 Mdot
.32709 .20358 Mdot
.99769 .20144 Mdot
.67175 .07137 Mdot
.55628 .02028 Mdot
.52347 .61663 Mdot
.52574 .59287 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50476 .6116 Mdot
.51518 .59755 Mdot
.54832 .55344 Mdot
.65283 .43255 Mdot
.95295 .38957 Mdot
.32262 .52202 Mdot
.47798 .54236 Mdot
.60042 .45533 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49988 .00016 Mdot
.49962 .00052 Mdot
.49879 .00164 Mdot
.49613 .00523 Mdot
.48767 .01665 Mdot
.46073 .05268 Mdot
.37549 .15669 Mdot
.12197 .25901 Mdot
.70288 .11789 Mdot
.51214 .10664 Mdot
.50089 .61683 Mdot
.50285 .61419 Mdot
.50907 .60579 Mdot
.52888 .57916 Mdot
.59177 .49872 Mdot
.78482 .3547 Mdot
.21091 .49781 Mdot
.40543 .58042 Mdot
.4663 .61143 Mdot
.47699 .01465 Mdot
.45328 .05735 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00301 Mdot
.4929 .0096 Mdot
.47737 .03051 Mdot
.428 .095 Mdot
.27429 .24083 Mdot
.88462 .14299 Mdot
.65325 .02188 Mdot
.61785 .54037 Mdot
.74351 .39295 Mdot
.10771 .48535 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60045 Mdot
.54148 .56243 Mdot
.63144 .45396 Mdot
.89692 .36494 Mdot
.30643 .50331 Mdot
.49205 .51068 Mdot
.66576 .38332 Mdot
.04554 .42496 Mdot
.35794 .53986 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00353 Mdot
.49167 .01125 Mdot
.47346 .03575 Mdot
.41562 .11036 Mdot
.23705 .25742 Mdot
.82054 .12413 Mdot
.6197 .02333 Mdot
.58194 .56871 Mdot
.66175 .44328 Mdot
.94451 .39287 Mdot
.50076 .61701 Mdot
.50241 .61477 Mdot
.50769 .60765 Mdot
.52449 .58504 Mdot
.57788 .51569 Mdot
.74348 .36827 Mdot
.14761 .48632 Mdot
.36073 .59957 Mdot
.39061 .07515 Mdot
.26902 .22164 Mdot
.9104 .1429 Mdot
.50089 .61683 Mdot
.50283 .61421 Mdot
.50901 .60586 Mdot
.5287 .5794 Mdot
.59121 .4994 Mdot
.78317 .35505 Mdot
.20869 .49765 Mdot
.40348 .58174 Mdot
.4622 .61646 Mdot
.46474 .03085 Mdot
.41483 .10608 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48973 .01387 Mdot
.46729 .04397 Mdot
.39614 .13357 Mdot
.18003 .26708 Mdot
.74789 .11955 Mdot
.55445 .07005 Mdot
.44112 .1234 Mdot
.24146 .27073 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00398 Mdot
.4906 .01269 Mdot
.47007 .04027 Mdot
.40491 .12327 Mdot
.20546 .26507 Mdot
.77656 .11958 Mdot
.58308 .04601 Mdot
.50863 .03802 Mdot
.44711 .08615 Mdot
.30771 .22411 Mdot
.50076 .61701 Mdot
.50241 .61477 Mdot
.50769 .60765 Mdot
.5245 .58503 Mdot
.5779 .51566 Mdot
.74355 .36824 Mdot
.14773 .48635 Mdot
.36079 .59957 Mdot
.39067 .0751 Mdot
.26916 .22158 Mdot
.91065 .14302 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50686 .60877 Mdot
.52184 .58859 Mdot
.56948 .52621 Mdot
.71806 .38162 Mdot
.10058 .46878 Mdot
.34207 .59232 Mdot
.38368 .07277 Mdot
.26594 .21957 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48948 .01421 Mdot
.46649 .04504 Mdot
.39361 .13648 Mdot
.17278 .267 Mdot
.74076 .1197 Mdot
.54708 .07669 Mdot
.42299 .14533 Mdot
.18784 .28176 Mdot
.73194 .13517 Mdot
.50132 .61624 Mdot
.50422 .61233 Mdot
.51345 .59988 Mdot
.54282 .56066 Mdot
.63565 .44959 Mdot
.9082 .36913 Mdot
.31094 .50599 Mdot
.49224 .51318 Mdot
.66189 .38768 Mdot
.03462 .41952 Mdot
.35583 .53563 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53083 .57656 Mdot
.59793 .4914 Mdot
.80283 .35191 Mdot
.23343 .49865 Mdot
.42659 .56432 Mdot
.51351 .55181 Mdot
.62066 .45036 Mdot
.89196 .35772 Mdot
.49959 .00055 Mdot
.49869 .00176 Mdot
.49584 .00562 Mdot
.48674 .0179 Mdot
.45779 .05657 Mdot
.36626 .16647 Mdot
.0969 .25085 Mdot
.69101 .11333 Mdot
.50764 .10625 Mdot
.33572 .23291 Mdot
.95886 .1952 Mdot
.64303 .07974 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51012 .60437 Mdot
.53222 .57471 Mdot
.60233 .48625 Mdot
.81556 .35104 Mdot
.24756 .49857 Mdot
.44085 .55215 Mdot
.54745 .50881 Mdot
.72417 .36321 Mdot
.13649 .47479 Mdot
.49967 .00045 Mdot
.49893 .00144 Mdot
.4966 .00459 Mdot
.48917 .01462 Mdot
.46552 .04633 Mdot
.39055 .13999 Mdot
.16404 .26653 Mdot
.73278 .11985 Mdot
.53886 .08418 Mdot
.40265 .16891 Mdot
.12935 .27605 Mdot
.68269 .1415 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00433 Mdot
.48978 .0138 Mdot
.46745 .04376 Mdot
.39664 .13299 Mdot
.18146 .26706 Mdot
.74935 .11952 Mdot
.55596 .0687 Mdot
.4448 .11885 Mdot
.2525 .26638 Mdot
.82149 .13347 Mdot
.50108 .61657 Mdot
.50344 .61338 Mdot
.51097 .60322 Mdot
.53494 .57108 Mdot
.61091 .47639 Mdot
.8401 .35186 Mdot
.27078 .49815 Mdot
.46476 .53056 Mdot
.6063 .43918 Mdot
.89569 .34926 Mdot
.33059 .47829 Mdot
.50009 .61792 Mdot
.50028 .61766 Mdot
.50088 .61684 Mdot
.50281 .61423 Mdot
.50896 .60593 Mdot
.52855 .57961 Mdot
.59072 .49999 Mdot
.78172 .35537 Mdot
.20672 .49749 Mdot
.40177 .58288 Mdot
.45864 .00276 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00907 Mdot
.4786 .02885 Mdot
.43192 .09005 Mdot
.28621 .2338 Mdot
.90792 .15312 Mdot
.66017 .02846 Mdot
.61413 .54952 Mdot
.72498 .4038 Mdot
.07162 .46798 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00367 Mdot
.49134 .01169 Mdot
.47242 .03714 Mdot
.41233 .11436 Mdot
.22729 .26041 Mdot
.80594 .12188 Mdot
.60873 .02874 Mdot
.56222 .59055 Mdot
.60669 .49889 Mdot
.50029 .61765 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60547 Mdot
.52963 .57816 Mdot
.59414 .49589 Mdot
.79177 .3534 Mdot
.21996 .49832 Mdot
.41366 .5745 Mdot
.4841 .58921 Mdot
.53073 .5609 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51284 .6007 Mdot
.54089 .5632 Mdot
.62961 .45589 Mdot
.89196 .36325 Mdot
.3042 .50232 Mdot
.49143 .51026 Mdot
.66581 .38289 Mdot
.04629 .42519 Mdot
.35831 .53987 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50712 .60842 Mdot
.52268 .58747 Mdot
.57214 .52286 Mdot
.72613 .37697 Mdot
.11618 .47536 Mdot
.34703 .59633 Mdot
.38215 .07783 Mdot
.25622 .22526 Mdot
.89174 .13246 Mdot
.50016 .61781 Mdot
.50052 .61733 Mdot
.50167 .61578 Mdot
.50532 .61084 Mdot
.51695 .59516 Mdot
.55397 .54608 Mdot
.6704 .41661 Mdot
.99631 .41319 Mdot
.32776 .54347 Mdot
.4484 .59047 Mdot
.493 .59696 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48907 .01476 Mdot
.4652 .04677 Mdot
.38953 .14115 Mdot
.16114 .26629 Mdot
.73027 .11988 Mdot
.5363 .08651 Mdot
.39632 .17597 Mdot
.1116 .27116 Mdot
.50131 .61627 Mdot
.50417 .61241 Mdot
.51327 .60012 Mdot
.54226 .5614 Mdot
.63388 .45142 Mdot
.90348 .36732 Mdot
.30914 .50479 Mdot
.49237 .51187 Mdot
.66414 .38528 Mdot
.04075 .42264 Mdot
.3569 .53814 Mdot
.5002 .61777 Mdot
.50063 .61719 Mdot
.502 .61534 Mdot
.50636 .60944 Mdot
.52027 .5907 Mdot
.5645 .53253 Mdot
.70286 .39141 Mdot
.06955 .45385 Mdot
.33521 .58075 Mdot
.39553 .05276 Mdot
.31017 .18988 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50744 .60799 Mdot
.52369 .58611 Mdot
.57535 .51883 Mdot
.73586 .37187 Mdot
.13416 .48203 Mdot
.35422 .59905 Mdot
.38493 .07864 Mdot
.25768 .22602 Mdot
.89198 .13339 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50101 .61666 Mdot
.50323 .61367 Mdot
.51029 .60414 Mdot
.53278 .57396 Mdot
.60408 .48421 Mdot
.82062 .35095 Mdot
.25277 .49847 Mdot
.44623 .54738 Mdot
.56055 .4926 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50304 .61393 Mdot
.50968 .60496 Mdot
.53084 .57654 Mdot
.59797 .49135 Mdot
.80296 .35189 Mdot
.23358 .49865 Mdot
.42674 .5642 Mdot
.51385 .55137 Mdot
.62172 .44921 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49343 .00887 Mdot
.47908 .02821 Mdot
.43343 .08814 Mdot
.29082 .23086 Mdot
.91728 .15758 Mdot
.66231 .03187 Mdot
.61075 .55532 Mdot
.71222 .41192 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.5132 .60021 Mdot
.54204 .56169 Mdot
.6332 .45213 Mdot
.90163 .36664 Mdot
.3084 .50436 Mdot
.49234 .51146 Mdot
.66478 .38457 Mdot
.04253 .42353 Mdot
.35725 .53883 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .60141 Mdot
.53922 .56541 Mdot
.62436 .4615 Mdot
.87764 .35892 Mdot
.2969 .5001 Mdot
.48772 .51147 Mdot
.66015 .38682 Mdot
.03426 .41834 Mdot
.35738 .53356 Mdot
.50001 .61802 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51088 .60335 Mdot
.53464 .57148 Mdot
.60996 .47746 Mdot
.83741 .35162 Mdot
.26848 .49817 Mdot
.49994 9e-05 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00278 Mdot
.49345 .00884 Mdot
.47914 .02812 Mdot
.43364 .08788 Mdot
.29145 .23045 Mdot
.91858 .15821 Mdot
.66258 .03237 Mdot
.6102 .55621 Mdot
.71023 .41325 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49007 .01341 Mdot
.46837 .04254 Mdot
.39953 .12962 Mdot
.1898 .26674 Mdot
.75821 .11939 Mdot
.56504 .06076 Mdot
.46673 .09138 Mdot
.31888 .22532 Mdot
.95431 .18354 Mdot
.50119 .61642 Mdot
.5038 .6129 Mdot
.51212 .60167 Mdot
.53859 .56625 Mdot
.62239 .46364 Mdot
.8722 .35749 Mdot
.29377 .49949 Mdot
.48557 .51286 Mdot
.65575 .39043 Mdot
.02401 .41261 Mdot
.35639 .5284 Mdot
.50034 .61758 Mdot
.50108 .61657 Mdot
.50344 .61338 Mdot
.51097 .60322 Mdot
.53494 .57108 Mdot
.61091 .47639 Mdot
.8401 .35186 Mdot
.27078 .49815 Mdot
.46476 .53055 Mdot
.6063 .43917 Mdot
.89571 .34926 Mdot
.49986 .0002 Mdot
.49954 .00062 Mdot
.49853 .00199 Mdot
.49532 .00633 Mdot
.48508 .02014 Mdot
.4525 .06352 Mdot
.34972 .18304 Mdot
.05355 .23175 Mdot
.67856 .09882 Mdot
.51867 .08156 Mdot
.3867 .17794 Mdot
.09879 .26376 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48683 .01777 Mdot
.45807 .05619 Mdot
.36715 .16554 Mdot
.0993 .25174 Mdot
.69198 .11389 Mdot
.5077 .10676 Mdot
.33496 .23378 Mdot
.95669 .19413 Mdot
.64259 .07892 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00522 Mdot
.48769 .01662 Mdot
.46081 .05258 Mdot
.37572 .15644 Mdot
.1226 .25918 Mdot
.70323 .11796 Mdot
.51236 .10651 Mdot
.34002 .23108 Mdot
.96612 .19991 Mdot
.64266 .08467 Mdot
.49966 .00046 Mdot
.49893 .00145 Mdot
.49658 .00462 Mdot
.48911 .01471 Mdot
.46531 .04662 Mdot
.38988 .14076 Mdot
.16213 .26638 Mdot
.73112 .11987 Mdot
.53717 .08573 Mdot
.39846 .1736 Mdot
.11756 .27295 Mdot
.67593 .14109 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48858 .01542 Mdot
.46363 .04884 Mdot
.3846 .1467 Mdot
.14723 .26454 Mdot
.7192 .11975 Mdot
.52544 .09626 Mdot
.36969 .20401 Mdot
.03959 .24034 Mdot
.65072 .12058 Mdot
.5003 .61763 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50957 .6051 Mdot
.5305 .577 Mdot
.59689 .49263 Mdot
.7998 .35225 Mdot
.22986 .49861 Mdot
.42309 .56717 Mdot
.50539 .56218 Mdot
.59576 .47866 Mdot
.49995 7e-05 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .0024 Mdot
.49435 .00763 Mdot
.48201 .02428 Mdot
.44273 .07623 Mdot
.31938 .20998 Mdot
.97962 .19114 Mdot
.67035 .06169 Mdot
.57053 .61645 Mdot
.57309 .55105 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48972 .01388 Mdot
.46725 .04403 Mdot
.39602 .13371 Mdot
.17967 .26708 Mdot
.74752 .11956 Mdot
.55408 .07038 Mdot
.4402 .12452 Mdot
.23873 .27169 Mdot
.79912 .13112 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00216 Mdot
.49492 .00687 Mdot
.4838 .02186 Mdot
.44843 .06884 Mdot
.33705 .19486 Mdot
.02176 .21497 Mdot
.67393 .08396 Mdot
.53809 .04898 Mdot
.45883 .08672 Mdot
.31852 .2208 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00514 Mdot
.48788 .01636 Mdot
.46141 .05179 Mdot
.37761 .1544 Mdot
.12778 .26054 Mdot
.70622 .11854 Mdot
.51442 .10518 Mdot
.34423 .22761 Mdot
.97595 .2054 Mdot
.6436 .08962 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.4882 .01593 Mdot
.46243 .05043 Mdot
.38083 .15088 Mdot
.13671 .26259 Mdot
.71183 .11927 Mdot
.51885 .10184 Mdot
.35407 .21895 Mdot
.9998 .21877 Mdot
.64583 .10171 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.4899 .01364 Mdot
.46784 .04325 Mdot
.39786 .13157 Mdot
.18499 .26697 Mdot
.75302 .11945 Mdot
.55974 .06536 Mdot
.45399 .10743 Mdot
.28016 .25233 Mdot
.87189 .14598 Mdot
.50063 .61719 Mdot
.502 .61533 Mdot
.50637 .60943 Mdot
.5203 .59066 Mdot
.5646 .5324 Mdot
.70315 .3912 Mdot
.07017 .45417 Mdot
.33531 .58102 Mdot
.3952 .05327 Mdot
.30901 .19079 Mdot
.00031 .19107 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.49808 .00259 Mdot
.4939 .00824 Mdot
.48056 .02622 Mdot
.43814 .08214 Mdot
.30524 .22088 Mdot
.94784 .17339 Mdot
.66729 .04532 Mdot
.59395 .58123 Mdot
.6535 .45998 Mdot
.90923 .38033 Mdot
.50006 .61795 Mdot
.5002 .61776 Mdot
.50064 .61716 Mdot
.50205 .61526 Mdot
.50653 .60921 Mdot
.52081 .58998 Mdot
.56621 .53035 Mdot
.70808 .3879 Mdot
.08045 .45934 Mdot
.33722 .58528 Mdot
.39022 .06114 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50101 .61667 Mdot
.50323 .61367 Mdot
.51028 .60415 Mdot
.53275 .57401 Mdot
.60398 .48432 Mdot
.82033 .35095 Mdot
.25248 .49848 Mdot
.44592 .54765 Mdot
.49984 .00021 Mdot
.49951 .00067 Mdot
.49842 .00213 Mdot
.49498 .00678 Mdot
.48401 .02159 Mdot
.44908 .06799 Mdot
.33907 .19303 Mdot
.02674 .2177 Mdot
.67449 .08645 Mdot
.53461 .05462 Mdot
.44622 .10354 Mdot
.2787 .24869 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00248 Mdot
.49415 .0079 Mdot
.48137 .02514 Mdot
.44069 .07885 Mdot
.31311 .21495 Mdot
.96531 .18304 Mdot
.66914 .05414 Mdot
.58154 .59984 Mdot
.61098 .50509 Mdot
.79373 .36308 Mdot
.50018 .6178 Mdot
.50056 .61728 Mdot
.50178 .61563 Mdot
.50568 .61037 Mdot
.51808 .59364 Mdot
.55755 .54144 Mdot
.68148 .40736 Mdot
.02235 .42801 Mdot
.32981 .55739 Mdot
.42792 .00392 Mdot
.42159 .0737 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00561 Mdot
.48676 .01788 Mdot
.45783 .05651 Mdot
.3664 .16632 Mdot
.09729 .251 Mdot
.69116 .11342 Mdot
.50764 .10634 Mdot
.33558 .23306 Mdot
.95847 .195 Mdot
.64295 .07959 Mdot
.50103 .61664 Mdot
.50329 .61359 Mdot
.51049 .60387 Mdot
.53341 .57313 Mdot
.60606 .48192 Mdot
.8263 .35101 Mdot
.25836 .49835 Mdot
.45201 .54217 Mdot
.57476 .47539 Mdot
.80557 .33674 Mdot
.26071 .48395 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49063 .01266 Mdot
.47015 .04017 Mdot
.40515 .12298 Mdot
.20616 .26497 Mdot
.77744 .11961 Mdot
.58391 .04538 Mdot
.51048 .03567 Mdot
.45278 .0788 Mdot
.32527 .21015 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50993 .60462 Mdot
.53163 .57549 Mdot
.60047 .48842 Mdot
.81019 .3513 Mdot
.24178 .49865 Mdot
.43495 .55728 Mdot
.53325 .52668 Mdot
.68106 .39277 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00437 Mdot
.4897 .0139 Mdot
.46721 .04409 Mdot
.39587 .13388 Mdot
.17926 .26708 Mdot
.7471 .11956 Mdot
.55364 .07077 Mdot
.43914 .12583 Mdot
.23555 .27276 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50172 .61571 Mdot
.50547 .61064 Mdot
.51743 .59452 Mdot
.55548 .54412 Mdot
.67508 .41262 Mdot
.00745 .41952 Mdot
.32865 .54942 Mdot
.43967 .60402 Mdot
.46235 .02057 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49697 .0041 Mdot
.49034 .01305 Mdot
.46923 .04139 Mdot
.40226 .12641 Mdot
.19773 .26607 Mdot
.76722 .11939 Mdot
.57405 .05319 Mdot
.48799 .06431 Mdot
.38393 .16262 Mdot
.1208 .26417 Mdot
.50019 .61777 Mdot
.50062 .6172 Mdot
.50197 .61537 Mdot
.50628 .60955 Mdot
.52 .59106 Mdot
.56364 .53363 Mdot
.70021 .39324 Mdot
.06394 .45093 Mdot
.33431 .57825 Mdot
.39868 .04793 Mdot
.32113 .18098 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49818 .00246 Mdot
.49421 .00782 Mdot
.48155 .02489 Mdot
.44127 .07811 Mdot
.31488 .21357 Mdot
.96933 .1853 Mdot
.6695 .05624 Mdot
.57851 .60441 Mdot
.60056 .51727 Mdot
.7636 .37026 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49678 .00434 Mdot
.48976 .01383 Mdot
.46737 .04387 Mdot
.39639 .13328 Mdot
.18074 .26707 Mdot
.7486 .11953 Mdot
.5552 .06938 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.50252 .61464 Mdot
.50801 .60721 Mdot
.52553 .58365 Mdot
.58117 .51162 Mdot
.75334 .36411 Mdot
.1642 .49073 Mdot
.37018 .59817 Mdot
.40233 .0651 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49029 .01311 Mdot
.46907 .04161 Mdot
.40174 .12702 Mdot
.19622 .26622 Mdot
.76546 .11937 Mdot
.57231 .05462 Mdot
.48394 .06948 Mdot
.37151 .17608 Mdot
.08661 .25246 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49103 .01211 Mdot
.47144 .03844 Mdot
.40924 .11809 Mdot
.21817 .26269 Mdot
.79312 .12053 Mdot
.5981 .03524 Mdot
.54108 .61561 Mdot
.545 .57444 Mdot
.61554 .4765 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00368 Mdot
.49131 .01173 Mdot
.47233 .03725 Mdot
.41206 .1147 Mdot
.22647 .26063 Mdot
.80476 .12174 Mdot
.60779 .02927 Mdot
.56043 .59263 Mdot
.60154 .50475 Mdot
.78484 .36073 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49945 .00074 Mdot
.49826 .00235 Mdot
.49446 .00748 Mdot
.48235 .02381 Mdot
.44383 .0748 Mdot
.3228 .20718 Mdot
.98758 .19568 Mdot
.67097 .06595 Mdot
.56426 .00798 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04863 Mdot
.38512 .14612 Mdot
.14869 .26477 Mdot
.72029 .11979 Mdot
.52647 .09536 Mdot
.37218 .20152 Mdot
.04611 .24367 Mdot
.65184 .12331 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49613 .00523 Mdot
.48768 .01664 Mdot
.46076 .05265 Mdot
.37558 .1566 Mdot
.12219 .25907 Mdot
.703 .11791 Mdot
.51222 .1066 Mdot
.33974 .23131 Mdot
.96547 .19955 Mdot
.6426 .08435 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00217 Mdot
.49489 .00691 Mdot
.48371 .02198 Mdot
.44815 .0692 Mdot
.33619 .19563 Mdot
.01966 .21381 Mdot
.67371 .08289 Mdot
.53959 .04657 Mdot
.46424 .07944 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00335 Mdot
.4921 .01067 Mdot
.47484 .03389 Mdot
.42 .10497 Mdot
.25015 .25252 Mdot
.84157 .12873 Mdot
.63328 .01911 Mdot
.60236 .54866 Mdot
.71461 .40475 Mdot
.05972 .45882 Mdot
.50014 .61784 Mdot
.50045 .61742 Mdot
.50144 .61609 Mdot
.5046 .61183 Mdot
.51464 .59827 Mdot
.54662 .55567 Mdot
.64753 .43766 Mdot
.93938 .38281 Mdot
.31998 .51632 Mdot
.48455 .53063 Mdot
.62597 .42566 Mdot
.50008 .61793 Mdot
.50026 .61769 Mdot
.50081 .61693 Mdot
.50259 .61453 Mdot
.50826 .60687 Mdot
.52632 .58258 Mdot
.58368 .50853 Mdot
.76086 .36133 Mdot
.17622 .4933 Mdot
.37804 .59562 Mdot
.41431 .05324 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46803 .043 Mdot
.39846 .13087 Mdot
.1867 .2669 Mdot
.75485 .11943 Mdot
.56161 .06372 Mdot
.4585 .10176 Mdot
.29385 .24374 Mdot
.89948 .15662 Mdot
.50112 .61652 Mdot
.50358 .6132 Mdot
.51141 .60263 Mdot
.53632 .56925 Mdot
.61526 .4715 Mdot
.85235 .35343 Mdot
.28049 .49827 Mdot
.47427 .52203 Mdot
.62961 .41472 Mdot
.95858 .37675 Mdot
.34898 .49667 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51311 .60033 Mdot
.54176 .56206 Mdot
.63234 .45303 Mdot
.89932 .3658 Mdot
.30745 .50383 Mdot
.49223 .51103 Mdot
.66537 .38385 Mdot
.04428 .42438 Mdot
.35762 .53946 Mdot
.50006 .61795 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50611 .60978 Mdot
.51946 .59179 Mdot
.56192 .53582 Mdot
.69495 .39702 Mdot
.05256 .44486 Mdot
.33276 .5729 Mdot
.40578 .0372 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47747 .03037 Mdot
.42833 .09459 Mdot
.27528 .24028 Mdot
.88651 .14376 Mdot
.65391 .0223 Mdot
.61783 .54081 Mdot
.74278 .39341 Mdot
.10623 .48474 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50732 .60814 Mdot
.52333 .58659 Mdot
.5742 .52027 Mdot
.73239 .37363 Mdot
.12785 .47981 Mdot
.35151 .59835 Mdot
.38336 .07902 Mdot
.25549 .22648 Mdot
.88904 .13175 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49892 .00147 Mdot
.49654 .00467 Mdot
.48899 .01487 Mdot
.46493 .04712 Mdot
.3887 .14209 Mdot
.15879 .26606 Mdot
.72829 .11989 Mdot
.53431 .08833 Mdot
.39139 .18138 Mdot
.09791 .26653 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49038 .01299 Mdot
.46936 .04123 Mdot
.40265 .12595 Mdot
.19885 .26594 Mdot
.76854 .1194 Mdot
.57535 .05213 Mdot
.491 .06046 Mdot
.39317 .15223 Mdot
.14685 .26986 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61173 Mdot
.51486 .59798 Mdot
.54732 .55475 Mdot
.64971 .43555 Mdot
.94498 .38555 Mdot
.32115 .51859 Mdot
.48204 .53521 Mdot
.61606 .4369 Mdot
.90915 .35717 Mdot
.50035 .61756 Mdot
.50111 .61654 Mdot
.50353 .61327 Mdot
.51124 .60285 Mdot
.53581 .56994 Mdot
.61362 .47333 Mdot
.84777 .35275 Mdot
.277 .49818 Mdot
.47092 .52499 Mdot
.62147 .423 Mdot
.93704 .36615 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52557 .58359 Mdot
.58131 .51144 Mdot
.75378 .36394 Mdot
.16492 .4909 Mdot
.37063 .59805 Mdot
.40296 .06451 Mdot
.29858 .20523 Mdot
.96651 .17441 Mdot
.50095 .61675 Mdot
.50302 .61395 Mdot
.50962 .60504 Mdot
.53066 .57679 Mdot
.59739 .49203 Mdot
.80127 .35208 Mdot
.2316 .49864 Mdot
.42479 .56579 Mdot
.50931 .55717 Mdot
.6078 .4647 Mdot
.8559 .34863 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49734 .00359 Mdot
.49153 .01144 Mdot
.47301 .03634 Mdot
.4142 .11208 Mdot
.23285 .25877 Mdot
.81414 .12305 Mdot
.61504 .02545 Mdot
.57387 .57743 Mdot
.63957 .464 Mdot
.88881 .3691 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49664 .00454 Mdot
.48929 .01447 Mdot
.46587 .04586 Mdot
.39166 .13872 Mdot
.16721 .26675 Mdot
.73561 .11981 Mdot
.54175 .08154 Mdot
.40982 .16074 Mdot
.14973 .27996 Mdot
.69675 .1406 Mdot
.50042 .61746 Mdot
.50134 .61622 Mdot
.50429 .61224 Mdot
.51365 .5996 Mdot
.54347 .5598 Mdot
.63769 .4475 Mdot
.91363 .3713 Mdot
.31286 .50748 Mdot
.49173 .51514 Mdot
.65821 .39146 Mdot
.02481 .41437 Mdot
.50051 .61735 Mdot
.50161 .61586 Mdot
.50514 .6111 Mdot
.51636 .59595 Mdot
.55209 .54852 Mdot
.66458 .42172 Mdot
.98222 .40527 Mdot
.32648 .53611 Mdot
.45904 .57366 Mdot
.53084 .54525 Mdot
.6486 .42665 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00561 Mdot
.48676 .01787 Mdot
.45784 .05651 Mdot
.36641 .16631 Mdot
.09731 .25101 Mdot
.69117 .11343 Mdot
.50764 .10635 Mdot
.33557 .23308 Mdot
.95845 .19499 Mdot
.64295 .07958 Mdot
.50032 .6176 Mdot
.50103 .61664 Mdot
.50328 .6136 Mdot
.51047 .6039 Mdot
.53333 .57322 Mdot
.60584 .48218 Mdot
.82565 .35099 Mdot
.25773 .49836 Mdot
.45136 .54275 Mdot
.57317 .47729 Mdot
.8009 .33722 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50701 .60857 Mdot
.52232 .58794 Mdot
.57101 .52428 Mdot
.72271 .3789 Mdot
.10963 .47269 Mdot
.34481 .59482 Mdot
.38238 .07616 Mdot
.25915 .22346 Mdot
.50039 .6175 Mdot
.50126 .61634 Mdot
.504 .61262 Mdot
.51276 .60081 Mdot
.54063 .56355 Mdot
.62878 .45677 Mdot
.88971 .36252 Mdot
.30315 .50191 Mdot
.49104 .51022 Mdot
.66549 .38299 Mdot
.0458 .42487 Mdot
.50018 .61779 Mdot
.50057 .61726 Mdot
.50182 .61558 Mdot
.50579 .61021 Mdot
.51845 .59314 Mdot
.55872 .53993 Mdot
.6851 .40448 Mdot
.03064 .43271 Mdot
.3305 .56178 Mdot
.42152 .01358 Mdot
.39955 .10065 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49276 .00978 Mdot
.47694 .03107 Mdot
.42667 .09668 Mdot
.27023 .24303 Mdot
.877 .14002 Mdot
.65044 .02042 Mdot
.6174 .53922 Mdot
.74493 .39175 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00538 Mdot
.4873 .01714 Mdot
.45957 .05422 Mdot
.37183 .16061 Mdot
.11195 .25605 Mdot
.69766 .11641 Mdot
.5093 .1078 Mdot
.33488 .23485 Mdot
.95489 .19359 Mdot
.64166 .07893 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49678 .00435 Mdot
.48974 .01386 Mdot
.46731 .04395 Mdot
.39619 .13351 Mdot
.18017 .26708 Mdot
.74803 .11954 Mdot
.5546 .06991 Mdot
.44149 .12294 Mdot
.24256 .27033 Mdot
.80517 .13156 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00216 Mdot
.49491 .00688 Mdot
.48378 .02189 Mdot
.44835 .06894 Mdot
.3368 .19508 Mdot
.02115 .21463 Mdot
.67387 .08365 Mdot
.53852 .04828 Mdot
.4604 .08462 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00306 Mdot
.49279 .00973 Mdot
.47704 .03094 Mdot
.42697 .09629 Mdot
.27117 .24254 Mdot
.87874 .14068 Mdot
.65111 .02072 Mdot
.49962 .00052 Mdot
.49878 .00164 Mdot
.49612 .00524 Mdot
.48764 .01669 Mdot
.46064 .0528 Mdot
.37521 .15699 Mdot
.1212 .2588 Mdot
.70245 .11779 Mdot
.51187 .10679 Mdot
.33907 .23183 Mdot
.96396 .19871 Mdot
.64245 .08359 Mdot
.50026 .61769 Mdot
.50081 .61694 Mdot
.50259 .61454 Mdot
.50825 .60689 Mdot
.52627 .58265 Mdot
.58353 .50871 Mdot
.76042 .36148 Mdot
.17553 .49317 Mdot
.37757 .5958 Mdot
.41354 .05404 Mdot
.3261 .18503 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.4975 .00338 Mdot
.49202 .01078 Mdot
.47458 .03424 Mdot
.41917 .106 Mdot
.24766 .25353 Mdot
.83745 .1277 Mdot
.63083 .01962 Mdot
.59908 .55162 Mdot
.70654 .40954 Mdot
.04388 .44971 Mdot
.50058 .61725 Mdot
.50185 .61553 Mdot
.50591 .61005 Mdot
.51882 .59264 Mdot
.5599 .53841 Mdot
.68873 .40167 Mdot
.03882 .4373 Mdot
.33125 .56603 Mdot
.4154 .02278 Mdot
.37853 .12477 Mdot
.17664 .25692 Mdot
.50045 .61743 Mdot
.50143 .6161 Mdot
.50455 .61188 Mdot
.5145 .59846 Mdot
.54617 .55626 Mdot
.64613 .43903 Mdot
.93576 .38108 Mdot
.31915 .51492 Mdot
.486 .52788 Mdot
.63187 .41915 Mdot
.95368 .37681 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00536 Mdot
.48737 .01705 Mdot
.45978 .05394 Mdot
.3725 .15989 Mdot
.11379 .25662 Mdot
.69857 .11672 Mdot
.50972 .10771 Mdot
.33543 .23451 Mdot
.50008 .61793 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50822 .60694 Mdot
.52617 .58278 Mdot
.58321 .50911 Mdot
.75946 .36182 Mdot
.17402 .49287 Mdot
.37654 .59619 Mdot
.41189 .05573 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49652 .0047 Mdot
.48893 .01495 Mdot
.46473 .04739 Mdot
.38806 .14281 Mdot
.15698 .26587 Mdot
.7268 .11989 Mdot
.53282 .08968 Mdot
.38771 .18536 Mdot
.08779 .26268 Mdot
.66277 .13675 Mdot
.50098 .61671 Mdot
.50313 .6138 Mdot
.50998 .60456 Mdot
.53178 .57529 Mdot
.60093 .48787 Mdot
.81155 .35122 Mdot
.24326 .49863 Mdot
.43646 .55599 Mdot
.53685 .52213 Mdot
.69202 .38427 Mdot
.07026 .44731 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50258 .61454 Mdot
.50824 .60691 Mdot
.52623 .5827 Mdot
.58341 .50887 Mdot
.76004 .36162 Mdot
.17493 .49305 Mdot
.37715 .59596 Mdot
.41287 .05472 Mdot
.32433 .18647 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.48671 .01794 Mdot
.45767 .05672 Mdot
.3659 .16685 Mdot
.09593 .25049 Mdot
.69063 .1131 Mdot
.50763 .10602 Mdot
.33609 .2325 Mdot
.95989 .19571 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.5417 .56214 Mdot
.63213 .45324 Mdot
.89876 .3656 Mdot
.30722 .50371 Mdot
.4922 .51094 Mdot
.66549 .38371 Mdot
.04463 .42454 Mdot
.3577 .53957 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49756 .00329 Mdot
.49224 .01048 Mdot
.47528 .03331 Mdot
.42138 .10327 Mdot
.25428 .25076 Mdot
.84853 .1306 Mdot
.63721 .01858 Mdot
.60714 .54462 Mdot
.72593 .39876 Mdot
.08071 .47042 Mdot
.50107 .61658 Mdot
.50342 .61341 Mdot
.5109 .60331 Mdot
.53472 .57138 Mdot
.61022 .47717 Mdot
.83814 .35168 Mdot
.26911 .49816 Mdot
.46306 .5321 Mdot
.60212 .44379 Mdot
.88404 .34556 Mdot
.32492 .47705 Mdot
.49986 .00018 Mdot
.49957 .00058 Mdot
.49862 .00186 Mdot
.49561 .00592 Mdot
.48603 .01886 Mdot
.45551 .05957 Mdot
.35913 .17377 Mdot
.07797 .24319 Mdot
.68448 .10797 Mdot
.50977 .09892 Mdot
.34971 .21844 Mdot
.99626 .21498 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49886 .00155 Mdot
.49636 .00492 Mdot
.48839 .01568 Mdot
.46302 .04965 Mdot
.38268 .14883 Mdot
.14186 .26361 Mdot
.71533 .11955 Mdot
.52189 .09932 Mdot
.36119 .2123 Mdot
.01769 .22866 Mdot
.50034 .61757 Mdot
.5011 .61655 Mdot
.50349 .61331 Mdot
.51113 .603 Mdot
.53545 .57041 Mdot
.6125 .47459 Mdot
.84461 .35235 Mdot
.27449 .49815 Mdot
.46847 .5272 Mdot
.61545 .42931 Mdot
.9208 .35889 Mdot
.4998 .00027 Mdot
.49935 .00087 Mdot
.49794 .00278 Mdot
.49344 .00886 Mdot
.47911 .02816 Mdot
.43355 .08799 Mdot
.29117 .23063 Mdot
.918 .15793 Mdot
.66246 .03215 Mdot
.61045 .55582 Mdot
.71112 .41265 Mdot
.04343 .45242 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.5231 .5869 Mdot
.57347 .52118 Mdot
.73019 .37478 Mdot
.12378 .47831 Mdot
.34987 .59775 Mdot
.38269 .07888 Mdot
.25507 .22635 Mdot
.88883 .13146 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51208 .60172 Mdot
.53847 .5664 Mdot
.62201 .46405 Mdot
.87117 .35724 Mdot
.29315 .49939 Mdot
.48511 .51318 Mdot
.65478 .39126 Mdot
.0217 .41132 Mdot
.35618 .52723 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61434 Mdot
.50872 .60626 Mdot
.52778 .58064 Mdot
.58828 .50293 Mdot
.77453 .35713 Mdot
.19668 .49647 Mdot
.39337 .5881 Mdot
.44181 .02282 Mdot
.40489 .10584 Mdot
.4997 .00041 Mdot
.49904 .0013 Mdot
.49694 .00413 Mdot
.49025 .01316 Mdot
.46896 .04176 Mdot
.40139 .12744 Mdot
.19518 .26632 Mdot
.76427 .11937 Mdot
.57113 .0556 Mdot
.48116 .07303 Mdot
.36299 .18493 Mdot
.06377 .24248 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49855 .00195 Mdot
.4954 .00622 Mdot
.48533 .0198 Mdot
.45329 .06249 Mdot
.35219 .18065 Mdot
.05989 .23487 Mdot
.67986 .10142 Mdot
.51576 .08683 Mdot
.37527 .19098 Mdot
.06625 .25064 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00495 Mdot
.48832 .01577 Mdot
.46281 .04993 Mdot
.38203 .14955 Mdot
.14006 .26327 Mdot
.71408 .11946 Mdot
.52079 .10025 Mdot
.35859 .21476 Mdot
.50016 .61782 Mdot
.50052 .61734 Mdot
.50164 .61582 Mdot
.50523 .61097 Mdot
.51666 .59555 Mdot
.55303 .5473 Mdot
.66749 .41914 Mdot
.9893 .40923 Mdot
.32715 .53978 Mdot
.45378 .58203 Mdot
.51203 .57088 Mdot
.50011 .61789 Mdot
.50035 .61756 Mdot
.50112 .61652 Mdot
.50356 .61322 Mdot
.51136 .6027 Mdot
.53617 .56946 Mdot
.61477 .47205 Mdot
.85098 .35322 Mdot
.27946 .49824 Mdot
.47329 .52288 Mdot
.62726 .41708 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48992 .01361 Mdot
.4679 .04317 Mdot
.39805 .13135 Mdot
.18552 .26695 Mdot
.75359 .11944 Mdot
.56032 .06485 Mdot
.45539 .10567 Mdot
.28442 .24977 Mdot
.88028 .14896 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.5064 .60939 Mdot
.52038 .59056 Mdot
.56483 .5321 Mdot
.70388 .39071 Mdot
.0717 .45495 Mdot
.33557 .58168 Mdot
.3944 .05451 Mdot
.30619 .19296 Mdot
.99398 .18738 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51054 .6038 Mdot
.53358 .57289 Mdot
.60662 .48128 Mdot
.82789 .35106 Mdot
.25987 .49832 Mdot
.45357 .54075 Mdot
.57862 .47079 Mdot
.81687 .33608 Mdot
.27308 .48207 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49652 .0047 Mdot
.48891 .01498 Mdot
.46468 .04746 Mdot
.38789 .143 Mdot
.15651 .26581 Mdot
.72641 .11989 Mdot
.53243 .09003 Mdot
.38676 .18637 Mdot
.08521 .26165 Mdot
.66186 .13615 Mdot
.50025 .61769 Mdot
.50081 .61695 Mdot
.50257 .61457 Mdot
.50818 .60699 Mdot
.52604 .58296 Mdot
.5828 .50961 Mdot
.75824 .36226 Mdot
.17208 .49248 Mdot
.37524 .59665 Mdot
.40984 .0578 Mdot
.31632 .19272 Mdot
.5004 .6175 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60076 Mdot
.54075 .56339 Mdot
.62916 .45637 Mdot
.89073 .36285 Mdot
.30363 .5021 Mdot
.49122 .51023 Mdot
.66566 .38292 Mdot
.04609 .42505 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49595 .00546 Mdot
.48711 .0174 Mdot
.45896 .05502 Mdot
.36993 .16263 Mdot
.10679 .25437 Mdot
.69522 .11547 Mdot
.50838 .10771 Mdot
.33411 .23512 Mdot
.95367 .19278 Mdot
.64175 .07806 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49775 .00304 Mdot
.49282 .0097 Mdot
.47713 .03083 Mdot
.42725 .09595 Mdot
.27199 .24209 Mdot
.88029 .14128 Mdot
.65169 .021 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00907 Mdot
.4786 .02885 Mdot
.43193 .09005 Mdot
.28623 .23378 Mdot
.90796 .15313 Mdot
.66018 .02847 Mdot
.61412 .54955 Mdot
.72493 .40383 Mdot
.07153 .46793 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50438 .61212 Mdot
.51394 .59921 Mdot
.54439 .55859 Mdot
.64058 .44456 Mdot
.92126 .37451 Mdot
.31529 .50981 Mdot
.4904 .5187 Mdot
.65113 .39872 Mdot
.00598 .40426 Mdot
.50082 .61693 Mdot
.50261 .6145 Mdot
.50833 .60679 Mdot
.52653 .58231 Mdot
.58433 .50773 Mdot
.7628 .36067 Mdot
.17923 .49386 Mdot
.38014 .59477 Mdot
.41779 .04961 Mdot
.33752 .1754 Mdot
.05371 .22426 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60801 Mdot
.52364 .58617 Mdot
.5752 .51902 Mdot
.73541 .37209 Mdot
.13335 .48175 Mdot
.35386 .59898 Mdot
.38469 .07873 Mdot
.2573 .22612 Mdot
.5011 .61655 Mdot
.50349 .61332 Mdot
.51112 .60301 Mdot
.53543 .57044 Mdot
.61243 .47467 Mdot
.8444 .35233 Mdot
.27432 .49815 Mdot
.4683 .52735 Mdot
.61503 .42975 Mdot
.91968 .35841 Mdot
.33976 .48311 Mdot
.49983 .00023 Mdot
.49946 .00072 Mdot
.49829 .0023 Mdot
.49457 .00734 Mdot
.48269 .02336 Mdot
.4449 .07342 Mdot
.32609 .20442 Mdot
.99533 .2001 Mdot
.67157 .07011 Mdot
.55813 .0174 Mdot
.52998 .60781 Mdot
.54652 .5653 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00366 Mdot
.49138 .01164 Mdot
.47254 .03697 Mdot
.41272 .11389 Mdot
.22845 .26008 Mdot
.80763 .1221 Mdot
.61006 .02801 Mdot
.56474 .58767 Mdot
.61386 .49089 Mdot
.81958 .35723 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49857 .00194 Mdot
.49543 .00617 Mdot
.48544 .01965 Mdot
.45366 .06201 Mdot
.35333 .17953 Mdot
.06284 .23629 Mdot
.68052 .10258 Mdot
.51455 .08911 Mdot
.37036 .19644 Mdot
.05252 .24425 Mdot
.4997 .0004 Mdot
.49906 .00128 Mdot
.49699 .00406 Mdot
.49042 .01294 Mdot
.46948 .04106 Mdot
.40304 .12549 Mdot
.2 .26581 Mdot
.76991 .11942 Mdot
.57668 .05105 Mdot
.49408 .05653 Mdot
.40261 .14129 Mdot
.174 .27233 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49873 .00172 Mdot
.49594 .00549 Mdot
.48706 .01747 Mdot
.4588 .05523 Mdot
.36944 .16314 Mdot
.10546 .25391 Mdot
.69462 .11521 Mdot
.5082 .10761 Mdot
.33409 .23504 Mdot
.95379 .1928 Mdot
.50021 .61775 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52129 .58933 Mdot
.56773 .52842 Mdot
.71274 .3849 Mdot
.08996 .46392 Mdot
.33931 .58884 Mdot
.38655 .06729 Mdot
.27767 .21262 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00351 Mdot
.49172 .01118 Mdot
.47364 .03551 Mdot
.41619 .10966 Mdot
.23875 .25684 Mdot
.82317 .12462 Mdot
.62154 .02258 Mdot
.585 .56551 Mdot
.67 .43621 Mdot
.96419 .40329 Mdot
.50084 .61691 Mdot
.50266 .61444 Mdot
.50848 .60658 Mdot
.527 .58167 Mdot
.58584 .5059 Mdot
.76728 .35922 Mdot
.18604 .49501 Mdot
.38509 .59252 Mdot
.42638 .04033 Mdot
.36112 .15335 Mdot
.11299 .24952 Mdot
.50104 .61663 Mdot
.50331 .61356 Mdot
.51054 .6038 Mdot
.53358 .57289 Mdot
.60662 .48128 Mdot
.82789 .35106 Mdot
.25987 .49832 Mdot
.45358 .54075 Mdot
.57863 .47079 Mdot
.81688 .33608 Mdot
.2731 .48207 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.487 .01755 Mdot
.45861 .05549 Mdot
.36883 .16378 Mdot
.10383 .25335 Mdot
.6939 .11488 Mdot
.50802 .10745 Mdot
.33416 .23484 Mdot
.95419 .19295 Mdot
.64198 .0781 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51293 .60057 Mdot
.54118 .56282 Mdot
.63052 .45493 Mdot
.89443 .36408 Mdot
.30533 .5028 Mdot
.49178 .51042 Mdot
.66591 .38299 Mdot
.04623 .42524 Mdot
.5005 .61735 Mdot
.5016 .61587 Mdot
.5051 .61114 Mdot
.51625 .5961 Mdot
.55174 .54897 Mdot
.66348 .4227 Mdot
.97954 .40378 Mdot
.3262 .53474 Mdot
.46098 .57055 Mdot
.53782 .53582 Mdot
.67084 .40615 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00395 Mdot
.49069 .01257 Mdot
.47036 .03989 Mdot
.40582 .1222 Mdot
.2081 .26466 Mdot
.77988 .1197 Mdot
.58619 .04365 Mdot
.51557 .02924 Mdot
.46826 .05846 Mdot
.37367 .16366 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.48991 .01362 Mdot
.46787 .04321 Mdot
.39796 .13145 Mdot
.18527 .26696 Mdot
.75331 .11945 Mdot
.56004 .0651 Mdot
.45472 .10651 Mdot
.28238 .25101 Mdot
.87623 .14749 Mdot
.50017 .61781 Mdot
.50053 .61731 Mdot
.5017 .61574 Mdot
.5054 .61073 Mdot
.51722 .5948 Mdot
.55481 .54498 Mdot
.67301 .41437 Mdot
.00254 .41673 Mdot
.32826 .54679 Mdot
.44354 .59804 Mdot
.47589 .00228 Mdot
.49966 .00046 Mdot
.49892 .00145 Mdot
.49657 .00463 Mdot
.48908 .01474 Mdot
.46523 .04673 Mdot
.38962 .14104 Mdot
.16141 .26631 Mdot
.7305 .11988 Mdot
.53654 .0863 Mdot
.39691 .17533 Mdot
.11322 .27166 Mdot
.67367 .14076 Mdot
.50001 .61802 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50134 .61623 Mdot
.50426 .61228 Mdot
.51358 .59971 Mdot
.54323 .56012 Mdot
.63694 .44827 Mdot
.91162 .37048 Mdot
.31217 .50691 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01439 Mdot
.46607 .0456 Mdot
.39228 .13802 Mdot
.16896 .26685 Mdot
.7372 .11978 Mdot
.5434 .08004 Mdot
.41388 .15604 Mdot
.1614 .28131 Mdot
.70623 .13931 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01558 Mdot
.46326 .04933 Mdot
.38344 .14799 Mdot
.144 .264 Mdot
.71684 .11964 Mdot
.52326 .09816 Mdot
.36444 .20917 Mdot
.02599 .23316 Mdot
.64873 .11449 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60554 Mdot
.52947 .57838 Mdot
.59364 .49649 Mdot
.7903 .35365 Mdot
.21808 .49824 Mdot
.41191 .57579 Mdot
.48026 .59405 Mdot
.51906 .57643 Mdot
.58638 .50022 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.50921 .6056 Mdot
.52934 .57855 Mdot
.59322 .49699 Mdot
.78906 .35387 Mdot
.21649 .49816 Mdot
.41045 .57686 Mdot
.47707 .59805 Mdot
.50941 .58932 Mdot
.55587 .53859 Mdot
.49983 .00023 Mdot
.49946 .00074 Mdot
.49827 .00234 Mdot
.49447 .00747 Mdot
.48239 .02376 Mdot
.44395 .07465 Mdot
.32316 .20688 Mdot
.98842 .19615 Mdot
.67103 .0664 Mdot
.5636 .009 Mdot
.54903 .5823 Mdot
.60685 .49052 Mdot
.49999 2e-05 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49583 .00564 Mdot
.4867 .01795 Mdot
.45765 .05675 Mdot
.36583 .16691 Mdot
.09577 .25043 Mdot
.69056 .11306 Mdot
.50764 .10598 Mdot
.50114 .61649 Mdot
.50364 .61312 Mdot
.51158 .60239 Mdot
.53689 .5685 Mdot
.61703 .46953 Mdot
.85731 .35427 Mdot
.28409 .49845 Mdot
.47758 .51916 Mdot
.63757 .40692 Mdot
.97916 .38766 Mdot
.35192 .50597 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50119 .61643 Mdot
.50379 .61291 Mdot
.51207 .60173 Mdot
.53845 .56644 Mdot
.62193 .46414 Mdot
.87094 .35718 Mdot
.29301 .49937 Mdot
.48501 .51325 Mdot
.65455 .39145 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49675 .00439 Mdot
.48964 .01399 Mdot
.467 .04437 Mdot
.39521 .13464 Mdot
.17735 .26708 Mdot
.7452 .11961 Mdot
.55168 .07253 Mdot
.43432 .13171 Mdot
.2212 .27685 Mdot
.77326 .13087 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49708 .00394 Mdot
.4907 .01256 Mdot
.47039 .03985 Mdot
.40591 .12208 Mdot
.20838 .26461 Mdot
.78023 .11972 Mdot
.58652 .0434 Mdot
.51629 .02833 Mdot
.47045 .05557 Mdot
.38054 .1562 Mdot
.50076 .61701 Mdot
.50242 .61476 Mdot
.50771 .60762 Mdot
.52456 .58494 Mdot
.57811 .5154 Mdot
.74417 .36796 Mdot
.1488 .48667 Mdot
.36136 .59955 Mdot
.39127 .07465 Mdot
.27049 .22097 Mdot
.91296 .14424 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.4918 .01108 Mdot
.47387 .0352 Mdot
.41691 .10878 Mdot
.2409 .25608 Mdot
.82655 .12528 Mdot
.62385 .02171 Mdot
.58873 .56168 Mdot
.67991 .42821 Mdot
.98704 .41622 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.501 .61669 Mdot
.50317 .61375 Mdot
.5101 .60439 Mdot
.53218 .57476 Mdot
.6022 .48639 Mdot
.8152 .35106 Mdot
.24718 .49858 Mdot
.44047 .55249 Mdot
.54652 .50998 Mdot
.50122 .61638 Mdot
.5039 .61276 Mdot
.51243 .60125 Mdot
.53959 .56492 Mdot
.62554 .46024 Mdot
.88086 .35982 Mdot
.29866 .50052 Mdot
.4888 .51089 Mdot
.66217 .38525 Mdot
.03883 .42089 Mdot
.35782 .53585 Mdot
.50125 .61635 Mdot
.50398 .61265 Mdot
.51269 .60091 Mdot
.5404 .56385 Mdot
.62807 .45753 Mdot
.88777 .3619 Mdot
.30221 .50158 Mdot
.49064 .51025 Mdot
.66504 .38323 Mdot
.04497 .42436 Mdot
.35833 .53903 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49834 .00225 Mdot
.49471 .00715 Mdot
.48313 .02276 Mdot
.44631 .07159 Mdot
.33047 .20068 Mdot
.00576 .20602 Mdot
.67242 .07566 Mdot
.54999 .03008 Mdot
.50133 .02884 Mdot
.45466 .07031 Mdot
.50005 .61796 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50172 .61571 Mdot
.50547 .61064 Mdot
.51743 .59451 Mdot
.55549 .5441 Mdot
.67512 .41259 Mdot
.00754 .41957 Mdot
.32865 .54946 Mdot
.4396 .60412 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.49841 .00215 Mdot
.49492 .00686 Mdot
.48382 .02184 Mdot
.44848 .06877 Mdot
.3372 .19472 Mdot
.02214 .21518 Mdot
.67397 .08415 Mdot
.53782 .04942 Mdot
.45786 .08802 Mdot
.31544 .22327 Mdot
.49982 .00025 Mdot
.49942 .00078 Mdot
.49816 .00249 Mdot
.49413 .00793 Mdot
.48131 .02522 Mdot
.4405 .0791 Mdot
.31251 .21541 Mdot
.96397 .18229 Mdot
.66901 .05344 Mdot
.58254 .59834 Mdot
.61441 .50118 Mdot
.80349 .36189 Mdot
.49971 .00039 Mdot
.49907 .00126 Mdot
.49704 .004 Mdot
.49056 .01275 Mdot
.46992 .04047 Mdot
.40445 .12382 Mdot
.2041 .26527 Mdot
.77487 .11953 Mdot
.58148 .04725 Mdot
.50502 .0426 Mdot
.4361 .10026 Mdot
.27387 .24615 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00382 Mdot
.49099 .01217 Mdot
.4713 .03863 Mdot
.40881 .11862 Mdot
.21688 .26298 Mdot
.79137 .12039 Mdot
.59658 .03625 Mdot
.53792 .00143 Mdot
.53561 .58673 Mdot
.50066 .61715 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52127 .58935 Mdot
.56769 .52848 Mdot
.71259 .38499 Mdot
.08967 .46379 Mdot
.33924 .58874 Mdot
.38665 .06712 Mdot
.27804 .21238 Mdot
.9344 .15327 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47323 .03605 Mdot
.4149 .11124 Mdot
.23492 .25812 Mdot
.81727 .12356 Mdot
.61735 .02436 Mdot
.57793 .573 Mdot
.65079 .45321 Mdot
.91749 .38009 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51236 .60134 Mdot
.53937 .56522 Mdot
.62483 .461 Mdot
.87892 .35927 Mdot
.29761 .50026 Mdot
.48817 .51122 Mdot
.66101 .38614 Mdot
.03621 .41943 Mdot
.49983 .00024 Mdot
.49945 .00075 Mdot
.49823 .00239 Mdot
.49437 .0076 Mdot
.48207 .02419 Mdot
.44293 .07597 Mdot
.32001 .20947 Mdot
.98109 .19198 Mdot
.67047 .06247 Mdot
.56938 .00017 Mdot
.5691 .55614 Mdot
.66926 .42718 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50476 .6116 Mdot
.51516 .59757 Mdot
.54828 .55349 Mdot
.65271 .43267 Mdot
.95263 .3894 Mdot
.32256 .52187 Mdot
.47815 .54206 Mdot
.60108 .45453 Mdot
.86562 .34424 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00568 Mdot
.48661 .01807 Mdot
.45738 .05711 Mdot
.36497 .16781 Mdot
.09345 .24955 Mdot
.68967 .11247 Mdot
.50769 .10535 Mdot
.33722 .23129 Mdot
.96299 .19728 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60706 Mdot
.52588 .58317 Mdot
.58229 .51024 Mdot
.75669 .36283 Mdot
.16962 .49196 Mdot
.37362 .59718 Mdot
.40736 .06027 Mdot
.30984 .1975 Mdot
.99028 .1885 Mdot
.50132 .61626 Mdot
.50419 .61237 Mdot
.51335 .60001 Mdot
.54252 .56106 Mdot
.63471 .45056 Mdot
.90569 .36816 Mdot
.31 .50534 Mdot
.49234 .51244 Mdot
.6632 .3863 Mdot
.03815 .42133 Mdot
.35642 .5371 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00351 Mdot
.49172 .01119 Mdot
.47361 .03554 Mdot
.41611 .10975 Mdot
.23853 .25692 Mdot
.82283 .12455 Mdot
.6213 .02267 Mdot
.58461 .56591 Mdot
.66896 .43708 Mdot
.96174 .40195 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49767 .00315 Mdot
.49258 .01003 Mdot
.47636 .03186 Mdot
.4248 .09902 Mdot
.26459 .24594 Mdot
.86664 .13628 Mdot
.64614 .01905 Mdot
.61531 .5393 Mdot
.7427 .39191 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49795 .00276 Mdot
.49348 .00881 Mdot
.47923 .028 Mdot
.43392 .08752 Mdot
.29232 .22988 Mdot
.92037 .1591 Mdot
.66295 .03308 Mdot
.60942 .55748 Mdot
.70741 .41518 Mdot
.03563 .44794 Mdot
.50101 .61667 Mdot
.50322 .61368 Mdot
.51026 .60418 Mdot
.53268 .57409 Mdot
.60378 .48456 Mdot
.81974 .35096 Mdot
.25189 .49849 Mdot
.44531 .5482 Mdot
.5583 .49535 Mdot
.75681 .34794 Mdot
.19384 .48639 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.4961 .00528 Mdot
.48756 .0168 Mdot
.46038 .05315 Mdot
.37439 .15787 Mdot
.11895 .25816 Mdot
.70123 .11749 Mdot
.51113 .10718 Mdot
.33772 .23287 Mdot
.96093 .19701 Mdot
.64216 .08206 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61342 Mdot
.51088 .60334 Mdot
.53465 .57148 Mdot
.60997 .47745 Mdot
.83745 .35162 Mdot
.26851 .49817 Mdot
.46246 .53264 Mdot
.60063 .44545 Mdot
.87987 .34436 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.49631 .00499 Mdot
.48823 .01589 Mdot
.46252 .05031 Mdot
.38111 .15056 Mdot
.13749 .26275 Mdot
.71235 .11932 Mdot
.51929 .10148 Mdot
.35509 .21801 Mdot
.00234 .22018 Mdot
.64608 .10299 Mdot
.49987 .00017 Mdot
.49959 .00056 Mdot
.49869 .00178 Mdot
.49581 .00566 Mdot
.48666 .01802 Mdot
.4575 .05694 Mdot
.36537 .16739 Mdot
.09452 .24996 Mdot
.69008 .11275 Mdot
.50765 .10565 Mdot
.3367 .23184 Mdot
.96158 .19657 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48858 .01542 Mdot
.46363 .04884 Mdot
.3846 .1467 Mdot
.14723 .26454 Mdot
.7192 .11975 Mdot
.52544 .09626 Mdot
.36969 .20402 Mdot
.03958 .24033 Mdot
.65071 .12058 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61239 Mdot
.51332 .60005 Mdot
.54242 .56119 Mdot
.63439 .45089 Mdot
.90483 .36783 Mdot
.30967 .50513 Mdot
.49236 .51221 Mdot
.66359 .38588 Mdot
.03922 .42187 Mdot
.50069 .61711 Mdot
.50219 .61507 Mdot
.50698 .60861 Mdot
.52223 .58806 Mdot
.57073 .52463 Mdot
.72187 .37938 Mdot
.10802 .47201 Mdot
.3443 .5944 Mdot
.38253 .07565 Mdot
.26013 .22289 Mdot
.89948 .13578 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50873 .60625 Mdot
.5278 .58061 Mdot
.58835 .50285 Mdot
.77473 .35708 Mdot
.19696 .49651 Mdot
.3936 .58796 Mdot
.44225 .0223 Mdot
.40618 .10432 Mdot
.23737 .25141 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.50711 .60842 Mdot
.52266 .58749 Mdot
.57209 .52292 Mdot
.72598 .37705 Mdot
.1159 .47525 Mdot
.34693 .59627 Mdot
.38215 .07777 Mdot
.25631 .2252 Mdot
.89193 .13254 Mdot
.49989 .00014 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.4966 .0046 Mdot
.48915 .01465 Mdot
.46545 .04643 Mdot
.39032 .14025 Mdot
.1634 .26648 Mdot
.73222 .11986 Mdot
.53829 .0847 Mdot
.40124 .1705 Mdot
.12536 .27507 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50297 .61402 Mdot
.50946 .60526 Mdot
.53012 .57751 Mdot
.59568 .49405 Mdot
.79629 .35271 Mdot
.2256 .49852 Mdot
.41898 .57043 Mdot
.496 .57414 Mdot
.56703 .51382 Mdot
.49994 8e-05 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49395 .00818 Mdot
.48071 .02602 Mdot
.43862 .08152 Mdot
.30672 .21979 Mdot
.95109 .17516 Mdot
.66767 .04692 Mdot
.59176 .58451 Mdot
.646 .46737 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00552 Mdot
.48698 .01757 Mdot
.45855 .05557 Mdot
.36863 .16399 Mdot
.10328 .25316 Mdot
.69366 .11476 Mdot
.50797 .10738 Mdot
.33422 .23475 Mdot
.95438 .19304 Mdot
.64204 .07815 Mdot
.49974 .00035 Mdot
.49917 .00113 Mdot
.49735 .00359 Mdot
.49154 .01142 Mdot
.47307 .03627 Mdot
.41438 .11187 Mdot
.23337 .25861 Mdot
.81493 .12317 Mdot
.61563 .02516 Mdot
.57491 .57629 Mdot
.64246 .46116 Mdot
.89628 .37167 Mdot
.50124 .61636 Mdot
.50394 .61272 Mdot
.51254 .6011 Mdot
.53994 .56446 Mdot
.62661 .45908 Mdot
.8838 .36068 Mdot
.30021 .50094 Mdot
.48967 .51051 Mdot
.66364 .38416 Mdot
.04205 .4227 Mdot
.35812 .53749 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49027 .01314 Mdot
.46902 .04167 Mdot
.40159 .1272 Mdot
.19577 .26627 Mdot
.76494 .11937 Mdot
.5718 .05504 Mdot
.48274 .07102 Mdot
.36783 .17994 Mdot
.07668 .24831 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00183 Mdot
.49568 .00584 Mdot
.48622 .0186 Mdot
.45614 .05875 Mdot
.36108 .17179 Mdot
.08311 .24539 Mdot
.68607 .10959 Mdot
.50875 .10148 Mdot
.34455 .22375 Mdot
.98252 .20757 Mdot
.50091 .61681 Mdot
.50289 .61413 Mdot
.5092 .60561 Mdot
.5293 .5786 Mdot
.59312 .49711 Mdot
.78877 .35392 Mdot
.21611 .49814 Mdot
.41011 .57711 Mdot
.47632 .59898 Mdot
.50715 .59235 Mdot
.54872 .54789 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49716 .00383 Mdot
.49096 .01221 Mdot
.47121 .03875 Mdot
.40852 .11896 Mdot
.21604 .26316 Mdot
.79025 .12031 Mdot
.59559 .03692 Mdot
.53585 .00397 Mdot
.52943 .59487 Mdot
.56691 .53465 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49037 .013 Mdot
.46934 .04125 Mdot
.4026 .12601 Mdot
.19871 .26596 Mdot
.76838 .1194 Mdot
.57519 .05226 Mdot
.49064 .06093 Mdot
.39206 .1535 Mdot
.14369 .26933 Mdot
.49971 .0004 Mdot
.49906 .00126 Mdot
.49702 .00403 Mdot
.49051 .01282 Mdot
.46976 .04069 Mdot
.40392 .12445 Mdot
.20256 .26549 Mdot
.77299 .11948 Mdot
.57967 .04866 Mdot
.50093 .0478 Mdot
.42359 .11595 Mdot
.23599 .26292 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49808 .0026 Mdot
.49387 .00828 Mdot
.48047 .02635 Mdot
.43783 .08252 Mdot
.30431 .22156 Mdot
.94581 .17229 Mdot
.66704 .04434 Mdot
.59529 .57922 Mdot
.65809 .4556 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51094 .60327 Mdot
.53483 .57124 Mdot
.61055 .47679 Mdot
.83908 .35176 Mdot
.26992 .49815 Mdot
.46388 .53135 Mdot
.60414 .44155 Mdot
.88971 .34729 Mdot
.32778 .47756 Mdot
.4998 .00027 Mdot
.49937 .00086 Mdot
.49798 .00273 Mdot
.49357 .00869 Mdot
.47951 .02763 Mdot
.4348 .0864 Mdot
.29499 .22809 Mdot
.92593 .16188 Mdot
.66401 .03535 Mdot
.60681 .56163 Mdot
.69806 .42188 Mdot
.01545 .43618 Mdot
.49968 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48949 .01419 Mdot
.46653 .04499 Mdot
.39374 .13634 Mdot
.17315 .26701 Mdot
.74111 .1197 Mdot
.54744 .07636 Mdot
.42388 .14427 Mdot
.19045 .28161 Mdot
.73481 .13473 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50812 .60707 Mdot
.52585 .58321 Mdot
.58219 .51036 Mdot
.75641 .36293 Mdot
.16918 .49186 Mdot
.37333 .59728 Mdot
.40692 .0607 Mdot
.30871 .19831 Mdot
.98783 .18704 Mdot
.50091 .6168 Mdot
.5029 .61411 Mdot
.50925 .60554 Mdot
.52946 .57838 Mdot
.59362 .49651 Mdot
.79026 .35366 Mdot
.21803 .49824 Mdot
.41187 .57583 Mdot
.48016 .59417 Mdot
.51877 .57681 Mdot
.58548 .50131 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.51121 .6029 Mdot
.5357 .57008 Mdot
.6133 .47369 Mdot
.84686 .35263 Mdot
.27628 .49817 Mdot
.47023 .52561 Mdot
.61977 .42477 Mdot
.93248 .36403 Mdot
.34346 .48686 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48746 .01693 Mdot
.46006 .05357 Mdot
.37338 .15895 Mdot
.11619 .25735 Mdot
.69979 .11709 Mdot
.51033 .10752 Mdot
.33636 .23387 Mdot
.95794 .19534 Mdot
.64188 .08055 Mdot
.49971 .0004 Mdot
.49906 .00127 Mdot
.49701 .00404 Mdot
.49048 .01286 Mdot
.46968 .0408 Mdot
.40367 .12475 Mdot
.20182 .26558 Mdot
.77209 .11946 Mdot
.5788 .04935 Mdot
.49895 .05033 Mdot
.41752 .12342 Mdot
.21782 .26796 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00474 Mdot
.48882 .0151 Mdot
.46438 .04784 Mdot
.38697 .14404 Mdot
.15391 .2655 Mdot
.72432 .11987 Mdot
.53036 .09189 Mdot
.38168 .19175 Mdot
.07142 .25576 Mdot
.65759 .1324 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46506 .04694 Mdot
.38911 .14163 Mdot
.15994 .26618 Mdot
.72926 .11988 Mdot
.53528 .08744 Mdot
.3938 .17875 Mdot
.10457 .26887 Mdot
.66953 .13978 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49805 .00263 Mdot
.4938 .00838 Mdot
.48024 .02664 Mdot
.43713 .08342 Mdot
.30215 .22312 Mdot
.94115 .16979 Mdot
.66642 .04213 Mdot
.59826 .57475 Mdot
.6683 .44622 Mdot
.94631 .39738 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58652 Mdot
.57436 .52007 Mdot
.73288 .37337 Mdot
.12875 .48013 Mdot
.35188 .59847 Mdot
.38354 .07902 Mdot
.25569 .22647 Mdot
.88926 .13189 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47747 .03038 Mdot
.42832 .0946 Mdot
.27525 .2403 Mdot
.88644 .14373 Mdot
.65388 .02228 Mdot
.61783 .54079 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.50438 .61211 Mdot
.51397 .59918 Mdot
.54448 .55848 Mdot
.64083 .44431 Mdot
.92193 .3748 Mdot
.31549 .51003 Mdot
.49025 .51906 Mdot
.6504 .39948 Mdot
.00403 .40321 Mdot
.49979 .00028 Mdot
.49935 .00088 Mdot
.49792 .00281 Mdot
.49336 .00897 Mdot
.47886 .02851 Mdot
.43273 .08903 Mdot
.28867 .23224 Mdot
.91289 .15546 Mdot
.66135 .03022 Mdot
.61245 .55247 Mdot
.71854 .40779 Mdot
.05872 .461 Mdot
.50023 .61772 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50746 .60796 Mdot
.52375 .58602 Mdot
.57555 .51858 Mdot
.73647 .37157 Mdot
.13525 .4824 Mdot
.35471 .59915 Mdot
.38527 .0785 Mdot
.25826 .22584 Mdot
.50002 .61801 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.50069 .61711 Mdot
.50219 .61507 Mdot
.50698 .60861 Mdot
.52223 .58806 Mdot
.57073 .52462 Mdot
.72187 .37938 Mdot
.10803 .47201 Mdot
.3443 .59441 Mdot
.50006 .61795 Mdot
.50021 .61776 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60903 Mdot
.52123 .58941 Mdot
.56754 .52866 Mdot
.71214 .38527 Mdot
.08876 .46336 Mdot
.33903 .58841 Mdot
.38696 .06658 Mdot
.5011 .61655 Mdot
.5035 .61331 Mdot
.51114 .60299 Mdot
.53548 .57037 Mdot
.61261 .47447 Mdot
.84489 .35239 Mdot
.27472 .49815 Mdot
.46869 .52699 Mdot
.61601 .42872 Mdot
.92233 .35954 Mdot
.34059 .48382 Mdot
.50065 .61716 Mdot
.50207 .61524 Mdot
.50659 .60913 Mdot
.52101 .58971 Mdot
.56684 .52955 Mdot
.71002 .38663 Mdot
.08444 .46129 Mdot
.33806 .58682 Mdot
.38856 .06386 Mdot
.28524 .2078 Mdot
.94901 .16133 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.4958 .00568 Mdot
.48661 .01807 Mdot
.45738 .05711 Mdot
.36497 .16781 Mdot
.09345 .24955 Mdot
.68967 .11247 Mdot
.50769 .10535 Mdot
.33722 .23129 Mdot
.96299 .19729 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.46781 .04329 Mdot
.39777 .13167 Mdot
.18472 .26698 Mdot
.75274 .11946 Mdot
.55945 .06561 Mdot
.45329 .1083 Mdot
.27806 .25356 Mdot
.50071 .61708 Mdot
.50225 .61499 Mdot
.50718 .60833 Mdot
.52288 .5872 Mdot
.57277 .52206 Mdot
.72805 .37592 Mdot
.1198 .47679 Mdot
.34834 .59705 Mdot
.3823 .07845 Mdot
.25536 .22591 Mdot
.88982 .13174 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49506 .00667 Mdot
.48428 .02122 Mdot
.44994 .06686 Mdot
.34176 .19056 Mdot
.03343 .22132 Mdot
.67533 .08972 Mdot
.53015 .06194 Mdot
.42993 .12482 Mdot
.22796 .27096 Mdot
.49995 7e-05 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49464 .00724 Mdot
.48292 .02305 Mdot
.44562 .07249 Mdot
.32833 .20252 Mdot
.00064 .20312 Mdot
.67199 .07294 Mdot
.55397 .02387 Mdot
.51535 .00966 Mdot
.49968 .00043 Mdot
.499 .00136 Mdot
.4968 .00432 Mdot
.48981 .01377 Mdot
.46753 .04366 Mdot
.3969 .13269 Mdot
.18219 .26705 Mdot
.7501 .1195 Mdot
.55674 .06801 Mdot
.4467 .11651 Mdot
.25818 .26386 Mdot
.83125 .13513 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .61231 Mdot
.51349 .59982 Mdot
.54296 .56047 Mdot
.6361 .44912 Mdot
.90941 .3696 Mdot
.31138 .50631 Mdot
.49216 .51358 Mdot
.66117 .38842 Mdot
.03269 .41851 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50129 .6163 Mdot
.5041 .6125 Mdot
.51306 .6004 Mdot
.54159 .56228 Mdot
.6318 .45359 Mdot
.89789 .36528 Mdot
.30684 .50352 Mdot
.49214 .51081 Mdot
.50025 .6177 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52558 .58357 Mdot
.58135 .5114 Mdot
.75388 .3639 Mdot
.16508 .49094 Mdot
.37073 .59803 Mdot
.40311 .06437 Mdot
.29895 .20499 Mdot
.49975 .00033 Mdot
.49922 .00106 Mdot
.4975 .00337 Mdot
.49205 .01074 Mdot
.47468 .03412 Mdot
.41948 .10562 Mdot
.24857 .25316 Mdot
.83895 .12807 Mdot
.63174 .01942 Mdot
.60032 .55049 Mdot
.70961 .40767 Mdot
.04999 .45325 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51059 .60374 Mdot
.53372 .57272 Mdot
.60704 .4808 Mdot
.8291 .3511 Mdot
.26101 .49829 Mdot
.45475 .53968 Mdot
.58153 .46735 Mdot
.82534 .33603 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00477 Mdot
.48875 .01519 Mdot
.46418 .04812 Mdot
.38632 .14477 Mdot
.15207 .26526 Mdot
.72287 .11985 Mdot
.52895 .09316 Mdot
.37822 .19535 Mdot
.06214 .2515 Mdot
.50002 .618 Mdot
.50008 .61793 Mdot
.50025 .6177 Mdot
.5008 .61696 Mdot
.50254 .61461 Mdot
.50808 .60712 Mdot
.52575 .58335 Mdot
.58186 .51076 Mdot
.75544 .3633 Mdot
.1676 .49151 Mdot
.37232 .59758 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48957 .01409 Mdot
.46677 .04467 Mdot
.39448 .13548 Mdot
.17527 .26706 Mdot
.74316 .11965 Mdot
.54956 .07444 Mdot
.42911 .13801 Mdot
.20581 .2799 Mdot
.75292 .13238 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00167 Mdot
.49607 .00531 Mdot
.48748 .01691 Mdot
.46012 .05349 Mdot
.37357 .15875 Mdot
.11671 .25751 Mdot
.70005 .11717 Mdot
.51047 .10747 Mdot
.33659 .23371 Mdot
.95844 .19562 Mdot
.50025 .61769 Mdot
.50081 .61694 Mdot
.50258 .61454 Mdot
.50823 .60691 Mdot
.52623 .5827 Mdot
.58339 .50888 Mdot
.76 .36163 Mdot
.17488 .49304 Mdot
.37712 .59597 Mdot
.41282 .05478 Mdot
.32418 .18659 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49607 .0053 Mdot
.48749 .01689 Mdot
.46017 .05343 Mdot
.37373 .15859 Mdot
.11713 .25763 Mdot
.70027 .11723 Mdot
.51059 .10742 Mdot
.33678 .23357 Mdot
.95887 .19586 Mdot
.64196 .08102 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49565 .00587 Mdot
.48616 .01869 Mdot
.45592 .05903 Mdot
.3604 .17248 Mdot
.08131 .24463 Mdot
.6855 .10904 Mdot
.50907 .10063 Mdot
.34624 .22201 Mdot
.49967 .00045 Mdot
.49894 .00143 Mdot
.49663 .00456 Mdot
.48925 .01451 Mdot
.46577 .046 Mdot
.39134 .13909 Mdot
.16628 .26669 Mdot
.73477 .11982 Mdot
.54089 .08233 Mdot
.40769 .16319 Mdot
.14365 .279 Mdot
.69222 .14107 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .0056 Mdot
.48679 .01783 Mdot
.45794 .05638 Mdot
.36672 .16599 Mdot
.09814 .25131 Mdot
.6915 .11362 Mdot
.50766 .10653 Mdot
.3353 .23338 Mdot
.95767 .19461 Mdot
.64279 .07929 Mdot
.50007 .61794 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60801 Mdot
.52364 .58618 Mdot
.57518 .51905 Mdot
.73534 .37213 Mdot
.13322 .48171 Mdot
.3538 .59897 Mdot
.38465 .07875 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51143 .6026 Mdot
.53641 .56913 Mdot
.61554 .47118 Mdot
.85315 .35356 Mdot
.28108 .4983 Mdot
.47482 .52154 Mdot
.63095 .41338 Mdot
.96209 .37857 Mdot
.34955 .49818 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49735 .00358 Mdot
.49157 .01139 Mdot
.47313 .03618 Mdot
.41459 .11161 Mdot
.234 .25841 Mdot
.81588 .12333 Mdot
.61633 .02483 Mdot
.57615 .57493 Mdot
.64589 .45785 Mdot
.90507 .37497 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47977 .02728 Mdot
.43562 .08535 Mdot
.29753 .22636 Mdot
.93126 .1646 Mdot
.66493 .03764 Mdot
.60403 .56595 Mdot
.68829 .42936 Mdot
.99357 .4234 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49148 .01151 Mdot
.47285 .03655 Mdot
.41371 .11269 Mdot
.23138 .25922 Mdot
.81194 .12271 Mdot
.61339 .02627 Mdot
.57089 .58073 Mdot
.63124 .47239 Mdot
.8669 .36289 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51169 .60225 Mdot
.53724 .56804 Mdot
.61812 .46831 Mdot
.86038 .35485 Mdot
.28621 .49859 Mdot
.47947 .51757 Mdot
.64202 .4027 Mdot
.49993 9e-05 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49784 .00292 Mdot
.49311 .0093 Mdot
.47806 .02958 Mdot
.4302 .09223 Mdot
.28098 .23699 Mdot
.89752 .14841 Mdot
.65738 .02516 Mdot
.61668 .54445 Mdot
.73573 .3975 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51204 .60178 Mdot
.53834 .56658 Mdot
.62159 .46451 Mdot
.87 .35695 Mdot
.29244 .49928 Mdot
.48458 .51356 Mdot
.65362 .39225 Mdot
.01894 .40977 Mdot
.35592 .52583 Mdot
.50065 .61715 Mdot
.50208 .61523 Mdot
.50662 .6091 Mdot
.52107 .58962 Mdot
.56705 .52928 Mdot
.71066 .38622 Mdot
.08573 .46191 Mdot
.33834 .58731 Mdot
.38806 .0647 Mdot
.28337 .20901 Mdot
.94518 .15919 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49328 .00908 Mdot
.4786 .02886 Mdot
.4319 .09008 Mdot
.28616 .23383 Mdot
.90781 .15306 Mdot
.66014 .02842 Mdot
.61416 .54946 Mdot
.72512 .40372 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50706 .6085 Mdot
.52248 .58773 Mdot
.57152 .52363 Mdot
.72426 .37801 Mdot
.11263 .47392 Mdot
.3458 .59554 Mdot
.3822 .07701 Mdot
.2576 .22439 Mdot
.89453 .13361 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49943 .00077 Mdot
.49818 .00246 Mdot
.4942 .00783 Mdot
.48153 .02491 Mdot
.44123 .07817 Mdot
.31475 .21367 Mdot
.96902 .18513 Mdot
.66947 .05608 Mdot
.57874 .60406 Mdot
.60135 .51632 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49064 .01264 Mdot
.47019 .04012 Mdot
.40528 .12284 Mdot
.20652 .26491 Mdot
.77789 .11963 Mdot
.58433 .04506 Mdot
.51143 .03447 Mdot
.45565 .07505 Mdot
.33422 .20241 Mdot
.49976 .00032 Mdot
.49925 .00101 Mdot
.49761 .00323 Mdot
.49239 .01028 Mdot
.47575 .03268 Mdot
.42287 .10141 Mdot
.25879 .24873 Mdot
.85633 .13291 Mdot
.64128 .01847 Mdot
.61139 .54146 Mdot
.73528 .39455 Mdot
.09689 .47893 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49028 .01313 Mdot
.46904 .04164 Mdot
.40166 .12712 Mdot
.19599 .26624 Mdot
.76519 .11937 Mdot
.57205 .05484 Mdot
.48331 .07028 Mdot
.3696 .17809 Mdot
.08144 .25034 Mdot
.49964 .00049 Mdot
.49884 .00156 Mdot
.49631 .00498 Mdot
.48826 .01586 Mdot
.4626 .05021 Mdot
.38137 .15028 Mdot
.13821 .2629 Mdot
.71283 .11936 Mdot
.5197 .10115 Mdot
.35604 .21714 Mdot
.0047 .2215 Mdot
.64631 .10417 Mdot
.50038 .61752 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51225 .6015 Mdot
.53901 .56569 Mdot
.62369 .46222 Mdot
.8758 .35842 Mdot
.29586 .49988 Mdot
.48704 .51188 Mdot
.6588 .38791 Mdot
.03115 .4166 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48937 .01436 Mdot
.46613 .04552 Mdot
.39248 .13778 Mdot
.16955 .26687 Mdot
.73774 .11977 Mdot
.54395 .07954 Mdot
.41526 .15444 Mdot
.16538 .28161 Mdot
.70972 .13877 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50767 .60768 Mdot
.52442 .58513 Mdot
.57766 .51596 Mdot
.74281 .36857 Mdot
.14645 .48597 Mdot
.36013 .59958 Mdot
.38999 .0756 Mdot
.26767 .22224 Mdot
.90808 .14168 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49973 .00037 Mdot
.49913 .00118 Mdot
.49722 .00376 Mdot
.49113 .01197 Mdot
.47176 .03802 Mdot
.41025 .11688 Mdot
.22113 .262 Mdot
.7972 .1209 Mdot
.60158 .033 Mdot
.54819 .60704 Mdot
.50029 .61765 Mdot
.50091 .61681 Mdot
.5029 .61412 Mdot
.50923 .60556 Mdot
.52941 .57846 Mdot
.59345 .49672 Mdot
.78974 .35375 Mdot
.21736 .4982 Mdot
.41125 .57628 Mdot
.47882 .59585 Mdot
.51471 .58224 Mdot
.50041 .61748 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51333 .60004 Mdot
.54246 .56114 Mdot
.63451 .45077 Mdot
.90515 .36795 Mdot
.30979 .50521 Mdot
.49235 .51229 Mdot
.66345 .38603 Mdot
.03883 .42168 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50496 .61133 Mdot
.5158 .59671 Mdot
.5503 .55086 Mdot
.65899 .42679 Mdot
.96844 .39772 Mdot
.32492 .52921 Mdot
.46863 .5581 Mdot
.5656 .49899 Mdot
.75821 .35165 Mdot
.49997 5e-05 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48866 .01532 Mdot
.46387 .04852 Mdot
.38537 .14584 Mdot
.1494 .26487 Mdot
.72082 .1198 Mdot
.52698 .09491 Mdot
.3734 .20028 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00479 Mdot
.48871 .01524 Mdot
.46405 .04828 Mdot
.38593 .14521 Mdot
.15098 .2651 Mdot
.72203 .11983 Mdot
.52813 .09389 Mdot
.37622 .19741 Mdot
.0568 .24896 Mdot
.65398 .12747 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.5062 .60965 Mdot
.51977 .59137 Mdot
.5629 .53456 Mdot
.69796 .39484 Mdot
.0591 .44838 Mdot
.33361 .57602 Mdot
.40159 .04352 Mdot
.33117 .17229 Mdot
.05241 .22 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.49938 .00084 Mdot
.49803 .00266 Mdot
.49372 .00849 Mdot
.47998 .027 Mdot
.4363 .08449 Mdot
.29959 .22493 Mdot
.93564 .16688 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00349 Mdot
.49178 .0111 Mdot
.47381 .03527 Mdot
.41674 .10898 Mdot
.2404 .25626 Mdot
.82576 .12512 Mdot
.62331 .0219 Mdot
.58788 .56254 Mdot
.67766 .42998 Mdot
.98194 .41327 Mdot
.50105 .61661 Mdot
.50335 .6135 Mdot
.51069 .6036 Mdot
.53404 .57228 Mdot
.60807 .47961 Mdot
.83204 .35124 Mdot
.26372 .49824 Mdot
.45755 .53713 Mdot
.58846 .45927 Mdot
.84534 .33742 Mdot
.29938 .47792 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47324 .03604 Mdot
.41493 .1112 Mdot
.235 .25809 Mdot
.8174 .12358 Mdot
.61744 .02432 Mdot
.57809 .57284 Mdot
.65122 .45281 Mdot
.91856 .38056 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48865 .01533 Mdot
.46384 .04856 Mdot
.38526 .14595 Mdot
.14911 .26483 Mdot
.7206 .1198 Mdot
.52677 .0951 Mdot
.3729 .2008 Mdot
.04801 .24463 Mdot
.65219 .12408 Mdot
.49979 .00028 Mdot
.49933 .00091 Mdot
.49786 .00289 Mdot
.49319 .00919 Mdot
.47832 .02923 Mdot
.43102 .09119 Mdot
.28348 .23548 Mdot
.90245 .15061 Mdot
.65876 .02665 Mdot
.61564 .54667 Mdot
.7311 .40017 Mdot
.08362 .47417 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00398 Mdot
.49062 .01267 Mdot
.47012 .0402 Mdot
.40507 .12308 Mdot
.20591 .265 Mdot
.77713 .1196 Mdot
.58361 .0456 Mdot
.50983 .0365 Mdot
.45077 .08141 Mdot
.31905 .21529 Mdot
.50071 .61708 Mdot
.50225 .615 Mdot
.50716 .60836 Mdot
.52281 .58728 Mdot
.57257 .52231 Mdot
.72746 .37624 Mdot
.11868 .47635 Mdot
.34793 .59683 Mdot
.38223 .07828 Mdot
.25557 .22574 Mdot
.89032 .13192 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49844 .0021 Mdot
.49504 .0067 Mdot
.48421 .02131 Mdot
.44972 .06715 Mdot
.34107 .1912 Mdot
.0317 .22039 Mdot
.6751 .08889 Mdot
.53128 .06008 Mdot
.43407 .11947 Mdot
.24076 .26677 Mdot
.50083 .61691 Mdot
.50266 .61444 Mdot
.50847 .6066 Mdot
.52697 .58171 Mdot
.58575 .50601 Mdot
.767 .35931 Mdot
.18563 .49495 Mdot
.38479 .59267 Mdot
.42583 .04093 Mdot
.3596 .15486 Mdot
.10904 .24821 Mdot
.50132 .61625 Mdot
.50422 .61234 Mdot
.51343 .5999 Mdot
.54277 .56072 Mdot
.63551 .44973 Mdot
.90782 .36898 Mdot
.3108 .50589 Mdot
.49226 .51306 Mdot
.6621 .38745 Mdot
.03519 .41981 Mdot
.35592 .53587 Mdot
.50013 .61786 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.51341 .59994 Mdot
.54269 .56084 Mdot
.63524 .45002 Mdot
.9071 .3687 Mdot
.31053 .5057 Mdot
.49229 .51284 Mdot
.6625 .38704 Mdot
.49973 .00036 Mdot
.49914 .00116 Mdot
.49727 .00369 Mdot
.49131 .01174 Mdot
.47231 .03728 Mdot
.412 .11477 Mdot
.2263 .26068 Mdot
.80451 .1217 Mdot
.60759 .02939 Mdot
.56003 .59308 Mdot
.6004 .50606 Mdot
.78159 .36141 Mdot
.50067 .61713 Mdot
.50212 .61517 Mdot
.50676 .60891 Mdot
.52152 .58901 Mdot
.56848 .52747 Mdot
.71502 .38347 Mdot
.09454 .46606 Mdot
.34045 .59041 Mdot
.38515 .06985 Mdot
.27213 .21597 Mdot
.92269 .14708 Mdot
.49988 .00016 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49613 .00522 Mdot
.48769 .01663 Mdot
.46078 .05262 Mdot
.37565 .15652 Mdot
.12239 .25913 Mdot
.70312 .11794 Mdot
.51229 .10656 Mdot
.33987 .2312 Mdot
.96579 .19973 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49522 .00646 Mdot
.48477 .02055 Mdot
.45151 .06481 Mdot
.34665 .18598 Mdot
.04572 .22779 Mdot
.67716 .09543 Mdot
.52275 .07441 Mdot
.40235 .15936 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49909 .00123 Mdot
.4971 .00392 Mdot
.49075 .01249 Mdot
.47053 .03965 Mdot
.40637 .12153 Mdot
.20973 .26438 Mdot
.78196 .1198 Mdot
.58812 .04222 Mdot
.51981 .0239 Mdot
.48114 .04134 Mdot
.49982 .00024 Mdot
.49943 .00078 Mdot
.49817 .00247 Mdot
.49418 .00787 Mdot
.48145 .02503 Mdot
.44095 .07853 Mdot
.31388 .21435 Mdot
.96707 .18403 Mdot
.6693 .05505 Mdot
.58022 .60183 Mdot
.60644 .51034 Mdot
.78069 .36553 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50669 .609 Mdot
.52132 .58929 Mdot
.56782 .52831 Mdot
.713 .38473 Mdot
.09049 .46417 Mdot
.33944 .58903 Mdot
.38638 .0676 Mdot
.27699 .21303 Mdot
.9323 .15214 Mdot
.50077 .617 Mdot
.50244 .61474 Mdot
.50777 .60754 Mdot
.52475 .58469 Mdot
.5787 .51467 Mdot
.74596 .36717 Mdot
.15186 .48754 Mdot
.363 .59943 Mdot
.3931 .07321 Mdot
.27464 .21899 Mdot
.9203 .14816 Mdot
.50055 .61729 Mdot
.50176 .61566 Mdot
.50559 .61048 Mdot
.51781 .594 Mdot
.5567 .54254 Mdot
.67886 .40949 Mdot
.0163 .42457 Mdot
.32933 .55416 Mdot
.43268 .61473 Mdot
.43803 .0527 Mdot
.35275 .17055 Mdot
.50086 .61687 Mdot
.50275 .61432 Mdot
.50875 .60622 Mdot
.52786 .58052 Mdot
.58856 .50259 Mdot
.77535 .35691 Mdot
.19785 .49661 Mdot
.39432 .58754 Mdot
.44366 .02065 Mdot
.41025 .09951 Mdot
.24924 .24705 Mdot
.50045 .61743 Mdot
.50142 .61612 Mdot
.50452 .61192 Mdot
.51441 .59858 Mdot
.5459 .55662 Mdot
.64527 .43988 Mdot
.93353 .38003 Mdot
.31862 .51407 Mdot
.48683 .52627 Mdot
.63531 .41541 Mdot
.96316 .38156 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49627 .00504 Mdot
.48811 .01605 Mdot
.46214 .05083 Mdot
.3799 .1519 Mdot
.13412 .26203 Mdot
.71015 .11909 Mdot
.51746 .10294 Mdot
.35089 .22182 Mdot
.99199 .21439 Mdot
.64509 .09775 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01054 Mdot
.47515 .03348 Mdot
.42097 .10377 Mdot
.25307 .25129 Mdot
.84648 .13003 Mdot
.63608 .0187 Mdot
.60583 .54569 Mdot
.72289 .40028 Mdot
.07523 .46745 Mdot
.50035 .61757 Mdot
.5011 .61654 Mdot
.50351 .61329 Mdot
.5112 .60291 Mdot
.53566 .57013 Mdot
.61317 .47384 Mdot
.84648 .35258 Mdot
.27599 .49817 Mdot
.46994 .52587 Mdot
.61906 .42551 Mdot
.93058 .36317 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50729 .60819 Mdot
.52322 .58674 Mdot
.57386 .52069 Mdot
.73136 .37416 Mdot
.12596 .47911 Mdot
.35073 .59808 Mdot
.38301 .07899 Mdot
.2552 .22646 Mdot
.88878 .13154 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60458 Mdot
.53174 .57535 Mdot
.60081 .48801 Mdot
.81119 .35124 Mdot
.24287 .49864 Mdot
.43606 .55633 Mdot
.53589 .52334 Mdot
.68911 .38646 Mdot
.0638 .44404 Mdot
.49969 .00041 Mdot
.49902 .00132 Mdot
.49689 .0042 Mdot
.4901 .01337 Mdot
.46846 .04242 Mdot
.39983 .12927 Mdot
.19066 .26668 Mdot
.75916 .11938 Mdot
.566 .05993 Mdot
.46902 .08847 Mdot
.32588 .21956 Mdot
.97062 .19248 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49001 .01349 Mdot
.46819 .04278 Mdot
.39898 .13026 Mdot
.18821 .26683 Mdot
.75648 .1194 Mdot
.56327 .06228 Mdot
.4625 .09672 Mdot
.30601 .23522 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .6042 Mdot
.53263 .57416 Mdot
.60363 .48473 Mdot
.81931 .35096 Mdot
.25144 .4985 Mdot
.44485 .54861 Mdot
.55719 .49673 Mdot
.75347 .34922 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00452 Mdot
.48935 .01438 Mdot
.46608 .04559 Mdot
.39231 .13798 Mdot
.16905 .26685 Mdot
.73728 .11978 Mdot
.54348 .07997 Mdot
.41408 .15581 Mdot
.16199 .28136 Mdot
.70674 .13923 Mdot
.50084 .6169 Mdot
.50267 .61443 Mdot
.50851 .60654 Mdot
.52711 .58153 Mdot
.58616 .5055 Mdot
.76825 .35892 Mdot
.18749 .49524 Mdot
.38619 .59198 Mdot
.42834 .03816 Mdot
.36659 .14785 Mdot
.12736 .25372 Mdot
.50018 .61779 Mdot
.50058 .61725 Mdot
.50185 .61553 Mdot
.5059 .61006 Mdot
.5188 .59267 Mdot
.55983 .5385 Mdot
.68852 .40183 Mdot
.03834 .43703 Mdot
.33121 .56578 Mdot
.41575 .02225 Mdot
.37975 .12342 Mdot
.50032 .6176 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51031 .60411 Mdot
.53284 .57388 Mdot
.60429 .48397 Mdot
.82121 .35095 Mdot
.25336 .49846 Mdot
.44684 .54683 Mdot
.56204 .49076 Mdot
.76798 .34416 Mdot
.50015 .61784 Mdot
.50047 .61741 Mdot
.50148 .61603 Mdot
.50472 .61165 Mdot
.51505 .59772 Mdot
.54792 .55396 Mdot
.6516 .43373 Mdot
.94981 .38797 Mdot
.32207 .52064 Mdot
.47965 .53946 Mdot
.60679 .44773 Mdot
.50037 .61754 Mdot
.50118 .61644 Mdot
.50375 .61297 Mdot
.51194 .60191 Mdot
.53802 .567 Mdot
.6206 .46559 Mdot
.86726 .35631 Mdot
.29073 .49905 Mdot
.48325 .51455 Mdot
.65069 .39481 Mdot
.01189 .40581 Mdot
.50084 .6169 Mdot
.50268 .61441 Mdot
.50855 .60649 Mdot
.52723 .58136 Mdot
.58657 .50501 Mdot
.76945 .35856 Mdot
.18928 .4955 Mdot
.38755 .59129 Mdot
.43082 .03539 Mdot
.37355 .14067 Mdot
.14595 .25779 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47976 .02729 Mdot
.4356 .08538 Mdot
.29746 .22641 Mdot
.93112 .16453 Mdot
.66491 .03758 Mdot
.6041 .56584 Mdot
.68856 .42915 Mdot
.99417 .42375 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48953 .01414 Mdot
.46665 .04483 Mdot
.39411 .13591 Mdot
.1742 .26704 Mdot
.74213 .11967 Mdot
.54849 .07541 Mdot
.42647 .14118 Mdot
.19803 .28093 Mdot
.74348 .13351 Mdot
.49979 .00028 Mdot
.49933 .00091 Mdot
.49786 .00288 Mdot
.4932 .00919 Mdot
.47833 .02922 Mdot
.43105 .09116 Mdot
.28355 .23544 Mdot
.90259 .15067 Mdot
.6588 .0267 Mdot
.6156 .54674 Mdot
.73096 .40025 Mdot
.08334 .47403 Mdot
.50009 .61791 Mdot
.50029 .61764 Mdot
.50092 .61679 Mdot
.50293 .61408 Mdot
.50934 .60543 Mdot
.52974 .57802 Mdot
.59448 .49548 Mdot
.79278 .35323 Mdot
.22123 .49838 Mdot
.41484 .57361 Mdot
.48673 .58589 Mdot
.50004 .61798 Mdot
.50013 .61786 Mdot
.50041 .61748 Mdot
.50131 .61627 Mdot
.50417 .61241 Mdot
.51327 .60011 Mdot
.54227 .56139 Mdot
.63392 .45138 Mdot
.90358 .36736 Mdot
.30918 .50482 Mdot
.49237 .5119 Mdot
.49985 .0002 Mdot
.49953 .00064 Mdot
.4985 .00203 Mdot
.49521 .00647 Mdot
.48475 .02058 Mdot
.45145 .06489 Mdot
.34646 .18616 Mdot
.04525 .22754 Mdot
.67708 .09522 Mdot
.52301 .07395 Mdot
.40335 .15814 Mdot
.14747 .27612 Mdot
.5001 .61789 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50337 .61348 Mdot
.51075 .60352 Mdot
.53424 .57202 Mdot
.60869 .47892 Mdot
.83378 .35135 Mdot
.26529 .49821 Mdot
.45917 .53565 Mdot
.59247 .45467 Mdot
.50055 .61729 Mdot
.50177 .61565 Mdot
.50563 .61043 Mdot
.51792 .59385 Mdot
.55705 .54209 Mdot
.67994 .40861 Mdot
.0188 .426 Mdot
.32953 .5555 Mdot
.4307 .61773 Mdot
.43119 .06152 Mdot
.33165 .19007 Mdot
.50092 .61679 Mdot
.50293 .61407 Mdot
.50934 .60542 Mdot
.52975 .578 Mdot
.59453 .49543 Mdot
.79291 .35321 Mdot
.2214 .49838 Mdot
.415 .57349 Mdot
.48707 .58546 Mdot
.53977 .54898 Mdot
.65151 .42879 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49801 .00269 Mdot
.49365 .00858 Mdot
.47977 .02728 Mdot
.43563 .08535 Mdot
.29753 .22636 Mdot
.93127 .16461 Mdot
.66493 .03764 Mdot
.60402 .56596 Mdot
.68827 .42938 Mdot
.99353 .42338 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49856 .00195 Mdot
.49541 .00621 Mdot
.48536 .01976 Mdot
.4534 .06234 Mdot
.35253 .18032 Mdot
.06077 .23529 Mdot
.68006 .10177 Mdot
.51539 .08752 Mdot
.37377 .19266 Mdot
.06205 .24873 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48866 .01531 Mdot
.46388 .04851 Mdot
.38538 .14582 Mdot
.14943 .26488 Mdot
.72085 .1198 Mdot
.527 .09489 Mdot
.37347 .20022 Mdot
.04951 .24538 Mdot
.65248 .12468 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.4886 .0154 Mdot
.46368 .04877 Mdot
.38477 .14651 Mdot
.14771 .26461 Mdot
.71955 .11976 Mdot
.52578 .09597 Mdot
.37049 .20321 Mdot
.04169 .24142 Mdot
.65106 .12148 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.4991 .00121 Mdot
.49714 .00387 Mdot
.49088 .01231 Mdot
.47096 .03909 Mdot
.40772 .11992 Mdot
.21368 .26364 Mdot
.7871 .12009 Mdot
.5928 .03885 Mdot
.52994 .01126 Mdot
.51171 .00042 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49744 .00345 Mdot
.49185 .011 Mdot
.47405 .03495 Mdot
.4175 .10806 Mdot
.24265 .25545 Mdot
.82933 .12585 Mdot
.6257 .02107 Mdot
.5916 .55879 Mdot
.68746 .4225 Mdot
.00384 .42606 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61095 Mdot
.51671 .59548 Mdot
.55321 .54707 Mdot
.66803 .41866 Mdot
.99062 .40997 Mdot
.32727 .54047 Mdot
.45278 .58361 Mdot
.50848 .57575 Mdot
.5769 .5072 Mdot
.49996 5e-05 Mdot
.49989 .00016 Mdot
.49963 .00049 Mdot
.49884 .00157 Mdot
.49629 .00501 Mdot
.48818 .01597 Mdot
.46234 .05055 Mdot
.38054 .15119 Mdot
.13592 .26242 Mdot
.71131 .11922 Mdot
.51841 .10219 Mdot
.35307 .21986 Mdot
.49982 .00024 Mdot
.49944 .00075 Mdot
.49822 .0024 Mdot
.49434 .00765 Mdot
.48195 .02435 Mdot
.44256 .07645 Mdot
.31886 .2104 Mdot
.97842 .19046 Mdot
.67025 .06105 Mdot
.57147 .61503 Mdot
.57633 .54695 Mdot
.69136 .4093 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.499 .00136 Mdot
.4968 .00433 Mdot
.4898 .01377 Mdot
.46751 .04368 Mdot
.39683 .13277 Mdot
.182 .26705 Mdot
.74991 .11951 Mdot
.55654 .06819 Mdot
.44621 .11712 Mdot
.25671 .26453 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48994 .01359 Mdot
.46796 .04309 Mdot
.39824 .13113 Mdot
.18607 .26693 Mdot
.75417 .11943 Mdot
.56092 .06433 Mdot
.45682 .10387 Mdot
.28876 .24706 Mdot
.88901 .15231 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52884 .57922 Mdot
.59164 .49889 Mdot
.78442 .35478 Mdot
.21038 .49777 Mdot
.40496 .58074 Mdot
.46531 .61264 Mdot
.47404 .01857 Mdot
.44399 .06943 Mdot
.50062 .61719 Mdot
.50198 .61536 Mdot
.50631 .60951 Mdot
.52009 .59094 Mdot
.56393 .53325 Mdot
.70111 .39261 Mdot
.06585 .45193 Mdot
.33461 .57911 Mdot
.39758 .04961 Mdot
.31731 .18416 Mdot
.01934 .20204 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.50651 .60925 Mdot
.52072 .59009 Mdot
.56594 .53069 Mdot
.70726 .38843 Mdot
.07876 .45851 Mdot
.33688 .58461 Mdot
.39096 .05993 Mdot
.29399 .20188 Mdot
.96734 .17182 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00696 Mdot
.48358 .02216 Mdot
.44771 .06977 Mdot
.33482 .19685 Mdot
.01631 .21195 Mdot
.67338 .08117 Mdot
.54203 .04266 Mdot
.47302 .06755 Mdot
.36371 .17901 Mdot
.50019 .61777 Mdot
.50061 .61721 Mdot
.50195 .6154 Mdot
.50622 .60964 Mdot
.51981 .59132 Mdot
.56303 .53441 Mdot
.69834 .39457 Mdot
.05992 .44881 Mdot
.33373 .57641 Mdot
.40108 .04428 Mdot
.32943 .17383 Mdot
.50033 .61759 Mdot
.50104 .61662 Mdot
.50332 .61354 Mdot
.51059 .60374 Mdot
.53372 .5727 Mdot
.60707 .48076 Mdot
.82918 .3511 Mdot
.26108 .49829 Mdot
.45483 .53961 Mdot
.58172 .46714 Mdot
.82588 .33604 Mdot
.5 1e-05 Mdot
.49999 2e-05 Mdot
.49995 6e-05 Mdot
.49985 .0002 Mdot
.49954 .00063 Mdot
.49852 .002 Mdot
.49529 .00636 Mdot
.48501 .02024 Mdot
.45226 .06383 Mdot
.34899 .18374 Mdot
.05169 .23082 Mdot
.67821 .09803 Mdot
.50073 .61705 Mdot
.50232 .6149 Mdot
.50738 .60807 Mdot
.52351 .58635 Mdot
.57477 .51956 Mdot
.73409 .37276 Mdot
.13096 .48092 Mdot
.35282 .59873 Mdot
.38405 .07893 Mdot
.25634 .22636 Mdot
.89008 .13237 Mdot
.49963 .0005 Mdot
.49883 .00159 Mdot
.49626 .00505 Mdot
.48809 .01609 Mdot
.46206 .05092 Mdot
.37966 .15215 Mdot
.13348 .26189 Mdot
.70973 .11904 Mdot
.51712 .1032 Mdot
.35014 .22249 Mdot
.99014 .21336 Mdot
.64492 .09682 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49466 .00722 Mdot
.48297 .02298 Mdot
.4458 .07226 Mdot
.32888 .20205 Mdot
.00196 .20386 Mdot
.6721 .07364 Mdot
.55294 .02547 Mdot
.51173 .0146 Mdot
.48811 .02562 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51225 .6015 Mdot
.53901 .56569 Mdot
.6237 .46222 Mdot
.87581 .35842 Mdot
.29587 .49988 Mdot
.48705 .51188 Mdot
.65881 .3879 Mdot
.03118 .41662 Mdot
.35708 .53201 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.4883 .0158 Mdot
.46273 .05003 Mdot
.38178 .14982 Mdot
.13936 .26313 Mdot
.71361 .11943 Mdot
.52037 .10059 Mdot
.35761 .21567 Mdot
.00864 .22368 Mdot
.64672 .10613 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.4922 .01053 Mdot
.47516 .03347 Mdot
.42099 .10375 Mdot
.25313 .25126 Mdot
.84658 .13006 Mdot
.63614 .01869 Mdot
.6059 .54564 Mdot
.72304 .4002 Mdot
.0755 .4676 Mdot
.49962 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48755 .01681 Mdot
.46036 .05318 Mdot
.37431 .15796 Mdot
.11874 .2581 Mdot
.70112 .11746 Mdot
.51107 .10721 Mdot
.33761 .23296 Mdot
.96067 .19687 Mdot
.64213 .08193 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.5108 .60345 Mdot
.53439 .57181 Mdot
.60918 .47835 Mdot
.83519 .35144 Mdot
.26654 .49819 Mdot
.46045 .53448 Mdot
.59565 .45105 Mdot
.86583 .34089 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.51309 .60036 Mdot
.5417 .56214 Mdot
.63213 .45324 Mdot
.89877 .3656 Mdot
.30722 .50371 Mdot
.4922 .51094 Mdot
.66548 .38371 Mdot
.04462 .42454 Mdot
.3577 .53957 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .0133 Mdot
.46863 .0422 Mdot
.40035 .12867 Mdot
.19216 .26657 Mdot
.76084 .11937 Mdot
.56769 .05849 Mdot
.47304 .08336 Mdot
.33816 .20885 Mdot
.00024 .20907 Mdot
.50038 .61752 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51232 .6014 Mdot
.53924 .56539 Mdot
.62441 .46145 Mdot
.87777 .35895 Mdot
.29698 .50012 Mdot
.48777 .51144 Mdot
.66024 .38675 Mdot
.03447 .41845 Mdot
.49994 8e-05 Mdot
.49981 .00026 Mdot
.4994 .00081 Mdot
.49808 .00259 Mdot
.49389 .00826 Mdot
.48053 .02626 Mdot
.43803 .08227 Mdot
.30491 .22112 Mdot
.94712 .173 Mdot
.6672 .04497 Mdot
.59443 .58051 Mdot
.65514 .45841 Mdot
.49983 .00023 Mdot
.49945 .00075 Mdot
.49824 .00238 Mdot
.49439 .00757 Mdot
.48214 .02409 Mdot
.44315 .07568 Mdot
.3207 .2089 Mdot
.98269 .19289 Mdot
.67059 .06333 Mdot
.56812 .00209 Mdot
.56474 .56175 Mdot
.65581 .4393 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50477 .61159 Mdot
.51519 .59753 Mdot
.54837 .55337 Mdot
.653 .43239 Mdot
.95337 .38978 Mdot
.32269 .5222 Mdot
.47775 .54276 Mdot
.59954 .45638 Mdot
.8611 .34335 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .0053 Mdot
.4875 .01687 Mdot
.4602 .05338 Mdot
.37383 .15847 Mdot
.11742 .25772 Mdot
.70042 .11727 Mdot
.51067 .10738 Mdot
.33692 .23346 Mdot
.95917 .19603 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48783 .01643 Mdot
.46124 .05201 Mdot
.37709 .15496 Mdot
.12635 .26017 Mdot
.70538 .11839 Mdot
.51382 .1056 Mdot
.34296 .22868 Mdot
.97294 .20372 Mdot
.64332 .0881 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49718 .00382 Mdot
.491 .01216 Mdot
.47133 .03859 Mdot
.4089 .11851 Mdot
.21714 .26292 Mdot
.79173 .12042 Mdot
.59689 .03604 Mdot
.53857 .00064 Mdot
.53753 .5842 Mdot
.59228 .50337 Mdot
.5009 .61681 Mdot
.50288 .61415 Mdot
.50917 .60565 Mdot
.52921 .57872 Mdot
.59282 .49747 Mdot
.78789 .35409 Mdot
.21496 .49807 Mdot
.40906 .57786 Mdot
.47406 .60181 Mdot
.50031 .60152 Mdot
.52703 .57658 Mdot
.50032 .6176 Mdot
.50101 .61667 Mdot
.50323 .61368 Mdot
.51028 .60416 Mdot
.53273 .57403 Mdot
.60394 .48438 Mdot
.8202 .35095 Mdot
.25235 .49848 Mdot
.44579 .54777 Mdot
.55948 .49391 Mdot
.76031 .34667 Mdot
.49984 .00022 Mdot
.49949 .0007 Mdot
.49836 .00221 Mdot
.49478 .00706 Mdot
.48336 .02245 Mdot
.44704 .07065 Mdot
.33272 .19871 Mdot
.0112 .20908 Mdot
.67289 .07852 Mdot
.54585 .0366 Mdot
.48662 .04899 Mdot
.40734 .13012 Mdot
.50095 .61675 Mdot
.50302 .61396 Mdot
.50961 .60506 Mdot
.53061 .57686 Mdot
.59724 .49222 Mdot
.80081 .35213 Mdot
.23106 .49863 Mdot
.42426 .56622 Mdot
.50809 .55873 Mdot
.60405 .46899 Mdot
.84521 .34707 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00264 Mdot
.49376 .00842 Mdot
.48014 .02679 Mdot
.43679 .08386 Mdot
.30109 .22387 Mdot
.93886 .16858 Mdot
.6661 .04106 Mdot
.59966 .57263 Mdot
.67312 .44196 Mdot
.95801 .40349 Mdot
.50132 .61626 Mdot
.50419 .61237 Mdot
.51336 .6 Mdot
.54253 .56105 Mdot
.63474 .45053 Mdot
.90577 .36819 Mdot
.31003 .50536 Mdot
.49234 .51246 Mdot
.66316 .38634 Mdot
.03806 .42128 Mdot
.35641 .53706 Mdot
.50083 .61692 Mdot
.50263 .61448 Mdot
.50838 .60672 Mdot
.52668 .5821 Mdot
.58483 .50712 Mdot
.76429 .36017 Mdot
.18152 .49427 Mdot
.38177 .59406 Mdot
.42056 .04666 Mdot
.34506 .16866 Mdot
.07217 .23329 Mdot
.49965 .00047 Mdot
.49889 .00149 Mdot
.49648 .00476 Mdot
.48878 .01516 Mdot
.46426 .04801 Mdot
.38657 .14449 Mdot
.15277 .26535 Mdot
.72342 .11986 Mdot
.52949 .09268 Mdot
.37953 .194 Mdot
.06564 .25314 Mdot
.65606 .13056 Mdot
.49976 .00032 Mdot
.49923 .00103 Mdot
.49756 .0033 Mdot
.49222 .0105 Mdot
.47523 .03338 Mdot
.42123 .10346 Mdot
.25383 .25096 Mdot
.84777 .13039 Mdot
.63679 .01862 Mdot
.60666 .54501 Mdot
.72482 .39931 Mdot
.07873 .46935 Mdot
.50052 .61734 Mdot
.50165 .61581 Mdot
.50525 .61095 Mdot
.51672 .59548 Mdot
.55321 .54706 Mdot
.66804 .41865 Mdot
.99065 .40999 Mdot
.32727 .54048 Mdot
.45275 .58364 Mdot
.5084 .57586 Mdot
.57664 .50753 Mdot
.50094 .61676 Mdot
.50301 .61397 Mdot
.50958 .60509 Mdot
.53052 .57697 Mdot
.59696 .49255 Mdot
.8 .35222 Mdot
.23009 .49861 Mdot
.42331 .56699 Mdot
.5059 .56152 Mdot
.59734 .4768 Mdot
.82586 .3457 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49593 .0055 Mdot
.48702 .01752 Mdot
.45868 .05539 Mdot
.36905 .16355 Mdot
.10442 .25355 Mdot
.69416 .115 Mdot
.50808 .10751 Mdot
.33412 .23492 Mdot
.95401 .19288 Mdot
.64193 .07807 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48657 .01813 Mdot
.45723 .0573 Mdot
.36452 .16827 Mdot
.09224 .24908 Mdot
.68922 .11216 Mdot
.50774 .10499 Mdot
.33786 .23062 Mdot
.96471 .19817 Mdot
.64406 .08212 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .6123 Mdot
.51351 .59979 Mdot
.54303 .56039 Mdot
.6363 .44892 Mdot
.90993 .36981 Mdot
.31157 .50645 Mdot
.49212 .51375 Mdot
.66085 .38876 Mdot
.03182 .41806 Mdot
.49978 .0003 Mdot
.49928 .00097 Mdot
.49772 .00308 Mdot
.49274 .00981 Mdot
.47687 .03118 Mdot
.42642 .09699 Mdot
.26948 .24343 Mdot
.8756 .1395 Mdot
.64989 .02019 Mdot
.61722 .53911 Mdot
.74492 .39165 Mdot
.11122 .48656 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00535 Mdot
.48738 .01703 Mdot
.45982 .05388 Mdot
.37264 .15975 Mdot
.11415 .25673 Mdot
.69875 .11677 Mdot
.5098 .10769 Mdot
.33555 .23443 Mdot
.95624 .19437 Mdot
.64174 .07966 Mdot
.50097 .61672 Mdot
.5031 .61385 Mdot
.50987 .6047 Mdot
.53145 .57574 Mdot
.59989 .4891 Mdot
.80851 .35141 Mdot
.23992 .49866 Mdot
.43307 .5589 Mdot
.52875 .53238 Mdot
.66734 .4043 Mdot
.01317 .41649 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.49589 .00555 Mdot
.48692 .01766 Mdot
.45835 .05583 Mdot
.36801 .16464 Mdot
.10162 .25257 Mdot
.69295 .11441 Mdot
.50783 .10716 Mdot
.33445 .23441 Mdot
.95515 .19339 Mdot
.64225 .07839 Mdot
.5008 .61695 Mdot
.50255 .61459 Mdot
.50811 .60708 Mdot
.52584 .58323 Mdot
.58215 .51041 Mdot
.75628 .36298 Mdot
.16896 .49181 Mdot
.37319 .59732 Mdot
.40671 .06091 Mdot
.30816 .19871 Mdot
.98664 .18634 Mdot
.50063 .61718 Mdot
.50202 .6153 Mdot
.50644 .60933 Mdot
.52053 .59035 Mdot
.56531 .53149 Mdot
.70535 .38971 Mdot
.07478 .45651 Mdot
.33612 .58298 Mdot
.39285 .05694 Mdot
.30071 .19706 Mdot
.98185 .18028 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49738 .00354 Mdot
.49165 .01128 Mdot
.4734 .03582 Mdot
.41545 .11057 Mdot
.23654 .25759 Mdot
.81975 .12399 Mdot
.61914 .02357 Mdot
.581 .56972 Mdot
.65918 .44555 Mdot
.93826 .38974 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.5043 .61223 Mdot
.51369 .59956 Mdot
.54359 .55965 Mdot
.63805 .44713 Mdot
.91458 .37169 Mdot
.31318 .50776 Mdot
.49161 .51554 Mdot
.65745 .39224 Mdot
.02279 .4133 Mdot
.50067 .61713 Mdot
.50214 .61514 Mdot
.50683 .60881 Mdot
.52175 .58871 Mdot
.5692 .52656 Mdot
.71721 .38214 Mdot
.0989 .46803 Mdot
.34161 .5918 Mdot
.38405 .072 Mdot
.26754 .21865 Mdot
.91375 .14255 Mdot
.5002 .61777 Mdot
.50062 .61719 Mdot
.50199 .61535 Mdot
.50634 .60947 Mdot
.52019 .59081 Mdot
.56425 .53285 Mdot
.70208 .39194 Mdot
.0679 .453 Mdot
.33493 .58003 Mdot
.39643 .05137 Mdot
.31331 .18739 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00172 Mdot
.49593 .00549 Mdot
.48705 .01749 Mdot
.45875 .0553 Mdot
.36928 .16331 Mdot
.10503 .25377 Mdot
.69443 .11512 Mdot
.50815 .10757 Mdot
.3341 .23499 Mdot
.95387 .19283 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00525 Mdot
.48762 .01672 Mdot
.46057 .0529 Mdot
.37497 .15726 Mdot
.12052 .25861 Mdot
.70208 .1177 Mdot
.51164 .10692 Mdot
.33864 .23216 Mdot
.96299 .19816 Mdot
.64235 .0831 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.4986 .0019 Mdot
.49553 .00604 Mdot
.48575 .01924 Mdot
.45462 .06074 Mdot
.35634 .17656 Mdot
.07067 .23994 Mdot
.68244 .10549 Mdot
.51176 .09459 Mdot
.3587 .20904 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50583 .61015 Mdot
.51858 .59296 Mdot
.55915 .53938 Mdot
.68641 .40346 Mdot
.0336 .43438 Mdot
.33076 .56333 Mdot
.41927 .01697 Mdot
.39182 .10971 Mdot
.21432 .25356 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48872 .01524 Mdot
.46406 .04827 Mdot
.38596 .14518 Mdot
.15106 .26512 Mdot
.72209 .11983 Mdot
.5282 .09383 Mdot
.37637 .19726 Mdot
.05721 .24915 Mdot
.65406 .12761 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49614 .00521 Mdot
.48772 .01659 Mdot
.46088 .05249 Mdot
.37594 .1562 Mdot
.12321 .25935 Mdot
.70357 .11804 Mdot
.51259 .10638 Mdot
.34046 .23073 Mdot
.96713 .20047 Mdot
.64276 .08517 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60223 Mdot
.53727 .568 Mdot
.61823 .4682 Mdot
.86066 .35491 Mdot
.28641 .49861 Mdot
.47964 .51743 Mdot
.64242 .40233 Mdot
.99143 .39439 Mdot
.50035 .61755 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51148 .60253 Mdot
.53656 .56894 Mdot
.616 .47067 Mdot
.85444 .35377 Mdot
.28203 .49834 Mdot
.4757 .52077 Mdot
.63307 .41129 Mdot
.96759 .38145 Mdot
.50098 .61671 Mdot
.50312 .61382 Mdot
.50995 .6046 Mdot
.53168 .57543 Mdot
.60062 .48824 Mdot
.81063 .35127 Mdot
.24226 .49864 Mdot
.43544 .55686 Mdot
.53442 .52521 Mdot
.68462 .38994 Mdot
.05369 .43877 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48701 .01754 Mdot
.45863 .05546 Mdot
.36888 .16373 Mdot
.10397 .2534 Mdot
.69396 .11491 Mdot
.50803 .10746 Mdot
.33415 .23486 Mdot
.95414 .19293 Mdot
.50074 .61703 Mdot
.50237 .61483 Mdot
.50755 .60784 Mdot
.52404 .58564 Mdot
.57644 .51747 Mdot
.73916 .37027 Mdot
.14005 .48398 Mdot
.35695 .59945 Mdot
.38702 .07758 Mdot
.26149 .22474 Mdot
.89785 .13641 Mdot
.50031 .61762 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50996 .60459 Mdot
.53171 .57538 Mdot
.60073 .48811 Mdot
.81095 .35125 Mdot
.24261 .49864 Mdot
.43579 .55656 Mdot
.53525 .52415 Mdot
.68717 .38795 Mdot
.50098 .61671 Mdot
.50311 .61383 Mdot
.50992 .60463 Mdot
.53161 .57552 Mdot
.60039 .48851 Mdot
.80996 .35131 Mdot
.24152 .49865 Mdot
.43469 .55751 Mdot
.53263 .52747 Mdot
.67916 .3943 Mdot
.04117 .43205 Mdot
.50051 .61735 Mdot
.50161 .61586 Mdot
.50514 .6111 Mdot
.51636 .59596 Mdot
.55208 .54853 Mdot
.66454 .42175 Mdot
.98213 .40522 Mdot
.32647 .53606 Mdot
.45911 .57355 Mdot
.53108 .54493 Mdot
.64936 .42591 Mdot
.50013 .61785 Mdot
.50042 .61746 Mdot
.50135 .61621 Mdot
.50431 .61221 Mdot
.51373 .59949 Mdot
.54373 .55946 Mdot
.63851 .44666 Mdot
.91581 .3722 Mdot
.31358 .50812 Mdot
.49142 .51607 Mdot
.65641 .39331 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.50229 .61494 Mdot
.50729 .60819 Mdot
.52322 .58674 Mdot
.57385 .5207 Mdot
.73134 .37417 Mdot
.12591 .4791 Mdot
.35071 .59807 Mdot
.38301 .07899 Mdot
.2552 .22646 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49579 .00568 Mdot
.4866 .01809 Mdot
.45732 .05719 Mdot
.36478 .168 Mdot
.09295 .24936 Mdot
.68949 .11235 Mdot
.50771 .10521 Mdot
.33748 .23102 Mdot
.96368 .19764 Mdot
.64389 .08169 Mdot
.50047 .6174 Mdot
.50149 .61601 Mdot
.50476 .6116 Mdot
.51517 .59756 Mdot
.54829 .55347 Mdot
.65276 .43262 Mdot
.95276 .38947 Mdot
.32259 .52193 Mdot
.47808 .54218 Mdot
.60081 .45485 Mdot
.86485 .34408 Mdot
.50066 .61714 Mdot
.5021 .61519 Mdot
.5067 .60899 Mdot
.52133 .58927 Mdot
.56787 .52824 Mdot
.71316 .38463 Mdot
.09082 .46433 Mdot
.33952 .58914 Mdot
.38627 .06779 Mdot
.27657 .21329 Mdot
.93147 .1517 Mdot
.50092 .6168 Mdot
.50292 .61409 Mdot
.5093 .60548 Mdot
.52962 .57818 Mdot
.59411 .49593 Mdot
.79168 .35342 Mdot
.21984 .49832 Mdot
.41354 .57458 Mdot
.48385 .58953 Mdot
.52996 .56193 Mdot
.62074 .46042 Mdot
.50083 .61692 Mdot
.50264 .61447 Mdot
.5084 .60669 Mdot
.52676 .582 Mdot
.58506 .50685 Mdot
.76495 .35996 Mdot
.18253 .49444 Mdot
.38251 .59374 Mdot
.42182 .0453 Mdot
.34853 .16546 Mdot
.08082 .2372 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48701 .01754 Mdot
.45864 .05545 Mdot
.36892 .16369 Mdot
.10406 .25343 Mdot
.694 .11493 Mdot
.50804 .10747 Mdot
.33415 .23487 Mdot
.95412 .19292 Mdot
.64196 .07809 Mdot
.50131 .61626 Mdot
.50418 .61238 Mdot
.51332 .60005 Mdot
.54242 .56118 Mdot
.63441 .45087 Mdot
.90488 .36785 Mdot
.30969 .50514 Mdot
.49236 .51222 Mdot
.66357 .3859 Mdot
.03917 .42185 Mdot
.35661 .53751 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49386 .0083 Mdot
.48042 .0264 Mdot
.4377 .08269 Mdot
.30391 .22185 Mdot
.94494 .17182 Mdot
.66693 .04392 Mdot
.59586 .57837 Mdot
.66003 .45378 Mdot
.92581 .38746 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46802 .04301 Mdot
.39843 .13091 Mdot
.18661 .26691 Mdot
.75474 .11943 Mdot
.56151 .06381 Mdot
.45825 .10207 Mdot
.50127 .61632 Mdot
.50403 .61259 Mdot
.51285 .60069 Mdot
.54091 .56318 Mdot
.62967 .45583 Mdot
.89213 .36331 Mdot
.30428 .50235 Mdot
.49146 .51027 Mdot
.66582 .38289 Mdot
.0463 .42521 Mdot
.3583 .53989 Mdot
.50013 .61786 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50405 .61256 Mdot
.51292 .60059 Mdot
.54114 .56288 Mdot
.63039 .45508 Mdot
.89406 .36396 Mdot
.30516 .50273 Mdot
.49173 .51039 Mdot
.66591 .38296 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.5047 .61168 Mdot
.51498 .59782 Mdot
.54769 .55426 Mdot
.65088 .43442 Mdot
.94798 .38704 Mdot
.32173 .51986 Mdot
.48058 .53782 Mdot
.61038 .4435 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49684 .00427 Mdot
.48994 .01359 Mdot
.46794 .04311 Mdot
.39819 .13119 Mdot
.18592 .26694 Mdot
.75401 .11944 Mdot
.56075 .06447 Mdot
.45644 .10436 Mdot
.28758 .24781 Mdot
.50115 .61648 Mdot
.50367 .61308 Mdot
.51168 .60226 Mdot
.53719 .5681 Mdot
.618 .46846 Mdot
.86002 .35478 Mdot
.28597 .49857 Mdot
.47926 .51775 Mdot
.64152 .40317 Mdot
.98918 .39315 Mdot
.35306 .51083 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60311 Mdot
.5352 .57074 Mdot
.61173 .47545 Mdot
.84243 .3521 Mdot
.27272 .49815 Mdot
.4667 .52879 Mdot
.61111 .43395 Mdot
.90896 .35408 Mdot
.33605 .48058 Mdot
.50112 .61653 Mdot
.50356 .61323 Mdot
.51133 .60274 Mdot
.53607 .56958 Mdot
.61447 .47238 Mdot
.85014 .35309 Mdot
.27882 .49822 Mdot
.47268 .52342 Mdot
.62577 .41859 Mdot
.94848 .37166 Mdot
.34713 .49257 Mdot
.50003 .61799 Mdot
.50011 .61789 Mdot
.50035 .61756 Mdot
.50111 .61653 Mdot
.50354 .61325 Mdot
.51129 .60279 Mdot
.53594 .56975 Mdot
.61406 .47284 Mdot
.849 .35293 Mdot
.27795 .4982 Mdot
.47185 .52416 Mdot
.50023 .61773 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50734 .60812 Mdot
.52338 .58653 Mdot
.57435 .52008 Mdot
.73284 .3734 Mdot
.12867 .4801 Mdot
.35185 .59846 Mdot
.38352 .07902 Mdot
.25567 .22647 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00422 Mdot
.49005 .01343 Mdot
.46832 .0426 Mdot
.39939 .12979 Mdot
.18939 .26676 Mdot
.75776 .11939 Mdot
.56458 .06115 Mdot
.46564 .09276 Mdot
.31555 .22797 Mdot
.94669 .17947 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49835 .00223 Mdot
.49475 .0071 Mdot
.48327 .02258 Mdot
.44673 .07105 Mdot
.33177 .19954 Mdot
.00891 .2078 Mdot
.67269 .07732 Mdot
.54758 .03386 Mdot
.49279 .04055 Mdot
.42717 .10573 Mdot
.50038 .61752 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51236 .60134 Mdot
.53937 .56522 Mdot
.62482 .46101 Mdot
.8789 .35926 Mdot
.2976 .50026 Mdot
.48816 .51122 Mdot
.66099 .38615 Mdot
.03618 .41941 Mdot
.50105 .61662 Mdot
.50333 .61353 Mdot
.51062 .60369 Mdot
.53383 .57256 Mdot
.6074 .48038 Mdot
.83013 .35115 Mdot
.26196 .49827 Mdot
.45574 .53878 Mdot
.58398 .46448 Mdot
.83243 .33629 Mdot
.2883 .47958 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50687 .60876 Mdot
.52188 .58854 Mdot
.56961 .52605 Mdot
.71845 .38139 Mdot
.10134 .46912 Mdot
.34229 .59255 Mdot
.38353 .0731 Mdot
.26525 .21997 Mdot
.50058 .61725 Mdot
.50186 .61553 Mdot
.50591 .61004 Mdot
.51884 .59262 Mdot
.55996 .53834 Mdot
.68892 .40153 Mdot
.03923 .43753 Mdot
.3313 .56624 Mdot
.4151 .02324 Mdot
.37749 .12592 Mdot
.17375 .25685 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.5122 .60156 Mdot
.53886 .56589 Mdot
.62324 .46272 Mdot
.87454 .35809 Mdot
.29514 .49974 Mdot
.48655 .5122 Mdot
.65779 .38873 Mdot
.02882 .4153 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.49241 .01026 Mdot
.47581 .03259 Mdot
.42307 .10117 Mdot
.25938 .24845 Mdot
.85738 .13323 Mdot
.6418 .01849 Mdot
.61188 .54114 Mdot
.73629 .39415 Mdot
.09855 .47978 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50891 .606 Mdot
.52839 .57981 Mdot
.59023 .50057 Mdot
.78028 .35569 Mdot
.20476 .49732 Mdot
.40008 .58398 Mdot
.45519 .00694 Mdot
.44395 .05783 Mdot
.35038 .17699 Mdot
.50099 .61669 Mdot
.50316 .61376 Mdot
.51007 .60444 Mdot
.53207 .5749 Mdot
.60186 .48679 Mdot
.81422 .35109 Mdot
.24614 .49859 Mdot
.43939 .55343 Mdot
.54392 .51323 Mdot
.71349 .36955 Mdot
.11555 .4675 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50888 .60603 Mdot
.5283 .57994 Mdot
.58995 .50092 Mdot
.77944 .35589 Mdot
.20359 .49721 Mdot
.39909 .58461 Mdot
.45317 .00937 Mdot
.438 .0654 Mdot
.33218 .19371 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01088 Mdot
.47433 .03458 Mdot
.41838 .10697 Mdot
.24531 .25445 Mdot
.8336 .1268 Mdot
.62844 .02023 Mdot
.59571 .55479 Mdot
.69804 .41504 Mdot
.02649 .43948 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50904 .60582 Mdot
.52881 .57926 Mdot
.59155 .49899 Mdot
.78418 .35483 Mdot
.21005 .49775 Mdot
.40467 .58093 Mdot
.4647 .61339 Mdot
.47222 .02097 Mdot
.43829 .07676 Mdot
.50027 .61767 Mdot
.50087 .61686 Mdot
.50276 .6143 Mdot
.50879 .60616 Mdot
.52801 .58032 Mdot
.58904 .50201 Mdot
.77676 .35655 Mdot
.19985 .49683 Mdot
.39596 .58656 Mdot
.4469 .01684 Mdot
.41965 .08821 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48859 .0154 Mdot
.46367 .04879 Mdot
.38473 .14655 Mdot
.14761 .2646 Mdot
.71948 .11976 Mdot
.52571 .09603 Mdot
.37032 .20338 Mdot
.04125 .24119 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01007 Mdot
.47626 .03199 Mdot
.4245 .09939 Mdot
.26368 .24639 Mdot
.86501 .13572 Mdot
.64541 .01891 Mdot
.61481 .5395 Mdot
.74188 .39215 Mdot
.10738 .48431 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49822 .00241 Mdot
.49432 .00768 Mdot
.4819 .02442 Mdot
.44238 .07668 Mdot
.31832 .21084 Mdot
.97718 .18975 Mdot
.67015 .06039 Mdot
.57245 .61355 Mdot
.5797 .54272 Mdot
.70155 .40196 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48783 .01643 Mdot
.46125 .052 Mdot
.3771 .15495 Mdot
.12639 .26019 Mdot
.7054 .1184 Mdot
.51384 .10558 Mdot
.343 .22865 Mdot
.97303 .20377 Mdot
.64333 .08814 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51303 .60044 Mdot
.5415 .5624 Mdot
.63152 .45389 Mdot
.89711 .36501 Mdot
.30651 .50335 Mdot
.49207 .5107 Mdot
.66574 .38335 Mdot
.04546 .42493 Mdot
.35791 .53984 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49822 .00241 Mdot
.49432 .00767 Mdot
.48191 .0244 Mdot
.44243 .07661 Mdot
.31847 .21071 Mdot
.97753 .18995 Mdot
.67018 .06057 Mdot
.57217 .61397 Mdot
.57875 .5439 Mdot
.6987 .40395 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00443 Mdot
.48954 .01412 Mdot
.4667 .04477 Mdot
.39425 .13575 Mdot
.17461 .26705 Mdot
.74252 .11966 Mdot
.5489 .07504 Mdot
.42747 .13998 Mdot
.20099 .28058 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49685 .00426 Mdot
.48996 .01356 Mdot
.46802 .04301 Mdot
.39842 .13092 Mdot
.18658 .26691 Mdot
.75472 .11943 Mdot
.56148 .06384 Mdot
.45819 .10215 Mdot
.29291 .24436 Mdot
.89753 .15579 Mdot
.49998 3e-05 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49755 .00331 Mdot
.49218 .01056 Mdot
.4751 .03355 Mdot
.42081 .10397 Mdot
.25258 .2515 Mdot
.84565 .12981 Mdot
.63562 .01875 Mdot
.60528 .54615 Mdot
.50054 .61731 Mdot
.50172 .61571 Mdot
.50547 .61064 Mdot
.51744 .59451 Mdot
.55551 .54408 Mdot
.67516 .41255 Mdot
.00764 .41963 Mdot
.32866 .54952 Mdot
.43952 .60425 Mdot
.46182 .02128 Mdot
.42739 .08628 Mdot
.49979 .00028 Mdot
.49933 .0009 Mdot
.49787 .00288 Mdot
.49321 .00917 Mdot
.47837 .02917 Mdot
.43118 .091 Mdot
.28394 .2352 Mdot
.90337 .15103 Mdot
.65901 .02694 Mdot
.61541 .54712 Mdot
.73015 .40072 Mdot
.08177 .47323 Mdot
.50085 .61688 Mdot
.50272 .61436 Mdot
.50866 .60633 Mdot
.5276 .58087 Mdot
.58773 .5036 Mdot
.77288 .35758 Mdot
.19431 .49618 Mdot
.39147 .58918 Mdot
.43815 .02705 Mdot
.39439 .11792 Mdot
.20359 .25924 Mdot
.50087 .61686 Mdot
.50276 .6143 Mdot
.5088 .60614 Mdot
.52804 .58028 Mdot
.58913 .5019 Mdot
.77704 .35648 Mdot
.20024 .49687 Mdot
.39628 .58636 Mdot
.44753 .01609 Mdot
.42149 .08596 Mdot
.28241 .23045 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50831 .60682 Mdot
.52646 .5824 Mdot
.58411 .508 Mdot
.76215 .36089 Mdot
.17822 .49368 Mdot
.37943 .59507 Mdot
.41659 .05086 Mdot
.3343 .17819 Mdot
.04598 .22023 Mdot
.50044 .61743 Mdot
.50141 .61612 Mdot
.50451 .61194 Mdot
.51436 .59865 Mdot
.54573 .55684 Mdot
.64475 .44039 Mdot
.93218 .37941 Mdot
.31829 .51358 Mdot
.4873 .52534 Mdot
.63729 .41327 Mdot
.96861 .38436 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46591 .04582 Mdot
.39178 .13859 Mdot
.16754 .26677 Mdot
.7359 .1198 Mdot
.54206 .08127 Mdot
.41056 .15988 Mdot
.15187 .28026 Mdot
.6984 .1404 Mdot
.49974 .00035 Mdot
.49916 .00113 Mdot
.49734 .0036 Mdot
.49152 .01145 Mdot
.47299 .03638 Mdot
.41413 .11218 Mdot
.23263 .25884 Mdot
.81381 .123 Mdot
.6148 .02557 Mdot
.57343 .57792 Mdot
.63833 .46522 Mdot
.88559 .36806 Mdot
.50024 .61771 Mdot
.50077 .617 Mdot
.50244 .61473 Mdot
.50779 .60751 Mdot
.52482 .5846 Mdot
.57891 .51441 Mdot
.74659 .36689 Mdot
.15294 .48784 Mdot
.36359 .59937 Mdot
.39379 .07266 Mdot
.27622 .2182 Mdot
.50089 .61683 Mdot
.50284 .6142 Mdot
.50905 .60581 Mdot
.52882 .57924 Mdot
.59159 .49894 Mdot
.7843 .3548 Mdot
.21021 .49776 Mdot
.40482 .58084 Mdot
.465 .61302 Mdot
.47312 .01979 Mdot
.44109 .07316 Mdot
.49977 .00031 Mdot
.49928 .00097 Mdot
.4977 .0031 Mdot
.49268 .00989 Mdot
.47668 .03142 Mdot
.42584 .09771 Mdot
.26773 .24434 Mdot
.87238 .13831 Mdot
.64859 .01972 Mdot
.61669 .53901 Mdot
.74455 .39155 Mdot
.11101 .48632 Mdot
.49988 .00016 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48754 .01682 Mdot
.46032 .05323 Mdot
.37419 .15809 Mdot
.1184 .258 Mdot
.70094 .11741 Mdot
.51097 .10725 Mdot
.33743 .23309 Mdot
.96027 .19665 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00399 Mdot
.4906 .0127 Mdot
.47005 .0403 Mdot
.40485 .12335 Mdot
.20526 .2651 Mdot
.77632 .11957 Mdot
.58285 .04619 Mdot
.50811 .03868 Mdot
.44553 .0882 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48655 .01816 Mdot
.45717 .05738 Mdot
.36433 .16847 Mdot
.09174 .24888 Mdot
.68904 .11203 Mdot
.50777 .10483 Mdot
.33815 .23032 Mdot
.96548 .19857 Mdot
.64419 .08245 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50337 .61347 Mdot
.51075 .60351 Mdot
.53424 .57201 Mdot
.60871 .47889 Mdot
.83385 .35135 Mdot
.26535 .49821 Mdot
.45922 .5356 Mdot
.59261 .45451 Mdot
.85719 .33918 Mdot
.50129 .61629 Mdot
.50412 .61247 Mdot
.51312 .60032 Mdot
.54179 .56202 Mdot
.63242 .45294 Mdot
.89954 .36587 Mdot
.30754 .50388 Mdot
.49225 .51106 Mdot
.66533 .38391 Mdot
.04414 .42431 Mdot
.35759 .53941 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.49719 .0038 Mdot
.49105 .01209 Mdot
.47148 .03839 Mdot
.40937 .11794 Mdot
.21854 .26261 Mdot
.79362 .12057 Mdot
.59853 .03496 Mdot
.54196 .61454 Mdot
.54762 .57105 Mdot
.62365 .4676 Mdot
.50056 .61728 Mdot
.50178 .61562 Mdot
.50569 .61035 Mdot
.51812 .59359 Mdot
.55766 .5413 Mdot
.68181 .4071 Mdot
.02311 .42845 Mdot
.32987 .5578 Mdot
.42733 .00482 Mdot
.41952 .07629 Mdot
.29608 .2177 Mdot
.50021 .61776 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60904 Mdot
.52121 .58943 Mdot
.56749 .52872 Mdot
.71201 .38536 Mdot
.08848 .46322 Mdot
.33897 .58831 Mdot
.38706 .06641 Mdot
.2796 .21141 Mdot
.49959 .00056 Mdot
.49868 .00178 Mdot
.49581 .00567 Mdot
.48664 .01804 Mdot
.45745 .05702 Mdot
.36519 .16758 Mdot
.09403 .24977 Mdot
.68989 .11262 Mdot
.50767 .10552 Mdot
.33693 .23159 Mdot
.96221 .19689 Mdot
.64364 .08108 Mdot
.501 .61668 Mdot
.50319 .61372 Mdot
.51018 .60429 Mdot
.53242 .57444 Mdot
.60295 .48552 Mdot
.81736 .35099 Mdot
.24944 .49854 Mdot
.44279 .55044 Mdot
.55215 .50295 Mdot
.73836 .3558 Mdot
.16266 .48168 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .0019 Mdot
.49551 .00606 Mdot
.48571 .01929 Mdot
.45449 .06091 Mdot
.35594 .17695 Mdot
.06963 .23946 Mdot
.68217 .10511 Mdot
.51209 .09392 Mdot
.36013 .20752 Mdot
.02435 .23001 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49959 .00056 Mdot
.49868 .00179 Mdot
.49579 .00569 Mdot
.48658 .01812 Mdot
.45726 .05726 Mdot
.36461 .16818 Mdot
.0925 .24918 Mdot
.68932 .11223 Mdot
.50773 .10507 Mdot
.33772 .23077 Mdot
.50008 .61792 Mdot
.50027 .61767 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50873 .60624 Mdot
.52782 .58058 Mdot
.58843 .50275 Mdot
.77497 .35701 Mdot
.19731 .49655 Mdot
.39388 .5878 Mdot
.4428 .02166 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49725 .00371 Mdot
.49125 .01182 Mdot
.47213 .03752 Mdot
.41142 .11547 Mdot
.22459 .26114 Mdot
.80206 .12141 Mdot
.60561 .03054 Mdot
.55619 .59756 Mdot
.58933 .51903 Mdot
.74952 .37148 Mdot
.49966 .00047 Mdot
.4989 .00148 Mdot
.4965 .00473 Mdot
.48885 .01506 Mdot
.46449 .0477 Mdot
.38731 .14366 Mdot
.15486 .26562 Mdot
.72508 .11988 Mdot
.53112 .09122 Mdot
.38352 .18981 Mdot
.0764 .25795 Mdot
.65903 .13386 Mdot
.50034 .61757 Mdot
.50109 .61656 Mdot
.50347 .61335 Mdot
.51105 .60312 Mdot
.53519 .57076 Mdot
.61167 .47552 Mdot
.84226 .35208 Mdot
.27258 .49815 Mdot
.46656 .52892 Mdot
.61076 .43433 Mdot
.908 .35371 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.50551 .61059 Mdot
.51756 .59435 Mdot
.55588 .5436 Mdot
.67631 .41159 Mdot
.01035 .42118 Mdot
.32887 .55097 Mdot
.43738 .60754 Mdot
.45436 .03123 Mdot
.40383 .11506 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49887 .00153 Mdot
.4964 .00487 Mdot
.48853 .01549 Mdot
.46346 .04907 Mdot
.38406 .1473 Mdot
.14572 .26429 Mdot
.71809 .1197 Mdot
.52441 .09717 Mdot
.36719 .20649 Mdot
.03309 .23694 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00298 Mdot
.49298 .00948 Mdot
.47764 .03014 Mdot
.42886 .09392 Mdot
.2769 .23936 Mdot
.8896 .14503 Mdot
.65494 .02303 Mdot
.61768 .54164 Mdot
.74128 .39432 Mdot
.50007 .61794 Mdot
.50023 .61773 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50728 .6082 Mdot
.52318 .58679 Mdot
.57374 .52084 Mdot
.731 .37435 Mdot
.1253 .47887 Mdot
.35047 .59798 Mdot
.38291 .07897 Mdot
.50005 .61796 Mdot
.50017 .61781 Mdot
.50054 .61731 Mdot
.50171 .61572 Mdot
.50545 .61068 Mdot
.51735 .59462 Mdot
.55524 .54444 Mdot
.67432 .41326 Mdot
.00565 .4185 Mdot
.32851 .54845 Mdot
.44109 .60182 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50741 .60803 Mdot
.5236 .58623 Mdot
.57506 .5192 Mdot
.73497 .37231 Mdot
.13256 .48148 Mdot
.35351 .5989 Mdot
.38447 .07881 Mdot
.25695 .22621 Mdot
.89093 .13283 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.50702 .60856 Mdot
.52235 .5879 Mdot
.57111 .52415 Mdot
.72301 .37873 Mdot
.11022 .47293 Mdot
.345 .59496 Mdot
.38234 .07634 Mdot
.25882 .22366 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.4983 .0023 Mdot
.49458 .00732 Mdot
.48274 .02329 Mdot
.44505 .07322 Mdot
.32658 .20401 Mdot
.99648 .20075 Mdot
.67166 .07072 Mdot
.55723 .0188 Mdot
.5268 .61211 Mdot
.5364 .57866 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00382 Mdot
.49099 .01216 Mdot
.47131 .03862 Mdot
.40883 .11859 Mdot
.21695 .26296 Mdot
.79146 .1204 Mdot
.59665 .0362 Mdot
.53808 .00123 Mdot
.53608 .5861 Mdot
.58775 .50882 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49014 .01332 Mdot
.46859 .04225 Mdot
.40023 .1288 Mdot
.19183 .2666 Mdot
.76046 .11937 Mdot
.56732 .05881 Mdot
.47216 .08449 Mdot
.33545 .21128 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61506 Mdot
.507 .60857 Mdot
.52231 .58796 Mdot
.57098 .52432 Mdot
.72261 .37895 Mdot
.10946 .47261 Mdot
.34475 .59477 Mdot
.3824 .07611 Mdot
.25925 .2234 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51485 .59799 Mdot
.54728 .5548 Mdot
.64961 .43564 Mdot
.94472 .38542 Mdot
.3211 .51849 Mdot
.48217 .53499 Mdot
.61654 .43635 Mdot
.91051 .35769 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00368 Mdot
.49132 .01172 Mdot
.47236 .03721 Mdot
.41216 .11457 Mdot
.22678 .26055 Mdot
.80521 .12179 Mdot
.60814 .02907 Mdot
.5611 .59184 Mdot
.60348 .50253 Mdot
.79037 .35971 Mdot
.49977 .00032 Mdot
.49925 .00101 Mdot
.49762 .00322 Mdot
.4924 .01026 Mdot
.4758 .03261 Mdot
.42304 .1012 Mdot
.25929 .2485 Mdot
.85722 .13318 Mdot
.64172 .01849 Mdot
.61181 .54119 Mdot
.73614 .3942 Mdot
.09831 .47965 Mdot
.50098 .61671 Mdot
.50313 .61381 Mdot
.50997 .60458 Mdot
.53174 .57534 Mdot
.60082 .488 Mdot
.81121 .35124 Mdot
.2429 .49864 Mdot
.43609 .55631 Mdot
.53596 .52325 Mdot
.68932 .38631 Mdot
.06426 .44427 Mdot
.49966 .00045 Mdot
.49893 .00145 Mdot
.49658 .00461 Mdot
.48912 .0147 Mdot
.46534 .04657 Mdot
.38998 .14063 Mdot
.16243 .2664 Mdot
.73138 .11987 Mdot
.53743 .08549 Mdot
.39911 .17287 Mdot
.1194 .27347 Mdot
.67692 .14121 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01184 Mdot
.47208 .03759 Mdot
.41125 .11567 Mdot
.22409 .26127 Mdot
.80135 .12133 Mdot
.60503 .03088 Mdot
.55506 .59888 Mdot
.58605 .52294 Mdot
.7399 .3757 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00183 Mdot
.49568 .00584 Mdot
.48624 .01858 Mdot
.45617 .0587 Mdot
.36119 .17168 Mdot
.0834 .24551 Mdot
.68616 .10967 Mdot
.5087 .10161 Mdot
.34429 .22401 Mdot
.98184 .20721 Mdot
.5001 .6179 Mdot
.50031 .61761 Mdot
.501 .61669 Mdot
.50318 .61374 Mdot
.51013 .60435 Mdot
.53227 .57465 Mdot
.60247 .48608 Mdot
.81598 .35103 Mdot
.248 .49856 Mdot
.4413 .55175 Mdot
.54855 .50744 Mdot
.50038 .61752 Mdot
.50122 .61638 Mdot
.50389 .61277 Mdot
.51241 .60129 Mdot
.53951 .56504 Mdot
.62526 .46054 Mdot
.88009 .3596 Mdot
.29825 .50041 Mdot
.48856 .51101 Mdot
.66173 .38558 Mdot
.03784 .42033 Mdot
.50038 .61752 Mdot
.5012 .61641 Mdot
.50383 .61286 Mdot
.51219 .60157 Mdot
.53884 .56592 Mdot
.62315 .46281 Mdot
.87431 .35803 Mdot
.295 .49971 Mdot
.48645 .51226 Mdot
.6576 .38889 Mdot
.02836 .41504 Mdot
.49972 .00038 Mdot
.49911 .0012 Mdot
.49717 .00383 Mdot
.49098 .01219 Mdot
.47125 .03869 Mdot
.40864 .11881 Mdot
.2164 .26308 Mdot
.79073 .12034 Mdot
.59601 .03663 Mdot
.53674 .00288 Mdot
.53208 .59137 Mdot
.57522 .52421 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00177 Mdot
.49584 .00562 Mdot
.48674 .01791 Mdot
.45776 .05661 Mdot
.36617 .16657 Mdot
.09666 .25076 Mdot
.69091 .11327 Mdot
.50764 .1062 Mdot
.33581 .23281 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00552 Mdot
.48697 .01759 Mdot
.45851 .05561 Mdot
.36853 .1641 Mdot
.10302 .25307 Mdot
.69355 .11471 Mdot
.50794 .10735 Mdot
.33424 .2347 Mdot
.95448 .19308 Mdot
.64207 .07818 Mdot
.50116 .61647 Mdot
.50369 .61304 Mdot
.51177 .60214 Mdot
.53749 .56771 Mdot
.61892 .46744 Mdot
.86258 .3553 Mdot
.2877 .49872 Mdot
.48075 .51652 Mdot
.645 .39994 Mdot
.99789 .39798 Mdot
.35394 .51516 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52558 .58357 Mdot
.58134 .51141 Mdot
.75386 .36391 Mdot
.16504 .49093 Mdot
.3707 .59803 Mdot
.40306 .06441 Mdot
.29885 .20506 Mdot
.96705 .17473 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48744 .01695 Mdot
.46001 .05364 Mdot
.37322 .15912 Mdot
.11576 .25722 Mdot
.69956 .11702 Mdot
.51021 .10756 Mdot
.33617 .23401 Mdot
.95754 .19511 Mdot
.64185 .08034 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00399 Mdot
.49059 .0127 Mdot
.47004 .04031 Mdot
.40482 .12338 Mdot
.20518 .26512 Mdot
.77621 .11957 Mdot
.58275 .04627 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47747 .03037 Mdot
.42834 .09458 Mdot
.2753 .24026 Mdot
.88655 .14377 Mdot
.65392 .02231 Mdot
.61783 .54082 Mdot
.74277 .39342 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48717 .01732 Mdot
.45914 .05479 Mdot
.37049 .16203 Mdot
.10832 .25487 Mdot
.69592 .11576 Mdot
.50861 .10778 Mdot
.33422 .23515 Mdot
.95375 .19287 Mdot
.64168 .0782 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.49869 .00176 Mdot
.49584 .00562 Mdot
.48674 .01789 Mdot
.45779 .05657 Mdot
.36626 .16647 Mdot
.09691 .25086 Mdot
.69101 .11333 Mdot
.50764 .10626 Mdot
.33571 .23292 Mdot
.49974 .00035 Mdot
.49918 .00111 Mdot
.49739 .00353 Mdot
.49167 .01125 Mdot
.47348 .03572 Mdot
.41568 .11029 Mdot
.23722 .25736 Mdot
.82081 .12418 Mdot
.61988 .02325 Mdot
.58226 .56838 Mdot
.6626 .44253 Mdot
.94657 .39393 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49791 .00283 Mdot
.49333 .00901 Mdot
.47876 .02864 Mdot
.43243 .08942 Mdot
.28774 .23283 Mdot
.91101 .15457 Mdot
.66092 .02954 Mdot
.61312 .55132 Mdot
.72107 .4062 Mdot
.06382 .46379 Mdot
.50037 .61754 Mdot
.50117 .61646 Mdot
.50372 .61301 Mdot
.51184 .60204 Mdot
.53772 .5674 Mdot
.61965 .46663 Mdot
.86463 .35573 Mdot
.28905 .49885 Mdot
.48188 .51561 Mdot
.6476 .39757 Mdot
.00432 .40158 Mdot
.50098 .61671 Mdot
.50312 .61381 Mdot
.50995 .6046 Mdot
.53169 .57541 Mdot
.60066 .48819 Mdot
.81075 .35127 Mdot
.24239 .49864 Mdot
.43557 .55675 Mdot
.53472 .52482 Mdot
.68555 .38921 Mdot
.0558 .43988 Mdot
.50005 .61797 Mdot
.50015 .61784 Mdot
.50047 .6174 Mdot
.50148 .61603 Mdot
.50473 .61165 Mdot
.51507 .5977 Mdot
.54797 .5539 Mdot
.65174 .43359 Mdot
.95017 .38815 Mdot
.32213 .5208 Mdot
.47946 .53979 Mdot
.49965 .00048 Mdot
.49887 .00152 Mdot
.49641 .00485 Mdot
.48856 .01545 Mdot
.46355 .04895 Mdot
.38435 .14698 Mdot
.14653 .26443 Mdot
.71868 .11973 Mdot
.52496 .09669 Mdot
.36852 .20518 Mdot
.03654 .23875 Mdot
.65023 .11926 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49933 .00091 Mdot
.49786 .00289 Mdot
.49318 .00921 Mdot
.47828 .02929 Mdot
.43089 .09137 Mdot
.28305 .23574 Mdot
.90162 .15023 Mdot
.65854 .02639 Mdot
.61584 .54627 Mdot
.73195 .39968 Mdot
.50132 .61625 Mdot
.50422 .61234 Mdot
.51344 .59989 Mdot
.54279 .5607 Mdot
.63556 .44969 Mdot
.90795 .36903 Mdot
.31085 .50592 Mdot
.49225 .5131 Mdot
.66203 .38753 Mdot
.03501 .41972 Mdot
.35589 .53579 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00284 Mdot
.49329 .00906 Mdot
.47863 .02882 Mdot
.432 .08995 Mdot
.28645 .23365 Mdot
.90841 .15334 Mdot
.66029 .02862 Mdot
.61398 .5498 Mdot
.72438 .40416 Mdot
.50106 .6166 Mdot
.50338 .61346 Mdot
.51077 .60348 Mdot
.53432 .57192 Mdot
.60894 .47863 Mdot
.8345 .3514 Mdot
.26593 .4982 Mdot
.45983 .53505 Mdot
.5941 .45281 Mdot
.86143 .33998 Mdot
.31134 .4767 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48873 .01522 Mdot
.46409 .04823 Mdot
.38606 .14506 Mdot
.15135 .26516 Mdot
.72232 .11984 Mdot
.52841 .09364 Mdot
.3769 .19672 Mdot
.05861 .24983 Mdot
.65438 .12812 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48971 .0139 Mdot
.46722 .04408 Mdot
.3959 .13385 Mdot
.17933 .26708 Mdot
.74718 .11956 Mdot
.55372 .0707 Mdot
.43933 .12559 Mdot
.50073 .61704 Mdot
.50234 .61487 Mdot
.50745 .60796 Mdot
.52375 .58603 Mdot
.57553 .51861 Mdot
.73641 .3716 Mdot
.13514 .48236 Mdot
.35466 .59914 Mdot
.38524 .07851 Mdot
.2582 .22586 Mdot
.89275 .13379 Mdot
.4998 .00027 Mdot
.49936 .00087 Mdot
.49796 .00276 Mdot
.49349 .00879 Mdot
.47927 .02795 Mdot
.43405 .08736 Mdot
.2927 .22962 Mdot
.92116 .15949 Mdot
.6631 .03339 Mdot
.60907 .55804 Mdot
.70614 .41607 Mdot
.03292 .44637 Mdot
.5011 .61654 Mdot
.50352 .61328 Mdot
.5112 .6029 Mdot
.53569 .5701 Mdot
.61325 .47375 Mdot
.84671 .35261 Mdot
.27617 .49817 Mdot
.47011 .52571 Mdot
.61949 .42506 Mdot
.93174 .36369 Mdot
.34327 .48662 Mdot
.49959 .00055 Mdot
.4987 .00175 Mdot
.49587 .00558 Mdot
.48684 .01777 Mdot
.45809 .05617 Mdot
.3672 .16549 Mdot
.09944 .25179 Mdot
.69204 .11392 Mdot
.5077 .10679 Mdot
.33492 .23382 Mdot
.95659 .19407 Mdot
.64257 .07888 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50703 .60854 Mdot
.52239 .58785 Mdot
.57123 .524 Mdot
.72338 .37851 Mdot
.11093 .47323 Mdot
.34524 .59513 Mdot
.38229 .07655 Mdot
.25843 .22388 Mdot
.89618 .13432 Mdot
.49985 .0002 Mdot
.49952 .00064 Mdot
.49849 .00205 Mdot
.49518 .00652 Mdot
.48463 .02074 Mdot
.45107 .06539 Mdot
.34527 .18728 Mdot
.04226 .22599 Mdot
.6766 .09386 Mdot
.52472 .07104 Mdot
.40978 .15026 Mdot
.16665 .27803 Mdot
.49968 .00043 Mdot
.49899 .00137 Mdot
.49677 .00436 Mdot
.48972 .01388 Mdot
.46726 .04402 Mdot
.39604 .13369 Mdot
.17972 .26708 Mdot
.74757 .11955 Mdot
.55413 .07034 Mdot
.44032 .12437 Mdot
.23908 .27157 Mdot
.79967 .13115 Mdot
.50127 .61632 Mdot
.50403 .61258 Mdot
.51285 .60069 Mdot
.54092 .56317 Mdot
.6297 .4558 Mdot
.89219 .36333 Mdot
.30431 .50237 Mdot
.49147 .51027 Mdot
.66583 .38289 Mdot
.04631 .42521 Mdot
.3583 .53989 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49807 .0026 Mdot
.49387 .00829 Mdot
.48046 .02636 Mdot
.43781 .08256 Mdot
.30422 .22162 Mdot
.94563 .17219 Mdot
.66701 .04425 Mdot
.59541 .57904 Mdot
.6585 .45522 Mdot
.92194 .38572 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51085 .60338 Mdot
.53456 .5716 Mdot
.60969 .47777 Mdot
.83664 .35155 Mdot
.26782 .49818 Mdot
.46175 .53329 Mdot
.59886 .44743 Mdot
.87491 .34304 Mdot
.31986 .47659 Mdot
.49966 .00046 Mdot
.49893 .00145 Mdot
.49658 .00462 Mdot
.4891 .01472 Mdot
.46528 .04665 Mdot
.38979 .14085 Mdot
.16189 .26636 Mdot
.73091 .11987 Mdot
.53695 .08592 Mdot
.39793 .17419 Mdot
.11609 .27252 Mdot
.67515 .14099 Mdot
.50007 .61794 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50224 .61501 Mdot
.50713 .60841 Mdot
.52271 .58743 Mdot
.57223 .52274 Mdot
.72643 .37681 Mdot
.11674 .47558 Mdot
.34723 .59644 Mdot
.38216 .07794 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49647 .00478 Mdot
.48874 .01521 Mdot
.46413 .04818 Mdot
.38618 .14492 Mdot
.15169 .2652 Mdot
.72258 .11984 Mdot
.52867 .09341 Mdot
.37753 .19607 Mdot
.06028 .25063 Mdot
.65476 .12872 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50406 .61254 Mdot
.51294 .60056 Mdot
.54122 .56277 Mdot
.63064 .45481 Mdot
.89475 .36419 Mdot
.30548 .50287 Mdot
.49182 .51044 Mdot
.66591 .38302 Mdot
.04617 .42522 Mdot
.49996 5e-05 Mdot
.49989 .00016 Mdot
.49963 .00049 Mdot
.49883 .00157 Mdot
.49629 .00502 Mdot
.48817 .01597 Mdot
.46233 .05057 Mdot
.3805 .15124 Mdot
.13579 .2624 Mdot
.71123 .11921 Mdot
.51834 .10224 Mdot
.35292 .22 Mdot
.50041 .61747 Mdot
.50132 .61625 Mdot
.50421 .61235 Mdot
.5134 .59994 Mdot
.54267 .56086 Mdot
.63519 .45006 Mdot
.90697 .36865 Mdot
.31048 .50567 Mdot
.4923 .5128 Mdot
.66256 .38697 Mdot
.03643 .42045 Mdot
.50017 .6178 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.5055 .6106 Mdot
.51752 .59439 Mdot
.55578 .54373 Mdot
.67601 .41184 Mdot
.00963 .42077 Mdot
.32882 .55059 Mdot
.43795 .60667 Mdot
.45634 .0286 Mdot
.5002 .61776 Mdot
.50064 .61716 Mdot
.50205 .61526 Mdot
.50654 .60919 Mdot
.52085 .58992 Mdot
.56634 .53019 Mdot
.70848 .38763 Mdot
.08128 .45975 Mdot
.33739 .58561 Mdot
.38986 .06172 Mdot
.28999 .20463 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46026 .05331 Mdot
.37401 .15828 Mdot
.1179 .25786 Mdot
.70068 .11734 Mdot
.51082 .10732 Mdot
.33716 .23329 Mdot
.9597 .19632 Mdot
.64204 .08144 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54283 .56064 Mdot
.6357 .44954 Mdot
.90833 .36918 Mdot
.31099 .50602 Mdot
.49223 .51322 Mdot
.66182 .38775 Mdot
.03443 .41942 Mdot
.4997 .0004 Mdot
.49905 .00128 Mdot
.49698 .00408 Mdot
.49038 .01299 Mdot
.46935 .04123 Mdot
.40264 .12597 Mdot
.19882 .26595 Mdot
.76851 .1194 Mdot
.57532 .05215 Mdot
.49093 .06055 Mdot
.39295 .15248 Mdot
.14624 .26976 Mdot
.50047 .6174 Mdot
.50149 .61603 Mdot
.50473 .61164 Mdot
.51508 .59768 Mdot
.54801 .55384 Mdot
.65187 .43347 Mdot
.95051 .38832 Mdot
.32219 .52095 Mdot
.47928 .5401 Mdot
.60538 .44939 Mdot
.87826 .34722 Mdot
.50121 .6164 Mdot
.50384 .61284 Mdot
.51225 .6015 Mdot
.53901 .5657 Mdot
.62369 .46223 Mdot
.87579 .35842 Mdot
.29586 .49988 Mdot
.48704 .51188 Mdot
.65879 .38791 Mdot
.03114 .4166 Mdot
.35708 .53199 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49178 .0111 Mdot
.47382 .03526 Mdot
.41677 .10895 Mdot
.24049 .25623 Mdot
.8259 .12515 Mdot
.62341 .02187 Mdot
.58803 .56239 Mdot
.67807 .42966 Mdot
.98287 .41381 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49638 .00489 Mdot
.48846 .01559 Mdot
.46324 .04936 Mdot
.38337 .14806 Mdot
.1438 .26396 Mdot
.7167 .11963 Mdot
.52313 .09827 Mdot
.36413 .20947 Mdot
.02521 .23274 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.4993 .00094 Mdot
.49779 .00299 Mdot
.49294 .00953 Mdot
.47752 .0303 Mdot
.4285 .09437 Mdot
.2758 .23999 Mdot
.88749 .14416 Mdot
.65424 .02252 Mdot
.6178 .54106 Mdot
.74235 .39368 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.4961 .00526 Mdot
.48759 .01676 Mdot
.46048 .05302 Mdot
.3747 .15755 Mdot
.11978 .2584 Mdot
.70168 .1176 Mdot
.5114 .10704 Mdot
.3382 .23251 Mdot
.96199 .19761 Mdot
.64226 .0826 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49149 .0115 Mdot
.47289 .03651 Mdot
.41382 .11255 Mdot
.23171 .25912 Mdot
.81244 .12279 Mdot
.61376 .02608 Mdot
.57157 .57998 Mdot
.63315 .47044 Mdot
.87196 .36414 Mdot
.50028 .61766 Mdot
.50088 .61685 Mdot
.5028 .61425 Mdot
.50893 .60597 Mdot
.52844 .57975 Mdot
.59039 .50038 Mdot
.78076 .35558 Mdot
.20542 .49738 Mdot
.40065 .58362 Mdot
.45633 .00556 Mdot
.44735 .05348 Mdot
.49966 .00045 Mdot
.49893 .00144 Mdot
.4966 .0046 Mdot
.48916 .01464 Mdot
.46546 .04641 Mdot
.39036 .14021 Mdot
.1635 .26649 Mdot
.73231 .11986 Mdot
.53838 .08462 Mdot
.40146 .17025 Mdot
.12599 .27522 Mdot
.68066 .14146 Mdot
.50112 .61653 Mdot
.50355 .61323 Mdot
.51132 .60274 Mdot
.53606 .5696 Mdot
.61443 .47242 Mdot
.85004 .35308 Mdot
.27875 .49822 Mdot
.47261 .52349 Mdot
.6256 .41877 Mdot
.94802 .37143 Mdot
.34703 .49239 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49752 .00335 Mdot
.49209 .01068 Mdot
.47481 .03393 Mdot
.41991 .10509 Mdot
.24986 .25264 Mdot
.84109 .1286 Mdot
.633 .01916 Mdot
.602 .54898 Mdot
.71373 .40525 Mdot
.05803 .45786 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00192 Mdot
.49548 .0061 Mdot
.48561 .01943 Mdot
.45418 .06132 Mdot
.35496 .17793 Mdot
.06707 .23828 Mdot
.68153 .10418 Mdot
.51296 .09218 Mdot
.36381 .20359 Mdot
.0344 .23523 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49741 .00349 Mdot
.49176 .01113 Mdot
.47375 .03536 Mdot
.41654 .10923 Mdot
.2398 .25647 Mdot
.82482 .12493 Mdot
.62267 .02214 Mdot
.58685 .5636 Mdot
.67493 .43217 Mdot
.97567 .4097 Mdot
.50086 .61687 Mdot
.50275 .61431 Mdot
.50877 .60619 Mdot
.52794 .58042 Mdot
.5888 .50231 Mdot
.77605 .35673 Mdot
.19885 .49672 Mdot
.39513 .58706 Mdot
.44526 .01877 Mdot
.41488 .09398 Mdot
.26282 .24104 Mdot
.50048 .61739 Mdot
.50152 .61598 Mdot
.50484 .61149 Mdot
.51543 .5972 Mdot
.54914 .55237 Mdot
.65539 .43013 Mdot
.95942 .39292 Mdot
.32366 .52494 Mdot
.47429 .54868 Mdot
.58651 .47237 Mdot
.82219 .33975 Mdot
.49979 .00028 Mdot
.49934 .00089 Mdot
.49789 .00285 Mdot
.49329 .00906 Mdot
.47863 .02882 Mdot
.432 .08996 Mdot
.28644 .23365 Mdot
.90839 .15333 Mdot
.66029 .02862 Mdot
.61398 .54979 Mdot
.72441 .40414 Mdot
.0705 .46738 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50366 .61308 Mdot
.51167 .60227 Mdot
.53718 .56811 Mdot
.61796 .4685 Mdot
.8599 .35476 Mdot
.28589 .49857 Mdot
.47919 .51781 Mdot
.64136 .40332 Mdot
.49989 .00015 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49648 .00475 Mdot
.48879 .01513 Mdot
.4643 .04795 Mdot
.38672 .14432 Mdot
.1532 .26541 Mdot
.72376 .11986 Mdot
.52981 .09239 Mdot
.38033 .19316 Mdot
.06778 .25412 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00543 Mdot
.48718 .0173 Mdot
.45919 .05472 Mdot
.37065 .16186 Mdot
.10875 .25502 Mdot
.69613 .11584 Mdot
.50869 .1078 Mdot
.33427 .23514 Mdot
.95381 .19292 Mdot
.64167 .07825 Mdot
.50049 .61737 Mdot
.50158 .61591 Mdot
.50502 .61125 Mdot
.51599 .59646 Mdot
.5509 .55007 Mdot
.66087 .42507 Mdot
.9731 .40024 Mdot
.32549 .5315 Mdot
.4655 .56323 Mdot
.55418 .51397 Mdot
.72257 .36861 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51255 .60109 Mdot
.53997 .56443 Mdot
.6267 .45899 Mdot
.88404 .36075 Mdot
.30033 .50098 Mdot
.48973 .51049 Mdot
.66374 .38409 Mdot
.04227 .42282 Mdot
.35814 .5376 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.49551 .00607 Mdot
.48569 .01932 Mdot
.45442 .061 Mdot
.35572 .17717 Mdot
.06906 .2392 Mdot
.68202 .10491 Mdot
.51228 .09354 Mdot
.36093 .20667 Mdot
.02654 .23116 Mdot
.49989 .00015 Mdot
.49965 .00048 Mdot
.49888 .00152 Mdot
.49642 .00484 Mdot
.48858 .01542 Mdot
.46364 .04884 Mdot
.38462 .14667 Mdot
.1473 .26455 Mdot
.71925 .11975 Mdot
.52549 .09622 Mdot
.3698 .20391 Mdot
.03986 .24048 Mdot
.50012 .61788 Mdot
.50037 .61753 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51204 .60177 Mdot
.53835 .56656 Mdot
.62163 .46446 Mdot
.87012 .35698 Mdot
.29251 .4993 Mdot
.48463 .51352 Mdot
.65374 .39215 Mdot
.49983 .00024 Mdot
.49944 .00075 Mdot
.49823 .00239 Mdot
.49436 .00762 Mdot
.48204 .02423 Mdot
.44284 .07609 Mdot
.31972 .2097 Mdot
.98042 .19159 Mdot
.67041 .06211 Mdot
.56991 .6174 Mdot
.57093 .55381 Mdot
.67485 .4224 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49671 .00444 Mdot
.48953 .01415 Mdot
.46664 .04485 Mdot
.39407 .13596 Mdot
.17408 .26703 Mdot
.74201 .11968 Mdot
.54837 .07552 Mdot
.42618 .14153 Mdot
.19718 .28102 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49723 .00374 Mdot
.49118 .01191 Mdot
.47191 .03782 Mdot
.41071 .11632 Mdot
.2225 .26167 Mdot
.79911 .12109 Mdot
.60317 .032 Mdot
.55139 .60322 Mdot
.57536 .53594 Mdot
.70818 .39346 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00367 Mdot
.49136 .01168 Mdot
.47246 .03708 Mdot
.41247 .11419 Mdot
.2277 .26029 Mdot
.80654 .12196 Mdot
.6092 .02848 Mdot
.56312 .58952 Mdot
.60925 .49601 Mdot
.8067 .35773 Mdot
.50099 .6167 Mdot
.50315 .61378 Mdot
.51003 .60449 Mdot
.53195 .57507 Mdot
.60147 .48724 Mdot
.81311 .35114 Mdot
.24495 .49861 Mdot
.43818 .55449 Mdot
.54099 .51692 Mdot
.7046 .37533 Mdot
.0973 .46002 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49864 .00184 Mdot
.49567 .00585 Mdot
.4862 .01863 Mdot
.45606 .05885 Mdot
.36083 .17204 Mdot
.08246 .24511 Mdot
.68586 .10939 Mdot
.50886 .10118 Mdot
.34515 .22314 Mdot
.98411 .20843 Mdot
.50129 .61628 Mdot
.50413 .61246 Mdot
.51314 .60029 Mdot
.54186 .56193 Mdot
.63264 .45271 Mdot
.90013 .36609 Mdot
.30779 .50401 Mdot
.49228 .51117 Mdot
.66519 .38408 Mdot
.04373 .42412 Mdot
.3575 .53926 Mdot
.5002 .61777 Mdot
.50063 .61718 Mdot
.50201 .61532 Mdot
.50639 .6094 Mdot
.52037 .59057 Mdot
.56481 .53213 Mdot
.7038 .39076 Mdot
.07153 .45486 Mdot
.33554 .5816 Mdot
.39449 .05438 Mdot
.30651 .19272 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50742 .60801 Mdot
.52364 .58617 Mdot
.5752 .51902 Mdot
.73541 .37209 Mdot
.13335 .48175 Mdot
.35386 .59898 Mdot
.38469 .07873 Mdot
.2573 .22612 Mdot
.89142 .1331 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00297 Mdot
.49299 .00947 Mdot
.47766 .03011 Mdot
.42894 .09382 Mdot
.27715 .23922 Mdot
.89008 .14523 Mdot
.6551 .02315 Mdot
.61764 .54179 Mdot
.74101 .39448 Mdot
.50075 .61702 Mdot
.50238 .61481 Mdot
.5076 .60777 Mdot
.52421 .58542 Mdot
.57698 .5168 Mdot
.74077 .36951 Mdot
.1429 .48489 Mdot
.35834 .59955 Mdot
.38825 .07681 Mdot
.26397 .22378 Mdot
.90188 .13847 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49782 .00294 Mdot
.49307 .00936 Mdot
.47792 .02976 Mdot
.42976 .09279 Mdot
.27963 .23778 Mdot
.8949 .14727 Mdot
.6566 .02441 Mdot
.6171 .54342 Mdot
.73784 .3963 Mdot
.0966 .48046 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50704 .60853 Mdot
.52242 .58781 Mdot
.57133 .52387 Mdot
.72369 .37834 Mdot
.11152 .47347 Mdot
.34543 .59528 Mdot
.38225 .07671 Mdot
.25813 .22407 Mdot
.50024 .6177 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.50791 .60735 Mdot
.5252 .58409 Mdot
.58012 .51291 Mdot
.75022 .36537 Mdot
.15904 .48946 Mdot
.36707 .59886 Mdot
.3981 .06897 Mdot
.28651 .21264 Mdot
.49967 .00045 Mdot
.49895 .00142 Mdot
.49664 .00454 Mdot
.4893 .01445 Mdot
.46592 .0458 Mdot
.39181 .13855 Mdot
.16763 .26677 Mdot
.73598 .1198 Mdot
.54214 .08119 Mdot
.41078 .15964 Mdot
.15248 .28034 Mdot
.69888 .14034 Mdot
.5013 .61627 Mdot
.50415 .61242 Mdot
.51323 .60017 Mdot
.54214 .56156 Mdot
.63351 .45181 Mdot
.90247 .36695 Mdot
.30874 .50455 Mdot
.49235 .51164 Mdot
.6645 .38488 Mdot
.04176 .42315 Mdot
.35709 .53853 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48761 .01673 Mdot
.46053 .05295 Mdot
.37485 .15738 Mdot
.1202 .25852 Mdot
.70191 .11766 Mdot
.51153 .10697 Mdot
.33845 .23232 Mdot
.96255 .19792 Mdot
.64231 .08288 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01007 Mdot
.47626 .032 Mdot
.42448 .09941 Mdot
.26363 .24641 Mdot
.86493 .13569 Mdot
.64537 .0189 Mdot
.61479 .53951 Mdot
.74184 .39216 Mdot
.10731 .48427 Mdot
.49965 .00047 Mdot
.49888 .00151 Mdot
.49644 .00481 Mdot
.48866 .01531 Mdot
.46389 .0485 Mdot
.38541 .14579 Mdot
.14952 .26489 Mdot
.72092 .1198 Mdot
.52707 .09483 Mdot
.37362 .20006 Mdot
.04992 .24558 Mdot
.65256 .12484 Mdot
.49984 .00022 Mdot
.49948 .0007 Mdot
.49836 .00222 Mdot
.49476 .00708 Mdot
.48331 .02253 Mdot
.44686 .07088 Mdot
.33217 .19919 Mdot
.00988 .20834 Mdot
.67277 .07783 Mdot
.54685 .03502 Mdot
.49018 .04412 Mdot
.41879 .11618 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00487 Mdot
.48851 .01552 Mdot
.4634 .04914 Mdot
.38389 .14749 Mdot
.14525 .26421 Mdot
.71775 .11969 Mdot
.52409 .09744 Mdot
.36643 .20724 Mdot
.03111 .23589 Mdot
.64943 .11684 Mdot
.50103 .61664 Mdot
.50329 .61358 Mdot
.51049 .60386 Mdot
.53342 .57311 Mdot
.60611 .48186 Mdot
.82644 .35101 Mdot
.25849 .49835 Mdot
.45215 .54204 Mdot
.5751 .47497 Mdot
.80658 .33665 Mdot
.26186 .48379 Mdot
.50056 .61728 Mdot
.50179 .61562 Mdot
.5057 .61034 Mdot
.51816 .59354 Mdot
.55779 .54114 Mdot
.68221 .40678 Mdot
.02402 .42897 Mdot
.32994 .55829 Mdot
.42662 .0059 Mdot
.41708 .07934 Mdot
.28871 .22254 Mdot
.50069 .6171 Mdot
.50221 .61505 Mdot
.50703 .60854 Mdot
.52239 .58785 Mdot
.57122 .52401 Mdot
.72336 .37853 Mdot
.11089 .47321 Mdot
.34522 .59512 Mdot
.38229 .07653 Mdot
.25845 .22387 Mdot
.89622 .13434 Mdot
.50075 .61702 Mdot
.50239 .61481 Mdot
.5076 .60777 Mdot
.52421 .58541 Mdot
.577 .51678 Mdot
.74083 .36948 Mdot
.143 .48492 Mdot
.35839 .59955 Mdot
.38829 .07678 Mdot
.26407 .22375 Mdot
.90204 .13856 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50033 .61759 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51057 .60375 Mdot
.53368 .57276 Mdot
.60693 .48093 Mdot
.82877 .35109 Mdot
.2607 .4983 Mdot
.45444 .53997 Mdot
.5001 .61789 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61345 Mdot
.51081 .60344 Mdot
.53442 .57179 Mdot
.60925 .47827 Mdot
.83538 .35146 Mdot
.26671 .49819 Mdot
.46062 .53432 Mdot
.59607 .45057 Mdot
.50022 .61774 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60848 Mdot
.52252 .58768 Mdot
.57164 .52348 Mdot
.72464 .3778 Mdot
.11333 .47421 Mdot
.34604 .5957 Mdot
.38218 .07719 Mdot
.25728 .22458 Mdot
.50109 .61657 Mdot
.50346 .61336 Mdot
.51102 .60315 Mdot
.53511 .57087 Mdot
.61142 .4758 Mdot
.84156 .35201 Mdot
.272 .49815 Mdot
.46598 .52944 Mdot
.60932 .43588 Mdot
.90405 .35222 Mdot
.33414 .47962 Mdot
.49973 .00037 Mdot
.49913 .00117 Mdot
.49724 .00373 Mdot
.4912 .01188 Mdot
.47198 .03772 Mdot
.41095 .11603 Mdot
.22321 .26149 Mdot
.80011 .1212 Mdot
.60401 .03149 Mdot
.55305 .60125 Mdot
.5802 .53001 Mdot
.72263 .38464 Mdot
.50014 .61785 Mdot
.50043 .61745 Mdot
.50137 .61618 Mdot
.50438 .61212 Mdot
.51394 .59922 Mdot
.54439 .5586 Mdot
.64056 .44458 Mdot
.92121 .37449 Mdot
.31528 .5098 Mdot
.49041 .51868 Mdot
.65117 .39868 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49584 .00561 Mdot
.48676 .01788 Mdot
.45783 .05651 Mdot
.3664 .16632 Mdot
.09729 .251 Mdot
.69116 .11342 Mdot
.50764 .10634 Mdot
.33558 .23306 Mdot
.95847 .195 Mdot
.64295 .07959 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49015 .01331 Mdot
.46862 .04221 Mdot
.40031 .1287 Mdot
.19207 .26658 Mdot
.76073 .11937 Mdot
.56759 .05858 Mdot
.4728 .08368 Mdot
.33741 .20952 Mdot
.9984 .20804 Mdot
.50068 .61712 Mdot
.50215 .61513 Mdot
.50686 .60877 Mdot
.52185 .58858 Mdot
.56952 .52616 Mdot
.71817 .38156 Mdot
.1008 .46888 Mdot
.34214 .59238 Mdot
.38364 .07286 Mdot
.26574 .21969 Mdot
.91028 .14085 Mdot
.50071 .61707 Mdot
.50227 .61497 Mdot
.50723 .60827 Mdot
.52303 .58699 Mdot
.57325 .52146 Mdot
.72951 .37514 Mdot
.12253 .47783 Mdot
.34938 .59754 Mdot
.38254 .07877 Mdot
.25508 .22624 Mdot
.88901 .13149 Mdot
.5007 .61708 Mdot
.50224 .61501 Mdot
.50714 .60839 Mdot
.52275 .58736 Mdot
.57238 .52255 Mdot
.72688 .37656 Mdot
.11759 .47592 Mdot
.34753 .59662 Mdot
.38219 .0781 Mdot
.25582 .22554 Mdot
.89088 .13213 Mdot
.50014 .61785 Mdot
.50044 .61744 Mdot
.50139 .61615 Mdot
.50443 .61204 Mdot
.51413 .59897 Mdot
.54498 .55782 Mdot
.6424 .44273 Mdot
.92605 .37662 Mdot
.31667 .5114 Mdot
.48921 .5214 Mdot
.64557 .40449 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49092 .01226 Mdot
.47109 .03892 Mdot
.40811 .11945 Mdot
.21485 .26341 Mdot
.78865 .12019 Mdot
.59417 .03789 Mdot
.53286 .00764 Mdot
.52049 .60673 Mdot
.53878 .57114 Mdot
.50044 .61744 Mdot
.5014 .61614 Mdot
.50448 .61199 Mdot
.51426 .59879 Mdot
.5454 .55727 Mdot
.64372 .44142 Mdot
.92949 .37817 Mdot
.3176 .5126 Mdot
.48819 .52354 Mdot
.64108 .40922 Mdot
.97896 .38977 Mdot
.50073 .61705 Mdot
.50231 .61491 Mdot
.50736 .60809 Mdot
.52346 .58642 Mdot
.57462 .51975 Mdot
.73364 .37298 Mdot
.13014 .48063 Mdot
.35247 .59864 Mdot
.38385 .07897 Mdot
.25607 .22641 Mdot
.88973 .13217 Mdot
.50003 .61799 Mdot
.5001 .61789 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50338 .61347 Mdot
.51075 .60351 Mdot
.53425 .57201 Mdot
.60872 .47888 Mdot
.83388 .35135 Mdot
.26538 .49821 Mdot
.45925 .53557 Mdot
.50117 .61646 Mdot
.50371 .61302 Mdot
.51183 .60206 Mdot
.53767 .56746 Mdot
.61951 .46679 Mdot
.86422 .35564 Mdot
.28878 .49883 Mdot
.48166 .51579 Mdot
.6471 .39802 Mdot
.00308 .40088 Mdot
.35444 .51778 Mdot
.50023 .61772 Mdot
.50074 .61703 Mdot
.50236 .61485 Mdot
.50752 .60788 Mdot
.52395 .58576 Mdot
.57618 .5178 Mdot
.73837 .37065 Mdot
.13865 .48353 Mdot
.35628 .59938 Mdot
.38647 .0779 Mdot
.26043 .22512 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00366 Mdot
.49137 .01166 Mdot
.47251 .03701 Mdot
.41263 .114 Mdot
.22816 .26016 Mdot
.80721 .12205 Mdot
.60973 .02819 Mdot
.56412 .58838 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.4948 .00702 Mdot
.48345 .02234 Mdot
.44731 .0703 Mdot
.33356 .19797 Mdot
.01324 .21023 Mdot
.67308 .07959 Mdot
.54431 .03904 Mdot
.48115 .05647 Mdot
.49963 .00051 Mdot
.49881 .00161 Mdot
.4962 .00514 Mdot
.48788 .01636 Mdot
.46141 .05178 Mdot
.37762 .15438 Mdot
.12783 .26055 Mdot
.70625 .11854 Mdot
.51445 .10517 Mdot
.34428 .22757 Mdot
.97606 .20546 Mdot
.64361 .08967 Mdot
.501 .61669 Mdot
.50317 .61374 Mdot
.51012 .60437 Mdot
.53222 .57471 Mdot
.60232 .48626 Mdot
.81554 .35105 Mdot
.24753 .49857 Mdot
.44083 .55217 Mdot
.54739 .50889 Mdot
.72399 .36331 Mdot
.13614 .47468 Mdot
.50055 .61729 Mdot
.50175 .61567 Mdot
.50558 .6105 Mdot
.51776 .59407 Mdot
.55654 .54274 Mdot
.67837 .40989 Mdot
.01514 .42391 Mdot
.32924 .55354 Mdot
.43359 .61334 Mdot
.44118 .0486 Mdot
.36255 .16077 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50422 .61233 Mdot
.51345 .59987 Mdot
.54284 .56063 Mdot
.63573 .44951 Mdot
.90841 .36921 Mdot
.31102 .50604 Mdot
.49222 .51325 Mdot
.66177 .3878 Mdot
.0343 .41935 Mdot
.5001 .6179 Mdot
.50032 .61761 Mdot
.50101 .61667 Mdot
.50322 .61369 Mdot
.51025 .60419 Mdot
.53265 .57413 Mdot
.60369 .48466 Mdot
.81949 .35096 Mdot
.25162 .4985 Mdot
.44504 .54844 Mdot
.55764 .49616 Mdot
.49986 .00018 Mdot
.49957 .00059 Mdot
.49862 .00187 Mdot
.4956 .00595 Mdot
.48597 .01894 Mdot
.45533 .05981 Mdot
.35856 .17434 Mdot
.07647 .24254 Mdot
.68404 .10748 Mdot
.51013 .0981 Mdot
.35141 .21669 Mdot
.00079 .21742 Mdot
.49969 .00042 Mdot
.49901 .00134 Mdot
.49683 .00428 Mdot
.4899 .01364 Mdot
.46784 .04325 Mdot
.39787 .13156 Mdot
.18499 .26697 Mdot
.75302 .11945 Mdot
.55975 .06536 Mdot
.454 .10741 Mdot
.28021 .25231 Mdot
.87197 .14601 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50665 .60905 Mdot
.5212 .58945 Mdot
.56745 .52878 Mdot
.71186 .38545 Mdot
.08819 .46309 Mdot
.3389 .58821 Mdot
.38716 .06623 Mdot
.27999 .21117 Mdot
.93832 .1554 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49635 .00493 Mdot
.48838 .0157 Mdot
.46298 .04971 Mdot
.38255 .14898 Mdot
.1415 .26354 Mdot
.71508 .11953 Mdot
.52167 .09951 Mdot
.36066 .2128 Mdot
.01634 .22792 Mdot
.50076 .61701 Mdot
.50241 .61478 Mdot
.50768 .60766 Mdot
.52446 .58508 Mdot
.57778 .51581 Mdot
.74318 .3684 Mdot
.14709 .48616 Mdot
.36046 .59957 Mdot
.39033 .07536 Mdot
.2684 .22192 Mdot
.90933 .14234 Mdot
.49968 .00043 Mdot
.49898 .00137 Mdot
.49676 .00437 Mdot
.48969 .01392 Mdot
.46716 .04415 Mdot
.39573 .13404 Mdot
.17886 .26709 Mdot
.7467 .11957 Mdot
.55323 .07114 Mdot
.43812 .12708 Mdot
.2325 .27373 Mdot
.7896 .13073 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50305 .61391 Mdot
.50973 .6049 Mdot
.53099 .57635 Mdot
.59843 .4908 Mdot
.8043 .35176 Mdot
.23513 .49866 Mdot
.42828 .56293 Mdot
.51744 .54679 Mdot
.63272 .43753 Mdot
.50029 .61764 Mdot
.50092 .61678 Mdot
.50295 .61405 Mdot
.50939 .60536 Mdot
.5299 .5778 Mdot
.595 .49486 Mdot
.7943 .353 Mdot
.22314 .49844 Mdot
.41664 .57224 Mdot
.49073 .58083 Mdot
.55094 .53441 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48699 .01756 Mdot
.45859 .05552 Mdot
.36875 .16386 Mdot
.10362 .25328 Mdot
.69381 .11484 Mdot
.508 .10742 Mdot
.33418 .23481 Mdot
.95426 .19298 Mdot
.64201 .07812 Mdot
.49988 .00017 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45944 .0544 Mdot
.37142 .16105 Mdot
.11084 .25569 Mdot
.69712 .11622 Mdot
.50907 .10782 Mdot
.33462 .23499 Mdot
.9544 .19329 Mdot
.49964 .00049 Mdot
.49884 .00157 Mdot
.4963 .005 Mdot
.48821 .01592 Mdot
.46245 .05041 Mdot
.38087 .15082 Mdot
.13684 .26262 Mdot
.71191 .11928 Mdot
.51892 .10178 Mdot
.35424 .21879 Mdot
.00022 .219 Mdot
.64587 .10192 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49857 .00193 Mdot
.49544 .00616 Mdot
.48548 .0196 Mdot
.45378 .06185 Mdot
.3537 .17916 Mdot
.06381 .23675 Mdot
.68075 .10295 Mdot
.51416 .08984 Mdot
.3688 .19815 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49597 .00544 Mdot
.48717 .01732 Mdot
.45915 .05478 Mdot
.37051 .16201 Mdot
.10837 .25489 Mdot
.69595 .11577 Mdot
.50862 .10778 Mdot
.33423 .23515 Mdot
.95375 .19287 Mdot
.50021 .61776 Mdot
.50066 .61715 Mdot
.50209 .61521 Mdot
.50666 .60903 Mdot
.52123 .58941 Mdot
.56755 .52865 Mdot
.71218 .38525 Mdot
.08883 .46339 Mdot
.33905 .58844 Mdot
.38694 .06662 Mdot
.27914 .2117 Mdot
.50013 .61786 Mdot
.50042 .61747 Mdot
.50133 .61624 Mdot
.50424 .61231 Mdot
.51349 .59982 Mdot
.54297 .56046 Mdot
.63613 .4491 Mdot
.90947 .36963 Mdot
.3114 .50633 Mdot
.49215 .5136 Mdot
.66113 .38846 Mdot
.50002 .61801 Mdot
.50006 .61795 Mdot
.50019 .61777 Mdot
.50062 .6172 Mdot
.50197 .61538 Mdot
.50627 .60957 Mdot
.51997 .59111 Mdot
.56354 .53375 Mdot
.69991 .39346 Mdot
.06328 .45059 Mdot
.33421 .57796 Mdot
.5007 .61709 Mdot
.50222 .61504 Mdot
.50707 .60849 Mdot
.52251 .58769 Mdot
.57162 .52351 Mdot
.72456 .37784 Mdot
.1132 .47416 Mdot
.34599 .59567 Mdot
.38218 .07715 Mdot
.25734 .22454 Mdot
.89402 .1334 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48949 .0142 Mdot
.46652 .04501 Mdot
.3937 .13639 Mdot
.17302 .26701 Mdot
.74099 .1197 Mdot
.54731 .07648 Mdot
.42357 .14464 Mdot
.18953 .28167 Mdot
.73378 .13489 Mdot
.49968 .00044 Mdot
.49897 .0014 Mdot
.49671 .00445 Mdot
.48951 .01417 Mdot
.46658 .04493 Mdot
.39388 .13618 Mdot
.17354 .26702 Mdot
.74149 .11969 Mdot
.54783 .07601 Mdot
.42485 .14312 Mdot
.19328 .28139 Mdot
.73798 .13427 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00048 Mdot
.49886 .00154 Mdot
.49636 .00492 Mdot
.4884 .01567 Mdot
.46305 .04962 Mdot
.38276 .14874 Mdot
.14209 .26365 Mdot
.7155 .11956 Mdot
.52204 .09919 Mdot
.36154 .21196 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51041 .60398 Mdot
.53314 .57348 Mdot
.60524 .48287 Mdot
.82394 .35096 Mdot
.25607 .4984 Mdot
.44964 .54432 Mdot
.56891 .48241 Mdot
.78836 .33913 Mdot
.23964 .48636 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49737 .00356 Mdot
.49161 .01134 Mdot
.47326 .036 Mdot
.41501 .1111 Mdot
.23524 .25801 Mdot
.81776 .12364 Mdot
.6177 .0242 Mdot
.57854 .57234 Mdot
.65247 .45164 Mdot
.49996 5e-05 Mdot
.49988 .00017 Mdot
.4996 .00054 Mdot
.49874 .00171 Mdot
.49598 .00544 Mdot
.48718 .01731 Mdot
.45917 .05475 Mdot
.37059 .16193 Mdot
.10858 .25496 Mdot
.69605 .11581 Mdot
.50866 .10779 Mdot
.33425 .23514 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.5113 .60277 Mdot
.53599 .56969 Mdot
.61421 .47267 Mdot
.84942 .35299 Mdot
.27827 .49821 Mdot
.47216 .52389 Mdot
.62449 .4199 Mdot
.94508 .36999 Mdot
.34643 .49127 Mdot
.50013 .61785 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50432 .6122 Mdot
.51376 .59946 Mdot
.54381 .55936 Mdot
.63876 .44641 Mdot
.91645 .37246 Mdot
.31379 .50831 Mdot
.49132 .51635 Mdot
.65585 .39388 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48091 .02575 Mdot
.43925 .0807 Mdot
.30868 .21833 Mdot
.9554 .17753 Mdot
.66815 .04907 Mdot
.58876 .58902 Mdot
.63571 .4779 Mdot
.86245 .36568 Mdot
.50055 .6173 Mdot
.50174 .61569 Mdot
.50554 .61055 Mdot
.51764 .59423 Mdot
.55615 .54326 Mdot
.67714 .4109 Mdot
.01228 .42228 Mdot
.32902 .55201 Mdot
.43585 .60988 Mdot
.44904 .03829 Mdot
.38707 .13442 Mdot
.50015 .61783 Mdot
.50047 .6174 Mdot
.5015 .61601 Mdot
.50477 .6116 Mdot
.51518 .59754 Mdot
.54834 .55342 Mdot
.65289 .43249 Mdot
.9531 .38964 Mdot
.32265 .52208 Mdot
.4779 .54251 Mdot
.6001 .4557 Mdot
.5007 .61708 Mdot
.50224 .61501 Mdot
.50713 .6084 Mdot
.52272 .58741 Mdot
.57227 .52269 Mdot
.72655 .37674 Mdot
.11696 .47567 Mdot
.34731 .59649 Mdot
.38217 .07798 Mdot
.25599 .22542 Mdot
.89125 .13227 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00387 Mdot
.49086 .01234 Mdot
.4709 .03917 Mdot
.40753 .12015 Mdot
.21311 .26375 Mdot
.78635 .12004 Mdot
.59212 .03933 Mdot
.52849 .01305 Mdot
.50737 .00622 Mdot
.4973 .00873 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46506 .04695 Mdot
.3891 .14164 Mdot
.15993 .26618 Mdot
.72925 .11988 Mdot
.53527 .08745 Mdot
.39377 .17879 Mdot
.10448 .26884 Mdot
.66949 .13977 Mdot
.50118 .61644 Mdot
.50377 .61294 Mdot
.512 .60183 Mdot
.53823 .56673 Mdot
.62124 .46489 Mdot
.86902 .35672 Mdot
.29184 .4992 Mdot
.48412 .5139 Mdot
.65261 .39312 Mdot
.01653 .40842 Mdot
.35569 .5246 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50668 .60901 Mdot
.52129 .58933 Mdot
.56774 .5284 Mdot
.71277 .38488 Mdot
.09002 .46395 Mdot
.33933 .58886 Mdot
.38653 .06733 Mdot
.27759 .21266 Mdot
.93349 .15279 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.50832 .6068 Mdot
.52649 .58236 Mdot
.58422 .50788 Mdot
.76245 .36078 Mdot
.17869 .49377 Mdot
.37976 .59493 Mdot
.41715 .05028 Mdot
.3358 .17689 Mdot
.04958 .22212 Mdot
.49961 .00053 Mdot
.49876 .00168 Mdot
.49604 .00536 Mdot
.48737 .01705 Mdot
.45977 .05395 Mdot
.37248 .15992 Mdot
.11372 .2566 Mdot
.69853 .1167 Mdot
.5097 .10772 Mdot
.3354 .23453 Mdot
.95593 .19419 Mdot
.64172 .0795 Mdot
.5 0 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49788 .00286 Mdot
.49325 .00912 Mdot
.4785 .02898 Mdot
.43161 .09045 Mdot
.28525 .23439 Mdot
.49992 .00011 Mdot
.49973 .00037 Mdot
.49914 .00116 Mdot
.49726 .00371 Mdot
.49126 .01181 Mdot
.47215 .03749 Mdot
.41149 .11538 Mdot
.22481 .26108 Mdot
.80237 .12145 Mdot
.60586 .03039 Mdot
.5567 .59697 Mdot
.59078 .5173 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49773 .00307 Mdot
.49277 .00977 Mdot
.47697 .03104 Mdot
.42674 .09658 Mdot
.27047 .24291 Mdot
.87743 .14018 Mdot
.6506 .02049 Mdot
.61745 .53926 Mdot
.74492 .39179 Mdot
.11099 .48654 Mdot
.49998 2e-05 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49838 .00219 Mdot
.49484 .00696 Mdot
.48357 .02216 Mdot
.44771 .06977 Mdot
.33482 .19686 Mdot
.0163 .21194 Mdot
.67337 .08117 Mdot
.54204 .04264 Mdot
.5013 .61627 Mdot
.50416 .61242 Mdot
.51324 .60016 Mdot
.54216 .56153 Mdot
.63358 .45173 Mdot
.90266 .36702 Mdot
.30882 .5046 Mdot
.49236 .51168 Mdot
.66444 .38495 Mdot
.04158 .42306 Mdot
.35706 .53846 Mdot
.50036 .61755 Mdot
.50114 .61649 Mdot
.50364 .61311 Mdot
.51161 .60236 Mdot
.53697 .5684 Mdot
.61727 .46926 Mdot
.858 .3544 Mdot
.28457 .49848 Mdot
.47802 .51879 Mdot
.6386 .40593 Mdot
.98179 .38909 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48983 .01374 Mdot
.4676 .04356 Mdot
.39712 .13243 Mdot
.18283 .26703 Mdot
.75076 .11949 Mdot
.55742 .06741 Mdot
.44836 .11445 Mdot
.26318 .26148 Mdot
.84009 .13695 Mdot
.49989 .00014 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00469 Mdot
.48895 .01492 Mdot
.46481 .04728 Mdot
.38831 .14253 Mdot
.1577 .26595 Mdot
.72739 .11989 Mdot
.5334 .08915 Mdot
.38915 .1838 Mdot
.09176 .26423 Mdot
.50009 .61791 Mdot
.50029 .61764 Mdot
.50093 .61678 Mdot
.50296 .61404 Mdot
.50943 .6053 Mdot
.53003 .57763 Mdot
.59541 .49438 Mdot
.79548 .35282 Mdot
.22461 .49849 Mdot
.41803 .57117 Mdot
.49387 .57685 Mdot
.50066 .61714 Mdot
.5021 .6152 Mdot
.50669 .609 Mdot
.52132 .58929 Mdot
.56782 .52831 Mdot
.71299 .38474 Mdot
.09048 .46417 Mdot
.33944 .58902 Mdot
.38638 .0676 Mdot
.27701 .21302 Mdot
.93233 .15216 Mdot
.50058 .61725 Mdot
.50186 .61552 Mdot
.50592 .61004 Mdot
.51885 .59261 Mdot
.55999 .5383 Mdot
.689 .40146 Mdot
.03943 .43764 Mdot
.33131 .56634 Mdot
.41495 .02345 Mdot
.37701 .12646 Mdot
.17239 .25681 Mdot
.50111 .61654 Mdot
.50353 .61326 Mdot
.51125 .60284 Mdot
.53583 .56991 Mdot
.61369 .47325 Mdot
.84795 .35278 Mdot
.27714 .49818 Mdot
.47106 .52486 Mdot
.62182 .42264 Mdot
.93797 .36658 Mdot
.34483 .4887 Mdot
.5003 .61762 Mdot
.50097 .61673 Mdot
.50308 .61387 Mdot
.50982 .60477 Mdot
.53127 .57597 Mdot
.59934 .48974 Mdot
.80692 .35153 Mdot
.23813 .49867 Mdot
.43127 .56042 Mdot
.52449 .53781 Mdot
.65429 .41615 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00344 Mdot
.49188 .01097 Mdot
.47414 .03484 Mdot
.41777 .10772 Mdot
.24348 .25514 Mdot
.83066 .12614 Mdot
.62656 .02079 Mdot
.59292 .55749 Mdot
.69088 .42001 Mdot
.01128 .43046 Mdot
.49995 6e-05 Mdot
.49985 .00021 Mdot
.49951 .00066 Mdot
.49845 .00209 Mdot
.49507 .00665 Mdot
.48431 .02118 Mdot
.45004 .06674 Mdot
.34206 .19028 Mdot
.03418 .22172 Mdot
.67542 .09008 Mdot
.52967 .06273 Mdot
.42817 .12709 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49757 .00328 Mdot
.49226 .01046 Mdot
.47534 .03323 Mdot
.42157 .10303 Mdot
.25487 .2505 Mdot
.84955 .13089 Mdot
.63777 .01854 Mdot
.60777 .54413 Mdot
.72735 .39808 Mdot
.08325 .47178 Mdot
.49963 .0005 Mdot
.49883 .00158 Mdot
.49628 .00503 Mdot
.48813 .01602 Mdot
.4622 .05073 Mdot
.38011 .15166 Mdot
.13473 .26217 Mdot
.71053 .11913 Mdot
.51777 .10269 Mdot
.35161 .22117 Mdot
.99375 .21538 Mdot
.64526 .09865 Mdot
.49994 8e-05 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49428 .00773 Mdot
.48176 .0246 Mdot
.44196 .07722 Mdot
.31701 .21189 Mdot
.97417 .18804 Mdot
.66991 .05879 Mdot
.57479 .61002 Mdot
.58776 .53272 Mdot
.49982 .00024 Mdot
.49942 .00078 Mdot
.49816 .00249 Mdot
.49414 .00792 Mdot
.48132 .0252 Mdot
.44054 .07905 Mdot
.31265 .21531 Mdot
.96427 .18246 Mdot
.66904 .0536 Mdot
.58232 .59868 Mdot
.61364 .50205 Mdot
.8013 .36211 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48978 .01381 Mdot
.46743 .04379 Mdot
.39658 .13306 Mdot
.18128 .26706 Mdot
.74916 .11952 Mdot
.55577 .06887 Mdot
.44434 .11942 Mdot
.25111 .26696 Mdot
.81915 .13313 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49673 .00442 Mdot
.48958 .01407 Mdot
.46682 .0446 Mdot
.39465 .13529 Mdot
.17574 .26707 Mdot
.74362 .11964 Mdot
.55004 .07401 Mdot
.43028 .1366 Mdot
.20926 .27934 Mdot
.75729 .13195 Mdot
.50049 .61737 Mdot
.50156 .61592 Mdot
.50497 .61131 Mdot
.51585 .59665 Mdot
.55045 .55066 Mdot
.65947 .42635 Mdot
.96962 .39836 Mdot
.32507 .52979 Mdot
.46785 .5594 Mdot
.56273 .50274 Mdot
.74928 .35519 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00098 Mdot
.49769 .00312 Mdot
.49263 .00995 Mdot
.47653 .03164 Mdot
.42534 .09834 Mdot
.26622 .24512 Mdot
.86961 .13732 Mdot
.64743 .01937 Mdot
.61609 .53907 Mdot
.49966 .00046 Mdot
.49891 .00147 Mdot
.49653 .00468 Mdot
.48895 .01492 Mdot
.46482 .04727 Mdot
.38834 .1425 Mdot
.15777 .26595 Mdot
.72745 .11989 Mdot
.53346 .08909 Mdot
.38931 .18364 Mdot
.09217 .26439 Mdot
.66438 .13769 Mdot
.5003 .61763 Mdot
.50096 .61674 Mdot
.50306 .6139 Mdot
.50974 .60488 Mdot
.53103 .5763 Mdot
.59856 .49066 Mdot
.80465 .35173 Mdot
.23554 .49867 Mdot
.42868 .56259 Mdot
.51839 .54557 Mdot
.63564 .43451 Mdot
.49982 .00024 Mdot
.49943 .00076 Mdot
.4982 .00243 Mdot
.49426 .00775 Mdot
.48172 .02465 Mdot
.44183 .07738 Mdot
.31662 .21219 Mdot
.97329 .18755 Mdot
.66984 .05833 Mdot
.57546 .609 Mdot
.59009 .52987 Mdot
.73274 .38319 Mdot
.49979 .00029 Mdot
.49932 .00093 Mdot
.49782 .00295 Mdot
.49305 .00939 Mdot
.47786 .02985 Mdot
.42956 .09304 Mdot
.27903 .23813 Mdot
.89372 .14677 Mdot
.65625 .02409 Mdot
.61726 .54299 Mdot
.73869 .39582 Mdot
.09825 .48122 Mdot
.50029 .61765 Mdot
.50091 .6168 Mdot
.50292 .6141 Mdot
.50929 .60549 Mdot
.52959 .57822 Mdot
.59401 .49605 Mdot
.79138 .35346 Mdot
.21946 .4983 Mdot
.41319 .57484 Mdot
.48307 .59051 Mdot
.52762 .56503 Mdot
.50032 .6176 Mdot
.50103 .61665 Mdot
.50327 .61361 Mdot
.51042 .60396 Mdot
.5332 .5734 Mdot
.60541 .48267 Mdot
.82444 .35097 Mdot
.25656 .49839 Mdot
.45015 .54386 Mdot
.57017 .48089 Mdot
.79207 .33847 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50407 .61253 Mdot
.51298 .60051 Mdot
.54134 .56261 Mdot
.63102 .45441 Mdot
.89576 .36454 Mdot
.30592 .50307 Mdot
.49194 .51054 Mdot
.66586 .38314 Mdot
.04594 .42513 Mdot
.49968 .00043 Mdot
.49899 .00136 Mdot
.49679 .00434 Mdot
.48977 .01382 Mdot
.46741 .04382 Mdot
.3965 .13315 Mdot
.18106 .26707 Mdot
.74894 .11953 Mdot
.55554 .06908 Mdot
.44377 .12013 Mdot
.2494 .26767 Mdot
.8163 .13274 Mdot
.49978 .0003 Mdot
.4993 .00094 Mdot
.49778 .003 Mdot
.49293 .00955 Mdot
.47747 .03036 Mdot
.42835 .09457 Mdot
.27533 .24025 Mdot
.88659 .14379 Mdot
.65394 .02232 Mdot
.61783 .54083 Mdot
.74275 .39344 Mdot
.10616 .48471 Mdot
.49966 .00046 Mdot
.49891 .00148 Mdot
.49651 .00471 Mdot
.48889 .015 Mdot
.46461 .04754 Mdot
.38769 .14323 Mdot
.15594 .26575 Mdot
.72595 .11988 Mdot
.53198 .09044 Mdot
.38564 .18757 Mdot
.08215 .26039 Mdot
.66083 .1354 Mdot
.50107 .61659 Mdot
.5034 .61344 Mdot
.51084 .6034 Mdot
.53452 .57165 Mdot
.60957 .47791 Mdot
.8363 .35153 Mdot
.26751 .49818 Mdot
.46144 .53358 Mdot
.5981 .44828 Mdot
.87276 .3425 Mdot
.31859 .47655 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00114 Mdot
.4973 .00364 Mdot
.49141 .0116 Mdot
.47264 .03684 Mdot
.41304 .1135 Mdot
.22939 .25981 Mdot
.80901 .12229 Mdot
.61114 .02743 Mdot
.56675 .58538 Mdot
.61959 .48465 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00206 Mdot
.49513 .00657 Mdot
.4845 .02092 Mdot
.45064 .06595 Mdot
.34394 .18853 Mdot
.03888 .22422 Mdot
.67608 .0923 Mdot
.52673 .06764 Mdot
.41729 .14091 Mdot
.1893 .27785 Mdot
.49998 3e-05 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.4925 .01013 Mdot
.47611 .0322 Mdot
.42402 .09999 Mdot
.26222 .2471 Mdot
.86241 .13485 Mdot
.64421 .01872 Mdot
.61393 .53993 Mdot
.50054 .6173 Mdot
.50173 .6157 Mdot
.5055 .6106 Mdot
.51753 .59438 Mdot
.5558 .54371 Mdot
.67606 .4118 Mdot
.00976 .42084 Mdot
.32883 .55066 Mdot
.43784 .60682 Mdot
.45598 .02908 Mdot
.40893 .10897 Mdot
.50121 .6164 Mdot
.50386 .61282 Mdot
.5123 .60142 Mdot
.53918 .56546 Mdot
.62425 .46163 Mdot
.87732 .35883 Mdot
.29672 .50006 Mdot
.48761 .51154 Mdot
.65992 .387 Mdot
.03375 .41805 Mdot
.35733 .5333 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01428 Mdot
.46631 .04529 Mdot
.39303 .13715 Mdot
.17112 .26694 Mdot
.7392 .11974 Mdot
.54546 .07816 Mdot
.41899 .15006 Mdot
.17619 .28202 Mdot
.71987 .13711 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49768 .00314 Mdot
.49259 .01001 Mdot
.4764 .0318 Mdot
.42495 .09882 Mdot
.26505 .24571 Mdot
.86749 .13657 Mdot
.64651 .01914 Mdot
.61554 .53922 Mdot
.74307 .39181 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49384 .00831 Mdot
.48039 .02645 Mdot
.4376 .08282 Mdot
.30359 .22209 Mdot
.94424 .17145 Mdot
.66684 .04359 Mdot
.5963 .5777 Mdot
.66157 .45235 Mdot
.92965 .38924 Mdot
.50046 .61741 Mdot
.50148 .61603 Mdot
.50471 .61167 Mdot
.51502 .59776 Mdot
.54782 .55409 Mdot
.65128 .43404 Mdot
.94899 .38756 Mdot
.32192 .52029 Mdot
.48007 .53872 Mdot
.60839 .44583 Mdot
.88703 .34967 Mdot
.50129 .61629 Mdot
.50411 .61248 Mdot
.5131 .60035 Mdot
.54172 .56212 Mdot
.6322 .45318 Mdot
.89894 .36566 Mdot
.30729 .50375 Mdot
.49221 .51097 Mdot
.66545 .38375 Mdot
.04452 .42449 Mdot
.35768 .53954 Mdot
.49983 .00022 Mdot
.49947 .00071 Mdot
.49832 .00227 Mdot
.49464 .00724 Mdot
.48292 .02305 Mdot
.44563 .07248 Mdot
.32835 .2025 Mdot
.0007 .20315 Mdot
.672 .07297 Mdot
.55392 .02394 Mdot
.51519 .00988 Mdot
.4992 .01062 Mdot
.50023 .61772 Mdot
.50073 .61705 Mdot
.50233 .61489 Mdot
.50741 .60803 Mdot
.5236 .58623 Mdot
.57506 .5192 Mdot
.73498 .37231 Mdot
.13257 .48148 Mdot
.35351 .5989 Mdot
.38447 .07881 Mdot
.25695 .22621 Mdot
.49975 .00033 Mdot
.49921 .00107 Mdot
.49748 .0034 Mdot
.49199 .01082 Mdot
.47447 .03439 Mdot
.41883 .10642 Mdot
.24664 .25393 Mdot
.83577 .1273 Mdot
.6298 .01987 Mdot
.59765 .55295 Mdot
.70295 .41181 Mdot
.03664 .44547 Mdot
.50105 .61661 Mdot
.50336 .6135 Mdot
.51069 .60359 Mdot
.53406 .57226 Mdot
.60812 .47956 Mdot
.83217 .35125 Mdot
.26384 .49824 Mdot
.45768 .53701 Mdot
.58877 .45892 Mdot
.84622 .33753 Mdot
.30009 .47783 Mdot
.5005 .61736 Mdot
.50158 .6159 Mdot
.50504 .61123 Mdot
.51604 .59638 Mdot
.55107 .54985 Mdot
.6614 .42458 Mdot
.97442 .40096 Mdot
.32564 .53216 Mdot
.4646 .56471 Mdot
.55088 .51834 Mdot
.71218 .37494 Mdot
.49983 .00023 Mdot
.49947 .00072 Mdot
.49831 .00229 Mdot
.49461 .00729 Mdot
.48282 .02318 Mdot
.44531 .07289 Mdot
.32738 .20334 Mdot
.99837 .20183 Mdot
.67181 .07173 Mdot
.55574 .0211 Mdot
.5216 .00114 Mdot
.51975 .60091 Mdot
.50122 .61638 Mdot
.50389 .61278 Mdot
.51239 .60131 Mdot
.53946 .5651 Mdot
.62511 .4607 Mdot
.87968 .35948 Mdot
.29802 .50036 Mdot
.48842 .51108 Mdot
.66148 .38578 Mdot
.03728 .42002 Mdot
.35767 .53507 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.49822 .00241 Mdot
.49432 .00767 Mdot
.48192 .02439 Mdot
.44245 .07659 Mdot
.31851 .21068 Mdot
.97763 .19001 Mdot
.67019 .06063 Mdot
.57209 .61409 Mdot
.57848 .54425 Mdot
.69786 .40455 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46277 .04998 Mdot
.38189 .1497 Mdot
.13968 .26319 Mdot
.71382 .11944 Mdot
.52056 .10044 Mdot
.35805 .21527 Mdot
.00974 .22429 Mdot
.64683 .10667 Mdot
.50039 .6175 Mdot
.50125 .61634 Mdot
.50399 .61265 Mdot
.5127 .60089 Mdot
.54045 .56379 Mdot
.62822 .45737 Mdot
.88817 .36203 Mdot
.3024 .50164 Mdot
.49073 .51024 Mdot
.66515 .38317 Mdot
.04517 .42448 Mdot
.5009 .61681 Mdot
.50288 .61415 Mdot
.50917 .60565 Mdot
.52921 .57873 Mdot
.59281 .49748 Mdot
.78786 .35409 Mdot
.21492 .49807 Mdot
.40903 .57789 Mdot
.47399 .60189 Mdot
.50011 .6018 Mdot
.52638 .57745 Mdot
.49963 .0005 Mdot
.49881 .00161 Mdot
.49622 .00511 Mdot
.48794 .01628 Mdot
.4616 .05154 Mdot
.37821 .15375 Mdot
.12944 .26094 Mdot
.70722 .1187 Mdot
.51516 .10466 Mdot
.34582 .22627 Mdot
.97971 .20751 Mdot
.64396 .09152 Mdot
.50127 .61632 Mdot
.50404 .61257 Mdot
.51287 .60065 Mdot
.541 .56306 Mdot
.62994 .45554 Mdot
.89286 .36355 Mdot
.30462 .50249 Mdot
.49157 .51031 Mdot
.66588 .3829 Mdot
.04634 .42525 Mdot
.35827 .53995 Mdot
.50065 .61716 Mdot
.50207 .61523 Mdot
.5066 .60911 Mdot
.52103 .58967 Mdot
.56693 .52944 Mdot
.71028 .38647 Mdot
.08496 .46154 Mdot
.33817 .58702 Mdot
.38836 .0642 Mdot
.28448 .2083 Mdot
.94745 .16046 Mdot
.49995 7e-05 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00215 Mdot
.49494 .00684 Mdot
.48387 .02177 Mdot
.44864 .06857 Mdot
.33769 .19428 Mdot
.02334 .21584 Mdot
.67411 .08475 Mdot
.53697 .05079 Mdot
.45479 .09214 Mdot
.50062 .6172 Mdot
.50197 .61538 Mdot
.50626 .60958 Mdot
.51995 .59113 Mdot
.56347 .53384 Mdot
.6997 .3936 Mdot
.06284 .45036 Mdot
.33415 .57776 Mdot
.39932 .04695 Mdot
.32335 .17911 Mdot
.03355 .20998 Mdot
.50002 .61801 Mdot
.50005 .61797 Mdot
.50016 .61782 Mdot
.50051 .61735 Mdot
.50162 .61584 Mdot
.50517 .61105 Mdot
.51646 .59582 Mdot
.5524 .54812 Mdot
.66553 .42087 Mdot
.98454 .40656 Mdot
.32671 .5373 Mdot
.49962 .00052 Mdot
.49878 .00164 Mdot
.49612 .00524 Mdot
.48765 .01668 Mdot
.46066 .05278 Mdot
.37526 .15694 Mdot
.12133 .25883 Mdot
.70253 .1178 Mdot
.51191 .10677 Mdot
.33916 .23176 Mdot
.96416 .19881 Mdot
.64247 .08368 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49986 .00019 Mdot
.49956 .00059 Mdot
.4986 .00189 Mdot
.49553 .00603 Mdot
.48577 .0192 Mdot
.4547 .06064 Mdot
.35659 .17631 Mdot
.07132 .24023 Mdot
.68261 .10572 Mdot
.51156 .09501 Mdot
.50033 .61758 Mdot
.50106 .6166 Mdot
.50339 .61346 Mdot
.51079 .60347 Mdot
.53435 .57187 Mdot
.60905 .4785 Mdot
.83482 .35142 Mdot
.26621 .4982 Mdot
.46011 .53479 Mdot
.59481 .45201 Mdot
.86345 .34038 Mdot
.49966 .00046 Mdot
.49892 .00146 Mdot
.49656 .00465 Mdot
.48903 .01481 Mdot
.46506 .04694 Mdot
.38911 .14162 Mdot
.15996 .26618 Mdot
.72927 .11988 Mdot
.5353 .08743 Mdot
.39383 .17872 Mdot
.10466 .2689 Mdot
.66957 .1398 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50726 .60823 Mdot
.52311 .58688 Mdot
.57352 .52112 Mdot
.73032 .37471 Mdot
.12403 .4784 Mdot
.34996 .59779 Mdot
.38273 .0789 Mdot
.25507 .22637 Mdot
.8888 .13146 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.5083 .60682 Mdot
.52644 .58243 Mdot
.58405 .50808 Mdot
.76197 .36095 Mdot
.17794 .49363 Mdot
.37924 .59514 Mdot
.41627 .0512 Mdot
.33343 .17893 Mdot
.04391 .21913 Mdot
.50037 .61754 Mdot
.50117 .61645 Mdot
.50374 .61298 Mdot
.51191 .60195 Mdot
.53793 .56712 Mdot
.62032 .4659 Mdot
.86648 .35614 Mdot
.29024 .49899 Mdot
.48285 .51485 Mdot
.6498 .39559 Mdot
.00972 .4046 Mdot
.50077 .61699 Mdot
.50246 .61471 Mdot
.50785 .60744 Mdot
.52499 .58436 Mdot
.57948 .51371 Mdot
.74828 .36617 Mdot
.15581 .48862 Mdot
.3652 .59917 Mdot
.39572 .07104 Mdot
.28078 .21583 Mdot
.93156 .15432 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49732 .00361 Mdot
.49148 .01151 Mdot
.47285 .03656 Mdot
.41369 .11271 Mdot
.23132 .25924 Mdot
.81186 .1227 Mdot
.61333 .0263 Mdot
.57078 .58085 Mdot
.63094 .4727 Mdot
.86609 .3627 Mdot
.50028 .61765 Mdot
.5009 .61682 Mdot
.50286 .61417 Mdot
.50911 .60573 Mdot
.52902 .57897 Mdot
.59223 .49818 Mdot
.78616 .35442 Mdot
.21269 .49793 Mdot
.40701 .57931 Mdot
.46966 .60727 Mdot
.48708 .0012 Mdot
.50064 .61717 Mdot
.50204 .61528 Mdot
.5065 .60925 Mdot
.5207 .59011 Mdot
.56588 .53077 Mdot
.70707 .38856 Mdot
.07837 .45831 Mdot
.3368 .58445 Mdot
.39114 .05965 Mdot
.29464 .20143 Mdot
.96872 .17262 Mdot
.49967 .00044 Mdot
.49895 .00142 Mdot
.49666 .00451 Mdot
.48936 .01437 Mdot
.4661 .04556 Mdot
.39238 .1379 Mdot
.16926 .26686 Mdot
.73747 .11977 Mdot
.54367 .07979 Mdot
.41457 .15524 Mdot
.16338 .28147 Mdot
.70795 .13904 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51032 .60409 Mdot
.53288 .57383 Mdot
.6044 .48384 Mdot
.82154 .35095 Mdot
.2537 .49845 Mdot
.44718 .54652 Mdot
.56289 .48973 Mdot
.77049 .34341 Mdot
.21485 .48737 Mdot
.50039 .61751 Mdot
.50123 .61637 Mdot
.50392 .61273 Mdot
.5125 .60116 Mdot
.53981 .56464 Mdot
.62621 .45952 Mdot
.88269 .36035 Mdot
.29963 .50078 Mdot
.48936 .51064 Mdot
.66313 .38453 Mdot
.04094 .42207 Mdot
.49996 5e-05 Mdot
.49987 .00017 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49592 .00551 Mdot
.48702 .01753 Mdot
.45865 .05543 Mdot
.36896 .16365 Mdot
.10418 .25347 Mdot
.69405 .11495 Mdot
.50806 .10749 Mdot
.33414 .23489 Mdot
.49962 .00052 Mdot
.49878 .00165 Mdot
.49611 .00526 Mdot
.48759 .01675 Mdot
.46049 .053 Mdot
.37473 .15751 Mdot
.11986 .25842 Mdot
.70173 .11761 Mdot
.51142 .10703 Mdot
.33824 .23247 Mdot
.9621 .19766 Mdot
.64227 .08265 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00302 Mdot
.49288 .00961 Mdot
.47733 .03056 Mdot
.42787 .09516 Mdot
.27389 .24105 Mdot
.88386 .14269 Mdot
.65299 .02172 Mdot
.61785 .54021 Mdot
.74376 .39278 Mdot
.10823 .48556 Mdot
.50081 .61694 Mdot
.50258 .61455 Mdot
.50821 .60695 Mdot
.52615 .58282 Mdot
.58313 .50921 Mdot
.75922 .36191 Mdot
.17364 .49279 Mdot
.37628 .59628 Mdot
.41148 .05615 Mdot
.32063 .1894 Mdot
.01418 .20253 Mdot
.49992 .00011 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49148 .01151 Mdot
.47286 .03655 Mdot
.41373 .11267 Mdot
.23143 .25921 Mdot
.81202 .12272 Mdot
.61345 .02624 Mdot
.57099 .58062 Mdot
.63153 .4721 Mdot
.49963 .00049 Mdot
.49883 .00157 Mdot
.49629 .00502 Mdot
.48817 .01597 Mdot
.46233 .05057 Mdot
.38051 .15122 Mdot
.13583 .2624 Mdot
.71125 .11921 Mdot
.51837 .10222 Mdot
.35297 .21995 Mdot
.99708 .21725 Mdot
.64557 .10034 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.49992 .00011 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49729 .00365 Mdot
.49138 .01164 Mdot
.47255 .03697 Mdot
.41273 .11388 Mdot
.22848 .26007 Mdot
.80767 .12211 Mdot
.61009 .02799 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00155 Mdot
.49634 .00494 Mdot
.48835 .01573 Mdot
.4629 .04981 Mdot
.3823 .14925 Mdot
.14082 .26341 Mdot
.71461 .1195 Mdot
.52125 .09986 Mdot
.35967 .21374 Mdot
.01383 .22655 Mdot
.50045 .61743 Mdot
.50142 .61612 Mdot
.50452 .61193 Mdot
.5144 .5986 Mdot
.54584 .55669 Mdot
.6451 .44005 Mdot
.93308 .37983 Mdot
.31851 .51391 Mdot
.48699 .52596 Mdot
.63596 .4147 Mdot
.96497 .38248 Mdot
.50014 .61784 Mdot
.50046 .61741 Mdot
.50147 .61605 Mdot
.50467 .61172 Mdot
.51488 .59795 Mdot
.54738 .55467 Mdot
.64992 .43534 Mdot
.94552 .38582 Mdot
.32125 .51882 Mdot
.48179 .53567 Mdot
.61506 .43805 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49565 .00588 Mdot
.48613 .01873 Mdot
.45582 .05916 Mdot
.36009 .17279 Mdot
.0805 .24428 Mdot
.68524 .10878 Mdot
.50923 .10023 Mdot
.34705 .22119 Mdot
.50101 .61667 Mdot
.50321 .61369 Mdot
.51024 .60421 Mdot
.53261 .57419 Mdot
.60355 .48483 Mdot
.81908 .35096 Mdot
.25121 .4985 Mdot
.44461 .54882 Mdot
.5566 .49745 Mdot
.7517 .34992 Mdot
.18552 .48552 Mdot
.49962 .00051 Mdot
.49879 .00164 Mdot
.49613 .00522 Mdot
.48768 .01663 Mdot
.46077 .05264 Mdot
.37559 .15658 Mdot
.12224 .25909 Mdot
.70303 .11792 Mdot
.51223 .10659 Mdot
.33977 .23128 Mdot
.96555 .19959 Mdot
.6426 .08438 Mdot
.49997 4e-05 Mdot
.4999 .00014 Mdot
.49968 .00043 Mdot
.49898 .00138 Mdot
.49676 .00438 Mdot
.48966 .01396 Mdot
.46707 .04427 Mdot
.39544 .13438 Mdot
.17802 .26709 Mdot
.74587 .11959 Mdot
.55236 .07192 Mdot
.436 .12966 Mdot
.50048 .61739 Mdot
.50152 .61599 Mdot
.50483 .61151 Mdot
.51539 .59726 Mdot
.54901 .55254 Mdot
.65499 .43051 Mdot
.9584 .39239 Mdot
.32351 .52447 Mdot
.47489 .54765 Mdot
.58877 .46956 Mdot
.829 .33982 Mdot
.49964 .00048 Mdot
.49887 .00153 Mdot
.49639 .00488 Mdot
.48848 .01555 Mdot
.46332 .04925 Mdot
.38364 .14777 Mdot
.14454 .26409 Mdot
.71723 .11966 Mdot
.52362 .09785 Mdot
.3653 .20834 Mdot
.02819 .23434 Mdot
.64902 .11551 Mdot
.49992 .00011 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.49739 .00352 Mdot
.4917 .01121 Mdot
.47356 .03561 Mdot
.41595 .10996 Mdot
.23803 .25708 Mdot
.82206 .12441 Mdot
.62077 .02289 Mdot
.58373 .56683 Mdot
.66658 .43909 Mdot
.50045 .61742 Mdot
.50144 .61609 Mdot
.50459 .61183 Mdot
.51462 .5983 Mdot
.54656 .55575 Mdot
.64734 .43785 Mdot
.93889 .38258 Mdot
.31987 .51613 Mdot
.48475 .53024 Mdot
.6268 .42474 Mdot
.93955 .37004 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49681 .00431 Mdot
.48985 .01371 Mdot
.46766 .04349 Mdot
.39729 .13223 Mdot
.18334 .26702 Mdot
.75129 .11948 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00125 Mdot
.49706 .00397 Mdot
.49064 .01264 Mdot
.47019 .04011 Mdot
.40529 .12282 Mdot
.20656 .26491 Mdot
.77793 .11963 Mdot
.58437 .04502 Mdot
.51152 .03435 Mdot
.50043 .61746 Mdot
.50137 .61619 Mdot
.50435 .61216 Mdot
.51386 .59933 Mdot
.54413 .55894 Mdot
.63975 .4454 Mdot
.91908 .37357 Mdot
.31463 .50912 Mdot
.49085 .51759 Mdot
.65337 .39642 Mdot
.01194 .40748 Mdot
.50018 .6178 Mdot
.50056 .61728 Mdot
.50178 .61563 Mdot
.50567 .61038 Mdot
.51806 .59367 Mdot
.55748 .54154 Mdot
.68126 .40754 Mdot
.02184 .42773 Mdot
.32977 .55712 Mdot
.42832 .00332 Mdot
.42295 .07199 Mdot
.5003 .61763 Mdot
.50095 .61675 Mdot
.50303 .61394 Mdot
.50966 .60499 Mdot
.53078 .57663 Mdot
.59776 .49159 Mdot
.80235 .35196 Mdot
.23287 .49865 Mdot
.42604 .56477 Mdot
.51221 .55346 Mdot
.61669 .45472 Mdot
.50085 .61689 Mdot
.5027 .61438 Mdot
.50861 .60641 Mdot
.52742 .58111 Mdot
.58717 .50428 Mdot
.77122 .35805 Mdot
.19189 .49587 Mdot
.38956 .59023 Mdot
.43455 .03117 Mdot
.38411 .12936 Mdot
.17479 .26074 Mdot
.49976 .00033 Mdot
.49923 .00104 Mdot
.49754 .00332 Mdot
.49218 .01057 Mdot
.47507 .03358 Mdot
.42073 .10407 Mdot
.25235 .25159 Mdot
.84526 .1297 Mdot
.6354 .01878 Mdot
.60502 .54637 Mdot
.72098 .40127 Mdot
.07171 .46552 Mdot
.50007 .61794 Mdot
.50023 .61772 Mdot
.50073 .61704 Mdot
.50233 .61488 Mdot
.50743 .60799 Mdot
.52368 .58612 Mdot
.57532 .51887 Mdot
.73577 .37191 Mdot
.134 .48198 Mdot
.35415 .59904 Mdot
.38488 .07866 Mdot
.4999 .00014 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.4967 .00446 Mdot
.48947 .01421 Mdot
.46647 .04507 Mdot
.39356 .13655 Mdot
.17261 .26699 Mdot
.7406 .11971 Mdot
.54691 .07684 Mdot
.42258 .14581 Mdot
.18665 .28182 Mdot
.4996 .00055 Mdot
.49871 .00174 Mdot
.4959 .00554 Mdot
.48695 .01762 Mdot
.45843 .05572 Mdot
.36828 .16436 Mdot
.10233 .25283 Mdot
.69325 .11456 Mdot
.50788 .10726 Mdot
.33433 .23457 Mdot
.95479 .19322 Mdot
.64215 .07827 Mdot
.50082 .61693 Mdot
.50261 .61451 Mdot
.5083 .60682 Mdot
.52645 .58241 Mdot
.58409 .50803 Mdot
.76207 .36091 Mdot
.1781 .49366 Mdot
.37935 .5951 Mdot
.41646 .05101 Mdot
.33393 .17851 Mdot
.0451 .21976 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49972 .00038 Mdot
.49911 .00121 Mdot
.49715 .00385 Mdot
.49093 .01225 Mdot
.47111 .03889 Mdot
.40818 .11936 Mdot
.21505 .26336 Mdot
.78892 .12021 Mdot
.59441 .03773 Mdot
.53337 .00702 Mdot
.50103 .61665 Mdot
.50327 .61362 Mdot
.51042 .60397 Mdot
.53318 .57343 Mdot
.60534 .48275 Mdot
.82424 .35097 Mdot
.25636 .49839 Mdot
.44994 .54404 Mdot
.56967 .48149 Mdot
.7906 .33872 Mdot
.24254 .4861 Mdot
.5004 .61749 Mdot
.50127 .61631 Mdot
.50406 .61255 Mdot
.51292 .60058 Mdot
.54116 .56285 Mdot
.63044 .45502 Mdot
.89421 .36401 Mdot
.30523 .50276 Mdot
.49175 .5104 Mdot
.66591 .38297 Mdot
.04626 .42525 Mdot
.4997 .0004 Mdot
.49905 .00129 Mdot
.49697 .0041 Mdot
.49033 .01306 Mdot
.4692 .04143 Mdot
.40216 .12653 Mdot
.19743 .2661 Mdot
.76687 .11938 Mdot
.57371 .05347 Mdot
.48719 .06533 Mdot
.38148 .16533 Mdot
.11398 .26219 Mdot
.50109 .61656 Mdot
.50348 .61333 Mdot
.51109 .60305 Mdot
.53533 .57057 Mdot
.61214 .475 Mdot
.84358 .35223 Mdot
.27366 .49815 Mdot
.46764 .52794 Mdot
.61342 .43147 Mdot
.91528 .35659 Mdot
.33831 .482 Mdot
.49995 7e-05 Mdot
.49984 .00022 Mdot
.49948 .00071 Mdot
.49833 .00226 Mdot
.49468 .00719 Mdot
.48304 .02288 Mdot
.44602 .07197 Mdot
.32958 .20145 Mdot
.00363 .20481 Mdot
.67224 .07453 Mdot
.55164 .02749 Mdot
.50716 .02086 Mdot
.50072 .61707 Mdot
.50228 .61495 Mdot
.50727 .60821 Mdot
.52317 .58681 Mdot
.5737 .5209 Mdot
.73086 .37442 Mdot
.12503 .47877 Mdot
.35036 .59794 Mdot
.38287 .07895 Mdot
.25512 .22642 Mdot
.88876 .13149 Mdot
.49967 .00045 Mdot
.49894 .00144 Mdot
.49661 .00458 Mdot
.4892 .01459 Mdot
.46559 .04624 Mdot
.39078 .13973 Mdot
.16469 .26658 Mdot
.73336 .11984 Mdot
.53945 .08365 Mdot
.4041 .16727 Mdot
.13346 .27699 Mdot
.68527 .14148 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00057 Mdot
.49866 .00181 Mdot
.49573 .00577 Mdot
.48639 .01838 Mdot
.45665 .05808 Mdot
.36268 .17016 Mdot
.08735 .24713 Mdot
.68748 .11083 Mdot
.50815 .10328 Mdot
.34104 .22733 Mdot
.50068 .61711 Mdot
.50218 .61509 Mdot
.50695 .60864 Mdot
.52215 .58818 Mdot
.57045 .52498 Mdot
.72102 .37987 Mdot
.10637 .4713 Mdot
.34378 .59397 Mdot
.38272 .07508 Mdot
.26124 .22226 Mdot
.90163 .13675 Mdot
.50053 .61732 Mdot
.50167 .61577 Mdot
.50534 .61083 Mdot
.517 .5951 Mdot
.55411 .5459 Mdot
.67082 .41624 Mdot
.99733 .41376 Mdot
.32784 .54401 Mdot
.44762 .5917 Mdot
.49022 .60076 Mdot
.51817 .58395 Mdot
.50052 .61733 Mdot
.50165 .61581 Mdot
.50526 .61093 Mdot
.51674 .59544 Mdot
.5533 .54694 Mdot
.66833 .4184 Mdot
.99135 .41038 Mdot
.32733 .54085 Mdot
.45222 .58448 Mdot
.50652 .57844 Mdot
.57059 .51513 Mdot
.50074 .61703 Mdot
.50236 .61484 Mdot
.50752 .60787 Mdot
.52397 .58574 Mdot
.57622 .51775 Mdot
.73848 .37059 Mdot
.13886 .4836 Mdot
.35638 .59939 Mdot
.38654 .07785 Mdot
.26058 .22507 Mdot
.8964 .13567 Mdot
.4998 .00027 Mdot
.49937 .00085 Mdot
.49799 .00272 Mdot
.4936 .00865 Mdot
.4796 .02751 Mdot
.43508 .08604 Mdot
.29588 .22749 Mdot
.92778 .16282 Mdot
.66434 .03613 Mdot
.60587 .5631 Mdot
.69475 .42436 Mdot
.00813 .43189 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00305 Mdot
.4928 .00972 Mdot
.47707 .0309 Mdot
.42707 .09617 Mdot
.27147 .24237 Mdot
.87929 .1409 Mdot
.65132 .02082 Mdot
.61763 .53946 Mdot
.74477 .392 Mdot
.1105 .4864 Mdot
.49961 .00052 Mdot
.49876 .00167 Mdot
.49606 .00532 Mdot
.48745 .01694 Mdot
.46004 .0536 Mdot
.37332 .15902 Mdot
.11601 .2573 Mdot
.69969 .11706 Mdot
.51028 .10754 Mdot
.33628 .23393 Mdot
.95777 .19524 Mdot
.64187 .08046 Mdot
.49976 .00032 Mdot
.49924 .00103 Mdot
.49758 .00327 Mdot
.49229 .01041 Mdot
.47544 .03309 Mdot
.42189 .10263 Mdot
.25584 .25008 Mdot
.8512 .13137 Mdot
.63865 .01849 Mdot
.60873 .54338 Mdot
.72952 .39706 Mdot
.08706 .4738 Mdot
.5004 .6175 Mdot
.50126 .61633 Mdot
.50402 .61261 Mdot
.5128 .60075 Mdot
.54076 .56337 Mdot
.62921 .45632 Mdot
.89086 .36289 Mdot
.30369 .50212 Mdot
.49125 .51023 Mdot
.66568 .38291 Mdot
.04611 .42507 Mdot
.49993 .0001 Mdot
.49977 .00031 Mdot
.49926 .001 Mdot
.49765 .00318 Mdot
.49251 .01012 Mdot
.47613 .03217 Mdot
.42408 .09991 Mdot
.26243 .247 Mdot
.86278 .13497 Mdot
.64439 .01874 Mdot
.61406 .53986 Mdot
.74056 .39257 Mdot
.50086 .61687 Mdot
.50274 .61433 Mdot
.50873 .60624 Mdot
.52781 .58059 Mdot
.58839 .50279 Mdot
.77486 .35704 Mdot
.19715 .49653 Mdot
.39375 .58787 Mdot
.44255 .02195 Mdot
.40704 .10331 Mdot
.23987 .25056 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.50501 .61126 Mdot
.51597 .59649 Mdot
.55083 .55016 Mdot
.66066 .42526 Mdot
.97257 .39996 Mdot
.32543 .53124 Mdot
.46586 .56265 Mdot
.55548 .51225 Mdot
.72665 .36629 Mdot
.49981 .00026 Mdot
.4994 .00082 Mdot
.49808 .0026 Mdot
.49387 .00828 Mdot
.48046 .02635 Mdot
.43783 .08253 Mdot
.30429 .22158 Mdot
.94577 .17227 Mdot
.66703 .04432 Mdot
.59532 .57918 Mdot
.65819 .45551 Mdot
.92115 .38537 Mdot
.49991 .00011 Mdot
.49973 .00037 Mdot
.49914 .00117 Mdot
.49725 .00372 Mdot
.49123 .01184 Mdot
.47207 .0376 Mdot
.41122 .1157 Mdot
.22401 .26129 Mdot
.80124 .12132 Mdot
.60494 .03093 Mdot
.55489 .59909 Mdot
.58554 .52355 Mdot
.4996 .00054 Mdot
.49872 .00173 Mdot
.49591 .00552 Mdot
.48697 .01759 Mdot
.45852 .05561 Mdot
.36855 .16408 Mdot
.10306 .25308 Mdot
.69356 .11472 Mdot
.50794 .10736 Mdot
.33424 .23471 Mdot
.95447 .19308 Mdot
.64207 .07818 Mdot
.49977 .00032 Mdot
.49926 .001 Mdot
.49763 .0032 Mdot
.49245 .0102 Mdot
.47595 .0324 Mdot
.42352 .10061 Mdot
.26073 .24782 Mdot
.85976 .13399 Mdot
.64296 .01857 Mdot
.6129 .5405 Mdot
.73835 .39335 Mdot
.1019 .48149 Mdot
.4999 .00013 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.4969 .00418 Mdot
.49014 .01332 Mdot
.46859 .04225 Mdot
.40023 .1288 Mdot
.19183 .2666 Mdot
.76046 .11937 Mdot
.56731 .05881 Mdot
.47215 .0845 Mdot
.33543 .21129 Mdot
.50065 .61715 Mdot
.50209 .61522 Mdot
.50665 .60906 Mdot
.52117 .58949 Mdot
.56736 .52889 Mdot
.71159 .38563 Mdot
.08763 .46282 Mdot
.33877 .588 Mdot
.38736 .06589 Mdot
.28074 .21069 Mdot
.93983 .15624 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.5101 .6044 Mdot
.53216 .57479 Mdot
.60214 .48647 Mdot
.81501 .35106 Mdot
.24698 .49858 Mdot
.44026 .55267 Mdot
.54602 .5106 Mdot
.71985 .3657 Mdot
.12814 .47206 Mdot
.49984 .00022 Mdot
.49949 .00069 Mdot
.49837 .0022 Mdot
.49481 .00701 Mdot
.48347 .02231 Mdot
.44737 .07021 Mdot
.33376 .19779 Mdot
.01373 .2105 Mdot
.67313 .07984 Mdot
.54395 .03961 Mdot
.47986 .05823 Mdot
.38565 .15534 Mdot
.50119 .61643 Mdot
.50378 .61293 Mdot
.51203 .60179 Mdot
.53831 .56662 Mdot
.6215 .46461 Mdot
.86974 .35689 Mdot
.29228 .49926 Mdot
.48446 .51365 Mdot
.65336 .39248 Mdot
.01832 .40942 Mdot
.35586 .52552 Mdot
.50126 .61633 Mdot
.50403 .6126 Mdot
.51283 .60072 Mdot
.54084 .56327 Mdot
.62946 .45606 Mdot
.89154 .36311 Mdot
.30401 .50224 Mdot
.49136 .51025 Mdot
.66576 .38289 Mdot
.04623 .42515 Mdot
.35832 .53982 Mdot
.50073 .61704 Mdot
.50234 .61488 Mdot
.50745 .60798 Mdot
.52372 .58607 Mdot
.57544 .51872 Mdot
.73615 .37173 Mdot
.13467 .4822 Mdot
.35445 .5991 Mdot
.38509 .07858 Mdot
.25795 .22594 Mdot
.89237 .13359 Mdot
.50095 .61676 Mdot
.50302 .61396 Mdot
.50961 .60506 Mdot
.5306 .57687 Mdot
.5972 .49226 Mdot
.80071 .35214 Mdot
.23094 .49863 Mdot
.42414 .56632 Mdot
.50782 .55907 Mdot
.60322 .46995 Mdot
.84283 .3468 Mdot
.49974 .00035 Mdot
.49917 .00111 Mdot
.49737 .00355 Mdot
.49162 .01131 Mdot
.47332 .03593 Mdot
.41518 .1109 Mdot
.23573 .25785 Mdot
.81852 .12377 Mdot
.61825 .02396 Mdot
.57949 .57133 Mdot
.65506 .44927 Mdot
.92813 .38488 Mdot
.49982 .00025 Mdot
.49941 .00079 Mdot
.49813 .00253 Mdot
.49404 .00806 Mdot
.481 .02562 Mdot
.43954 .08033 Mdot
.30956 .21767 Mdot
.95737 .17862 Mdot
.66836 .05006 Mdot
.58736 .59111 Mdot
.63092 .48297 Mdot
.84946 .36331 Mdot
.49965 .00047 Mdot
.49889 .0015 Mdot
.49646 .00478 Mdot
.48874 .01521 Mdot
.46413 .04818 Mdot
.38616 .14494 Mdot
.15164 .2652 Mdot
.72254 .11984 Mdot
.52863 .09345 Mdot
.37743 .19617 Mdot
.06002 .2505 Mdot
.6547 .12863 Mdot
.49965 .00048 Mdot
.49888 .00151 Mdot
.49643 .00482 Mdot
.48863 .01535 Mdot
.46379 .04864 Mdot
.38509 .14615 Mdot
.14861 .26476 Mdot
.72023 .11978 Mdot
.52642 .09541 Mdot
.37204 .20166 Mdot
.04575 .24349 Mdot
.65177 .12316 Mdot
.50113 .61651 Mdot
.5036 .61317 Mdot
.51148 .60253 Mdot
.53657 .56893 Mdot
.61602 .47065 Mdot
.85448 .35378 Mdot
.28206 .49834 Mdot
.47573 .52075 Mdot
.63314 .41122 Mdot
.96778 .38155 Mdot
.35042 .50069 Mdot
.49962 .00051 Mdot
.4988 .00163 Mdot
.49616 .00518 Mdot
.48778 .0165 Mdot
.46109 .05222 Mdot
.3766 .15549 Mdot
.125 .25983 Mdot
.7046 .11824 Mdot
.51327 .10595 Mdot
.34184 .22961 Mdot
.97032 .20225 Mdot
.64307 .08678 Mdot
.49962 .00051 Mdot
.4988 .00162 Mdot
.49618 .00516 Mdot
.48783 .01643 Mdot
.46125 .052 Mdot
.3771 .15495 Mdot
.12639 .26019 Mdot
.7054 .1184 Mdot
.51383 .10559 Mdot
.34299 .22865 Mdot
.97303 .20377 Mdot
.64333 .08814 Mdot
.50096 .61673 Mdot
.50307 .61388 Mdot
.50979 .60481 Mdot
.53119 .57608 Mdot
.59908 .49004 Mdot
.80617 .35159 Mdot
.23728 .49867 Mdot
.43042 .56113 Mdot
.52249 .54035 Mdot
.64818 .42199 Mdot
.96539 .39015 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49812 .00254 Mdot
.49401 .00809 Mdot
.48092 .02574 Mdot
.43926 .08069 Mdot
.3087 .21831 Mdot
.95547 .17757 Mdot
.66816 .0491 Mdot
.58872 .58908 Mdot
.63556 .47807 Mdot
.86203 .36559 Mdot
.50035 .61756 Mdot
.50113 .61651 Mdot
.50359 .61319 Mdot
.51142 .60261 Mdot
.53639 .56917 Mdot
.61545 .47128 Mdot
.8529 .35352 Mdot
.2809 .49829 Mdot
.47465 .52169 Mdot
.63054 .41379 Mdot
.96102 .37801 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01006 Mdot
.47628 .03197 Mdot
.42456 .09932 Mdot
.26386 .2463 Mdot
.86533 .13583 Mdot
.64555 .01893 Mdot
.61491 .53946 Mdot
.74205 .3921 Mdot
.10763 .48444 Mdot
.49973 .00036 Mdot
.49915 .00115 Mdot
.49728 .00368 Mdot
.49133 .01171 Mdot
.47237 .0372 Mdot
.41219 .11453 Mdot
.22687 .26052 Mdot
.80534 .12181 Mdot
.60825 .02901 Mdot
.56131 .59161 Mdot
.60407 .50186 Mdot
.79205 .35943 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00564 Mdot
.48669 .01797 Mdot
.45761 .0568 Mdot
.3657 .16705 Mdot
.09541 .2503 Mdot
.69042 .11297 Mdot
.50764 .10589 Mdot
.33631 .23227 Mdot
.96049 .19602 Mdot
.64333 .08039 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00302 Mdot
.49288 .00961 Mdot
.47733 .03056 Mdot
.42789 .09514 Mdot
.27394 .24102 Mdot
.88396 .14273 Mdot
.65302 .02174 Mdot
.61785 .54023 Mdot
.74373 .3928 Mdot
.10816 .48553 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49213 .01064 Mdot
.47492 .03379 Mdot
.42024 .10468 Mdot
.25087 .25222 Mdot
.84278 .12904 Mdot
.63399 .01899 Mdot
.60326 .54787 Mdot
.71679 .40353 Mdot
.06387 .46116 Mdot
.50121 .61639 Mdot
.50387 .61281 Mdot
.51233 .60139 Mdot
.53927 .56535 Mdot
.6245 .46135 Mdot
.87803 .35902 Mdot
.29712 .50015 Mdot
.48786 .51139 Mdot
.66041 .38661 Mdot
.03487 .41868 Mdot
.35744 .53386 Mdot
.50032 .6176 Mdot
.50102 .61666 Mdot
.50324 .61366 Mdot
.51031 .60411 Mdot
.53285 .57387 Mdot
.60432 .48394 Mdot
.82129 .35095 Mdot
.25345 .49846 Mdot
.44692 .54676 Mdot
.56225 .4905 Mdot
.7686 .34397 Mdot
.49999 1e-05 Mdot
.49997 4e-05 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00132 Mdot
.49688 .00421 Mdot
.49006 .01342 Mdot
.46835 .04257 Mdot
.39947 .12969 Mdot
.18962 .26675 Mdot
.75802 .11939 Mdot
.56484 .06093 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49858 .00192 Mdot
.49548 .0061 Mdot
.48561 .01943 Mdot
.45418 .06132 Mdot
.35496 .17792 Mdot
.06707 .23828 Mdot
.68153 .10418 Mdot
.51296 .09218 Mdot
.3638 .20359 Mdot
.03439 .23522 Mdot
.5004 .61749 Mdot
.50128 .61631 Mdot
.50407 .61254 Mdot
.51295 .60055 Mdot
.54125 .56274 Mdot
.63072 .45473 Mdot
.89495 .36426 Mdot
.30557 .50291 Mdot
.49185 .51046 Mdot
.6659 .38304 Mdot
.04613 .42521 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51485 .59799 Mdot
.54729 .55479 Mdot
.64962 .43563 Mdot
.94476 .38544 Mdot
.3211 .51851 Mdot
.48215 .53502 Mdot
.61646 .43644 Mdot
.91029 .35761 Mdot
.50003 .61799 Mdot
.5001 .6179 Mdot
.50032 .6176 Mdot
.50102 .61665 Mdot
.50325 .61364 Mdot
.51037 .60404 Mdot
.53301 .57365 Mdot
.60483 .48334 Mdot
.82277 .35095 Mdot
.25491 .49843 Mdot
.44844 .54539 Mdot
.50015 .61784 Mdot
.50047 .6174 Mdot
.50149 .61602 Mdot
.50475 .61162 Mdot
.51513 .59761 Mdot
.54818 .55362 Mdot
.65241 .43296 Mdot
.95187 .38901 Mdot
.32243 .52154 Mdot
.47856 .54136 Mdot
.60263 .45267 Mdot
.50078 .61698 Mdot
.50248 .61468 Mdot
.50791 .60735 Mdot
.52521 .58407 Mdot
.58016 .51287 Mdot
.75032 .36532 Mdot
.15922 .48951 Mdot
.36718 .59884 Mdot
.39824 .06885 Mdot
.28684 .21246 Mdot
.94307 .1608 Mdot
.49999 2e-05 Mdot
.49996 6e-05 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49868 .00179 Mdot
.49578 .0057 Mdot
.48655 .01815 Mdot
.45719 .05737 Mdot
.36436 .16843 Mdot
.09184 .24892 Mdot
.68907 .11206 Mdot
.50776 .10487 Mdot
.49978 .0003 Mdot
.49929 .00095 Mdot
.49775 .00304 Mdot
.49283 .00969 Mdot
.47716 .03079 Mdot
.42734 .09584 Mdot
.27227 .24194 Mdot
.8808 .14148 Mdot
.65188 .0211 Mdot
.61774 .53967 Mdot
.74453 .39221 Mdot
.10992 .4862 Mdot
.49998 3e-05 Mdot
.49993 9e-05 Mdot
.49978 .0003 Mdot
.4993 .00095 Mdot
.49777 .00301 Mdot
.4929 .00959 Mdot
.47738 .0305 Mdot
.42803 .09496 Mdot
.27438 .24078 Mdot
.8848 .14306 Mdot
.65332 .02192 Mdot
.61785 .54041 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50583 .61016 Mdot
.51857 .59298 Mdot
.55912 .53943 Mdot
.68631 .40354 Mdot
.03337 .43425 Mdot
.33074 .56321 Mdot
.41945 .0167 Mdot
.39243 .109 Mdot
.21606 .25321 Mdot
.50015 .61783 Mdot
.50049 .61737 Mdot
.50156 .61593 Mdot
.50496 .61133 Mdot
.5158 .59671 Mdot
.55031 .55083 Mdot
.65905 .42673 Mdot
.96858 .39779 Mdot
.32494 .52928 Mdot
.46854 .55826 Mdot
.56527 .49943 Mdot
.49974 .00035 Mdot
.49917 .00112 Mdot
.49736 .00356 Mdot
.4916 .01135 Mdot
.47323 .03606 Mdot
.41489 .11125 Mdot
.23488 .25813 Mdot
.81722 .12355 Mdot
.61731 .02438 Mdot
.57786 .57308 Mdot
.6506 .45338 Mdot
.91701 .37989 Mdot
.49994 8e-05 Mdot
.4998 .00026 Mdot
.49938 .00084 Mdot
.49802 .00268 Mdot
.49368 .00854 Mdot
.47986 .02716 Mdot
.43591 .08498 Mdot
.29842 .22575 Mdot
.93315 .16558 Mdot
.66523 .03847 Mdot
.60299 .56756 Mdot
.68466 .43227 Mdot
.50093 .61677 Mdot
.50298 .61401 Mdot
.50949 .60522 Mdot
.53023 .57736 Mdot
.59605 .49362 Mdot
.79735 .35256 Mdot
.22689 .49855 Mdot
.42022 .56945 Mdot
.49882 .57055 Mdot
.57566 .50302 Mdot
.76176 .35588 Mdot
.49982 .00025 Mdot
.49942 .00079 Mdot
.49815 .0025 Mdot
.49409 .00798 Mdot
.48118 .02538 Mdot
.44011 .0796 Mdot
.31131 .21634 Mdot
.96127 .18079 Mdot
.66875 .05205 Mdot
.58453 .59535 Mdot
.62124 .49352 Mdot
.82271 .3611 Mdot
.50014 .61784 Mdot
.50046 .61741 Mdot
.50146 .61606 Mdot
.50466 .61174 Mdot
.51485 .59798 Mdot
.54729 .55478 Mdot
.64964 .43561 Mdot
.9448 .38546 Mdot
.32111 .51852 Mdot
.48213 .53505 Mdot
.6164 .43651 Mdot
.49975 .00033 Mdot
.49921 .00106 Mdot
.49749 .00339 Mdot
.49201 .01079 Mdot
.47454 .0343 Mdot
.41905 .10615 Mdot
.2473 .25367 Mdot
.83686 .12756 Mdot
.63047 .01971 Mdot
.59858 .55208 Mdot
.7053 .41032 Mdot
.0414 .44826 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61167 Mdot
.51501 .59778 Mdot
.54778 .55415 Mdot
.65114 .43417 Mdot
.94864 .38738 Mdot
.32185 .52014 Mdot
.48024 .53841 Mdot
.60908 .44502 Mdot
.88902 .35027 Mdot
.49981 .00025 Mdot
.4994 .00081 Mdot
.4981 .00257 Mdot
.49395 .00817 Mdot
.48073 .02599 Mdot
.43867 .08145 Mdot
.30689 .21967 Mdot
.95146 .17536 Mdot
.66772 .0471 Mdot
.59151 .5849 Mdot
.64513 .46824 Mdot
.88751 .37242 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49513 .00659 Mdot
.48447 .02096 Mdot
.45056 .06606 Mdot
.34366 .18879 Mdot
.03819 .22386 Mdot
.67598 .09198 Mdot
.52715 .06693 Mdot
.41886 .13894 Mdot
.19405 .27746 Mdot
.50131 .61626 Mdot
.50419 .61238 Mdot
.51334 .60003 Mdot
.54246 .56113 Mdot
.63454 .45074 Mdot
.90523 .36798 Mdot
.30982 .50523 Mdot
.49235 .51231 Mdot
.66341 .38607 Mdot
.03874 .42163 Mdot
.35653 .53734 Mdot
.50057 .61726 Mdot
.50183 .61556 Mdot
.50583 .61015 Mdot
.51859 .59296 Mdot
.55915 .53938 Mdot
.68642 .40345 Mdot
.03362 .43439 Mdot
.33077 .56334 Mdot
.41926 .01698 Mdot
.39179 .10975 Mdot
.21421 .25358 Mdot
.50041 .61748 Mdot
.50131 .61627 Mdot
.50417 .6124 Mdot
.51328 .60011 Mdot
.54229 .56137 Mdot
.63398 .45132 Mdot
.90373 .36741 Mdot
.30924 .50486 Mdot
.49237 .51193 Mdot
.66404 .38539 Mdot
.04048 .42251 Mdot
.50088 .61685 Mdot
.50279 .61427 Mdot
.50889 .60603 Mdot
.52831 .57993 Mdot
.58996 .5009 Mdot
.77949 .35588 Mdot
.20367 .49722 Mdot
.39915 .58457 Mdot
.45329 .00922 Mdot
.43838 .06493 Mdot
.33332 .19272 Mdot
.50043 .61745 Mdot
.50138 .61617 Mdot
.5044 .61209 Mdot
.51401 .59912 Mdot
.54462 .55829 Mdot
.6413 .44384 Mdot
.92315 .37533 Mdot
.31585 .51043 Mdot
.48996 .51973 Mdot
.64902 .4009 Mdot
.00036 .40123 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46279 .04996 Mdot
.38194 .14965 Mdot
.13981 .26322 Mdot
.71391 .11945 Mdot
.52064 .10037 Mdot
.35823 .2151 Mdot
.0102 .22454 Mdot
.64688 .1069 Mdot
.50128 .61631 Mdot
.50407 .61254 Mdot
.51296 .60054 Mdot
.54127 .56271 Mdot
.63079 .45465 Mdot
.89515 .36433 Mdot
.30565 .50295 Mdot
.49187 .51048 Mdot
.6659 .38306 Mdot
.04609 .42519 Mdot
.35811 .53999 Mdot
.49985 .0002 Mdot
.49952 .00065 Mdot
.49847 .00207 Mdot
.49511 .0066 Mdot
.48443 .02102 Mdot
.45042 .06624 Mdot
.34324 .18918 Mdot
.03715 .2233 Mdot
.67583 .09149 Mdot
.5278 .06585 Mdot
.42125 .13591 Mdot
.20135 .27661 Mdot
.49967 .00044 Mdot
.49896 .0014 Mdot
.49669 .00447 Mdot
.48945 .01424 Mdot
.46641 .04515 Mdot
.39336 .13678 Mdot
.17204 .26698 Mdot
.74007 .11972 Mdot
.54636 .07734 Mdot
.42121 .14744 Mdot
.18266 .28197 Mdot
.72642 .13604 Mdot
.49981 .00026 Mdot
.49939 .00082 Mdot
.49807 .00261 Mdot
.49386 .0083 Mdot
.48042 .0264 Mdot
.4377 .08269 Mdot
.3039 .22185 Mdot
.94494 .17182 Mdot
.66693 .04392 Mdot
.59586 .57837 Mdot
.66004 .45377 Mdot
.92582 .38747 Mdot
.5 0 Mdot
.49999 1e-05 Mdot
.49998 3e-05 Mdot
.49992 .00011 Mdot
.49975 .00034 Mdot
.49921 .00107 Mdot
.49747 .00342 Mdot
.49194 .01089 Mdot
.47432 .03459 Mdot
.41836 .107 Mdot
.24523 .25448 Mdot
.83348 .12677 Mdot
.49965 .00047 Mdot
.4989 .00149 Mdot
.49649 .00474 Mdot
.48883 .01508 Mdot
.46442 .04779 Mdot
.38709 .14391 Mdot
.15425 .26554 Mdot
.72459 .11987 Mdot
.53063 .09165 Mdot
.38233 .19107 Mdot
.07317 .25654 Mdot
.65808 .13292 Mdot
.50036 .61755 Mdot
.50113 .6165 Mdot
.50361 .61316 Mdot
.51149 .60251 Mdot
.53661 .56888 Mdot
.61614 .47051 Mdot
.85484 .35384 Mdot
.28232 .49835 Mdot
.47597 .52054 Mdot
.63372 .41066 Mdot
.96926 .38234 Mdot
.50015 .61784 Mdot
.50046 .61741 Mdot
.50148 .61604 Mdot
.50471 .61167 Mdot
.51501 .59777 Mdot
.5478 .55412 Mdot
.65121 .4341 Mdot
.94882 .38747 Mdot
.32188 .52022 Mdot
.48015 .53857 Mdot
.60873 .44543 Mdot
.50116 .61646 Mdot
.50371 .61302 Mdot
.51182 .60208 Mdot
.53764 .56751 Mdot
.61939 .46692 Mdot
.86391 .35557 Mdot
.28858 .49881 Mdot
.48149 .51593 Mdot
.64671 .39838 Mdot
.00212 .40034 Mdot
.35435 .51729 Mdot
.50105 .61661 Mdot
.50335 .6135 Mdot
.51069 .6036 Mdot
.53404 .57229 Mdot
.60806 .47963 Mdot
.83201 .35124 Mdot
.26369 .49824 Mdot
.45752 .53716 Mdot
.58838 .45937 Mdot
.84511 .33739 Mdot
.2992 .47795 Mdot
.49976 .00033 Mdot
.49923 .00105 Mdot
.49753 .00333 Mdot
.49214 .01062 Mdot
.47495 .03374 Mdot
.42036 .10453 Mdot
.25122 .25207 Mdot
.84336 .12919 Mdot
.63432 .01894 Mdot
.60368 .54751 Mdot
.7178 .40297 Mdot
.06577 .46223 Mdot
.50054 .61731 Mdot
.50171 .61573 Mdot
.50544 .61068 Mdot
.51734 .59464 Mdot
.55518 .5445 Mdot
.67416 .41339 Mdot
.00528 .41828 Mdot
.32848 .54825 Mdot
.44139 .60137 Mdot
.46835 .01248 Mdot
.44815 .0597 Mdot
.50042 .61747 Mdot
.50134 .61622 Mdot
.50427 .61226 Mdot
.51361 .59966 Mdot
.54334 .55998 Mdot
.63727 .44793 Mdot
.9125 .37084 Mdot
.31247 .50716 Mdot
.49187 .5147 Mdot
.65907 .39059 Mdot
.02709 .41558 Mdot
.49987 .00018 Mdot
.49958 .00056 Mdot
.49867 .00179 Mdot
.49577 .00571 Mdot
.48652 .01819 Mdot
.45709 .05749 Mdot
.36406 .16874 Mdot
.09103 .24861 Mdot
.68878 .11184 Mdot
.50781 .1046 Mdot
.33856 .22989 Mdot
.96659 .19915 Mdot
.49959 .00056 Mdot
.49869 .00177 Mdot
.49582 .00565 Mdot
.48668 .01799 Mdot
.45757 .05686 Mdot
.36558 .16718 Mdot
.09508 .25017 Mdot
.69029 .11288 Mdot
.50764 .1058 Mdot
.33645 .23211 Mdot
.96089 .19622 Mdot
.64341 .08055 Mdot
.49961 .00053 Mdot
.49875 .00169 Mdot
.49601 .00539 Mdot
.48728 .01718 Mdot
.45949 .05433 Mdot
.37158 .16088 Mdot
.11128 .25583 Mdot
.69733 .1163 Mdot
.50916 .10781 Mdot
.33472 .23494 Mdot
.95458 .1934 Mdot
.64165 .07875 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.49902 .00133 Mdot
.49687 .00423 Mdot
.49002 .01348 Mdot
.4682 .04277 Mdot
.399 .13024 Mdot
.18826 .26682 Mdot
.75653 .1194 Mdot
.56333 .06223 Mdot
.46264 .09655 Mdot
.30642 .23492 Mdot
.4996 .00054 Mdot
.49874 .0017 Mdot
.49598 .00543 Mdot
.48719 .01729 Mdot
.45921 .05469 Mdot
.37071 .1618 Mdot
.10892 .25507 Mdot
.69621 .11588 Mdot
.50872 .1078 Mdot
.33429 .23513 Mdot
.95384 .19294 Mdot
.64166 .07828 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .0056 Mdot
.48679 .01783 Mdot
.45795 .05636 Mdot
.36675 .16596 Mdot
.09823 .25135 Mdot
.69154 .11364 Mdot
.50766 .10655 Mdot
.33527 .23342 Mdot
.95759 .19456 Mdot
.64278 .07925 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00216 Mdot
.4949 .00689 Mdot
.48375 .02194 Mdot
.44825 .06907 Mdot
.3365 .19535 Mdot
.02041 .21422 Mdot
.67379 .08327 Mdot
.53905 .04743 Mdot
.4623 .08206 Mdot
.32953 .21156 Mdot
.50061 .61722 Mdot
.50193 .61543 Mdot
.50615 .60972 Mdot
.5196 .5916 Mdot
.56237 .53524 Mdot
.69633 .39601 Mdot
.05558 .44649 Mdot
.33314 .57436 Mdot
.40381 .04017 Mdot
.33882 .16533 Mdot
.07132 .22925 Mdot
.49975 .00034 Mdot
.49919 .0011 Mdot
.49741 .00349 Mdot
.49176 .01113 Mdot
.47375 .03536 Mdot
.41653 .10924 Mdot
.23978 .25648 Mdot
.82479 .12493 Mdot
.62265 .02215 Mdot
.58681 .56363 Mdot
.67483 .43224 Mdot
.97546 .40958 Mdot
.49987 .00017 Mdot
.49959 .00055 Mdot
.4987 .00176 Mdot
.49585 .00561 Mdot
.48677 .01786 Mdot
.45788 .05644 Mdot
.36655 .16616 Mdot
.0977 .25115 Mdot
.69133 .11352 Mdot
.50765 .10643 Mdot
.33544 .23322 Mdot
.95808 .1948 Mdot
.49979 .00029 Mdot
.49932 .00091 Mdot
.49784 .00291 Mdot
.49313 .00928 Mdot
.47811 .02951 Mdot
.43037 .09202 Mdot
.28148 .23669 Mdot
.8985 .14885 Mdot
.65767 .02544 Mdot
.6165 .54487 Mdot
.73488 .39799 Mdot
.09092 .47777 Mdot
.50065 .61715 Mdot
.50209 .61522 Mdot
.50665 .60906 Mdot
.52117 .58948 Mdot
.56737 .52888 Mdot
.71162 .38561 Mdot
.0877 .46285 Mdot
.33879 .58803 Mdot
.38733 .06594 Mdot
.28065 .21075 Mdot
.93964 .15613 Mdot
.50099 .61669 Mdot
.50317 .61375 Mdot
.5101 .60439 Mdot
.53217 .57477 Mdot
.60217 .48643 Mdot
.81511 .35106 Mdot
.24708 .49858 Mdot
.44036 .55258 Mdot
.54626 .5103 Mdot
.72058 .36527 Mdot
.12956 .47254 Mdot
.49978 .00029 Mdot
.4993 .00094 Mdot
.49778 .00299 Mdot
.49294 .00954 Mdot
.47751 .03031 Mdot
.42846 .09442 Mdot
.27569 .24005 Mdot
.88728 .14407 Mdot
.65417 .02247 Mdot
.6178 .541 Mdot
.74245 .39362 Mdot
.10555 .48446 Mdot
.50125 .61634 Mdot
.50399 .61264 Mdot
.51273 .60085 Mdot
.54053 .56368 Mdot
.62848 .45709 Mdot
.88889 .36225 Mdot
.30275 .50177 Mdot
.49087 .51022 Mdot
.66532 .38307 Mdot
.04549 .42468 Mdot
.35835 .53933 Mdot
.49979 .00028 Mdot
.49934 .0009 Mdot
.49789 .00285 Mdot
.49327 .00909 Mdot
.47856 .0289 Mdot
.43179 .09022 Mdot
.28582 .23404 Mdot
.90713 .15275 Mdot
.65998 .02819 Mdot
.61437 .54909 Mdot
.72593 .40323 Mdot
.07349 .46896 Mdot
.50077 .61699 Mdot
.50245 .61472 Mdot
.50782 .60747 Mdot
.5249 .58448 Mdot
.57919 .51406 Mdot
.74742 .36653 Mdot
.15436 .48823 Mdot
.36438 .59928 Mdot
.39472 .07188 Mdot
.27842 .21708 Mdot
.92717 .1519 Mdot
.50027 .61766 Mdot
.50087 .61685 Mdot
.50279 .61427 Mdot
.50888 .60604 Mdot
.52829 .57995 Mdot
.58991 .50097 Mdot
.77932 .35592 Mdot
.20343 .49719 Mdot
.39896 .5847 Mdot
.45289 .0097 Mdot
.4372 .06642 Mdot
.49993 9e-05 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00298 Mdot
.49298 .00949 Mdot
.47762 .03017 Mdot
.42881 .09398 Mdot
.27675 .23945 Mdot
.88931 .14491 Mdot
.65484 .02296 Mdot
.6177 .54156 Mdot
.74144 .39423 Mdot
.49984 .00021 Mdot
.4995 .00068 Mdot
.4984 .00216 Mdot
.49491 .00688 Mdot
.48377 .0219 Mdot
.44833 .06896 Mdot
.33674 .19513 Mdot
.02101 .21456 Mdot
.67385 .08358 Mdot
.53862 .04813 Mdot
.46075 .08414 Mdot
.32461 .21577 Mdot
.50104 .61663 Mdot
.50332 .61355 Mdot
.51058 .60374 Mdot
.53371 .57272 Mdot
.60702 .48082 Mdot
.82904 .3511 Mdot
.26095 .49829 Mdot
.4547 .53973 Mdot
.5814 .46752 Mdot
.82494 .33603 Mdot
.28124 .48074 Mdot
.49991 .00012 Mdot
.49972 .00037 Mdot
.49912 .00119 Mdot
.4972 .00379 Mdot
.49107 .01207 Mdot
.47154 .03831 Mdot
.40955 .11772 Mdot
.21908 .26249 Mdot
.79436 .12064 Mdot
.59916 .03454 Mdot
.54327 .61295 Mdot
.55149 .56604 Mdot
.50057 .61726 Mdot
.50182 .61557 Mdot
.50581 .61019 Mdot
.5185 .59307 Mdot
.55889 .53972 Mdot
.6856 .40409 Mdot
.03177 .43335 Mdot
.3306 .56237 Mdot
.42066 .01488 Mdot
.39659 .10415 Mdot
.22807 .25029 Mdot
.5004 .61749 Mdot
.50128 .6163 Mdot
.50409 .61251 Mdot
.51302 .60045 Mdot
.54148 .56243 Mdot
.63144 .45397 Mdot
.89691 .36494 Mdot
.30642 .50331 Mdot
.49205 .51067 Mdot
.66576 .38332 Mdot
.04554 .42496 Mdot
.50013 .61785 Mdot
.50043 .61746 Mdot
.50136 .6162 Mdot
.50433 .61218 Mdot
.5138 .5994 Mdot
.54395 .55917 Mdot
.63919 .44597 Mdot
.9176 .37295 Mdot
.31416 .50866 Mdot
.49113 .51688 Mdot
.65479 .39496 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49908 .00124 Mdot
.49707 .00396 Mdot
.49065 .01262 Mdot
.47023 .04007 Mdot
.4054 .12269 Mdot
.20688 .26485 Mdot
.77834 .11964 Mdot
.58475 .04473 Mdot
.51237 .03327 Mdot
.45854 .07128 Mdot
.5005 .61736 Mdot
.50159 .61588 Mdot
.50508 .61118 Mdot
.51617 .59621 Mdot
.55148 .54931 Mdot
.66268 .42342 Mdot
.97756 .40269 Mdot
.32599 .53373 Mdot
.46239 .56827 Mdot
.54291 .52897 Mdot
.68701 .39283 Mdot
.49981 .00026 Mdot
.49939 .00083 Mdot
.49804 .00264 Mdot
.49377 .00842 Mdot
.48015 .02678 Mdot
.43682 .08382 Mdot
.30119 .2238 Mdot
.93907 .16869 Mdot
.66613 .04116 Mdot
.59953 .57282 Mdot
.67269 .44234 Mdot
.95697 .40294 Mdot
.50007 .61794 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50726 .60823 Mdot
.52312 .58688 Mdot
.57353 .52112 Mdot
.73034 .37469 Mdot
.12408 .47842 Mdot
.34998 .59779 Mdot
.38273 .0789 Mdot
.4999 .00013 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49682 .0043 Mdot
.48986 .01369 Mdot
.46772 .04341 Mdot
.39747 .13202 Mdot
.18385 .26701 Mdot
.75182 .11947 Mdot
.55851 .06644 Mdot
.45101 .11115 Mdot
.27117 .25739 Mdot
.4999 .00014 Mdot
.49968 .00044 Mdot
.49897 .00139 Mdot
.49672 .00443 Mdot
.48956 .0141 Mdot
.46675 .04469 Mdot
.39444 .13553 Mdot
.17515 .26706 Mdot
.74304 .11965 Mdot
.54944 .07456 Mdot
.4288 .13838 Mdot
.2049 .28004 Mdot
.50011 .61789 Mdot
.50034 .61758 Mdot
.50107 .61659 Mdot
.50341 .61343 Mdot
.51086 .60338 Mdot
.53457 .57158 Mdot
.60975 .47771 Mdot
.8368 .35157 Mdot
.26795 .49817 Mdot
.46189 .53317 Mdot
.5992 .44705 Mdot
.49986 .00019 Mdot
.49956 .0006 Mdot
.49859 .00191 Mdot
.4955 .00608 Mdot
.48567 .01934 Mdot
.45437 .06106 Mdot
.35557 .17732 Mdot
.06866 .23902 Mdot
.68192 .10477 Mdot
.51241 .09327 Mdot
.36149 .20607 Mdot
.02806 .23195 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49608 .00529 Mdot
.48752 .01685 Mdot
.46024 .05333 Mdot
.37396 .15834 Mdot
.11776 .25782 Mdot
.7006 .11732 Mdot
.51077 .10734 Mdot
.33709 .23334 Mdot
.95954 .19624 Mdot
.64203 .08136 Mdot
.4997 .00041 Mdot
.49903 .00131 Mdot
.49691 .00418 Mdot
.49014 .01332 Mdot
.4686 .04224 Mdot
.40025 .12878 Mdot
.19189 .26659 Mdot
.76053 .11937 Mdot
.56738 .05876 Mdot
.47231 .0843 Mdot
.33592 .21086 Mdot
.99474 .20599 Mdot
.50078 .61699 Mdot
.50247 .61469 Mdot
.50788 .60739 Mdot
.52509 .58423 Mdot
.57979 .51332 Mdot
.74922 .36578 Mdot
.15739 .48904 Mdot
.36611 .59903 Mdot
.39686 .07006 Mdot
.2835 .21435 Mdot
.93668 .15718 Mdot
.49996 5e-05 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49886 .00155 Mdot
.49636 .00492 Mdot
.48839 .01568 Mdot
.46302 .04966 Mdot
.38267 .14883 Mdot
.14186 .26361 Mdot
.71533 .11955 Mdot
.52189 .09932 Mdot
.36118 .2123 Mdot
.50079 .61697 Mdot
.50252 .61463 Mdot
.50803 .60719 Mdot
.52558 .58358 Mdot
.58132 .51143 Mdot
.75381 .36393 Mdot
.16497 .49091 Mdot
.37066 .59804 Mdot
.403 .06447 Mdot
.2987 .20516 Mdot
.96674 .17455 Mdot
.49972 .00038 Mdot
.4991 .00122 Mdot
.49713 .00387 Mdot
.49087 .01234 Mdot
.47091 .03916 Mdot
.40755 .12012 Mdot
.21318 .26374 Mdot
.78644 .12005 Mdot
.59221 .03927 Mdot
.52867 .01284 Mdot
.5079 .00552 Mdot
.49897 .00647 Mdot
.50011 .61788 Mdot
.50036 .61755 Mdot
.50115 .61648 Mdot
.50367 .61307 Mdot
.5117 .60224 Mdot
.53726 .56801 Mdot
.61819 .46824 Mdot
.86057 .35489 Mdot
.28634 .4986 Mdot
.47959 .51748 Mdot
.64229 .40245 Mdot
.50044 .61744 Mdot
.50141 .61613 Mdot
.50449 .61196 Mdot
.51431 .59871 Mdot
.54557 .55704 Mdot
.64427 .44087 Mdot
.93092 .37883 Mdot
.31797 .51312 Mdot
.48773 .52448 Mdot
.6391 .41134 Mdot
.97354 .38692 Mdot
.49975 .00034 Mdot
.49919 .00109 Mdot
.49742 .00348 Mdot
.49179 .01109 Mdot
.47384 .03524 Mdot
.41683 .10888 Mdot
.24066 .25617 Mdot
.82617 .1252 Mdot
.62359 .0218 Mdot
.58832 .5621 Mdot
.67882 .42907 Mdot
.98458 .41479 Mdot
.50064 .61717 Mdot
.50205 .61527 Mdot
.50653 .60922 Mdot
.52079 .59 Mdot
.56614 .53044 Mdot
.70787 .38803 Mdot
.08003 .45913 Mdot
.33713 .58511 Mdot
.3904 .06084 Mdot
.29196 .20329 Mdot
.96304 .16933 Mdot
.49978 .0003 Mdot
.49929 .00096 Mdot
.49774 .00306 Mdot
.49279 .00974 Mdot
.47704 .03095 Mdot
.42697 .0963 Mdot
.27115 .24254 Mdot
.87871 .14067 Mdot
.65109 .02071 Mdot
.61758 .53939 Mdot
.74483 .39192 Mdot
.11069 .48646 Mdot
.50073 .61705 Mdot
.50231 .61491 Mdot
.50736 .60809 Mdot
.52345 .58642 Mdot
.5746 .51977 Mdot
.73359 .37301 Mdot
.13005 .4806 Mdot
.35243 .59863 Mdot
.38383 .07898 Mdot
.25604 .22641 Mdot
.8897 .13215 Mdot
.50079 .61696 Mdot
.50253 .61462 Mdot
.50805 .60717 Mdot
.52563 .58351 Mdot
.58149 .51122 Mdot
.75432 .36373 Mdot
.1658 .4911 Mdot
.37118 .59791 Mdot
.40375 .06376 Mdot
.30058 .20392 Mdot
.97064 .17685 Mdot
.49961 .00053 Mdot
.49875 .0017 Mdot
.496 .0054 Mdot
.48726 .0172 Mdot
.45944 .05439 Mdot
.37144 .16103 Mdot
.11089 .25571 Mdot
.69714 .11623 Mdot
.50908 .10782 Mdot
.33463 .23499 Mdot
.95442 .1933 Mdot
.64165 .07865 Mdot
.50021 .61775 Mdot
.50068 .61712 Mdot
.50216 .61512 Mdot
.50688 .60874 Mdot
.52191 .5885 Mdot
.5697 .52592 Mdot
.71874 .38121 Mdot
.10192 .46938 Mdot
.34246 .59272 Mdot
.38342 .07335 Mdot
.26474 .22026 Mdot
.49977 .00031 Mdot
.49927 .00099 Mdot
.49766 .00316 Mdot
.49255 .01006 Mdot
.47626 .03199 Mdot
.42451 .09938 Mdot
.26371 .24638 Mdot
.86506 .13574 Mdot
.64543 .01891 Mdot
.61483 .53949 Mdot
.74191 .39214 Mdot
.10742 .48433 Mdot
.49992 .0001 Mdot
.49976 .00033 Mdot
.49922 .00105 Mdot
.49753 .00334 Mdot
.49212 .01065 Mdot
.47489 .03383 Mdot
.42014 .1048 Mdot
.25057 .25234 Mdot
.84227 .12891 Mdot
.6337 .01904 Mdot
.60289 .54819 Mdot
.7159 .40402 Mdot
.49987 .00018 Mdot
.49957 .00058 Mdot
.49863 .00185 Mdot
.49564 .00589 Mdot
.48611 .01875 Mdot
.45578 .05921 Mdot
.35998 .17291 Mdot
.08021 .24416 Mdot
.68515 .10869 Mdot
.50929 .10009 Mdot
.34735 .22088 Mdot
.98995 .21157 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00215 Mdot
.49494 .00684 Mdot
.48387 .02177 Mdot
.44865 .06855 Mdot
.33772 .19425 Mdot
.02343 .21589 Mdot
.67411 .0848 Mdot
.53691 .05088 Mdot
.45458 .09243 Mdot
.30503 .23124 Mdot
.50052 .61733 Mdot
.50166 .61579 Mdot
.50529 .61089 Mdot
.51685 .5953 Mdot
.55363 .54652 Mdot
.66935 .41752 Mdot
.99379 .41176 Mdot
.32755 .54213 Mdot
.45035 .58742 Mdot
.49989 .58751 Mdot
.54928 .54256 Mdot
.49961 .00053 Mdot
.49874 .0017 Mdot
.496 .00541 Mdot
.48725 .01721 Mdot
.45941 .05443 Mdot
.37133 .16114 Mdot
.11061 .25562 Mdot
.69701 .11618 Mdot
.50902 .10782 Mdot
.33457 .23502 Mdot
.95431 .19324 Mdot
.64164 .07859 Mdot
.50122 .61639 Mdot
.50388 .61279 Mdot
.51237 .60133 Mdot
.5394 .56518 Mdot
.62492 .4609 Mdot
.87916 .35934 Mdot
.29774 .50029 Mdot
.48825 .51117 Mdot
.66116 .38602 Mdot
.03656 .41962 Mdot
.3576 .53471 Mdot
.50072 .61706 Mdot
.5023 .61493 Mdot
.50732 .60814 Mdot
.52332 .5866 Mdot
.57419 .52029 Mdot
.73234 .37365 Mdot
.12776 .47977 Mdot
.35147 .59834 Mdot
.38334 .07902 Mdot
.25548 .22648 Mdot
.88902 .13174 Mdot
.49989 .00015 Mdot
.49964 .00049 Mdot
.49885 .00156 Mdot
.49633 .00496 Mdot
.48831 .01578 Mdot
.46278 .04997 Mdot
.38192 .14967 Mdot
.13974 .26321 Mdot
.71387 .11945 Mdot
.5206 .1004 Mdot
.35814 .21518 Mdot
.00998 .22442 Mdot
.5013 .61628 Mdot
.50414 .61244 Mdot
.51319 .60023 Mdot
.542 .56174 Mdot
.6331 .45224 Mdot
.90136 .36654 Mdot
.30829 .50429 Mdot
.49233 .5114 Mdot
.66486 .38447 Mdot
.04276 .42364 Mdot
.35729 .53891 Mdot
.50086 .61687 Mdot
.50275 .61431 Mdot
.50878 .60618 Mdot
.52796 .58039 Mdot
.58886 .50223 Mdot
.77624 .35668 Mdot
.19911 .49675 Mdot
.39535 .58692 Mdot
.44569 .01827 Mdot
.41613 .09247 Mdot
.26652 .23922 Mdot
.50127 .61632 Mdot
.50405 .61256 Mdot
.5129 .60062 Mdot
.54107 .56296 Mdot
.63018 .4553 Mdot
.89349 .36377 Mdot
.30491 .50262 Mdot
.49166 .51035 Mdot
.6659 .38292 Mdot
.04632 .42526 Mdot
.35823 .53998 Mdot
.50108 .61658 Mdot
.50343 .6134 Mdot
.51093 .60328 Mdot
.53481 .57126 Mdot
.61049 .47686 Mdot
.83891 .35175 Mdot
.26977 .49816 Mdot
.46373 .53149 Mdot
.60377 .44196 Mdot
.88865 .34696 Mdot
.32727 .47745 Mdot
.49974 .00035 Mdot
.49918 .0011 Mdot
.4974 .00352 Mdot
.49171 .0112 Mdot
.47359 .03557 Mdot
.41603 .10986 Mdot
.23827 .257 Mdot
.82244 .12448 Mdot
.62103 .02278 Mdot
.58416 .56638 Mdot
.66774 .43811 Mdot
.95887 .4004 Mdot
.50044 .61744 Mdot
.5014 .61614 Mdot
.50446 .61201 Mdot
.5142 .59887 Mdot
.54521 .55751 Mdot
.64314 .442 Mdot
.92798 .37748 Mdot
.3172 .51207 Mdot
.48866 .52258 Mdot
.64311 .40707 Mdot
.98445 .39268 Mdot
.49995 7e-05 Mdot
.49983 .00023 Mdot
.49946 .00072 Mdot
.49829 .00231 Mdot
.49456 .00735 Mdot
.48266 .02339 Mdot
.44482 .07353 Mdot
.32584 .20464 Mdot
.99472 .19975 Mdot
.67152 .06978 Mdot
.55861 .01666 Mdot
.53165 .60555 Mdot
.49978 .00029 Mdot
.49931 .00093 Mdot
.4978 .00298 Mdot
.49298 .00948 Mdot
.47765 .03013 Mdot
.42889 .09389 Mdot
.27698 .23932 Mdot
.88976 .14509 Mdot
.65499 .02307 Mdot
.61767 .54169 Mdot
.7412 .39437 Mdot
.10309 .4834 Mdot
.50132 .61625 Mdot
.5042 .61236 Mdot
.51337 .59998 Mdot
.54259 .56097 Mdot
.63492 .45034 Mdot
.90626 .36838 Mdot
.31022 .50549 Mdot
.49232 .5126 Mdot
.66292 .38659 Mdot
.03741 .42095 Mdot
.35629 .53679 Mdot
.50112 .61652 Mdot
.50357 .61321 Mdot
.51139 .60266 Mdot
.53626 .56933 Mdot
.61506 .47172 Mdot
.8518 .35334 Mdot
.28008 .49826 Mdot
.47388 .52236 Mdot
.62868 .41565 Mdot
.95614 .3755 Mdot
.34856 .49565 Mdot
.49975 .00033 Mdot
.49922 .00106 Mdot
.4975 .00337 Mdot
.49205 .01074 Mdot
.47466 .03414 Mdot
.41943 .10568 Mdot
.24843 .25322 Mdot
.83871 .12801 Mdot
.63159 .01945 Mdot
.60012 .55067 Mdot
.70913 .40796 Mdot
.04904 .4527 Mdot
.49997 4e-05 Mdot
.49991 .00012 Mdot
.49971 .00039 Mdot
.49907 .00125 Mdot
.49705 .00398 Mdot
.4906 .01269 Mdot
.47007 .04027 Mdot
.40491 .12328 Mdot
.20544 .26508 Mdot
.77654 .11958 Mdot
.58306 .04603 Mdot
.50858 .03807 Mdot
.49975 .00034 Mdot
.4992 .00108 Mdot
.49745 .00345 Mdot
.49187 .01097 Mdot
.47412 .03486 Mdot
.41771 .1078 Mdot
.24328 .25521 Mdot
.83034 .12607 Mdot
.62635 .02086 Mdot
.59261 .5578 Mdot
.69006 .4206 Mdot
.00952 .42942 Mdot
.50105 .61661 Mdot
.50335 .61351 Mdot
.51067 .60363 Mdot
.53398 .57237 Mdot
.60787 .47985 Mdot
.83146 .35121 Mdot
.26319 .49825 Mdot
.45701 .53762 Mdot
.58711 .46084 Mdot
.84146 .33699 Mdot
.2962 .47837 Mdot
.50033 .61759 Mdot
.50105 .61662 Mdot
.50334 .61352 Mdot
.51064 .60366 Mdot
.5339 .57247 Mdot
.60763 .48013 Mdot
.83076 .35118 Mdot
.26255 .49826 Mdot
.45634 .53823 Mdot
.58547 .46274 Mdot
.83674 .33657 Mdot
.49979 .00029 Mdot
.49932 .00092 Mdot
.49783 .00294 Mdot
.49307 .00936 Mdot
.47793 .02976 Mdot
.42978 .09276 Mdot
.2797 .23774 Mdot
.89502 .14733 Mdot
.65664 .02445 Mdot
.61709 .54346 Mdot
.73774 .39636 Mdot
.09642 .48038 Mdot
.50077 .617 Mdot
.50245 .61473 Mdot
.5078 .60749 Mdot
.52486 .58454 Mdot
.57905 .51424 Mdot
.74699 .36672 Mdot
.15362 .48803 Mdot
.36397 .59933 Mdot
.39423 .07229 Mdot
.27726 .21768 Mdot
.92506 .15074 Mdot
.50015 .61782 Mdot
.50049 .61737 Mdot
.50157 .61591 Mdot
.50501 .61126 Mdot
.51597 .59649 Mdot
.55083 .55016 Mdot
.66066 .42526 Mdot
.97257 .39996 Mdot
.32543 .53124 Mdot
.46586 .56265 Mdot
.55548 .51225 Mdot
.49984 .00021 Mdot
.4995 .00067 Mdot
.49841 .00214 Mdot
.49495 .00682 Mdot
.48391 .02171 Mdot
.44878 .06838 Mdot
.33813 .19388 Mdot
.02443 .21644 Mdot
.67423 .0853 Mdot
.5362 .05203 Mdot
.45202 .09584 Mdot
.29695 .23701 Mdot
.50012 .61787 Mdot
.50039 .61751 Mdot
.50124 .61636 Mdot
.50394 .61271 Mdot
.51256 .60107 Mdot
.54 .56438 Mdot
.62682 .45887 Mdot
.88435 .36085 Mdot
.30049 .50103 Mdot
.48982 .51046 Mdot
.66388 .384 Mdot
.5007 .61709 Mdot
.50223 .61502 Mdot
.5071 .60845 Mdot
.52261 .58756 Mdot
.57191 .52314 Mdot
.72545 .37735 Mdot
.11488 .47484 Mdot
.34657 .59605 Mdot
.38215 .07755 Mdot
.25666 .22497 Mdot
.89265 .13283 Mdot
.50026 .61768 Mdot
.50083 .61691 Mdot
.50266 .61445 Mdot
.50846 .60661 Mdot
.52695 .58174 Mdot
.58567 .5061 Mdot
.76678 .35938 Mdot
.1853 .4949 Mdot
.38454 .59279 Mdot
.42539 .04142 Mdot
.35837 .15606 Mdot
.50011 .61789 Mdot
.50034 .61758 Mdot
.50108 .61657 Mdot
.50345 .61337 Mdot
.51099 .6032 Mdot
.53499 .57102 Mdot
.61107 .47621 Mdot
.84055 .3519 Mdot
.27115 .49815 Mdot
.46513 .53021 Mdot
.60723 .43815 Mdot
.49974 .00036 Mdot
.49916 .00114 Mdot
.49732 .00362 Mdot
.49145 .01155 Mdot
.47277 .03667 Mdot
.41344 .11301 Mdot
.23059 .25946 Mdot
.81077 .12254 Mdot
.6125 .02672 Mdot
.56926 .58255 Mdot
.62667 .47713 Mdot
.85465 .36035 Mdot
.50072 .61705 Mdot
.50231 .61491 Mdot
.50736 .60809 Mdot
.52344 .58644 Mdot
.57456 .51982 Mdot
.73348 .37306 Mdot
.12985 .48053 Mdot
.35234 .5986 Mdot
.38378 .07898 Mdot
.25598 .22642 Mdot
.88962 .13211 Mdot
.50072 .61706 Mdot
.5023 .61492 Mdot
.50733 .60813 Mdot
.52336 .58655 Mdot
.57429 .52015 Mdot
.73267 .37348 Mdot
.12836 .47999 Mdot
.35172 .59842 Mdot
.38346 .07902 Mdot
.2556 .22647 Mdot
.88916 .13183 Mdot
.50016 .61782 Mdot
.50051 .61734 Mdot
.50164 .61582 Mdot
.50522 .61098 Mdot
.51663 .5956 Mdot
.55292 .54744 Mdot
.66716 .41943 Mdot
.9885 .40878 Mdot
.32708 .53936 Mdot
.45438 .58107 Mdot
.51419 .56793 Mdot
.49981 .00025 Mdot
.49941 .0008 Mdot
.49811 .00255 Mdot
.49398 .00814 Mdot
.48081 .02589 Mdot
.43893 .08112 Mdot
.30766 .21909 Mdot
.95317 .1763 Mdot
.66791 .04795 Mdot
.59033 .58667 Mdot
.64108 .47234 Mdot
.87682 .36921 Mdot
.50022 .61774 Mdot
.50069 .6171 Mdot
.5022 .61507 Mdot
.507 .60858 Mdot
.5223 .58798 Mdot
.57093 .52438 Mdot
.72247 .37903 Mdot
.10919 .4725 Mdot
.34467 .5947 Mdot
.38242 .07602 Mdot
.25941 .22331 Mdot
.49967 .00044 Mdot
.49896 .00141 Mdot
.49668 .00449 Mdot
.48942 .01429 Mdot
.46631 .04529 Mdot
.39303 .13715 Mdot
.17111 .26694 Mdot
.73919 .11974 Mdot
.54545 .07817 Mdot
.41896 .15009 Mdot
.17611 .28202 Mdot
.71979 .13712 Mdot
.49969 .00042 Mdot
.499 .00135 Mdot
.49683 .00429 Mdot
.48989 .01365 Mdot
.4678 .04329 Mdot
.39775 .1317 Mdot
.18466 .26698 Mdot
.75268 .11946 Mdot
.55939 .06567 Mdot
.45314 .10849 Mdot
.2776 .25382 Mdot
.8669 .14432 Mdot
.49961 .00052 Mdot
.49877 .00166 Mdot
.49609 .00528 Mdot
.48754 .01682 Mdot
.46032 .05323 Mdot
.37419 .15809 Mdot
.1184 .258 Mdot
.70094 .11741 Mdot
.51096 .10725 Mdot
.33742 .2331 Mdot
.96027 .19664 Mdot
.64209 .08173 Mdot
.50022 .61773 Mdot
.50071 .61707 Mdot
.50228 .61496 Mdot
.50725 .60824 Mdot
.5231 .5869 Mdot
.57348 .52117 Mdot
.73021 .37476 Mdot
.12383 .47833 Mdot
.34989 .59775 Mdot
.3827 .07888 Mdot
.25507 .22635 Mdot
.49974 .00036 Mdot
.49916 .00113 Mdot
.49733 .00361 Mdot
.49149 .01149 Mdot
.47289 .03651 Mdot
.41382 .11255 Mdot
.23171 .25912 Mdot
.81245 .12279 Mdot
.61377 .02607 Mdot
.57158 .57996 Mdot
.63318 .47041 Mdot
.87204 .36416 Mdot
.50111 .61653 Mdot
.50355 .61324 Mdot
.5113 .60278 Mdot
.53599 .56969 Mdot
.6142 .47268 Mdot
.8494 .35298 Mdot
.27826 .49821 Mdot
.47214 .5239 Mdot
.62445 .41993 Mdot
.94499 .36994 Mdot
.34641 .49124 Mdot
.50019 .61778 Mdot
.5006 .61722 Mdot
.50192 .61544 Mdot
.50611 .60978 Mdot
.51948 .59176 Mdot
.56198 .53575 Mdot
.69512 .39689 Mdot
.05295 .44507 Mdot
.33281 .57309 Mdot
.40552 .03759 Mdot
.3447 .15977 Mdot
.49991 .00013 Mdot
.4997 .00041 Mdot
.49904 .00129 Mdot
.49695 .00412 Mdot
.49027 .01314 Mdot
.46902 .04167 Mdot
.40159 .1272 Mdot
.19577 .26627 Mdot
.76494 .11937 Mdot
.5718 .05505 Mdot
.48273 .07103 Mdot
.3678 .17997 Mdot
.49982 .00024 Mdot
.49944 .00076 Mdot
.4982 .00243 Mdot
.49427 .00773 Mdot
.48176 .02461 Mdot
.44195 .07724 Mdot
.31697 .21191 Mdot
.97409 .188 Mdot
.6699 .05875 Mdot
.57484 .60993 Mdot
.58795 .53248 Mdot
.72639 .38656 Mdot
.49983 .00023 Mdot
.49946 .00073 Mdot
.49828 .00233 Mdot
.49451 .00742 Mdot
.4825 .02362 Mdot
.44428 .07422 Mdot
.32419 .20602 Mdot
.99084 .19753 Mdot
.67122 .0677 Mdot
.56168 .01193 Mdot
.54237 .59115 Mdot
.58587 .51535 Mdot
.49986 .00019 Mdot
.49955 .00061 Mdot
.49855 .00195 Mdot
.49539 .00622 Mdot
.48532 .01981 Mdot
.45327 .06251 Mdot
.35212 .18071 Mdot
.05972 .23479 Mdot
.67983 .10135 Mdot
.51583 .0867 Mdot
.37556 .19066 Mdot
.06706 .25101 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00W?ooool3o`00087ooooo002K
ooooo`05o`000?ooooooooooooooool00000P?ooool009_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1mooooo`00Voooool6o`0007oooooo002Looooo`05o`000?oooooooooooooo
ool00000Ooooool009gooooo0ol00020ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQ
ooooo`00Coooool2o`0000Cooooo00Co0000oooooooooooooooo1Ol0000Qooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`?o00008Oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3
o`0002;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0ol0000Wooooo`?o00002Oooool0
04kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000Pooooo`04o`000?oo
ooooooooo`0000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000008?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000009oooool00ol0003oooooooooo`08ooooo`00C_ooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo023ooooo00Co0000oooooooooooo00001oooool5o`00023ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000023ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000002Oooooo00?o0000ooooooooool02?oo
ool004kooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Oooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00008Oooool01?l0003oooooooooool00007oooo
o`Co00008Oooool01?l0003oooooooooool00008ooooo`?o0000:?ooool00ol0003oooooooooo`08
ooooo`00C_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000008?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000027ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00000Wooooo`03o`000?oooooooooo00Sooooo001>ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`00000Pooooo`04o`000?ooooooooooo`0000Wooooo
0_l0000Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000009_ooool2o`0000[ooooo001?oooo
o`;o00002Oooool3o`0002;ooooo0_l0000;ooooo`03o`000?oooooooooo023ooooo0_l0000:oooo
o`;o00008_ooool2o`0000Wooooo0ol0000Xooooo`03o`000?oooooooooo00Sooooo003oooooob7o
oooo003oooooob7ooooo003oooooob7ooooo002=ooooo`03ool00?l0003ooooo00Gooooo00D00000
ooooooooooooooooool00004ooooo`;oo`0000Goooooool00?ooooooooooo`000002ooooo`03ool0
0?l0003ooooo00Gooooo00?oo`00ooooooooool0K_ooool002KoooooIol000000ooo003o0000o`00
0004o`000006ool00?l0003o0000o`000?oo003o00000_oo00001?l0003oo`00ool00?l00002ool0
0003o`000?oo003o000000;o000000?oo`00o`000?l000001?l00002ool006Co00000`000009oooo
o`009_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool00oooool01?oo003oooooooooooooool3o`0000;oo`000_ooool01Ooo003o0000o`000?oo003o
oooo00Goo`0000?o0000ool00?oo00000_l000000ooo003o0000ooooo`02ooooo`;o00000_oo0003
ooooo`?o000000?oooooo`000?ooool0;_ooool00ol0003oooooooooo`0]ooooo`0300000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo06;ooooo0_oo0005ooooo`;oo`000_l00002ool0
0003oooooooo003oo`0000Goo`0000?o0000ool00?oo00000_l00002ool000;ooooo0ol000001?oo
ooooo`00o`000?l00004ooooo`?o0000Goooool00`00003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`1Rooooo`03ool00?oooooooooo00?ooooo0_oo0002ooooo`04o`000?oo003o0000
ooooo`Woo`000_l00002ool000Co000000Coooooo`000?oo003oo`000_ooool3o`0000?ooooo0ol0
001Mooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05Wooooo2?l00002
ool000Cooooo0_oo0003ooooo`03ool00?ooooooo`0000Koo`0000Goooooo`000?oo003o0000oooo
o`02ool00003o`000?oooooo000000?o00000_oo00001Ooooooo0000o`000?l0003ooooo00?o0000
1?ooool3o`0000Soo`00D_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`1Iooooo`03o`000?oooooooooo00Cooooo0_oo0002o`0000;ooooo0_oo0003ooooo`;oo`0000?o
ooooool00?ooool01?oo0002ooooo`;oo`0000?oooooo`000?oo00001?l000001?oooooo0000o`00
0?oo0003o`00000400000?l0003o0000o`0000;ooooo0_l00002ooooo`Coo`0000?o0000oooooooo
ool00oooool2ool0057ooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
FOooool2o`0000Gooooo00Coo`00oooooooooooooooo0_l000001?oo003o0000ooooooooool2ool0
0003oooooooo003ooooo00;oo`000_ooool01?oo003o0000ool00?oo0002ooooo`03ool00?oooooo
000000Go00000_oo0009o`0000;ooooo00?o0000ool00?oo00000oooool3o`0000Cooooo0_oo001@
ooooo`0300000?oooooooooo00Oooooo000Vooooo`;o0000Foooool2o`0000?ooooo00?oo`00oooo
ooooool00oooool00ooo003oooooo`000002o`000003ool00?ooooooo`0000Koo`0000?oooooool0
0?oo00000_l00002ool000Cooooo0_l00002ool00003o`000?oooooo000000Go00000_ooool01Ol0
003oo`00ool00?oo003ooooo00;o00000oooool3o`0000?ooooo00?oo`00ooooooooool0COooool0
0ol000000000ooooo`08ooooo`009_ooool00ol0003oooooooooo`1Kooooo`;o000000?oooooool0
0?oo00001?ooool00ooo003oooooooooo`02ooooo`05ool00?oooooo0000ool00?l000000ooo0003
ooooo`03ool00?oooooooooo00;oo`0000?o0000ooooooooool01?ooool00ooo003o0000o`000004
o`0000;ooooo0ol00002ool000;o00000oooool3o`0000?ooooo0ol00002ool004oooooo00<00000
ooooooooool01oooool002Kooooo00?o0000ooooooooool0G?ooool2o`000003ool00?oooooooooo
00;ooooo0_oo0003ooooo`Coo`0000?oooooool00?oo00000ooo00001?ooooooo`00ool00?ooool2
ool00004ooooool0003o0000o`0000?ooooo0_oo0002ooooo`0300000?l0003ooooo00;o000000Co
ooooo`000?oo003oo`000_l000001?oooooo0000ooooool00004ooooo`?o00000_ooool2o`000003
ool00?oooooooooo04gooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0
GOooool2ool00003o`000?oooooooooo00;oo`000oooool2ool00004oooooooo003oo`00ooooo`;o
o`0000Goooooool00?l0003o0000ool00002ooooo`03ool00?oooooooooo00?ooooo0ol000000ooo
003oooooooooo`02ooooo`?o000000Koooooo`000?oo003oo`00o`000?ooool5o`000004ooooool0
003o0000o`0000?ooooo0_l00002ooooo`03ool00?l0003o000004gooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0G?ooool2ool00003ooooool0003o000000;oo`001?oo
ool01Ooo003oooooool00?oo003ooooo00Coo`000_ooool01Ooo003oooooo`000?oo003o000000Oo
oooo0_oo00000ol0003oooooooooo`04ooooo`03o`000?oo003oo`0000_o000000?oooooo`000?l0
00000oooool2o`0000;oo`001?l0001:ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo05cooooo00Coo`00oooooooooooooooo0_oo00001_l0003oooooooooooooooooo`00
ooooo`Soo`0000Coooooool00?oooooooooo0_oo0004o`0000?ooooo0_oo00001?oooooo0000o`00
0?l00003ooooo`;oo`000_ooool2o`000003ooooool0003o000000;o000000Goooooo`000?l0003o
0000ooooo`05o`0000;ooooo00?o0000ool00?l000000_ooool3o`0004Sooooo00<00000oooooooo
ool01oooool002Kooooo00?o0000ooooooooool0Foooool2ool000;ooooo0_oo00001Ooooooo0000
o`000?ooooooo`0000;ooooo1ooo00001?ooooooo`00ool00?ooool2ool000Cooooo1?l000000ooo
003oooooooooo`02ooooo`?o00000_oo0005ooooo`;o000000<00000o`000?ooool01ol00002oooo
o`;o00000_ooool00ooo003oooooo`000002o`000004ooooool0003o0000o`0004Kooooo00<00000
ooooooooool01oooool002Kooooo0_l0001Kooooo`;oo`000_ooool2ool000?ooooo00Co0000ool0
0?oo003ooooo1ooo00001?ooooooo`00ool00?ooool2ool000Sooooo0_oo0002o`0000Cooooo0_oo
0002o`0000Kooooo0ol000000ooooooo0000o`000008o`000004ooooool0003oo`00o`0000;ooooo
1ol00013ooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`000?oooooooooo05[ooooo00?o
o`00ooooooooool00_oo0004ooooo`;oo`0000Co0000ool00?oooooooooo0_oo00001Oooooooo`00
ooooooooooooo`0000;ooooo00?oo`00ooooooooool01_ooool2ool000;ooooo0ol000000ooooooo
o`00ool00002ooooo`?o00002_ooool4o`000003ooooool0003o000000;o000000Coooooool00?l0
003o00001?ooool3o`000004ooooool0003o0000o`00047ooooo00<00000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool0FOooool2ool00003oooooooo003oo`0000Gooooo00?oo`00oooo
oooo00001ooo00001Oooooooo`00ooooooooooooo`0000Wooooo00?oo`00ooooooooool01?ooool2
ool00003o`000?oooooooooo00;ooooo0ol00007ooooo`?o000000?oooooo`000?l000001Ol00000
0ooo003o0000ooooo`03o`0000?ooooo1ol0000oooooo`0300000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo05Wooooo00Coo`00oooooooo003oo`001Oooool2ool00003oooooooo003o
o`0000Goo`0000Coooooool00?oooooooooo0_oo0008ooooo`;oo`001Oooool2ool00003ooooool0
003o000000;o00000oooool3o`0000Oooooo00Co0000ooooool0003ooooo1Ol000001?oo003o0000
o`000?ooool3o`0000Gooooo1_l0000mooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo05Wooooo0_oo0006ooooo`Coo`0000Ooooooool00?oo003oo`00o`000?oo003o0000
00;oo`0000?oooooool00?oo00002Oooool00ooo003oooooooooo`02ooooo`?oo`001Oooool4o`00
00;ooooo1?l00006ooooo`04ool00?l0003o0000ooooo`;o000000?oooooo`000?oo00001Ol00000
0ooooooo0000o`000005ooooo`Co0000??ooool00`00003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`1Pooooo`;oo`0000?oooooool00?oo00000ooo00001_ooooooo`00ooooool0003o
o`00ooooo`;oo`002Oooool2ool000?ooooo0_oo000:ooooo`?o00000oooool3o`0000Cooooo0_oo
0002ooooo`Co000000?oo`00o`000?ooool01?l000000ooooooo0000o`000002o`00000300000?oo
oooooooo03oooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0H?ooool0
1?oo003oooooool00?ooool5ool000;ooooo0_oo00000ol0003oo`00ooooo`09ooooo`04ool00?oo
ooooooooooooo`;oo`003_ooool3o`0000;ooooo0ol00002ooooo`03ool00?oooooooooo00?ooooo
0_l000000ooo003o0000o`000002ooooo`Co000000?oooooo`000?ooool00ol0000oooooo`030000
0?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo05oooooo00Goo`00oooooooo003oo`00
ooooo`02ool00004oooooooo003oo`00ooooo`;oo`0000Coooooool00?oo003o00002?ooool2ool0
00;ooooo0_oo000Booooo`?o000000Koooooo`000?l0003o0000oooooooo0006ooooo`04ool00?l0
003o0000ooooo`;o000000?oooooo`000?l000001?l000001?oooooo0000o`000?l0000mooooo`03
00000?oooooooooo00Oooooo000Vooooo`;o0000Goooool00ooo003oooooool00004ool00003oooo
oooo003oo`0000;ooooo00Goo`00oooooooo003oo`00ooooo`02o`0000Oooooo00?oo`00oooooooo
ool00_oo000Eooooo`Ko000000?oo`00ooooooooool01?ooool2ool000Ko000000?oooooo`000?oo
ool02Ol0000iooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`000?oooooooooo05gooooo
1Ooo00000oooooooo`00ooooo`02ool000;ooooo00Coo`00oooooooo003oo`000oooool2o`0000Go
oooo0_oo00000oooooooo`00ool0000Iooooo`?o000000?oo`00o`000?l000001Oooool01?oo003o
ooooooooooooool5o`0000;ooooo2_l0000hooooo`0300000?oooooooooo00Oooooo000Vooooo`03
o`000?oooooooooo05cooooo1?oo00000oooooooo`00ool00003ool000;ooooo1?oo0005ooooo`;o
00001?ooool01?oo003oooooool00?oo000Mooooo`03ool00?l0003o000000;o00000oooool2ool0
00Cooooo00?o0000ooooooooool00ol000000ooooooo0000ooooo`04o`000004ooooool0003o0000
o`0003Kooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Foooool2ool0
0003oooooooo003oo`0000?oo`0000Coooooool00?oo003ooooo0_oo00000oooooooo`00ooooo`06
ooooo`;o00000oooool3ool001kooooo00?oo`00ooooool000000ol00003ooooo`;oo`001oooool5
o`000003ooooool0003o000000?o00000oooool2o`0003?ooooo00<00000ooooooooool01oooool0
02Kooooo00?o0000ooooooooool0F_ooool2ool00004oooooooo003oooooooooo`;oo`0000?ooooo
ool00?oo00000_ooool01?oo003oooooool00?oo0008ooooo`03o`000?oooooooooo02;ooooo0_oo
0008ooooo`;oo`001oooool2o`000004ooooool0003o0000ooooo`[o000000<00000o`000?ooool0
;oooool00`00003oooooooooo`07ooooo`004oooool2o`0000Cooooo00Co0000oooooooooooooooo
1Ol00004ooooo`03o`000?oooooooooo05[ooooo00?oo`00oooooooo00001ooo0002ooooo`04ool0
0?ooooooo`00ool000Sooooo0_l0000Uooooo`03ool00?oooooooooo00Oooooo1?oo0006ooooo`Ko
00000oooool3o`000003ooooool0003ooooo00?o0000;_ooool00`00003oooooooooo`07ooooo`00
4_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0FOooool00ooo003oooooool00004ool000;o000000Goo`00o`000?l0003oo`00o`000002
ool000[o00009_ooool00ooo003oooooooooo`0:oooooaWoo`000ol0000[ooooo`0300000?oooooo
oooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool01?ooool2
o`0005Sooooo00?o0000ool00?l000000_oo0002ooooo`;oo`0000Coooooool00?oooooooooo1?oo
000aooooo`;oo`006?ooool5o`000003ooooool0003o000000?o00001ooo000Vooooo`<000002Ooo
ool001;ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo05Cooooo0ol00003ool000?ooooo1Ooo00001Oooooooo`00ool00?ooooooo`0003?ooooo
00?oo`00ooooooooool06?ooool5o`000003ooooool0003ooooo00Co00000oooool5ool002Cooooo
00<00000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool0B_ooool2o`0000Oooooo0_l000001_oooooo
o`00ool00?ooooooo`00ooooo`?oo`0000?oooooool00?oo00000_ooool01?oo003oooooool00?oo
000cooooo`;oo`004_ooool3ool00003oooooooo003oo`0000coo`0000Ko0000ool00?oo003oo`00
o`000?ooool2o`0000Goo`001Oooool3ool001Sooooo00<00000ooooooooool01oooool001;ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0B_ooool2o`0000Gooooo0ol00002ooooo`03ool00?ooooooo`0000Coo`0000?oooooool0
0?ooool00_ooool01?oo003oooooool00?oo000eooooo`?oo`002_ooool7ool000_ooooo1_l00002
ooooo`?o00000ooo00001?oooooo0000ooooool00004ool000Cooooo0ooo000Fooooo`0300000?oo
oooooooo00Oooooo000Cooooo`;o00002Oooool3o`0000Gooooo00?o0000ooooooooool0BOooool2
o`0000Gooooo0_l00002ooooo`Coo`000_ooool5ool000;ooooo1?oo000hooooo`coo`004oooool<
o`0000;ooooo0_oo0002o`000004oooooooo003oo`00ool000Cooooo0ooo000Dooooo`0300000?oo
oooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Wooooo0_l00005ooooo`05o`000?oooooo
ooooool00?ooool00_oo00000oooooooo`00ool00004ool000;ooooo1?oo001Kooooo`Go00000_oo
ool7o`0000;oo`000_l00004ool000?ooooo0ooo000Booooo`0300000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo04Sooooo0ol00004ooooo`;o000000Koooooool00?oo003oooooool0
0?ooool3ool000;ooooo0_oo00000oooooooo`00ool00002ool005kooooo1Ol00002ooooo`03o`00
0?oooooo000000?o000000Coooooool00?oo003oo`000_l00003ool000;ooooo1?oo000@ooooo`03
00000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Sooooo0ol00003ooooo`;o0000
00?oooooool00?oo00000_oo00000oooooooo`00ooooo`04ool000?ooooo00?oo`00oooooooo0000
H_ooool4o`000003ooooool0003ooooo00Go000000Coooooo`000?oo003ooooo0_l00003ool000?o
oooo0ooo000>ooooo`0300000?oooooooooo00Oooooo000Vooooo`;o0000BOooool2o`0000Cooooo
00?o0000oooooooo00000_ooool00ooo003oooooool00003ool00003oooooooo003ooooo00;ooooo
00Coo`00oooooooo003oo`00I?ooool5o`000004ooooool0003o0000ooooo`?o00000_ooool01?l0
003oo`00ool00?l00003ool000;ooooo1?oo000;ooooo`03o`000000003ooooo00Sooooo000Voooo
o`03o`000?oooooooooo04Sooooo0_l00004ooooo`03o`000?oo003oo`0000;oo`0000?oooooool0
0?ooool01Ooo0002ooooo`Coo`00Ioooool6o`0000;ooooo00?o000000000?l000000ol000001?oo
ooooo`00ool00?l00003ool000;ooooo1?oo000:ooooo`0300000?oooooooooo00Oooooo000Voooo
o`03o`000?oooooooooo04Sooooo0_l00003ooooo`03o`000?oo003oo`0000;oo`000oooool5ool0
00;ooooo1?oo001[ooooo`Go00000oooool6o`000003ool00?l0003o000000?oo`000_ooool3ool0
00Wooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0B?ooool2o`0000?o
oooo00Ooo`00oooooooo003oo`00oooooooo003ooooo00;oo`0000?oooooool00?oo00000_ooool4
ool006oooooo0_l000001?oooooo0000ooooooooool2o`000003ooooool0003o000000?o000000?o
ooooool00?oo00000_oo0002ooooo`?oo`001oooool00`00003oooooooooo`07ooooo`009_ooool0
0ol0003oooooooooo`17ooooo`?o00000_ooool4ool00003oooooooo003ooooo00Goo`000oooool3
ool007;ooooo1Ol00003ooooo`Go000000?oo`00o`000?l000000ooo00001?l0003oooooool00?oo
0006ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooool000000_oo00001Oooooooo`00ool00?oo003ooooo00Koo`000oooool3ool007Gooooo1Ol0
0002ooooo`;o000000Ooooooo`000?l0003o0000oooooooo003o000000?oo`0000Go0000ool00?oo
003oooooool00003ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04Oo
oooo00Go0000oooooooo003oo`00ooooo`08ool000Gooooo0ooo001iooooo`Go00000_ooool5o`00
00;oo`0000?oooooool00?oo00000_l00003ool000;ooooo00<00000ooooooooool01oooool002Ko
oooo0_l00018ooooo`07o`000?oo003oo`00oooooooo003o0000ooooo`04ool00003oooooooo003o
o`0000?ooooo0ooo001mooooo`Go00000_ooool01?l0003oooooo`000?l00005ool00003o`000?oo
003oo`0000;oo`0000<00000ooooooooool01oooool002Kooooo00?oo`00o`000?ooool0Aoooool4
ool00004oooooooo003oo`00ooooo`;oo`0000?oooooool00?oo00000oooool3ool0083ooooo1Ol0
00000ooooooo0000o`000003o`0000Goo`0000Co0000ool00?oo003oo`002Oooool002Kooooo00?o
0000ool00?oo00000_l00013ooooo`Goo`0000?oooooool00?oo00001_oo00000ol0003ooooooooo
o`03ool008Cooooo1?l000001_ooooooo`00ool00?oo003o0000ool000;o00000_oo00000ooooooo
0000ool00009ooooo`009_ooool00ol0003oo`00ool00002ool000?o0000?oooool5ool000;ooooo
1ooo0002o`000004oooooooo003oo`00ool008Oooooo1Ol00003ool00004o`000?ooooooo`00o`00
00;oo`0000?o0000ooooooooool01oooool002Kooooo0_oo00000oooooooo`00ool00002ool000Co
0000>oooool4ool000;o000000?oo`00oooooooo00000_oo00001?ooooooo`00ooooooooool2o`00
00?oo`00Roooool3o`0000Coo`0000Goooooo`000?oo003o0000ool00009ooooo`009_ooool4ool0
0003o`000?oo003oo`0000;oo`001Ol0000fooooo`Goo`0000?oooooo`000?oo00000ooo00001?l0
003oo`00ool00?oo0002ooooo`04o`000?oo003oo`00ool008kooooo0ol00003ool000;ooooo0_oo
0009ooooo`009_ooool00ooo003oooooo`000002ool00003o`000?oo003oo`0000;oo`001ol0000a
ooooo`Goo`000_ooool2o`0000Ooo`000oooool3ool009?ooooo00Ko0000ool00?oo003oo`00oooo
o`000009ooooo`009_ooool00ooo003oooooooooo`02ooooo`;oo`0000?o0000ool00?oo00000_oo
00000ooooooo0000o`000006o`0002cooooo1?oo0004ooooo`03o`000?oo003oo`0000Goo`000ooo
ool3ool009Kooooo00Co0000ool00?oo003oo`002Oooool002Kooooo0ooo00000ol0003oooooool0
0003ool00003oooooooo003oo`0000;oo`0000Co0000oooooooooooooooo1_l0000Wooooo`Goo`00
0oooool6ool00003oooooooo003ooooo00?ooooo0ooo002Iooooo`03o`000?oo003ooooo00Sooooo
000Vooooo`03o`000?oo003oo`0000;oo`0000?o0000ool00?oo00000ooo00001?l0003oo`00ool0
0?oo0002o`000005ooooool0003oooooo`000?ooool01Ol0000Rooooo`Goo`000_ooool3ool00003
oooooooo003oo`0000Coo`0000Co0000oooooooooooooooo0ooo00000ol0003oooooooooo`2Hoooo
o`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Coo`0000?o0000ool00?oo
ool00ooo00000ol0003oo`00ool00002ool000Co000000Cooooo00000?oooooooooo0_l0000Qoooo
o`;oo`001Oooool5ool00004ooooool0003oo`00ool000;o00000_ooool3ool000;o0000V_ooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`02ooooo`Coo`0000?o0000ool0
0?oo00000ooo00000oooooooo`00ool00003ool000;o0000:_ooool6ool000;o00000_oo0002oooo
o`03o`000?oooooooooo00?oo`000ol0002Jooooo`0300000?oooooooooo00Oooooo000Cooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`Ko
o`0000Goooooool00?oo003oo`00ooooo`05ool000Co000000?oooooo`000?ooool08oooool00ooo
003oooooool00007ool00003ooooool0003o000000;ooooo0_oo00000ooooooo0000o`00002Koooo
o`0300000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`?oo`000_ooool5ool00003oooooooo003oo`00
00;oo`002Ol000000ooooooo0000ooooo`0Hooooo`Woo`0000Coooooool00?oo003oo`000oooool0
0ol0003oooooooooo`04ooooo`;o0000Voooool00`00003oooooooooo`07ooooo`004_ooool01?l0
003oooooooooool00007ooooo`Go00001?ooool00ol0003oooooooooo`08ooooo`?oo`000_ooool0
0ooo003oooooool00003ool00003oooooooo003o000000?oo`0000?oooooo`000?l000000ol00000
0ooooooo0000o`000002o`0001?ooooo0ooo00000oooooooo`00ool00005ool00003o`000?oo003o
o`0000?ooooo0_l00005ooooo`?o0000Voooool00`00003oooooooooo`07ooooo`004_ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Gooooo0_l0000;ooooo`Coo`0000?o
ooooool00?oo00001?oo0002ooooo`Coo`0000?oooooo`000?ooool01?l00002ooooo`04o`000?oo
ooooooooo`0000cooooo2Ooo00000oooooooo`00o`000003ool000Cooooo0_l00005ooooo`?o0000
V_ooool3000000Wooooo000Booooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`0<ooooo`Coo`0000?oooooool00?oo00001Ooo0002ooooo`?oo`00
00Go0000ool00?ooooooooooool00005o`0000;ooooo00?o0000ooooooooool00_l000000ooooooo
o`00ool00006ool00003oooooooo003oo`0000?oo`0000?o0000ool00?oo00000_oo0004ooooo`;o
00001_ooool3o`0009cooooo00<00000ooooooooool01oooool001;ooooo00Co0000oooooooooooo
00002Oooool2o`0000Gooooo00?o0000ooooooooool03_ooool4ool000Cooooo1Ooo0002ooooo`Co
o`0000?o0000ool00?l000001?oo00000ol0003oo`00ool00006ool00004o`000?oo003o0000o`00
00Coo`000_l000000ooo003oooooool00002ool000Cooooo0ol00006ooooo`?o0000WOooool00`00
003oooooooooo`07ooooo`004oooool2o`0000_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0@ooooo`Goo`000_ooool2ool00003oooooooo003oo`0000Coo`000oooool00ooo003o
0000ool00002ool000;ooooo1Ooo0002o`0000Koo`001?ooool3ool000Cooooo0ol00007ooooo`Co
0000WOooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Cooooo`Goo`00
0_ooool4ool00003oooooooo003oo`0001;oo`0000Ko0000ool00?l0003o0000ool00?l00003ool0
00Ko00002Oooool4o`0009kooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool05Oooool6ool000?ooooo0ooo0002ooooo`03ool00?oooooooooo00?ooooo0ol000001Ooo003o
ooooool00?oo003o000000;oo`0000?oooooool00?oo00001?oo000?ooooo`Go0000Woooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Hooooo`Woo`001?ooool4ool000Co
oooo0ol000000ooo003o0000o`000004ool000kooooo1?l000000ooooooo0000o`00002Qooooo`03
00000?oooooooooo00Oooooo000Vooooo`;o00007Oooool7ool00003oooooooo003oo`0000?oo`00
00?oooooool00?oo00002?oo0009o`000003ooooool0003o000000[o0000X_ooool00ol000000000
ooooo`08ooooo`009_ooool00ol0003oooooooooo`0Qooooo`koo`002_ooool4o`000003ooooool0
003o000000?o000000Coooooo`000?l0003o0000Y_ooool00`00003oooooooooo`07ooooo`009_oo
ool00ol0003oooooooooo`3]ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo0>gooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0kOooool00`00
003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`0300000?oooooooooo00Oo
oooo0007ooooo`?o00007?ooool00ol0003oooooooooo`3]ooooo`0300000?oooooooooo00Oooooo
0008ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0kOooool00`00003ooooooooo
o`07ooooo`002?ooool00ol0003oooooooooo`0Kooooo`;o0000kOooool00ol000000000ooooo`08
ooooo`002?ooool2o`0001cooooo00?o0000ooooooooool0kOooool00`00003oooooooooo`07oooo
o`001oooool2o`000003ooooool0003o000001[ooooo00?o0000ooooooooool0kOooool00`00003o
ooooooooo`07ooooo`009_ooool00ol0003oooooooooo`3]ooooo`0300000?oooooooooo00Oooooo
000Vooooo`03o`000?oooooooooo0>gooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0kOooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2Toooo
o`Ko000000Koooooo`000?l0003oooooo`000?ooool3o`0000Wooooo3_oo000Sooooo`0300000?oo
oooooooo00Oooooo000Vooooo`;o0000X_ooool:o`000004ooooool0003o0000o`0000;ooooo1_l0
0006ool000;ooooo0_oo00001oooooooo`00ool00?oo003oooooool00?ooool01ooo000Mooooo`03
o`000000003ooooo00Sooooo000Vooooo`03o`000?oooooooooo09oooooo1ol0000>ooooo`Koo`00
00Goooooool00?l0003o0000ooooo`02ool000;ooooo00?oo`00oooooooo00001_ooool7ool001[o
oooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0WOooool5o`0000oooooo
1_oo0003ooooo`;oo`000ol000000ooooooo0000o`000005ooooo`Koo`000oooool6ool001Oooooo
00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0WOooool4o`0000Oooooo2?l0
0005ool000;o000000?oo`00o`000?oo00004ooo0004ooooo`03ool00?ooooooo`0000Goo`005?oo
ool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`2Looooo`03o`000?oooooo
000000Oooooo0ol00004ooooo`goo`0000Soooooo`000?oo003oo`00o`000?oo003o0000ooooo`?o
o`0000Co0000ool00?l0003o00000oooool5ool000;ooooo0_oo0002ooooo`Coo`004_ooool00`00
003oooooooooo`07ooooo`004oooool2o`0000Cooooo00?o0000ooooooooool00_ooool3o`0000Go
oooo00?o0000ooooooooool0Voooool3o`0000Kooooo0ol00004ooooo`Koo`0000?o0000ool00?oo
00000_oo0002o`0000coo`0000?o0000ool00?oo00001?oo00000oooooooo`00ool00002ooooo`Co
o`0000?oooooool00?ooool00_ooool4ool0013ooooo00<00000ooooooooool01oooool001;ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0V_ooool3o`0000Kooooo0_l00005ooooo`?oo`0000?o0000ool00?oo00000ooo00001?oo
ooooo`00ooooooooool4ool000;ooooo00?o000000000?l000000ol00002ooooo`Co00001?oo0000
0ol0003oo`00ool00002ool00003oooooooo003oo`0000;oo`0000Coooooool00?oo003ooooo1?oo
000>ooooo`0300000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooool00000
1Oooool2o`0000Cooooo2_oo0002ooooo`03ool00?oooooooooo00cooooo1Ol000000ooooooo0000
o`000003o`0000Koo`000_ooool4ool00003oooooooo003ooooo00;ooooo0ooo000;ooooo`030000
0?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo1?l00005ooooo`;o0000
V_ooool3o`0000Gooooo0_l00003ooooo`Goo`0000?oooooool00?oo00000ooo0002ooooo`03ool0
0?oooooooooo017ooooo0_l000001?oooooo0000o`000?ooool4o`000005oooooooo003oo`00ool0
0?ooool00_oo00001?ooooooo`00ool00?oo0004ooooo`Coo`001oooool3000000Wooooo000Boooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2I
ooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`;oo`0000?o0000oooooooo00000_oo0002
ooooo`;oo`007?ooool2o`000003ooooool0003o000000;o00001_oo00001Oooooooo`00ool00?oo
003ooooo00;oo`0000?oooooool00?oo00000_oo0007ooooo`0300000?oooooooooo00Oooooo000B
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Iooooo`;o000000?oooooool00?oo00000_ooool2o`0000;ooooo00Goo`00oooooooo003o0000
ooooo`02ool000;ooooo0_oo000Qooooo`?o000000Coooooo`000?l0003o00001?oo0002ooooo`?o
o`000_ooool2o`0000Coo`001Oooool00`00003oooooooooo`07ooooo`004oooool2o`0000[ooooo
0_l00005ooooo`03o`000?oooooooooo09Wooooo0_l00003ool000;ooooo00Co0000oooooooo003o
o`000_l00003ool00003oooooooo003oo`0002Wooooo1Ol00004ool00006oooooooo003oo`00ool0
0?ooooooo`000_l00003ool000Cooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooo
ooooool0V?ooool2o`0000?oo`000_ooool2o`0000;oo`0000?o0000ool00?oo00001Ooo0004oooo
o`;oo`008Oooool3o`0000Cooooo0ol00003ool00003oooooooo003oo`0000Coo`000_l00003ool0
00;ooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0V?ooool01?l0003o
o`00ool00?oo0003ooooo`03o`000?oo003oo`0000Koo`0000?oooooool00?ooool00_ooool4ool0
02;ooooo1_l00002ooooo`04o`000?oooooo0000o`0000?oo`0000Coooooool00?oo003oo`000_oo
ool00ol0003oo`00ool00002ool0000300000?oooooooooo00Oooooo000Vooooo`;oo`00VOooool3
ool000Cooooo0_oo0002ooooo`;oo`001_ooool4ool002Oooooo1_l000001_oooooo0000o`000?l0
003oo`00o`0000;oo`0000?o0000ool00?oo00001ooo0009ooooo`009_ooool3ool000;o0000UOoo
ool3ool000?ooooo2Ooo0003ooooo`Coo`00;Oooool6o`000003ooooool0003oo`0000?oo`0000?o
0000ool00?oo00000_oo00000ooooooo0000ool00009ooooo`009_ooool00ol0003oooooool00002
ool000;o0000T_ooool3ool00005o`000?ooooooooooool00?ooool01?oo00000ol0003oooooool0
0002ooooo`Goo`00<Oooool6o`000003oooooooo003oo`0000;oo`0000?o0000ool00?oo00000ooo
0009ooooo`009_ooool01?l0003oo`00ooooooooool3ool000?o0000S_ooool3ool00003o`000?oo
oooooooo00;oo`0000Goooooo`000?oo003oo`00ooooo`02ool00003o`000?oo003oo`0000?oo`00
=_ooool6o`0000?oo`000_l00002ool0000300000?oooooooooo00Oooooo000Vooooo`;oo`0000?o
0000ool00?ooool01?oo0003o`0008_ooooo0ooo0002o`000003oooooooo003oo`0000;ooooo1?oo
0002o`0000Goo`00>_ooool6o`0000;oo`0000?oooooool00?oo00002Oooool002Kooooo00Ko0000
ool00?oo003oo`00o`000?oo0002ooooo`?oo`001?l00027ooooo`?oo`0000?oooooo`000?l00000
0_oo00000oooooooo`00ool00002ool00003oooooooo003oo`0000Coo`00?oooool3o`0000Coo`00
00<00000ooooooooool01oooool002Kooooo00?oo`00o`000?ooool00_oo00001?l0003oo`00ool0
0?l00003ool00003ooooool0003o000000;o0000Q?ooool3ool000;ooooo00Go0000ool00?oo003o
o`00ooooo`04ool00004oooooooo003oo`00o`0000;oo`00@oooool2o`0000;oo`0000?o0000oooo
ooooool01oooool002Kooooo0ooo00000ol0003oo`00ool00002ool00004o`000?oo003oooooo`00
00?ooooo1Ol00020ooooo`?oo`000oooool00ooo003oooooool00002ool000;ooooo00Coo`00oooo
oooo003ooooo0_oo0018ooooo`03o`000?oo003ooooo00Sooooo000Vooooo`03o`000?oo003oo`00
00;oo`0000Ko0000ool00?oo003oo`00o`000?oo0005o`0000;ooooo0ol0001nooooo`?oo`000ooo
ool2ool00003oooooooo003oo`0000;ooooo00?oo`00o`000?oo00000ooo00000ol0003ooooooooo
o`16ooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`000?oooooooooo00?oo`000_l00004
ool000Ko00001?ooool3o`0007Wooooo1?oo0002ooooo`Ooo`0000Coooooool00?oo003ooooo0_oo
00000ooooooo0000ooooo`18ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooo
oooo00;ooooo0ooo0002o`0000;oo`0000?oooooool00?oo00001?l00002ooooo`03o`000?oooooo
000000Co0000MOooool2ool000Cooooo1Ooo00000oooooooo`00ooooo`02ool00006o`000?oo003o
ooooo`000?oooooo0000BOooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`03ooooo`Coo`0000Goooooo`000?oo003oo`00o`000002ool000Oo000000?oooooo`000?l00000
0ol0001booooo`Coo`000_ooool2ool00006oooooooo003oo`00oooooooo003ooooo1?oo0002oooo
o`03o`000?oooooo000004Wooooo00<00000ooooooooool01oooool002Kooooo00?o0000oooooooo
ool01Oooool4ool00005oooooooo003oo`00ool00?l000000_oo00000`00003o0000o`000005o`00
0006ooooool0003o0000o`000?oooooo0000K_ooool4ool000;ooooo0_oo00000oooooooo`00ool0
0005ool00003oooooooo003ooooo00;ooooo0_l0001:ooooo`0300000?oooooooooo00Oooooo000V
ooooo`03o`000?oooooooooo00Oooooo0ooo0002ooooo`?oo`0000?o0000ool00?l000001_l00002
ooooo`Ko0000Joooool4ool000;ooooo1Ooo0003ooooo`Coo`0000Co0000oooooooooooooooo0_l0
001:ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo00Wooooo0ooo0002
ooooo`?oo`000_l00002ool00003ooooool0003o000000Go000000?oooooo`000?l000000ol0001W
ooooo`;oo`0000?oooooool00?ooool00_ooool00ooo003oooooool00003ool00003oooooooo003o
o`0000;oo`000_l00003ooooo`;o0000B_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0
003oooooooooo`0:ooooo`Coo`000_ooool3ool00004o`000?oo003oooooool000Go000000Cooooo
o`000?oooooooooo1Ol0001Uooooo`03ool00?ooooooo`0000?ooooo1?oo0003ooooo`Coo`0000?o
ooooo`000?ooool00oooool2o`0004[ooooo00<00000ooooooooool01oooool002Kooooo0_l0000=
ooooo`Coo`000_ooool3ool00005o`000?oo003oo`00ool00?ooool01Ol00002ooooo`0300000?oo
oooo000000Co0000HOooool01?oo003oooooool00?oo0002ooooo`Koo`0000?oooooool00?oo0000
0_oo00000ooooooo0000o`000004ooooo`;o0000BOooool00ol000000000ooooo`08ooooo`009_oo
ool00ol0003oooooooooo`0>ooooo`Coo`000_ooool4ool00004o`000?oo003oo`00ool000Oo0000
0_ooool5o`0005kooooo0ooo0003ooooo`03ool00?ooooooo`0000Soo`000_ooool00ol0003ooooo
ooooo`02ooooo`?o0000B_ooool00`00003oooooooooo`07ooooo`009_ooool00ol0003ooooooooo
o`0@ooooo`Coo`000oooool3ool000;o00000ooo00000ol0003oooooo`00000:o`0005_ooooo0_oo
00001?ooooooo`00ooooooooool6ool00003oooooooo003oo`0000;oo`000_ooool2o`0000Cooooo
0_l0001;ooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo01;ooooo1?oo
0003ooooo`Coo`000_l00004ool000Go00000_ooool00ol0003oooooooooo`02o`0001?ooooo3?oo
000hooooo`;oo`0000Koooooool00?ooooooooooool00?ooool9ool000;ooooo0_l00005ooooo`;o
0000Boooool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`0Dooooo`Coo`00
1?ooool4ool00003o`000?ooooooo`0000;oo`001_l000000ooooooo0000o`000003o`0000_ooooo
1?oo00000oooooooo`00ool0000:ooooo`?oo`00=Oooool2ool00005oooooooo003ooooooooooooo
00000_ooool3ool00003oooooooo003ooooo00;oo`0000Coooooo`000?l0003o00001Oooool3o`00
04_ooooo00<00000ooooooooool01oooool001?ooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo0ol00005ooooo`03o`000?oooooooooo01Kooooo0ooo0006ooooo`Coo`001?l0000<ool00003
o`000?oo003oo`0000Koo`004oooool2ool003?ooooo0_oo00000oooooooo`00ooooo`02ooooo`04
ool00?ooooooo`00ool000;ooooo0_oo00000oooooooo`00ooooo`02o`0000Oooooo0_l0001<oooo
o`0300000?oooooooooo00Oooooo000Booooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo02;ooooo1Ooo0007o`0000Cooooo0_l00000
0ooooooo0000o`00000Iooooo`03ool00?oooooooooo037ooooo00Goo`00oooooooo003oo`00oooo
o`09ool00003oooooooo003o000000;o0000E_ooool00`00003oooooooooo`07ooooo`004_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001?ooool2o`0002Oooooo
1ooo0003o`0000Cooooo1?l0000Hooooo`;oo`00<Oooool2ool00004oooooooo003oooooooooo`So
o`0000?o0000ool00?l00000Eoooool3000000Wooooo000Booooo`04o`000?ooooooooooo`0000So
oooo0ol00005ooooo`03o`000?oooooooooo02Wooooo0ol0000Jool000_ooooo00?oo`00oooooooo
ool09?ooool:o`0000;oo`0000Co0000ool00?l0003o00001Ooo00001Ol0003oo`00ool00?oooooo
o`0005_ooooo00<00000ooooooooool01oooool001;ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0;?ooool3o`000003ooooool0
003ooooo00Co00000_ooool6o`0000Oooooo0ooo0009ooooo`03ool00?oooooooooo02?ooooo0_l0
0008ooooo`;oo`0000Goooooool00?ooooooooooool00002ooooo`Goo`0000?oooooool00?oo0000
Foooool00`00003oooooooooo`07ooooo`004_ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0_ooooo`Co000000?oooooo`000?l0
00001ol000000ooooooo0000o`000007ooooo`;oo`002?ooool2ool002Cooooo00?o0000oooooooo
ool01_ooool2ool00003oooooooo003oo`0000;ooooo1Ooo00000oooooooo`00ooooo`02ool005co
oooo00<00000ooooooooool01oooool001?ooooo0_l00009ooooo`?o00001Oooool00ol0003ooooo
ooooo`0aooooo`?o000000?oooooo`000?l000001?l00002ooooo`Ko00001_ooool01?oo003ooooo
ooooooooool4o`000003oooooooo003ooooo01gooooo0ooo0003ooooo`;o00001oooool01Ooo003o
ooooool00?oo003ooooo00Goo`000_ooool01?oo003oooooool00?oo001Mooooo`0300000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo03Cooooo2_l000000ooooooo0000o`000002o`00
00Kooooo0_oo0003ooooo`Co000000?oo`00o`000?ooool06oooool2ool00003oooooooo003ooooo
00?ooooo0_l00005ooooo`;oo`0000Coooooool00?oooooooooo2_oo001Nooooo`0300000?oooooo
oooo00Oooooo000Vooooo`03o`000?oooooooooo03Kooooo1?l000000ooooooo0000o`000007o`00
000300000?l0003o000000?ooooo00?oo`00ooooooooool00oooool2o`000003ool00?l0003o0000
00;o00006?ooool2ool00003oooooooo003oo`0000Gooooo0_l00003ooooo`;oo`0000Goooooool0
0?ooooooooooool00002ooooo`Goo`0000?oooooool00?ooool0G_ooool00`00003oooooooooo`07
ooooo`009_ooool00ol0003oooooooooo`0hooooo`Wo00000oooool6o`0000;oo`001_ooool01?oo
003o0000o`000?ooool3o`0001Gooooo0_oo0002ooooo`03ool00?oooooooooo00Gooooo0_l00000
0oooooooo`00ool00002ooooo`04ool00?ooooooo`00ooooo`?oo`0000Goooooool00?oo003ooooo
ool0001Pooooo`0300000?oooooooooo00Oooooo000Vooooo`;o0000??ooool:o`000007ooooool0
003o0000o`000?oooooo0000ool00006ooooo`;oo`000ol000000ooooooo0000o`000002o`00017o
oooo0_oo0003ooooo`03ool00?oooooooooo00Oooooo0_oo00000oooooooo`00ooooo`02ooooo`Co
o`001?ooool00ooo003oooooooooo`1Nooooo`03o`000000003ooooo00Sooooo000Vooooo`03o`00
0?oooooooooo03oooooo00Co0000ooooool0003ooooo1Ol000001?oooooo0000o`000?oo0002o`00
00Gooooo00Coo`00oooooooooooooooo0_l00002ooooo`?o00003_ooool2ool000?ooooo00?oo`00
ooooooooool02?ooool01?oo003o0000o`000?oo0002ooooo`Ooo`0000?oooooool00?oo0000HOoo
ool00`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`10ooooo`?o000000?ooooo
00000?l000000ol00002ooooo`03ool00?l0003o000000;o00000_ooool2ool000Gooooo0ol00002
ooooo`?o00002_ooool2ool000?ooooo0_oo0009ooooo`;oo`0000Coooooool00?l0003o00001Ooo
00000oooooooo`00ool00002ool006;ooooo00<00000ooooooooool01oooool002Kooooo00?o0000
ooooooooool0>_ooool4o`0000Gooooo0_l000000ooooooo0000o`000003o`0000;oo`0000?ooooo
o`000?l000000_l000000`00003oo`00ooooo`06ooooo`?o00000oooool3o`0000Kooooo0_oo0004
ooooo`03ool00?oooooooooo00Oooooo0_oo00001_ooooooo`00ool00?ooooooo`00o`0000;oo`00
0_ooool2ool000Sooooo0_oo001Kooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oo
oooooooo03_ooooo1_l00004ooooo`?o000000Goooooo`000?l0003o0000ool00002o`0000;ooooo
0_l000000ooooooo0000o`000007ooooo`?o00000oooool4o`000003oooooooo003oo`0000Gooooo
0_oo0008ooooo`;oo`0000Koooooool00?oo003oooooool00?ooool6ool00003oooooooo003ooooo
00Cooooo1?oo001Kooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo03go
oooo1ol00003ooooo`Co000000?oooooool00?l000000ol000001Ooooooo0000o`000?l0003ooooo
00;o00001oooool3o`0000Cooooo00?o0000ool00?oo00001_ooool00ooo003oooooooooo`07oooo
o`05ool00?ooooooooooool00?ooool00_oo00002?ooooooo`00ool00?oo003o0000ool00?oooooo
o`001Oooool2ool00003oooooooo003oo`0005_ooooo00<00000ooooooooool01oooool002Kooooo
00?o0000ooooooooool0@?ooool6o`0000Cooooo0_l000000ooo003o0000o`00000<o`0000Kooooo
0ol00002ooooo`;oo`0000Coooooo`000?l0003o00000_ooool00ooo003oooooooooo`07ooooo`03
ool00?oooooooooo00?ooooo1_oo0002o`0000;oo`001?ooool2ool000;ooooo00?oo`00oooooooo
ool0F_ooool00`00003oooooooooo`07ooooo`009_ooool2o`0004?ooooo0ol000001?oooooo0000
o`000?l00003ooooo`04ool00?l0003o0000ooooo`Ko000000Coooooo`000?l0003o00000_ooool0
0`00003oooooooooo`05ooooo`03o`000?oo003oo`0000Gooooo00?o0000ool00?oo00002?ooool2
ool00004oooooooo003oo`00ooooo`Coo`000_ooool01Ooo003oooooool00?oo003o000000?ooooo
0_oo0002ooooo`;oo`00Foooool00ol000000000ooooo`08ooooo`009_ooool00ol0003ooooooooo
o`14ooooo`?o000000?oooooo`000?l000000_l000000ooo003oooooo`000002o`000003ooooool0
003ooooo00Go000000Coooooo`000?l0003ooooo0ol00004ooooo`;oo`000ol00004ooooo`03ool0
0?l0003o000000;o00001?ooool2ool000;ooooo00Goo`00oooooooo003oo`00ooooo`02ool00006
oooooooo003ooooooooooooo003ooooo0_l000000oooooooo`00ool00002ooooo`;oo`00GOooool0
0`00003oooooooooo`07ooooo`009_ooool00ol0003oooooooooo`16ooooo`Co000000Coooooo`00
0?oo003oo`000oooool00ol000000000o`000005o`000003ooooool0003o000000Go00000_ooool2
ool000?ooooo0ol000000oooooooo`00ool00003ooooo`Co00000_oo0002ooooo`03ool00?oooooo
oooo00Ooo`0000?oooooool00?ooool00_ooool00ol0003oo`00ool00003ooooo`03ool00?oooooo
oooo05cooooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0BOooool3o`00
0003oooooooo003o000000;o00000_ooool=o`000004oooooooo003oo`00o`0000Kooooo0_l00000
0ooo003oooooooooo`05ooooo`05o`000?oo003o0000o`000?oo00000_ooool5ool00004oooooooo
003oooooool000Cooooo0_oo0002o`000003oooooooo003oo`0005kooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0Boooool2o`000003ool00?oooooooooo00?o00000ooo
ool8o`0000;ooooo0_oo00001?l0003oooooo`000?l00005ooooo`;oo`000ol00004ooooo`;oo`00
00Goooooool00?oo003o0000ool00002ooooo`05ool00?ooooooo`00ool00?ooool00_oo0003oooo
o`;oo`000_ooool2o`000003ool00?oooooooooo05gooooo00<00000ooooooooool01oooool002Ko
oooo00?o0000ooooooooool0COooool00ooo003o0000o`000003ooooo`03o`000?oooooooooo00;o
oooo0_l00003ooooo`;o00000_oo0002ooooo`Ko000000?oooooool00?oo00000oooool3o`000003
oooooooo003oo`0000;ooooo00?oo`00oooooooo00001_oo00000oooooooo`00ool00003ooooo`;o
o`001?ooool00ooo003o0000o`00001Nooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`00
0?oooooooooo04gooooo0_oo0004o`0000;ooooo0ol00002ooooo`?o00000_oo0005o`0000;ooooo
1?l000000ooo003o0000ooooo`04ooooo`03o`000?oo003oo`0000;ooooo00?oo`00oooooooo0000
1ooo00000oooooooo`00ooooo`03ooooo`03ool00?oooooooooo00;ooooo0_oo00000ooooooo0000
o`00001Mooooo`0300000?oooooooooo00Oooooo000Vooooo`03o`000?oooooooooo04kooooo00Co
o`00oooooooooooooooo0ol00003ooooo`?o00000ooo00001?l0003oooooo`000?ooool6o`000003
oooooooo003oo`0000?o00001?ooool01?oo003o0000o`000?oo0002ooooo`Coo`0000Coooooool0
0?oo003ooooo1?l000000oooooooo`00ooooo`04ooooo`04ool00?ooooooooooooooo`;o0000G?oo
ool00`00003oooooooooo`07ooooo`009_ooool2o`0004oooooo0_oo0004ooooo`?o00000oooool2
ool00003o`000?oooooooooo00?o00000_ooool4o`0000;oo`001_l000001oooooooo`00oooooooo
ooooo`00ooooool000000_oo00001_ooooooo`00ooooooooooooo`00ooooo`;oo`000_ooool01?l0
003oo`00o`000?l00003ooooo`03ool00?oooooooooo00?ooooo0_l0001Jooooo`03o`000000003o
oooo00Sooooo000Vooooo`03o`000?oooooooooo04oooooo0_oo0005ooooo`03o`000?oo003oo`00
00;oo`000_ooool3o`000003ooooool0003o000000Go000000Goo`00o`000?oooooo0000ooooo`02
o`000007oooooooo003oo`00o`000?ooooooo`00ooooo`08ool00003oooooooo003ooooo00;ooooo
0_oo0002ooooo`;o00000_oo0006ooooo`03o`000?oooooooooo05Wooooo00<00000ooooooooool0
1oooool002Kooooo00?o0000ooooooooool0D?ooool8ool00004ooooool0003o0000o`0000?ooooo
0ol00002ooooo`?o00000_oo0003o`0000?ooooo0_oo00001?oooooo0000ool00?l00003ooooo`;o
o`000_l000000ooo003oooooool00003ooooo`;oo`001Oooool00ooo003oooooo`000006o`0005_o
oooo00<00000ooooooooool01oooool002Kooooo00?o0000ooooooooool0Foooool3o`0000Cooooo
00So000000000?ooooooooooo`000?oo003o0000ooooo`Co00000_oo0002o`0000;oo`0000?ooooo
ool00?l000000_oo00001_ooooooo`00ooooool0003oo`00o`0000;ooooo0_oo0005ooooo`;oo`00
Hoooool00`00003oooooooooo`07ooooo`007_ooool3o`0000Gooooo00?o0000ooooooooool0GOoo
ool3o`0000Cooooo0_l000000ooo003oooooooooo`03o`000003ooooool0003oo`0000;o000000?o
o`00o`000?ooool01?oo00001?l0003oo`00ool00?ooool2ool00004ooooool0003o0000ool000Go
oooo0_oo001Tooooo`0300000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo00Cooooo
00<00000ooooooooool0;Oooool00`00003oooooooooo`0]ooooo`0300000?oooooo000000?o0000
0_ooool2ool000?o000000Koooooo`000?l0003oo`00o`000?ooool3o`000003ool00?l0003o0000
00;oo`0000?oooooool00?l000000_oo0002ooooo`;oo`000ol00003ooooo`03ool00?oooooooooo
00?ooooo00<00000ooooooooool0;Oooool00`00003oooooooooo`0]ooooo`0300000?oooooooooo
00Oooooo000Oooooo`03o`000?oooooooooo00Cooooo00<00000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00`00003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`0300000?oooooooooo00;ooooo0ol000001?oo003oooooooooooooool3o`00
00;oo`000_l000001Ooo003o0000ool00?oo003o000000?oo`000ol000002?oo003o0000o`000?oo
ooooo`00ooooool0003ooooo0ol000000ooo003oooooooooo`04ooooo`0300000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00<00000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00`00003oooooooooo`07ooooo`007oooool00ol0003ooooo
ooooo`04ooooofL0000000?oo`000000000000001@0000001Ooo0000000000000000003oo`0000@0
000000Koo`0000000?oo003o000000000?l0000300000003o`000?oo0000000000@0000000?o0000
ool000000000IP000009ooooo`007oooool00ol0003oooooooooo`3nooooo`007_ooool2o`000?oo
oooo0Oooool001oooooo00?o0000ooooooooool0o_ooool00?oooooo8Oooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 302.812}, {697, 555.688}} -> {-0.54256, \
4.52677, 0.00417185, 0.0067502}}]
}, Open  ]],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
We can create an animation of the successive iterates of the \
homoclinic tangle by generating several of these plots and copying them to \
another file.  Once the plots are arranged one can select the plots and \
choose Animate Selected Graphics from the Cell menu to run the \
animation.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exponential Divergence and Lyapunov Exponents", "Section"],

Cell["\<\
To illustrate exponential divergence of neighboring trajectories we \
can start with two different, but very close, initial points.  The distance \
between the iterates of these points should increase exponentially with time \
if the initial points are in a chaotic region of the phase space.  Therefore, \
a plot of the natural log of this distance should increase linearly with the \
number of iterations.  In the example below we create such a plot using \
initial points {0.5,0} (which is a fixed point) and {0.50000001,0}.  The \
graph shows the log of the distance between the trajectories versus the \
number of iterations of the map, up to 30 iterations.  Note that the function \
is no longer defined Modulo 1, because this leads to incorrect measures of \
the distance between the trajectories.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(K = 1.5; \[Theta]1 = 0.5; r1 = 0; \[Theta]2 = 0.50000001; r2 = 0; 
    n = 30;\), "\n", 
    \(\(f[{\[Theta]_, r_}] := 
        N[{\[Theta] + r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 
            r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]]}];\)\), "\n", 
    \(\(L1 = NestList[f, {\[Theta]2, r2}, n];\)\), "\[IndentingNewLine]", 
    \(\(DList = 
        Table[Log[
            Sqrt[\((0.5 - L1[\([i, 1]\)])\)^2 + \((0 - 
                      L1[\([i, 2]\)])\)^2]], {i, 
            n + 1}];\)\), "\[IndentingNewLine]", 
    \(ListPlot[DList, Frame \[Rule] True, Axes \[Rule] False, 
      FrameLabel \[Rule] {"\<n\>", \*"\"\<Ln(\!\(d\_n\))\>\"", "\<\>", \
"\<\>"}, PlotStyle \[Rule] PointSize[0.01]]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.030722 0.583677 0.0308871 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.17742 -0.0125 -3 -9 ]
[.17742 -0.0125 3 0 ]
[.33103 -0.0125 -6 -9 ]
[.33103 -0.0125 6 0 ]
[.48464 -0.0125 -6 -9 ]
[.48464 -0.0125 6 0 ]
[.63825 -0.0125 -6 -9 ]
[.63825 -0.0125 6 0 ]
[.79186 -0.0125 -6 -9 ]
[.79186 -0.0125 6 0 ]
[.94547 -0.0125 -6 -9 ]
[.94547 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .12037 -18 -4.5 ]
[-0.0125 .12037 0 4.5 ]
[-0.0125 .27481 -18 -4.5 ]
[-0.0125 .27481 0 4.5 ]
[-0.0125 .42924 -12 -4.5 ]
[-0.0125 .42924 0 4.5 ]
[-0.0125 .58368 -6 -4.5 ]
[-0.0125 .58368 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30 -19.625 ]
[-0.01875 .30902 -18 19.625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.17742 0 m
.17742 .00625 L
s
[(5)] .17742 -0.0125 0 1 Mshowa
.33103 0 m
.33103 .00625 L
s
[(10)] .33103 -0.0125 0 1 Mshowa
.48464 0 m
.48464 .00625 L
s
[(15)] .48464 -0.0125 0 1 Mshowa
.63825 0 m
.63825 .00625 L
s
[(20)] .63825 -0.0125 0 1 Mshowa
.79186 0 m
.79186 .00625 L
s
[(25)] .79186 -0.0125 0 1 Mshowa
.94547 0 m
.94547 .00625 L
s
[(30)] .94547 -0.0125 0 1 Mshowa
.125 Mabswid
.05453 0 m
.05453 .00375 L
s
.08525 0 m
.08525 .00375 L
s
.11598 0 m
.11598 .00375 L
s
.1467 0 m
.1467 .00375 L
s
.20814 0 m
.20814 .00375 L
s
.23886 0 m
.23886 .00375 L
s
.26959 0 m
.26959 .00375 L
s
.30031 0 m
.30031 .00375 L
s
.36175 0 m
.36175 .00375 L
s
.39247 0 m
.39247 .00375 L
s
.4232 0 m
.4232 .00375 L
s
.45392 0 m
.45392 .00375 L
s
.51536 0 m
.51536 .00375 L
s
.54608 0 m
.54608 .00375 L
s
.5768 0 m
.5768 .00375 L
s
.60753 0 m
.60753 .00375 L
s
.66897 0 m
.66897 .00375 L
s
.69969 0 m
.69969 .00375 L
s
.73041 0 m
.73041 .00375 L
s
.76114 0 m
.76114 .00375 L
s
.82258 0 m
.82258 .00375 L
s
.8533 0 m
.8533 .00375 L
s
.88402 0 m
.88402 .00375 L
s
.91475 0 m
.91475 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12037 m
.00625 .12037 L
s
[(-15)] -0.0125 .12037 1 0 Mshowa
0 .27481 m
.00625 .27481 L
s
[(-10)] -0.0125 .27481 1 0 Mshowa
0 .42924 m
.00625 .42924 L
s
[(-5)] -0.0125 .42924 1 0 Mshowa
0 .58368 m
.00625 .58368 L
s
[(0)] -0.0125 .58368 1 0 Mshowa
.125 Mabswid
0 .15126 m
.00375 .15126 L
s
0 .18214 m
.00375 .18214 L
s
0 .21303 m
.00375 .21303 L
s
0 .24392 m
.00375 .24392 L
s
0 .30569 m
.00375 .30569 L
s
0 .33658 m
.00375 .33658 L
s
0 .36747 m
.00375 .36747 L
s
0 .39835 m
.00375 .39835 L
s
0 .46013 m
.00375 .46013 L
s
0 .49102 m
.00375 .49102 L
s
0 .5219 m
.00375 .5219 L
s
0 .55279 m
.00375 .55279 L
s
0 .08948 m
.00375 .08948 L
s
0 .0586 m
.00375 .0586 L
s
0 .02771 m
.00375 .02771 L
s
0 .61456 m
.00375 .61456 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -104.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
80.625 10 translate
90 rotate
-80.625 -10 translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ln) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
87.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.250 13.000 moveto
(L) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.17742 .61178 m
.17742 .61803 L
s
.33103 .61178 m
.33103 .61803 L
s
.48464 .61178 m
.48464 .61803 L
s
.63825 .61178 m
.63825 .61803 L
s
.79186 .61178 m
.79186 .61803 L
s
.94547 .61178 m
.94547 .61803 L
s
.125 Mabswid
.05453 .61428 m
.05453 .61803 L
s
.08525 .61428 m
.08525 .61803 L
s
.11598 .61428 m
.11598 .61803 L
s
.1467 .61428 m
.1467 .61803 L
s
.20814 .61428 m
.20814 .61803 L
s
.23886 .61428 m
.23886 .61803 L
s
.26959 .61428 m
.26959 .61803 L
s
.30031 .61428 m
.30031 .61803 L
s
.36175 .61428 m
.36175 .61803 L
s
.39247 .61428 m
.39247 .61803 L
s
.4232 .61428 m
.4232 .61803 L
s
.45392 .61428 m
.45392 .61803 L
s
.51536 .61428 m
.51536 .61803 L
s
.54608 .61428 m
.54608 .61803 L
s
.5768 .61428 m
.5768 .61803 L
s
.60753 .61428 m
.60753 .61803 L
s
.66897 .61428 m
.66897 .61803 L
s
.69969 .61428 m
.69969 .61803 L
s
.73041 .61428 m
.73041 .61803 L
s
.76114 .61428 m
.76114 .61803 L
s
.82258 .61428 m
.82258 .61803 L
s
.8533 .61428 m
.8533 .61803 L
s
.88402 .61428 m
.88402 .61803 L
s
.91475 .61428 m
.91475 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .12037 m
1 .12037 L
s
.99375 .27481 m
1 .27481 L
s
.99375 .42924 m
1 .42924 L
s
.99375 .58368 m
1 .58368 L
s
.125 Mabswid
.99625 .15126 m
1 .15126 L
s
.99625 .18214 m
1 .18214 L
s
.99625 .21303 m
1 .21303 L
s
.99625 .24392 m
1 .24392 L
s
.99625 .30569 m
1 .30569 L
s
.99625 .33658 m
1 .33658 L
s
.99625 .36747 m
1 .36747 L
s
.99625 .39835 m
1 .39835 L
s
.99625 .46013 m
1 .46013 L
s
.99625 .49102 m
1 .49102 L
s
.99625 .5219 m
1 .5219 L
s
.99625 .55279 m
1 .55279 L
s
.99625 .08948 m
1 .08948 L
s
.99625 .0586 m
1 .0586 L
s
.99625 .02771 m
1 .02771 L
s
.99625 .61456 m
1 .61456 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.05453 .01472 Mdot
.08525 .04777 Mdot
.11598 .0838 Mdot
.1467 .11962 Mdot
.17742 .15541 Mdot
.20814 .1912 Mdot
.23886 .227 Mdot
.26959 .26279 Mdot
.30031 .29858 Mdot
.33103 .33437 Mdot
.36175 .37017 Mdot
.39247 .40596 Mdot
.4232 .44175 Mdot
.45392 .47753 Mdot
.48464 .51325 Mdot
.51536 .54826 Mdot
.54608 .57666 Mdot
.5768 .58052 Mdot
.60753 .58106 Mdot
.63825 .57835 Mdot
.66897 .56904 Mdot
.69969 .55618 Mdot
.73041 .52499 Mdot
.76114 .5012 Mdot
.79186 .52373 Mdot
.82258 .55763 Mdot
.8533 .58041 Mdot
.88402 .58399 Mdot
.91475 .58909 Mdot
.94547 .59872 Mdot
.97619 .60332 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00WOooool3o`000003ooooool0
003o000007gooooo002Nooooo`04o`000?ooooooooooo`0007kooooo002Nooooo`04o`000?oooooo
ooooo`0007kooooo002Nooooo`04o`000?ooooooooooo`0007kooooo002Mooooo`Co0000Ooooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool002Wooooo0_l0000S
ooooo`?o00008?ooool3o`0000Cooooo0_l0000Mooooo`?o00000oooool3o`0001cooooo1Ol00003
ooooo`;o00007?ooool5o`0000;ooooo0ol0000Mooooo`?o00001?ooool2o`0000kooooo000Xoooo
o`04o`000?ooooooooooo`00027ooooo00Go0000ooooooooooooooooo`00000Pooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00007Oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool06_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooooooo
o`0001cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo01Wooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000gooooo000Xooooo`04
o`000?ooooooooooo`0002Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0001gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`0;ooooo`00:?ooool01?l0003oooooooooool0000Uooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool07?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo0_l00003oooo
o`04o`000?ooooooooooo`0000gooooo000Xooooo`04o`000?ooooooooooo`00027ooooo1?l0000Q
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00007Oooool01?l0003ooooooooo
ooooool4o`0001cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
01_ooooo00Ko0000ooooooooooooooooo`000?ooool4o`00023ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`0;ooooo`00:?ooool01?l0003oooooooooool0000Qooooo`03o`00
0?oooooooooo027ooooo0_l00004ooooo`04o`000?ooooooooooo`0001cooooo0_l00003ooooo`03
o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0001_ooooo00Oo0000ooooooooooooooooo`000?oooooo000001oooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000gooooo000Yooooo`;o00008_ooool5o`00023o
oooo00?o0000ooooooooool00oooool2o`0001kooooo00Co0000oooooooooooooooo1Ol0000Loooo
o`?o00001?ooool2o`0001gooooo0ol00002ooooo`Go00007?ooool3o`0000Cooooo0_l0000>oooo
o`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`009Oooooogo`00
000300000?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`0300000?oooooooooo007ooooo000Uooooo`03o`00
0?oooooooooo0?Cooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool02Ooo
ool200000>Wooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool02Oooool2
00000>Wooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0m?ooool00`00
003oooooooooo`01ooooo`009Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007o
oooo000Uooooo`;o0000m?ooool00ol000000000ooooo`02ooooo`009Oooool00ol0003ooooooooo
o`3dooooo`0300000?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo0?Cooooo00<00000
ooooooooool00Oooool002Gooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01oooo
o`009Oooool00ol0003oooooooooo`0Aooooo`800000hOooool00`00003oooooooooo`01ooooo`00
9Oooool00ol0003oooooooooo`0Aooooo`800000hOooool00`00003oooooooooo`01ooooo`009Ooo
ool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000Uooooo`;o0000m?ooool0
0ol000000000ooooo`02ooooo`009Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo
007ooooo000Uooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Oooool002Gooooo
00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`009Oooool00ol0003ooooooooo
o`3dooooo`0300000?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo0?Cooooo00<00000
ooooooooool00Oooool002Gooooo00?o0000ooooooooool06Oooool200000=Wooooo00<00000oooo
ooooool00Oooool002Gooooo00?o0000ooooooooool06Oooool200000=Wooooo00<00000oooooooo
ool00Oooool002Gooooo0_l0003dooooo`03o`000000003ooooo00;ooooo000Uooooo`03o`000?oo
oooooooo0?Cooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0m?ooool0
0`00003oooooooooo`01ooooo`009Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo
007ooooo000Uooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Oooool001Oooooo
0ol00003ooooo`?o00001Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo
000Hooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?Cooooo00<00000ooooooooool00Oooool0013ooooo1Ol00003ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool2o`00027ooooo0P00003@ooooo`<000000ooo
ool001Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo023ooooo0P00003Booooo`0300000?oooooooooo007ooooo000Hooooo`04o`000?oooooooooo
ooooo`Co00001Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000Goooo
o`;o00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?Cooooo00<00000oooo
ooooool00Oooool001Sooooo00Co0000oooooooooooooooo1Ol00004ooooo`03o`000?oooooooooo
0?Cooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0m?ooool00`00003o
ooooooooo`01ooooo`009Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo
000Uooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Oooool002Gooooo0_l0003d
ooooo`03o`000000003ooooo00;ooooo000Uooooo`03o`000?oooooooooo02Sooooo0P00003:oooo
o`0300000?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo02Sooooo0P00003:ooooo`03
00000?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool0
0Oooool002Gooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`009Oooool0
0ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo
0?Cooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0m?ooool00`00003o
ooooooooo`01ooooo`009Oooool2o`000?Cooooo00?o000000000?ooool00_ooool002Gooooo00?o
0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`009Oooool00ol0003oooooooooo`0_
ooooo`800000`oooool00`00003oooooooooo`01ooooo`009Oooool00ol0003oooooooooo`0_oooo
o`800000`oooool00`00003oooooooooo`01ooooo`009Oooool00ol0003oooooooooo`3dooooo`03
00000?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool0
0Oooool002Gooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`009Oooool2
o`000?Cooooo00?o000000000?ooool00_ooool002Gooooo00?o0000ooooooooool0m?ooool00`00
003oooooooooo`01ooooo`009Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007o
oooo000Uooooo`03o`000?oooooooooo03Oooooo0P00002kooooo`0300000?oooooooooo007ooooo
000Uooooo`03o`000?oooooooooo03Oooooo0P00002kooooo`0300000?oooooooooo007ooooo000U
ooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Oooool002Gooooo00?o0000oooo
ooooool0m?ooool00`00003oooooooooo`01ooooo`002oooool5o`0001Gooooo00?o0000oooooooo
ool0m?ooool00`00003oooooooooo`01ooooo`003?ooool01?l0003oooooooooool0000Eooooo`;o
0000m?ooool00ol000000000ooooo`02ooooo`003?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0?Cooooo00<00000ooooooooool00Oooool000cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000<ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`003?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo03oooooo0P00002cooooo`0300000?oooooooooo
007ooooo000;ooooo`?o000000?oooooo`000?l000001_ooool3o`0000Cooooo0_l00005ooooo`03
o`000?oooooooooo03oooooo0P00002cooooo`0300000?oooooooooo007ooooo000<ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Oooool000cooooo00?o0000oooooooo
ool01_l00003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000<ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`;o0000loooool3
000000?ooooo000;ooooo`Go00002?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`003_ooool00ol0
003oooooooooo`06ooooo`;o00001?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo0?Cooooo00<00000ooooooooool00Oooool000gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo
007ooooo000=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0m?ooool00`00003o
ooooooooo`01ooooo`003Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Kooooo
0P00002/ooooo`0300000?oooooooooo007ooooo000=ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0A_ooool200000:cooooo00<00000ooooooooool00Oooool000kooooo00?o0000
ooooooooool05?ooool2o`000?Cooooo00?o000000000?ooool00_ooool000oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000<ooooo`Co
00005Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000;ooooo`04o`00
0?ooooooooooo`0001Kooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`00
2oooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo0?Cooooo00<00000oooooooo
ool00Oooool000_ooooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`3dooooo`03
00000?oooooooooo007ooooo000<ooooo`?o00005_ooool00ol0003oooooooooo`3dooooo`030000
0?oooooooooo007ooooo000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0C_oo
ool200000:Cooooo00<00000ooooooooool00Oooool000gooooo0_l000000ooooooo0000ooooo`0C
ooooo`;o0000Coooool200000:?ooooo00?o000000000?ooool00_ooool000kooooo00?o0000oooo
ool000005?ooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000>ooooo`03
o`000?oooooo000001Cooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`00
3_ooool3o`0001Cooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`003?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Ooo
ool000gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3dooooo`0300000?oooooo
oooo007ooooo000>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0m?ooool00`00
003oooooooooo`01ooooo`003_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?Co
oooo00<00000ooooooooool00Oooool000kooooo00?o0000ooooooooool05?ooool2o`0005Kooooo
0P00002Looooo`03o`000000003ooooo00;ooooo000>ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0EOooool2000009gooooo00<00000ooooooooool00Oooool000gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000<oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01oooo
o`009Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000Uooooo`03o`00
0?oooooooooo0?Cooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0m?oo
ool00`00003oooooooooo`01ooooo`009Oooool2o`000?Cooooo00?o000000000?ooool00_ooool0
02Gooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`009Oooool00ol0003o
ooooooooo`1Mooooo`800000UOooool00`00003oooooooooo`01ooooo`009Oooool00ol0003ooooo
ooooo`1Mooooo`800000UOooool00`00003oooooooooo`01ooooo`009Oooool00ol0003ooooooooo
o`3dooooo`0300000?oooooooooo007ooooo000Mooooo`?o00001Oooool00ol0003oooooooooo`3d
ooooo`0300000?oooooooooo007ooooo000Looooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000Fooooo`Go00001Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Oooool0023o
oooo00?o0000ooooooooool00_ooool2o`000??ooooo0`000003ooooo`007?ooool4o`0000Gooooo
00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`007?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Oooool001cooooo1Ol00004
ooooo`03o`000?oooooooooo06Gooooo0P00002=ooooo`0300000?oooooooooo007ooooo000Uoooo
o`03o`000?oooooooooo06Gooooo0P00002=ooooo`0300000?oooooooooo007ooooo000Uooooo`03
o`000?oooooooooo0?Cooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0
m?ooool00`00003oooooooooo`01ooooo`009Oooool2o`000?Cooooo00?o000000000?ooool00_oo
ool002Gooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`009Oooool00ol0
003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo0?Co
oooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0K?ooool2000008Kooooo
00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0K?ooool2000008Kooooo00<0
0000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01
ooooo`009Oooool00ol0003oooooooooo`3dooooo`0300000?oooooooooo007ooooo000Uooooo`;o
0000m?ooool00ol000000000ooooo`02ooooo`009Oooool00ol0003oooooooooo`3dooooo`030000
0?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo0;Sooooo0P00000jooooo`0300000?oo
oooooooo007ooooo000Uooooo`03o`000?oooooooooo0;Sooooo0P00000jooooo`0300000?oooooo
oooo007ooooo000Uooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Oooool002Go
oooo00?o0000ooooooooool0M?ooool2000007kooooo00<00000ooooooooool00Oooool002Gooooo
00?o0000ooooooooool0M?ooool2000007kooooo00<00000ooooooooool00Oooool002Gooooo00?o
0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`009Oooool2o`000;;ooooo0P00000=
ooooo`800000<Oooool00ol000000000ooooo`02ooooo`009Oooool00ol0003oooooooooo`2aoooo
o`8000003Oooool2000003;ooooo00<00000ooooooooool00Oooool002Gooooo00?o0000oooooooo
ool0m?ooool00`00003oooooooooo`01ooooo`009Oooool00ol0003oooooooooo`3dooooo`030000
0?oooooooooo007ooooo000Uooooo`03o`000?oooooooooo0?Cooooo00<00000ooooooooool00Ooo
ool002Gooooo00?o0000ooooooooool0m?ooool00`00003oooooooooo`01ooooo`009Oooool00ol0
003oooooooooo`1kooooo`800000Moooool00`00003oooooooooo`01ooooo`009Oooool2o`0007co
oooo0P00001fooooo`03o`000000003ooooo00;ooooo000Uooooo`03o`000?oooooooooo0:Wooooo
0P00000Looooo`800000:oooool00`00003oooooooooo`01ooooo`009Oooool00ol0003ooooooooo
o`2Yooooo`8000007?ooool2000002_ooooo00<00000ooooooooool00Oooool002Gooooo00?o0000
ooooooooool0m?ooool00`00003oooooooooo`01ooooo`009Oooool00ol0003oooooooooo`2Qoooo
o`800000DOooool00`00003oooooooooo`01ooooo`009Oooool00ol0003oooooooooo`2Qooooo`80
0000DOooool00`00003oooooooooo`01ooooo`007_ooool2o`0000Gooooo00?o0000ooooooooool0
Poooool2000001Gooooo0P00001Hooooo`0300000?oooooooooo007ooooo000Mooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0Poooool2000000Kooooo0P000005ooooo`800000
1_ooool2000003?ooooo0P00000Sooooo`0300000?oooooooooo007ooooo000Mooooo`04o`000?oo
ooooooooo`0000Cooooo0_l0002<ooooo`8000001Oooool2000003_ooooo0P000006ooooo`800000
6Oooool3000000?ooooo000Mooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
eoooool2000000Gooooo0P00000Dooooo`0300000?oooooooooo007ooooo000Mooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0g_ooool2000001Cooooo00<00000ooooooooool0
0Oooool001gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3Vooooo`800000
3?ooool00`00003oooooooooo`01ooooo`007_ooool2o`0000Gooooo00?o0000ooooooooool0i_oo
ool2000000cooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0kOooool2
000000Gooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool0kOooool20000
00Gooooo00<00000ooooooooool00Oooool002Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0;ooooo`0300000?oooooooooo007ooooo000UooooooH0000000?o000000000?ooool0
0_ooool00001\
\>"],
  ImageRangeCache->{{{73.4375, 302.812}, {501.75, 360.438}} -> {-17.7844, \
37.0386, 0.131867, 0.131163}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
This result can be compared to the positive Lyapunov exponent for \
this fixed point, which should be equal to the slope of the line in the \
previous plot.  The Lyapunov exponent of the fixed point is found by taking \
the natural log of the eigenvalues of the Jacobian matrix for the fixed point \
(see previous section).  Using the Jacobian given in the previous section we \
find:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(K = 1.5;\)\), "\[IndentingNewLine]", 
    \(\(Jac = {{1 + K, 1}, {K, 1}};\)\), "\[IndentingNewLine]", 
    \(Log[Eigenvalues[Jac]]\)}], "Input"],

Cell[BoxData[
    \({1.158810360429947`, \(-1.1588103604299467`\)}\)], "Output"]
}, Open  ]],

Cell["\<\
The slope of the line (for n<17) in the above plot is roughly given \
by\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((DList[\([16]\)] - DList[\([1]\)])\)/15\)], "Input"],

Cell[BoxData[
    \(1.151611231341415`\)], "Output"]
}, Open  ]],

Cell["So we see that the agreement between the two is good.", "Text"],

Cell[TextData[{
  "For a trajectory near a stable fixed point we would expect the slope of \
log(",
  Cell[BoxData[
      \(TraditionalForm\`d\_n\)]],
  ") vs. n to be zero.  The plot below demonstrates that this is the case for \
a trajectory near the stable periodic orbit at the origin for K=0.8."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(K = 0.8; \[Theta]1 = 0; r1 = 0; \[Theta]2 = 0.00000001; r2 = 0; 
    n = 30;\), "\n", 
    \(\(f[{\[Theta]_, r_}] := 
        N[{\[Theta] + r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]], 
            r - \((K/\((2*Pi)\))\)*Sin[2*Pi*\[Theta]]}];\)\), "\n", 
    \(\(L1 = NestList[f, {\[Theta]2, r2}, n];\)\), "\[IndentingNewLine]", 
    \(\(DList = 
        Table[Log[
            Sqrt[\((0.5 - L1[\([i, 1]\)])\)^2 + \((0 - 
                      L1[\([i, 2]\)])\)^2]], {i, 
            n + 1}];\)\), "\[IndentingNewLine]", 
    \(ListPlot[DList, Frame \[Rule] True, Axes \[Rule] False, 
      FrameLabel \[Rule] {"\<n\>", \*"\"\<Ln(\!\(d\_n\))\>\"", "\<\>", \
"\<\>"}, PlotStyle \[Rule] PointSize[0.01], 
      PlotRange \[Rule] {{0, 30}, {\(-10\), 1}}]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 0.0333333 0.561849 0.0561849 [
[.16667 -0.0125 -3 -9 ]
[.16667 -0.0125 3 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.5 -0.0125 -6 -9 ]
[.5 -0.0125 6 0 ]
[.66667 -0.0125 -6 -9 ]
[.66667 -0.0125 6 0 ]
[.83333 -0.0125 -6 -9 ]
[.83333 -0.0125 6 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .11237 -12 -4.5 ]
[-0.0125 .11237 0 4.5 ]
[-0.0125 .22474 -12 -4.5 ]
[-0.0125 .22474 0 4.5 ]
[-0.0125 .33711 -12 -4.5 ]
[-0.0125 .33711 0 4.5 ]
[-0.0125 .44948 -12 -4.5 ]
[-0.0125 .44948 0 4.5 ]
[-0.0125 .56185 -6 -4.5 ]
[-0.0125 .56185 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -24 -19.625 ]
[-0.01875 .30902 -12 19.625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 0 m
.16667 .00625 L
s
[(5)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(10)] .33333 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(15)] .5 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(20)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(25)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(30)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11237 m
.00625 .11237 L
s
[(-8)] -0.0125 .11237 1 0 Mshowa
0 .22474 m
.00625 .22474 L
s
[(-6)] -0.0125 .22474 1 0 Mshowa
0 .33711 m
.00625 .33711 L
s
[(-4)] -0.0125 .33711 1 0 Mshowa
0 .44948 m
.00625 .44948 L
s
[(-2)] -0.0125 .44948 1 0 Mshowa
0 .56185 m
.00625 .56185 L
s
[(0)] -0.0125 .56185 1 0 Mshowa
.125 Mabswid
0 .02809 m
.00375 .02809 L
s
0 .05618 m
.00375 .05618 L
s
0 .08428 m
.00375 .08428 L
s
0 .14046 m
.00375 .14046 L
s
0 .16855 m
.00375 .16855 L
s
0 .19665 m
.00375 .19665 L
s
0 .25283 m
.00375 .25283 L
s
0 .28092 m
.00375 .28092 L
s
0 .30902 m
.00375 .30902 L
s
0 .3652 m
.00375 .3652 L
s
0 .39329 m
.00375 .39329 L
s
0 .42139 m
.00375 .42139 L
s
0 .47757 m
.00375 .47757 L
s
0 .50566 m
.00375 .50566 L
s
0 .53376 m
.00375 .53376 L
s
0 .58994 m
.00375 .58994 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -98.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
80.625 10 translate
90 rotate
-80.625 -10 translate
0 20 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Ln) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
87.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.250 13.000 moveto
(L) show
98.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61178 m
0 .61803 L
s
.16667 .61178 m
.16667 .61803 L
s
.33333 .61178 m
.33333 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.66667 .61178 m
.66667 .61803 L
s
.83333 .61178 m
.83333 .61803 L
s
.125 Mabswid
.03333 .61428 m
.03333 .61803 L
s
.06667 .61428 m
.06667 .61803 L
s
.1 .61428 m
.1 .61803 L
s
.13333 .61428 m
.13333 .61803 L
s
.2 .61428 m
.2 .61803 L
s
.23333 .61428 m
.23333 .61803 L
s
.26667 .61428 m
.26667 .61803 L
s
.3 .61428 m
.3 .61803 L
s
.36667 .61428 m
.36667 .61803 L
s
.4 .61428 m
.4 .61803 L
s
.43333 .61428 m
.43333 .61803 L
s
.46667 .61428 m
.46667 .61803 L
s
.53333 .61428 m
.53333 .61803 L
s
.56667 .61428 m
.56667 .61803 L
s
.6 .61428 m
.6 .61803 L
s
.63333 .61428 m
.63333 .61803 L
s
.7 .61428 m
.7 .61803 L
s
.73333 .61428 m
.73333 .61803 L
s
.76667 .61428 m
.76667 .61803 L
s
.8 .61428 m
.8 .61803 L
s
.86667 .61428 m
.86667 .61803 L
s
.9 .61428 m
.9 .61803 L
s
.93333 .61428 m
.93333 .61803 L
s
.96667 .61428 m
.96667 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .11237 m
1 .11237 L
s
.99375 .22474 m
1 .22474 L
s
.99375 .33711 m
1 .33711 L
s
.99375 .44948 m
1 .44948 L
s
.99375 .56185 m
1 .56185 L
s
.125 Mabswid
.99625 .02809 m
1 .02809 L
s
.99625 .05618 m
1 .05618 L
s
.99625 .08428 m
1 .08428 L
s
.99625 .14046 m
1 .14046 L
s
.99625 .16855 m
1 .16855 L
s
.99625 .19665 m
1 .19665 L
s
.99625 .25283 m
1 .25283 L
s
.99625 .28092 m
1 .28092 L
s
.99625 .30902 m
1 .30902 L
s
.99625 .3652 m
1 .3652 L
s
.99625 .39329 m
1 .39329 L
s
.99625 .42139 m
1 .42139 L
s
.99625 .47757 m
1 .47757 L
s
.99625 .50566 m
1 .50566 L
s
.99625 .53376 m
1 .53376 L
s
.99625 .58994 m
1 .58994 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.01 w
.03333 .5229 Mdot
.06667 .5229 Mdot
.1 .5229 Mdot
.13333 .5229 Mdot
.16667 .5229 Mdot
.2 .5229 Mdot
.23333 .5229 Mdot
.26667 .5229 Mdot
.3 .5229 Mdot
.33333 .5229 Mdot
.36667 .5229 Mdot
.4 .5229 Mdot
.43333 .5229 Mdot
.46667 .5229 Mdot
.5 .5229 Mdot
.53333 .5229 Mdot
.56667 .5229 Mdot
.6 .5229 Mdot
.63333 .5229 Mdot
.66667 .5229 Mdot
.7 .5229 Mdot
.73333 .5229 Mdot
.76667 .5229 Mdot
.8 .5229 Mdot
.83333 .5229 Mdot
.86667 .5229 Mdot
.9 .5229 Mdot
.93333 .5229 Mdot
.96667 .5229 Mdot
1 .5229 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003ooooooolQ
ooooo`00oooooolQooooo`00oooooolQooooo`00oooooolQooooo`00Uoooool3o`000003ooooool0
003o000008?ooooo002Hooooo`04o`000?ooooooooooo`0008Cooooo002Hooooo`04o`000?oooooo
ooooo`0008Cooooo002Hooooo`04o`000?ooooooooooo`0008Cooooo002Gooooo`Co0000QOooool0
0?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool00?oooooo8Oooool004Kooooo0ol0000S
ooooo`?o00001?ooool2o`00023ooooo0ol00003ooooo`?o00008?ooool5o`0000?ooooo0_l0000O
ooooo`Go00000_ooool3o`00023ooooo0ol00004ooooo`;o00001_ooool004Gooooo00Go0000oooo
ooooooooooooo`00000Sooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00008?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool07_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0001oooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`000002ooooo`04o`00
0?ooooooooooo`0000Gooooo0019ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool0000Pooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00023ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Pooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool004Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`00023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0P
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool07_ooool2o`0000?ooooo00Co0000oooooooooooo0000
1Oooool004Gooooo1?l0000Tooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
8?ooool01?l0003oooooooooooooool4o`00023ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0001kooooo00Ko0000ooooooooooooooooo`000?ooool4o`0002?ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`00AOooool00ol0003ooooo
ooooo`0Tooooo`;o00001?ooool01?l0003oooooooooool0000Oooooo`;o00000oooool00ol0003o
ooooooooo`0Qooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0000N
ooooo`07o`000?ooooooooooooooool0003oooooo`00000Rooooo`05o`000?ooooooooooooooool0
00000_ooool01?l0003oooooooooool00005ooooo`00AOooool5o`0002?ooooo00?o0000oooooooo
ool00oooool2o`00027ooooo00Co0000oooooooooooooooo1Ol0000Pooooo`?o00001?ooool2o`00
023ooooo0ol00002ooooo`Go00007oooool3o`0000Cooooo0_l00006ooooo`00oooooolQooooo`00
oooooolQooooo`00oooooolQooooo`00oooooolQooooo`007ooooooho`0000Wooooo000Oooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool0
1oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`007oooool0
0ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo
0?Cooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003o
ooooooooo`07ooooo`007oooool2o`000?Cooooo0_l00009ooooo`007oooool00ol0003ooooooooo
o`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000
ooooooooool01oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07oooo
o`007oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`00
0?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0m?oo
ool00ol0003oooooooooo`07ooooo`007oooool2o`000?Cooooo0_l00009ooooo`007oooool00ol0
003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Co
oooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003ooooo
ooooo`07ooooo`007oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000O
ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo0_l0003doooo
o`;o00002Oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`00
7oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oo
oooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0m?ooool0
0ol0003oooooooooo`07ooooo`005oooool3o`0000Gooooo00?o0000ooooooooool0m?ooool00ol0
003oooooooooo`07ooooo`005_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool0m?ooool00ol0003oooooooooo`07ooooo`004?ooool5o`000003ooooool0003ooooo00;o
oooo00?o0000ooooooooool00_ooool2o`000??ooooo0ol00009ooooo`005oooool3o`0000Gooooo
00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`005_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`005_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0m?ooool00ol0003ooooo
ooooo`07ooooo`005oooool3o`0000Gooooo00?o0000ooooooooool0m?ooool00ol0003ooooooooo
o`07ooooo`007oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Ooooo
o`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo0_l0003dooooo`;o
00002Oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`007ooo
ool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooo
oooo0?Cooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0m?ooool00ol0
003oooooooooo`07ooooo`007oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oo
oooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo0_l0
003dooooo`;o00002Oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07
ooooo`007oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03
o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0
m?ooool00ol0003oooooooooo`07ooooo`007oooool00ol0003oooooooooo`3dooooo`03o`000?oo
oooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool0
01oooooo0_l0003dooooo`;o00002Oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003o
ooooooooo`07ooooo`007oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo
000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo00?o0000
ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`005oooool3o`0000Gooooo00?o0000oooo
ooooool0m?ooool00ol0003oooooooooo`07ooooo`005_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`004?ooool5o`000003
ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool2o`000??ooooo0ol00009ooooo`00
5_ooool4o`0000Gooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`005_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01ooo
ool001Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3dooooo`03o`000?oooooo
oooo00Oooooo000;ooooo`Go00002?ooool2o`0000Gooooo00?o0000ooooooooool0m?ooool00ol0
003oooooooooo`07ooooo`003?ooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo
0?Cooooo00?o0000ooooooooool01oooool000cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo013ooooo
0_l0003dooooo`;o00002Oooool000cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`3dooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`002oooool3o`000003ooooool0003o0000
00kooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`003?ooool01?l0003o
ooooooooool0000?ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool000co
oooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo
00Oooooo000<ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool0m?ooool00ol0
003oooooooooo`07ooooo`002oooool5o`0000oooooo0_l0003dooooo`;o00002Oooool000kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo
000=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0m?ooool00ol0003ooooooooo
o`07ooooo`003Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?Cooooo00?o0000
ooooooooool01oooool000gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3doooo
o`03o`000?oooooooooo00Oooooo000=ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0m?ooool00ol0003oooooooooo`07ooooo`003_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo0?Cooooo00?o0000ooooooooool01oooool000oooooo00?o0000ooooooooool03Ooo
ool2o`000?Cooooo0_l00009ooooo`003?ooool4o`0000oooooo00?o0000ooooooooool0m?ooool0
0ol0003oooooooooo`07ooooo`002oooool01?l0003oooooooooool0000@ooooo`03o`000?oooooo
oooo0?Cooooo00?o0000ooooooooool01oooool000_ooooo00Co0000oooooooooooo00004?ooool0
0ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000;ooooo`04o`000?oooooooooo
o`00013ooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`003?ooool3o`00
00Wooooo0ol00004ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool000ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?Co
oooo00?o0000ooooooooool01oooool000gooooo0_l000000ooooooo0000o`000003o`000003oooo
ool0003o000000?o00001?ooool2o`000??ooooo0ol00009ooooo`003_ooool00ol0003oooooo`00
0005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0m?ooool00ol0003ooooo
ooooo`07ooooo`003_ooool00ol0003oooooo`000006ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`003_ooool3o`0000Oooooo0_l00005
ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool000cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?Cooooo00?o0000oooo
ooooool01oooool000gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3dooooo`03
o`000?oooooooooo00Oooooo000>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
m?ooool00ol0003oooooooooo`07ooooo`003_ooool00ol0003oooooooooo`0>ooooo`;o0000m?oo
ool2o`0000Wooooo000>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0m?ooool0
0ol0003oooooooooo`07ooooo`003_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
0?Cooooo00?o0000ooooooooool01oooool000gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000<ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`007oooool00ol0003ooooooooo
o`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000
ooooooooool01oooool001oooooo0_l0003dooooo`;o00002Oooool001oooooo00?o0000oooooooo
ool0m?ooool00ol0003oooooooooo`07ooooo`007oooool00ol0003oooooooooo`3dooooo`03o`00
0?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01ooo
ool001oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`007oooool00ol0
003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Co
oooo00?o0000ooooooooool01oooool001oooooo0_l0003dooooo`;o00002Oooool001oooooo00?o
0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`007oooool00ol0003oooooooooo`3d
ooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000oooo
ooooool01oooool001Kooooo1Ol00004ooooo`03o`000?oooooooooo0?Cooooo00?o0000oooooooo
ool01oooool001Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3dooooo`03
o`000?oooooooooo00Oooooo000@ooooo`Go00000oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001Wooooo00?o0000ooooooooool00ooo
ool2o`000??ooooo0ol00009ooooo`005_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`005_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`005oooool3
o`0000Gooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`007oooool00ol0
003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Co
oooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003ooooo
ooooo`07ooooo`007oooool2o`000?Cooooo0_l00009ooooo`007oooool00ol0003oooooooooo`3d
ooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000oooo
ooooool01oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`00
7oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oo
oooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0m?ooool0
0ol0003oooooooooo`07ooooo`007oooool2o`000?Cooooo0_l00009ooooo`007oooool00ol0003o
ooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`03o`000?oooooooooo0?Cooooo
00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0m?ooool00ol0003ooooooooo
o`07ooooo`007oooool00ol0003oooooooooo`04ooooo`8000001_ooool2000000Oooooo0P000006
ooooo`8000001_ooool2000000Kooooo0P000007ooooo`8000001_ooool2000000Kooooo0P000006
ooooo`8000001oooool2000000Kooooo0P000006ooooo`8000001_ooool2000000Oooooo0P000006
ooooo`8000001_ooool2000000Kooooo0P000007ooooo`8000001_ooool2000000Kooooo0P000006
ooooo`8000001oooool2000000Kooooo0P000006ooooo`8000001_ooool2000000Oooooo0P000006
ooooo`8000001_ooool2000000Kooooo0P000009ooooo`007oooool00ol0003oooooooooo`04oooo
o`8000001_ooool2000000Oooooo0P000006ooooo`8000001_ooool2000000Kooooo0P000007oooo
o`8000001_ooool2000000Kooooo0P000006ooooo`8000001oooool2000000Kooooo0P000006oooo
o`8000001_ooool2000000Oooooo0P000006ooooo`8000001_ooool2000000Kooooo0P000007oooo
o`8000001_ooool2000000Kooooo0P000006ooooo`8000001oooool2000000Kooooo0P000006oooo
o`8000001_ooool2000000Oooooo0P000006ooooo`8000001_ooool2000000Kooooo0P000009oooo
o`007oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Oooooo`;o0000
m?ooool2o`0000Wooooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01ooo
ool001oooooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`007oooool00ol0
003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Hooooo`;o00001Oooool00ol0003o
ooooooooo`3dooooo`03o`000?oooooooooo00Oooooo000Gooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`005oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001Oooooo
00Co0000oooooooooooo00001?ooool2o`000??ooooo0ol00009ooooo`005oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001Oooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oo
oooo000Hooooo`;o00001Oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Oooooo
000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo00?o0000
ooooooooool0m?ooool00ol0003oooooooooo`07ooooo`007oooool00ol0003oooooooooo`3doooo
o`03o`000?oooooooooo00Oooooo000Oooooo`;o0000m?ooool2o`0000Wooooo000Oooooo`03o`00
0?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001oooooo00?o0000ooooooooool0m?oo
ool00ol0003oooooooooo`07ooooo`007oooool00ol0003oooooooooo`3dooooo`03o`000?oooooo
oooo00Oooooo000Oooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01oooool001oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool01oooool001oooooon?l00009ooooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.78035, -11.7339, \
0.121306, 0.0719681}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 998}},
WindowSize->{520, 624},
WindowMargins->{{49, Automatic}, {Automatic, 19}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 36, 0, 52, "Subtitle"],
Cell[1815, 55, 713, 11, 158, "Text"],
Cell[2531, 68, 357, 6, 86, "Text"],

Cell[CellGroupData[{
Cell[2913, 78, 94, 4, 69, "Section"],
Cell[3010, 84, 622, 16, 104, "Text"],
Cell[3635, 102, 70, 0, 32, "Text"],
Cell[3708, 104, 261, 5, 75, "Input"],
Cell[3972, 111, 359, 9, 68, "Text"],

Cell[CellGroupData[{
Cell[4356, 124, 55, 1, 27, "Input"],
Cell[4414, 127, 76, 1, 27, "Output"]
}, Open  ]],
Cell[4505, 131, 188, 5, 50, "Text"],

Cell[CellGroupData[{
Cell[4718, 140, 59, 1, 27, "Input"],
Cell[4780, 143, 261, 5, 43, "Output"]
}, Open  ]],
Cell[5056, 151, 222, 7, 50, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5315, 163, 38, 0, 69, "Section"],
Cell[5356, 165, 784, 21, 140, "Text"],

Cell[CellGroupData[{
Cell[6165, 190, 727, 14, 203, "Input"],
Cell[6895, 206, 363528, 18028, 186, 304647, 17297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[370426, 18236, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[370605, 18245, 79, 0, 91, "Section"],
Cell[370687, 18247, 438, 7, 104, "Text"],
Cell[371128, 18256, 292, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[371445, 18266, 727, 14, 219, "Input"],
Cell[372175, 18282, 120530, 5678, 189, 99626, 5416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[492708, 23962, 130, 3, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[492875, 23970, 31, 0, 38, "Subsection"],
Cell[492909, 23972, 393, 9, 86, "Text"],

Cell[CellGroupData[{
Cell[493327, 23985, 725, 14, 235, "Input"],

Cell[CellGroupData[{
Cell[494077, 24003, 115574, 5643, 186, 100788, 5456, "GraphicsData", \
"PostScript", "Graphics"],
Cell[609654, 29648, 116360, 5652, 186, 100889, 5456, "GraphicsData", \
"PostScript", "Graphics"],
Cell[726017, 35302, 117278, 5665, 186, 100786, 5456, "GraphicsData", \
"PostScript", "Graphics"],
Cell[843298, 40969, 118802, 5682, 186, 100873, 5456, "GraphicsData", \
"PostScript", "Graphics"],
Cell[962103, 46653, 121030, 5710, 186, 100861, 5456, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1083136, 52365, 123812, 5745, 186, 100836, 5456, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1206951, 58112, 129240, 5812, 186, 100837, 5456, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[1336206, 63927, 928, 23, 42, "Output"]
}, Open  ]],
Cell[1337149, 63953, 121, 3, 50, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1337319, 63962, 36, 0, 69, "Section"],
Cell[1337358, 63964, 831, 15, 176, "Text"],

Cell[CellGroupData[{
Cell[1338214, 63983, 572, 10, 155, "Input"],
Cell[1338789, 63995, 242897, 11031, 164, 193438, 10416, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1581689, 75028, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1581868, 75037, 49, 0, 69, "Section"],
Cell[1581920, 75039, 214, 4, 68, "Text"],
Cell[1582137, 75045, 196, 5, 41, "Input"],
Cell[1582336, 75052, 125, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[1582486, 75059, 154, 3, 59, "Input"],
Cell[1582643, 75064, 39, 1, 27, "Output"]
}, Open  ]],
Cell[1582697, 75068, 149, 3, 50, "Text"],
Cell[1582849, 75073, 173, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[1583047, 75083, 163, 3, 59, "Input"],
Cell[1583213, 75088, 117, 2, 42, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1583367, 75095, 50, 1, 27, "Input"],
Cell[1583420, 75098, 151, 2, 51, "Output"]
}, Open  ]],
Cell[1583586, 75103, 86, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[1583697, 75108, 97, 2, 43, "Input"],
Cell[1583797, 75112, 76, 1, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1583910, 75118, 50, 1, 27, "Input"],
Cell[1583963, 75121, 136, 2, 27, "Output"]
}, Open  ]],
Cell[1584114, 75126, 685, 10, 158, "Text"],
Cell[1584802, 75138, 228, 4, 68, "Text"],

Cell[CellGroupData[{
Cell[1585055, 75146, 1568, 30, 443, "Input"],
Cell[1586626, 75178, 191, 3, 35, "Message"],

Cell[CellGroupData[{
Cell[1586842, 75185, 46200, 1647, 296, 19891, 1318, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1633045, 76834, 48216, 1655, 296, 19426, 1295, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1681264, 78491, 63200, 2340, 296, 31654, 1946, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1744479, 80834, 130, 3, 27, "Output"]
}, Open  ]],
Cell[1744624, 80840, 329, 6, 86, "Text"],
Cell[1744956, 80848, 263, 5, 68, "Text"],
Cell[1745222, 80855, 333, 9, 68, "Text"],
Cell[1745558, 80866, 55, 1, 27, "Input"],
Cell[1745616, 80869, 406, 7, 104, "Text"],
Cell[1746025, 80878, 177, 3, 59, "Input"],
Cell[1746205, 80883, 197, 6, 50, "Text"],

Cell[CellGroupData[{
Cell[1746427, 80893, 323, 6, 91, "Input"],
Cell[1746753, 80901, 86506, 2455, 284, 37880, 1850, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1833262, 83358, 130, 3, 27, "Output"]
}, Open  ]],
Cell[1833407, 83364, 258, 5, 68, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1833702, 83374, 36, 0, 69, "Section"],
Cell[1833741, 83376, 199, 4, 50, "Text"],
Cell[1833943, 83382, 625, 11, 140, "Text"],

Cell[CellGroupData[{
Cell[1834593, 83397, 1489, 32, 491, "Input"],

Cell[CellGroupData[{
Cell[1836107, 83433, 1111482, 58252, 186, 1084276, 57912, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2947592, 141687, 1115600, 58271, 186, 1083947, 57876, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4063195, 199960, 2202519, 115871, 186, 2162507, 115373, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6265729, 315834, 130, 3, 27, "Output"]
}, Open  ]],
Cell[6265874, 315840, 313, 6, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6266224, 315851, 64, 0, 91, "Section"],
Cell[6266291, 315853, 828, 12, 176, "Text"],

Cell[CellGroupData[{
Cell[6267144, 315869, 736, 14, 219, "Input"],
Cell[6267883, 315885, 24393, 755, 186, 8332, 552, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6292279, 316642, 130, 3, 27, "Output"]
}, Open  ]],
Cell[6292424, 316648, 408, 7, 104, "Text"],

Cell[CellGroupData[{
Cell[6292857, 316659, 167, 3, 59, "Input"],
Cell[6293027, 316664, 80, 1, 27, "Output"]
}, Open  ]],
Cell[6293122, 316668, 96, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[6293243, 316675, 74, 1, 27, "Input"],
Cell[6293320, 316678, 52, 1, 27, "Output"]
}, Open  ]],
Cell[6293387, 316682, 69, 0, 32, "Text"],
Cell[6293459, 316684, 312, 7, 68, "Text"],

Cell[CellGroupData[{
Cell[6293796, 316695, 784, 15, 235, "Input"],
Cell[6294583, 316712, 24535, 781, 186, 9253, 588, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6319121, 317495, 130, 3, 27, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

